Standard name | ST_INTERFERON_GAMMA_PATHWAY
Systematic name | M4170
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Interferon gamma pathway.
Full description |

Standard name | ST_WNT_CA2_CYCLIC_GMP_PATHWAY
Systematic name | M16518
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Wnt/Ca2+/cyclic GMP signaling.
Full description |

Standard name | ST_DIFFERENTIATION_PATHWAY_IN_PC12_CELLS
Systematic name | M2579
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Differentiation Pathway in PC12 Cells; this is a specific case of PAC1 Receptor Pathway.
Full description |

Standard name | ST_TUMOR_NECROSIS_FACTOR_PATHWAY
Systematic name | M18030
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Tumor Necrosis Factor Pathway.
Full description |

Standard name | ST_ERK1_ERK2_MAPK_PATHWAY
Systematic name | M4910
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | ERK1/ERK2 MAPK Pathway
Full description |

Standard name | ST_GA12_PATHWAY
Systematic name | M15743
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | G alpha 12 Pathway
Full description |

Standard name | ST_G_ALPHA_S_PATHWAY
Systematic name | M14775
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | G alpha s Pathway
Full description |

Standard name | ST_G_ALPHA_I_PATHWAY
Systematic name | M18342
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | G alpha i Pathway
Full description |

Standard name | ST_IL_13_PATHWAY
Systematic name | M17580
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Interleukin 13 (IL-13) Pathway
Full description |

Standard name | ST_P38_MAPK_PATHWAY
Systematic name | M12012
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | p38 MAPK Pathway
Full description |

Standard name | ST_JAK_STAT_PATHWAY
Systematic name | M5248
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Jak-STAT Pathway
Full description |

Standard name | ST_GRANULE_CELL_SURVIVAL_PATHWAY
Systematic name | M7871
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Granule Cell Survival Pathway is a specific case of more general PAC1 Receptor Pathway.
Full description |

Standard name | ST_ADRENERGIC
Systematic name | M19043
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Adrenergic Pathway
Full description |

Standard name | ST_INTEGRIN_SIGNALING_PATHWAY
Systematic name | M3270
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Integrin Signaling Pathway
Full description |

Standard name | ST_GAQ_PATHWAY
Systematic name | M7416
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | G alpha q Pathway
Full description |

Standard name | ST_GA13_PATHWAY
Systematic name | M12645
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | G alpha 13 Pathway
Full description |

Standard name | ST_STAT3_PATHWAY
Systematic name | M9174
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | STAT3 Pathway
Full description |

Standard name | ST_T_CELL_SIGNAL_TRANSDUCTION
Systematic name | M9526
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | T Cell Signal Transduction
Full description |

Standard name | ST_TYPE_I_INTERFERON_PATHWAY
Systematic name | M19336
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Type I Interferon (alpha/beta IFN) Pathway
Full description |

Standard name | ST_PAC1_RECEPTOR_PATHWAY
Systematic name | M599
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | PAC1 Receptor Pathway
Full description |

Standard name | ST_B_CELL_ANTIGEN_RECEPTOR
Systematic name | M3501
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | B Cell Antigen Receptor
Full description |

Standard name | ST_INTERLEUKIN_4_PATHWAY
Systematic name | M9378
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Interleukin 4 (IL-4) Pathway
Full description |

Standard name | ST_WNT_BETA_CATENIN_PATHWAY
Systematic name | M17761
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Wnt/beta-catenin Pathway
Full description |

Standard name | ST_JNK_MAPK_PATHWAY
Systematic name | M3721
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | JNK MAPK Pathway
Full description |

Standard name | ST_FAS_SIGNALING_PATHWAY
Systematic name | M8873
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Fas Signaling Pathway
Full description |

Standard name | ST_MYOCYTE_AD_PATHWAY
Systematic name | M2701
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Myocyte Adrenergic Pathway is a specific case of the generalized Adrenergic Pathway.
Full description |

Standard name | ST_PHOSPHOINOSITIDE_3_KINASE_PATHWAY
Systematic name | M14532
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | PI3K Pathway
Full description |

Standard name | REACTOME_REMOVAL_OF_THE_FLAP_INTERMEDIATE_FROM_THE_C_STRAND
Systematic name | M12363
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:REACTOME
Brief description | Removal of the Flap Intermediate from the C-strand
Full description |

Standard name | BLANCO_MELO_SARS_COV_1_INFECTION_MCR5_CELLS_UP
Systematic name | M34000
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SARS-CoV-1 infection (MRC5 cells, MOI: 3, 24hpi).
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_SARS_COV_1_INFECTION_MCR5_CELLS_DN
Systematic name | M34001
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SARS-CoV-1 infection (MRC5 cells, MOI: 3, 24hpi).
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_MERS_COV_INFECTION_MCR5_CELLS_UP
Systematic name | M34002
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MERS-CoV infection (MRC5 cells, MOI: 3, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_MERS_COV_INFECTION_MCR5_CELLS_DN
Systematic name | M34003
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MERS-CoV infection (MRC5 cells, MOI: 3, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_INFLUENZA_A_INFECTION_A594_CELLS_UP
Systematic name | M34004
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in IAV (A549 cells, MOI: 5, 9hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_INFLUENZA_A_INFECTION_A594_CELLS_DN
Systematic name | M34005
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in IAV (A549 cells, MOI: 5, 9hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_HUMAN_PARAINFLUENZA_VIRUS_3_INFECTION_A594_CELLS_UP
Systematic name | M34006
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HPIV3 (A549 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_HUMAN_PARAINFLUENZA_VIRUS_3_INFECTION_A594_CELLS_DN
Systematic name | M34007
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HPIV3 (A549 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_RESPIRATORY_SYNCYTIAL_VIRUS_INFECTION_A594_CELLS_UP
Systematic name | M34008
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RSV (A549 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_RESPIRATORY_SYNCYTIAL_VIRUS_INFECTION_A594_CELLS_DN
Systematic name | M34009
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in RSV (A549 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_INFECTION_A594_CELLS_UP
Systematic name | M34010
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SARS-CoV-2 infection (A549 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_INFECTION_A594_CELLS_DN
Systematic name | M34011
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SARS-CoV-2 infection (A549 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_INFECTION_CALU3_CELLS_UP
Systematic name | M34012
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SARS-CoV-2 infection (Calu-3 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_INFECTION_CALU3_CELLS_DN
Systematic name | M34013
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SARS-CoV-2 infection (Calu-3 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_LOW_MOI_INFECTION_A594_ACE2_EXPRESSING_CELLS_UP
Systematic name | M34014
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SARS-CoV-2 low MOI infection (ACE2 expressing A549 cells, MOI: 0.2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_LOW_MOI_INFECTION_A594_ACE2_EXPRESSING_CELLS_DN
Systematic name | M34015
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SARS-CoV-2 low MOI infection (ACE2 expressing A549 cells, MOI: 0.2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_INFECTION_A594_ACE2_EXPRESSING_CELLS_UP
Systematic name | M34016
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SARS-CoV-2 infection (ACE2 expressing A549 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_INFECTION_A594_ACE2_EXPRESSING_CELLS_DN
Systematic name | M34017
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SARS-CoV-2 infection (ACE2 expressing A549 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_INFECTION_A594_ACE2_EXPRESSING_CELLS_RUXOLITINIB_UP
Systematic name | M34018
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SARS-CoV-2 infection with Ruxolitinib (ACE2 expressing A549 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_INFECTION_A594_ACE2_EXPRESSING_CELLS_RUXOLITINIB_DN
Systematic name | M34019
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SARS-CoV-2 infection with Ruxolitinib (ACE2 expressing A549 cells, MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_BRONCHIAL_EPITHELIAL_CELLS_SARS_COV_2_INFECTION_UP
Systematic name | M34020
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated on infection of normal human bronchial epithelial cells by SARS-CoV-2 (MOI: 2, 24hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_BRONCHIAL_EPITHELIAL_CELLS_SARS_COV_2_INFECTION_DN
Systematic name | M34021
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description |
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_BETA_INTERFERON_TREATED_BRONCHIAL_EPITHELIAL_CELLS_UP
Systematic name | M34022
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated on treatment of normal human bronchial epithelial cells with beta interferon (hIFNB treatment 100u/ml, 4-12hrs).
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_BETA_INTERFERON_TREATED_BRONCHIAL_EPITHELIAL_CELLS_DN
Systematic name | M34023
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated on treatment of normal human bronchial epithelial cells with beta interferon (hIFNB treatment 100u/ml, 4-12hrs).
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_BRONCHIAL_EPITHELIAL_CELLS_INFLUENZA_A_INFECTION_UP
Systematic name | M34024
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated oninfection of normal human bronchial epithelial cells by Influenza A (MOI: 3, 12hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_BRONCHIAL_EPITHELIAL_CELLS_INFLUENZA_A_INFECTION_DN
Systematic name | M34025
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated oninfection of normal human bronchial epithelial cells by Influenza A (MOI: 3, 12hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_BRONCHIAL_EPITHELIAL_CELLS_INFLUENZA_A_DEL_NS1_INFECTION_UP
Systematic name | M34026
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated on infection of normal human bronchial epithelial cells by mutant Influenza A lacking its antiviral antagonist (IAV_NS1) (MOI: 3, 12hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_BRONCHIAL_EPITHELIAL_CELLS_INFLUENZA_A_DEL_NS1_INFECTION_DN
Systematic name | M34027
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated on infection of normal human bronchial epithelial cells by mutant Influenza A lacking its antiviral antagonist (IAV_NS1) (MOI: 3, 12hpi)
Full description | Analysis of the transcriptional response to SARS-CoV-2 compared with other respiratory viruses, including MERS-CoV, SARS-CoV-1 (SARS), human parainfluenza virus 3 (HPIV3), respiratory syncytial virus (RSV), and IAV.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_POS_PATIENT_LUNG_TISSUE_UP
Systematic name | M34028
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes strongly up-regulated (log2(FC)>3.58, padj<0.05) in post mortem lung tissue from COVID-19 patients vs uninfected biopsy.
Full description | Transcriptional profiling of post-mortem lung samples from COVID-19-positive patients compared with biopsied healthy lung tissue from uninfected individuals.

Standard name | BLANCO_MELO_COVID19_SARS_COV_2_POS_PATIENT_LUNG_TISSUE_DN
Systematic name | M34029
Organism | Homo sapiens
PMID | 32416070
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes strongly down-regulated (og2(FC)<-3.58, padj<0.05) in post mortem lung tissue from COVID-19 patients vs uninfected biopsy.
Full description | Transcriptional profiling of post-mortem lung samples from COVID-19-positive patients (N=2) compared with biopsied healthy lung tissue from uninfected individuals.

Standard name | BUFFA_HYPOXIA_METAGENE
Systematic name | M34030
Organism | Homo sapiens
PMID | 20087356
Authors |
Category | C2
Sub-category | CGP
Brief description | Common genes regulated by hypoxia across multiple head and neck and breast cancer clinical cohorts, and prognostic in multiple cancer types
Full description | Hypoxia is a key factor promoting solid tumour progression and resistance to therapy. Hypoxia biomarkers have the potential to predict prognosis and/or benefit from particular interventions. An approach combining knowledge of gene function and analysis of in vivo co-expression patterns was used to derive a gene expression signature of hypoxia. Specifically, previously validated hypoxia-regulated genes (seeds) were used to generate a co-expression network. To guarantee generality and robustness of this network, bootstrap was used to select genes that were consistently co-expressed with the hypoxia seeds in multiple cancers cohorts and across cancer types (three head and neck and five breast cancer clinical cohorts were used in this phase). Genes with the highest connectivity in the resulting co-expression gene network were extracted to form a hypoxia gene signature. This signature was highly enriched for hypoxia-regulated pathways, enriched for targets of the Hypoxia-Inducible Factor (HIF)-1 as determined in ChipSeq and HIF know-down experiments, and prognostic. Validation in independent data sets of head and neck, breast and lung cancer showed that this signature outperformed previously reported hypoxia gene signatures.

Standard name | chr10p11
Systematic name | M18358
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10p11
Full description |

Standard name | chr10p12
Systematic name | M16888
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10p12
Full description |

Standard name | chr10p13
Systematic name | M12412
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10p13
Full description |

Standard name | chr10p14
Systematic name | M2992
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10p14
Full description |

Standard name | chr10p15
Systematic name | M16648
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10p15
Full description |

Standard name | chr10q11
Systematic name | M7676
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10q11
Full description |

Standard name | chr10q21
Systematic name | M11384
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10q21
Full description |

Standard name | chr10q22
Systematic name | M558
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10q22
Full description |

Standard name | chr10q23
Systematic name | M1933
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10q23
Full description |

Standard name | chr10q24
Systematic name | M6304
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10q24
Full description |

Standard name | chr10q25
Systematic name | M17303
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10q25
Full description |

Standard name | chr10q26
Systematic name | M8014
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr10q26
Full description |

Standard name | chr11p11
Systematic name | M8254
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11p11
Full description |

Standard name | chr11p12
Systematic name | M6976
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11p12
Full description |

Standard name | chr11p13
Systematic name | M5824
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11p13
Full description |

Standard name | chr11p14
Systematic name | M19140
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11p14
Full description |

Standard name | chr11p15
Systematic name | M9514
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11p15
Full description |

Standard name | chr11q11
Systematic name | M3966
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11q11
Full description |

Standard name | chr11q12
Systematic name | M5761
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11q12
Full description |

Standard name | chr11q13
Systematic name | M11664
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11q13
Full description |

Standard name | chr11q14
Systematic name | M3443
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11q14
Full description |

Standard name | chr11q21
Systematic name | M18273
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11q21
Full description |

Standard name | chr11q22
Systematic name | M10823
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11q22
Full description |

Standard name | chr11q23
Systematic name | M831
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11q23
Full description |

Standard name | chr11q24
Systematic name | M18542
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11q24
Full description |

Standard name | chr11q25
Systematic name | M1628
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr11q25
Full description |

Standard name | chr12p11
Systematic name | M12062
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12p11
Full description |

Standard name | chr12p12
Systematic name | M18382
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12p12
Full description |

Standard name | chr12p13
Systematic name | M6845
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12p13
Full description |

Standard name | chr12q12
Systematic name | M11138
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12q12
Full description |

Standard name | chr12q13
Systematic name | M8020
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12q13
Full description |

Standard name | chr12q14
Systematic name | M7359
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12q14
Full description |

Standard name | chr12q15
Systematic name | M19138
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12q15
Full description |

Standard name | chr12q21
Systematic name | M12945
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12q21
Full description |

Standard name | chr12q22
Systematic name | M16212
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12q22
Full description |

Standard name | chr12q23
Systematic name | M18413
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12q23
Full description |

Standard name | chr12q24
Systematic name | M18147
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr12q24
Full description |

Standard name | chr13q11
Systematic name | M12340
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr13q11
Full description |

Standard name | chr13q12
Systematic name | M8835
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr13q12
Full description |

Standard name | chr13q13
Systematic name | M11694
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr13q13
Full description |

Standard name | chr13q14
Systematic name | M16785
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr13q14
Full description |

Standard name | chr13q21
Systematic name | M10019
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr13q21
Full description |

Standard name | chr13q22
Systematic name | M5158
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr13q22
Full description |

Standard name | chr13q31
Systematic name | M7051
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr13q31
Full description |

Standard name | chr13q32
Systematic name | M16825
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr13q32
Full description |

Standard name | chr13q33
Systematic name | M3924
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr13q33
Full description |

Standard name | chr13q34
Systematic name | M1302
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr13q34
Full description |

Standard name | chr14q11
Systematic name | M8787
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr14q11
Full description |

Standard name | chr14q12
Systematic name | M11846
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr14q12
Full description |

Standard name | chr14q13
Systematic name | M16500
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr14q13
Full description |

Standard name | chr14q21
Systematic name | M7803
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr14q21
Full description |

Standard name | chr14q22
Systematic name | M7052
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr14q22
Full description |

Standard name | chr14q23
Systematic name | M14773
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr14q23
Full description |

Standard name | chr14q24
Systematic name | M1258
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr14q24
Full description |

Standard name | chr14q31
Systematic name | M16850
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr14q31
Full description |

Standard name | chr14q32
Systematic name | M16134
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr14q32
Full description |

Standard name | chr15q11
Systematic name | M11848
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q11
Full description |

Standard name | chr15q12
Systematic name | M22104
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q12
Full description |

Standard name | chr15q13
Systematic name | M11097
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q13
Full description |

Standard name | chr15q14
Systematic name | M11310
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q14
Full description |

Standard name | chr15q15
Systematic name | M7154
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q15
Full description |

Standard name | chr15q21
Systematic name | M3959
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q21
Full description |

Standard name | chr15q22
Systematic name | M2335
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q22
Full description |

Standard name | chr15q23
Systematic name | M15373
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q23
Full description |

Standard name | chr15q24
Systematic name | M9231
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q24
Full description |

Standard name | chr15q25
Systematic name | M5764
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q25
Full description |

Standard name | chr15q26
Systematic name | M18957
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr15q26
Full description |

Standard name | chr16p11
Systematic name | M13160
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr16p11
Full description |

Standard name | chr16p12
Systematic name | M17179
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr16p12
Full description |

Standard name | chr16p13
Systematic name | M9048
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr16p13
Full description |

Standard name | chr16q11
Systematic name | M19266
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr16q11
Full description |

Standard name | chr16q12
Systematic name | M8333
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr16q12
Full description |

Standard name | chr16q13
Systematic name | M2272
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr16q13
Full description |

Standard name | chr16q21
Systematic name | M14505
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr16q21
Full description |

Standard name | chr16q22
Systematic name | M10488
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr16q22
Full description |

Standard name | chr16q23
Systematic name | M2744
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr16q23
Full description |

Standard name | chr16q24
Systematic name | M9818
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr16q24
Full description |

Standard name | chr17p11
Systematic name | M9816
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr17p11
Full description |

Standard name | chr17p12
Systematic name | M10133
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr17p12
Full description |

Standard name | chr17p13
Systematic name | M9760
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr17p13
Full description |

Standard name | chr17q11
Systematic name | M11706
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr17q11
Full description |

Standard name | chr17q12
Systematic name | M3433
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr17q12
Full description |

Standard name | chr17q21
Systematic name | M8783
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr17q21
Full description |

Standard name | chr17q22
Systematic name | M16047
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr17q22
Full description |

Standard name | chr17q23
Systematic name | M19737
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr17q23
Full description |

Standard name | chr17q24
Systematic name | M4340
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr17q24
Full description |

Standard name | chr17q25
Systematic name | M8281
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr17q25
Full description |

Standard name | chr18p11
Systematic name | M4748
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr18p11
Full description |

Standard name | chr18q11
Systematic name | M16558
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr18q11
Full description |

Standard name | chr18q12
Systematic name | M12525
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr18q12
Full description |

Standard name | chr18q21
Systematic name | M19127
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr18q21
Full description |

Standard name | chr18q22
Systematic name | M14543
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr18q22
Full description |

Standard name | chr18q23
Systematic name | M8988
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr18q23
Full description |

Standard name | chr19p12
Systematic name | M13706
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr19p12
Full description |

Standard name | chr19p13
Systematic name | M17751
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr19p13
Full description |

Standard name | chr19q12
Systematic name | M9758
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr19q12
Full description |

Standard name | chr19q13
Systematic name | M561
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr19q13
Full description |

Standard name | chr1p11
Systematic name | M12793
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p11
Full description |

Standard name | chr1p12
Systematic name | M14892
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p12
Full description |

Standard name | chr1p13
Systematic name | M6974
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p13
Full description |

Standard name | chr1p21
Systematic name | M16131
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p21
Full description |

Standard name | chr1p22
Systematic name | M15893
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p22
Full description |

Standard name | chr1p31
Systematic name | M468
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p31
Full description |

Standard name | chr1p32
Systematic name | M5904
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p32
Full description |

Standard name | chr1p33
Systematic name | M978
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p33
Full description |

Standard name | chr1p34
Systematic name | M13304
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p34
Full description |

Standard name | chr1p35
Systematic name | M17536
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p35
Full description |

Standard name | chr1p36
Systematic name | M19292
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1p36
Full description |

Standard name | chr1q21
Systematic name | M17159
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q21
Full description |

Standard name | chr1q22
Systematic name | M13971
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q22
Full description |

Standard name | chr1q23
Systematic name | M5051
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q23
Full description |

Standard name | chr1q24
Systematic name | M5647
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q24
Full description |

Standard name | chr1q25
Systematic name | M19314
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q25
Full description |

Standard name | chr1q31
Systematic name | M9072
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q31
Full description |

Standard name | chr1q32
Systematic name | M5704
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q32
Full description |

Standard name | chr1q41
Systematic name | M8067
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q41
Full description |

Standard name | chr1q42
Systematic name | M9891
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q42
Full description |

Standard name | chr1q43
Systematic name | M15819
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q43
Full description |

Standard name | chr1q44
Systematic name | M15976
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr1q44
Full description |

Standard name | chr20p11
Systematic name | M18324
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr20p11
Full description |

Standard name | chr20p12
Systematic name | M5269
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr20p12
Full description |

Standard name | chr20p13
Systematic name | M3658
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr20p13
Full description |

Standard name | chr20q11
Systematic name | M1556
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr20q11
Full description |

Standard name | chr20q12
Systematic name | M15289
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr20q12
Full description |

Standard name | chr20q13
Systematic name | M6627
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr20q13
Full description |

Standard name | chr21p11
Systematic name | M16860
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr21p11
Full description |

Standard name | chr21p12
Systematic name | M22106
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr21p12
Full description |

Standard name | chr21q11
Systematic name | M4325
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr21q11
Full description |

Standard name | chr21q21
Systematic name | M19516
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr21q21
Full description |

Standard name | chr21q22
Systematic name | M15759
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr21q22
Full description |

Standard name | chr22q11
Systematic name | M9468
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr22q11
Full description |

Standard name | chr22q12
Systematic name | M35
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr22q12
Full description |

Standard name | chr22q13
Systematic name | M17432
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr22q13
Full description |

Standard name | chr2p11
Systematic name | M14768
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p11
Full description |

Standard name | chr2p12
Systematic name | M14784
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p12
Full description |

Standard name | chr2p13
Systematic name | M19967
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p13
Full description |

Standard name | chr2p14
Systematic name | M1082
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p14
Full description |

Standard name | chr2p15
Systematic name | M4165
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p15
Full description |

Standard name | chr2p16
Systematic name | M7078
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p16
Full description |

Standard name | chr2p21
Systematic name | M5325
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p21
Full description |

Standard name | chr2p22
Systematic name | M2264
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p22
Full description |

Standard name | chr2p23
Systematic name | M3211
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p23
Full description |

Standard name | chr2p24
Systematic name | M7378
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p24
Full description |

Standard name | chr2p25
Systematic name | M1027
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2p25
Full description |

Standard name | chr2q11
Systematic name | M1900
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q11
Full description |

Standard name | chr2q12
Systematic name | M10969
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q12
Full description |

Standard name | chr2q13
Systematic name | M6210
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q13
Full description |

Standard name | chr2q14
Systematic name | M16205
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q14
Full description |

Standard name | chr2q21
Systematic name | M7812
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q21
Full description |

Standard name | chr2q22
Systematic name | M12720
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q22
Full description |

Standard name | chr2q23
Systematic name | M4422
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q23
Full description |

Standard name | chr2q24
Systematic name | M13084
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q24
Full description |

Standard name | chr2q31
Systematic name | M9939
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q31
Full description |

Standard name | chr2q32
Systematic name | M4254
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q32
Full description |

Standard name | chr2q33
Systematic name | M7425
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q33
Full description |

Standard name | chr2q34
Systematic name | M680
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q34
Full description |

Standard name | chr2q35
Systematic name | M3890
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q35
Full description |

Standard name | chr2q36
Systematic name | M6742
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q36
Full description |

Standard name | chr2q37
Systematic name | M3783
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr2q37
Full description |

Standard name | chr3p11
Systematic name | M5512
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3p11
Full description |

Standard name | chr3p12
Systematic name | M16747
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3p12
Full description |

Standard name | chr3p13
Systematic name | M12640
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3p13
Full description |

Standard name | chr3p14
Systematic name | M16098
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3p14
Full description |

Standard name | chr3p21
Systematic name | M2833
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3p21
Full description |

Standard name | chr3p22
Systematic name | M13652
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3p22
Full description |

Standard name | chr3p23
Systematic name | M4690
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3p23
Full description |

Standard name | chr3p24
Systematic name | M2406
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3p24
Full description |

Standard name | chr3p25
Systematic name | M9355
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3p25
Full description |

Standard name | chr3p26
Systematic name | M17645
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3p26
Full description |

Standard name | chr3q11
Systematic name | M5965
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q11
Full description |

Standard name | chr3q12
Systematic name | M19018
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q12
Full description |

Standard name | chr3q13
Systematic name | M3650
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q13
Full description |

Standard name | chr3q21
Systematic name | M15073
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q21
Full description |

Standard name | chr3q22
Systematic name | M15482
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q22
Full description |

Standard name | chr3q23
Systematic name | M3522
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q23
Full description |

Standard name | chr3q24
Systematic name | M10226
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q24
Full description |

Standard name | chr3q25
Systematic name | M19593
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q25
Full description |

Standard name | chr3q26
Systematic name | M1166
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q26
Full description |

Standard name | chr3q27
Systematic name | M3066
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q27
Full description |

Standard name | chr3q28
Systematic name | M7149
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q28
Full description |

Standard name | chr3q29
Systematic name | M7979
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr3q29
Full description |

Standard name | chr4p11
Systematic name | M14148
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4p11
Full description |

Standard name | chr4p12
Systematic name | M11919
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4p12
Full description |

Standard name | chr4p13
Systematic name | M4395
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4p13
Full description |

Standard name | chr4p14
Systematic name | M7314
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4p14
Full description |

Standard name | chr4p15
Systematic name | M18463
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4p15
Full description |

Standard name | chr4p16
Systematic name | M13675
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4p16
Full description |

Standard name | chr4q12
Systematic name | M19512
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q12
Full description |

Standard name | chr4q13
Systematic name | M1196
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q13
Full description |

Standard name | chr4q21
Systematic name | M16904
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q21
Full description |

Standard name | chr4q22
Systematic name | M14925
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q22
Full description |

Standard name | chr4q23
Systematic name | M8230
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q23
Full description |

Standard name | chr4q24
Systematic name | M10517
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q24
Full description |

Standard name | chr4q25
Systematic name | M10155
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q25
Full description |

Standard name | chr4q26
Systematic name | M6
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q26
Full description |

Standard name | chr4q27
Systematic name | M9454
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q27
Full description |

Standard name | chr4q28
Systematic name | M2374
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q28
Full description |

Standard name | chr4q31
Systematic name | M352
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q31
Full description |

Standard name | chr4q32
Systematic name | M1042
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q32
Full description |

Standard name | chr4q33
Systematic name | M16179
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q33
Full description |

Standard name | chr4q34
Systematic name | M11154
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q34
Full description |

Standard name | chr4q35
Systematic name | M13505
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr4q35
Full description |

Standard name | chr5p12
Systematic name | M8999
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5p12
Full description |

Standard name | chr5p13
Systematic name | M7377
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5p13
Full description |

Standard name | chr5p14
Systematic name | M4419
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5p14
Full description |

Standard name | chr5p15
Systematic name | M4573
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5p15
Full description |

Standard name | chr5q11
Systematic name | M17254
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q11
Full description |

Standard name | chr5q12
Systematic name | M15354
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q12
Full description |

Standard name | chr5q13
Systematic name | M8852
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q13
Full description |

Standard name | chr5q14
Systematic name | M7445
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q14
Full description |

Standard name | chr5q15
Systematic name | M16652
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q15
Full description |

Standard name | chr5q21
Systematic name | M15387
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q21
Full description |

Standard name | chr5q22
Systematic name | M4614
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q22
Full description |

Standard name | chr5q23
Systematic name | M6743
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q23
Full description |

Standard name | chr5q31
Systematic name | M17266
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q31
Full description |

Standard name | chr5q32
Systematic name | M16682
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q32
Full description |

Standard name | chr5q33
Systematic name | M3856
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q33
Full description |

Standard name | chr5q34
Systematic name | M6164
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q34
Full description |

Standard name | chr5q35
Systematic name | M652
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr5q35
Full description |

Standard name | chr6p11
Systematic name | M3762
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6p11
Full description |

Standard name | chr6p12
Systematic name | M1251
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6p12
Full description |

Standard name | chr6p21
Systematic name | M5918
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6p21
Full description |

Standard name | chr6p22
Systematic name | M6858
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6p22
Full description |

Standard name | chr6p23
Systematic name | M8412
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6p23
Full description |

Standard name | chr6p24
Systematic name | M10754
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6p24
Full description |

Standard name | chr6p25
Systematic name | M12151
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6p25
Full description |

Standard name | chr6q11
Systematic name | M22108
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q11
Full description |

Standard name | chr6q12
Systematic name | M10788
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q12
Full description |

Standard name | chr6q13
Systematic name | M3564
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q13
Full description |

Standard name | chr6q14
Systematic name | M18282
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q14
Full description |

Standard name | chr6q15
Systematic name | M10005
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q15
Full description |

Standard name | chr6q16
Systematic name | M8015
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q16
Full description |

Standard name | chr6q21
Systematic name | M7941
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q21
Full description |

Standard name | chr6q22
Systematic name | M18476
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q22
Full description |

Standard name | chr6q23
Systematic name | M18346
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q23
Full description |

Standard name | chr6q24
Systematic name | M548
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q24
Full description |

Standard name | chr6q25
Systematic name | M12253
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q25
Full description |

Standard name | chr6q26
Systematic name | M13442
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q26
Full description |

Standard name | chr6q27
Systematic name | M15574
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr6q27
Full description |

Standard name | chr7p11
Systematic name | M4445
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7p11
Full description |

Standard name | chr7p12
Systematic name | M18930
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7p12
Full description |

Standard name | chr7p13
Systematic name | M14982
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7p13
Full description |

Standard name | chr7p14
Systematic name | M5362
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7p14
Full description |

Standard name | chr7p15
Systematic name | M9460
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7p15
Full description |

Standard name | chr7p21
Systematic name | M6353
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7p21
Full description |

Standard name | chr7p22
Systematic name | M11827
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7p22
Full description |

Standard name | chr7q11
Systematic name | M14961
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7q11
Full description |

Standard name | chr7q21
Systematic name | M5717
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7q21
Full description |

Standard name | chr7q22
Systematic name | M3562
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7q22
Full description |

Standard name | chr7q31
Systematic name | M17858
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7q31
Full description |

Standard name | chr7q32
Systematic name | M13228
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7q32
Full description |

Standard name | chr7q33
Systematic name | M6674
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7q33
Full description |

Standard name | chr7q34
Systematic name | M4734
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7q34
Full description |

Standard name | chr7q35
Systematic name | M1601
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7q35
Full description |

Standard name | chr7q36
Systematic name | M6828
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr7q36
Full description |

Standard name | chr8p11
Systematic name | M3546
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8p11
Full description |

Standard name | chr8p12
Systematic name | M15013
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8p12
Full description |

Standard name | chr8p21
Systematic name | M12581
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8p21
Full description |

Standard name | chr8p22
Systematic name | M5111
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8p22
Full description |

Standard name | chr8p23
Systematic name | M6734
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8p23
Full description |

Standard name | chr8q11
Systematic name | M1661
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8q11
Full description |

Standard name | chr8q12
Systematic name | M19083
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8q12
Full description |

Standard name | chr8q13
Systematic name | M1691
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8q13
Full description |

Standard name | chr8q21
Systematic name | M19006
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8q21
Full description |

Standard name | chr8q22
Systematic name | M1438
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8q22
Full description |

Standard name | chr8q23
Systematic name | M2400
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8q23
Full description |

Standard name | chr8q24
Systematic name | M248
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr8q24
Full description |

Standard name | chr9p11
Systematic name | M11604
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9p11
Full description |

Standard name | chr9p12
Systematic name | M16630
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9p12
Full description |

Standard name | chr9p13
Systematic name | M13208
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9p13
Full description |

Standard name | chr9p21
Systematic name | M5933
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9p21
Full description |

Standard name | chr9p22
Systematic name | M693
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9p22
Full description |

Standard name | chr9p23
Systematic name | M9820
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9p23
Full description |

Standard name | chr9p24
Systematic name | M7601
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9p24
Full description |

Standard name | chr9q12
Systematic name | M6797
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9q12
Full description |

Standard name | chr9q13
Systematic name | M6608
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9q13
Full description |

Standard name | chr9q21
Systematic name | M17819
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9q21
Full description |

Standard name | chr9q22
Systematic name | M14776
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9q22
Full description |

Standard name | chr9q31
Systematic name | M7882
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9q31
Full description |

Standard name | chr9q32
Systematic name | M445
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9q32
Full description |

Standard name | chr9q33
Systematic name | M9194
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9q33
Full description |

Standard name | chr9q34
Systematic name | M2896
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chr9q34
Full description |

Standard name | chrXp11
Systematic name | M22110
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXp11
Full description |

Standard name | chrXp21
Systematic name | M22111
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXp21
Full description |

Standard name | chrXp22
Systematic name | M22112
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXp22
Full description |

Standard name | chrXq11
Systematic name | M22113
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq11
Full description |

Standard name | chrXq12
Systematic name | M22114
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq12
Full description |

Standard name | chrXq13
Systematic name | M22115
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq13
Full description |

Standard name | chrXq21
Systematic name | M22116
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq21
Full description |

Standard name | chrXq22
Systematic name | M22117
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq22
Full description |

Standard name | chrXq23
Systematic name | M22118
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq23
Full description |

Standard name | chrXq24
Systematic name | M22119
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq24
Full description |

Standard name | chrXq25
Systematic name | M22120
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq25
Full description |

Standard name | chrXq26
Systematic name | M22121
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq26
Full description |

Standard name | chrXq27
Systematic name | M22122
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq27
Full description |

Standard name | chrXq28
Systematic name | M22123
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrXq28
Full description |

Standard name | chrYp11
Systematic name | M22124
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrYp11
Full description |

Standard name | chrYq11
Systematic name | M22125
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band chrYq11
Full description |

Standard name | MT
Systematic name | M22127
Organism | Homo sapiens
PMID |
Authors |
Category | C1
Sub-category |
Brief description | Ensembl 101 Genes in Cytogenetic Band MT
Full description |

Standard name | NAKAMURA_CANCER_MICROENVIRONMENT_UP
Systematic name | M7581
Organism | Homo sapiens
PMID | 17210693
Authors | Nakamura T,Fidler IJ,Coombes KR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pancreatic cancer cells grown in orthotopic xenograft tumors compared to those grown in vitro.
Full description | To determine the influence of the microenvironment on changes in gene expression, we did microarray analysis on three variant lines of a human pancreatic cancer (FG, L3.3, and L3.6pl) with different metastatic potentials. The variant lines were grown in tissue culture in the subcutis (ectopic) or pancreas (orthotopic) of nude mice. Compared with tissue culture, the number of genes of which the expression was affected by the microenvironment was up-regulated in tumors growing in the subcutis and pancreas. In addition, highly metastatic L3.6pl cells growing in the pancreas expressed significantly higher levels of 226 genes than did the L3.3 or FG variant cells. Growth of the variant lines in the subcutis did not yield similar results, indicating that the orthotopic microenvironment significantly influences gene expression in pancreatic cancer cells. These data suggest that investigations of the functional consequence of gene expression require accounting for experimental growth conditions.

Standard name | NAKAMURA_CANCER_MICROENVIRONMENT_DN
Systematic name | M2427
Organism | Homo sapiens
PMID | 17210693
Authors | Nakamura T,Fidler IJ,Coombes KR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pancreatic cancer cells grown in orthotopic xenograft tumors compared to those grown in vitro.
Full description | To determine the influence of the microenvironment on changes in gene expression, we did microarray analysis on three variant lines of a human pancreatic cancer (FG, L3.3, and L3.6pl) with different metastatic potentials. The variant lines were grown in tissue culture in the subcutis (ectopic) or pancreas (orthotopic) of nude mice. Compared with tissue culture, the number of genes of which the expression was affected by the microenvironment was up-regulated in tumors growing in the subcutis and pancreas. In addition, highly metastatic L3.6pl cells growing in the pancreas expressed significantly higher levels of 226 genes than did the L3.3 or FG variant cells. Growth of the variant lines in the subcutis did not yield similar results, indicating that the orthotopic microenvironment significantly influences gene expression in pancreatic cancer cells. These data suggest that investigations of the functional consequence of gene expression require accounting for experimental growth conditions.

Standard name | WEST_ADRENOCORTICAL_TUMOR_MARKERS_UP
Systematic name | M205
Organism | Homo sapiens
PMID | 17234769
Authors | West AN,Neale GA,Pounds S,Figueredo BC,Rodriguez Galindo C,Pianovski MA,Oliveira Filho AG,Malkin D,Lalli E,Ribeiro R,Zambetti GP
Category | C2
Sub-category | CGP
Brief description | Top up-regulated genes in pediatric adrenocortical tumors (ACT) compared to the normal tissue.
Full description | Pediatric adrenocortical tumors (ACT) are rare and often fatal malignancies; little is known regarding their etiology and biology. To provide additional insight into the nature of ACT, we determined the gene expression profiles of 24 pediatric tumors (five adenomas, 18 carcinomas, and one undetermined) and seven normal adrenal glands. Distinct patterns of gene expression, validated by quantitative real-time PCR and Western blot analysis, were identified that distinguish normal adrenal cortex from tumor. Differences in gene expression were also identified between adrenocortical adenomas and carcinomas. In addition, pediatric adrenocortical carcinomas were found to share similar patterns of gene expression when compared with those published for adult ACT. This study represents the first microarray analysis of childhood ACT. Our findings lay the groundwork for establishing gene expression profiles that may aid in the diagnosis and prognosis of pediatric ACT, and in the identification of signaling pathways that contribute to this disease.

Standard name | WEST_ADRENOCORTICAL_TUMOR_MARKERS_DN
Systematic name | M8321
Organism | Homo sapiens
PMID | 17234769
Authors | West AN,Neale GA,Pounds S,Figueredo BC,Rodriguez Galindo C,Pianovski MA,Oliveira Filho AG,Malkin D,Lalli E,Ribeiro R,Zambetti GP
Category | C2
Sub-category | CGP
Brief description | Top down-regulated genes in pediatric adrenocortical tumors (ACT) compared to the normal tissue.
Full description | Pediatric adrenocortical tumors (ACT) are rare and often fatal malignancies; little is known regarding their etiology and biology. To provide additional insight into the nature of ACT, we determined the gene expression profiles of 24 pediatric tumors (five adenomas, 18 carcinomas, and one undetermined) and seven normal adrenal glands. Distinct patterns of gene expression, validated by quantitative real-time PCR and Western blot analysis, were identified that distinguish normal adrenal cortex from tumor. Differences in gene expression were also identified between adrenocortical adenomas and carcinomas. In addition, pediatric adrenocortical carcinomas were found to share similar patterns of gene expression when compared with those published for adult ACT. This study represents the first microarray analysis of childhood ACT. Our findings lay the groundwork for establishing gene expression profiles that may aid in the diagnosis and prognosis of pediatric ACT, and in the identification of signaling pathways that contribute to this disease.

Standard name | WINTER_HYPOXIA_UP
Systematic name | M5466
Organism | Homo sapiens
PMID | 17409455
Authors | Winter SC,Buffa FM,Silva P,Miller C,Valentine HR,Turley H,Shah KA,Cox GJ,Corbridge RJ,Homer JJ,Musgrove B,Slevin N,Sloan P,Price P,West CM,Harris AL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in head and neck tumor samples which clustered around known hypoxia genes.
Full description | Affymetrix U133plus2 GeneChips were used to profile 59 head and neck squamous cell cancers. A hypoxia metagene was obtained by analysis of genes whose in vivo expression clustered with the expression of 10 well-known hypoxia-regulated genes (e.g., CA9, GLUT1, and VEGF). To minimize random aggregation, strongly correlated up-regulated genes appearing in >50% of clusters defined a signature comprising 99 genes, of which 27% were previously known to be hypoxia associated. The median RNA expression of the 99 genes in the signature was an independent prognostic factor for recurrence-free survival in a publicly available head and neck cancer data set, outdoing the original intrinsic classifier. In a published breast cancer series, the hypoxia signature was a significant prognostic factor for overall survival independent of clinicopathologic risk factors and a trained profile. The work highlights the validity and potential of using data from analysis of in vitro stress pathways for deriving a biological metagene/gene signature in vivo.

Standard name | WINTER_HYPOXIA_DN
Systematic name | M2683
Organism | Homo sapiens
PMID | 17409455
Authors | Winter SC,Buffa FM,Silva P,Miller C,Valentine HR,Turley H,Shah KA,Cox GJ,Corbridge RJ,Homer JJ,Musgrove B,Slevin N,Sloan P,Price P,West CM,Harris AL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in head and neck tumor samples which clustered around known hypoxia genes.
Full description | Affymetrix U133plus2 GeneChips were used to profile 59 head and neck squamous cell cancers. A hypoxia metagene was obtained by analysis of genes whose in vivo expression clustered with the expression of 10 well-known hypoxia-regulated genes (e.g., CA9, GLUT1, and VEGF). To minimize random aggregation, strongly correlated up-regulated genes appearing in >50% of clusters defined a signature comprising 99 genes, of which 27% were previously known to be hypoxia associated. The median RNA expression of the 99 genes in the signature was an independent prognostic factor for recurrence-free survival in a publicly available head and neck cancer data set, outdoing the original intrinsic classifier. In a published breast cancer series, the hypoxia signature was a significant prognostic factor for overall survival independent of clinicopathologic risk factors and a trained profile. The work highlights the validity and potential of using data from analysis of in vitro stress pathways for deriving a biological metagene/gene signature in vivo.

Standard name | PARENT_MTOR_SIGNALING_UP
Systematic name | M16909
Organism | Homo sapiens
PMID | 17483347
Authors | Parent R,Kolippakkam D,Booth G,Beretta L
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HepaRG cells (liver cancer) expressing constituvely active form of MTOR [GeneID=2475].
Full description | The mammalian target of rapamycin (mTOR) pathway, a major regulator of translation, is frequently activated in hepatocellular carcinomas. We investigated the effects of mTOR activation in the human HepaRG cells, which possess potent hepatocytic differentiation capability. Differentiation of HepaRG cells into functional and polarized hepatocyte-like cells correlated with a decrease in mTOR and Akt activities. Stable cell lines expressing an activated mutant of mTOR were generated. Sustained activation of mTOR impaired the hepatocytic differentiation capability of these cells as shown by impaired formation of bile canaliculi, absence of polarity, and reduced secretion of alpha1-antitrypsin. An inhibitor of mTOR, rapamycin, was able to revert this phenotype. Furthermore, increased mTOR activity in HepaRG cells resulted in their resistance to the antiproliferative effects of transforming growth factor-beta1. Profiling of polysome-bound transcripts indicated that activated mTOR specifically targeted genes posttranscriptionally regulated on hepatocytic differentiation. Three major biological networks targeted by activated mTOR were identified: (a) cell death associated with tumor necrosis factor superfamily members, IFNs and caspases; (b) lipid homeostasis associated with the transcription factors PPARalpha, PPARdelta, and retinoid X receptor beta; and (c) liver development associated with CCAAT/enhancer binding protein alpha and hepatic mitogens. In conclusion, increased mTOR activity conferred a preneoplastic phenotype to the HepaRG cells by altering the translation of genes vital for establishing normal hepatic energy homeostasis and moderating hepatocellular growth.

Standard name | PARENT_MTOR_SIGNALING_DN
Systematic name | M16644
Organism | Homo sapiens
PMID | 17483347
Authors | Parent R,Kolippakkam D,Booth G,Beretta L
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HepaRG cells (liver cancer) expressing constituvely active form of MTOR [GeneID=2475].
Full description | The mammalian target of rapamycin (mTOR) pathway, a major regulator of translation, is frequently activated in hepatocellular carcinomas. We investigated the effects of mTOR activation in the human HepaRG cells, which possess potent hepatocytic differentiation capability. Differentiation of HepaRG cells into functional and polarized hepatocyte-like cells correlated with a decrease in mTOR and Akt activities. Stable cell lines expressing an activated mutant of mTOR were generated. Sustained activation of mTOR impaired the hepatocytic differentiation capability of these cells as shown by impaired formation of bile canaliculi, absence of polarity, and reduced secretion of alpha1-antitrypsin. An inhibitor of mTOR, rapamycin, was able to revert this phenotype. Furthermore, increased mTOR activity in HepaRG cells resulted in their resistance to the antiproliferative effects of transforming growth factor-beta1. Profiling of polysome-bound transcripts indicated that activated mTOR specifically targeted genes posttranscriptionally regulated on hepatocytic differentiation. Three major biological networks targeted by activated mTOR were identified: (a) cell death associated with tumor necrosis factor superfamily members, IFNs and caspases; (b) lipid homeostasis associated with the transcription factors PPARalpha, PPARdelta, and retinoid X receptor beta; and (c) liver development associated with CCAAT/enhancer binding protein alpha and hepatic mitogens. In conclusion, increased mTOR activity conferred a preneoplastic phenotype to the HepaRG cells by altering the translation of genes vital for establishing normal hepatic energy homeostasis and moderating hepatocellular growth.

Standard name | PYEON_HPV_POSITIVE_TUMORS_UP
Systematic name | M7738
Organism | Homo sapiens
PMID | 17510386
Authors | Pyeon D,Newton MA,Lambert PF,den Boon JA,Sengupta S,Marsit CJ,Woodworth CD,Connor JP,Haugen TH,Smith EM,Kelsey KT,Turek LP,Ahlquist P
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in cervical carcinoma and head and neck tumors positive for human papilloma virus (HPV) compared to those negative for HPV.
Full description | Human papillomaviruses (HPV) are associated with nearly all cervical cancers, 20% to 30% of head and neck cancers (HNC), and other cancers. Because HNCs also arise in HPV-negative patients, this type of cancer provides unique opportunities to define similarities and differences of HPV-positive versus HPV-negative cancers arising in the same tissue. Here, we describe genome-wide expression profiling of 84 HNCs, cervical cancers, and site-matched normal epithelial samples in which we used laser capture microdissection to enrich samples for tumor-derived versus normal epithelial cells. This analysis revealed that HPV(+) HNCs and cervical cancers differed in their patterns of gene expression yet shared many changes compared with HPV(-) HNCs. Some of these shared changes were predicted, but many others were not. Notably, HPV(+) HNCs and cervical cancers were found to be up-regulated in their expression of a distinct and larger subset of cell cycle genes than that observed in HPV(-) HNC. Moreover, HPV(+) cancers overexpressed testis-specific genes that are normally expressed only in meiotic cells. Many, although not all, of the hallmark differences between HPV(+) HNC and HPV(-) HNC were a direct consequence of HPV and in particular the viral E6 and E7 oncogenes. This included a novel association of HPV oncogenes with testis-specific gene expression. These findings in primary human tumors provide novel biomarkers for early detection of HPV(+) and HPV(-) cancers, and emphasize the potential value of targeting E6 and E7 function, alone or combined with radiation and/or traditional chemotherapy, in the treatment of HPV(+) cancers.

Standard name | PYEON_HPV_POSITIVE_TUMORS_DN
Systematic name | M18367
Organism | Homo sapiens
PMID | 17510386
Authors | Pyeon D,Newton MA,Lambert PF,den Boon JA,Sengupta S,Marsit CJ,Woodworth CD,Connor JP,Haugen TH,Smith EM,Kelsey KT,Turek LP,Ahlquist P
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in cervical carcinoma and head and neck tumors positive for human papilloma virus (HPV) compared to those negative for HPV.
Full description | Human papillomaviruses (HPV) are associated with nearly all cervical cancers, 20% to 30% of head and neck cancers (HNC), and other cancers. Because HNCs also arise in HPV-negative patients, this type of cancer provides unique opportunities to define similarities and differences of HPV-positive versus HPV-negative cancers arising in the same tissue. Here, we describe genome-wide expression profiling of 84 HNCs, cervical cancers, and site-matched normal epithelial samples in which we used laser capture microdissection to enrich samples for tumor-derived versus normal epithelial cells. This analysis revealed that HPV(+) HNCs and cervical cancers differed in their patterns of gene expression yet shared many changes compared with HPV(-) HNCs. Some of these shared changes were predicted, but many others were not. Notably, HPV(+) HNCs and cervical cancers were found to be up-regulated in their expression of a distinct and larger subset of cell cycle genes than that observed in HPV(-) HNC. Moreover, HPV(+) cancers overexpressed testis-specific genes that are normally expressed only in meiotic cells. Many, although not all, of the hallmark differences between HPV(+) HNC and HPV(-) HNC were a direct consequence of HPV and in particular the viral E6 and E7 oncogenes. This included a novel association of HPV oncogenes with testis-specific gene expression. These findings in primary human tumors provide novel biomarkers for early detection of HPV(+) and HPV(-) cancers, and emphasize the potential value of targeting E6 and E7 function, alone or combined with radiation and/or traditional chemotherapy, in the treatment of HPV(+) cancers.

Standard name | NAKAMURA_TUMOR_ZONE_PERIPHERAL_VS_CENTRAL_UP
Systematic name | M16975
Organism | Homo sapiens
PMID | 17699763
Authors | Nakamura T,Kuwai T,Kitadai Y,Sasaki T,Fan D,Coombes KR,Kim SJ,Fidler IJ
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in peripheral zone of human pancreatic cancer growing in the pancreas of nude mice compared to that of the tumor from the central zone.
Full description | Using Affymetrix HG-U133 Plus 2.0 array and laser capture microdissection techniques, we determined whether different zones of the same pancreatic tumor exhibited differential expression of genes. Human L3.6pl pancreatic cancer cells were implanted into the pancreas of nude mice. Three weeks later when tumors were 7 to 9 mm in diameter, gene expression patterns in tumor cells within the central and peripheral zones were compared, and 1,222 genes showed statistically significant differences. Bioinformatic functional analysis revealed that 346 up-regulated genes in the peripheral zone were related to cytoskeleton organization and biogenesis, cell cycle, cell adhesion, cell motility, DNA replication, localization, integrin-mediated signaling pathway, development, morphogenesis, and IkappaB kinase/nuclear factor-kappaB cascade; 876 up-regulated genes in the central zone were related to regulation of cell proliferation, regulation of transcription, transmembrane receptor protein tyrosine kinase signaling pathways, response to stress, small GTPase-mediated signal transduction, hexose metabolism, cell death, response to external stimulus, carbohydrate metabolism, and response to wounding. The reliability of the microarray results were confirmed by in situ hybridization analysis of the expression of two genes. Collectively, the data showed zonal heterogeneity for gene expression profiles in tumors and suggest that characterization of zonal gene expression profiles is essential if microarray analyses of genetic profiles are to produce reproducible data, predict disease prognosis, and allow design of specific therapeutics.

Standard name | NAKAMURA_TUMOR_ZONE_PERIPHERAL_VS_CENTRAL_DN
Systematic name | M14371
Organism | Homo sapiens
PMID | 17699763
Authors | Nakamura T,Kuwai T,Kitadai Y,Sasaki T,Fan D,Coombes KR,Kim SJ,Fidler IJ
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in peripheral zone of human pancreatic cancer growing in the pancreas of nude mice compared to that of the tumor from the central zone.
Full description | Using Affymetrix HG-U133 Plus 2.0 array and laser capture microdissection techniques, we determined whether different zones of the same pancreatic tumor exhibited differential expression of genes. Human L3.6pl pancreatic cancer cells were implanted into the pancreas of nude mice. Three weeks later when tumors were 7 to 9 mm in diameter, gene expression patterns in tumor cells within the central and peripheral zones were compared, and 1,222 genes showed statistically significant differences. Bioinformatic functional analysis revealed that 346 up-regulated genes in the peripheral zone were related to cytoskeleton organization and biogenesis, cell cycle, cell adhesion, cell motility, DNA replication, localization, integrin-mediated signaling pathway, development, morphogenesis, and IkappaB kinase/nuclear factor-kappaB cascade; 876 up-regulated genes in the central zone were related to regulation of cell proliferation, regulation of transcription, transmembrane receptor protein tyrosine kinase signaling pathways, response to stress, small GTPase-mediated signal transduction, hexose metabolism, cell death, response to external stimulus, carbohydrate metabolism, and response to wounding. The reliability of the microarray results were confirmed by in situ hybridization analysis of the expression of two genes. Collectively, the data showed zonal heterogeneity for gene expression profiles in tumors and suggest that characterization of zonal gene expression profiles is essential if microarray analyses of genetic profiles are to produce reproducible data, predict disease prognosis, and allow design of specific therapeutics.

Standard name | PICCALUGA_ANGIOIMMUNOBLASTIC_LYMPHOMA_UP
Systematic name | M12225
Organism | Homo sapiens
PMID | 18006812
Authors | Piccaluga PP,Agostinelli C,Califano A,Carbone A,Fantoni L,Ferrari S,Gazzola A,Gloghini A,Righi S,Rossi M,Tagliafico E,Zinzani PL,Zupo S,Baccarani M,Pileri SA
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in angioimmunoblastic lymphoma (AILT) compared to normal T lymphocytes.
Full description | Angioimmunoblastic lymphoma (AILT) is the second most common subtype of peripheral T-cell lymphoma (PTCL) and is characterized by dismal prognosis. Thus far, only a few studies have dealt with its molecular pathogenesis. We performed gene expression profile (GEP) analysis of six AILT, six anaplastic large cell lymphomas (ALCL), 28 PTCL-unspecified (PTCL/U), and 20 samples of normal T lymphocytes (including CD4(+), CD8(+), and activated and resting subpopulations), aiming to (a) assess the relationship of AILT with other PTCLs, (b) establish the relationship between AILT and normal T-cell subsets, and (c) recognize the cellular programs deregulated in AILT possibly looking for novel potential therapeutic targets. First, we found that AILT and other PTCLs have rather similar GEP, possibly sharing common oncogenic pathways. Second, we found that AILTs are closer to activated CD4(+), rather than to resting or CD8(+) lymphocytes. Furthermore, we found that the molecular signature of follicular T helper cells was significantly overexpressed in AILT, reinforcing the idea that AILT may arise from such cellular counterpart. Finally, we identified several genes deregulated in AILT, including PDGFRA, REL, and VEGF. The expression of several molecules was then studied by immunohistochemistry on tissue microarrays containing 45 independent AILT cases. Notably, we found that the vascular endothelial growth factor (VEGF) was expressed not only by reactive cells, but also by neoplastic cells, and that nuclear factor-kappaB (NF-kappaB) activation is uncommon in AILT, as suggested by frequent exclusively cytoplasmic c-REL localization. Our study provides new relevant information on AILT biology and new candidates for possible therapeutic targets such as PDGFRA (platelet-derived growth factor alpha) and VEGF.

Standard name | PICCALUGA_ANGIOIMMUNOBLASTIC_LYMPHOMA_DN
Systematic name | M4781
Organism | Homo sapiens
PMID | 18006812
Authors | Piccaluga PP,Agostinelli C,Califano A,Carbone A,Fantoni L,Ferrari S,Gazzola A,Gloghini A,Righi S,Rossi M,Tagliafico E,Zinzani PL,Zupo S,Baccarani M,Pileri SA
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in angioimmunoblastic lymphoma (AILT) compared to normal T lymphocytes.
Full description | Angioimmunoblastic lymphoma (AILT) is the second most common subtype of peripheral T-cell lymphoma (PTCL) and is characterized by dismal prognosis. Thus far, only a few studies have dealt with its molecular pathogenesis. We performed gene expression profile (GEP) analysis of six AILT, six anaplastic large cell lymphomas (ALCL), 28 PTCL-unspecified (PTCL/U), and 20 samples of normal T lymphocytes (including CD4(+), CD8(+), and activated and resting subpopulations), aiming to (a) assess the relationship of AILT with other PTCLs, (b) establish the relationship between AILT and normal T-cell subsets, and (c) recognize the cellular programs deregulated in AILT possibly looking for novel potential therapeutic targets. First, we found that AILT and other PTCLs have rather similar GEP, possibly sharing common oncogenic pathways. Second, we found that AILTs are closer to activated CD4(+), rather than to resting or CD8(+) lymphocytes. Furthermore, we found that the molecular signature of follicular T helper cells was significantly overexpressed in AILT, reinforcing the idea that AILT may arise from such cellular counterpart. Finally, we identified several genes deregulated in AILT, including PDGFRA, REL, and VEGF. The expression of several molecules was then studied by immunohistochemistry on tissue microarrays containing 45 independent AILT cases. Notably, we found that the vascular endothelial growth factor (VEGF) was expressed not only by reactive cells, but also by neoplastic cells, and that nuclear factor-kappaB (NF-kappaB) activation is uncommon in AILT, as suggested by frequent exclusively cytoplasmic c-REL localization. Our study provides new relevant information on AILT biology and new candidates for possible therapeutic targets such as PDGFRA (platelet-derived growth factor alpha) and VEGF.

Standard name | LU_TUMOR_VASCULATURE_UP
Systematic name | M12769
Organism | Homo sapiens
PMID | 17308118
Authors | Lu C,Bonome T,Li Y,Kamat AA,Han LY,Schmandt R,Coleman RL,Gershenson DM,Jaffe RB,Birrer MJ,Sood AK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in endothelial cells derived from invasive ovarian cancer tissue.
Full description | Therapeutic strategies based on antiangiogenic approaches are beginning to show great promise in clinical studies. However, full realization of these approaches requires identification of key differences in gene expression between endothelial cells from tumors versus their normal counterparts. Here, we examined gene expression differences in purified endothelial cells from 10 invasive epithelial ovarian cancers and 5 normal ovaries using Affymetrix U133 Plus 2.0 microarrays. More than 400 differentially expressed genes were identified in tumor-associated endothelial cells. We selected and validated 23 genes that were overexpressed by 3.6- to 168-fold using real-time reverse transcription-PCR and/or immunohistochemistry. Among these, the polycomb group protein enhancer of Zeste homologue 2 (EZH2), the Notch ligand Jagged1, and PTK2 were elevated 3- to 4.3-fold in tumor-associated endothelial cells. Silencing these genes individually with small interfering RNA blocked endothelial cell migration and tube formation in vitro. The present study shows that tumor and normal endothelium differ at the molecular level, which may have significant implications for the development of antiangiogenic therapies.

Standard name | LU_TUMOR_VASCULATURE_DN
Systematic name | M14262
Organism | Homo sapiens
PMID | 17308118
Authors | Lu C,Bonome T,Li Y,Kamat AA,Han LY,Schmandt R,Coleman RL,Gershenson DM,Jaffe RB,Birrer MJ,Sood AK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in endothelial cells derived from invasive ovarian cancer tissue.
Full description | Therapeutic strategies based on antiangiogenic approaches are beginning to show great promise in clinical studies. However, full realization of these approaches requires identification of key differences in gene expression between endothelial cells from tumors versus their normal counterparts. Here, we examined gene expression differences in purified endothelial cells from 10 invasive epithelial ovarian cancers and 5 normal ovaries using Affymetrix U133 Plus 2.0 microarrays. More than 400 differentially expressed genes were identified in tumor-associated endothelial cells. We selected and validated 23 genes that were overexpressed by 3.6- to 168-fold using real-time reverse transcription-PCR and/or immunohistochemistry. Among these, the polycomb group protein enhancer of Zeste homologue 2 (EZH2), the Notch ligand Jagged1, and PTK2 were elevated 3- to 4.3-fold in tumor-associated endothelial cells. Silencing these genes individually with small interfering RNA blocked endothelial cell migration and tube formation in vitro. The present study shows that tumor and normal endothelium differ at the molecular level, which may have significant implications for the development of antiangiogenic therapies.

Standard name | KORKOLA_EMBRYONAL_CARCINOMA_UP
Systematic name | M12730
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes from the 12p region that were up-regulated in embryonic carcinoma tumors compared to normal testis.
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | KORKOLA_EMBRYONAL_CARCINOMA_DN
Systematic name | M12977
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes from the 12p region that were down-regulated in embryonic carcinoma tumors compared to normal tissue.
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | KORKOLA_TERATOMA_UP
Systematic name | M16021
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes from the 12p region that up-regulated in teratoma cells compared to normal testis.
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | KORKOLA_YOLK_SAC_TUMOR_UP
Systematic name | M18161
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes from the 12p region that were up-regulated in yolk sac tumor cells compared to normal testis.
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | KORKOLA_CHORIOCARCINOMA_UP
Systematic name | M14050
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes from the 12p region that were up-regulated in choriocarcinoma cells compared to normal testis.
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | KORKOLA_CHORIOCARCINOMA_DN
Systematic name | M11068
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes from the 12p region that were down-regulated in choriocarcinoma cells compared to normal testis.
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | KORKOLA_SEMINOMA_UP
Systematic name | M18387
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes from the 12p region that were up-regulated in seminoma tumors compared to normal testis.
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | KORKOLA_SEMINOMA_DN
Systematic name | M632
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes from the 12p region that were down-regulated in seminoma tumors compared to normal testis.
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | WATANABE_RECTAL_CANCER_RADIOTHERAPY_RESPONSIVE_UP
Systematic name | M1260
Organism | Homo sapiens
PMID | 16585155
Authors | Watanabe T,Komuro Y,Kiyomatsu T,Kanazawa T,Kazama Y,Tanaka J,Tanaka T,Yamamoto Y,Shirane M,Muto T,Nagawa H
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in rectal cancer patients resistant to radiotherapy (non-responders) relative to the sensitive ones (responders).
Full description | Preoperative radiotherapy has been widely used to improve local control of disease and to improve survival in the treatment of rectal cancer. However, the response to radiotherapy differs among individual tumors. Our objective here was to identify a set of discriminating genes that can be used for characterization and prediction of response to radiotherapy in rectal cancer. Fifty-two rectal cancer patients who underwent preoperative radiotherapy were studied. Biopsy specimens were obtained from rectal cancer before preoperative radiotherapy. Response to radiotherapy was determined by histopathologic examination of surgically resected specimens and classified as responders or nonresponders. By determining gene expression profiles using human U95Av2 Gene Chip, we identified 33 novel discriminating genes of which the expression differed significantly between responders and nonresponders. Using this gene set, we were able to establish a new model to predict response to radiotherapy in rectal cancer with an accuracy of 82.4%. The list of discriminating genes included growth factor, apoptosis, cell proliferation, signal transduction, or cell adhesion-related genes. Among 33 discriminating genes, apoptosis inducers (lumican, thrombospondin 2, and galectin-1) showed higher expression in responders whereas apoptosis inhibitors (cyclophilin 40 and glutathione peroxidase) showed higher expression in nonresponders. The present study suggested the possibility that gene expression profiling may be useful in predicting response to radiotherapy to establish an individualized tailored therapy for rectal cancer. Global expression profiles of responders and nonresponders may provide insights into the development of novel therapeutic targets.

Standard name | WATANABE_RECTAL_CANCER_RADIOTHERAPY_RESPONSIVE_DN
Systematic name | M4752
Organism | Homo sapiens
PMID | 16585155
Authors | Watanabe T,Komuro Y,Kiyomatsu T,Kanazawa T,Kazama Y,Tanaka J,Tanaka T,Yamamoto Y,Shirane M,Muto T,Nagawa H
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in rectal cancer patients resistant to radiotherapy (non-responders) relative to the sensitive ones (responders).
Full description | Preoperative radiotherapy has been widely used to improve local control of disease and to improve survival in the treatment of rectal cancer. However, the response to radiotherapy differs among individual tumors. Our objective here was to identify a set of discriminating genes that can be used for characterization and prediction of response to radiotherapy in rectal cancer. Fifty-two rectal cancer patients who underwent preoperative radiotherapy were studied. Biopsy specimens were obtained from rectal cancer before preoperative radiotherapy. Response to radiotherapy was determined by histopathologic examination of surgically resected specimens and classified as responders or nonresponders. By determining gene expression profiles using human U95Av2 Gene Chip, we identified 33 novel discriminating genes of which the expression differed significantly between responders and nonresponders. Using this gene set, we were able to establish a new model to predict response to radiotherapy in rectal cancer with an accuracy of 82.4%. The list of discriminating genes included growth factor, apoptosis, cell proliferation, signal transduction, or cell adhesion-related genes. Among 33 discriminating genes, apoptosis inducers (lumican, thrombospondin 2, and galectin-1) showed higher expression in responders whereas apoptosis inhibitors (cyclophilin 40 and glutathione peroxidase) showed higher expression in nonresponders. The present study suggested the possibility that gene expression profiling may be useful in predicting response to radiotherapy to establish an individualized tailored therapy for rectal cancer. Global expression profiles of responders and nonresponders may provide insights into the development of novel therapeutic targets.

Standard name | HOLLMANN_APOPTOSIS_VIA_CD40_UP
Systematic name | M9695
Organism | Homo sapiens
PMID | 16585179
Authors | Hollmann CA,Owens T,Nalbantoglu J,Hudson TJ,Sladek R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DLBCL (diffuse large B-cell lymphoma) cell lines sensitive to stimulation of CD40 [GeneID=958] relative to the resistant ones.
Full description | CD40 promotes survival, proliferation, and differentiation of normal B cells but can cause activation-induced cell death in malignant B lymphocytes. CD40 ligand and anti-CD40 antibodies have been used successfully to induce apoptosis in lymphoma lines both in vitro and in xenograft tumor models. Although this makes CD40 an attractive target for antitumor therapies, the response of malignant B cells to CD40 signaling is variable, and CD40 stimulation can enhance proliferation and can increase chemoresistance in some cell lines. It would therefore be useful to identify markers that predict whether a specific cell line or tumor will undergo apoptosis when stimulated with CD40 and to identify targets downstream of CD40 that affect only the apoptotic arm of CD40 signaling. We have analyzed gene expression patterns in CD40-sensitive and CD40-resistant diffuse large B-cell lymphoma (DLBCL) cell lines to identify signaling pathways that are involved in CD40-mediated apoptosis. CD40-resistant lines expressed pre-B-cell markers, including RAG and VPREB, whereas CD40-sensitive cells resembled mature B cells and expressed higher levels of transcripts encoding several members of the CD40 signaling pathway, including LCK and VAV. In addition, CD40-sensitive DLBCL cell lines also displayed constitutive activation of extracellular signal-regulated kinase (ERK) and failed to undergo apoptosis when ERK phosphorylation was inhibited. In contrast, CD40-resistant lines showed no constitutive activation of ERK and no increase in ERK activity in response to CD40 stimulation. Our results suggest that constitutive activation of ERK may be required for death signaling by CD40.

Standard name | HOLLMANN_APOPTOSIS_VIA_CD40_DN
Systematic name | M6663
Organism | Homo sapiens
PMID | 16585179
Authors | Hollmann CA,Owens T,Nalbantoglu J,Hudson TJ,Sladek R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in DLBCL (diffuse large B-cell lymphoma) cell lines sensitive to stimulation of CD40 [GeneID=958] relative to the resistant ones.
Full description | CD40 promotes survival, proliferation, and differentiation of normal B cells but can cause activation-induced cell death in malignant B lymphocytes. CD40 ligand and anti-CD40 antibodies have been used successfully to induce apoptosis in lymphoma lines both in vitro and in xenograft tumor models. Although this makes CD40 an attractive target for antitumor therapies, the response of malignant B cells to CD40 signaling is variable, and CD40 stimulation can enhance proliferation and can increase chemoresistance in some cell lines. It would therefore be useful to identify markers that predict whether a specific cell line or tumor will undergo apoptosis when stimulated with CD40 and to identify targets downstream of CD40 that affect only the apoptotic arm of CD40 signaling. We have analyzed gene expression patterns in CD40-sensitive and CD40-resistant diffuse large B-cell lymphoma (DLBCL) cell lines to identify signaling pathways that are involved in CD40-mediated apoptosis. CD40-resistant lines expressed pre-B-cell markers, including RAG and VPREB, whereas CD40-sensitive cells resembled mature B cells and expressed higher levels of transcripts encoding several members of the CD40 signaling pathway, including LCK and VAV. In addition, CD40-sensitive DLBCL cell lines also displayed constitutive activation of extracellular signal-regulated kinase (ERK) and failed to undergo apoptosis when ERK phosphorylation was inhibited. In contrast, CD40-resistant lines showed no constitutive activation of ERK and no increase in ERK activity in response to CD40 stimulation. Our results suggest that constitutive activation of ERK may be required for death signaling by CD40.

Standard name | LIU_PROSTATE_CANCER_UP
Systematic name | M4619
Organism | Homo sapiens
PMID | 16618720
Authors | Liu P,Ramachandran S,Ali Seyed M,Scharer CD,Laycock N,Dalton WB,Williams H,Karanam S,Datta MW,Jaye DL,Moreno CS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in prostate cancer samples.
Full description | Prostate cancer is the most commonly diagnosed noncutaneous neoplasm and second most common cause of cancer-related mortality in western men. To investigate the mechanisms of prostate cancer development and progression, we did expression profiling of human prostate cancer and benign tissues. We show that the SOX4 is overexpressed in prostate tumor samples compared with benign tissues by microarray analysis, real-time PCR, and immunohistochemistry. We also show that SOX4 expression is highly correlated with Gleason score at the mRNA and protein level using tissue microarrays. Genes affected by SOX4 expression were also identified, including BCL10, CSF1, and NcoA4/ARA70. TLE-1 and BBC3/PUMA were identified as direct targets of SOX4. Silencing of SOX4 by small interfering RNA transfection induced apoptosis of prostate cancer cells, suggesting that SOX4 could be a therapeutic target for prostate cancer. Stable transfection of SOX4 into nontransformed prostate cells enabled colony formation in soft agar, suggesting that, in the proper cellular context, SOX4 can be a transforming oncogene.

Standard name | LIU_PROSTATE_CANCER_DN
Systematic name | M19391
Organism | Homo sapiens
PMID | 16618720
Authors | Liu P,Ramachandran S,Ali Seyed M,Scharer CD,Laycock N,Dalton WB,Williams H,Karanam S,Datta MW,Jaye DL,Moreno CS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in prostate cancer samples.
Full description | Prostate cancer is the most commonly diagnosed noncutaneous neoplasm and second most common cause of cancer-related mortality in western men. To investigate the mechanisms of prostate cancer development and progression, we did expression profiling of human prostate cancer and benign tissues. We show that the SOX4 is overexpressed in prostate tumor samples compared with benign tissues by microarray analysis, real-time PCR, and immunohistochemistry. We also show that SOX4 expression is highly correlated with Gleason score at the mRNA and protein level using tissue microarrays. Genes affected by SOX4 expression were also identified, including BCL10, CSF1, and NcoA4/ARA70. TLE-1 and BBC3/PUMA were identified as direct targets of SOX4. Silencing of SOX4 by small interfering RNA transfection induced apoptosis of prostate cancer cells, suggesting that SOX4 could be a therapeutic target for prostate cancer. Stable transfection of SOX4 into nontransformed prostate cells enabled colony formation in soft agar, suggesting that, in the proper cellular context, SOX4 can be a transforming oncogene.

Standard name | LIU_SOX4_TARGETS_UP
Systematic name | M17450
Organism | Homo sapiens
PMID | 16618720
Authors | Liu P,Ramachandran S,Ali Seyed M,Scharer CD,Laycock N,Dalton WB,Williams H,Karanam S,Datta MW,Jaye DL,Moreno CS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in LNCaP cells (prostate cancer) by overexpression of SOX4 [GeneID=6659] and down-regulated by its RNAi knockdown.
Full description | Prostate cancer is the most commonly diagnosed noncutaneous neoplasm and second most common cause of cancer-related mortality in western men. To investigate the mechanisms of prostate cancer development and progression, we did expression profiling of human prostate cancer and benign tissues. We show that the SOX4 is overexpressed in prostate tumor samples compared with benign tissues by microarray analysis, real-time PCR, and immunohistochemistry. We also show that SOX4 expression is highly correlated with Gleason score at the mRNA and protein level using tissue microarrays. Genes affected by SOX4 expression were also identified, including BCL10, CSF1, and NcoA4/ARA70. TLE-1 and BBC3/PUMA were identified as direct targets of SOX4. Silencing of SOX4 by small interfering RNA transfection induced apoptosis of prostate cancer cells, suggesting that SOX4 could be a therapeutic target for prostate cancer. Stable transfection of SOX4 into nontransformed prostate cells enabled colony formation in soft agar, suggesting that, in the proper cellular context, SOX4 can be a transforming oncogene.

Standard name | LIU_SOX4_TARGETS_DN
Systematic name | M17287
Organism | Homo sapiens
PMID | 16618720
Authors | Liu P,Ramachandran S,Ali Seyed M,Scharer CD,Laycock N,Dalton WB,Williams H,Karanam S,Datta MW,Jaye DL,Moreno CS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in LNCaP cells (prostate cancer) by overexpression of SOX4 [GeneID=6659] and up-regulated by its RNAi knockdown.
Full description | Prostate cancer is the most commonly diagnosed noncutaneous neoplasm and second most common cause of cancer-related mortality in western men. To investigate the mechanisms of prostate cancer development and progression, we did expression profiling of human prostate cancer and benign tissues. We show that the SOX4 is overexpressed in prostate tumor samples compared with benign tissues by microarray analysis, real-time PCR, and immunohistochemistry. We also show that SOX4 expression is highly correlated with Gleason score at the mRNA and protein level using tissue microarrays. Genes affected by SOX4 expression were also identified, including BCL10, CSF1, and NcoA4/ARA70. TLE-1 and BBC3/PUMA were identified as direct targets of SOX4. Silencing of SOX4 by small interfering RNA transfection induced apoptosis of prostate cancer cells, suggesting that SOX4 could be a therapeutic target for prostate cancer. Stable transfection of SOX4 into nontransformed prostate cells enabled colony formation in soft agar, suggesting that, in the proper cellular context, SOX4 can be a transforming oncogene.

Standard name | ONKEN_UVEAL_MELANOMA_UP
Systematic name | M12490
Organism | Homo sapiens
PMID | 16651410
Authors | Onken MD,Ehlers JP,Worley LA,Makita J,Yokota Y,Harbour JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in uveal melanoma: class 2 vs class 1 tumors.
Full description | Microarray gene expression profiling is a powerful tool for generating molecular cancer classifications. However, elucidating biological insights from these large data sets has been challenging. Previously, we identified a gene expression-based classification of primary uveal melanomas that accurately predicts metastatic death. Class 1 tumors have a low risk and class 2 tumors a high risk for metastatic death. Here, we used genes that discriminate these tumor classes to identify biological correlates of the aggressive class 2 signature. A search for Gene Ontology categories enriched in our class-discriminating gene list revealed a global down-regulation of neural crest and melanocyte-specific genes and an up-regulation of epithelial genes in class 2 tumors. Correspondingly, class 2 tumors exhibited epithelial features, such as polygonal cell morphology, up-regulation of the epithelial adhesion molecule E-cadherin, colocalization of E-cadherin and beta-catenin to the plasma membrane, and formation of cell-cell adhesions and acinar structures. One of our top class-discriminating genes was the helix-loop-helix inhibitor ID2, which was strongly down-regulated in class 2 tumors. The class 2 phenotype could be recapitulated by eliminating Id2 in cultured class 1 human uveal melanoma cells and in a mouse ocular melanoma model. Id2 seemed to suppress the epithelial-like class 2 phenotype by inhibiting an activator of the E-cadherin promoter. Consequently, Id2 loss triggered up-regulation of E-cadherin, which in turn promoted anchorage-independent cell growth, a likely antecedent to metastasis. These findings reveal new roles for Id2 and E-cadherin in uveal melanoma progression, and they identify potential targets for therapeutic intervention.

Standard name | ONKEN_UVEAL_MELANOMA_DN
Systematic name | M2605
Organism | Homo sapiens
PMID | 16651410
Authors | Onken MD,Ehlers JP,Worley LA,Makita J,Yokota Y,Harbour JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in uveal melanoma: class 2 vs class 1 tumors.
Full description | Microarray gene expression profiling is a powerful tool for generating molecular cancer classifications. However, elucidating biological insights from these large data sets has been challenging. Previously, we identified a gene expression-based classification of primary uveal melanomas that accurately predicts metastatic death. Class 1 tumors have a low risk and class 2 tumors a high risk for metastatic death. Here, we used genes that discriminate these tumor classes to identify biological correlates of the aggressive class 2 signature. A search for Gene Ontology categories enriched in our class-discriminating gene list revealed a global down-regulation of neural crest and melanocyte-specific genes and an up-regulation of epithelial genes in class 2 tumors. Correspondingly, class 2 tumors exhibited epithelial features, such as polygonal cell morphology, up-regulation of the epithelial adhesion molecule E-cadherin, colocalization of E-cadherin and beta-catenin to the plasma membrane, and formation of cell-cell adhesions and acinar structures. One of our top class-discriminating genes was the helix-loop-helix inhibitor ID2, which was strongly down-regulated in class 2 tumors. The class 2 phenotype could be recapitulated by eliminating Id2 in cultured class 1 human uveal melanoma cells and in a mouse ocular melanoma model. Id2 seemed to suppress the epithelial-like class 2 phenotype by inhibiting an activator of the E-cadherin promoter. Consequently, Id2 loss triggered up-regulation of E-cadherin, which in turn promoted anchorage-independent cell growth, a likely antecedent to metastasis. These findings reveal new roles for Id2 and E-cadherin in uveal melanoma progression, and they identify potential targets for therapeutic intervention.

Standard name | BERTUCCI_MEDULLARY_VS_DUCTAL_BREAST_CANCER_UP
Systematic name | M14539
Organism | Homo sapiens
PMID | 16651414
Authors | Bertucci F,Finetti P,Cervera N,Charafe-Jauffret E,Mamessier E,Adélaïde J,Debono S,Houvenaeghel G,Maraninchi D,Viens P,Charpin C,Jacquemier J,Birnbaum D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in medullary breast cancer (MBC) relative to ductal breast cancer (DBD).
Full description | Medullary breast cancer (MBC) is a rare but enigmatic pathologic type of breast cancer. Despite features of aggressiveness, MBC is associated with a favorable prognosis. Morphologic diagnosis remains difficult in many cases. Very little is known about the molecular alterations involved in MBC. Notably, it is not clear whether MBC and ductal breast cancer (DBC) represent molecularly distinct entities and what genes/proteins might account for their differences. Using whole-genome oligonucleotide microarrays, we compared gene expression profiles of 22 MBCs and 44 grade III DBCs. We show that MBCs are less heterogeneous than DBCs. Whereas different molecular subtypes (luminal A, luminal B, basal, ERBB2-overexpressing, and normal-like) exist in DBCs, 95% MBCs display a basal profile, similar to that of basal DBCs. Supervised analysis identified gene expression signatures that discriminated MBCs from DBCs. Discriminator genes are associated with various cellular processes related to MBC features, in particular immune reaction and apoptosis. As compared with MBCs, basal DBCs overexpress genes involved in smooth muscle cell differentiation, suggesting that MBCs are a distinct subgroup of basal breast cancer with limited myoepithelial differentiation. Finally, MBCs overexpress a series of genes located on the 12p13 and 6p21 chromosomal regions known to contain pluripotency genes. Our results contribute to a better understanding of MBC and of mammary oncogenesis in general.

Standard name | BERTUCCI_MEDULLARY_VS_DUCTAL_BREAST_CANCER_DN
Systematic name | M10605
Organism | Homo sapiens
PMID | 16651414
Authors | Bertucci F,Finetti P,Cervera N,Charafe-Jauffret E,Mamessier E,Adélaïde J,Debono S,Houvenaeghel G,Maraninchi D,Viens P,Charpin C,Jacquemier J,Birnbaum D
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in medullary breast cancer (MBC) relative to ductal breast cancer (DBD).
Full description | Medullary breast cancer (MBC) is a rare but enigmatic pathologic type of breast cancer. Despite features of aggressiveness, MBC is associated with a favorable prognosis. Morphologic diagnosis remains difficult in many cases. Very little is known about the molecular alterations involved in MBC. Notably, it is not clear whether MBC and ductal breast cancer (DBC) represent molecularly distinct entities and what genes/proteins might account for their differences. Using whole-genome oligonucleotide microarrays, we compared gene expression profiles of 22 MBCs and 44 grade III DBCs. We show that MBCs are less heterogeneous than DBCs. Whereas different molecular subtypes (luminal A, luminal B, basal, ERBB2-overexpressing, and normal-like) exist in DBCs, 95% MBCs display a basal profile, similar to that of basal DBCs. Supervised analysis identified gene expression signatures that discriminated MBCs from DBCs. Discriminator genes are associated with various cellular processes related to MBC features, in particular immune reaction and apoptosis. As compared with MBCs, basal DBCs overexpress genes involved in smooth muscle cell differentiation, suggesting that MBCs are a distinct subgroup of basal breast cancer with limited myoepithelial differentiation. Finally, MBCs overexpress a series of genes located on the 12p13 and 6p21 chromosomal regions known to contain pluripotency genes. Our results contribute to a better understanding of MBC and of mammary oncogenesis in general.

Standard name | SCHUETZ_BREAST_CANCER_DUCTAL_INVASIVE_UP
Systematic name | M17471
Organism | Homo sapiens
PMID | 16707453
Authors | Schuetz CS,Bonin M,Clare SE,Nieselt K,Sotlar K,Walter M,Fehm T,Solomayer E,Riess O,Wallwiener D,Kurek R,Neubauer HJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in invasive ductal carcinoma (IDC) relative to ductal carcinoma in situ (DCIS, non-invasive).
Full description | Becoming invasive is a crucial step in breast cancer oncogenesis. At this point, a lesion carries the potential for spreading and metastasis--a process, whose molecular characteristics still remain poorly understood. In this article, we describe a matched-pair analysis of ductal carcinoma in situ (DCIS) and invasive ductal carcinoma (IDC) of nine breast ductal carcinomas to identify novel molecular markers characterizing the transition from DCIS to IDC. The purpose of this study was to better understand the molecular biology of this transition and to identify candidate genes whose products might serve as prognostic markers and/or as molecular targets for treatment. To obtain cellular-based gene expression profiles from epithelial tumor cells, we combined laser capture microdissection with a T7-based two-round RNA amplification and Affymetrix oligonucleotide microarray analysis. Altogether, a set of 24 tumor samples was analyzed, comprised of nine matched DCIS/IDC and replicate DCIS/IDC preparations from three of the nine tumors. Cluster analysis on expression data shows the robustness and reproducibility of the techniques we established. Using multiple statistical methods, 546 significantly differentially expressed probe sets were identified. Eighteen candidate genes were evaluated by RT-PCR. Examples of genes already known to be associated with breast cancer invasion are BPAG1, LRRC15, MMP11, and PLAU. The expression of BPAG1, DACT1, GREM1, MEF2C, SART2, and TNFAIP6 was localized to epithelial tumor cells by in situ hybridization and/or immunohistochemistry, confirming the accuracy of laser capture microdissection sampling and microarray analysis.

Standard name | SCHUETZ_BREAST_CANCER_DUCTAL_INVASIVE_DN
Systematic name | M7012
Organism | Homo sapiens
PMID | 16707453
Authors | Schuetz CS,Bonin M,Clare SE,Nieselt K,Sotlar K,Walter M,Fehm T,Solomayer E,Riess O,Wallwiener D,Kurek R,Neubauer HJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in invasive ductal carcinoma (IDC) relative to ductal carcinoma in situ (DCIS, non-invasive).
Full description | Becoming invasive is a crucial step in breast cancer oncogenesis. At this point, a lesion carries the potential for spreading and metastasis--a process, whose molecular characteristics still remain poorly understood. In this article, we describe a matched-pair analysis of ductal carcinoma in situ (DCIS) and invasive ductal carcinoma (IDC) of nine breast ductal carcinomas to identify novel molecular markers characterizing the transition from DCIS to IDC. The purpose of this study was to better understand the molecular biology of this transition and to identify candidate genes whose products might serve as prognostic markers and/or as molecular targets for treatment. To obtain cellular-based gene expression profiles from epithelial tumor cells, we combined laser capture microdissection with a T7-based two-round RNA amplification and Affymetrix oligonucleotide microarray analysis. Altogether, a set of 24 tumor samples was analyzed, comprised of nine matched DCIS/IDC and replicate DCIS/IDC preparations from three of the nine tumors. Cluster analysis on expression data shows the robustness and reproducibility of the techniques we established. Using multiple statistical methods, 546 significantly differentially expressed probe sets were identified. Eighteen candidate genes were evaluated by RT-PCR. Examples of genes already known to be associated with breast cancer invasion are BPAG1, LRRC15, MMP11, and PLAU. The expression of BPAG1, DACT1, GREM1, MEF2C, SART2, and TNFAIP6 was localized to epithelial tumor cells by in situ hybridization and/or immunohistochemistry, confirming the accuracy of laser capture microdissection sampling and microarray analysis.

Standard name | DAVICIONI_PAX_FOXO1_SIGNATURE_IN_ARMS_UP
Systematic name | M4991
Organism | Homo sapiens
PMID | 16849537
Authors | Davicioni E,Finckenstein FG,Shahbazian V,Buckley JD,Triche TJ,Anderson MJ
Category | C2
Sub-category | CGP
Brief description | 'PAX-FKHR signature': genes up-regulated by PAX3- or PAX7-FOXO1 [GeneID=5081;5077;2308] fusion in primary alveolar rhabdomyosarcoma(ARMS) tumors.
Full description | Alveolar rhabdomyosarcomas (ARMS) are aggressive soft-tissue sarcomas affecting children and young adults. Most ARMS tumors express the PAX3-FKHR or PAX7-FKHR (PAX-FKHR) fusion genes resulting from the t(2;13) or t(1;13) chromosomal translocations, respectively. However, up to 25% of ARMS tumors are fusion negative, making it unclear whether ARMS represent a single disease or multiple clinical and biological entities with a common phenotype. To test to what extent PAX-FKHR determine class and behavior of ARMS, we used oligonucleotide microarray expression profiling on 139 primary rhabdomyosarcoma tumors and an in vitro model. We found that ARMS tumors expressing either PAX-FKHR gene share a common expression profile distinct from fusion-negative ARMS and from the other rhabdomyosarcoma variants. We also observed that PAX-FKHR expression above a minimum level is necessary for the detection of this expression profile. Using an ectopic PAX3-FKHR and PAX7-FKHR expression model, we identified an expression signature regulated by PAX-FKHR that is specific to PAX-FKHR-positive ARMS tumors. Data mining for functional annotations of signature genes suggested a role for PAX-FKHR in regulating ARMS proliferation and differentiation. Cox regression modeling identified a subset of genes within the PAX-FKHR expression signature that segregated ARMS patients into three risk groups with 5-year overall survival estimates of 7%, 48%, and 93%. These prognostic classes were independent of conventional clinical risk factors. Our results show that PAX-FKHR dictate a specific expression signature that helps define the molecular phenotype of PAX-FKHR-positive ARMS tumors and, because it is linked with disease outcome in ARMS patients, determine tumor behavior.

Standard name | DAVICIONI_PAX_FOXO1_SIGNATURE_IN_ARMS_DN
Systematic name | M3642
Organism | Homo sapiens
PMID | 16849537
Authors | Davicioni E,Finckenstein FG,Shahbazian V,Buckley JD,Triche TJ,Anderson MJ
Category | C2
Sub-category | CGP
Brief description | 'PAX-FKHR signature': genes down-regulated by PAX3- or PAX7-FOXO1 [GeneID=5081;5077;2308] fusion in primary alveolar rhabdomyosarcoma(ARMS) tumors.
Full description | Alveolar rhabdomyosarcomas (ARMS) are aggressive soft-tissue sarcomas affecting children and young adults. Most ARMS tumors express the PAX3-FKHR or PAX7-FKHR (PAX-FKHR) fusion genes resulting from the t(2;13) or t(1;13) chromosomal translocations, respectively. However, up to 25% of ARMS tumors are fusion negative, making it unclear whether ARMS represent a single disease or multiple clinical and biological entities with a common phenotype. To test to what extent PAX-FKHR determine class and behavior of ARMS, we used oligonucleotide microarray expression profiling on 139 primary rhabdomyosarcoma tumors and an in vitro model. We found that ARMS tumors expressing either PAX-FKHR gene share a common expression profile distinct from fusion-negative ARMS and from the other rhabdomyosarcoma variants. We also observed that PAX-FKHR expression above a minimum level is necessary for the detection of this expression profile. Using an ectopic PAX3-FKHR and PAX7-FKHR expression model, we identified an expression signature regulated by PAX-FKHR that is specific to PAX-FKHR-positive ARMS tumors. Data mining for functional annotations of signature genes suggested a role for PAX-FKHR in regulating ARMS proliferation and differentiation. Cox regression modeling identified a subset of genes within the PAX-FKHR expression signature that segregated ARMS patients into three risk groups with 5-year overall survival estimates of 7%, 48%, and 93%. These prognostic classes were independent of conventional clinical risk factors. Our results show that PAX-FKHR dictate a specific expression signature that helps define the molecular phenotype of PAX-FKHR-positive ARMS tumors and, because it is linked with disease outcome in ARMS patients, determine tumor behavior.

Standard name | FOURNIER_ACINAR_DEVELOPMENT_EARLY_UP
Systematic name | M18424
Organism | Homo sapiens
PMID | 16849555
Authors | Fournier MV,Martin KJ,Kenny PA,Xhaja K,Bosch I,Yaswen P,Bissell MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated early in HMEC cells (mammary epithelium) during acinar development in vitro.
Full description | Nonmalignant human mammary epithelial cells (HMEC) seeded in laminin-rich extracellular matrix (lrECM) form polarized acini and, in doing so, transit from a disorganized proliferating state to an organized growth-arrested state. We hypothesized that the gene expression pattern of organized and growth-arrested HMECs would share similarities with breast tumors with good prognoses. Using Affymetrix HG-U133A microarrays, we analyzed the expression of 22,283 gene transcripts in 184 (finite life span) and HMT3522 S1 (immortal nonmalignant) HMECs on successive days after seeding in a lrECM assay. Both HMECs underwent growth arrest in G0-G1 and differentiated into polarized acini between days 5 and 7. We identified gene expression changes with the same temporal pattern in both lines and examined the expression of these genes in a previously published panel of microarray data for 295 breast cancer samples. We show that genes that are significantly lower in the organized, growth-arrested HMEC than in their proliferating counterparts can be used to classify breast cancer patients into poor and good prognosis groups with high accuracy. This study represents a novel unsupervised approach to identifying breast cancer markers that may be of use clinically.

Standard name | FOURNIER_ACINAR_DEVELOPMENT_EARLY_DN
Systematic name | M14136
Organism | Homo sapiens
PMID | 16849555
Authors | Fournier MV,Martin KJ,Kenny PA,Xhaja K,Bosch I,Yaswen P,Bissell MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated early in HMEC cells (mammary epithelium) during acinar development in vitro.
Full description | Nonmalignant human mammary epithelial cells (HMEC) seeded in laminin-rich extracellular matrix (lrECM) form polarized acini and, in doing so, transit from a disorganized proliferating state to an organized growth-arrested state. We hypothesized that the gene expression pattern of organized and growth-arrested HMECs would share similarities with breast tumors with good prognoses. Using Affymetrix HG-U133A microarrays, we analyzed the expression of 22,283 gene transcripts in 184 (finite life span) and HMT3522 S1 (immortal nonmalignant) HMECs on successive days after seeding in a lrECM assay. Both HMECs underwent growth arrest in G0-G1 and differentiated into polarized acini between days 5 and 7. We identified gene expression changes with the same temporal pattern in both lines and examined the expression of these genes in a previously published panel of microarray data for 295 breast cancer samples. We show that genes that are significantly lower in the organized, growth-arrested HMEC than in their proliferating counterparts can be used to classify breast cancer patients into poor and good prognosis groups with high accuracy. This study represents a novel unsupervised approach to identifying breast cancer markers that may be of use clinically.

Standard name | FOURNIER_ACINAR_DEVELOPMENT_LATE_UP
Systematic name | M644
Organism | Homo sapiens
PMID | 16849555
Authors | Fournier MV,Martin KJ,Kenny PA,Xhaja K,Bosch I,Yaswen P,Bissell MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated late in HMEC cells (mammary epithelium) during acinar development in vitro.
Full description | Nonmalignant human mammary epithelial cells (HMEC) seeded in laminin-rich extracellular matrix (lrECM) form polarized acini and, in doing so, transit from a disorganized proliferating state to an organized growth-arrested state. We hypothesized that the gene expression pattern of organized and growth-arrested HMECs would share similarities with breast tumors with good prognoses. Using Affymetrix HG-U133A microarrays, we analyzed the expression of 22,283 gene transcripts in 184 (finite life span) and HMT3522 S1 (immortal nonmalignant) HMECs on successive days after seeding in a lrECM assay. Both HMECs underwent growth arrest in G0-G1 and differentiated into polarized acini between days 5 and 7. We identified gene expression changes with the same temporal pattern in both lines and examined the expression of these genes in a previously published panel of microarray data for 295 breast cancer samples. We show that genes that are significantly lower in the organized, growth-arrested HMEC than in their proliferating counterparts can be used to classify breast cancer patients into poor and good prognosis groups with high accuracy. This study represents a novel unsupervised approach to identifying breast cancer markers that may be of use clinically.

Standard name | FOURNIER_ACINAR_DEVELOPMENT_LATE_DN
Systematic name | M13202
Organism | Homo sapiens
PMID | 16849555
Authors | Fournier MV,Martin KJ,Kenny PA,Xhaja K,Bosch I,Yaswen P,Bissell MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated late in HMEC cells (mammary epithelium) during acinar development in vitro.
Full description | Nonmalignant human mammary epithelial cells (HMEC) seeded in laminin-rich extracellular matrix (lrECM) form polarized acini and, in doing so, transit from a disorganized proliferating state to an organized growth-arrested state. We hypothesized that the gene expression pattern of organized and growth-arrested HMECs would share similarities with breast tumors with good prognoses. Using Affymetrix HG-U133A microarrays, we analyzed the expression of 22,283 gene transcripts in 184 (finite life span) and HMT3522 S1 (immortal nonmalignant) HMECs on successive days after seeding in a lrECM assay. Both HMECs underwent growth arrest in G0-G1 and differentiated into polarized acini between days 5 and 7. We identified gene expression changes with the same temporal pattern in both lines and examined the expression of these genes in a previously published panel of microarray data for 295 breast cancer samples. We show that genes that are significantly lower in the organized, growth-arrested HMEC than in their proliferating counterparts can be used to classify breast cancer patients into poor and good prognosis groups with high accuracy. This study represents a novel unsupervised approach to identifying breast cancer markers that may be of use clinically.

Standard name | NAM_FXYD5_TARGETS_DN
Systematic name | M7076
Organism | Homo sapiens
PMID | 16849564
Authors | Nam JS,Kang MJ,Suchar AM,Shimamura T,Kohn EA,Michalowska AM,Jordan VC,Hirohashi S,Wakefield LM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MDA-MB-231 cells (breast cancer) after knockdown of FXYD5 [GeneID=53827] by RNAi.
Full description | Dysadherin, a cancer-associated membrane glycoprotein, down-regulates E-cadherin and promotes cancer metastasis. This study examined the role of dysadherin in breast cancer progression. Expression of dysadherin was found to be highest in breast cancer cell lines and tumors that lacked the estrogen receptor (ER). Knockdown of dysadherin caused increased association of E-cadherin with the actin cytoskeleton in breast cancer cell lines that expressed E-cadherin. However, knockdown of dysadherin could still suppress cell invasiveness in cells that had no functional E-cadherin, suggesting the existence of a novel mechanism of action. Global gene expression analysis identified chemokine (C-C motif) ligand 2 (CCL2) as the transcript most affected by dysadherin knockdown in MDA-MB-231 cells, and dysadherin was shown to regulate CCL2 expression in part through activation of the nuclear factor-kappaB pathway. The ability of dysadherin to promote tumor cell invasion in vitro was dependent on the establishment of a CCL2 autocrine loop, and CCL2 secreted by dysadherin-positive tumor cells also promoted endothelial cell migration in a paracrine fashion. Finally, experimental suppression of CCL2 in MDA-MB-231 cells reduced their ability to metastasize in vivo. This study shows that dysadherin has prometastatic effects that are independent of E-cadherin expression and that CCL2 could play an important role in mediating the prometastatic effect of dysadherin in ER-negative breast cancer.

Standard name | FRASOR_TAMOXIFEN_RESPONSE_UP
Systematic name | M17651
Organism | Homo sapiens
PMID | 16849584
Authors | Frasor J,Chang EC,Komm B,Lin CY,Vega VB,Liu ET,Miller LD,Smeds J,Bergh J,Katzenellenbogen BS
Category | C2
Sub-category | CGP
Brief description | Genes preferentially up-regulated in MCF-7 cells (breast cancer) by tamoxifen [PubChem=5376] but not by estradiol or fulvestrant (ICI 182780) [PubChem=5757;3478439].
Full description | The beneficial effect of the selective estrogen receptor (ER) modulator tamoxifen in the treatment and prevention of breast cancer is assumed to be through its ability to antagonize the stimulatory actions of estrogen, although tamoxifen can also have some estrogen-like agonist effects. Here, we report that, in addition to these mixed agonist/antagonist actions, tamoxifen can also selectively regulate a unique set of >60 genes, which are minimally regulated by estradiol (E2) or raloxifene in ERalpha-positive MCF-7 human breast cancer cells. This gene regulation by tamoxifen is mediated by ERalpha and reversed by E2 or ICI 182,780. Introduction of ERbeta into MCF-7 cells reverses tamoxifen action on approximately 75% of these genes. To examine whether these genes might serve as markers of tamoxifen sensitivity and/or the development of resistance, their expression level was examined in breast cancers of women who had received adjuvant therapy with tamoxifen. High expression of two of the tamoxifen-stimulated genes, YWHAZ/14-3-3z and LOC441453, was found to correlate significantly with disease recurrence following tamoxifen treatment in women with ER-positive cancers and hence seem to be markers of a poor prognosis. Our data indicate a new dimension in tamoxifen action, involving gene expression regulation that is tamoxifen preferential, and identify genes that might serve as markers of tumor responsiveness or resistance to tamoxifen therapy. This may have a potential effect on the choice of tamoxifen versus aromatase inhibitors as adjuvant endocrine therapy.

Standard name | FRASOR_TAMOXIFEN_RESPONSE_DN
Systematic name | M5082
Organism | Homo sapiens
PMID | 16849584
Authors | Frasor J,Chang EC,Komm B,Lin CY,Vega VB,Liu ET,Miller LD,Smeds J,Bergh J,Katzenellenbogen BS
Category | C2
Sub-category | CGP
Brief description | Genes preferentially down-regulated in MCF-7 cells (breast cancer) by tamoxifen [PubChem=5376] but not by estradiol or fulvestrant (ICI 182780) [PubChem=5757;3478439].
Full description | The beneficial effect of the selective estrogen receptor (ER) modulator tamoxifen in the treatment and prevention of breast cancer is assumed to be through its ability to antagonize the stimulatory actions of estrogen, although tamoxifen can also have some estrogen-like agonist effects. Here, we report that, in addition to these mixed agonist/antagonist actions, tamoxifen can also selectively regulate a unique set of >60 genes, which are minimally regulated by estradiol (E2) or raloxifene in ERalpha-positive MCF-7 human breast cancer cells. This gene regulation by tamoxifen is mediated by ERalpha and reversed by E2 or ICI 182,780. Introduction of ERbeta into MCF-7 cells reverses tamoxifen action on approximately 75% of these genes. To examine whether these genes might serve as markers of tamoxifen sensitivity and/or the development of resistance, their expression level was examined in breast cancers of women who had received adjuvant therapy with tamoxifen. High expression of two of the tamoxifen-stimulated genes, YWHAZ/14-3-3z and LOC441453, was found to correlate significantly with disease recurrence following tamoxifen treatment in women with ER-positive cancers and hence seem to be markers of a poor prognosis. Our data indicate a new dimension in tamoxifen action, involving gene expression regulation that is tamoxifen preferential, and identify genes that might serve as markers of tumor responsiveness or resistance to tamoxifen therapy. This may have a potential effect on the choice of tamoxifen versus aromatase inhibitors as adjuvant endocrine therapy.

Standard name | KIM_RESPONSE_TO_TSA_AND_DECITABINE_UP
Systematic name | M126
Organism | Homo sapiens
PMID | 16885346
Authors | Kim TY,Zhong S,Fields CR,Kim JH,Robertson KD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in glioma cell lines treated with both decitabine [PubChem=451668] and TSA [PubChem=5562].
Full description | Malignant glioma is the most common central nervous system tumor of adults and is associated with a significant degree of morbidity and mortality. Gliomas are highly invasive and respond poorly to conventional treatments. Gliomas, like other tumor types, arise from a complex and poorly understood sequence of genetic and epigenetic alterations. Epigenetic alterations leading to gene silencing, in the form of aberrant CpG island promoter hypermethylation and histone deacetylation, have not been thoroughly investigated in brain tumors, and elucidating such changes is likely to enhance our understanding of their etiology and provide new treatment options. We used a combined approach of pharmacologic inhibition of DNA methylation and histone deacetylation, coupled with expression microarrays, to identify novel targets of epigenetic silencing in glioma cell lines. From this analysis, we identified >160 genes up-regulated by 5-aza-2'-deoxycytidine and trichostatin A treatment. Further characterization of 10 of these genes, including the putative metastasis suppressor CST6, the apoptosis-inducer BIK, and TSPYL5, whose function is unknown, revealed that they are frequent targets of epigenetic silencing in glioma cell lines and primary tumors and suppress glioma cell growth in culture. Furthermore, we show that other members of the TSPYL gene family are epigenetically silenced in gliomas and dissect the contribution of individual DNA methyltransferases to the aberrant promoter hypermethylation events. These studies, therefore, lay the foundation for a comprehensive understanding of the full extent of epigenetic changes in gliomas and how they may be exploited for therapeutic purposes.

Standard name | KIM_RESPONSE_TO_TSA_AND_DECITABINE_DN
Systematic name | M14954
Organism | Homo sapiens
PMID | 16885346
Authors | Kim TY,Zhong S,Fields CR,Kim JH,Robertson KD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in glioma cell lines treated with both decitabine [PubChem=451668] and TSA [PubChem=5562].
Full description | Malignant glioma is the most common central nervous system tumor of adults and is associated with a significant degree of morbidity and mortality. Gliomas are highly invasive and respond poorly to conventional treatments. Gliomas, like other tumor types, arise from a complex and poorly understood sequence of genetic and epigenetic alterations. Epigenetic alterations leading to gene silencing, in the form of aberrant CpG island promoter hypermethylation and histone deacetylation, have not been thoroughly investigated in brain tumors, and elucidating such changes is likely to enhance our understanding of their etiology and provide new treatment options. We used a combined approach of pharmacologic inhibition of DNA methylation and histone deacetylation, coupled with expression microarrays, to identify novel targets of epigenetic silencing in glioma cell lines. From this analysis, we identified >160 genes up-regulated by 5-aza-2'-deoxycytidine and trichostatin A treatment. Further characterization of 10 of these genes, including the putative metastasis suppressor CST6, the apoptosis-inducer BIK, and TSPYL5, whose function is unknown, revealed that they are frequent targets of epigenetic silencing in glioma cell lines and primary tumors and suppress glioma cell growth in culture. Furthermore, we show that other members of the TSPYL gene family are epigenetically silenced in gliomas and dissect the contribution of individual DNA methyltransferases to the aberrant promoter hypermethylation events. These studies, therefore, lay the foundation for a comprehensive understanding of the full extent of epigenetic changes in gliomas and how they may be exploited for therapeutic purposes.

Standard name | SENGUPTA_NASOPHARYNGEAL_CARCINOMA_UP
Systematic name | M19875
Organism | Homo sapiens
PMID | 16912175
Authors | Sengupta S,den Boon JA,Chen IH,Newton MA,Dahl DB,Chen M,Cheng YJ,Westra WH,Chen CJ,Hildesheim A,Sugden B,Ahlquist P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in nsopharyngeal carcinoma relative to the normal tissue.
Full description | To identify the molecular mechanisms by which EBV-associated epithelial cancers are maintained, we measured the expression of essentially all human genes and all latent EBV genes in a collection of 31 laser-captured, microdissected nasopharyngeal carcinoma (NPC) tissue samples and 10 normal nasopharyngeal tissues. Global gene expression profiles clearly distinguished tumors from normal healthy epithelium. Expression levels of six viral genes (EBNA1, EBNA2, EBNA3A, EBNA3B, LMP1, and LMP2A) were correlated among themselves and strongly inversely correlated with the expression of a large subset of host genes. Among the human genes whose inhibition was most strongly correlated with increased EBV gene expression were multiple MHC class I HLA genes involved in regulating immune response via antigen presentation. The association between EBV gene expression and inhibition of MHC class I HLA expression implies that antigen display is either directly inhibited by EBV, facilitating immune evasion by tumor cells, and/or that tumor cells with inhibited presentation are selected for their ability to sustain higher levels of EBV to take maximum advantage of EBV oncogene-mediated tumor-promoting actions. Our data clearly reflect such tumor promotion, showing that deregulation of key proteins involved in apoptosis (BCL2-related protein A1 and Fas apoptotic inhibitory molecule), cell cycle checkpoints (AKIP, SCYL1, and NIN), and metastasis (matrix metalloproteinase 1) is closely correlated with the levels of EBV gene expression in NPC.

Standard name | SENGUPTA_NASOPHARYNGEAL_CARCINOMA_DN
Systematic name | M12671
Organism | Homo sapiens
PMID | 16912175
Authors | Sengupta S,den Boon JA,Chen IH,Newton MA,Dahl DB,Chen M,Cheng YJ,Westra WH,Chen CJ,Hildesheim A,Sugden B,Ahlquist P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in nsopharyngeal carcinoma relative to the normal tissue.
Full description | To identify the molecular mechanisms by which EBV-associated epithelial cancers are maintained, we measured the expression of essentially all human genes and all latent EBV genes in a collection of 31 laser-captured, microdissected nasopharyngeal carcinoma (NPC) tissue samples and 10 normal nasopharyngeal tissues. Global gene expression profiles clearly distinguished tumors from normal healthy epithelium. Expression levels of six viral genes (EBNA1, EBNA2, EBNA3A, EBNA3B, LMP1, and LMP2A) were correlated among themselves and strongly inversely correlated with the expression of a large subset of host genes. Among the human genes whose inhibition was most strongly correlated with increased EBV gene expression were multiple MHC class I HLA genes involved in regulating immune response via antigen presentation. The association between EBV gene expression and inhibition of MHC class I HLA expression implies that antigen display is either directly inhibited by EBV, facilitating immune evasion by tumor cells, and/or that tumor cells with inhibited presentation are selected for their ability to sustain higher levels of EBV to take maximum advantage of EBV oncogene-mediated tumor-promoting actions. Our data clearly reflect such tumor promotion, showing that deregulation of key proteins involved in apoptosis (BCL2-related protein A1 and Fas apoptotic inhibitory molecule), cell cycle checkpoints (AKIP, SCYL1, and NIN), and metastasis (matrix metalloproteinase 1) is closely correlated with the levels of EBV gene expression in NPC.

Standard name | WATANABE_COLON_CANCER_MSI_VS_MSS_UP
Systematic name | M12403
Organism | Homo sapiens
PMID | 17047040
Authors | Watanabe T,Kobunai T,Toda E,Yamamoto Y,Kanazawa T,Kazama Y,Tanaka J,Tanaka T,Konishi T,Okayama Y,Sugimoto Y,Oka T,Sasaki S,Muto T,Nagawa H
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes discriminating between MSI (microsatellite instability) and MSS (microsatellite stability) colon cancers.
Full description | Promoter methylation of the mismatch repair gene plays a key role in sporadic microsatellite instability (MSI) colorectal cancers. However, promoter methylation often occurs in proximal colon cancers, and molecular phenotypes underlying MSI cancers in distal colon have not been fully clarified. Our goal was to clarify the difference between MSI and microsatellite stability (MSS) cancers and, furthermore, to determine distinct characteristics of proximal and distal MSI cancers. By DNA microarray analysis of 84 cancers (33 MSI and 51 MSS), we identified discriminating genes (177 probe sets), which predicted MSI status with a high accuracy rate (97.6%). These genes were related to phenotypic characteristics of MSI cancers. Next, we identified 24 probe sets that were differentially expressed in proximal and distal MSI cancers. These genes included promoter methylation-mediated genes, whose expression was significantly down-regulated in proximal MSI cancers. Among discriminating genes between MSI and MSS, nine methylation-mediated genes showed down-regulation in MSI cancers. Of these, 7 (77.8%) showed down-regulation in proximal MSI cancers. Furthermore, methylation-specific PCR confirmed that frequency of hMLH1 promoter methylation was significantly higher in proximal MSI cancers (P = 0.0317). These results suggested that there is a difference between proximal and distal MSI cancers in methylation-mediated influence on gene silencing. In conclusion, using DNA microarray, we could distinguish MSI and MSS cancers. We also showed distinct characteristics of proximal and distal MSI cancers. The inactivation form of hMLH, per se, differed between proximal and distal MSI cancers. These results suggested that distal MSI cancers constitute a distinct subgroup of sporadic MSI cancers.

Standard name | WATANABE_COLON_CANCER_MSI_VS_MSS_DN
Systematic name | M8976
Organism | Homo sapiens
PMID | 17047040
Authors | Watanabe T,Kobunai T,Toda E,Yamamoto Y,Kanazawa T,Kazama Y,Tanaka J,Tanaka T,Konishi T,Okayama Y,Sugimoto Y,Oka T,Sasaki S,Muto T,Nagawa H
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes discriminating between MSI (microsatellite instability) and MSS (microsatellite stability) colon cancers.
Full description | Promoter methylation of the mismatch repair gene plays a key role in sporadic microsatellite instability (MSI) colorectal cancers. However, promoter methylation often occurs in proximal colon cancers, and molecular phenotypes underlying MSI cancers in distal colon have not been fully clarified. Our goal was to clarify the difference between MSI and microsatellite stability (MSS) cancers and, furthermore, to determine distinct characteristics of proximal and distal MSI cancers. By DNA microarray analysis of 84 cancers (33 MSI and 51 MSS), we identified discriminating genes (177 probe sets), which predicted MSI status with a high accuracy rate (97.6%). These genes were related to phenotypic characteristics of MSI cancers. Next, we identified 24 probe sets that were differentially expressed in proximal and distal MSI cancers. These genes included promoter methylation-mediated genes, whose expression was significantly down-regulated in proximal MSI cancers. Among discriminating genes between MSI and MSS, nine methylation-mediated genes showed down-regulation in MSI cancers. Of these, 7 (77.8%) showed down-regulation in proximal MSI cancers. Furthermore, methylation-specific PCR confirmed that frequency of hMLH1 promoter methylation was significantly higher in proximal MSI cancers (P = 0.0317). These results suggested that there is a difference between proximal and distal MSI cancers in methylation-mediated influence on gene silencing. In conclusion, using DNA microarray, we could distinguish MSI and MSS cancers. We also showed distinct characteristics of proximal and distal MSI cancers. The inactivation form of hMLH, per se, differed between proximal and distal MSI cancers. These results suggested that distal MSI cancers constitute a distinct subgroup of sporadic MSI cancers.

Standard name | KOBAYASHI_EGFR_SIGNALING_6HR_UP
Systematic name | M7331
Organism | Homo sapiens
PMID | 17145885
Authors | Kobayashi S,Shimamura T,Monti S,Steidl U,Hetherington CJ,Lowell AM,Golub T,Meyerson M,Tenen DG,Shapiro GI,Halmos B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in H1975 cells (non-small cell lung cancer, NSCLC) resistant to gefitinib [PubChem=123631] after treatment with EGFR inhibitor CL-387785 [PubChem=2776] for 6h.
Full description | Activating mutations in the epidermal growth factor receptor (EGFR) tyrosine kinase domain determine responsiveness to EGFR tyrosine kinase inhibitors in patients with advanced non-small cell lung cancer (NSCLC). The modulation of transcriptional pathways by mutant EGFR signaling is not fully understood. Previously, we and others identified a single base pair change leading to a threonine to methionine (T790M) amino acid alteration in the ATP-binding pocket of the EGFR as a common mechanism of acquired resistance. The gefitinib-resistant, T790M-mutant H1975 NSCLC cell line undergoes prominent growth arrest and apoptosis when treated with the irreversible EGFR inhibitor, CL-387,785. We did a transcriptional profiling study of mutant EGFR target genes that are differentially expressed in the resistant gefitinib-treated and the sensitive CL387,785-treated H1975 cells to identify the pivotal transcriptional changes in NSCLC with EGFR-activating mutations. We identified a small subset of early gene changes, including significant reduction of cyclin D1 as a result of EGFR inhibition by CL-387,785 but not by gefitinib. The reduction in cyclin D1 transcription was associated with subsequent suppression of E2F-responsive genes, consistent with proliferation arrest. Furthermore, cyclin D1 expression was higher in EGFR-mutant lung cancer cells compared with cells with wild-type EGFR. EGFR-mutant cells were routinely sensitive to the cyclin-dependent kinase inhibitor flavopiridol, confirming the functional relevance of the cyclin D axis. These studies suggest that cyclin D1 may contribute to the emergence of EGFR-driven tumorigenesis and can be an alternative target of therapy.

Standard name | KOBAYASHI_EGFR_SIGNALING_6HR_DN
Systematic name | M659
Organism | Homo sapiens
PMID | 17145885
Authors | Kobayashi S,Shimamura T,Monti S,Steidl U,Hetherington CJ,Lowell AM,Golub T,Meyerson M,Tenen DG,Shapiro GI,Halmos B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in H1975 cells (non-small cell lung cancer, NSCLC) resistant to gefitinib [PubChem=123631] after treatment with EGFR inhibitor CL-387785 [PubChem=2776] for 6h.
Full description | Activating mutations in the epidermal growth factor receptor (EGFR) tyrosine kinase domain determine responsiveness to EGFR tyrosine kinase inhibitors in patients with advanced non-small cell lung cancer (NSCLC). The modulation of transcriptional pathways by mutant EGFR signaling is not fully understood. Previously, we and others identified a single base pair change leading to a threonine to methionine (T790M) amino acid alteration in the ATP-binding pocket of the EGFR as a common mechanism of acquired resistance. The gefitinib-resistant, T790M-mutant H1975 NSCLC cell line undergoes prominent growth arrest and apoptosis when treated with the irreversible EGFR inhibitor, CL-387,785. We did a transcriptional profiling study of mutant EGFR target genes that are differentially expressed in the resistant gefitinib-treated and the sensitive CL387,785-treated H1975 cells to identify the pivotal transcriptional changes in NSCLC with EGFR-activating mutations. We identified a small subset of early gene changes, including significant reduction of cyclin D1 as a result of EGFR inhibition by CL-387,785 but not by gefitinib. The reduction in cyclin D1 transcription was associated with subsequent suppression of E2F-responsive genes, consistent with proliferation arrest. Furthermore, cyclin D1 expression was higher in EGFR-mutant lung cancer cells compared with cells with wild-type EGFR. EGFR-mutant cells were routinely sensitive to the cyclin-dependent kinase inhibitor flavopiridol, confirming the functional relevance of the cyclin D axis. These studies suggest that cyclin D1 may contribute to the emergence of EGFR-driven tumorigenesis and can be an alternative target of therapy.

Standard name | SOTIRIOU_BREAST_CANCER_GRADE_1_VS_3_UP
Systematic name | M3766
Organism | Homo sapiens
PMID | 16478745
Authors | Sotiriou C,Wirapati P,Loi S,Harris A,Fox S,Smeds J,Nordgren H,Farmer P,Praz V,Haibe-Kains B,Desmedt C,Larsimont D,Cardoso F,Peterse H,Nuyten D,Buyse M,Van de Vijver MJ,Bergh J,Piccart M,Delorenzi M
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes whose expression correlated with histologic grade of invasive breast cancer tumors: comparison of grade 1 vs grade 3.
Full description | BACKGROUND: Histologic grade in breast cancer provides clinically important prognostic information. However, 30%-60% of tumors are classified as histologic grade 2. This grade is associated with an intermediate risk of recurrence and is thus not informative for clinical decision making. We examined whether histologic grade was associated with gene expression profiles of breast cancers and whether such profiles could be used to improve histologic grading. METHODS: We analyzed microarray data from 189 invasive breast carcinomas and from three published gene expression datasets from breast carcinomas. We identified differentially expressed genes in a training set of 64 estrogen receptor (ER)-positive tumor samples by comparing expression profiles between histologic grade 3 tumors and histologic grade 1 tumors and used the expression of these genes to define the gene expression grade index. Data from 597 independent tumors were used to evaluate the association between relapse-free survival and the gene expression grade index in a Kaplan-Meier analysis. All statistical tests were two-sided. RESULTS: We identified 97 genes in our training set that were associated with histologic grade; most of these genes were involved in cell cycle regulation and proliferation. In validation datasets, the gene expression grade index was strongly associated with histologic grade 1 and 3 status; however, among histologic grade 2 tumors, the index spanned the values for histologic grade 1-3 tumors. Among patients with histologic grade 2 tumors, a high gene expression grade index was associated with a higher risk of recurrence than a low gene expression grade index (hazard ratio = 3.61, 95% confidence interval = 2.25 to 5.78; P < .001, log-rank test). CONCLUSIONS: Gene expression grade index appeared to reclassify patients with histologic grade 2 tumors into two groups with high versus low risks of recurrence. This approach may improve the accuracy of tumor grading and thus its prognostic value.

Standard name | SOTIRIOU_BREAST_CANCER_GRADE_1_VS_3_DN
Systematic name | M8077
Organism | Homo sapiens
PMID | 16478745
Authors | Sotiriou C,Wirapati P,Loi S,Harris A,Fox S,Smeds J,Nordgren H,Farmer P,Praz V,Haibe-Kains B,Desmedt C,Larsimont D,Cardoso F,Peterse H,Nuyten D,Buyse M,Van de Vijver MJ,Bergh J,Piccart M,Delorenzi M
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes whose expression correlated with histologic grade of invasive breast cancer tumors: comparison of grade 1 vs grade 3.
Full description | BACKGROUND: Histologic grade in breast cancer provides clinically important prognostic information. However, 30%-60% of tumors are classified as histologic grade 2. This grade is associated with an intermediate risk of recurrence and is thus not informative for clinical decision making. We examined whether histologic grade was associated with gene expression profiles of breast cancers and whether such profiles could be used to improve histologic grading. METHODS: We analyzed microarray data from 189 invasive breast carcinomas and from three published gene expression datasets from breast carcinomas. We identified differentially expressed genes in a training set of 64 estrogen receptor (ER)-positive tumor samples by comparing expression profiles between histologic grade 3 tumors and histologic grade 1 tumors and used the expression of these genes to define the gene expression grade index. Data from 597 independent tumors were used to evaluate the association between relapse-free survival and the gene expression grade index in a Kaplan-Meier analysis. All statistical tests were two-sided. RESULTS: We identified 97 genes in our training set that were associated with histologic grade; most of these genes were involved in cell cycle regulation and proliferation. In validation datasets, the gene expression grade index was strongly associated with histologic grade 1 and 3 status; however, among histologic grade 2 tumors, the index spanned the values for histologic grade 1-3 tumors. Among patients with histologic grade 2 tumors, a high gene expression grade index was associated with a higher risk of recurrence than a low gene expression grade index (hazard ratio = 3.61, 95% confidence interval = 2.25 to 5.78; P < .001, log-rank test). CONCLUSIONS: Gene expression grade index appeared to reclassify patients with histologic grade 2 tumors into two groups with high versus low risks of recurrence. This approach may improve the accuracy of tumor grading and thus its prognostic value.

Standard name | GAZDA_DIAMOND_BLACKFAN_ANEMIA_ERYTHROID_UP
Systematic name | M14024
Organism | Homo sapiens
PMID | 16741228
Authors | Gazda HT,Kho AT,Sanoudou D,Zaucha JM,Kohane IS,Sieff CA,Beggs AH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in erythroid progenitor cells isolated from bone marrow of patients with Diamond-Blackfan anemia (DBA) and mutated RPS19 [GeneID=6223].
Full description | Diamond-Blackfan anemia (DBA) is a broad developmental disease characterized by anemia, bone marrow (BM) erythroblastopenia, and an increased incidence of malignancy. Mutations in ribosomal protein gene S19 (RPS19) are found in approximately 25% of DBA patients; however, the role of RPS19 in the pathogenesis of DBA remains unknown. Using global gene expression analysis, we compared highly purified multipotential, erythroid, and myeloid BM progenitors from RPS19 mutated and control individuals. We found several ribosomal protein genes downregulated in all DBA progenitors. Apoptosis genes, such as TNFRSF10B and FAS, transcriptional control genes, including the erythropoietic transcription factor MYB (encoding c-myb), and translational genes were greatly dysregulated, mostly in diseased erythroid cells. Cancer-related genes, including RAS family oncogenes and tumor suppressor genes, were significantly dysregulated in all diseased progenitors. In addition, our results provide evidence that RPS19 mutations lead to codownregulation of multiple ribosomal protein genes, as well as downregulation of genes involved in translation in DBA cells. In conclusion, the altered expression of cancer-related genes suggests a molecular basis for malignancy in DBA. Downregulation of c-myb expression, which causes complete failure of fetal liver erythropoiesis in knockout mice, suggests a link between RPS19 mutations and reduced erythropoiesis in DBA.

Standard name | GAZDA_DIAMOND_BLACKFAN_ANEMIA_ERYTHROID_DN
Systematic name | M19016
Organism | Homo sapiens
PMID | 16741228
Authors | Gazda HT,Kho AT,Sanoudou D,Zaucha JM,Kohane IS,Sieff CA,Beggs AH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in erythroid progenitor cells isolated from bone marrow of patients with Diamond-Blackfan anemia (DBA) and mutated RPS19 [GeneID=6223].
Full description | Diamond-Blackfan anemia (DBA) is a broad developmental disease characterized by anemia, bone marrow (BM) erythroblastopenia, and an increased incidence of malignancy. Mutations in ribosomal protein gene S19 (RPS19) are found in approximately 25% of DBA patients; however, the role of RPS19 in the pathogenesis of DBA remains unknown. Using global gene expression analysis, we compared highly purified multipotential, erythroid, and myeloid BM progenitors from RPS19 mutated and control individuals. We found several ribosomal protein genes downregulated in all DBA progenitors. Apoptosis genes, such as TNFRSF10B and FAS, transcriptional control genes, including the erythropoietic transcription factor MYB (encoding c-myb), and translational genes were greatly dysregulated, mostly in diseased erythroid cells. Cancer-related genes, including RAS family oncogenes and tumor suppressor genes, were significantly dysregulated in all diseased progenitors. In addition, our results provide evidence that RPS19 mutations lead to codownregulation of multiple ribosomal protein genes, as well as downregulation of genes involved in translation in DBA cells. In conclusion, the altered expression of cancer-related genes suggests a molecular basis for malignancy in DBA. Downregulation of c-myb expression, which causes complete failure of fetal liver erythropoiesis in knockout mice, suggests a link between RPS19 mutations and reduced erythropoiesis in DBA.

Standard name | GAZDA_DIAMOND_BLACKFAN_ANEMIA_MYELOID_UP
Systematic name | M19107
Organism | Homo sapiens
PMID | 16741228
Authors | Gazda HT,Kho AT,Sanoudou D,Zaucha JM,Kohane IS,Sieff CA,Beggs AH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in myeloid progenitor cells isolated from bone marrow of patients with Diamond-Blackfan anemia (DBA) and mutated RPS19 [GeneID=6223].
Full description | Diamond-Blackfan anemia (DBA) is a broad developmental disease characterized by anemia, bone marrow (BM) erythroblastopenia, and an increased incidence of malignancy. Mutations in ribosomal protein gene S19 (RPS19) are found in approximately 25% of DBA patients; however, the role of RPS19 in the pathogenesis of DBA remains unknown. Using global gene expression analysis, we compared highly purified multipotential, erythroid, and myeloid BM progenitors from RPS19 mutated and control individuals. We found several ribosomal protein genes downregulated in all DBA progenitors. Apoptosis genes, such as TNFRSF10B and FAS, transcriptional control genes, including the erythropoietic transcription factor MYB (encoding c-myb), and translational genes were greatly dysregulated, mostly in diseased erythroid cells. Cancer-related genes, including RAS family oncogenes and tumor suppressor genes, were significantly dysregulated in all diseased progenitors. In addition, our results provide evidence that RPS19 mutations lead to codownregulation of multiple ribosomal protein genes, as well as downregulation of genes involved in translation in DBA cells. In conclusion, the altered expression of cancer-related genes suggests a molecular basis for malignancy in DBA. Downregulation of c-myb expression, which causes complete failure of fetal liver erythropoiesis in knockout mice, suggests a link between RPS19 mutations and reduced erythropoiesis in DBA.

Standard name | GAZDA_DIAMOND_BLACKFAN_ANEMIA_MYELOID_DN
Systematic name | M6979
Organism | Homo sapiens
PMID | 16741228
Authors | Gazda HT,Kho AT,Sanoudou D,Zaucha JM,Kohane IS,Sieff CA,Beggs AH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in myeloid progenitor cells isolated from bone marrow of patients with Diamond-Blackfan anemia (DBA) and mutated RPS19 [GeneID=6223].
Full description | Diamond-Blackfan anemia (DBA) is a broad developmental disease characterized by anemia, bone marrow (BM) erythroblastopenia, and an increased incidence of malignancy. Mutations in ribosomal protein gene S19 (RPS19) are found in approximately 25% of DBA patients; however, the role of RPS19 in the pathogenesis of DBA remains unknown. Using global gene expression analysis, we compared highly purified multipotential, erythroid, and myeloid BM progenitors from RPS19 mutated and control individuals. We found several ribosomal protein genes downregulated in all DBA progenitors. Apoptosis genes, such as TNFRSF10B and FAS, transcriptional control genes, including the erythropoietic transcription factor MYB (encoding c-myb), and translational genes were greatly dysregulated, mostly in diseased erythroid cells. Cancer-related genes, including RAS family oncogenes and tumor suppressor genes, were significantly dysregulated in all diseased progenitors. In addition, our results provide evidence that RPS19 mutations lead to codownregulation of multiple ribosomal protein genes, as well as downregulation of genes involved in translation in DBA cells. In conclusion, the altered expression of cancer-related genes suggests a molecular basis for malignancy in DBA. Downregulation of c-myb expression, which causes complete failure of fetal liver erythropoiesis in knockout mice, suggests a link between RPS19 mutations and reduced erythropoiesis in DBA.

Standard name | GAZDA_DIAMOND_BLACKFAN_ANEMIA_PROGENITOR_UP
Systematic name | M6984
Organism | Homo sapiens
PMID | 16741228
Authors | Gazda HT,Kho AT,Sanoudou D,Zaucha JM,Kohane IS,Sieff CA,Beggs AH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in common hematopoietic progenitor cells isolated from bone marrow of patients with Diamond-Blackfan anemia (DBA) and mutated RPS19 [GeneID=6223].
Full description | Diamond-Blackfan anemia (DBA) is a broad developmental disease characterized by anemia, bone marrow (BM) erythroblastopenia, and an increased incidence of malignancy. Mutations in ribosomal protein gene S19 (RPS19) are found in approximately 25% of DBA patients; however, the role of RPS19 in the pathogenesis of DBA remains unknown. Using global gene expression analysis, we compared highly purified multipotential, erythroid, and myeloid BM progenitors from RPS19 mutated and control individuals. We found several ribosomal protein genes downregulated in all DBA progenitors. Apoptosis genes, such as TNFRSF10B and FAS, transcriptional control genes, including the erythropoietic transcription factor MYB (encoding c-myb), and translational genes were greatly dysregulated, mostly in diseased erythroid cells. Cancer-related genes, including RAS family oncogenes and tumor suppressor genes, were significantly dysregulated in all diseased progenitors. In addition, our results provide evidence that RPS19 mutations lead to codownregulation of multiple ribosomal protein genes, as well as downregulation of genes involved in translation in DBA cells. In conclusion, the altered expression of cancer-related genes suggests a molecular basis for malignancy in DBA. Downregulation of c-myb expression, which causes complete failure of fetal liver erythropoiesis in knockout mice, suggests a link between RPS19 mutations and reduced erythropoiesis in DBA.

Standard name | GAZDA_DIAMOND_BLACKFAN_ANEMIA_PROGENITOR_DN
Systematic name | M12812
Organism | Homo sapiens
PMID | 16741228
Authors | Gazda HT,Kho AT,Sanoudou D,Zaucha JM,Kohane IS,Sieff CA,Beggs AH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in common hematopoietic progenitor cells isolated from bone marrow of patients with Diamond-Blackfan anemia (DBA) and mutated RPS19 [GeneID=6223].
Full description | Diamond-Blackfan anemia (DBA) is a broad developmental disease characterized by anemia, bone marrow (BM) erythroblastopenia, and an increased incidence of malignancy. Mutations in ribosomal protein gene S19 (RPS19) are found in approximately 25% of DBA patients; however, the role of RPS19 in the pathogenesis of DBA remains unknown. Using global gene expression analysis, we compared highly purified multipotential, erythroid, and myeloid BM progenitors from RPS19 mutated and control individuals. We found several ribosomal protein genes downregulated in all DBA progenitors. Apoptosis genes, such as TNFRSF10B and FAS, transcriptional control genes, including the erythropoietic transcription factor MYB (encoding c-myb), and translational genes were greatly dysregulated, mostly in diseased erythroid cells. Cancer-related genes, including RAS family oncogenes and tumor suppressor genes, were significantly dysregulated in all diseased progenitors. In addition, our results provide evidence that RPS19 mutations lead to codownregulation of multiple ribosomal protein genes, as well as downregulation of genes involved in translation in DBA cells. In conclusion, the altered expression of cancer-related genes suggests a molecular basis for malignancy in DBA. Downregulation of c-myb expression, which causes complete failure of fetal liver erythropoiesis in knockout mice, suggests a link between RPS19 mutations and reduced erythropoiesis in DBA.

Standard name | CHEMNITZ_RESPONSE_TO_PROSTAGLANDIN_E2_UP
Systematic name | M3045
Organism | Homo sapiens
PMID | 16424048
Authors | Chemnitz JM,Driesen J,Classen S,Riley JL,Debey S,Beyer M,Popov A,Zander T,Schultze JL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD4+ [GeneID=920] T lymphocytes after stimulation with prostaglandin E2 [PubChem=5280360].
Full description | Many tumors, including Hodgkin's lymphoma, are associated with decreased cellular immunity and elevated levels of prostaglandin E(2) (PGE(2)), a known inhibitor of CD4+ T cell activation, suggested to be involved in immune deviation in cancer. To address the molecular mechanisms tumor-derived PGE(2) might have on primary human CD4+ T cells, we used a whole genome-based transcriptional approach and show that PGE(2) severely limited changes of gene expression induced by signaling through the T cell receptor and CD28. This data suggests an interference of PGE(2) at an early step of T cell receptor signaling: indeed, PGE(2) stimulation of T cells leads to inactivation of lck and reduced phosphorylation of ZAP70. Antiapoptotic genes escaped PGE(2)-induced inhibition resulting in partial protection from apoptosis in response to irradiation or Fas-mediated signaling. As a functional consequence, PGE(2)-treated CD4+ T cells are arrested in the cell cycle associated with up-regulation of the cyclin/cyclin-dependent kinase inhibitor p27(kip1). Most importantly, CD4+ T cells in Hodgkin's lymphoma show similar regulation of genes that were altered in vitro by PGE(2) in T cells from healthy individuals. These data strongly suggest that PGE(2) is an important factor leading to CD4+ T cell impairment observed in Hodgkin's lymphoma.

Standard name | CHEMNITZ_RESPONSE_TO_PROSTAGLANDIN_E2_DN
Systematic name | M2214
Organism | Homo sapiens
PMID | 16424048
Authors | Chemnitz JM,Driesen J,Classen S,Riley JL,Debey S,Beyer M,Popov A,Zander T,Schultze JL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD4+ [GeneID=920] T lymphocytes after stimulation with prostaglandin E2 [PubChem=5280360].
Full description | Many tumors, including Hodgkin's lymphoma, are associated with decreased cellular immunity and elevated levels of prostaglandin E(2) (PGE(2)), a known inhibitor of CD4+ T cell activation, suggested to be involved in immune deviation in cancer. To address the molecular mechanisms tumor-derived PGE(2) might have on primary human CD4+ T cells, we used a whole genome-based transcriptional approach and show that PGE(2) severely limited changes of gene expression induced by signaling through the T cell receptor and CD28. This data suggests an interference of PGE(2) at an early step of T cell receptor signaling: indeed, PGE(2) stimulation of T cells leads to inactivation of lck and reduced phosphorylation of ZAP70. Antiapoptotic genes escaped PGE(2)-induced inhibition resulting in partial protection from apoptosis in response to irradiation or Fas-mediated signaling. As a functional consequence, PGE(2)-treated CD4+ T cells are arrested in the cell cycle associated with up-regulation of the cyclin/cyclin-dependent kinase inhibitor p27(kip1). Most importantly, CD4+ T cells in Hodgkin's lymphoma show similar regulation of genes that were altered in vitro by PGE(2) in T cells from healthy individuals. These data strongly suggest that PGE(2) is an important factor leading to CD4+ T cell impairment observed in Hodgkin's lymphoma.

Standard name | ZERBINI_RESPONSE_TO_SULINDAC_UP
Systematic name | M8991
Organism | Homo sapiens
PMID | 17178890
Authors | Zerbini LF,Czibere A,Wang Y,Correa RG,Otu H,Joseph M,Takayasu Y,Silver M,Gu X,Ruchusatsawat K,Li L,Sarkar D,Zhou JR,Fisher PB,Libermann TA
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated in DU145 and PC-3 cells (prostate cancer) after treatment with the NSAID (non-steroid anti-inflammatory drug) sulindac [PubChem=5352].
Full description | Numerous studies show that nonsteroidal anti-inflammatory drugs (NSAIDs) are effective in chemoprevention or treatment of cancer. Nevertheless, the mechanisms underlying these antineoplastic effects remain poorly understood. Here, we report that induction of the cancer-specific proapoptotic cytokine melanoma differentiation associated gene-7/interleukin-24 (MDA-7/IL-24) by several NSAIDs is an essential step for induction of apoptosis and G(2)-M growth arrest in cancer cells in vitro and inhibition of tumor growth in vivo. We also show that MDA-7/IL-24-dependent up-regulation of growth arrest and DNA damage inducible 45 alpha (GADD45alpha) and GADD45gamma gene expression is sufficient for cancer cell apoptosis via c-Jun NH(2)-terminal kinase (JNK) activation and growth arrest induction through inhibition of Cdc2-cyclin B checkpoint kinase. Knockdown of GADD45alpha and GADD45gamma transcription by small interfering RNA abrogates apoptosis and growth arrest induction by the NSAID treatment, blocks JNK activation, and restores Cdc2-cyclin B kinase activity. Our results establish MDA-7/IL-24 and GADD45alpha and GADD45gamma as critical mediators of apoptosis and growth arrest in response to NSAIDs in cancer cells.

Standard name | ZERBINI_RESPONSE_TO_SULINDAC_DN
Systematic name | M17956
Organism | Homo sapiens
PMID | 17178890
Authors | Zerbini LF,Czibere A,Wang Y,Correa RG,Otu H,Joseph M,Takayasu Y,Silver M,Gu X,Ruchusatsawat K,Li L,Sarkar D,Zhou JR,Fisher PB,Libermann TA
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated in DU145 and PC-3 cells (prostate cancer) after treatment with the NSAID (non-steroid anti-inflammatory drug) sulindac [PubChem=5352].
Full description | Numerous studies show that nonsteroidal anti-inflammatory drugs (NSAIDs) are effective in chemoprevention or treatment of cancer. Nevertheless, the mechanisms underlying these antineoplastic effects remain poorly understood. Here, we report that induction of the cancer-specific proapoptotic cytokine melanoma differentiation associated gene-7/interleukin-24 (MDA-7/IL-24) by several NSAIDs is an essential step for induction of apoptosis and G(2)-M growth arrest in cancer cells in vitro and inhibition of tumor growth in vivo. We also show that MDA-7/IL-24-dependent up-regulation of growth arrest and DNA damage inducible 45 alpha (GADD45alpha) and GADD45gamma gene expression is sufficient for cancer cell apoptosis via c-Jun NH(2)-terminal kinase (JNK) activation and growth arrest induction through inhibition of Cdc2-cyclin B checkpoint kinase. Knockdown of GADD45alpha and GADD45gamma transcription by small interfering RNA abrogates apoptosis and growth arrest induction by the NSAID treatment, blocks JNK activation, and restores Cdc2-cyclin B kinase activity. Our results establish MDA-7/IL-24 and GADD45alpha and GADD45gamma as critical mediators of apoptosis and growth arrest in response to NSAIDs in cancer cells.

Standard name | IGARASHI_ATF4_TARGETS_UP
Systematic name | M10762
Organism | Homo sapiens
PMID | 17297441
Authors | Igarashi T,Izumi H,Uchiumi T,Nishio K,Arao T,Tanabe M,Uramoto H,Sugio K,Yasumoto K,Sasaguri Y,Wang KY,Otsuji Y,Kohno K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A549 cells (lung cancer) after knockdown of ATF4 [GeneID=468] by RNAi.
Full description | The mechanisms underlying cellular drug resistance have been extensively studied, but little is known about its regulation. We have previously reported that activating transcription factor 4 (ATF4) is upregulated in cisplatin-resistant cells and plays a role in cisplatin resistance. Here, we find out a novel relationship between the circadian transcription factor Clock and drug resistance. Clock drives the periodical expression of many genes that regulate hormone release, cell division, sleep-awake cycle and tumor growth. We demonstrate that ATF4 is a direct target of Clock, and that Clock is overexpressed in cisplatin-resistant cells. Furthermore, Clock expression significantly correlates with cisplatin sensitivity, and that the downregulation of either Clock or ATF4 confers sensitivity of A549 cells to cisplatin and etoposide. Notably, ATF4-overexpressing cells show multidrug resistance and marked elevation of intracellular glutathione. The microarray study reveals that genes for glutathione metabolism are generally downregulated by the knockdown of ATF4 expression. These results suggest that the Clock and ATF4 transcription system might play an important role in multidrug resistance through glutathione-dependent redox system, and also indicate that physiological potentials of Clock-controlled redox system might be important to better understand the oxidative stress-associated disorders including cancer and systemic chronotherapy.

Standard name | IGARASHI_ATF4_TARGETS_DN
Systematic name | M4779
Organism | Homo sapiens
PMID | 17297441
Authors | Igarashi T,Izumi H,Uchiumi T,Nishio K,Arao T,Tanabe M,Uramoto H,Sugio K,Yasumoto K,Sasaguri Y,Wang KY,Otsuji Y,Kohno K
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A549 cells (lung cancer) after knockdown of ATF4 [GeneID=468] by RNAi.
Full description | The mechanisms underlying cellular drug resistance have been extensively studied, but little is known about its regulation. We have previously reported that activating transcription factor 4 (ATF4) is upregulated in cisplatin-resistant cells and plays a role in cisplatin resistance. Here, we find out a novel relationship between the circadian transcription factor Clock and drug resistance. Clock drives the periodical expression of many genes that regulate hormone release, cell division, sleep-awake cycle and tumor growth. We demonstrate that ATF4 is a direct target of Clock, and that Clock is overexpressed in cisplatin-resistant cells. Furthermore, Clock expression significantly correlates with cisplatin sensitivity, and that the downregulation of either Clock or ATF4 confers sensitivity of A549 cells to cisplatin and etoposide. Notably, ATF4-overexpressing cells show multidrug resistance and marked elevation of intracellular glutathione. The microarray study reveals that genes for glutathione metabolism are generally downregulated by the knockdown of ATF4 expression. These results suggest that the Clock and ATF4 transcription system might play an important role in multidrug resistance through glutathione-dependent redox system, and also indicate that physiological potentials of Clock-controlled redox system might be important to better understand the oxidative stress-associated disorders including cancer and systemic chronotherapy.

Standard name | ZHONG_RESPONSE_TO_AZACITIDINE_AND_TSA_UP
Systematic name | M3019
Organism | Homo sapiens
PMID | 17043644
Authors | Zhong S,Fields CR,Su N,Pan YX,Robertson KD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 3 out of 4 NSCLC cell lines (non-small cell lung cancer) after treatment with azacitidine [PubChem=9444] and TSA [PubChem=5562].
Full description | Lung cancer is the leading cause of cancer-related deaths in the United States due, in large part, to the lack of early detection methods. Lung cancer arises from a complex series of genetic and epigenetic changes leading to uncontrolled cell growth and metastasis. Unlike genetic changes, epigenetic changes, such as DNA methylation and histone acetylation, are reversible with currently available pharmaceuticals and are early events in lung tumorigenesis detectable by non-invasive methods. In order to better understand how epigenetic changes contribute to lung cancer, and to identify new disease biomarkers, we combined pharmacologic inhibition of DNA methylation and histone deacetylation in non-small cell lung cancer (NSCLC) cell lines, with genome-wide expression profiling. Of the more than 200 genes upregulated by these treatments, three of these, neuronatin, metallothionein 3 and cystatin E/M, were frequently hypermethylated and transcriptionally downregulated in NSCLC cell lines and tumors. Interestingly, four other genes, cylindromatosis, CD9, activating transcription factor 3 and oxytocin receptor, were dominantly regulated by histone deacetylation and were also frequently downregulated in lung tumors. The majority of these genes also suppressed NSCLC growth in culture when ectopically expressed. This study therefore reveals new putative NSCLC growth regulatory genes and epigenetic disease biomarkers that may enhance early detection strategies and serve as therapeutic targets.

Standard name | ZHONG_RESPONSE_TO_AZACITIDINE_AND_TSA_DN
Systematic name | M3988
Organism | Homo sapiens
PMID | 17043644
Authors | Zhong S,Fields CR,Su N,Pan YX,Robertson KD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 3 out of 4 NSCLC cell lines (non-small cell lung cancer) after treatment with azacitidine [PubChem=9444] and TSA [PubChem=5562].
Full description | Lung cancer is the leading cause of cancer-related deaths in the United States due, in large part, to the lack of early detection methods. Lung cancer arises from a complex series of genetic and epigenetic changes leading to uncontrolled cell growth and metastasis. Unlike genetic changes, epigenetic changes, such as DNA methylation and histone acetylation, are reversible with currently available pharmaceuticals and are early events in lung tumorigenesis detectable by non-invasive methods. In order to better understand how epigenetic changes contribute to lung cancer, and to identify new disease biomarkers, we combined pharmacologic inhibition of DNA methylation and histone deacetylation in non-small cell lung cancer (NSCLC) cell lines, with genome-wide expression profiling. Of the more than 200 genes upregulated by these treatments, three of these, neuronatin, metallothionein 3 and cystatin E/M, were frequently hypermethylated and transcriptionally downregulated in NSCLC cell lines and tumors. Interestingly, four other genes, cylindromatosis, CD9, activating transcription factor 3 and oxytocin receptor, were dominantly regulated by histone deacetylation and were also frequently downregulated in lung tumors. The majority of these genes also suppressed NSCLC growth in culture when ectopically expressed. This study therefore reveals new putative NSCLC growth regulatory genes and epigenetic disease biomarkers that may enhance early detection strategies and serve as therapeutic targets.

Standard name | DAVICIONI_MOLECULAR_ARMS_VS_ERMS_UP
Systematic name | M2012
Organism | Homo sapiens
PMID | 16849537
Authors | Davicioni E,Finckenstein FG,Shahbazian V,Buckley JD,Triche TJ,Anderson MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mARMS (molecular ARMS) compared to the mERMS (molecular ERMS) class of rhabdomyosarcoma tumors.
Full description | Alveolar rhabdomyosarcomas (ARMS) are aggressive soft-tissue sarcomas affecting children and young adults. Most ARMS tumors express the PAX3-FKHR or PAX7-FKHR (PAX-FKHR) fusion genes resulting from the t(2;13) or t(1;13) chromosomal translocations, respectively. However, up to 25% of ARMS tumors are fusion negative, making it unclear whether ARMS represent a single disease or multiple clinical and biological entities with a common phenotype. To test to what extent PAX-FKHR determine class and behavior of ARMS, we used oligonucleotide microarray expression profiling on 139 primary rhabdomyosarcoma tumors and an in vitro model. We found that ARMS tumors expressing either PAX-FKHR gene share a common expression profile distinct from fusion-negative ARMS and from the other rhabdomyosarcoma variants. We also observed that PAX-FKHR expression above a minimum level is necessary for the detection of this expression profile. Using an ectopic PAX3-FKHR and PAX7-FKHR expression model, we identified an expression signature regulated by PAX-FKHR that is specific to PAX-FKHR-positive ARMS tumors. Data mining for functional annotations of signature genes suggested a role for PAX-FKHR in regulating ARMS proliferation and differentiation. Cox regression modeling identified a subset of genes within the PAX-FKHR expression signature that segregated ARMS patients into three risk groups with 5-year overall survival estimates of 7%, 48%, and 93%. These prognostic classes were independent of conventional clinical risk factors. Our results show that PAX-FKHR dictate a specific expression signature that helps define the molecular phenotype of PAX-FKHR-positive ARMS tumors and, because it is linked with disease outcome in ARMS patients, determine tumor behavior.

Standard name | DAVICIONI_MOLECULAR_ARMS_VS_ERMS_DN
Systematic name | M8519
Organism | Homo sapiens
PMID | 16849537
Authors | Davicioni E,Finckenstein FG,Shahbazian V,Buckley JD,Triche TJ,Anderson MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mARMS (molecular ARMS) compared to the mERMS (molecular ERMS) class of rhabdomyosarcoma tumors.
Full description | Alveolar rhabdomyosarcomas (ARMS) are aggressive soft-tissue sarcomas affecting children and young adults. Most ARMS tumors express the PAX3-FKHR or PAX7-FKHR (PAX-FKHR) fusion genes resulting from the t(2;13) or t(1;13) chromosomal translocations, respectively. However, up to 25% of ARMS tumors are fusion negative, making it unclear whether ARMS represent a single disease or multiple clinical and biological entities with a common phenotype. To test to what extent PAX-FKHR determine class and behavior of ARMS, we used oligonucleotide microarray expression profiling on 139 primary rhabdomyosarcoma tumors and an in vitro model. We found that ARMS tumors expressing either PAX-FKHR gene share a common expression profile distinct from fusion-negative ARMS and from the other rhabdomyosarcoma variants. We also observed that PAX-FKHR expression above a minimum level is necessary for the detection of this expression profile. Using an ectopic PAX3-FKHR and PAX7-FKHR expression model, we identified an expression signature regulated by PAX-FKHR that is specific to PAX-FKHR-positive ARMS tumors. Data mining for functional annotations of signature genes suggested a role for PAX-FKHR in regulating ARMS proliferation and differentiation. Cox regression modeling identified a subset of genes within the PAX-FKHR expression signature that segregated ARMS patients into three risk groups with 5-year overall survival estimates of 7%, 48%, and 93%. These prognostic classes were independent of conventional clinical risk factors. Our results show that PAX-FKHR dictate a specific expression signature that helps define the molecular phenotype of PAX-FKHR-positive ARMS tumors and, because it is linked with disease outcome in ARMS patients, determine tumor behavior.

Standard name | DAVICIONI_TARGETS_OF_PAX_FOXO1_FUSIONS_UP
Systematic name | M4680
Organism | Homo sapiens
PMID | 16849537
Authors | Davicioni E,Finckenstein FG,Shahbazian V,Buckley JD,Triche TJ,Anderson MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RD cells (embryonal rhabdomyosarcoma, ERMS) by expression of PAX3- or PAX7-FOXO1 [GeneID=5077;5081;2308] fusions off retroviral vectors.
Full description | Alveolar rhabdomyosarcomas (ARMS) are aggressive soft-tissue sarcomas affecting children and young adults. Most ARMS tumors express the PAX3-FKHR or PAX7-FKHR (PAX-FKHR) fusion genes resulting from the t(2;13) or t(1;13) chromosomal translocations, respectively. However, up to 25% of ARMS tumors are fusion negative, making it unclear whether ARMS represent a single disease or multiple clinical and biological entities with a common phenotype. To test to what extent PAX-FKHR determine class and behavior of ARMS, we used oligonucleotide microarray expression profiling on 139 primary rhabdomyosarcoma tumors and an in vitro model. We found that ARMS tumors expressing either PAX-FKHR gene share a common expression profile distinct from fusion-negative ARMS and from the other rhabdomyosarcoma variants. We also observed that PAX-FKHR expression above a minimum level is necessary for the detection of this expression profile. Using an ectopic PAX3-FKHR and PAX7-FKHR expression model, we identified an expression signature regulated by PAX-FKHR that is specific to PAX-FKHR-positive ARMS tumors. Data mining for functional annotations of signature genes suggested a role for PAX-FKHR in regulating ARMS proliferation and differentiation. Cox regression modeling identified a subset of genes within the PAX-FKHR expression signature that segregated ARMS patients into three risk groups with 5-year overall survival estimates of 7%, 48%, and 93%. These prognostic classes were independent of conventional clinical risk factors. Our results show that PAX-FKHR dictate a specific expression signature that helps define the molecular phenotype of PAX-FKHR-positive ARMS tumors and, because it is linked with disease outcome in ARMS patients, determine tumor behavior.

Standard name | DAVICIONI_TARGETS_OF_PAX_FOXO1_FUSIONS_DN
Systematic name | M4001
Organism | Homo sapiens
PMID | 16849537
Authors | Davicioni E,Finckenstein FG,Shahbazian V,Buckley JD,Triche TJ,Anderson MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in RD cells (embryonal rhabdomyosarcoma, ERMS) by expression of PAX3- or PAX7-FOXO1 [GeneID=5077;5081;2308] fusions off retroviral vectors.
Full description | Alveolar rhabdomyosarcomas (ARMS) are aggressive soft-tissue sarcomas affecting children and young adults. Most ARMS tumors express the PAX3-FKHR or PAX7-FKHR (PAX-FKHR) fusion genes resulting from the t(2;13) or t(1;13) chromosomal translocations, respectively. However, up to 25% of ARMS tumors are fusion negative, making it unclear whether ARMS represent a single disease or multiple clinical and biological entities with a common phenotype. To test to what extent PAX-FKHR determine class and behavior of ARMS, we used oligonucleotide microarray expression profiling on 139 primary rhabdomyosarcoma tumors and an in vitro model. We found that ARMS tumors expressing either PAX-FKHR gene share a common expression profile distinct from fusion-negative ARMS and from the other rhabdomyosarcoma variants. We also observed that PAX-FKHR expression above a minimum level is necessary for the detection of this expression profile. Using an ectopic PAX3-FKHR and PAX7-FKHR expression model, we identified an expression signature regulated by PAX-FKHR that is specific to PAX-FKHR-positive ARMS tumors. Data mining for functional annotations of signature genes suggested a role for PAX-FKHR in regulating ARMS proliferation and differentiation. Cox regression modeling identified a subset of genes within the PAX-FKHR expression signature that segregated ARMS patients into three risk groups with 5-year overall survival estimates of 7%, 48%, and 93%. These prognostic classes were independent of conventional clinical risk factors. Our results show that PAX-FKHR dictate a specific expression signature that helps define the molecular phenotype of PAX-FKHR-positive ARMS tumors and, because it is linked with disease outcome in ARMS patients, determine tumor behavior.

Standard name | DAVICIONI_RHABDOMYOSARCOMA_PAX_FOXO1_FUSION_UP
Systematic name | M12362
Organism | Homo sapiens
PMID | 16849537
Authors | Davicioni E,Finckenstein FG,Shahbazian V,Buckley JD,Triche TJ,Anderson MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RMS cells (rhabdomyosarcoma) expressing PAX3 or PAX7 fusions with FOXO1 [GeneID=5077;5081;2308] compared to the fusion negative cell lines.
Full description | Alveolar rhabdomyosarcomas (ARMS) are aggressive soft-tissue sarcomas affecting children and young adults. Most ARMS tumors express the PAX3-FKHR or PAX7-FKHR (PAX-FKHR) fusion genes resulting from the t(2;13) or t(1;13) chromosomal translocations, respectively. However, up to 25% of ARMS tumors are fusion negative, making it unclear whether ARMS represent a single disease or multiple clinical and biological entities with a common phenotype. To test to what extent PAX-FKHR determine class and behavior of ARMS, we used oligonucleotide microarray expression profiling on 139 primary rhabdomyosarcoma tumors and an in vitro model. We found that ARMS tumors expressing either PAX-FKHR gene share a common expression profile distinct from fusion-negative ARMS and from the other rhabdomyosarcoma variants. We also observed that PAX-FKHR expression above a minimum level is necessary for the detection of this expression profile. Using an ectopic PAX3-FKHR and PAX7-FKHR expression model, we identified an expression signature regulated by PAX-FKHR that is specific to PAX-FKHR-positive ARMS tumors. Data mining for functional annotations of signature genes suggested a role for PAX-FKHR in regulating ARMS proliferation and differentiation. Cox regression modeling identified a subset of genes within the PAX-FKHR expression signature that segregated ARMS patients into three risk groups with 5-year overall survival estimates of 7%, 48%, and 93%. These prognostic classes were independent of conventional clinical risk factors. Our results show that PAX-FKHR dictate a specific expression signature that helps define the molecular phenotype of PAX-FKHR-positive ARMS tumors and, because it is linked with disease outcome in ARMS patients, determine tumor behavior.

Standard name | DAVICIONI_RHABDOMYOSARCOMA_PAX_FOXO1_FUSION_DN
Systematic name | M1614
Organism | Homo sapiens
PMID | 16849537
Authors | Davicioni E,Finckenstein FG,Shahbazian V,Buckley JD,Triche TJ,Anderson MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in RMS cells (rhabdomyosarcoma) expressing PAX3 or PAX7 fusions with FOXO1 [GeneID=5077;5081;2308] compared to the fusion negative cell lines.
Full description | Alveolar rhabdomyosarcomas (ARMS) are aggressive soft-tissue sarcomas affecting children and young adults. Most ARMS tumors express the PAX3-FKHR or PAX7-FKHR (PAX-FKHR) fusion genes resulting from the t(2;13) or t(1;13) chromosomal translocations, respectively. However, up to 25% of ARMS tumors are fusion negative, making it unclear whether ARMS represent a single disease or multiple clinical and biological entities with a common phenotype. To test to what extent PAX-FKHR determine class and behavior of ARMS, we used oligonucleotide microarray expression profiling on 139 primary rhabdomyosarcoma tumors and an in vitro model. We found that ARMS tumors expressing either PAX-FKHR gene share a common expression profile distinct from fusion-negative ARMS and from the other rhabdomyosarcoma variants. We also observed that PAX-FKHR expression above a minimum level is necessary for the detection of this expression profile. Using an ectopic PAX3-FKHR and PAX7-FKHR expression model, we identified an expression signature regulated by PAX-FKHR that is specific to PAX-FKHR-positive ARMS tumors. Data mining for functional annotations of signature genes suggested a role for PAX-FKHR in regulating ARMS proliferation and differentiation. Cox regression modeling identified a subset of genes within the PAX-FKHR expression signature that segregated ARMS patients into three risk groups with 5-year overall survival estimates of 7%, 48%, and 93%. These prognostic classes were independent of conventional clinical risk factors. Our results show that PAX-FKHR dictate a specific expression signature that helps define the molecular phenotype of PAX-FKHR-positive ARMS tumors and, because it is linked with disease outcome in ARMS patients, determine tumor behavior.

Standard name | SENGUPTA_NASOPHARYNGEAL_CARCINOMA_WITH_LMP1_UP
Systematic name | M19488
Organism | Homo sapiens
PMID | 16912175
Authors | Sengupta S,den Boon JA,Chen IH,Newton MA,Dahl DB,Chen M,Cheng YJ,Westra WH,Chen CJ,Hildesheim A,Sugden B,Ahlquist P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in nasopharyngeal carcinoma (NPC) positive for LMP1 [GeneID=9260], a latent gene of Epstein-Barr virus (EBV).
Full description | To identify the molecular mechanisms by which EBV-associated epithelial cancers are maintained, we measured the expression of essentially all human genes and all latent EBV genes in a collection of 31 laser-captured, microdissected nasopharyngeal carcinoma (NPC) tissue samples and 10 normal nasopharyngeal tissues. Global gene expression profiles clearly distinguished tumors from normal healthy epithelium. Expression levels of six viral genes (EBNA1, EBNA2, EBNA3A, EBNA3B, LMP1, and LMP2A) were correlated among themselves and strongly inversely correlated with the expression of a large subset of host genes. Among the human genes whose inhibition was most strongly correlated with increased EBV gene expression were multiple MHC class I HLA genes involved in regulating immune response via antigen presentation. The association between EBV gene expression and inhibition of MHC class I HLA expression implies that antigen display is either directly inhibited by EBV, facilitating immune evasion by tumor cells, and/or that tumor cells with inhibited presentation are selected for their ability to sustain higher levels of EBV to take maximum advantage of EBV oncogene-mediated tumor-promoting actions. Our data clearly reflect such tumor promotion, showing that deregulation of key proteins involved in apoptosis (BCL2-related protein A1 and Fas apoptotic inhibitory molecule), cell cycle checkpoints (AKIP, SCYL1, and NIN), and metastasis (matrix metalloproteinase 1) is closely correlated with the levels of EBV gene expression in NPC.

Standard name | SENGUPTA_NASOPHARYNGEAL_CARCINOMA_WITH_LMP1_DN
Systematic name | M6750
Organism | Homo sapiens
PMID | 16912175
Authors | Sengupta S,den Boon JA,Chen IH,Newton MA,Dahl DB,Chen M,Cheng YJ,Westra WH,Chen CJ,Hildesheim A,Sugden B,Ahlquist P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in nasopharyngeal carcinoma (NPC) positive for LMP1 [GeneID=9260], a latent gene of Epstein-Barr virus (EBV).
Full description | To identify the molecular mechanisms by which EBV-associated epithelial cancers are maintained, we measured the expression of essentially all human genes and all latent EBV genes in a collection of 31 laser-captured, microdissected nasopharyngeal carcinoma (NPC) tissue samples and 10 normal nasopharyngeal tissues. Global gene expression profiles clearly distinguished tumors from normal healthy epithelium. Expression levels of six viral genes (EBNA1, EBNA2, EBNA3A, EBNA3B, LMP1, and LMP2A) were correlated among themselves and strongly inversely correlated with the expression of a large subset of host genes. Among the human genes whose inhibition was most strongly correlated with increased EBV gene expression were multiple MHC class I HLA genes involved in regulating immune response via antigen presentation. The association between EBV gene expression and inhibition of MHC class I HLA expression implies that antigen display is either directly inhibited by EBV, facilitating immune evasion by tumor cells, and/or that tumor cells with inhibited presentation are selected for their ability to sustain higher levels of EBV to take maximum advantage of EBV oncogene-mediated tumor-promoting actions. Our data clearly reflect such tumor promotion, showing that deregulation of key proteins involved in apoptosis (BCL2-related protein A1 and Fas apoptotic inhibitory molecule), cell cycle checkpoints (AKIP, SCYL1, and NIN), and metastasis (matrix metalloproteinase 1) is closely correlated with the levels of EBV gene expression in NPC.

Standard name | TURASHVILI_BREAST_NORMAL_DUCTAL_VS_LOBULAR_UP
Systematic name | M2204
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in normal ductal and normal lobular breast cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_NORMAL_DUCTAL_VS_LOBULAR_DN
Systematic name | M13172
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in normal ductal and normal lobular breast cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_DUCTAL_CARCINOMA_VS_DUCTAL_NORMAL_UP
Systematic name | M7585
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ductal carcinoma vs normal ductal breast cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_DUCTAL_CARCINOMA_VS_DUCTAL_NORMAL_DN
Systematic name | M14134
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ductal carcinoma vs normal ductal breast cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_DUCTAL_CARCINOMA_VS_LOBULAR_NORMAL_UP
Systematic name | M4479
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ductal carcinoma vs normal lobular breast cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_DUCTAL_CARCINOMA_VS_LOBULAR_NORMAL_DN
Systematic name | M5618
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ductal carcinoma vs normal lobular breast cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_CARCINOMA_DUCTAL_VS_LOBULAR_UP
Systematic name | M15137
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ductal vs lobular carcinoma breast tumor cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_CARCINOMA_DUCTAL_VS_LOBULAR_DN
Systematic name | M12208
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ductal vs lobular carcinoma breast tumor cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_LOBULAR_CARCINOMA_VS_DUCTAL_NORMAL_UP
Systematic name | M10165
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in lobular carcinoma vs normal ductal breast cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_LOBULAR_CARCINOMA_VS_DUCTAL_NORMAL_DN
Systematic name | M3672
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in lobular carcinoma vs normal ductal breast cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_LOBULAR_CARCINOMA_VS_LOBULAR_NORMAL_UP
Systematic name | M5549
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in lobular carcinoma vs normal lobular breast cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | TURASHVILI_BREAST_LOBULAR_CARCINOMA_VS_LOBULAR_NORMAL_DN
Systematic name | M13547
Organism | Homo sapiens
PMID | 17389037
Authors | Turashvili G,Bouchal J,Baumforth K,Wei W,Dziechciarkova M,Ehrmann J,Klein J,Fridman E,Skarda J,Srovnal J,Hajduch M,Murray P,Kolar Z
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in lobular carcinoma vs normal lobular breast cells.
Full description | BACKGROUND: Invasive ductal and lobular carcinomas (IDC and ILC) are the most common histological types of breast cancer. Clinical follow-up data and metastatic patterns suggest that the development and progression of these tumors are different. The aim of our study was to identify gene expression profiles of IDC and ILC in relation to normal breast epithelial cells. METHODS: We examined 30 samples (normal ductal and lobular cells from 10 patients, IDC cells from 5 patients, ILC cells from 5 patients) microdissected from cryosections of ten mastectomy specimens from postmenopausal patients. Fifty nanograms of total RNA were amplified and labeled by PCR and in vitro transcription. Samples were analysed upon Affymetrix U133 Plus 2.0 Arrays. The expression of seven differentially expressed genes (CDH1, EMP1, DDR1, DVL1, KRT5, KRT6, KRT17) was verified by immunohistochemistry on tissue microarrays. Expression of ASPN mRNA was validated by in situ hybridization on frozen sections, and CTHRC1, ASPN and COL3A1 were tested by PCR. RESULTS: Using GCOS pairwise comparison algorithm and rank products we have identified 84 named genes common to ILC versus normal cell types, 74 named genes common to IDC versus normal cell types, 78 named genes differentially expressed between normal ductal and lobular cells, and 28 named genes between IDC and ILC. Genes distinguishing between IDC and ILC are involved in epithelial-mesenchymal transition, TGF-beta and Wnt signaling. These changes were present in both tumor types but appeared to be more prominent in ILC. Immunohistochemistry for several novel markers (EMP1, DVL1, DDR1) distinguished large sets of IDC from ILC. CONCLUSION: IDC and ILC can be differentiated both at the gene and protein levels. In this study we report two candidate genes, asporin (ASPN) and collagen triple helix repeat containing 1 (CTHRC1) which might be significant in breast carcinogenesis. Besides E-cadherin, the proteins validated on tissue microarrays (EMP1, DVL1, DDR1) may represent novel immunohistochemical markers helpful in distinguishing between IDC and ILC. Further studies with larger sets of patients are needed to verify the gene expression profiles of various histological types of breast cancer in order to determine molecular subclassifications, prognosis and the optimum treatment strategies.

Standard name | CHANDRAN_METASTASIS_TOP50_UP
Systematic name | M18970
Organism | Homo sapiens
PMID | 17430594
Authors | Chandran UR,Ma C,Dhir R,Bisceglia M,Lyons-Weiler M,Liang W,Michalopoulos G,Becich M,Monzon FA
Category | C2
Sub-category | CGP
Brief description | Top 50 genes up-regulated in metastatic vs primary prostate cancer tumors.
Full description | BACKGROUND: Prostate cancer is characterized by heterogeneity in the clinical course that often does not correlate with morphologic features of the tumor. Metastasis reflects the most adverse outcome of prostate cancer, and to date there are no reliable morphologic features or serum biomarkers that can reliably predict which patients are at higher risk of developing metastatic disease. Understanding the differences in the biology of metastatic and organ confined primary tumors is essential for developing new prognostic markers and therapeutic targets. METHODS: Using Affymetrix oligonucleotide arrays, we analyzed gene expression profiles of 24 androgen-ablation resistant metastatic samples obtained from 4 patients and a previously published dataset of 64 primary prostate tumor samples. Differential gene expression was analyzed after removing potentially uninformative stromal genes, addressing the differences in cellular content between primary and metastatic tumors. RESULTS: The metastatic samples are highly heterogenous in expression; however, differential expression analysis shows that 415 genes are upregulated and 364 genes are downregulated at least 2 fold in every patient with metastasis. The expression profile of metastatic samples reveals changes in expression of a unique set of genes representing both the androgen ablation related pathways and other metastasis related gene networks such as cell adhesion, bone remodelling and cell cycle. The differentially expressed genes include metabolic enzymes, transcription factors such as Forkhead Box M1 (FoxM1) and cell adhesion molecules such as Osteopontin (SPP1). CONCLUSION: We hypothesize that these genes have a role in the biology of metastatic disease and that they represent potential therapeutic targets for prostate cancer.

Standard name | CHANDRAN_METASTASIS_TOP50_DN
Systematic name | M17043
Organism | Homo sapiens
PMID | 17430594
Authors | Chandran UR,Ma C,Dhir R,Bisceglia M,Lyons-Weiler M,Liang W,Michalopoulos G,Becich M,Monzon FA
Category | C2
Sub-category | CGP
Brief description | Top 50 genes down-regulated in metastatic vs primary prostate cancer tumors.
Full description | BACKGROUND: Prostate cancer is characterized by heterogeneity in the clinical course that often does not correlate with morphologic features of the tumor. Metastasis reflects the most adverse outcome of prostate cancer, and to date there are no reliable morphologic features or serum biomarkers that can reliably predict which patients are at higher risk of developing metastatic disease. Understanding the differences in the biology of metastatic and organ confined primary tumors is essential for developing new prognostic markers and therapeutic targets. METHODS: Using Affymetrix oligonucleotide arrays, we analyzed gene expression profiles of 24 androgen-ablation resistant metastatic samples obtained from 4 patients and a previously published dataset of 64 primary prostate tumor samples. Differential gene expression was analyzed after removing potentially uninformative stromal genes, addressing the differences in cellular content between primary and metastatic tumors. RESULTS: The metastatic samples are highly heterogenous in expression; however, differential expression analysis shows that 415 genes are upregulated and 364 genes are downregulated at least 2 fold in every patient with metastasis. The expression profile of metastatic samples reveals changes in expression of a unique set of genes representing both the androgen ablation related pathways and other metastasis related gene networks such as cell adhesion, bone remodelling and cell cycle. The differentially expressed genes include metabolic enzymes, transcription factors such as Forkhead Box M1 (FoxM1) and cell adhesion molecules such as Osteopontin (SPP1). CONCLUSION: We hypothesize that these genes have a role in the biology of metastatic disease and that they represent potential therapeutic targets for prostate cancer.

Standard name | WILCOX_RESPONSE_TO_PROGESTERONE_UP
Systematic name | M18058
Organism | Homo sapiens
PMID | 18070364
Authors | Wilcox CB,Feddes GO,Willett-Brozick JE,Hsu LC,DeLoia JA,Baysal BE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary cultures of ovarian surface epithlium cells exposed to progesterone [PubChem=5994] for 5 days.
Full description | BACKGROUND: Ovarian cancer (OvCa) most often derives from ovarian surface epithelial (OSE) cells. Several lines of evidence strongly suggest that increased exposure to progesterone (P4) protects women against developing OvCa. However, the underlying mechanisms of this protection are incompletely understood. METHODS: To determine downstream gene targets of P4, we established short term in vitro cultures of non-neoplastic OSE cells from six subjects, exposed the cells to P4 (10-6 M) for five days and performed transcriptional profiling with oligonucleotide microarrays containing over 22,000 transcripts. RESULTS: We identified concordant but modest gene expression changes in cholesterol/lipid homeostasis genes in three of six samples (responders), whereas the other three samples (non-responders) showed no expressional response to P4. The most up-regulated gene was TMEM97 which encodes a transmembrane protein of unknown function (MAC30). Analyses of outlier transcripts, whose expression levels changed most significantly upon P4 exposure, uncovered coordinate up-regulation of 14 cholesterol biosynthesis enzymes, insulin-induced gene 1, low density lipoprotein receptor, ABCG1, endothelial lipase, stearoyl- CoA and fatty acid desaturases, long-chain fatty-acyl elongase, and down-regulation of steroidogenic acute regulatory protein and ABCC6. Highly correlated tissue-specific expression patterns of TMEM97 and the cholesterol biosynthesis genes were confirmed by analysis of the GNF Atlas 2 universal gene expression database. Real-time quantitative RT-PCR analyses revealed 2.4-fold suppression of the TMEM97 gene expression in short-term cultures of OvCa relative to the normal OSE cells. CONCLUSION: These findings suggest that a co-regulated transcript network of cholesterol/lipid homeostasis genes and TMEM97 are downstream targets of P4 in normal OSE cells and that TMEM97 plays a role in cholesterol and lipid metabolism. The P4-induced alterations in cholesterol and lipid metabolism in OSE cells might play a role in conferring protection against OvCa.

Standard name | WILCOX_RESPONSE_TO_PROGESTERONE_DN
Systematic name | M16774
Organism | Homo sapiens
PMID | 18070364
Authors | Wilcox CB,Feddes GO,Willett-Brozick JE,Hsu LC,DeLoia JA,Baysal BE
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary cultures of ovarian surface epithlium cells exposed to progesterone [PubChem=5994] for 5 days.
Full description | BACKGROUND: Ovarian cancer (OvCa) most often derives from ovarian surface epithelial (OSE) cells. Several lines of evidence strongly suggest that increased exposure to progesterone (P4) protects women against developing OvCa. However, the underlying mechanisms of this protection are incompletely understood. METHODS: To determine downstream gene targets of P4, we established short term in vitro cultures of non-neoplastic OSE cells from six subjects, exposed the cells to P4 (10-6 M) for five days and performed transcriptional profiling with oligonucleotide microarrays containing over 22,000 transcripts. RESULTS: We identified concordant but modest gene expression changes in cholesterol/lipid homeostasis genes in three of six samples (responders), whereas the other three samples (non-responders) showed no expressional response to P4. The most up-regulated gene was TMEM97 which encodes a transmembrane protein of unknown function (MAC30). Analyses of outlier transcripts, whose expression levels changed most significantly upon P4 exposure, uncovered coordinate up-regulation of 14 cholesterol biosynthesis enzymes, insulin-induced gene 1, low density lipoprotein receptor, ABCG1, endothelial lipase, stearoyl- CoA and fatty acid desaturases, long-chain fatty-acyl elongase, and down-regulation of steroidogenic acute regulatory protein and ABCC6. Highly correlated tissue-specific expression patterns of TMEM97 and the cholesterol biosynthesis genes were confirmed by analysis of the GNF Atlas 2 universal gene expression database. Real-time quantitative RT-PCR analyses revealed 2.4-fold suppression of the TMEM97 gene expression in short-term cultures of OvCa relative to the normal OSE cells. CONCLUSION: These findings suggest that a co-regulated transcript network of cholesterol/lipid homeostasis genes and TMEM97 are downstream targets of P4 in normal OSE cells and that TMEM97 plays a role in cholesterol and lipid metabolism. The P4-induced alterations in cholesterol and lipid metabolism in OSE cells might play a role in conferring protection against OvCa.

Standard name | FULCHER_INFLAMMATORY_RESPONSE_LECTIN_VS_LPS_UP
Systematic name | M6659
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in monocyte-derived dendritic cells (MDDC) after stimulation with galecin-1 (lectin, LGALS1) [GeneID=3956] compared to that with bacterial lipopolysaccharide (LPS).
Full description | Dendritic cells (DCs) are potent mediators of the immune response, and can be activated by exogenous pathogen components. Galectin-1 is a member of the conserved beta-galactoside-binding lectin family that binds galactoside residues on cell surface glycoconjugates. Galectin-1 is known to play a role in immune regulation via action on multiple immune cells. However, its effects on human DCs are unknown. In this study, we show that galectin-1 induces a phenotypic and functional maturation in human monocyte-derived DCs (MDDCs) similar to but distinct from the activity of the exogenous pathogen stimuli, LPS. Immature human MDDCs exposed to galectin-1 up-regulated cell surface markers characteristic of DC maturation (CD40, CD83, CD86, and HLA-DR), secreted high levels of IL-6 and TNF-alpha, stimulated T cell proliferation, and showed reduced endocytic capacity, similar to LPS-matured MDDCs. However, unlike LPS-matured DCs, galectin-1-treated MDDCs did not produce the Th1-polarizing cytokine IL-12. Microarray analysis revealed that in addition to modulating many of the same DC maturation genes as LPS, galectin-1 also uniquely up-regulated a significant subset of genes related to cell migration through the extracellular matrix (ECM). Indeed, compared with LPS, galectin-1-treated human MDDCs exhibited significantly better chemotactic migration through Matrigel, an in vitro ECM model. Our findings show that galectin-1 is a novel endogenous activator of human MDDCs that up-regulates a significant subset of genes distinct from those regulated by a model exogenous stimulus (LPS). One unique effect of galectin-1 is to increase DC migration through the ECM, suggesting that galectin-1 may be an important component in initiating an immune response.

Standard name | FULCHER_INFLAMMATORY_RESPONSE_LECTIN_VS_LPS_DN
Systematic name | M4785
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in monocyte-derived dendritic cells (MDDC) after stimulation with galecin-1 (lectin, LGALS1) [GeneID=3956] compared to that with bacterial lipopolysaccharide (LPS).
Full description | Dendritic cells (DCs) are potent mediators of the immune response, and can be activated by exogenous pathogen components. Galectin-1 is a member of the conserved beta-galactoside-binding lectin family that binds galactoside residues on cell surface glycoconjugates. Galectin-1 is known to play a role in immune regulation via action on multiple immune cells. However, its effects on human DCs are unknown. In this study, we show that galectin-1 induces a phenotypic and functional maturation in human monocyte-derived DCs (MDDCs) similar to but distinct from the activity of the exogenous pathogen stimuli, LPS. Immature human MDDCs exposed to galectin-1 up-regulated cell surface markers characteristic of DC maturation (CD40, CD83, CD86, and HLA-DR), secreted high levels of IL-6 and TNF-alpha, stimulated T cell proliferation, and showed reduced endocytic capacity, similar to LPS-matured MDDCs. However, unlike LPS-matured DCs, galectin-1-treated MDDCs did not produce the Th1-polarizing cytokine IL-12. Microarray analysis revealed that in addition to modulating many of the same DC maturation genes as LPS, galectin-1 also uniquely up-regulated a significant subset of genes related to cell migration through the extracellular matrix (ECM). Indeed, compared with LPS, galectin-1-treated human MDDCs exhibited significantly better chemotactic migration through Matrigel, an in vitro ECM model. Our findings show that galectin-1 is a novel endogenous activator of human MDDCs that up-regulates a significant subset of genes distinct from those regulated by a model exogenous stimulus (LPS). One unique effect of galectin-1 is to increase DC migration through the ECM, suggesting that galectin-1 may be an important component in initiating an immune response.

Standard name | GARY_CD5_TARGETS_UP
Systematic name | M17693
Organism | Homo sapiens
PMID | 17878328
Authors | Gary-Gouy H,Sainz-Perez A,Marteau JB,Marfaing-Koka A,Delic J,Merle-Beral H,Galanaud P,Dalloul A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Daudi cells (B lymphocytes) stably expressing CD5 [GeneID=921] off a plasmid vector.
Full description | Chronic lymphocytic leukemia (CLL) results in the accumulation of B cells, presumably reflecting the selection of malignant cell precursors with Ag combined with complex alterations in protein activity. Repeated BCR stimulation of normal B cells leads to anergy and CD5 expression, both of which are features of CLL. Because CD5 is phosphorylated on tyrosine following BCR engagement and negatively regulates BCR signaling in normal B cells, we investigated its phosphorylation status and found it to be naturally phosphorylated on tyrosine but not on serine residues in CLL samples. To analyze the role of CD5, we established a B cell line in which CD5 is phosphorylated. Gene profiling of vector vs CD5-transfected B cells pointed out gene groups whose expression was enhanced: Apoptosis inhibitors (BCL2), NF-kappaB (RELB, BCL3), Wnt, TGFbeta, VEGF, MAPKs, Stats, cytokines, chemokines (IL-10, IL-10R, IL-2R, CCL-3, CCL-4, and CCR7), TLR-9, and the surface Ags CD52, CD54, CD70, and CD72. Most of these gene groups are strongly expressed in CLL B cells as compared with normal B cells. Unexpectedly, metabolic pathways, namely cholesterol synthesis and adipogenesis, are also enhanced by CD5. Conversely, CD5 inhibited genes involved in RNA splicing and processing, ribosome biogenesis, proteasome, and CD80 and CD86 Ags, whose expression is low in CLL. Comparison of CD5- vs tailless CD5-transfected cells further demonstrated the role of CD5 phosphorylation in the regulation of selected genes. These results support a model where CLL cells are chronically stimulated, leading to CD5 activation and cell survival. In addition to CD5 itself, we point to several CD5-induced genes as potential therapeutic targets.

Standard name | GARY_CD5_TARGETS_DN
Systematic name | M13893
Organism | Homo sapiens
PMID | 17878328
Authors | Gary-Gouy H,Sainz-Perez A,Marteau JB,Marfaing-Koka A,Delic J,Merle-Beral H,Galanaud P,Dalloul A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Daudi cells (B lymphocytes) stably expressing CD5 [GeneID=921] off a plasmid vector.
Full description | Chronic lymphocytic leukemia (CLL) results in the accumulation of B cells, presumably reflecting the selection of malignant cell precursors with Ag combined with complex alterations in protein activity. Repeated BCR stimulation of normal B cells leads to anergy and CD5 expression, both of which are features of CLL. Because CD5 is phosphorylated on tyrosine following BCR engagement and negatively regulates BCR signaling in normal B cells, we investigated its phosphorylation status and found it to be naturally phosphorylated on tyrosine but not on serine residues in CLL samples. To analyze the role of CD5, we established a B cell line in which CD5 is phosphorylated. Gene profiling of vector vs CD5-transfected B cells pointed out gene groups whose expression was enhanced: Apoptosis inhibitors (BCL2), NF-kappaB (RELB, BCL3), Wnt, TGFbeta, VEGF, MAPKs, Stats, cytokines, chemokines (IL-10, IL-10R, IL-2R, CCL-3, CCL-4, and CCR7), TLR-9, and the surface Ags CD52, CD54, CD70, and CD72. Most of these gene groups are strongly expressed in CLL B cells as compared with normal B cells. Unexpectedly, metabolic pathways, namely cholesterol synthesis and adipogenesis, are also enhanced by CD5. Conversely, CD5 inhibited genes involved in RNA splicing and processing, ribosome biogenesis, proteasome, and CD80 and CD86 Ags, whose expression is low in CLL. Comparison of CD5- vs tailless CD5-transfected cells further demonstrated the role of CD5 phosphorylation in the regulation of selected genes. These results support a model where CLL cells are chronically stimulated, leading to CD5 activation and cell survival. In addition to CD5 itself, we point to several CD5-induced genes as potential therapeutic targets.

Standard name | ZHOU_INFLAMMATORY_RESPONSE_LIVE_UP
Systematic name | M18685
Organism | Homo sapiens
PMID | 18025224
Authors | Zhou Q,Amar S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in macrophage by live P.gingivalis.
Full description | Porphyromonas gingivalis (P. gingivalis) can trigger an inflammatory condition leading to the destruction of periodontal tissues. However P. gingivalis LPS and its fimbriae (FimA) play different roles compared with the live bacteria in the context of intracellular molecule induction and cytokine secretion. To elucidate whether this difference results from different signaling pathways in host immune response to P. gingivalis, its LPS, or its FimA, we examined gene expression profile of human macrophages exposed to P. gingivalis, its LPS, or its FimA. A comparison of gene expression resulted in the identification of three distinct groups of expressed genes. Furthermore, computer-assisted promoter analysis of a subset of each group of differentially regulated genes revealed four putative transcriptional regulation models that associate with transcription factors NFkappaB, IRF7, and KLF4. Using gene knockout mice and siRNA to silence mouse genes, we showed that both TLR2 and TLR7 are essential for the induction of NFkappaB-containing genes and NFkappaB-IFN-sensitive response element (ISRE) cocontaining genes by either P. gingivalis or its purified components. The gene induction via either TLR2 or TLR7 is dependent on both MyD88 and p38 MAPK. However, the unique induction of IFN-beta by P. gingivalis LPS requires TLR7 and IFNalphabetaR cosignaling, and the induction of ISRE-containing gene is dependent on the activation of IFN-beta autocrine loop. Taken together, these data demonstrate that P. gingivalis and its components induce NFkappaB-containing genes through either TLR2- or TLR7-MyD88-p38 MAPK pathway, while P. gingivalis LPS uniquely induces ISRE-containing genes, which requires IFNalphabetaR signaling involving IRF7, KLF4, and pY701 STAT1.

Standard name | ZHOU_INFLAMMATORY_RESPONSE_LIVE_DN
Systematic name | M14032
Organism | Homo sapiens
PMID | 18025224
Authors | Zhou Q,Amar S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in macrophage by live P.gingivalis.
Full description | Porphyromonas gingivalis (P. gingivalis) can trigger an inflammatory condition leading to the destruction of periodontal tissues. However P. gingivalis LPS and its fimbriae (FimA) play different roles compared with the live bacteria in the context of intracellular molecule induction and cytokine secretion. To elucidate whether this difference results from different signaling pathways in host immune response to P. gingivalis, its LPS, or its FimA, we examined gene expression profile of human macrophages exposed to P. gingivalis, its LPS, or its FimA. A comparison of gene expression resulted in the identification of three distinct groups of expressed genes. Furthermore, computer-assisted promoter analysis of a subset of each group of differentially regulated genes revealed four putative transcriptional regulation models that associate with transcription factors NFkappaB, IRF7, and KLF4. Using gene knockout mice and siRNA to silence mouse genes, we showed that both TLR2 and TLR7 are essential for the induction of NFkappaB-containing genes and NFkappaB-IFN-sensitive response element (ISRE) cocontaining genes by either P. gingivalis or its purified components. The gene induction via either TLR2 or TLR7 is dependent on both MyD88 and p38 MAPK. However, the unique induction of IFN-beta by P. gingivalis LPS requires TLR7 and IFNalphabetaR cosignaling, and the induction of ISRE-containing gene is dependent on the activation of IFN-beta autocrine loop. Taken together, these data demonstrate that P. gingivalis and its components induce NFkappaB-containing genes through either TLR2- or TLR7-MyD88-p38 MAPK pathway, while P. gingivalis LPS uniquely induces ISRE-containing genes, which requires IFNalphabetaR signaling involving IRF7, KLF4, and pY701 STAT1.

Standard name | SAMOLS_TARGETS_OF_KHSV_MIRNAS_UP
Systematic name | M13045
Organism | Homo sapiens
PMID | 17500590
Authors | Samols MA,Skalsky RL,Maldonado AM,Riva A,Lopez MC,Baker HV,Renne R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 293 cells (embryonic kidney) upon expression of KHSV (Kaposi sarcoma-associated herpesvirus) microRNAs.
Full description | MicroRNAs (miRNAs) are 19 to 23 nucleotide-long RNAs that post-transcriptionally regulate gene expression. Human cells express several hundred miRNAs which regulate important biological pathways such as development, proliferation, and apoptosis. Recently, 12 miRNA genes have been identified within the genome of Kaposi sarcoma-associated herpesvirus; however, their functions are still unknown. To identify host cellular genes that may be targeted by these novel viral regulators, we performed gene expression profiling in cells stably expressing KSHV-encoded miRNAs. Data analysis revealed a set of 81 genes whose expression was significantly changed in the presence of miRNAs. While the majority of changes were below 2-fold, eight genes were down-regulated between 4- and 20-fold. We confirmed miRNA-dependent regulation for three of these genes and found that protein levels of thrombospondin 1 (THBS1) were decreased >10-fold. THBS1 has previously been reported to be down-regulated in Kaposi sarcoma lesions and has known activity as a strong tumor suppressor and anti-angiogenic factor, exerting its anti-angiogenic effect in part by activating the latent form of TGF-beta. We show that reduced THBS1 expression in the presence of viral miRNAs translates into decreased TGF-beta activity. These data suggest that KSHV-encoded miRNAs may contribute directly to pathogenesis by down-regulation of THBS1, a major regulator of cell adhesion, migration, and angiogenesis.

Standard name | SAMOLS_TARGETS_OF_KHSV_MIRNAS_DN
Systematic name | M17268
Organism | Homo sapiens
PMID | 17500590
Authors | Samols MA,Skalsky RL,Maldonado AM,Riva A,Lopez MC,Baker HV,Renne R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 293 cells (embryonic kidney) upon expression of KHSV (Kaposi sarcoma-associated herpesvirus) microRNAs.
Full description | MicroRNAs (miRNAs) are 19 to 23 nucleotide-long RNAs that post-transcriptionally regulate gene expression. Human cells express several hundred miRNAs which regulate important biological pathways such as development, proliferation, and apoptosis. Recently, 12 miRNA genes have been identified within the genome of Kaposi sarcoma-associated herpesvirus; however, their functions are still unknown. To identify host cellular genes that may be targeted by these novel viral regulators, we performed gene expression profiling in cells stably expressing KSHV-encoded miRNAs. Data analysis revealed a set of 81 genes whose expression was significantly changed in the presence of miRNAs. While the majority of changes were below 2-fold, eight genes were down-regulated between 4- and 20-fold. We confirmed miRNA-dependent regulation for three of these genes and found that protein levels of thrombospondin 1 (THBS1) were decreased >10-fold. THBS1 has previously been reported to be down-regulated in Kaposi sarcoma lesions and has known activity as a strong tumor suppressor and anti-angiogenic factor, exerting its anti-angiogenic effect in part by activating the latent form of TGF-beta. We show that reduced THBS1 expression in the presence of viral miRNAs translates into decreased TGF-beta activity. These data suggest that KSHV-encoded miRNAs may contribute directly to pathogenesis by down-regulation of THBS1, a major regulator of cell adhesion, migration, and angiogenesis.

Standard name | HOOI_ST7_TARGETS_UP
Systematic name | M8455
Organism | Homo sapiens
PMID | 16474848
Authors | Hooi CF,Blancher C,Qiu W,Revet IM,Williams LH,Ciavarella ML,Anderson RL,Thompson EW,Connor A,Phillips WA,Campbell IG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in PC-3 cells (prostate cancer) stably expressing ST7 [GeneID=7982] off a plasmid vector.
Full description | Multiple lines of evidence have provided compelling evidence for the existence of a tumor suppressor gene (TSG) on chromosome 7q31.1. ST7 may be the target of this genetic instability but its designation as a TSG is controversial. In this study, we show that, functionally, ST7 behaves as a tumor suppressor in human cancer. ST7 suppressed growth of PC-3 prostate cancer cells inoculated subcutaneously into severe combined immunodeficient mice, and increased the latency of tumor detection from 13 days in control tumors to 23 days. Re-expression of ST7 was also associated with suppression of colony formation under anchorage-independent conditions in MDA-MB-231 breast cancer cells and ST7 mRNA expression was downregulated in 44% of primary breast cancers. Expression profiling of PC-3 cells revealed that ST7 predominantly induces changes in genes involved in re-modeling the extracellular matrix such as SPARC, IGFBP5 and several matrix metalloproteinases. These data indicate that ST7 may mediate tumor suppression through modification of the tumor microenvironment.

Standard name | HOOI_ST7_TARGETS_DN
Systematic name | M14801
Organism | Homo sapiens
PMID | 16474848
Authors | Hooi CF,Blancher C,Qiu W,Revet IM,Williams LH,Ciavarella ML,Anderson RL,Thompson EW,Connor A,Phillips WA,Campbell IG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in PC-3 cells (prostate cancer) stably expressing ST7 [GeneID=7982] off a plasmid vector.
Full description | Multiple lines of evidence have provided compelling evidence for the existence of a tumor suppressor gene (TSG) on chromosome 7q31.1. ST7 may be the target of this genetic instability but its designation as a TSG is controversial. In this study, we show that, functionally, ST7 behaves as a tumor suppressor in human cancer. ST7 suppressed growth of PC-3 prostate cancer cells inoculated subcutaneously into severe combined immunodeficient mice, and increased the latency of tumor detection from 13 days in control tumors to 23 days. Re-expression of ST7 was also associated with suppression of colony formation under anchorage-independent conditions in MDA-MB-231 breast cancer cells and ST7 mRNA expression was downregulated in 44% of primary breast cancers. Expression profiling of PC-3 cells revealed that ST7 predominantly induces changes in genes involved in re-modeling the extracellular matrix such as SPARC, IGFBP5 and several matrix metalloproteinases. These data indicate that ST7 may mediate tumor suppression through modification of the tumor microenvironment.

Standard name | PRAMOONJAGO_SOX4_TARGETS_UP
Systematic name | M14958
Organism | Homo sapiens
PMID | 16636670
Authors | Pramoonjago P,Baras AS,Moskaluk CA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ACC3 cells (adenoid cystic carcinoma) after knockdown of SOX4 [GeneID=6659] by RNAi.
Full description | Microarray RNA gene expression profiling analysis has shown that Sox4 (Sry-related high mobility group (HMG) box 4) is one of the most upregulated genes in adenoid cystic carcinoma (ACC), relative to non-neoplastic tissue of origin. Here, we show that Sox4 protein is similarly upregulated in ACC by immunohistochemistry of 28 primary cancers and 20 normal tissues. To elucidate the functional significance of these findings, RNA interference (RNAi)-mediated RNA silencing was used to downregulate Sox4 expression in the ACC-derived cell line, ACC3. With confirmed knockdown of Sox4 protein, cell viability was reduced by 51%, with a corresponding increase of apoptosis to 85% as compared to 12% in controls. Apoptosis was confirmed by cell morphology, DNA fragmentation and flow cytometry. Cells could be rescued from the proapoptotic effects of Sox4 RNAi by co-transfection with a construct expressing functional Sox4. Microarray gene expression profiling of RNAi knockdown experiments shows that downregulation of Sox4-modulated expression of critical genes involved in apoptosis and cell cycle control. Overall, our findings suggest that Sox4 contributes to the malignant phenotype of ACC cells by promoting cell survival.

Standard name | PRAMOONJAGO_SOX4_TARGETS_DN
Systematic name | M11665
Organism | Homo sapiens
PMID | 16636670
Authors | Pramoonjago P,Baras AS,Moskaluk CA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ACC3 cells (adenoid cystic carcinoma) after knockdown of SOX4 [GeneID=6659] by RNAi.
Full description | Microarray RNA gene expression profiling analysis has shown that Sox4 (Sry-related high mobility group (HMG) box 4) is one of the most upregulated genes in adenoid cystic carcinoma (ACC), relative to non-neoplastic tissue of origin. Here, we show that Sox4 protein is similarly upregulated in ACC by immunohistochemistry of 28 primary cancers and 20 normal tissues. To elucidate the functional significance of these findings, RNA interference (RNAi)-mediated RNA silencing was used to downregulate Sox4 expression in the ACC-derived cell line, ACC3. With confirmed knockdown of Sox4 protein, cell viability was reduced by 51%, with a corresponding increase of apoptosis to 85% as compared to 12% in controls. Apoptosis was confirmed by cell morphology, DNA fragmentation and flow cytometry. Cells could be rescued from the proapoptotic effects of Sox4 RNAi by co-transfection with a construct expressing functional Sox4. Microarray gene expression profiling of RNAi knockdown experiments shows that downregulation of Sox4-modulated expression of critical genes involved in apoptosis and cell cycle control. Overall, our findings suggest that Sox4 contributes to the malignant phenotype of ACC cells by promoting cell survival.

Standard name | PUIFFE_INVASION_INHIBITED_BY_ASCITES_UP
Systematic name | M3737
Organism | Homo sapiens
PMID | 17971902
Authors | Puiffe ML,Le Page C,Filali-Mouhim A,Zietarska M,Ouellet V,Tonin PN,Chevrette M,Provencher DM,Mes-Masson AM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in OV-90 cells (ovarian cancer) exposed to ascites which inhibited invasion.
Full description | At least one third of all cases of epithelial ovarian cancer are associated with the production of ascites, although its effect on tumor cell microenvironment remains poorly understood. This study addresses the effect of the heterologous acellular fraction of ovarian cancer-derived ascites on a cell line (OV-90) derived from the chemotherapy-naïve ovarian cancer patient. Ascites were assayed for their effect on cell invasion, growth, and spheroid formation. When compared to either no serum or 5% serum, ascites fell into one of two categories: stimulatory or inhibitory. RNA from OV-90 cells exposed to selected ascites were arrayed on an Affymetrix HG-U133A GeneChip. A supervised analysis identified a number of differentially expressed genes and quantitative polymerase chain reaction validation based on OV-90 cells exposed to 54 independent ascites demonstrated that stimulatory ascites affected the expression of ISGF3G, TRIB1, MKP1, RGS4, PLEC1, and MOSPD1 genes. In addition, TRIB1 expression was shown to independently correlate with prognosis when its expression was ascertained in an independent set of primary cultures established from ovarian ascites. The data support the validity of the strategy to uncover molecular events that are associated with tumor cell behavior and highlight the impact of ascites on the cellular and molecular parameters of ovarian cancer.

Standard name | PUIFFE_INVASION_INHIBITED_BY_ASCITES_DN
Systematic name | M19152
Organism | Homo sapiens
PMID | 17971902
Authors | Puiffe ML,Le Page C,Filali-Mouhim A,Zietarska M,Ouellet V,Tonin PN,Chevrette M,Provencher DM,Mes-Masson AM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in OV-90 cells (ovarian cancer) exposed to ascites which inhibited invasion.
Full description | At least one third of all cases of epithelial ovarian cancer are associated with the production of ascites, although its effect on tumor cell microenvironment remains poorly understood. This study addresses the effect of the heterologous acellular fraction of ovarian cancer-derived ascites on a cell line (OV-90) derived from the chemotherapy-naïve ovarian cancer patient. Ascites were assayed for their effect on cell invasion, growth, and spheroid formation. When compared to either no serum or 5% serum, ascites fell into one of two categories: stimulatory or inhibitory. RNA from OV-90 cells exposed to selected ascites were arrayed on an Affymetrix HG-U133A GeneChip. A supervised analysis identified a number of differentially expressed genes and quantitative polymerase chain reaction validation based on OV-90 cells exposed to 54 independent ascites demonstrated that stimulatory ascites affected the expression of ISGF3G, TRIB1, MKP1, RGS4, PLEC1, and MOSPD1 genes. In addition, TRIB1 expression was shown to independently correlate with prognosis when its expression was ascertained in an independent set of primary cultures established from ovarian ascites. The data support the validity of the strategy to uncover molecular events that are associated with tumor cell behavior and highlight the impact of ascites on the cellular and molecular parameters of ovarian cancer.

Standard name | PIEPOLI_LGI1_TARGETS_UP
Systematic name | M15008
Organism | Homo sapiens
PMID | 16533756
Authors | Piepoli T,Jakupoglu C,Gu W,Lualdi E,Suarez-Merino B,Poliani PL,Cattaneo MG,Ortino B,Goplen D,Wang J,Mola R,Inverardi F,Frassoni C,Bjerkvig R,Steinlein O,Vicentini LM,Brüstle O,Finocchiaro G
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in U87 cells (glioblastoma multiforme, GBM) engineered to stably express LGI1 [GeneID=9211].
Full description | Disruptions of LGI1 in glioblastoma (GBM) cell lines and LGI1 mutations in families with autosomal dominant epilepsy imply a role for LGI1 in glial cells as well as in neurons. Although we and others could not find LGI1 mutations in malignant gliomas, our initial studies appeared to support the idea that LGI1 is poorly expressed or absent in these tumors. Microarray data suggested that LGI1 could be involved in the control of matrix metalloproteinases, and we found that tumors derived from U87 glioblastoma cells overexpressing LGI1 were less aggressive than U87 control tumors. To our surprise, we observed that LGI1 expression after differentiation of murine neural stem cells was robust in neurons but negligible in glial cells, in agreement with immunohistochemistry studies on rodent brain. This observation could suggest that the variable levels of LGI1 expression in gliomas reflect the presence of neurons entrapped within the tumor. To test this hypothesis, we investigated LGI1 expression in parallel with expression of the neuronal marker NEF3 by real-time PCR on 30 malignant gliomas. Results showed a strong, positive correlation between the expression levels of these two genes (P < 0.0001). Thus, our data confirm that LGI1 is involved in cell-matrix interactions but suggest that its expression is not relevant in glial cells, implying that its role as a tumor suppressor in gliomas should be reconsidered.

Standard name | PIEPOLI_LGI1_TARGETS_DN
Systematic name | M2835
Organism | Homo sapiens
PMID | 16533756
Authors | Piepoli T,Jakupoglu C,Gu W,Lualdi E,Suarez-Merino B,Poliani PL,Cattaneo MG,Ortino B,Goplen D,Wang J,Mola R,Inverardi F,Frassoni C,Bjerkvig R,Steinlein O,Vicentini LM,Brüstle O,Finocchiaro G
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in U87 cells (glioblastoma multiforme, GBM) engineered to stably express LGI1 [GeneID=9211].
Full description | Disruptions of LGI1 in glioblastoma (GBM) cell lines and LGI1 mutations in families with autosomal dominant epilepsy imply a role for LGI1 in glial cells as well as in neurons. Although we and others could not find LGI1 mutations in malignant gliomas, our initial studies appeared to support the idea that LGI1 is poorly expressed or absent in these tumors. Microarray data suggested that LGI1 could be involved in the control of matrix metalloproteinases, and we found that tumors derived from U87 glioblastoma cells overexpressing LGI1 were less aggressive than U87 control tumors. To our surprise, we observed that LGI1 expression after differentiation of murine neural stem cells was robust in neurons but negligible in glial cells, in agreement with immunohistochemistry studies on rodent brain. This observation could suggest that the variable levels of LGI1 expression in gliomas reflect the presence of neurons entrapped within the tumor. To test this hypothesis, we investigated LGI1 expression in parallel with expression of the neuronal marker NEF3 by real-time PCR on 30 malignant gliomas. Results showed a strong, positive correlation between the expression levels of these two genes (P < 0.0001). Thus, our data confirm that LGI1 is involved in cell-matrix interactions but suggest that its expression is not relevant in glial cells, implying that its role as a tumor suppressor in gliomas should be reconsidered.

Standard name | THUM_SYSTOLIC_HEART_FAILURE_UP
Systematic name | M3654
Organism | Homo sapiens
PMID | 17606841
Authors | Thum T,Galuppo P,Wolf C,Fiedler J,Kneitz S,van Laake LW,Doevendans PA,Mummery CL,Borlak J,Haverich A,Gross C,Engelhardt S,Ertl G,Bauersachs J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in samples with systolic heart failure compared to normal hearts.
Full description | BACKGROUND: Chronic heart failure is characterized by left ventricular remodeling and reactivation of a fetal gene program; the underlying mechanisms are only partly understood. Here we provide evidence that cardiac microRNAs, recently discovered key regulators of gene expression, contribute to the transcriptional changes observed in heart failure. METHODS AND RESULTS: Cardiac transcriptome analyses revealed striking similarities between fetal and failing human heart tissue. Using microRNA arrays, we discovered profound alterations of microRNA expression in failing hearts. These changes closely mimicked the microRNA expression pattern observed in fetal cardiac tissue. Bioinformatic analysis demonstrated a striking concordance between regulated messenger RNA expression in heart failure and the presence of microRNA binding sites in the respective 3' untranslated regions. Messenger RNAs upregulated in the failing heart contained preferentially binding sites for downregulated microRNAs and vice versa. Mechanistically, transfection of cardiomyocytes with a set of fetal microRNAs induced cellular hypertrophy as well as changes in gene expression comparable to the failing heart. CONCLUSIONS: Our data support a novel mode of regulation for the transcriptional changes in cardiac failure. Reactivation of a fetal microRNA program substantially contributes to alterations of gene expression in the failing human heart.

Standard name | THUM_SYSTOLIC_HEART_FAILURE_DN
Systematic name | M18441
Organism | Homo sapiens
PMID | 17606841
Authors | Thum T,Galuppo P,Wolf C,Fiedler J,Kneitz S,van Laake LW,Doevendans PA,Mummery CL,Borlak J,Haverich A,Gross C,Engelhardt S,Ertl G,Bauersachs J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in samples with systolic heart failure compared to normal hearts.
Full description | BACKGROUND: Chronic heart failure is characterized by left ventricular remodeling and reactivation of a fetal gene program; the underlying mechanisms are only partly understood. Here we provide evidence that cardiac microRNAs, recently discovered key regulators of gene expression, contribute to the transcriptional changes observed in heart failure. METHODS AND RESULTS: Cardiac transcriptome analyses revealed striking similarities between fetal and failing human heart tissue. Using microRNA arrays, we discovered profound alterations of microRNA expression in failing hearts. These changes closely mimicked the microRNA expression pattern observed in fetal cardiac tissue. Bioinformatic analysis demonstrated a striking concordance between regulated messenger RNA expression in heart failure and the presence of microRNA binding sites in the respective 3' untranslated regions. Messenger RNAs upregulated in the failing heart contained preferentially binding sites for downregulated microRNAs and vice versa. Mechanistically, transfection of cardiomyocytes with a set of fetal microRNAs induced cellular hypertrophy as well as changes in gene expression comparable to the failing heart. CONCLUSIONS: Our data support a novel mode of regulation for the transcriptional changes in cardiac failure. Reactivation of a fetal microRNA program substantially contributes to alterations of gene expression in the failing human heart.

Standard name | CASORELLI_ACUTE_PROMYELOCYTIC_LEUKEMIA_UP
Systematic name | M2038
Organism | Homo sapiens
PMID | 16990782
Authors | Casorelli I,Tenedini E,Tagliafico E,Blasi MF,Giuliani A,Crescenzi M,Pelosi E,Testa U,Peschle C,Mele L,Diverio D,Breccia M,Lo-Coco F,Ferrari S,Bignami M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in APL (acute promyeolocytic leukemia) blasts expressing PML-RARA fusion [GeneID=5371;5914] compared to normal promyeloblasts.
Full description | Acute promyelocytic leukemia (APL) is a clonal expansion of hematopoietic precursors blocked at the promyelocytic stage. Gene expression profiles of APL cells obtained from 16 patients were compared to eight samples of CD34+-derived normal promyelocytes. Malignant promyelocytes showed widespread changes in transcription in comparison to their normal counterpart and 1020 differentially expressed genes were identified. Discriminating genes include transcriptional regulators (FOS, JUN and HOX genes) and genes involved in cell cycle and DNA repair. The strong upregulation in APL of some transcripts (FLT3, CD33, CD44 and HGF) was also confirmed at protein level. Interestingly, a trend toward a transcriptional repression of genes involved in different DNA repair pathways was found in APL and confirmed by real-time polymerase chain reactor (PCR) in a new set of nine APLs. Our results suggest that both inefficient base excision repair and recombinational repair might play a role in APLs development. To investigate the expression pathways underlying the development of APL occurring as a second malignancy (sAPL), we included in our study eight cases of sAPL. Although both secondary and de novo APL were characterized by a strong homogeneity in expression profiling, we identified a small set of differentially expressed genes that discriminate sAPL from de novo cases.

Standard name | CASORELLI_ACUTE_PROMYELOCYTIC_LEUKEMIA_DN
Systematic name | M18635
Organism | Homo sapiens
PMID | 16990782
Authors | Casorelli I,Tenedini E,Tagliafico E,Blasi MF,Giuliani A,Crescenzi M,Pelosi E,Testa U,Peschle C,Mele L,Diverio D,Breccia M,Lo-Coco F,Ferrari S,Bignami M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in APL (acute promyeolocytic leukemia) blasts expressing PML-RARA fusion [GeneID=5371;5914] compared to normal promyeloblasts.
Full description | Acute promyelocytic leukemia (APL) is a clonal expansion of hematopoietic precursors blocked at the promyelocytic stage. Gene expression profiles of APL cells obtained from 16 patients were compared to eight samples of CD34+-derived normal promyelocytes. Malignant promyelocytes showed widespread changes in transcription in comparison to their normal counterpart and 1020 differentially expressed genes were identified. Discriminating genes include transcriptional regulators (FOS, JUN and HOX genes) and genes involved in cell cycle and DNA repair. The strong upregulation in APL of some transcripts (FLT3, CD33, CD44 and HGF) was also confirmed at protein level. Interestingly, a trend toward a transcriptional repression of genes involved in different DNA repair pathways was found in APL and confirmed by real-time polymerase chain reactor (PCR) in a new set of nine APLs. Our results suggest that both inefficient base excision repair and recombinational repair might play a role in APLs development. To investigate the expression pathways underlying the development of APL occurring as a second malignancy (sAPL), we included in our study eight cases of sAPL. Although both secondary and de novo APL were characterized by a strong homogeneity in expression profiling, we identified a small set of differentially expressed genes that discriminate sAPL from de novo cases.

Standard name | CORRE_MULTIPLE_MYELOMA_UP
Systematic name | M13639
Organism | Homo sapiens
PMID | 17344918
Authors | Corre J,Mahtouk K,Attal M,Gadelorge M,Huynh A,Fleury-Cappellesso S,Danho C,Laharrague P,Klein B,Rème T,Bourin P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in multiple myeloma (MM) bone marrow mesenchymal stem cells.
Full description | Recent literature suggested that cells of the microenvironment of tumors could be abnormal as well. To address this hypothesis in multiple myeloma (MM), we studied bone marrow mesenchymal stem cells (BMMSCs), the only long-lived cells of the bone marrow microenvironment, by gene expression profiling and phenotypic and functional studies in three groups of individuals: patients with MM, patients with monoclonal gamopathy of undefined significance (MGUS) and healthy age-matched subjects. Gene expression profile independently classified the BMMSCs of these individuals in a normal and in an MM group. MGUS BMMSCs were interspersed between these two groups. Among the 145 distinct genes differentially expressed in MM and normal BMMSCs, 46% may account for a tumor-microenvironment cross-talk. Known soluble factors implicated in MM pathophysiologic features (i.e. IL (interleukin)-6, DKK1) were revealed and new ones were found which are involved in angiogenesis, osteogenic differentiation or tumor growth. In particular, GDF15 was found to induce dose-dependent growth of MOLP-6, a stromal cell-dependent myeloma cell line. Functionally, MM BMMSCs induced an overgrowth of MOLP-6, and their capacity to differentiate into an osteoblastic lineage was impaired. Thus, MM BMMSCs are abnormal and could create a very efficient niche to support the survival and proliferation of the myeloma cells.

Standard name | CORRE_MULTIPLE_MYELOMA_DN
Systematic name | M990
Organism | Homo sapiens
PMID | 17344918
Authors | Corre J,Mahtouk K,Attal M,Gadelorge M,Huynh A,Fleury-Cappellesso S,Danho C,Laharrague P,Klein B,Rème T,Bourin P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in multiple myeloma (MM) bone marrow mesenchymal stem cells.
Full description | Recent literature suggested that cells of the microenvironment of tumors could be abnormal as well. To address this hypothesis in multiple myeloma (MM), we studied bone marrow mesenchymal stem cells (BMMSCs), the only long-lived cells of the bone marrow microenvironment, by gene expression profiling and phenotypic and functional studies in three groups of individuals: patients with MM, patients with monoclonal gamopathy of undefined significance (MGUS) and healthy age-matched subjects. Gene expression profile independently classified the BMMSCs of these individuals in a normal and in an MM group. MGUS BMMSCs were interspersed between these two groups. Among the 145 distinct genes differentially expressed in MM and normal BMMSCs, 46% may account for a tumor-microenvironment cross-talk. Known soluble factors implicated in MM pathophysiologic features (i.e. IL (interleukin)-6, DKK1) were revealed and new ones were found which are involved in angiogenesis, osteogenic differentiation or tumor growth. In particular, GDF15 was found to induce dose-dependent growth of MOLP-6, a stromal cell-dependent myeloma cell line. Functionally, MM BMMSCs induced an overgrowth of MOLP-6, and their capacity to differentiate into an osteoblastic lineage was impaired. Thus, MM BMMSCs are abnormal and could create a very efficient niche to support the survival and proliferation of the myeloma cells.

Standard name | HUTTMANN_B_CLL_POOR_SURVIVAL_UP
Systematic name | M19993
Organism | Homo sapiens
PMID | 16932341
Authors | Hüttmann A,Klein-Hitpass L,Thomale J,Deenen R,Carpinteiro A,Nückel H,Ebeling P,Führer A,Edelmann J,Sellmann L,Dührsen U,Dürig J
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in B-CLL (B-cell chronic leukemia) patients expressing high levels of ZAP70 and CD38 [GeneID=7535;952], which are associated with poor survival.
Full description | B-cell chronic lymphocytic leukaemia (B-CLL) is a heterogenous disease with a highly variable clinical course and analysis of zeta-associated protein 70 (ZAP-70) and CD38 expression on B-CLL cells allowed for identification of patients with good (ZAP-70-CD38-) and poor (ZAP-70+CD38+) prognosis. DNA microarray technology was employed to compare eight ZAP-70+CD38+ with eight ZAP-70-CD38- B-CLL cases. The expression of 358 genes differed significantly between the two subgroups, including genes involved in B-cell receptor signaling, angiogenesis and lymphomagenesis. Three of these genes, that is, immune receptor translocation-associated protein 4 (IRTA4)/Fc receptor homologue 2 (FcRH2), angiopoietin 2 (ANGPT2) and Pim2 were selected for further validating studies in a cohort of 94 B-CLL patients. IRTA4/FcRH2 expression as detected by flow cytometry was significantly lower in the poor prognosis subgroup as compared to ZAP-70-CD38- B-CLL cells. In healthy individuals, IRTA4/FcRH2 protein expression was associated with a CD19+CD27+ memory cell phenotype. ANGPT2 plasma concentrations were twofold higher in the poor prognosis subgroup (P<0.05). Pim2 was significantly overexpressed in poor prognosis cases and Binet stage C. Disease progression may be related to proangiogenic processes and strong Pim2 expression.

Standard name | HUTTMANN_B_CLL_POOR_SURVIVAL_DN
Systematic name | M12653
Organism | Homo sapiens
PMID | 16932341
Authors | Hüttmann A,Klein-Hitpass L,Thomale J,Deenen R,Carpinteiro A,Nückel H,Ebeling P,Führer A,Edelmann J,Sellmann L,Dührsen U,Dürig J
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in B-CLL (B-cell chronic leukemia) patients expressing high levels of ZAP70 and CD38 [GeneID=7535;952], which are associated with poor survival.
Full description | B-cell chronic lymphocytic leukaemia (B-CLL) is a heterogenous disease with a highly variable clinical course and analysis of zeta-associated protein 70 (ZAP-70) and CD38 expression on B-CLL cells allowed for identification of patients with good (ZAP-70-CD38-) and poor (ZAP-70+CD38+) prognosis. DNA microarray technology was employed to compare eight ZAP-70+CD38+ with eight ZAP-70-CD38- B-CLL cases. The expression of 358 genes differed significantly between the two subgroups, including genes involved in B-cell receptor signaling, angiogenesis and lymphomagenesis. Three of these genes, that is, immune receptor translocation-associated protein 4 (IRTA4)/Fc receptor homologue 2 (FcRH2), angiopoietin 2 (ANGPT2) and Pim2 were selected for further validating studies in a cohort of 94 B-CLL patients. IRTA4/FcRH2 expression as detected by flow cytometry was significantly lower in the poor prognosis subgroup as compared to ZAP-70-CD38- B-CLL cells. In healthy individuals, IRTA4/FcRH2 protein expression was associated with a CD19+CD27+ memory cell phenotype. ANGPT2 plasma concentrations were twofold higher in the poor prognosis subgroup (P<0.05). Pim2 was significantly overexpressed in poor prognosis cases and Binet stage C. Disease progression may be related to proangiogenic processes and strong Pim2 expression.

Standard name | DIAZ_CHRONIC_MEYLOGENOUS_LEUKEMIA_UP
Systematic name | M535
Organism | Homo sapiens
PMID | 17252012
Authors | Diaz-Blanco E,Bruns I,Neumann F,Fischer JC,Graef T,Rosskopf M,Brors B,Pechtel S,Bork S,Koch A,Baer A,Rohr UP,Kobbe G,Haeseler A,Gattermann N,Haas R,Kronenwett R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD34+ [GeneID=947] cells isolated from bone marrow of CML (chronic myelogenous leukemia) patients, compared to those from normal donors.
Full description | In this study, we provide a molecular signature of highly enriched CD34+ cells from bone marrow of untreated patients with chronic myelogenous leukemia (CML) in chronic phase in comparison with normal CD34+ cells using microarrays covering 8746 genes. Expression data reflected several BCR-ABL-induced effects in primary CML progenitors, such as transcriptional activation of the classical mitogen-activated protein kinase pathway and the phosphoinositide-3 kinase/AKT pathway as well as downregulation of the proapoptotic gene IRF8. Moreover, novel transcriptional changes in comparison with normal CD34+ cells were identified. These include upregulation of genes involved in the transforming growth factorbeta pathway, fetal hemoglobin genes, leptin receptor, sorcin, tissue inhibitor of metalloproteinase 1, the neuroepithelial cell transforming gene 1 and downregulation of selenoprotein P. Additionally, genes associated with early hematopoietic stem cells (HSC) and leukemogenesis such as HoxA9 and MEIS1 were transcriptionally activated. Differential expression of differentiation-associated genes suggested an altered composition of the CD34+ cell population in CML. This was confirmed by subset analyses of chronic phase CML CD34+ cells showing an increase of the proportion of megakaryocyte-erythroid progenitors, whereas the proportion of HSC and granulocyte-macrophage progenitors was decreased in CML. In conclusion, our results give novel insights into the biology of CML and could provide the basis for identification of new therapeutic targets.

Standard name | DIAZ_CHRONIC_MEYLOGENOUS_LEUKEMIA_DN
Systematic name | M17778
Organism | Homo sapiens
PMID | 17252012
Authors | Diaz-Blanco E,Bruns I,Neumann F,Fischer JC,Graef T,Rosskopf M,Brors B,Pechtel S,Bork S,Koch A,Baer A,Rohr UP,Kobbe G,Haeseler A,Gattermann N,Haas R,Kronenwett R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD34+ [GeneID=947] cells isolated from bone marrow of CML (chronic myelogenous leukemia) patients, compared to those from normal donors.
Full description | In this study, we provide a molecular signature of highly enriched CD34+ cells from bone marrow of untreated patients with chronic myelogenous leukemia (CML) in chronic phase in comparison with normal CD34+ cells using microarrays covering 8746 genes. Expression data reflected several BCR-ABL-induced effects in primary CML progenitors, such as transcriptional activation of the classical mitogen-activated protein kinase pathway and the phosphoinositide-3 kinase/AKT pathway as well as downregulation of the proapoptotic gene IRF8. Moreover, novel transcriptional changes in comparison with normal CD34+ cells were identified. These include upregulation of genes involved in the transforming growth factorbeta pathway, fetal hemoglobin genes, leptin receptor, sorcin, tissue inhibitor of metalloproteinase 1, the neuroepithelial cell transforming gene 1 and downregulation of selenoprotein P. Additionally, genes associated with early hematopoietic stem cells (HSC) and leukemogenesis such as HoxA9 and MEIS1 were transcriptionally activated. Differential expression of differentiation-associated genes suggested an altered composition of the CD34+ cell population in CML. This was confirmed by subset analyses of chronic phase CML CD34+ cells showing an increase of the proportion of megakaryocyte-erythroid progenitors, whereas the proportion of HSC and granulocyte-macrophage progenitors was decreased in CML. In conclusion, our results give novel insights into the biology of CML and could provide the basis for identification of new therapeutic targets.

Standard name | CASORELLI_APL_SECONDARY_VS_DE_NOVO_UP
Systematic name | M13339
Organism | Homo sapiens
PMID | 16990782
Authors | Casorelli I,Tenedini E,Tagliafico E,Blasi MF,Giuliani A,Crescenzi M,Pelosi E,Testa U,Peschle C,Mele L,Diverio D,Breccia M,Lo-Coco F,Ferrari S,Bignami M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in secondary APL (acute promyelocytic leukemia) compared to the de novo tumors.
Full description | Acute promyelocytic leukemia (APL) is a clonal expansion of hematopoietic precursors blocked at the promyelocytic stage. Gene expression profiles of APL cells obtained from 16 patients were compared to eight samples of CD34+-derived normal promyelocytes. Malignant promyelocytes showed widespread changes in transcription in comparison to their normal counterpart and 1020 differentially expressed genes were identified. Discriminating genes include transcriptional regulators (FOS, JUN and HOX genes) and genes involved in cell cycle and DNA repair. The strong upregulation in APL of some transcripts (FLT3, CD33, CD44 and HGF) was also confirmed at protein level. Interestingly, a trend toward a transcriptional repression of genes involved in different DNA repair pathways was found in APL and confirmed by real-time polymerase chain reactor (PCR) in a new set of nine APLs. Our results suggest that both inefficient base excision repair and recombinational repair might play a role in APLs development. To investigate the expression pathways underlying the development of APL occurring as a second malignancy (sAPL), we included in our study eight cases of sAPL. Although both secondary and de novo APL were characterized by a strong homogeneity in expression profiling, we identified a small set of differentially expressed genes that discriminate sAPL from de novo cases.

Standard name | DEURIG_T_CELL_PROLYMPHOCYTIC_LEUKEMIA_UP
Systematic name | M16431
Organism | Homo sapiens
PMID | 17713554
Authors | Dürig J,Bug S,Klein-Hitpass L,Boes T,Jöns T,Martin-Subero JI,Harder L,Baudis M,Dührsen U,Siebert R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T-PLL cells (T-cell prolymphocytic leukemia) bearing the inv(14)/t(14:14) chromosomal aberration.
Full description | T-cell prolymphocytic leukemia (T-PLL) is a rare aggressive lymphoma derived from mature T cells, which is, in most cases, characterized by the presence of an inv(14)(q11q32)/t(14;14)(q11;q32) and a characteristic pattern of secondary chromosomal aberrations. DNA microarray technology was employed to compare the transcriptomes of eight immunomagnetically purified CD3+ normal donor-derived peripheral blood cell samples, with five highly purified inv(14)/t(14;14)-positive T-PLL blood samples. Between the two experimental groups, 734 genes were identified as differentially expressed, including functionally important genes involved in lymphomagenesis, cell cycle regulation, apoptosis and DNA repair. Notably, the differentially expressed genes were found to be significantly enriched in genomic regions affected by recurrent chromosomal imbalances. Upregulated genes clustered on chromosome arms 6p and 8q, and downregulated genes on 6q, 8p, 10p, 11q and 18p. High-resolution copy-number determination using single nucleotide polymorphism chip technology in 12 inv(14)/t(14;14)-positive T-PLL including those analyzed for gene expression, refined chromosomal breakpoints as well as regions of imbalances. In conclusion, combined transcriptional and molecular cytogenetic profiling identified novel specific chromosomal loci and genes that are likely to be involved in disease progression and suggests a gene dosage effect as a pathogenic mechanism in T-PLL.

Standard name | DEURIG_T_CELL_PROLYMPHOCYTIC_LEUKEMIA_DN
Systematic name | M12570
Organism | Homo sapiens
PMID | 17713554
Authors | Dürig J,Bug S,Klein-Hitpass L,Boes T,Jöns T,Martin-Subero JI,Harder L,Baudis M,Dührsen U,Siebert R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T-PLL cells (T-cell prolymphocytic leukemia) bearing the inv(14)/t(14:14) chromosomal aberration.
Full description | T-cell prolymphocytic leukemia (T-PLL) is a rare aggressive lymphoma derived from mature T cells, which is, in most cases, characterized by the presence of an inv(14)(q11q32)/t(14;14)(q11;q32) and a characteristic pattern of secondary chromosomal aberrations. DNA microarray technology was employed to compare the transcriptomes of eight immunomagnetically purified CD3+ normal donor-derived peripheral blood cell samples, with five highly purified inv(14)/t(14;14)-positive T-PLL blood samples. Between the two experimental groups, 734 genes were identified as differentially expressed, including functionally important genes involved in lymphomagenesis, cell cycle regulation, apoptosis and DNA repair. Notably, the differentially expressed genes were found to be significantly enriched in genomic regions affected by recurrent chromosomal imbalances. Upregulated genes clustered on chromosome arms 6p and 8q, and downregulated genes on 6q, 8p, 10p, 11q and 18p. High-resolution copy-number determination using single nucleotide polymorphism chip technology in 12 inv(14)/t(14;14)-positive T-PLL including those analyzed for gene expression, refined chromosomal breakpoints as well as regions of imbalances. In conclusion, combined transcriptional and molecular cytogenetic profiling identified novel specific chromosomal loci and genes that are likely to be involved in disease progression and suggests a gene dosage effect as a pathogenic mechanism in T-PLL.

Standard name | LIU_CMYB_TARGETS_UP
Systematic name | M15066
Organism | Homo sapiens
PMID | 16205643
Authors | Liu F,Lei W,O'Rourke JP,Ness SA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) by overexpression of CMYB [GeneID=4602] off adenovirus vector.
Full description | The v-Myb oncoprotein encoded by Avian Myeloblastosis Virus is highly oncogenic, induces leukemias in chickens and mice and transforms immature hematopoietic cells in vitro. The v-Myb protein is a mutated and truncated version of c-Myb, a DNA-binding transcription factor expressed in many cell types that is essential for normal hematopoiesis. Previous studies suggested that two types of differences, DNA binding domain mutations and the deletion of a C-terminal negative regulatory domain were important for increasing the transforming activity of v-Myb. Here, we combined structure-function studies of the v-Myb and c-Myb proteins with unbiased microarray-based transcription assays to compare the transcriptional specificities of the two proteins. In human cells, the v-Myb and c-Myb proteins displayed strikingly different activities and regulated overlapping, but largely distinct sets of target genes. Each type of mutation that distinguished v-Myb from c-Myb, including the N- and C-terminal deletions, DNA binding domain changes and mutations in the transcriptional activation domain, affected different sets of target genes and contributed to the different activities of c-Myb and v-Myb. The results suggest that v-Myb is not just a de-repressed version of c-Myb. Instead, it is a distinct transcriptional regulator with a unique set of activities.

Standard name | LIU_CMYB_TARGETS_DN
Systematic name | M9230
Organism | Homo sapiens
PMID | 16205643
Authors | Liu F,Lei W,O'Rourke JP,Ness SA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) by overexpression of CMYB [GeneID=4602] off adenovirus vector.
Full description | The v-Myb oncoprotein encoded by Avian Myeloblastosis Virus is highly oncogenic, induces leukemias in chickens and mice and transforms immature hematopoietic cells in vitro. The v-Myb protein is a mutated and truncated version of c-Myb, a DNA-binding transcription factor expressed in many cell types that is essential for normal hematopoiesis. Previous studies suggested that two types of differences, DNA binding domain mutations and the deletion of a C-terminal negative regulatory domain were important for increasing the transforming activity of v-Myb. Here, we combined structure-function studies of the v-Myb and c-Myb proteins with unbiased microarray-based transcription assays to compare the transcriptional specificities of the two proteins. In human cells, the v-Myb and c-Myb proteins displayed strikingly different activities and regulated overlapping, but largely distinct sets of target genes. Each type of mutation that distinguished v-Myb from c-Myb, including the N- and C-terminal deletions, DNA binding domain changes and mutations in the transcriptional activation domain, affected different sets of target genes and contributed to the different activities of c-Myb and v-Myb. The results suggest that v-Myb is not just a de-repressed version of c-Myb. Instead, it is a distinct transcriptional regulator with a unique set of activities.

Standard name | LIU_VMYB_TARGETS_UP
Systematic name | M1584
Organism | Homo sapiens
PMID | 16205643
Authors | Liu F,Lei W,O'Rourke JP,Ness SA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) by overexpression of v-MYB oncogenic varian of CMYB [GeneID=4602] off adenovirus vector.
Full description | The v-Myb oncoprotein encoded by Avian Myeloblastosis Virus is highly oncogenic, induces leukemias in chickens and mice and transforms immature hematopoietic cells in vitro. The v-Myb protein is a mutated and truncated version of c-Myb, a DNA-binding transcription factor expressed in many cell types that is essential for normal hematopoiesis. Previous studies suggested that two types of differences, DNA binding domain mutations and the deletion of a C-terminal negative regulatory domain were important for increasing the transforming activity of v-Myb. Here, we combined structure-function studies of the v-Myb and c-Myb proteins with unbiased microarray-based transcription assays to compare the transcriptional specificities of the two proteins. In human cells, the v-Myb and c-Myb proteins displayed strikingly different activities and regulated overlapping, but largely distinct sets of target genes. Each type of mutation that distinguished v-Myb from c-Myb, including the N- and C-terminal deletions, DNA binding domain changes and mutations in the transcriptional activation domain, affected different sets of target genes and contributed to the different activities of c-Myb and v-Myb. The results suggest that v-Myb is not just a de-repressed version of c-Myb. Instead, it is a distinct transcriptional regulator with a unique set of activities.

Standard name | LIU_TARGETS_OF_VMYB_VS_CMYB_UP
Systematic name | M3389
Organism | Homo sapiens
PMID | 16205643
Authors | Liu F,Lei W,O'Rourke JP,Ness SA
Category | C2
Sub-category | CGP
Brief description | Genes regulated in the opposite directions by v-MYB (UP) and c-MYB (DN) variants of CMYB [GeneID=4602] overexpressed in primary monocyte cultures off adenoviral vectors.
Full description | The v-Myb oncoprotein encoded by Avian Myeloblastosis Virus is highly oncogenic, induces leukemias in chickens and mice and transforms immature hematopoietic cells in vitro. The v-Myb protein is a mutated and truncated version of c-Myb, a DNA-binding transcription factor expressed in many cell types that is essential for normal hematopoiesis. Previous studies suggested that two types of differences, DNA binding domain mutations and the deletion of a C-terminal negative regulatory domain were important for increasing the transforming activity of v-Myb. Here, we combined structure-function studies of the v-Myb and c-Myb proteins with unbiased microarray-based transcription assays to compare the transcriptional specificities of the two proteins. In human cells, the v-Myb and c-Myb proteins displayed strikingly different activities and regulated overlapping, but largely distinct sets of target genes. Each type of mutation that distinguished v-Myb from c-Myb, including the N- and C-terminal deletions, DNA binding domain changes and mutations in the transcriptional activation domain, affected different sets of target genes and contributed to the different activities of c-Myb and v-Myb. The results suggest that v-Myb is not just a de-repressed version of c-Myb. Instead, it is a distinct transcriptional regulator with a unique set of activities.

Standard name | LIU_TARGETS_OF_VMYB_VS_CMYB_DN
Systematic name | M3258
Organism | Homo sapiens
PMID | 16205643
Authors | Liu F,Lei W,O'Rourke JP,Ness SA
Category | C2
Sub-category | CGP
Brief description | Gene regulated in the opposite directions by v-MYB (DN) and c-MYB (UP) variants of CMYB [GeneID=4602] overexpressed in primary monocyte cultures off adenoviral vectors.
Full description | The v-Myb oncoprotein encoded by Avian Myeloblastosis Virus is highly oncogenic, induces leukemias in chickens and mice and transforms immature hematopoietic cells in vitro. The v-Myb protein is a mutated and truncated version of c-Myb, a DNA-binding transcription factor expressed in many cell types that is essential for normal hematopoiesis. Previous studies suggested that two types of differences, DNA binding domain mutations and the deletion of a C-terminal negative regulatory domain were important for increasing the transforming activity of v-Myb. Here, we combined structure-function studies of the v-Myb and c-Myb proteins with unbiased microarray-based transcription assays to compare the transcriptional specificities of the two proteins. In human cells, the v-Myb and c-Myb proteins displayed strikingly different activities and regulated overlapping, but largely distinct sets of target genes. Each type of mutation that distinguished v-Myb from c-Myb, including the N- and C-terminal deletions, DNA binding domain changes and mutations in the transcriptional activation domain, affected different sets of target genes and contributed to the different activities of c-Myb and v-Myb. The results suggest that v-Myb is not just a de-repressed version of c-Myb. Instead, it is a distinct transcriptional regulator with a unique set of activities.

Standard name | CHARAFE_BREAST_CANCER_LUMINAL_VS_BASAL_UP
Systematic name | M2840
Organism | Homo sapiens
PMID | 16288205
Authors | Charafe-Jauffret E,Ginestier C,Monville F,Finetti P,Adélaïde J,Cervera N,Fekairi S,Xerri L,Jacquemier J,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in luminal-like breast cancer cell lines compared to the basal-like ones.
Full description | A better molecular characterization of breast cell lines (BCL) may help discover new markers to apply to tumour samples. We performed gene and protein expression profiling of 31 BCL using whole-genome DNA microarrays and immunohistochemistry (IHC) on 'cell microarrays' (CMA), respectively. Global hierarchical clustering discriminated two groups of BCL: group I corresponded to luminal cell lines, group II to basal and mesenchymal cell lines. Correlations with centroids calculated from a published 'intrinsic 500-gene set' assigned 15 cell lines as luminal, eight as basal and four as mesenchymal. A set of 1.233 genes was differentially expressed between basal and luminal samples. Mesenchymal and basal subtypes were rather similar and discriminated by only 227 genes. The expression of 10 proteins (CAV1, CD44, EGFR, MET, ETS1, GATA3, luminal cytokeratin CK19, basal cytokeratin CK5/6, CD10, and ERM protein moesin) encoded by luminal vs basal discriminator genes confirmed the subtype classification and the validity of the identified markers. Our BCL basal/luminal signature correctly re-classified the published series of tumour samples that originally served to identify the molecular subtypes, suggesting that the identified markers should be useful for tumour classification and might represent promising targets for disease management.

Standard name | CHARAFE_BREAST_CANCER_LUMINAL_VS_BASAL_DN
Systematic name | M14507
Organism | Homo sapiens
PMID | 16288205
Authors | Charafe-Jauffret E,Ginestier C,Monville F,Finetti P,Adélaïde J,Cervera N,Fekairi S,Xerri L,Jacquemier J,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in luminal-like breast cancer cell lines compared to the basal-like ones.
Full description | A better molecular characterization of breast cell lines (BCL) may help discover new markers to apply to tumour samples. We performed gene and protein expression profiling of 31 BCL using whole-genome DNA microarrays and immunohistochemistry (IHC) on 'cell microarrays' (CMA), respectively. Global hierarchical clustering discriminated two groups of BCL: group I corresponded to luminal cell lines, group II to basal and mesenchymal cell lines. Correlations with centroids calculated from a published 'intrinsic 500-gene set' assigned 15 cell lines as luminal, eight as basal and four as mesenchymal. A set of 1.233 genes was differentially expressed between basal and luminal samples. Mesenchymal and basal subtypes were rather similar and discriminated by only 227 genes. The expression of 10 proteins (CAV1, CD44, EGFR, MET, ETS1, GATA3, luminal cytokeratin CK19, basal cytokeratin CK5/6, CD10, and ERM protein moesin) encoded by luminal vs basal discriminator genes confirmed the subtype classification and the validity of the identified markers. Our BCL basal/luminal signature correctly re-classified the published series of tumour samples that originally served to identify the molecular subtypes, suggesting that the identified markers should be useful for tumour classification and might represent promising targets for disease management.

Standard name | CHARAFE_BREAST_CANCER_LUMINAL_VS_MESENCHYMAL_UP
Systematic name | M17299
Organism | Homo sapiens
PMID | 16288205
Authors | Charafe-Jauffret E,Ginestier C,Monville F,Finetti P,Adélaïde J,Cervera N,Fekairi S,Xerri L,Jacquemier J,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in luminal-like breast cancer cell lines compared to the mesenchymal-like ones.
Full description | A better molecular characterization of breast cell lines (BCL) may help discover new markers to apply to tumour samples. We performed gene and protein expression profiling of 31 BCL using whole-genome DNA microarrays and immunohistochemistry (IHC) on 'cell microarrays' (CMA), respectively. Global hierarchical clustering discriminated two groups of BCL: group I corresponded to luminal cell lines, group II to basal and mesenchymal cell lines. Correlations with centroids calculated from a published 'intrinsic 500-gene set' assigned 15 cell lines as luminal, eight as basal and four as mesenchymal. A set of 1.233 genes was differentially expressed between basal and luminal samples. Mesenchymal and basal subtypes were rather similar and discriminated by only 227 genes. The expression of 10 proteins (CAV1, CD44, EGFR, MET, ETS1, GATA3, luminal cytokeratin CK19, basal cytokeratin CK5/6, CD10, and ERM protein moesin) encoded by luminal vs basal discriminator genes confirmed the subtype classification and the validity of the identified markers. Our BCL basal/luminal signature correctly re-classified the published series of tumour samples that originally served to identify the molecular subtypes, suggesting that the identified markers should be useful for tumour classification and might represent promising targets for disease management.

Standard name | CHARAFE_BREAST_CANCER_LUMINAL_VS_MESENCHYMAL_DN
Systematic name | M9192
Organism | Homo sapiens
PMID | 16288205
Authors | Charafe-Jauffret E,Ginestier C,Monville F,Finetti P,Adélaïde J,Cervera N,Fekairi S,Xerri L,Jacquemier J,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in luminal-like breast cancer cell lines compared to the mesenchymal-like ones.
Full description | A better molecular characterization of breast cell lines (BCL) may help discover new markers to apply to tumour samples. We performed gene and protein expression profiling of 31 BCL using whole-genome DNA microarrays and immunohistochemistry (IHC) on 'cell microarrays' (CMA), respectively. Global hierarchical clustering discriminated two groups of BCL: group I corresponded to luminal cell lines, group II to basal and mesenchymal cell lines. Correlations with centroids calculated from a published 'intrinsic 500-gene set' assigned 15 cell lines as luminal, eight as basal and four as mesenchymal. A set of 1.233 genes was differentially expressed between basal and luminal samples. Mesenchymal and basal subtypes were rather similar and discriminated by only 227 genes. The expression of 10 proteins (CAV1, CD44, EGFR, MET, ETS1, GATA3, luminal cytokeratin CK19, basal cytokeratin CK5/6, CD10, and ERM protein moesin) encoded by luminal vs basal discriminator genes confirmed the subtype classification and the validity of the identified markers. Our BCL basal/luminal signature correctly re-classified the published series of tumour samples that originally served to identify the molecular subtypes, suggesting that the identified markers should be useful for tumour classification and might represent promising targets for disease management.

Standard name | CHARAFE_BREAST_CANCER_BASAL_VS_MESENCHYMAL_UP
Systematic name | M12795
Organism | Homo sapiens
PMID | 16288205
Authors | Charafe-Jauffret E,Ginestier C,Monville F,Finetti P,Adélaïde J,Cervera N,Fekairi S,Xerri L,Jacquemier J,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in basal-like breast cancer cell lines as compared to the mesenchymal-like ones.
Full description | A better molecular characterization of breast cell lines (BCL) may help discover new markers to apply to tumour samples. We performed gene and protein expression profiling of 31 BCL using whole-genome DNA microarrays and immunohistochemistry (IHC) on 'cell microarrays' (CMA), respectively. Global hierarchical clustering discriminated two groups of BCL: group I corresponded to luminal cell lines, group II to basal and mesenchymal cell lines. Correlations with centroids calculated from a published 'intrinsic 500-gene set' assigned 15 cell lines as luminal, eight as basal and four as mesenchymal. A set of 1.233 genes was differentially expressed between basal and luminal samples. Mesenchymal and basal subtypes were rather similar and discriminated by only 227 genes. The expression of 10 proteins (CAV1, CD44, EGFR, MET, ETS1, GATA3, luminal cytokeratin CK19, basal cytokeratin CK5/6, CD10, and ERM protein moesin) encoded by luminal vs basal discriminator genes confirmed the subtype classification and the validity of the identified markers. Our BCL basal/luminal signature correctly re-classified the published series of tumour samples that originally served to identify the molecular subtypes, suggesting that the identified markers should be useful for tumour classification and might represent promising targets for disease management.

Standard name | CHARAFE_BREAST_CANCER_BASAL_VS_MESENCHYMAL_DN
Systematic name | M12895
Organism | Homo sapiens
PMID | 16288205
Authors | Charafe-Jauffret E,Ginestier C,Monville F,Finetti P,Adélaïde J,Cervera N,Fekairi S,Xerri L,Jacquemier J,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in basal-like breast cancer cell lines as compared to the mesenchymal-like ones.
Full description | A better molecular characterization of breast cell lines (BCL) may help discover new markers to apply to tumour samples. We performed gene and protein expression profiling of 31 BCL using whole-genome DNA microarrays and immunohistochemistry (IHC) on 'cell microarrays' (CMA), respectively. Global hierarchical clustering discriminated two groups of BCL: group I corresponded to luminal cell lines, group II to basal and mesenchymal cell lines. Correlations with centroids calculated from a published 'intrinsic 500-gene set' assigned 15 cell lines as luminal, eight as basal and four as mesenchymal. A set of 1.233 genes was differentially expressed between basal and luminal samples. Mesenchymal and basal subtypes were rather similar and discriminated by only 227 genes. The expression of 10 proteins (CAV1, CD44, EGFR, MET, ETS1, GATA3, luminal cytokeratin CK19, basal cytokeratin CK5/6, CD10, and ERM protein moesin) encoded by luminal vs basal discriminator genes confirmed the subtype classification and the validity of the identified markers. Our BCL basal/luminal signature correctly re-classified the published series of tumour samples that originally served to identify the molecular subtypes, suggesting that the identified markers should be useful for tumour classification and might represent promising targets for disease management.

Standard name | DOANE_BREAST_CANCER_CLASSES_UP
Systematic name | M17427
Organism | Homo sapiens
PMID | 16491124
Authors | Doane AS,Danso M,Lal P,Donaton M,Zhang L,Hudis C,Gerald WL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ER(-) / PR(-) breast tumors (do not express ESR1 and PGR [GeneID=2099;5241]) with molecular similarity to ER(+) (class A) relative to the rest of the ER(-) / PR(-) samples (class B).
Full description | Little is known of the underlying biology of estrogen receptor-negative, progesterone receptor-negative (ER(-)/PR(-)) breast cancer (BC), and few targeted therapies are available. Clinical heterogeneity of ER(-)/PR(-) tumors suggests that molecular subsets exist. We performed genome-wide expression analysis of 99 primary BC samples and eight BC cell lines in an effort to reveal distinct subsets, provide insight into their biology and potentially identify new therapeutic targets. We identified a subset of ER(-)/PR(-) tumors with paradoxical expression of genes known to be either direct targets of ER, responsive to estrogen, or typically expressed in ER(+) BC. Differentially expressed genes included SPDEF, FOXA1, XBP1, CYB5, TFF3, NAT1, APOD, ALCAM and AR (P<0.001). A classification model based on the expression signature of this tumor class identified molecularly similar BCs in an independent human BC data set and among BC cell lines (MDA-MB-453). This cell line demonstrated a proliferative response to androgen in an androgen receptor-dependent and ER-independent manner. In addition, the androgen-induced transcriptional program of MDA-MB-453 significantly overlapped the molecular signature of the unique ER(-)/PR(-) subclass of human tumors. This subset of BCs, characterized by a hormonally regulated transcriptional program and response to androgen, suggests the potential for therapeutic strategies targeting the androgen signaling pathway.

Standard name | DOANE_BREAST_CANCER_CLASSES_DN
Systematic name | M11771
Organism | Homo sapiens
PMID | 16491124
Authors | Doane AS,Danso M,Lal P,Donaton M,Zhang L,Hudis C,Gerald WL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ER(-) / PR(-) breast tumors (do not express ESR1 and PGR [GeneID=2099;5241]) with molecular similarity to ER(+) (class A) relative to the rest of the ER(-) / PR(-) samples (class B).
Full description | Little is known of the underlying biology of estrogen receptor-negative, progesterone receptor-negative (ER(-)/PR(-)) breast cancer (BC), and few targeted therapies are available. Clinical heterogeneity of ER(-)/PR(-) tumors suggests that molecular subsets exist. We performed genome-wide expression analysis of 99 primary BC samples and eight BC cell lines in an effort to reveal distinct subsets, provide insight into their biology and potentially identify new therapeutic targets. We identified a subset of ER(-)/PR(-) tumors with paradoxical expression of genes known to be either direct targets of ER, responsive to estrogen, or typically expressed in ER(+) BC. Differentially expressed genes included SPDEF, FOXA1, XBP1, CYB5, TFF3, NAT1, APOD, ALCAM and AR (P<0.001). A classification model based on the expression signature of this tumor class identified molecularly similar BCs in an independent human BC data set and among BC cell lines (MDA-MB-453). This cell line demonstrated a proliferative response to androgen in an androgen receptor-dependent and ER-independent manner. In addition, the androgen-induced transcriptional program of MDA-MB-453 significantly overlapped the molecular signature of the unique ER(-)/PR(-) subclass of human tumors. This subset of BCs, characterized by a hormonally regulated transcriptional program and response to androgen, suggests the potential for therapeutic strategies targeting the androgen signaling pathway.

Standard name | DOANE_RESPONSE_TO_ANDROGEN_UP
Systematic name | M7600
Organism | Homo sapiens
PMID | 16491124
Authors | Doane AS,Danso M,Lal P,Donaton M,Zhang L,Hudis C,Gerald WL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MDA-MB-453 cells (class A ER(-) [GeneID=2099] breast cancer) after exposure to the androgen R1881 [PubChem=13766].
Full description | Little is known of the underlying biology of estrogen receptor-negative, progesterone receptor-negative (ER(-)/PR(-)) breast cancer (BC), and few targeted therapies are available. Clinical heterogeneity of ER(-)/PR(-) tumors suggests that molecular subsets exist. We performed genome-wide expression analysis of 99 primary BC samples and eight BC cell lines in an effort to reveal distinct subsets, provide insight into their biology and potentially identify new therapeutic targets. We identified a subset of ER(-)/PR(-) tumors with paradoxical expression of genes known to be either direct targets of ER, responsive to estrogen, or typically expressed in ER(+) BC. Differentially expressed genes included SPDEF, FOXA1, XBP1, CYB5, TFF3, NAT1, APOD, ALCAM and AR (P<0.001). A classification model based on the expression signature of this tumor class identified molecularly similar BCs in an independent human BC data set and among BC cell lines (MDA-MB-453). This cell line demonstrated a proliferative response to androgen in an androgen receptor-dependent and ER-independent manner. In addition, the androgen-induced transcriptional program of MDA-MB-453 significantly overlapped the molecular signature of the unique ER(-)/PR(-) subclass of human tumors. This subset of BCs, characterized by a hormonally regulated transcriptional program and response to androgen, suggests the potential for therapeutic strategies targeting the androgen signaling pathway.

Standard name | DOANE_RESPONSE_TO_ANDROGEN_DN
Systematic name | M12816
Organism | Homo sapiens
PMID | 16491124
Authors | Doane AS,Danso M,Lal P,Donaton M,Zhang L,Hudis C,Gerald WL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MDA-MB-453 cells (class A ER(-) [GeneID=2099] breast cancer) after exposure to the androgen R1881 [PubChem=13766].
Full description | Little is known of the underlying biology of estrogen receptor-negative, progesterone receptor-negative (ER(-)/PR(-)) breast cancer (BC), and few targeted therapies are available. Clinical heterogeneity of ER(-)/PR(-) tumors suggests that molecular subsets exist. We performed genome-wide expression analysis of 99 primary BC samples and eight BC cell lines in an effort to reveal distinct subsets, provide insight into their biology and potentially identify new therapeutic targets. We identified a subset of ER(-)/PR(-) tumors with paradoxical expression of genes known to be either direct targets of ER, responsive to estrogen, or typically expressed in ER(+) BC. Differentially expressed genes included SPDEF, FOXA1, XBP1, CYB5, TFF3, NAT1, APOD, ALCAM and AR (P<0.001). A classification model based on the expression signature of this tumor class identified molecularly similar BCs in an independent human BC data set and among BC cell lines (MDA-MB-453). This cell line demonstrated a proliferative response to androgen in an androgen receptor-dependent and ER-independent manner. In addition, the androgen-induced transcriptional program of MDA-MB-453 significantly overlapped the molecular signature of the unique ER(-)/PR(-) subclass of human tumors. This subset of BCs, characterized by a hormonally regulated transcriptional program and response to androgen, suggests the potential for therapeutic strategies targeting the androgen signaling pathway.

Standard name | DOANE_BREAST_CANCER_ESR1_UP
Systematic name | M19439
Organism | Homo sapiens
PMID | 16491124
Authors | Doane AS,Danso M,Lal P,Donaton M,Zhang L,Hudis C,Gerald WL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in breast cancer samples positive for ESR1 [GeneID=2099] compared to the ESR1 negative tumors.
Full description | Little is known of the underlying biology of estrogen receptor-negative, progesterone receptor-negative (ER(-)/PR(-)) breast cancer (BC), and few targeted therapies are available. Clinical heterogeneity of ER(-)/PR(-) tumors suggests that molecular subsets exist. We performed genome-wide expression analysis of 99 primary BC samples and eight BC cell lines in an effort to reveal distinct subsets, provide insight into their biology and potentially identify new therapeutic targets. We identified a subset of ER(-)/PR(-) tumors with paradoxical expression of genes known to be either direct targets of ER, responsive to estrogen, or typically expressed in ER(+) BC. Differentially expressed genes included SPDEF, FOXA1, XBP1, CYB5, TFF3, NAT1, APOD, ALCAM and AR (P<0.001). A classification model based on the expression signature of this tumor class identified molecularly similar BCs in an independent human BC data set and among BC cell lines (MDA-MB-453). This cell line demonstrated a proliferative response to androgen in an androgen receptor-dependent and ER-independent manner. In addition, the androgen-induced transcriptional program of MDA-MB-453 significantly overlapped the molecular signature of the unique ER(-)/PR(-) subclass of human tumors. This subset of BCs, characterized by a hormonally regulated transcriptional program and response to androgen, suggests the potential for therapeutic strategies targeting the androgen signaling pathway.

Standard name | DOANE_BREAST_CANCER_ESR1_DN
Systematic name | M8570
Organism | Homo sapiens
PMID | 16491124
Authors | Doane AS,Danso M,Lal P,Donaton M,Zhang L,Hudis C,Gerald WL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in breast cancer samples positive for ESR1 [GeneID=2099] compared to the ESR1 negative tumors.
Full description | Little is known of the underlying biology of estrogen receptor-negative, progesterone receptor-negative (ER(-)/PR(-)) breast cancer (BC), and few targeted therapies are available. Clinical heterogeneity of ER(-)/PR(-) tumors suggests that molecular subsets exist. We performed genome-wide expression analysis of 99 primary BC samples and eight BC cell lines in an effort to reveal distinct subsets, provide insight into their biology and potentially identify new therapeutic targets. We identified a subset of ER(-)/PR(-) tumors with paradoxical expression of genes known to be either direct targets of ER, responsive to estrogen, or typically expressed in ER(+) BC. Differentially expressed genes included SPDEF, FOXA1, XBP1, CYB5, TFF3, NAT1, APOD, ALCAM and AR (P<0.001). A classification model based on the expression signature of this tumor class identified molecularly similar BCs in an independent human BC data set and among BC cell lines (MDA-MB-453). This cell line demonstrated a proliferative response to androgen in an androgen receptor-dependent and ER-independent manner. In addition, the androgen-induced transcriptional program of MDA-MB-453 significantly overlapped the molecular signature of the unique ER(-)/PR(-) subclass of human tumors. This subset of BCs, characterized by a hormonally regulated transcriptional program and response to androgen, suggests the potential for therapeutic strategies targeting the androgen signaling pathway.

Standard name | WANG_RESPONSE_TO_ANDROGEN_UP
Systematic name | M16075
Organism | Homo sapiens
PMID | 16751804
Authors | Wang G,Jones SJ,Marra MA,Sadar MD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in LNCaP cells (prostate cancer) treated with synthetic androgen R1881 [PubChem=13766].
Full description | Progression of prostate cancer to androgen independence is suspected to involve the androgen and protein kinase A (PKA) signaling pathways. Here for the first time, the transcriptomes associated with each pathway and common transcriptional targets in response to stimulation of both pathways were identified in human prostate cancer cells using Affymetrix GeneChip technology (Human Genome U133 plus2). Statistically significant changes in the levels of 858 genes in response to androgen and 303 genes in response to activation of the PKA pathway were determined using GeneSpring software. Expression of a subset of these genes (22) that were transcriptional targets for the androgen and/or PKA pathways were validated by reverse transcriptase-polymerase chain reaction and Western blot analyses. Application of small interfering RNAs to the androgen receptor (AR) revealed that in addition to KLK3, levels of expression of KLK2 and SESN1 were regulated by AR activated by both the androgen and PKA signaling pathways. SESN1 was identified as a gene repressed by activated AR. These results provide a broad view of the effects of the androgen and PKA signaling pathways on the transcriptional program of prostate cancer cells and indicate that only a limited number of genes are targeted by cross-talk between AR and PKA pathways.

Standard name | WANG_RESPONSE_TO_FORSKOLIN_UP
Systematic name | M14942
Organism | Homo sapiens
PMID | 16751804
Authors | Wang G,Jones SJ,Marra MA,Sadar MD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in LNCaP cells (prostate cancer) treated with forskolin [PubChem=47936], an activator of PKA pathway.
Full description | Progression of prostate cancer to androgen independence is suspected to involve the androgen and protein kinase A (PKA) signaling pathways. Here for the first time, the transcriptomes associated with each pathway and common transcriptional targets in response to stimulation of both pathways were identified in human prostate cancer cells using Affymetrix GeneChip technology (Human Genome U133 plus2). Statistically significant changes in the levels of 858 genes in response to androgen and 303 genes in response to activation of the PKA pathway were determined using GeneSpring software. Expression of a subset of these genes (22) that were transcriptional targets for the androgen and/or PKA pathways were validated by reverse transcriptase-polymerase chain reaction and Western blot analyses. Application of small interfering RNAs to the androgen receptor (AR) revealed that in addition to KLK3, levels of expression of KLK2 and SESN1 were regulated by AR activated by both the androgen and PKA signaling pathways. SESN1 was identified as a gene repressed by activated AR. These results provide a broad view of the effects of the androgen and PKA signaling pathways on the transcriptional program of prostate cancer cells and indicate that only a limited number of genes are targeted by cross-talk between AR and PKA pathways.

Standard name | WANG_RESPONSE_TO_FORSKOLIN_DN
Systematic name | M19162
Organism | Homo sapiens
PMID | 16751804
Authors | Wang G,Jones SJ,Marra MA,Sadar MD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in LNCaP cells (prostate cancer) treated with forskolin [PubChem=47936], an activator of PKA pathway.
Full description | Progression of prostate cancer to androgen independence is suspected to involve the androgen and protein kinase A (PKA) signaling pathways. Here for the first time, the transcriptomes associated with each pathway and common transcriptional targets in response to stimulation of both pathways were identified in human prostate cancer cells using Affymetrix GeneChip technology (Human Genome U133 plus2). Statistically significant changes in the levels of 858 genes in response to androgen and 303 genes in response to activation of the PKA pathway were determined using GeneSpring software. Expression of a subset of these genes (22) that were transcriptional targets for the androgen and/or PKA pathways were validated by reverse transcriptase-polymerase chain reaction and Western blot analyses. Application of small interfering RNAs to the androgen receptor (AR) revealed that in addition to KLK3, levels of expression of KLK2 and SESN1 were regulated by AR activated by both the androgen and PKA signaling pathways. SESN1 was identified as a gene repressed by activated AR. These results provide a broad view of the effects of the androgen and PKA signaling pathways on the transcriptional program of prostate cancer cells and indicate that only a limited number of genes are targeted by cross-talk between AR and PKA pathways.

Standard name | TIMOFEEVA_GROWTH_STRESS_VIA_STAT1_DN
Systematic name | M2849
Organism | Homo sapiens
PMID | 16799645
Authors | Timofeeva OA,Plisov S,Evseev AA,Peng S,Jose-Kampfner M,Lovvorn HN,Dome JS,Perantoni AO
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SK-NEP-1 cells (Wilm's tumor ) stably expressing inactivated forms of STAT1 [GeneID=6772] under growth stress (hypoxia or nutritional deprivation).
Full description | Wilms' tumor (WT), one of the most common pediatric solid cancers, arises in the developing kidney as a result of genetic and epigenetic changes that lead to the abnormal proliferation and differentiation of the metanephric blastema. As activation of signal transducers and activators of transcription (STATs) plays an important role in the maintenance/growth and differentiation of the metanephric blastema, and constitutively activated STATs facilitate neoplastic behaviors of a variety of cancers, we hypothesized that dysregulation of STAT signaling may also contribute to WT pathogenesis. Accordingly, we evaluated STAT phosphorylation patterns in tumors and found that STAT1 was constitutively phosphorylated on serine 727 (S727) in 19 of 21 primary WT samples and two WT cell lines. An inactivating mutation of S727 to alanine reduced colony formation of WT cells in soft agar by more than 80% and induced apoptosis under conditions of growth stress. S727-phosphorylated STAT1 provided apoptotic resistance for WT cells via upregulation of expression of the heat-shock protein (HSP)27 and antiapoptotic protein myeloid cell leukemia (MCL)-1. The kinase responsible for STAT1 S727 phosphorylation in WT cells was identified based upon the use of selective inhibitors as protein kinase CK2, not p38, MAP-kinase kinase (MEK)1/2, phosphatidylinositol 3'-kinase, protein kinase C or Ca/calmodulin-dependent protein kinase II (CaMKII). The inhibition of CK2 blocked the anchorage-independent growth of WT cells and induced apoptosis under conditions of growth stress. Our findings suggest that serine-phosphorylated STAT1, as a downstream target of protein kinase CK2, plays a critical role in the pathogenesis of WT and possibly other neoplasms with similar STAT1 phosphorylation patterns.

Standard name | LAIHO_COLORECTAL_CANCER_SERRATED_UP
Systematic name | M16586
Organism | Homo sapiens
PMID | 16819509
Authors | Laiho P,Kokko A,Vanharanta S,Salovaara R,Sammalkorpi H,Järvinen H,Mecklin JP,Karttunen TJ,Tuppurainen K,Davalos V,Schwartz S,Arango D,Mäkinen MJ,Aaltonen LA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in serrated vs conventional colorectal carcinoma (CRC) samples.
Full description | Serrated colorectal carcinomas (CRCs) are morphologically different from conventional CRCs and have been proposed to follow a distinct pathway of CRC formation. Despite studies of single molecular events in this tumor type, the diagnosis of serrated CRC relies on morphology and the putative unique biological character of these tumors has not been established. Here we show that the gene expression profiling of 37 CRCs separated serrated and conventional CRCs into two distinct branches in unsupervised hierarchical clustering (P-value 7.8 x 10(-7)), and revealed 201 differentially expressed genes representing potential biomarkers for serrated CRC. Immunohistochemistry was utilized to verify the key findings in the 37 CRCs examined by expression profiling, and a separate validation set of 37 serrated and 86 conventional CRCs was examined to evaluate the candidate biomarkers in an extended sample material. Ephrin receptor B2, hypoxia-inducible factor 1-alpha and patched appeared as proteins important for genesis of serrated CRC. This study establishes serrated CRCs as a biologically distinct subclass of CRC and represents a step forward in the molecular classification of these cancers. The study also provides a platform to understand the molecular basis of serrated CRC and in long term may contribute to the development of specific treatment options for this tumor type.

Standard name | LAIHO_COLORECTAL_CANCER_SERRATED_DN
Systematic name | M17423
Organism | Homo sapiens
PMID | 16819509
Authors | Laiho P,Kokko A,Vanharanta S,Salovaara R,Sammalkorpi H,Järvinen H,Mecklin JP,Karttunen TJ,Tuppurainen K,Davalos V,Schwartz S,Arango D,Mäkinen MJ,Aaltonen LA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in serrated vs conventional colorectal carcinoma (CRC) samples.
Full description | Serrated colorectal carcinomas (CRCs) are morphologically different from conventional CRCs and have been proposed to follow a distinct pathway of CRC formation. Despite studies of single molecular events in this tumor type, the diagnosis of serrated CRC relies on morphology and the putative unique biological character of these tumors has not been established. Here we show that the gene expression profiling of 37 CRCs separated serrated and conventional CRCs into two distinct branches in unsupervised hierarchical clustering (P-value 7.8 x 10(-7)), and revealed 201 differentially expressed genes representing potential biomarkers for serrated CRC. Immunohistochemistry was utilized to verify the key findings in the 37 CRCs examined by expression profiling, and a separate validation set of 37 serrated and 86 conventional CRCs was examined to evaluate the candidate biomarkers in an extended sample material. Ephrin receptor B2, hypoxia-inducible factor 1-alpha and patched appeared as proteins important for genesis of serrated CRC. This study establishes serrated CRCs as a biologically distinct subclass of CRC and represents a step forward in the molecular classification of these cancers. The study also provides a platform to understand the molecular basis of serrated CRC and in long term may contribute to the development of specific treatment options for this tumor type.

Standard name | BORCZUK_MALIGNANT_MESOTHELIOMA_UP
Systematic name | M10236
Organism | Homo sapiens
PMID | 16862182
Authors | Borczuk AC,Cappellini GC,Kim HK,Hesdorffer M,Taub RN,Powell CA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in biphasic (mixed) vs epithelial subtypes of malignant peritoneal mesothelioma.
Full description | Malignant mesothelioma is an aggressive neoplastic proliferation derived from cells lining serosal membranes. The biological and clinical characteristics of epithelial type malignant mesothelioma are distinct from those of biphasic and sarcomatous type tumors. The goal of our study was to examine the molecular basis for this distinction. Microarray analysis confirmed that the molecular signatures of epithelial and biphasic histologic subtypes were distinct. Among the differentially expressed functional gene categories was the ubiquitin-proteasome pathway, which was upregulated in biphasic tumors. Cytotoxicity experiments indicated that 211H cells derived from biphasic tumors were synergistically sensitive to sequential combination regimens containing the proteasome inhibitor bortezomib and oxaliplatin. The mechanism of this synergistic response, which was not detected in cells of epithelial tumor origin, was apoptosis. Together, our results identify the ubiquitin-proteasome pathway as a biomarker of poor prognosis biphasic peritoneal mesothelioma tumors and suggest that proteasome inhibitors could increase the effectiveness of cytotoxic chemotherapy in this subset of patients.

Standard name | BORCZUK_MALIGNANT_MESOTHELIOMA_DN
Systematic name | M7988
Organism | Homo sapiens
PMID | 16862182
Authors | Borczuk AC,Cappellini GC,Kim HK,Hesdorffer M,Taub RN,Powell CA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in biphasic (mixed) vs epithelial subtypes of malignant peritoneal mesothelioma.
Full description | Malignant mesothelioma is an aggressive neoplastic proliferation derived from cells lining serosal membranes. The biological and clinical characteristics of epithelial type malignant mesothelioma are distinct from those of biphasic and sarcomatous type tumors. The goal of our study was to examine the molecular basis for this distinction. Microarray analysis confirmed that the molecular signatures of epithelial and biphasic histologic subtypes were distinct. Among the differentially expressed functional gene categories was the ubiquitin-proteasome pathway, which was upregulated in biphasic tumors. Cytotoxicity experiments indicated that 211H cells derived from biphasic tumors were synergistically sensitive to sequential combination regimens containing the proteasome inhibitor bortezomib and oxaliplatin. The mechanism of this synergistic response, which was not detected in cells of epithelial tumor origin, was apoptosis. Together, our results identify the ubiquitin-proteasome pathway as a biomarker of poor prognosis biphasic peritoneal mesothelioma tumors and suggest that proteasome inhibitors could increase the effectiveness of cytotoxic chemotherapy in this subset of patients.

Standard name | ROY_WOUND_BLOOD_VESSEL_UP
Systematic name | M7337
Organism | Homo sapiens
PMID | 17728400
Authors | Roy S,Patel D,Khanna S,Gordillo GM,Biswas S,Friedman A,Sen CK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in blood vessel cells from wound site.
Full description | Chronic wounds represent a substantial public health problem. The development of tools that would enable sophisticated scrutiny of clinical wound tissue material is highly desirable. This work presents evidence enabling rapid specific identification and laser capture of blood vessels from human tissue in a manner which lends itself to successful high-density (U133A) microarray analysis. Such screening of transcriptome followed by real-time PCR and immunohistochemical verification of candidate genes and their corresponding products were performed by using 3 mm biopsies. Of the 18,400 transcripts and variants screened, a focused set of 53 up-regulated and 24 down-regulated genes were noted in wound-derived blood vessels compared with blood vessels from intact human skin. The mean abundance of periostin in wound-site blood vessels was 96-fold higher. Periostin is known to be induced in response to vascular injury and its expression is associated with smooth muscle cell differentiation in vitro and promotes cell migration. Forty-fold higher expression of heparan sulfate 6-O-endosulfatase1 (Sulf1) was noted in wound-site vessels. Sulf1 has been recently recognized to be anti-angiogenic. During embryonic vasculogenesis, CD24 expression is down-regulated in human embryonic stem cells. Wound-site vessels had lower CD24 expression. The findings of this work provide a unique opportunity to appreciate the striking contrast in the transcriptome composition in blood vessels collected from the intact skin and from the wound-edge tissue. Sets of genes with known vascular functions but never connected to wound healing were identified to be differentially expressed in wound-derived blood vessels paving the way for innovative clinically relevant hypotheses.

Standard name | ROY_WOUND_BLOOD_VESSEL_DN
Systematic name | M2176
Organism | Homo sapiens
PMID | 17728400
Authors | Roy S,Patel D,Khanna S,Gordillo GM,Biswas S,Friedman A,Sen CK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in blood vessel cells from wound site.
Full description | Chronic wounds represent a substantial public health problem. The development of tools that would enable sophisticated scrutiny of clinical wound tissue material is highly desirable. This work presents evidence enabling rapid specific identification and laser capture of blood vessels from human tissue in a manner which lends itself to successful high-density (U133A) microarray analysis. Such screening of transcriptome followed by real-time PCR and immunohistochemical verification of candidate genes and their corresponding products were performed by using 3 mm biopsies. Of the 18,400 transcripts and variants screened, a focused set of 53 up-regulated and 24 down-regulated genes were noted in wound-derived blood vessels compared with blood vessels from intact human skin. The mean abundance of periostin in wound-site blood vessels was 96-fold higher. Periostin is known to be induced in response to vascular injury and its expression is associated with smooth muscle cell differentiation in vitro and promotes cell migration. Forty-fold higher expression of heparan sulfate 6-O-endosulfatase1 (Sulf1) was noted in wound-site vessels. Sulf1 has been recently recognized to be anti-angiogenic. During embryonic vasculogenesis, CD24 expression is down-regulated in human embryonic stem cells. Wound-site vessels had lower CD24 expression. The findings of this work provide a unique opportunity to appreciate the striking contrast in the transcriptome composition in blood vessels collected from the intact skin and from the wound-edge tissue. Sets of genes with known vascular functions but never connected to wound healing were identified to be differentially expressed in wound-derived blood vessels paving the way for innovative clinically relevant hypotheses.

Standard name | GRABARCZYK_BCL11B_TARGETS_UP
Systematic name | M6222
Organism | Homo sapiens
PMID | 17173069
Authors | Grabarczyk P,Przybylski GK,Depke M,Völker U,Bahr J,Assmus K,Bröker BM,Walther R,Schmidt CA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Jurkat cells (transformed T lymphocytes) after knockdown of BCL11B [GeneID=64919] by RNAi.
Full description | The B-cell chronic lymphocytic leukemia (CLL)/lymphoma 11B gene (BCL11B) encodes a Krüppel-like zinc-finger protein, which plays a crucial role in thymopoiesis and has been associated with hematopoietic malignancies. It was hypothesized that BCL11B may act as a tumor-suppressor gene, but its precise function has not yet been elucidated. Here, we demonstrate that the survival of human T-cell leukemia and lymphoma cell lines is critically dependent on Bcl11b. Suppression of Bcl11b by RNA interference selectively induced apoptosis in transformed T cells whereas normal mature T cells remained unaffected. The apoptosis was effected by simultaneous activation of death receptor-mediated and intrinsic apoptotic pathways, most likely as a result of tumor necrosis factor-related apoptosis-inducing ligand (TRAIL) upregulation and suppression of the Bcl-xL antiapoptotic protein. Our data indicate an antiapoptotic function of Bcl11b. The resistance of normal mature T lymphocytes to Bcl11b suppression-induced apoptosis and restricted expression pattern make it an attractive therapeutic target in T-cell malignancies.

Standard name | GRABARCZYK_BCL11B_TARGETS_DN
Systematic name | M19457
Organism | Homo sapiens
PMID | 17173069
Authors | Grabarczyk P,Przybylski GK,Depke M,Völker U,Bahr J,Assmus K,Bröker BM,Walther R,Schmidt CA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Jurkat cells (transformed T lymphocytes) after knockdown of BCL11B [GeneID=64919] by RNAi.
Full description | The B-cell chronic lymphocytic leukemia (CLL)/lymphoma 11B gene (BCL11B) encodes a Krüppel-like zinc-finger protein, which plays a crucial role in thymopoiesis and has been associated with hematopoietic malignancies. It was hypothesized that BCL11B may act as a tumor-suppressor gene, but its precise function has not yet been elucidated. Here, we demonstrate that the survival of human T-cell leukemia and lymphoma cell lines is critically dependent on Bcl11b. Suppression of Bcl11b by RNA interference selectively induced apoptosis in transformed T cells whereas normal mature T cells remained unaffected. The apoptosis was effected by simultaneous activation of death receptor-mediated and intrinsic apoptotic pathways, most likely as a result of tumor necrosis factor-related apoptosis-inducing ligand (TRAIL) upregulation and suppression of the Bcl-xL antiapoptotic protein. Our data indicate an antiapoptotic function of Bcl11b. The resistance of normal mature T lymphocytes to Bcl11b suppression-induced apoptosis and restricted expression pattern make it an attractive therapeutic target in T-cell malignancies.

Standard name | NEWMAN_ERCC6_TARGETS_UP
Systematic name | M5459
Organism | Homo sapiens
PMID | 16772382
Authors | Newman JC,Bailey AD,Weiner AM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Cockayne syndrome fibroblasts rescued by expression of ERCC6 [GeneID=2074] off a plasmid vector.
Full description | Cockayne syndrome (CS) is an inherited neurodevelopmental disorder with progeroid features. Although the genes responsible for CS have been implicated in a variety of DNA repair- and transcription-related pathways, the nature of the molecular defect in CS remains mysterious. Using expression microarrays and a unique method for comparative expression analysis called L2L, we sought to define this defect in cells lacking a functional CS group B (CSB) protein, the SWI/SNF-like ATPase responsible for most cases of CS. Remarkably, many of the genes regulated by CSB are also affected by inhibitors of histone deacetylase and DNA methylation, as well as by defects in poly(ADP-ribose)-polymerase function and RNA polymerase II elongation. Moreover, consistent with these microarray expression data, CSB-null cells are sensitive to inhibitors of histone deacetylase or poly(ADP-ribose)-polymerase. Our data indicate a general role for CSB protein in maintenance and remodeling of chromatin structure and suggest that CS is a disease of transcriptional deregulation caused by misexpression of growth-suppressive, inflammatory, and proapoptotic pathways.

Standard name | NEWMAN_ERCC6_TARGETS_DN
Systematic name | M6239
Organism | Homo sapiens
PMID | 16772382
Authors | Newman JC,Bailey AD,Weiner AM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Cockayne syndrome fibroblasts rescued by expression of ERCC6 [GeneID=2074] off a plasmid vector.
Full description | Cockayne syndrome (CS) is an inherited neurodevelopmental disorder with progeroid features. Although the genes responsible for CS have been implicated in a variety of DNA repair- and transcription-related pathways, the nature of the molecular defect in CS remains mysterious. Using expression microarrays and a unique method for comparative expression analysis called L2L, we sought to define this defect in cells lacking a functional CS group B (CSB) protein, the SWI/SNF-like ATPase responsible for most cases of CS. Remarkably, many of the genes regulated by CSB are also affected by inhibitors of histone deacetylase and DNA methylation, as well as by defects in poly(ADP-ribose)-polymerase function and RNA polymerase II elongation. Moreover, consistent with these microarray expression data, CSB-null cells are sensitive to inhibitors of histone deacetylase or poly(ADP-ribose)-polymerase. Our data indicate a general role for CSB protein in maintenance and remodeling of chromatin structure and suggest that CS is a disease of transcriptional deregulation caused by misexpression of growth-suppressive, inflammatory, and proapoptotic pathways.

Standard name | HORIUCHI_WTAP_TARGETS_UP
Systematic name | M1973
Organism | Homo sapiens
PMID | 17088532
Authors | Horiuchi K,Umetani M,Minami T,Okayama H,Takada S,Yamamoto M,Aburatani H,Reid PC,Housman DE,Hamakubo T,Kodama T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary endothelial cells (HUVEC) after knockdown of WTAP [GeneID=9589] by RNAi.
Full description | Wilms' tumor 1-associating protein (WTAP) has been reported to be a ubiquitously expressed nuclear protein. Although a relation to splicing factors has been postulated, its actual physiological function still remains to be elucidated. To investigate the role of WTAP, we generated WTAP-knockout mice and performed small interfering RNA (siRNA)-mediated knockdown analyses in primary cultured cells. In DNA microarrays using human umbilical vein endothelial cells, WTAP-targeted siRNA treatment resulted in markedly reduced expression of cell-cycle-related genes. siRNA-mediated WTAP knockdown down-regulated the stability of cyclin A2 mRNA through a nine-nucleotide essential sequence in cyclin A2 mRNA 3' UTR. WTAP knockdown induced G2 accumulation, which is partially rescued by adenoviral overexpression of cyclin A2. Moreover, WTAP-null mice exhibited proliferative failure with death resulting at approximately embryonic day 6.5, an etiology almost identical to cyclin A2-null mice. Collectively, these findings establish WTAP as an essential factor for the stabilization of cyclin A2 mRNA, thereby regulating G2/M cell-cycle transition.

Standard name | HORIUCHI_WTAP_TARGETS_DN
Systematic name | M10279
Organism | Homo sapiens
PMID | 17088532
Authors | Horiuchi K,Umetani M,Minami T,Okayama H,Takada S,Yamamoto M,Aburatani H,Reid PC,Housman DE,Hamakubo T,Kodama T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary endothelial cells (HUVEC) after knockdown of WTAP [GeneID=9589] by RNAi.
Full description | Wilms' tumor 1-associating protein (WTAP) has been reported to be a ubiquitously expressed nuclear protein. Although a relation to splicing factors has been postulated, its actual physiological function still remains to be elucidated. To investigate the role of WTAP, we generated WTAP-knockout mice and performed small interfering RNA (siRNA)-mediated knockdown analyses in primary cultured cells. In DNA microarrays using human umbilical vein endothelial cells, WTAP-targeted siRNA treatment resulted in markedly reduced expression of cell-cycle-related genes. siRNA-mediated WTAP knockdown down-regulated the stability of cyclin A2 mRNA through a nine-nucleotide essential sequence in cyclin A2 mRNA 3' UTR. WTAP knockdown induced G2 accumulation, which is partially rescued by adenoviral overexpression of cyclin A2. Moreover, WTAP-null mice exhibited proliferative failure with death resulting at approximately embryonic day 6.5, an etiology almost identical to cyclin A2-null mice. Collectively, these findings establish WTAP as an essential factor for the stabilization of cyclin A2 mRNA, thereby regulating G2/M cell-cycle transition.

Standard name | GAL_LEUKEMIC_STEM_CELL_UP
Systematic name | M17428
Organism | Homo sapiens
PMID | 17039238
Authors | Gal H,Amariglio N,Trakhtenbrot L,Jacob-Hirsh J,Margalit O,Avigdor A,Nagler A,Tavor S,Ein-Dor L,Lapidot T,Domany E,Rechavi G,Givol D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in leukemic stem cells (LSC), defined as CD34+CD38- [GeneID=947;952] cells from AML (acute myeloid leukemia patients) compared to the CD34+CD38+ cells.
Full description | Tumors contain a fraction of cancer stem cells that maintain the propagation of the disease. The CD34(+)CD38(-) cells, isolated from acute myeloid leukemia (AML), were shown to be enriched leukemic stem cells (LSC). We isolated the CD34(+)CD38(-) cell fraction from AML and compared their gene expression profiles to the CD34(+)CD38(+) cell fraction, using microarrays. We found 409 genes that were at least twofold over- or underexpressed between the two cell populations. These include underexpression of DNA repair, signal transduction and cell cycle genes, consistent with the relative quiescence of stem cells, and chromosomal aberrations and mutations of leukemic cells. Comparison of the LSC expression data to that of normal hematopoietic stem cells (HSC) revealed that 34% of the modulated genes are shared by both LSC and HSC, supporting the suggestion that the LSC originated within the HSC progenitors. We focused on the Notch pathway since Jagged-2, a Notch ligand was found to be overexpressed in the LSC samples. We show that DAPT, an inhibitor of gamma-secretase, a protease that is involved in Jagged and Notch signaling, inhibits LSC growth in colony formation assays. Identification of additional genes that regulate LSC self-renewal may provide new targets for therapy.

Standard name | GAL_LEUKEMIC_STEM_CELL_DN
Systematic name | M4502
Organism | Homo sapiens
PMID | 17039238
Authors | Gal H,Amariglio N,Trakhtenbrot L,Jacob-Hirsh J,Margalit O,Avigdor A,Nagler A,Tavor S,Ein-Dor L,Lapidot T,Domany E,Rechavi G,Givol D
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in leukemic stem cells (LSC), defined as CD34+CD38- [GeneID=947;952] cells from AML (acute myeloid leukemia patients) compared to the CD34+CD38+ cells.
Full description | Tumors contain a fraction of cancer stem cells that maintain the propagation of the disease. The CD34(+)CD38(-) cells, isolated from acute myeloid leukemia (AML), were shown to be enriched leukemic stem cells (LSC). We isolated the CD34(+)CD38(-) cell fraction from AML and compared their gene expression profiles to the CD34(+)CD38(+) cell fraction, using microarrays. We found 409 genes that were at least twofold over- or underexpressed between the two cell populations. These include underexpression of DNA repair, signal transduction and cell cycle genes, consistent with the relative quiescence of stem cells, and chromosomal aberrations and mutations of leukemic cells. Comparison of the LSC expression data to that of normal hematopoietic stem cells (HSC) revealed that 34% of the modulated genes are shared by both LSC and HSC, supporting the suggestion that the LSC originated within the HSC progenitors. We focused on the Notch pathway since Jagged-2, a Notch ligand was found to be overexpressed in the LSC samples. We show that DAPT, an inhibitor of gamma-secretase, a protease that is involved in Jagged and Notch signaling, inhibits LSC growth in colony formation assays. Identification of additional genes that regulate LSC self-renewal may provide new targets for therapy.

Standard name | CHOI_ATL_CHRONIC_VS_ACUTE_DN
Systematic name | M609
Organism | Homo sapiens
PMID | 16909099
Authors | Choi YL,Tsukasaki K,O'Neill MC,Yamada Y,Onimaru Y,Matsumoto K,Ohashi J,Yamashita Y,Tsutsumi S,Kaneda R,Takada S,Aburatani H,Kamihira S,Nakamura T,Tomonaga M,Mano H
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in adult T-cell leukemia (ATL), chronic vs acute clinical condition.
Full description | Adult T-cell leukemia (ATL) is an intractable malignancy of CD4+ T cells that is etiologically associated with infection by human T-cell leukemia virus-type I. Most individuals in the chronic stage of ATL eventually undergo progression to a highly aggressive acute stage. To clarify the mechanism responsible for this stage progression, we isolated CD4+ cells from individuals in the chronic (n=19) or acute (n=22) stages of ATL and subjected them to profiling of gene expression with DNA microarrays containing >44,000 probe sets. Changes in chromosome copy number were also examined for 24 cell specimens with the use of microarrays harboring approximately 50,000 probe sets. Stage-dependent changes in gene expression profile and chromosome copy number were apparent. Furthermore, expression of the gene for MET, a receptor tyrosine kinase for hepatocyte growth factor (HGF), was shown to be specific to the acute stage of ATL, and the plasma concentration of HGF was increased in individuals in either the acute or chronic stage. HGF induced proliferation of a MET-positive ATL cell line, and this effect was blocked by antibodies to HGF. The HGF-MET signaling pathway is thus a potential therapeutic target for ATL.

Standard name | BASAKI_YBX1_TARGETS_UP
Systematic name | M14985
Organism | Homo sapiens
PMID | 17072343
Authors | Basaki Y,Hosoi F,Oda Y,Fotovati A,Maruyama Y,Oie S,Ono M,Izumi H,Kohno K,Sakai K,Shimoyama T,Nishio K,Kuwano M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SKOC-3 cells (ovarian cancer) after YB-1 (YBX1) [GeneID=4904] knockdown by RNAi.
Full description | Y-box-binding protein 1 (YB-1), which is a member of the DNA-binding protein family containing a cold-shock domain, has pleiotropic functions in response to various environmental stimuli. As we previously showed that YB-1 is a global marker of multidrug resistance in ovarian cancer and other tumor types. To identify YB-1-regulated genes in ovarian cancers, we investigated the expression profile of YB-1 small-interfering RNA (siRNA)-transfected ovarian cancer cells using a high-density oligonucleotide array. YB-1 knockdown by siRNA upregulated 344 genes, including MDR1, thymidylate synthetase, S100 calcium binding protein and cyclin B, and downregulated 534 genes, including CXCR4, N-myc downstream regulated gene 1, E-cadherin and phospholipase C. Exogenous serum addition stimulated YB-1 translocation from the cytoplasm to the nucleus, and treatment with Akt inhibitors as well as Akt siRNA and integrin-linked kinase (ILK) siRNA specifically blocked YB-1 nuclear localization. Inhibition of Akt activation downregulated CXCR4 and upregulated MDR1 (ABCB1) gene expression. Administration of Akt inhibitor resulted in decrease in nuclear YB-1-positive cancer cells in a xenograft animal model. Akt activation thus regulates the nuclear translocation of YB-1, affecting the expression of drug-resistance genes and other genes associated with the malignant characteristics in ovarian cancer cells. Therefore, the Akt pathway could be a novel target of disrupting the nuclear translocation of YB-1 that has important implications for further development of therapeutic strategy against ovarian cancers.

Standard name | BASAKI_YBX1_TARGETS_DN
Systematic name | M14877
Organism | Homo sapiens
PMID | 17072343
Authors | Basaki Y,Hosoi F,Oda Y,Fotovati A,Maruyama Y,Oie S,Ono M,Izumi H,Kohno K,Sakai K,Shimoyama T,Nishio K,Kuwano M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SKOC-3 cells (ovarian cancer) after YB-1 (YBX1) [GeneID=4904] knockdown by RNAi.
Full description | Y-box-binding protein 1 (YB-1), which is a member of the DNA-binding protein family containing a cold-shock domain, has pleiotropic functions in response to various environmental stimuli. As we previously showed that YB-1 is a global marker of multidrug resistance in ovarian cancer and other tumor types. To identify YB-1-regulated genes in ovarian cancers, we investigated the expression profile of YB-1 small-interfering RNA (siRNA)-transfected ovarian cancer cells using a high-density oligonucleotide array. YB-1 knockdown by siRNA upregulated 344 genes, including MDR1, thymidylate synthetase, S100 calcium binding protein and cyclin B, and downregulated 534 genes, including CXCR4, N-myc downstream regulated gene 1, E-cadherin and phospholipase C. Exogenous serum addition stimulated YB-1 translocation from the cytoplasm to the nucleus, and treatment with Akt inhibitors as well as Akt siRNA and integrin-linked kinase (ILK) siRNA specifically blocked YB-1 nuclear localization. Inhibition of Akt activation downregulated CXCR4 and upregulated MDR1 (ABCB1) gene expression. Administration of Akt inhibitor resulted in decrease in nuclear YB-1-positive cancer cells in a xenograft animal model. Akt activation thus regulates the nuclear translocation of YB-1, affecting the expression of drug-resistance genes and other genes associated with the malignant characteristics in ovarian cancer cells. Therefore, the Akt pathway could be a novel target of disrupting the nuclear translocation of YB-1 that has important implications for further development of therapeutic strategy against ovarian cancers.

Standard name | NOJIMA_SFRP2_TARGETS_UP
Systematic name | M14772
Organism | Homo sapiens
PMID | 17297461
Authors | Nojima M,Suzuki H,Toyota M,Watanabe Y,Maruyama R,Sasaki S,Sasaki Y,Mita H,Nishikawa N,Yamaguchi K,Hirata K,Itoh F,Tokino T,Mori M,Imai K,Shinomura Y
Category | C2
Sub-category | CGP
Brief description | Cellular proliferation, growth, apoptosis and Wnt signaling genes up-regulated in SNU638 cells (gastric cancer) by overexpression of SFRP2 [GeneID=6423] off a plasmid vector.
Full description | Activation of Wnt signaling has been implicated in gastric tumorigenesis, although mutations in APC (adenomatous polyposis coli), CTNNB1 (beta-catenin) and AXIN are seen much less frequently in gastric cancer (GC) than in colorectal cancer. In the present study, we investigated the relationship between activation of Wnt signaling and changes in the expression of secreted frizzled-related protein (SFRP) family genes in GC. We frequently observed nuclear beta-catenin accumulation (13/15; 87%) and detected the active form of beta-catenin in most (12/16; 75%) GC cell lines. CpG methylation-dependent silencing of SFRP1, SFRP2 and SFRP5 was frequently seen among GC cell lines (SFRP1, 16/16, 100%; SFRP2, 16/16, 100%; SFRP5, 13/16, 81%) and primary GC specimens (SFRP1, 42/46, 91%; SFRP2, 44/46, 96%; SFRP5, 30/46, 65%), and treatment with the DNA methyltransferase inhibitor 5-aza-2'-deoxycytidine rapidly restored SFRP expression. Ectopic expression of SFRPs downregulated T-cell factor/lymphocyte enhancer factor transcriptional activity, suppressed cell growth and induced apoptosis in GC cells. Analysis of global expression revealed that overexpression of SFRP2 repressed Wnt target genes and induced changes in the expression of numerous genes related to proliferation, growth and apoptosis in GC cells. It thus appears that aberrant SFRP methylation is one of the major mechanisms by which Wnt signaling is activated in GC.

Standard name | NOJIMA_SFRP2_TARGETS_DN
Systematic name | M2733
Organism | Homo sapiens
PMID | 17297461
Authors | Nojima M,Suzuki H,Toyota M,Watanabe Y,Maruyama R,Sasaki S,Sasaki Y,Mita H,Nishikawa N,Yamaguchi K,Hirata K,Itoh F,Tokino T,Mori M,Imai K,Shinomura Y
Category | C2
Sub-category | CGP
Brief description | Cellular proliferation, growth, apoptosis and Wnt signaling genes down-regulated in SNU638 cells (gastric cancer) by overexpression of SFRP2 [GeneID=6423] off a plasmid vector.
Full description | Activation of Wnt signaling has been implicated in gastric tumorigenesis, although mutations in APC (adenomatous polyposis coli), CTNNB1 (beta-catenin) and AXIN are seen much less frequently in gastric cancer (GC) than in colorectal cancer. In the present study, we investigated the relationship between activation of Wnt signaling and changes in the expression of secreted frizzled-related protein (SFRP) family genes in GC. We frequently observed nuclear beta-catenin accumulation (13/15; 87%) and detected the active form of beta-catenin in most (12/16; 75%) GC cell lines. CpG methylation-dependent silencing of SFRP1, SFRP2 and SFRP5 was frequently seen among GC cell lines (SFRP1, 16/16, 100%; SFRP2, 16/16, 100%; SFRP5, 13/16, 81%) and primary GC specimens (SFRP1, 42/46, 91%; SFRP2, 44/46, 96%; SFRP5, 30/46, 65%), and treatment with the DNA methyltransferase inhibitor 5-aza-2'-deoxycytidine rapidly restored SFRP expression. Ectopic expression of SFRPs downregulated T-cell factor/lymphocyte enhancer factor transcriptional activity, suppressed cell growth and induced apoptosis in GC cells. Analysis of global expression revealed that overexpression of SFRP2 repressed Wnt target genes and induced changes in the expression of numerous genes related to proliferation, growth and apoptosis in GC cells. It thus appears that aberrant SFRP methylation is one of the major mechanisms by which Wnt signaling is activated in GC.

Standard name | WIKMAN_ASBESTOS_LUNG_CANCER_UP
Systematic name | M18658
Organism | Homo sapiens
PMID | 17297452
Authors | Wikman H,Ruosaari S,Nymark P,Sarhadi VK,Saharinen J,Vanhala E,Karjalainen A,Hollmén J,Knuutila S,Anttila S
Category | C2
Sub-category | CGP
Brief description | Genes positively correlated with the asbestos exposure of lung cancer patients.
Full description | Asbestos is a pulmonary carcinogen known to give rise to DNA and chromosomal damage, but the exact carcinogenic mechanisms are still largely unknown. In this study, gene expression arrays were performed on lung tumor samples from 14 heavily asbestos-exposed and 14 non-exposed patients matched for other characteristics. Using a two-step statistical analysis, 47 genes were revealed that could differentiate the tumors of asbestos-exposed from those of non-exposed patients. To identify asbestos-associated regions with DNA copy number and expressional changes, the gene expression data were combined with comparative genomic hybridization microarray data. As a result, a combinatory profile of DNA copy number aberrations and expressional changes significantly associated with asbestos exposure was obtained. Asbestos-related areas were detected in 2p21-p16.3, 3p21.31, 5q35.2-q35.3, 16p13.3, 19p13.3-p13.1 and 22q12.3-q13.1. The most prominent of these, 19p13, was further characterized by microsatellite analysis in 62 patients for the differences in allelic imbalance (AI) between the two groups of lung tumors. 79% of the exposed and 45% of the non-exposed patients (P=0.008) were found to be carriers of AI in their lung tumors. In the exposed group, AI in 19p was prevalent regardless of the histological tumor type. In adenocarcinomas, AI in 19p appeared to occur independently of the asbestos exposure.

Standard name | WIKMAN_ASBESTOS_LUNG_CANCER_DN
Systematic name | M9729
Organism | Homo sapiens
PMID | 17297452
Authors | Wikman H,Ruosaari S,Nymark P,Sarhadi VK,Saharinen J,Vanhala E,Karjalainen A,Hollmén J,Knuutila S,Anttila S
Category | C2
Sub-category | CGP
Brief description | Genes negatively correlated with the asbestos exposure of lung cancer patients.
Full description | Asbestos is a pulmonary carcinogen known to give rise to DNA and chromosomal damage, but the exact carcinogenic mechanisms are still largely unknown. In this study, gene expression arrays were performed on lung tumor samples from 14 heavily asbestos-exposed and 14 non-exposed patients matched for other characteristics. Using a two-step statistical analysis, 47 genes were revealed that could differentiate the tumors of asbestos-exposed from those of non-exposed patients. To identify asbestos-associated regions with DNA copy number and expressional changes, the gene expression data were combined with comparative genomic hybridization microarray data. As a result, a combinatory profile of DNA copy number aberrations and expressional changes significantly associated with asbestos exposure was obtained. Asbestos-related areas were detected in 2p21-p16.3, 3p21.31, 5q35.2-q35.3, 16p13.3, 19p13.3-p13.1 and 22q12.3-q13.1. The most prominent of these, 19p13, was further characterized by microsatellite analysis in 62 patients for the differences in allelic imbalance (AI) between the two groups of lung tumors. 79% of the exposed and 45% of the non-exposed patients (P=0.008) were found to be carriers of AI in their lung tumors. In the exposed group, AI in 19p was prevalent regardless of the histological tumor type. In adenocarcinomas, AI in 19p appeared to occur independently of the asbestos exposure.

Standard name | RODRIGUES_DCC_TARGETS_UP
Systematic name | M18359
Organism | Homo sapiens
PMID | 17334389
Authors | Rodrigues S,De Wever O,Bruyneel E,Rooney RJ,Gespach C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HCT8/S1 cells (colon cancer) which normally lack DCC [GeneID=9423] compared to those stably expressing wild type DCC off a plasmid vector.
Full description | Deleted in colon cancer (DCC) and UNC5 function as netrin dependence receptors by inducing apoptosis in the absence of their ligand and accordingly were recently designated as putative conditional tumor suppressors. Herein, we determined whether netrin-1 and its receptors are implicated in cancer cell invasion and tumor progression. Expression of DCC, UNC5 and adenosine A2B-receptors (A2B-Rs) was investigated by reverse transcription polymerase chain reaction in human colon cancer cells. The impact of DCC restitution and netrin-1 was evaluated on collagen type I invasion, tumor growth and metastasis in nude mice, cancer cell survival and gene expression profiling. Flow cytometry, poly(ADP-ribose)polymerase-1 and caspase-8 activation were used to evaluate the impact of DCC on cell death. Both netrin-1 and A2B-R activation induced the invasive phenotype through the Rho-Rho kinase axis in DCC-deficient human colorectal cancer cells. Restitution of wild-type DCC blocked invasion induced by netrin-1, A2B-R agonist and other agents. Ectopic expression of netrin-1 led to increased growth of human colon tumor xenografts in athymic mice. Conversely, introduction of wt-DCC in kidney MDCKts.src-ggl cells strongly inhibited metastasis in lymph nodes and lungs and increased sensitivity to apoptosis in hypoxia. DNA microarrays revealed that netrin and DCC had common and divergent impacts on gene expression linked to cell cycle, survival, surface signaling and adhesion. Our findings underscore that netrin is a potent invasion and tumor growth-promoting agent and that DCC is a metastasis suppressor gene targeting both proinvasive and survival pathways in a cumulative manner.

Standard name | RODRIGUES_DCC_TARGETS_DN
Systematic name | M15927
Organism | Homo sapiens
PMID | 17334389
Authors | Rodrigues S,De Wever O,Bruyneel E,Rooney RJ,Gespach C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HCT8/S1 cells (colon cancer) which normally lack DCC [GeneID=9423] compared to those stably expressing wild type DCC off a plasmid vector.
Full description | Deleted in colon cancer (DCC) and UNC5 function as netrin dependence receptors by inducing apoptosis in the absence of their ligand and accordingly were recently designated as putative conditional tumor suppressors. Herein, we determined whether netrin-1 and its receptors are implicated in cancer cell invasion and tumor progression. Expression of DCC, UNC5 and adenosine A2B-receptors (A2B-Rs) was investigated by reverse transcription polymerase chain reaction in human colon cancer cells. The impact of DCC restitution and netrin-1 was evaluated on collagen type I invasion, tumor growth and metastasis in nude mice, cancer cell survival and gene expression profiling. Flow cytometry, poly(ADP-ribose)polymerase-1 and caspase-8 activation were used to evaluate the impact of DCC on cell death. Both netrin-1 and A2B-R activation induced the invasive phenotype through the Rho-Rho kinase axis in DCC-deficient human colorectal cancer cells. Restitution of wild-type DCC blocked invasion induced by netrin-1, A2B-R agonist and other agents. Ectopic expression of netrin-1 led to increased growth of human colon tumor xenografts in athymic mice. Conversely, introduction of wt-DCC in kidney MDCKts.src-ggl cells strongly inhibited metastasis in lymph nodes and lungs and increased sensitivity to apoptosis in hypoxia. DNA microarrays revealed that netrin and DCC had common and divergent impacts on gene expression linked to cell cycle, survival, surface signaling and adhesion. Our findings underscore that netrin is a potent invasion and tumor growth-promoting agent and that DCC is a metastasis suppressor gene targeting both proinvasive and survival pathways in a cumulative manner.

Standard name | RODRIGUES_NTN1_TARGETS_UP
Systematic name | M12027
Organism | Homo sapiens
PMID | 17334389
Authors | Rodrigues S,De Wever O,Bruyneel E,Rooney RJ,Gespach C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HCT8/S11 cells (colon cancer) engineered to stably express NTN1 [GeneID=1630] off a plasmid vector.
Full description | Deleted in colon cancer (DCC) and UNC5 function as netrin dependence receptors by inducing apoptosis in the absence of their ligand and accordingly were recently designated as putative conditional tumor suppressors. Herein, we determined whether netrin-1 and its receptors are implicated in cancer cell invasion and tumor progression. Expression of DCC, UNC5 and adenosine A2B-receptors (A2B-Rs) was investigated by reverse transcription polymerase chain reaction in human colon cancer cells. The impact of DCC restitution and netrin-1 was evaluated on collagen type I invasion, tumor growth and metastasis in nude mice, cancer cell survival and gene expression profiling. Flow cytometry, poly(ADP-ribose)polymerase-1 and caspase-8 activation were used to evaluate the impact of DCC on cell death. Both netrin-1 and A2B-R activation induced the invasive phenotype through the Rho-Rho kinase axis in DCC-deficient human colorectal cancer cells. Restitution of wild-type DCC blocked invasion induced by netrin-1, A2B-R agonist and other agents. Ectopic expression of netrin-1 led to increased growth of human colon tumor xenografts in athymic mice. Conversely, introduction of wt-DCC in kidney MDCKts.src-ggl cells strongly inhibited metastasis in lymph nodes and lungs and increased sensitivity to apoptosis in hypoxia. DNA microarrays revealed that netrin and DCC had common and divergent impacts on gene expression linked to cell cycle, survival, surface signaling and adhesion. Our findings underscore that netrin is a potent invasion and tumor growth-promoting agent and that DCC is a metastasis suppressor gene targeting both proinvasive and survival pathways in a cumulative manner.

Standard name | RODRIGUES_NTN1_TARGETS_DN
Systematic name | M11857
Organism | Homo sapiens
PMID | 17334389
Authors | Rodrigues S,De Wever O,Bruyneel E,Rooney RJ,Gespach C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HCT8/S11 cells (colon cancer) engineered to stably express NTN1 [GeneID=1630] off a plasmid vector.
Full description | Deleted in colon cancer (DCC) and UNC5 function as netrin dependence receptors by inducing apoptosis in the absence of their ligand and accordingly were recently designated as putative conditional tumor suppressors. Herein, we determined whether netrin-1 and its receptors are implicated in cancer cell invasion and tumor progression. Expression of DCC, UNC5 and adenosine A2B-receptors (A2B-Rs) was investigated by reverse transcription polymerase chain reaction in human colon cancer cells. The impact of DCC restitution and netrin-1 was evaluated on collagen type I invasion, tumor growth and metastasis in nude mice, cancer cell survival and gene expression profiling. Flow cytometry, poly(ADP-ribose)polymerase-1 and caspase-8 activation were used to evaluate the impact of DCC on cell death. Both netrin-1 and A2B-R activation induced the invasive phenotype through the Rho-Rho kinase axis in DCC-deficient human colorectal cancer cells. Restitution of wild-type DCC blocked invasion induced by netrin-1, A2B-R agonist and other agents. Ectopic expression of netrin-1 led to increased growth of human colon tumor xenografts in athymic mice. Conversely, introduction of wt-DCC in kidney MDCKts.src-ggl cells strongly inhibited metastasis in lymph nodes and lungs and increased sensitivity to apoptosis in hypoxia. DNA microarrays revealed that netrin and DCC had common and divergent impacts on gene expression linked to cell cycle, survival, surface signaling and adhesion. Our findings underscore that netrin is a potent invasion and tumor growth-promoting agent and that DCC is a metastasis suppressor gene targeting both proinvasive and survival pathways in a cumulative manner.

Standard name | WANG_LMO4_TARGETS_UP
Systematic name | M4735
Organism | Homo sapiens
PMID | 17452977
Authors | Wang N,Lin KK,Lu Z,Lam KS,Newton R,Xu X,Yu Z,Gill GN,Andersen B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) engineered to conditionally express LMO4 [GeneID=8543] by a Tet Off system.
Full description | The nuclear LIM-only protein 4 (LMO4) is upregulated in breast cancer, especially estrogen receptor-negative tumors, and its overexpression in mice leads to hyperplasia and tumor formation. Here, we show that deletion of LMO4 in the mammary glands of mice leads to impaired lobuloalveolar development due to decreased epithelial cell proliferation. With the goal of discovering potential LMO4-target genes, we also developed a conditional expression system in MCF-7 cells for both LMO4 and a dominant negative (DN) form of its co-regulator, cofactor of LIM domains (Clim/Ldb/Nli). We then used DNA microarrays to identify genes responsive to LMO4 and DN-Clim upregulation. One of the genes common to both data sets was bone morphogenic protein 7 (BMP7), whose expression is also significantly correlated with LMO4 transcript levels in a large dataset of human breast cancers, suggesting that BMP7 is a bona fide target gene of LMO4 in breast cancer. Inhibition of BMP7 partially blocks the effects of LMO4 on apoptosis, indicating that BMP7 mediates at least some functions of LMO4. Gene transfer studies show that LMO4 regulates the BMP7 promoter, and chromatin immunoprecipitation studies show that LMO4 and its cofactor Clim2 are recruited to the BMP7 promoter. Furthermore, we demonstrate that HDAC2 recruitment to the BMP7 promoter is inhibited by upregulation of LMO4 and that HDAC2 knockdown upregulates the promoter. These studies suggest a novel mechanism of action for LMO4: LMO4, Clim2 and HDAC2 are part of a transcriptional complex, and increased LMO4 levels can disrupt the complex, leading to decreased HDAC2 recruitment and increased promoter activity.

Standard name | WANG_LMO4_TARGETS_DN
Systematic name | M12674
Organism | Homo sapiens
PMID | 17452977
Authors | Wang N,Lin KK,Lu Z,Lam KS,Newton R,Xu X,Yu Z,Gill GN,Andersen B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) engineered to conditionally express LMO4 [GeneID=8543] by a Tet Off system.
Full description | The nuclear LIM-only protein 4 (LMO4) is upregulated in breast cancer, especially estrogen receptor-negative tumors, and its overexpression in mice leads to hyperplasia and tumor formation. Here, we show that deletion of LMO4 in the mammary glands of mice leads to impaired lobuloalveolar development due to decreased epithelial cell proliferation. With the goal of discovering potential LMO4-target genes, we also developed a conditional expression system in MCF-7 cells for both LMO4 and a dominant negative (DN) form of its co-regulator, cofactor of LIM domains (Clim/Ldb/Nli). We then used DNA microarrays to identify genes responsive to LMO4 and DN-Clim upregulation. One of the genes common to both data sets was bone morphogenic protein 7 (BMP7), whose expression is also significantly correlated with LMO4 transcript levels in a large dataset of human breast cancers, suggesting that BMP7 is a bona fide target gene of LMO4 in breast cancer. Inhibition of BMP7 partially blocks the effects of LMO4 on apoptosis, indicating that BMP7 mediates at least some functions of LMO4. Gene transfer studies show that LMO4 regulates the BMP7 promoter, and chromatin immunoprecipitation studies show that LMO4 and its cofactor Clim2 are recruited to the BMP7 promoter. Furthermore, we demonstrate that HDAC2 recruitment to the BMP7 promoter is inhibited by upregulation of LMO4 and that HDAC2 knockdown upregulates the promoter. These studies suggest a novel mechanism of action for LMO4: LMO4, Clim2 and HDAC2 are part of a transcriptional complex, and increased LMO4 levels can disrupt the complex, leading to decreased HDAC2 recruitment and increased promoter activity.

Standard name | WANG_CLIM2_TARGETS_UP
Systematic name | M10334
Organism | Homo sapiens
PMID | 17452977
Authors | Wang N,Lin KK,Lu Z,Lam KS,Newton R,Xu X,Yu Z,Gill GN,Andersen B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) engineered to conditionally express a dominant negative form of CLIM2 [GeneID=8861] by a Tet Off system.
Full description | The nuclear LIM-only protein 4 (LMO4) is upregulated in breast cancer, especially estrogen receptor-negative tumors, and its overexpression in mice leads to hyperplasia and tumor formation. Here, we show that deletion of LMO4 in the mammary glands of mice leads to impaired lobuloalveolar development due to decreased epithelial cell proliferation. With the goal of discovering potential LMO4-target genes, we also developed a conditional expression system in MCF-7 cells for both LMO4 and a dominant negative (DN) form of its co-regulator, cofactor of LIM domains (Clim/Ldb/Nli). We then used DNA microarrays to identify genes responsive to LMO4 and DN-Clim upregulation. One of the genes common to both data sets was bone morphogenic protein 7 (BMP7), whose expression is also significantly correlated with LMO4 transcript levels in a large dataset of human breast cancers, suggesting that BMP7 is a bona fide target gene of LMO4 in breast cancer. Inhibition of BMP7 partially blocks the effects of LMO4 on apoptosis, indicating that BMP7 mediates at least some functions of LMO4. Gene transfer studies show that LMO4 regulates the BMP7 promoter, and chromatin immunoprecipitation studies show that LMO4 and its cofactor Clim2 are recruited to the BMP7 promoter. Furthermore, we demonstrate that HDAC2 recruitment to the BMP7 promoter is inhibited by upregulation of LMO4 and that HDAC2 knockdown upregulates the promoter. These studies suggest a novel mechanism of action for LMO4: LMO4, Clim2 and HDAC2 are part of a transcriptional complex, and increased LMO4 levels can disrupt the complex, leading to decreased HDAC2 recruitment and increased promoter activity.

Standard name | WANG_CLIM2_TARGETS_DN
Systematic name | M8577
Organism | Homo sapiens
PMID | 17452977
Authors | Wang N,Lin KK,Lu Z,Lam KS,Newton R,Xu X,Yu Z,Gill GN,Andersen B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) engineered to conditionally express a dominant negative form of CLIM2 [GeneID=8861] by a Tet Off system.
Full description | The nuclear LIM-only protein 4 (LMO4) is upregulated in breast cancer, especially estrogen receptor-negative tumors, and its overexpression in mice leads to hyperplasia and tumor formation. Here, we show that deletion of LMO4 in the mammary glands of mice leads to impaired lobuloalveolar development due to decreased epithelial cell proliferation. With the goal of discovering potential LMO4-target genes, we also developed a conditional expression system in MCF-7 cells for both LMO4 and a dominant negative (DN) form of its co-regulator, cofactor of LIM domains (Clim/Ldb/Nli). We then used DNA microarrays to identify genes responsive to LMO4 and DN-Clim upregulation. One of the genes common to both data sets was bone morphogenic protein 7 (BMP7), whose expression is also significantly correlated with LMO4 transcript levels in a large dataset of human breast cancers, suggesting that BMP7 is a bona fide target gene of LMO4 in breast cancer. Inhibition of BMP7 partially blocks the effects of LMO4 on apoptosis, indicating that BMP7 mediates at least some functions of LMO4. Gene transfer studies show that LMO4 regulates the BMP7 promoter, and chromatin immunoprecipitation studies show that LMO4 and its cofactor Clim2 are recruited to the BMP7 promoter. Furthermore, we demonstrate that HDAC2 recruitment to the BMP7 promoter is inhibited by upregulation of LMO4 and that HDAC2 knockdown upregulates the promoter. These studies suggest a novel mechanism of action for LMO4: LMO4, Clim2 and HDAC2 are part of a transcriptional complex, and increased LMO4 levels can disrupt the complex, leading to decreased HDAC2 recruitment and increased promoter activity.

Standard name | VECCHI_GASTRIC_CANCER_ADVANCED_VS_EARLY_UP
Systematic name | M17079
Organism | Homo sapiens
PMID | 17297478
Authors | Vecchi M,Nuciforo P,Romagnoli S,Confalonieri S,Pellegrini C,Serio G,Quarto M,Capra M,Roviaro GC,Contessini Avesani E,Corsi C,Coggi G,Di Fiore PP,Bosari S
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes distinguishing between two subtypes of gastric cancer: advanced (AGC) and early (EGC).
Full description | Gastric carcinoma is one of the major causes of cancer mortality worldwide. Early detection results in excellent prognosis for patients with early cancer (EGC), whereas the prognosis of advanced cancer (AGC) patients remains poor. It is not clear whether EGC and AGC are molecularly distinct, and whether they represent progressive stages of the same tumor or different entities ab initio. Gene expression profiles of EGC and AGC were determined by Affymetrix technology and quantitative polymerase chain reaction. Representative regulated genes were further analysed by in situ hybridization (ISH) on tissue microarrays. Expression analysis allowed the identification of a signature that differentiates AGC from EGC. In addition, comparison with normal gastric mucosa indicated that the majority of alterations associated with EGC are retained in AGC, and that further expression changes mark the transition from EGC to AGC. Finally, ISH analysis showed that representative genes, differentially expressed in the invasive areas of EGC and AGC, are not differentially expressed in the non-invasive areas of the same tumors. Our data are more directly compatible with a progression model of gastric carcinogenesis, whereby EGC and AGC may represent different molecular stages of the same tumor. Finally, the identification of an AGC-specific signature might help devising novel therapeutic strategies for advanced gastric cancer.

Standard name | VECCHI_GASTRIC_CANCER_ADVANCED_VS_EARLY_DN
Systematic name | M2108
Organism | Homo sapiens
PMID | 17297478
Authors | Vecchi M,Nuciforo P,Romagnoli S,Confalonieri S,Pellegrini C,Serio G,Quarto M,Capra M,Roviaro GC,Contessini Avesani E,Corsi C,Coggi G,Di Fiore PP,Bosari S
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes distinguishing between two subtypes of gastric cancer: advanced (AGC) and early (EGC).
Full description | Gastric carcinoma is one of the major causes of cancer mortality worldwide. Early detection results in excellent prognosis for patients with early cancer (EGC), whereas the prognosis of advanced cancer (AGC) patients remains poor. It is not clear whether EGC and AGC are molecularly distinct, and whether they represent progressive stages of the same tumor or different entities ab initio. Gene expression profiles of EGC and AGC were determined by Affymetrix technology and quantitative polymerase chain reaction. Representative regulated genes were further analysed by in situ hybridization (ISH) on tissue microarrays. Expression analysis allowed the identification of a signature that differentiates AGC from EGC. In addition, comparison with normal gastric mucosa indicated that the majority of alterations associated with EGC are retained in AGC, and that further expression changes mark the transition from EGC to AGC. Finally, ISH analysis showed that representative genes, differentially expressed in the invasive areas of EGC and AGC, are not differentially expressed in the non-invasive areas of the same tumors. Our data are more directly compatible with a progression model of gastric carcinogenesis, whereby EGC and AGC may represent different molecular stages of the same tumor. Finally, the identification of an AGC-specific signature might help devising novel therapeutic strategies for advanced gastric cancer.

Standard name | VECCHI_GASTRIC_CANCER_EARLY_UP
Systematic name | M18855
Organism | Homo sapiens
PMID | 17297478
Authors | Vecchi M,Nuciforo P,Romagnoli S,Confalonieri S,Pellegrini C,Serio G,Quarto M,Capra M,Roviaro GC,Contessini Avesani E,Corsi C,Coggi G,Di Fiore PP,Bosari S
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes distinguishing between early gastric cancer (EGC) and normal tissue samples.
Full description | Gastric carcinoma is one of the major causes of cancer mortality worldwide. Early detection results in excellent prognosis for patients with early cancer (EGC), whereas the prognosis of advanced cancer (AGC) patients remains poor. It is not clear whether EGC and AGC are molecularly distinct, and whether they represent progressive stages of the same tumor or different entities ab initio. Gene expression profiles of EGC and AGC were determined by Affymetrix technology and quantitative polymerase chain reaction. Representative regulated genes were further analysed by in situ hybridization (ISH) on tissue microarrays. Expression analysis allowed the identification of a signature that differentiates AGC from EGC. In addition, comparison with normal gastric mucosa indicated that the majority of alterations associated with EGC are retained in AGC, and that further expression changes mark the transition from EGC to AGC. Finally, ISH analysis showed that representative genes, differentially expressed in the invasive areas of EGC and AGC, are not differentially expressed in the non-invasive areas of the same tumors. Our data are more directly compatible with a progression model of gastric carcinogenesis, whereby EGC and AGC may represent different molecular stages of the same tumor. Finally, the identification of an AGC-specific signature might help devising novel therapeutic strategies for advanced gastric cancer.

Standard name | VECCHI_GASTRIC_CANCER_EARLY_DN
Systematic name | M15472
Organism | Homo sapiens
PMID | 17297478
Authors | Vecchi M,Nuciforo P,Romagnoli S,Confalonieri S,Pellegrini C,Serio G,Quarto M,Capra M,Roviaro GC,Contessini Avesani E,Corsi C,Coggi G,Di Fiore PP,Bosari S
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes distinguishing between early gastric cancer (EGC) and normal tissue samples.
Full description | Gastric carcinoma is one of the major causes of cancer mortality worldwide. Early detection results in excellent prognosis for patients with early cancer (EGC), whereas the prognosis of advanced cancer (AGC) patients remains poor. It is not clear whether EGC and AGC are molecularly distinct, and whether they represent progressive stages of the same tumor or different entities ab initio. Gene expression profiles of EGC and AGC were determined by Affymetrix technology and quantitative polymerase chain reaction. Representative regulated genes were further analysed by in situ hybridization (ISH) on tissue microarrays. Expression analysis allowed the identification of a signature that differentiates AGC from EGC. In addition, comparison with normal gastric mucosa indicated that the majority of alterations associated with EGC are retained in AGC, and that further expression changes mark the transition from EGC to AGC. Finally, ISH analysis showed that representative genes, differentially expressed in the invasive areas of EGC and AGC, are not differentially expressed in the non-invasive areas of the same tumors. Our data are more directly compatible with a progression model of gastric carcinogenesis, whereby EGC and AGC may represent different molecular stages of the same tumor. Finally, the identification of an AGC-specific signature might help devising novel therapeutic strategies for advanced gastric cancer.

Standard name | BARRIER_COLON_CANCER_RECURRENCE_UP
Systematic name | M9728
Organism | Homo sapiens
PMID | 17043639
Authors | Barrier A,Roser F,Boëlle PY,Franc B,Tse C,Brault D,Lacaine F,Houry S,Callard P,Penna C,Debuire B,Flahault A,Dudoit S,Lemoine A
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the 70-gene prognosis predictor for stage 2 colon cancer, based on non-neoplastic mucosa gene expression profiles.
Full description | We have assessed the possibility to build a prognosis predictor (PP), based on non-neoplastic mucosa microarray gene expression measures, for stage II colon cancer patients. Non-neoplastic colonic mucosa mRNA samples from 24 patients (10 with a metachronous metastasis, 14 with no recurrence) were profiled using the Affymetrix HGU133A GeneChip. Patients were repeatedly and randomly divided into 1000 training sets (TSs) of size 16 and validation sets (VS) of size 8. For each TS/VS split, a 70-gene PP, identified on the TS by selecting the 70 most differentially expressed genes and applying diagonal linear discriminant analysis, was used to predict the prognoses of VS patients. Mean prognosis prediction performances of the 70-gene PP were 81.8% for accuracy, 73.0% for sensitivity and 87.1% for specificity. Informative genes suggested branching signal-transduction pathways with possible extensive networks between individual pathways. They also included genes coding for proteins involved in immune surveillance. In conclusion, our study suggests that one can build an accurate PP for stage II colon cancer patients, based on non-neoplastic mucosa microarray gene expression measures.

Standard name | BARRIER_COLON_CANCER_RECURRENCE_DN
Systematic name | M5736
Organism | Homo sapiens
PMID | 17043639
Authors | Barrier A,Roser F,Boëlle PY,Franc B,Tse C,Brault D,Lacaine F,Houry S,Callard P,Penna C,Debuire B,Flahault A,Dudoit S,Lemoine A
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the 70-gene prognosis predictor for stage 2 colon cancer, based on non-neoplastic mucosa gene expression profiles.
Full description | We have assessed the possibility to build a prognosis predictor (PP), based on non-neoplastic mucosa microarray gene expression measures, for stage II colon cancer patients. Non-neoplastic colonic mucosa mRNA samples from 24 patients (10 with a metachronous metastasis, 14 with no recurrence) were profiled using the Affymetrix HGU133A GeneChip. Patients were repeatedly and randomly divided into 1000 training sets (TSs) of size 16 and validation sets (VS) of size 8. For each TS/VS split, a 70-gene PP, identified on the TS by selecting the 70 most differentially expressed genes and applying diagonal linear discriminant analysis, was used to predict the prognoses of VS patients. Mean prognosis prediction performances of the 70-gene PP were 81.8% for accuracy, 73.0% for sensitivity and 87.1% for specificity. Informative genes suggested branching signal-transduction pathways with possible extensive networks between individual pathways. They also included genes coding for proteins involved in immune surveillance. In conclusion, our study suggests that one can build an accurate PP for stage II colon cancer patients, based on non-neoplastic mucosa microarray gene expression measures.

Standard name | SMIRNOV_CIRCULATING_ENDOTHELIOCYTES_IN_CANCER_UP
Systematic name | M986
Organism | Homo sapiens
PMID | 16540638
Authors | Smirnov DA,Foulk BW,Doyle GV,Connelly MC,Terstappen LW,O'Hara SM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in circulating endothelial cells (CEC) from cancer patients compared to those from healthy donors.
Full description | Increased numbers of endothelial cells are observed in peripheral blood of cancer patients. These circulating endothelial cells (CECs) may contribute to the formation of blood vessels in the tumor or reflect vascular damage caused by treatment or tumor growth. Characterization of these cells may aid in the understanding of the angiogenic process and may provide biomarkers for treatment efficacy of angiogenesis inhibitors. To identify markers typical for CECs in cancer patients, we assessed global gene expression profiles of CD146 immunomagnetically enriched CECs from healthy donors and patients with metastatic breast, colorectal, prostate, lung, and renal cancer. From the generated gene profiles, a list of 61 marker genes for CEC detection was generated, and their expression was measured by real-time quantitative PCR in blood samples from 81 metastatic cancer patients and 55 healthy donors that were immunomagnetically enriched for CECs. A set of 34 genes, among which novel CEC-associated genes, such as THBD, BST1, TIE1, POSTN1, SELE, SORT1, and DTR, were identified that were expressed at higher levels in cancer patients compared with healthy donors. Expression of the VWF, DTR, CDH5, TIE, and IGFBP7 genes were found to discriminate between cancer patients and healthy donors with a receiver operating characteristic curve accuracy of 0.93. Assessment of the expression of these genes may provide biomarkers to evaluate treatment efficacy.

Standard name | SMIRNOV_CIRCULATING_ENDOTHELIOCYTES_IN_CANCER_DN
Systematic name | M15967
Organism | Homo sapiens
PMID | 16540638
Authors | Smirnov DA,Foulk BW,Doyle GV,Connelly MC,Terstappen LW,O'Hara SM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in circulating endothelial cells (CEC) from cancer patients compared to those from healthy donors.
Full description | Increased numbers of endothelial cells are observed in peripheral blood of cancer patients. These circulating endothelial cells (CECs) may contribute to the formation of blood vessels in the tumor or reflect vascular damage caused by treatment or tumor growth. Characterization of these cells may aid in the understanding of the angiogenic process and may provide biomarkers for treatment efficacy of angiogenesis inhibitors. To identify markers typical for CECs in cancer patients, we assessed global gene expression profiles of CD146 immunomagnetically enriched CECs from healthy donors and patients with metastatic breast, colorectal, prostate, lung, and renal cancer. From the generated gene profiles, a list of 61 marker genes for CEC detection was generated, and their expression was measured by real-time quantitative PCR in blood samples from 81 metastatic cancer patients and 55 healthy donors that were immunomagnetically enriched for CECs. A set of 34 genes, among which novel CEC-associated genes, such as THBD, BST1, TIE1, POSTN1, SELE, SORT1, and DTR, were identified that were expressed at higher levels in cancer patients compared with healthy donors. Expression of the VWF, DTR, CDH5, TIE, and IGFBP7 genes were found to discriminate between cancer patients and healthy donors with a receiver operating characteristic curve accuracy of 0.93. Assessment of the expression of these genes may provide biomarkers to evaluate treatment efficacy.

Standard name | SLEBOS_HEAD_AND_NECK_CANCER_WITH_HPV_UP
Systematic name | M14132
Organism | Homo sapiens
PMID | 16467079
Authors | Slebos RJ,Yi Y,Ely K,Carter J,Evjen A,Zhang X,Shyr Y,Murphy BM,Cmelak AJ,Burkey BB,Netterville JL,Levy S,Yarbrough WG,Chung CH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in head and neck squamous cell carcinoma (HNSCC) samples positive for HPV compared to the HPV-negative tumors.
Full description | Human papillomavirus (HPV) is associated with a subset of head and neck squamous cell carcinoma (HNSCC). Between 15% and 35% of HNSCCs harbor HPV DNA. Demographic and exposure differences between HPV-positive (HPV+) and negative (HPV-) HNSCCs suggest that HPV+ tumors may constitute a subclass with different biology, whereas clinical differences have also been observed. Gene expression profiles of HPV+ and HPV- tumors were compared with further exploration of the biological effect of HPV in HNSCC. Thirty-six HNSCC tumors were analyzed using Affymetrix Human 133U Plus 2.0 GeneChip and for HPV by PCR and real-time PCR. Eight of 36 (22%) tumors were positive for HPV subtype 16. Statistical analysis using Significance Analysis of Microarrays based on HPV status as a supervising variable resulted in a list of 91 genes that were differentially expressed with statistical significance. Results for a subset of these genes were verified by real-time PCR. Genes highly expressed in HPV+ samples included cell cycle regulators (p16(INK4A), p18, and CDC7) and transcription factors (TAF7L, RFC4, RPA2, and TFDP2). The microarray data were also investigated by mapping genes by chromosomal location (DIGMAP). A large number of genes on chromosome 3q24-qter had high levels of expression in HPV+ tumors. Further investigation of differentially expressed genes may reveal the unique pathways in HPV+ tumors that may explain the different natural history and biological properties of these tumors. These properties may be exploited as a target of novel therapeutic agents in HNSCC treatment.

Standard name | JAEGER_METASTASIS_UP
Systematic name | M5740
Organism | Homo sapiens
PMID | 17289871
Authors | Jaeger J,Koczan D,Thiesen HJ,Ibrahim SM,Gross G,Spang R,Kunz M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in metastases from malignant melanoma compared to the primary tumors.
Full description | PURPOSE: To better understand the molecular mechanisms of malignant melanoma progression and metastasis, gene expression profiling was done of primary melanomas and melanoma metastases. EXPERIMENTAL DESIGN: Tumor cell-specific gene expression in 19 primary melanomas and 22 melanoma metastases was analyzed using oligonucleotide microarrays after laser-capture microdissection of melanoma cells. Statistical analysis was done by random permutation analysis and support vector machines. Microarray data were further validated by immunohistochemistry and immunoblotting. RESULTS: Overall, 308 genes were identified that showed significant differential expression between primary melanomas and melanoma metastases (false discovery rate<or=0.05). Significantly overrepresented gene ontology categories in the list of 308 genes were cell cycle regulation, mitosis, cell communication, and cell adhesion. Overall, 47 genes showed up-regulation in metastases. These included Cdc6, Cdk1, septin 6, mitosin, kinesin family member 2C, osteopontin, and fibronectin. Down-regulated genes included E-cadherin, fibroblast growth factor binding protein, and desmocollin 1 and desmocollin 3, stratifin/14-3-3sigma, and the chemokine CCL27. Using support vector machine analysis of gene expression data, a performance of >85% correct classifications for primary melanomas and metastases was reached. Further analysis showed that subtypes of primary melanomas displayed characteristic gene expression patterns, as do thin tumors (<or=1.0 mm Breslow thickness) compared with intermediate and thick tumors (>2.0 mm Breslow thickness). CONCLUSIONS: Taken together, this large-scale gene expression study of malignant melanoma identified molecular signatures related to metastasis, melanoma subtypes, and tumor thickness. These findings not only provide deeper insights into the pathogenesis of melanoma progression but may also guide future research on innovative treatments.

Standard name | JAEGER_METASTASIS_DN
Systematic name | M10702
Organism | Homo sapiens
PMID | 17289871
Authors | Jaeger J,Koczan D,Thiesen HJ,Ibrahim SM,Gross G,Spang R,Kunz M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in metastases from malignant melanoma compared to the primary tumors.
Full description | PURPOSE: To better understand the molecular mechanisms of malignant melanoma progression and metastasis, gene expression profiling was done of primary melanomas and melanoma metastases. EXPERIMENTAL DESIGN: Tumor cell-specific gene expression in 19 primary melanomas and 22 melanoma metastases was analyzed using oligonucleotide microarrays after laser-capture microdissection of melanoma cells. Statistical analysis was done by random permutation analysis and support vector machines. Microarray data were further validated by immunohistochemistry and immunoblotting. RESULTS: Overall, 308 genes were identified that showed significant differential expression between primary melanomas and melanoma metastases (false discovery rate<or=0.05). Significantly overrepresented gene ontology categories in the list of 308 genes were cell cycle regulation, mitosis, cell communication, and cell adhesion. Overall, 47 genes showed up-regulation in metastases. These included Cdc6, Cdk1, septin 6, mitosin, kinesin family member 2C, osteopontin, and fibronectin. Down-regulated genes included E-cadherin, fibroblast growth factor binding protein, and desmocollin 1 and desmocollin 3, stratifin/14-3-3sigma, and the chemokine CCL27. Using support vector machine analysis of gene expression data, a performance of >85% correct classifications for primary melanomas and metastases was reached. Further analysis showed that subtypes of primary melanomas displayed characteristic gene expression patterns, as do thin tumors (<or=1.0 mm Breslow thickness) compared with intermediate and thick tumors (>2.0 mm Breslow thickness). CONCLUSIONS: Taken together, this large-scale gene expression study of malignant melanoma identified molecular signatures related to metastasis, melanoma subtypes, and tumor thickness. These findings not only provide deeper insights into the pathogenesis of melanoma progression but may also guide future research on innovative treatments.

Standard name | OSMAN_BLADDER_CANCER_UP
Systematic name | M5275
Organism | Homo sapiens
PMID | 16740760
Authors | Osman I,Bajorin DF,Sun TT,Zhong H,Douglas D,Scattergood J,Zheng R,Han M,Marshall KW,Liew CC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in blood samples from bladder cancer patients.
Full description | PURPOSE: Recent data indicate that cDNA microarray gene expression profile of blood cells can reflect disease states and thus have diagnostic value. We tested the hypothesis that blood cell gene expression can differentiate between bladder cancer and other genitourinary cancers as well as between bladder cancer and healthy controls. EXPERIMENTAL DESIGN: We used Affymetrix U133 Plus 2.0 GeneChip (Affymetrix, Santa Clara, CA) to profile circulating blood total RNA from 35 patients diagnosed with one of three types of genitourinary cancer [bladder cancer (n = 16), testicular cancer (n = 10), and renal cell carcinoma (n = 9)] and compared their cDNA profiles with those of 10 healthy subjects. We then verified the expression levels of selected genes from the Affymetrix results in a larger number of bladder cancer patients (n = 40) and healthy controls (n = 27). RESULTS: Blood gene expression profiles distinguished bladder cancer patients from healthy controls and from testicular and renal cancer patients. Differential expression of a combined set of seven gene transcripts (insulin-like growth factor-binding protein 7, sorting nexin 16, chondroitin sulfate proteoglycan 6, and cathepsin D, chromodomain helicase DNA-binding protein 2, nell-like 2, and tumor necrosis factor receptor superfamily member 7) was able to discriminate bladder cancer from control samples with a sensitivity of 83% (95% confidence interval, 67-93%) and a specificity of 93% (95% confidence interval, 76-99%). CONCLUSION: We have shown that the gene expression profile of circulating blood cells can distinguish bladder cancer from other types of genitourinary cancer and healthy controls and can be used to identify novel blood markers for bladder cancer.

Standard name | OSMAN_BLADDER_CANCER_DN
Systematic name | M16858
Organism | Homo sapiens
PMID | 16740760
Authors | Osman I,Bajorin DF,Sun TT,Zhong H,Douglas D,Scattergood J,Zheng R,Han M,Marshall KW,Liew CC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in blood samples from bladder cancer patients.
Full description | PURPOSE: Recent data indicate that cDNA microarray gene expression profile of blood cells can reflect disease states and thus have diagnostic value. We tested the hypothesis that blood cell gene expression can differentiate between bladder cancer and other genitourinary cancers as well as between bladder cancer and healthy controls. EXPERIMENTAL DESIGN: We used Affymetrix U133 Plus 2.0 GeneChip (Affymetrix, Santa Clara, CA) to profile circulating blood total RNA from 35 patients diagnosed with one of three types of genitourinary cancer [bladder cancer (n = 16), testicular cancer (n = 10), and renal cell carcinoma (n = 9)] and compared their cDNA profiles with those of 10 healthy subjects. We then verified the expression levels of selected genes from the Affymetrix results in a larger number of bladder cancer patients (n = 40) and healthy controls (n = 27). RESULTS: Blood gene expression profiles distinguished bladder cancer patients from healthy controls and from testicular and renal cancer patients. Differential expression of a combined set of seven gene transcripts (insulin-like growth factor-binding protein 7, sorting nexin 16, chondroitin sulfate proteoglycan 6, and cathepsin D, chromodomain helicase DNA-binding protein 2, nell-like 2, and tumor necrosis factor receptor superfamily member 7) was able to discriminate bladder cancer from control samples with a sensitivity of 83% (95% confidence interval, 67-93%) and a specificity of 93% (95% confidence interval, 76-99%). CONCLUSION: We have shown that the gene expression profile of circulating blood cells can distinguish bladder cancer from other types of genitourinary cancer and healthy controls and can be used to identify novel blood markers for bladder cancer.

Standard name | GINESTIER_BREAST_CANCER_ZNF217_AMPLIFIED_UP
Systematic name | M5827
Organism | Homo sapiens
PMID | 16899599
Authors | Ginestier C,Cervera N,Finetti P,Esteyries S,Esterni B,Adélaïde J,Xerri L,Viens P,Jacquemier J,Charafe-Jauffret E,Chaffanet M,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in non-metastatic breast cancer tumors having type 1 amplification in the 20q13 region; involves ZNF217 [GeneID=7764] locus only.
Full description | PURPOSE: Amplification of chromosomal region 20q13 occurs in breast cancer but remains poorly characterized. EXPERIMENTAL DESIGN: To establish the frequency of 20q13 amplification and select the amplified cases to be studied, we used fluorescence in situ hybridization of bacterial artificial chromosome probes for three 20q13 loci (MYBL2, STK6, ZNF217) on sections of tissue microarrays containing 466 primary carcinoma samples. We used Affymetryx whole-genome DNA microarrays to establish the gene expression profiles of 20q13-amplified tumors and quantitative reverse transcription-PCR to validate the results. RESULTS: We found 36 (8%) 20q13-amplified samples. They were distributed in two types: type 1 tumors showed ZNF217 amplification only, whereas type 2 tumors showed amplification at two or three loci. Examination of the histoclinical features of the amplified tumors showed two strikingly opposite data. First, type 1 tumors were more frequently lymph node-negative tumors but were paradoxically associated with a poor prognosis. Second, type 2 tumors were more frequently lymph node-positive tumors but were paradoxically associated with a good prognosis. Type 1 and type 2 showed different gene expression profiles. No 20q13 gene could be associated with type 1 amplification, whereas several 20q13 genes were overexpressed in type 2 tumors. CONCLUSIONS: Our results suggest that amplified tumors of types 1 and 2 are two distinct entities resulting from two different mechanisms and associated to different prognosis.

Standard name | GINESTIER_BREAST_CANCER_ZNF217_AMPLIFIED_DN
Systematic name | M17094
Organism | Homo sapiens
PMID | 16899599
Authors | Ginestier C,Cervera N,Finetti P,Esteyries S,Esterni B,Adélaïde J,Xerri L,Viens P,Jacquemier J,Charafe-Jauffret E,Chaffanet M,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in non-metastatic breast cancer tumors having type 1 amplification in the 20q13 region; involves ZNF217 [GeneID=7764] locus only.
Full description | PURPOSE: Amplification of chromosomal region 20q13 occurs in breast cancer but remains poorly characterized. EXPERIMENTAL DESIGN: To establish the frequency of 20q13 amplification and select the amplified cases to be studied, we used fluorescence in situ hybridization of bacterial artificial chromosome probes for three 20q13 loci (MYBL2, STK6, ZNF217) on sections of tissue microarrays containing 466 primary carcinoma samples. We used Affymetryx whole-genome DNA microarrays to establish the gene expression profiles of 20q13-amplified tumors and quantitative reverse transcription-PCR to validate the results. RESULTS: We found 36 (8%) 20q13-amplified samples. They were distributed in two types: type 1 tumors showed ZNF217 amplification only, whereas type 2 tumors showed amplification at two or three loci. Examination of the histoclinical features of the amplified tumors showed two strikingly opposite data. First, type 1 tumors were more frequently lymph node-negative tumors but were paradoxically associated with a poor prognosis. Second, type 2 tumors were more frequently lymph node-positive tumors but were paradoxically associated with a good prognosis. Type 1 and type 2 showed different gene expression profiles. No 20q13 gene could be associated with type 1 amplification, whereas several 20q13 genes were overexpressed in type 2 tumors. CONCLUSIONS: Our results suggest that amplified tumors of types 1 and 2 are two distinct entities resulting from two different mechanisms and associated to different prognosis.

Standard name | GINESTIER_BREAST_CANCER_20Q13_AMPLIFICATION_UP
Systematic name | M19076
Organism | Homo sapiens
PMID | 16899599
Authors | Ginestier C,Cervera N,Finetti P,Esteyries S,Esterni B,Adélaïde J,Xerri L,Viens P,Jacquemier J,Charafe-Jauffret E,Chaffanet M,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in metastatic breast cancer tumors having type 2 amplification in the 20q13 region; involves MYBL2, STK6 and ZNF217 [GeneID=4605;6790;7764]
Full description | PURPOSE: Amplification of chromosomal region 20q13 occurs in breast cancer but remains poorly characterized. EXPERIMENTAL DESIGN: To establish the frequency of 20q13 amplification and select the amplified cases to be studied, we used fluorescence in situ hybridization of bacterial artificial chromosome probes for three 20q13 loci (MYBL2, STK6, ZNF217) on sections of tissue microarrays containing 466 primary carcinoma samples. We used Affymetryx whole-genome DNA microarrays to establish the gene expression profiles of 20q13-amplified tumors and quantitative reverse transcription-PCR to validate the results. RESULTS: We found 36 (8%) 20q13-amplified samples. They were distributed in two types: type 1 tumors showed ZNF217 amplification only, whereas type 2 tumors showed amplification at two or three loci. Examination of the histoclinical features of the amplified tumors showed two strikingly opposite data. First, type 1 tumors were more frequently lymph node-negative tumors but were paradoxically associated with a poor prognosis. Second, type 2 tumors were more frequently lymph node-positive tumors but were paradoxically associated with a good prognosis. Type 1 and type 2 showed different gene expression profiles. No 20q13 gene could be associated with type 1 amplification, whereas several 20q13 genes were overexpressed in type 2 tumors. CONCLUSIONS: Our results suggest that amplified tumors of types 1 and 2 are two distinct entities resulting from two different mechanisms and associated to different prognosis.

Standard name | GINESTIER_BREAST_CANCER_20Q13_AMPLIFICATION_DN
Systematic name | M19988
Organism | Homo sapiens
PMID | 16899599
Authors | Ginestier C,Cervera N,Finetti P,Esteyries S,Esterni B,Adélaïde J,Xerri L,Viens P,Jacquemier J,Charafe-Jauffret E,Chaffanet M,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in metastatic breast cancer tumors having type 2 amplification in the 20q13 region; involves MYBL2, STK6 and ZNF217 [GeneID=4605;6790;7764]
Full description | PURPOSE: Amplification of chromosomal region 20q13 occurs in breast cancer but remains poorly characterized. EXPERIMENTAL DESIGN: To establish the frequency of 20q13 amplification and select the amplified cases to be studied, we used fluorescence in situ hybridization of bacterial artificial chromosome probes for three 20q13 loci (MYBL2, STK6, ZNF217) on sections of tissue microarrays containing 466 primary carcinoma samples. We used Affymetryx whole-genome DNA microarrays to establish the gene expression profiles of 20q13-amplified tumors and quantitative reverse transcription-PCR to validate the results. RESULTS: We found 36 (8%) 20q13-amplified samples. They were distributed in two types: type 1 tumors showed ZNF217 amplification only, whereas type 2 tumors showed amplification at two or three loci. Examination of the histoclinical features of the amplified tumors showed two strikingly opposite data. First, type 1 tumors were more frequently lymph node-negative tumors but were paradoxically associated with a poor prognosis. Second, type 2 tumors were more frequently lymph node-positive tumors but were paradoxically associated with a good prognosis. Type 1 and type 2 showed different gene expression profiles. No 20q13 gene could be associated with type 1 amplification, whereas several 20q13 genes were overexpressed in type 2 tumors. CONCLUSIONS: Our results suggest that amplified tumors of types 1 and 2 are two distinct entities resulting from two different mechanisms and associated to different prognosis.

Standard name | OSWALD_HEMATOPOIETIC_STEM_CELL_IN_COLLAGEN_GEL_UP
Systematic name | M12383
Organism | Homo sapiens
PMID | 16166251
Authors | Oswald J,Steudel C,Salchert K,Joergensen B,Thiede C,Ehninger G,Werner C,Bornhäuser M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hematopoietic stem cells (HSC, CD34+ [GeneID=947]) cultured in a three-dimentional collagen gel compared to the cells grown in suspension.
Full description | CD34+ hematopoietic stem/progenitor cells (HSCs) reside in the bone marrow in close proximity to the endosteal bone surface, surrounded by osteoblasts, stromal cells, and various extracellular matrix molecules. We used a bioartificial matrix of fibrillar collagen I, the major matrix component of bone, as a scaffold for ex vivo expansion of HSCs. CD34+ HSCs were isolated from umbilical cord blood and cultivated within reconstituted collagen I fibrils in the presence of fms-like tyrosine kinase-3 ligand, stem cell factor, and interleukin (IL)-3. After 7 days of culture, the cell number, number of colony-forming units (CFU-C), and gene-expression profile of the cultured cells were assessed. Although the total expansion factor of CD34+ cells was slightly lower when cells were cultivated in the collagen I gel, the frequency of CFU-C was greater than in control suspension cultures. Gene-expression analysis with microarray chip technology revealed the upregulation of more than 50 genes in the presence of collagen I. Among these, genes for several growth factors, cytokines, and chemokines (e.g., IL-8 and macrophage inhibitory protein 1alpha) could be confirmed using quantitative polymerase chain reaction. Furthermore, greater expression levels of the negative cell-cycle regulator BTG2/TIS21 and an inhibitor of the mitogen-activated protein kinase pathway, DUSP2, underline the regulatory role of the extracellular matrix. Together, these data show that the expansion of CD34+ cord blood cells in a culture system containing a three-dimensional collagen I matrix induces a qualitative change in the gene-expression profile of cultivated HSCs.

Standard name | OSWALD_HEMATOPOIETIC_STEM_CELL_IN_COLLAGEN_GEL_DN
Systematic name | M7089
Organism | Homo sapiens
PMID | 16166251
Authors | Oswald J,Steudel C,Salchert K,Joergensen B,Thiede C,Ehninger G,Werner C,Bornhäuser M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hematopoietic stem cells (HSC, CD34+ [GeneID=947]) cultured in a three-dimentional collagen gel compared to the cells grown in suspension.
Full description | CD34+ hematopoietic stem/progenitor cells (HSCs) reside in the bone marrow in close proximity to the endosteal bone surface, surrounded by osteoblasts, stromal cells, and various extracellular matrix molecules. We used a bioartificial matrix of fibrillar collagen I, the major matrix component of bone, as a scaffold for ex vivo expansion of HSCs. CD34+ HSCs were isolated from umbilical cord blood and cultivated within reconstituted collagen I fibrils in the presence of fms-like tyrosine kinase-3 ligand, stem cell factor, and interleukin (IL)-3. After 7 days of culture, the cell number, number of colony-forming units (CFU-C), and gene-expression profile of the cultured cells were assessed. Although the total expansion factor of CD34+ cells was slightly lower when cells were cultivated in the collagen I gel, the frequency of CFU-C was greater than in control suspension cultures. Gene-expression analysis with microarray chip technology revealed the upregulation of more than 50 genes in the presence of collagen I. Among these, genes for several growth factors, cytokines, and chemokines (e.g., IL-8 and macrophage inhibitory protein 1alpha) could be confirmed using quantitative polymerase chain reaction. Furthermore, greater expression levels of the negative cell-cycle regulator BTG2/TIS21 and an inhibitor of the mitogen-activated protein kinase pathway, DUSP2, underline the regulatory role of the extracellular matrix. Together, these data show that the expansion of CD34+ cord blood cells in a culture system containing a three-dimensional collagen I matrix induces a qualitative change in the gene-expression profile of cultivated HSCs.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_YELLOW_UP
Systematic name | M1930
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the yellow module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_YELLOW_DN
Systematic name | M10172
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the yellow module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_TURQUOISE_UP
Systematic name | M15537
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the turquoise module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_TURQUOISE_DN
Systematic name | M19590
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the turquoise module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_RED_UP
Systematic name | M4035
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the red module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_RED_DN
Systematic name | M18008
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the red module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_MAGENTA_UP
Systematic name | M2422
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the magenta module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_MAGENTA_DN
Systematic name | M168
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the magenta module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_LIGHTYELLOW_UP
Systematic name | M19724
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the lightyellow module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_GREEN_UP
Systematic name | M5968
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the green module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_GREEN_DN
Systematic name | M19520
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the green module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_BLUE_UP
Systematic name | M11672
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the blue module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_BLUE_DN
Systematic name | M12517
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the blue module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_BLACK_UP
Systematic name | M2231
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the black module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_BLACK_DN
Systematic name | M4397
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the black module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_GREY_UP
Systematic name | M19133
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the grey module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_GREY_DN
Systematic name | M8565
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the grey module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | RUNNE_GENDER_EFFECT_UP
Systematic name | M17072
Organism | Homo sapiens
PMID | 17724341
Authors | Runne H,Kuhn A,Wild EJ,Pratyaksha W,Kristiansen M,Isaacs JD,Régulier E,Delorenzi M,Tabrizi SJ,Luthi-Carter R
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes detecting gender effects in global expression profiling studies.
Full description | Highly quantitative biomarkers of neurodegenerative disease remain an important need in the urgent quest for disease-modifying therapies. For Huntington's disease (HD), a genetic test is available (trait marker), but necessary state markers are still in development. In this report, we describe a large battery of transcriptomic tests explored as state biomarker candidates. In an attempt to exploit the known neuroinflammatory and transcriptional perturbations of disease, we measured relevant mRNAs in peripheral blood cells. The performance of these potential markers was weak overall, with only one mRNA, immediate early response 3 (IER3), showing a modest but significant increase of 32% in HD samples compared with controls. No statistically significant differences were found for any other mRNAs tested, including a panel of 12 RNA biomarkers identified in a previous report [Borovecki F, Lovrecic L, Zhou J, Jeong H, Then F, Rosas HD, Hersch SM, Hogarth P, Bouzou B, Jensen RV, et al. (2005) Proc Natl Acad Sci USA 102:11023-11028]. The present results may nonetheless inform the future design and testing of HD biomarker strategies.

Standard name | TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_6HR_UP
Systematic name | M18559
Organism | Homo sapiens
PMID | 16818636
Authors | Takeda A,Goolsby C,Yaseen NR
Category | C2
Sub-category | CGP
Brief description | Genes up-rgulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 6h.
Full description | NUP98-HOXA9, the chimeric protein resulting from the t(7;11)(p15;p15) chromosomal translocation, is a prototype of several NUP98 fusions that occur in myelodysplastic syndromes and acute myeloid leukemia. We examined its effect on differentiation, proliferation, and gene expression in primary human CD34+ hematopoietic cells. Colony-forming cell (CFC) assays in semisolid medium combined with morphologic examination and flow cytometric immunophenotyping revealed that NUP98-HOXA9 increased the numbers of erythroid precursors and impaired both myeloid and erythroid differentiation. In continuous liquid culture, cells transduced with NUP98-HOXA9 exhibited a biphasic growth curve with initial growth inhibition followed by enhanced long-term proliferation, suggesting an increase in the numbers of primitive self-renewing cells. This was confirmed by a dramatic increase in the numbers of long-term culture-initiating cells, the most primitive hematopoietic cells detectable in vitro. To understand the molecular mechanisms underlying the effects of NUP98-HOXA9 on hematopoietic cell proliferation and differentiation, oligonucleotide microarray analysis was done at several time points over 16 days, starting at 6 hours posttransduction. The early growth suppression was preceded by up-regulation of IFNbeta1 and accompanied by marked up-regulation of IFN-induced genes, peaking at 3 days posttransduction. In contrast, oncogenes such as homeobox transcription factors, FLT3, KIT, and WT1 peaked at 8 days or beyond, coinciding with increased proliferation. In addition, several putative tumor suppressors and genes associated with hematopoietic differentiation were repressed at later time points. These findings provide a comprehensive picture of the changes in proliferation, differentiation, and global gene expression that underlie the leukemic transformation of human hematopoietic cells by NUP98-HOXA9.

Standard name | TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_6HR_DN
Systematic name | M10084
Organism | Homo sapiens
PMID | 16818636
Authors | Takeda A,Goolsby C,Yaseen NR
Category | C2
Sub-category | CGP
Brief description | Genes down-rgulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 6h.
Full description | NUP98-HOXA9, the chimeric protein resulting from the t(7;11)(p15;p15) chromosomal translocation, is a prototype of several NUP98 fusions that occur in myelodysplastic syndromes and acute myeloid leukemia. We examined its effect on differentiation, proliferation, and gene expression in primary human CD34+ hematopoietic cells. Colony-forming cell (CFC) assays in semisolid medium combined with morphologic examination and flow cytometric immunophenotyping revealed that NUP98-HOXA9 increased the numbers of erythroid precursors and impaired both myeloid and erythroid differentiation. In continuous liquid culture, cells transduced with NUP98-HOXA9 exhibited a biphasic growth curve with initial growth inhibition followed by enhanced long-term proliferation, suggesting an increase in the numbers of primitive self-renewing cells. This was confirmed by a dramatic increase in the numbers of long-term culture-initiating cells, the most primitive hematopoietic cells detectable in vitro. To understand the molecular mechanisms underlying the effects of NUP98-HOXA9 on hematopoietic cell proliferation and differentiation, oligonucleotide microarray analysis was done at several time points over 16 days, starting at 6 hours posttransduction. The early growth suppression was preceded by up-regulation of IFNbeta1 and accompanied by marked up-regulation of IFN-induced genes, peaking at 3 days posttransduction. In contrast, oncogenes such as homeobox transcription factors, FLT3, KIT, and WT1 peaked at 8 days or beyond, coinciding with increased proliferation. In addition, several putative tumor suppressors and genes associated with hematopoietic differentiation were repressed at later time points. These findings provide a comprehensive picture of the changes in proliferation, differentiation, and global gene expression that underlie the leukemic transformation of human hematopoietic cells by NUP98-HOXA9.

Standard name | TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_3D_UP
Systematic name | M6670
Organism | Homo sapiens
PMID | 16818636
Authors | Takeda A,Goolsby C,Yaseen NR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 3 days after transduction.
Full description | NUP98-HOXA9, the chimeric protein resulting from the t(7;11)(p15;p15) chromosomal translocation, is a prototype of several NUP98 fusions that occur in myelodysplastic syndromes and acute myeloid leukemia. We examined its effect on differentiation, proliferation, and gene expression in primary human CD34+ hematopoietic cells. Colony-forming cell (CFC) assays in semisolid medium combined with morphologic examination and flow cytometric immunophenotyping revealed that NUP98-HOXA9 increased the numbers of erythroid precursors and impaired both myeloid and erythroid differentiation. In continuous liquid culture, cells transduced with NUP98-HOXA9 exhibited a biphasic growth curve with initial growth inhibition followed by enhanced long-term proliferation, suggesting an increase in the numbers of primitive self-renewing cells. This was confirmed by a dramatic increase in the numbers of long-term culture-initiating cells, the most primitive hematopoietic cells detectable in vitro. To understand the molecular mechanisms underlying the effects of NUP98-HOXA9 on hematopoietic cell proliferation and differentiation, oligonucleotide microarray analysis was done at several time points over 16 days, starting at 6 hours posttransduction. The early growth suppression was preceded by up-regulation of IFNbeta1 and accompanied by marked up-regulation of IFN-induced genes, peaking at 3 days posttransduction. In contrast, oncogenes such as homeobox transcription factors, FLT3, KIT, and WT1 peaked at 8 days or beyond, coinciding with increased proliferation. In addition, several putative tumor suppressors and genes associated with hematopoietic differentiation were repressed at later time points. These findings provide a comprehensive picture of the changes in proliferation, differentiation, and global gene expression that underlie the leukemic transformation of human hematopoietic cells by NUP98-HOXA9.

Standard name | TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_3D_DN
Systematic name | M3210
Organism | Homo sapiens
PMID | 16818636
Authors | Takeda A,Goolsby C,Yaseen NR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 3 days after transduction.
Full description | NUP98-HOXA9, the chimeric protein resulting from the t(7;11)(p15;p15) chromosomal translocation, is a prototype of several NUP98 fusions that occur in myelodysplastic syndromes and acute myeloid leukemia. We examined its effect on differentiation, proliferation, and gene expression in primary human CD34+ hematopoietic cells. Colony-forming cell (CFC) assays in semisolid medium combined with morphologic examination and flow cytometric immunophenotyping revealed that NUP98-HOXA9 increased the numbers of erythroid precursors and impaired both myeloid and erythroid differentiation. In continuous liquid culture, cells transduced with NUP98-HOXA9 exhibited a biphasic growth curve with initial growth inhibition followed by enhanced long-term proliferation, suggesting an increase in the numbers of primitive self-renewing cells. This was confirmed by a dramatic increase in the numbers of long-term culture-initiating cells, the most primitive hematopoietic cells detectable in vitro. To understand the molecular mechanisms underlying the effects of NUP98-HOXA9 on hematopoietic cell proliferation and differentiation, oligonucleotide microarray analysis was done at several time points over 16 days, starting at 6 hours posttransduction. The early growth suppression was preceded by up-regulation of IFNbeta1 and accompanied by marked up-regulation of IFN-induced genes, peaking at 3 days posttransduction. In contrast, oncogenes such as homeobox transcription factors, FLT3, KIT, and WT1 peaked at 8 days or beyond, coinciding with increased proliferation. In addition, several putative tumor suppressors and genes associated with hematopoietic differentiation were repressed at later time points. These findings provide a comprehensive picture of the changes in proliferation, differentiation, and global gene expression that underlie the leukemic transformation of human hematopoietic cells by NUP98-HOXA9.

Standard name | TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_8D_UP
Systematic name | M17275
Organism | Homo sapiens
PMID | 16818636
Authors | Takeda A,Goolsby C,Yaseen NR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 8 days after transduction.
Full description | NUP98-HOXA9, the chimeric protein resulting from the t(7;11)(p15;p15) chromosomal translocation, is a prototype of several NUP98 fusions that occur in myelodysplastic syndromes and acute myeloid leukemia. We examined its effect on differentiation, proliferation, and gene expression in primary human CD34+ hematopoietic cells. Colony-forming cell (CFC) assays in semisolid medium combined with morphologic examination and flow cytometric immunophenotyping revealed that NUP98-HOXA9 increased the numbers of erythroid precursors and impaired both myeloid and erythroid differentiation. In continuous liquid culture, cells transduced with NUP98-HOXA9 exhibited a biphasic growth curve with initial growth inhibition followed by enhanced long-term proliferation, suggesting an increase in the numbers of primitive self-renewing cells. This was confirmed by a dramatic increase in the numbers of long-term culture-initiating cells, the most primitive hematopoietic cells detectable in vitro. To understand the molecular mechanisms underlying the effects of NUP98-HOXA9 on hematopoietic cell proliferation and differentiation, oligonucleotide microarray analysis was done at several time points over 16 days, starting at 6 hours posttransduction. The early growth suppression was preceded by up-regulation of IFNbeta1 and accompanied by marked up-regulation of IFN-induced genes, peaking at 3 days posttransduction. In contrast, oncogenes such as homeobox transcription factors, FLT3, KIT, and WT1 peaked at 8 days or beyond, coinciding with increased proliferation. In addition, several putative tumor suppressors and genes associated with hematopoietic differentiation were repressed at later time points. These findings provide a comprehensive picture of the changes in proliferation, differentiation, and global gene expression that underlie the leukemic transformation of human hematopoietic cells by NUP98-HOXA9.

Standard name | TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_8D_DN
Systematic name | M9740
Organism | Homo sapiens
PMID | 16818636
Authors | Takeda A,Goolsby C,Yaseen NR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 8 days after transduction.
Full description | NUP98-HOXA9, the chimeric protein resulting from the t(7;11)(p15;p15) chromosomal translocation, is a prototype of several NUP98 fusions that occur in myelodysplastic syndromes and acute myeloid leukemia. We examined its effect on differentiation, proliferation, and gene expression in primary human CD34+ hematopoietic cells. Colony-forming cell (CFC) assays in semisolid medium combined with morphologic examination and flow cytometric immunophenotyping revealed that NUP98-HOXA9 increased the numbers of erythroid precursors and impaired both myeloid and erythroid differentiation. In continuous liquid culture, cells transduced with NUP98-HOXA9 exhibited a biphasic growth curve with initial growth inhibition followed by enhanced long-term proliferation, suggesting an increase in the numbers of primitive self-renewing cells. This was confirmed by a dramatic increase in the numbers of long-term culture-initiating cells, the most primitive hematopoietic cells detectable in vitro. To understand the molecular mechanisms underlying the effects of NUP98-HOXA9 on hematopoietic cell proliferation and differentiation, oligonucleotide microarray analysis was done at several time points over 16 days, starting at 6 hours posttransduction. The early growth suppression was preceded by up-regulation of IFNbeta1 and accompanied by marked up-regulation of IFN-induced genes, peaking at 3 days posttransduction. In contrast, oncogenes such as homeobox transcription factors, FLT3, KIT, and WT1 peaked at 8 days or beyond, coinciding with increased proliferation. In addition, several putative tumor suppressors and genes associated with hematopoietic differentiation were repressed at later time points. These findings provide a comprehensive picture of the changes in proliferation, differentiation, and global gene expression that underlie the leukemic transformation of human hematopoietic cells by NUP98-HOXA9.

Standard name | TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_10D_UP
Systematic name | M13479
Organism | Homo sapiens
PMID | 16818636
Authors | Takeda A,Goolsby C,Yaseen NR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 10 days after transduction.
Full description | NUP98-HOXA9, the chimeric protein resulting from the t(7;11)(p15;p15) chromosomal translocation, is a prototype of several NUP98 fusions that occur in myelodysplastic syndromes and acute myeloid leukemia. We examined its effect on differentiation, proliferation, and gene expression in primary human CD34+ hematopoietic cells. Colony-forming cell (CFC) assays in semisolid medium combined with morphologic examination and flow cytometric immunophenotyping revealed that NUP98-HOXA9 increased the numbers of erythroid precursors and impaired both myeloid and erythroid differentiation. In continuous liquid culture, cells transduced with NUP98-HOXA9 exhibited a biphasic growth curve with initial growth inhibition followed by enhanced long-term proliferation, suggesting an increase in the numbers of primitive self-renewing cells. This was confirmed by a dramatic increase in the numbers of long-term culture-initiating cells, the most primitive hematopoietic cells detectable in vitro. To understand the molecular mechanisms underlying the effects of NUP98-HOXA9 on hematopoietic cell proliferation and differentiation, oligonucleotide microarray analysis was done at several time points over 16 days, starting at 6 hours posttransduction. The early growth suppression was preceded by up-regulation of IFNbeta1 and accompanied by marked up-regulation of IFN-induced genes, peaking at 3 days posttransduction. In contrast, oncogenes such as homeobox transcription factors, FLT3, KIT, and WT1 peaked at 8 days or beyond, coinciding with increased proliferation. In addition, several putative tumor suppressors and genes associated with hematopoietic differentiation were repressed at later time points. These findings provide a comprehensive picture of the changes in proliferation, differentiation, and global gene expression that underlie the leukemic transformation of human hematopoietic cells by NUP98-HOXA9.

Standard name | TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_10D_DN
Systematic name | M7388
Organism | Homo sapiens
PMID | 16818636
Authors | Takeda A,Goolsby C,Yaseen NR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 10 days after transduction.
Full description | NUP98-HOXA9, the chimeric protein resulting from the t(7;11)(p15;p15) chromosomal translocation, is a prototype of several NUP98 fusions that occur in myelodysplastic syndromes and acute myeloid leukemia. We examined its effect on differentiation, proliferation, and gene expression in primary human CD34+ hematopoietic cells. Colony-forming cell (CFC) assays in semisolid medium combined with morphologic examination and flow cytometric immunophenotyping revealed that NUP98-HOXA9 increased the numbers of erythroid precursors and impaired both myeloid and erythroid differentiation. In continuous liquid culture, cells transduced with NUP98-HOXA9 exhibited a biphasic growth curve with initial growth inhibition followed by enhanced long-term proliferation, suggesting an increase in the numbers of primitive self-renewing cells. This was confirmed by a dramatic increase in the numbers of long-term culture-initiating cells, the most primitive hematopoietic cells detectable in vitro. To understand the molecular mechanisms underlying the effects of NUP98-HOXA9 on hematopoietic cell proliferation and differentiation, oligonucleotide microarray analysis was done at several time points over 16 days, starting at 6 hours posttransduction. The early growth suppression was preceded by up-regulation of IFNbeta1 and accompanied by marked up-regulation of IFN-induced genes, peaking at 3 days posttransduction. In contrast, oncogenes such as homeobox transcription factors, FLT3, KIT, and WT1 peaked at 8 days or beyond, coinciding with increased proliferation. In addition, several putative tumor suppressors and genes associated with hematopoietic differentiation were repressed at later time points. These findings provide a comprehensive picture of the changes in proliferation, differentiation, and global gene expression that underlie the leukemic transformation of human hematopoietic cells by NUP98-HOXA9.

Standard name | TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_16D_UP
Systematic name | M15588
Organism | Homo sapiens
PMID | 16818636
Authors | Takeda A,Goolsby C,Yaseen NR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 16 days after transduction.
Full description | NUP98-HOXA9, the chimeric protein resulting from the t(7;11)(p15;p15) chromosomal translocation, is a prototype of several NUP98 fusions that occur in myelodysplastic syndromes and acute myeloid leukemia. We examined its effect on differentiation, proliferation, and gene expression in primary human CD34+ hematopoietic cells. Colony-forming cell (CFC) assays in semisolid medium combined with morphologic examination and flow cytometric immunophenotyping revealed that NUP98-HOXA9 increased the numbers of erythroid precursors and impaired both myeloid and erythroid differentiation. In continuous liquid culture, cells transduced with NUP98-HOXA9 exhibited a biphasic growth curve with initial growth inhibition followed by enhanced long-term proliferation, suggesting an increase in the numbers of primitive self-renewing cells. This was confirmed by a dramatic increase in the numbers of long-term culture-initiating cells, the most primitive hematopoietic cells detectable in vitro. To understand the molecular mechanisms underlying the effects of NUP98-HOXA9 on hematopoietic cell proliferation and differentiation, oligonucleotide microarray analysis was done at several time points over 16 days, starting at 6 hours posttransduction. The early growth suppression was preceded by up-regulation of IFNbeta1 and accompanied by marked up-regulation of IFN-induced genes, peaking at 3 days posttransduction. In contrast, oncogenes such as homeobox transcription factors, FLT3, KIT, and WT1 peaked at 8 days or beyond, coinciding with increased proliferation. In addition, several putative tumor suppressors and genes associated with hematopoietic differentiation were repressed at later time points. These findings provide a comprehensive picture of the changes in proliferation, differentiation, and global gene expression that underlie the leukemic transformation of human hematopoietic cells by NUP98-HOXA9.

Standard name | TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_16D_DN
Systematic name | M15410
Organism | Homo sapiens
PMID | 16818636
Authors | Takeda A,Goolsby C,Yaseen NR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 16 days after transduction.
Full description | NUP98-HOXA9, the chimeric protein resulting from the t(7;11)(p15;p15) chromosomal translocation, is a prototype of several NUP98 fusions that occur in myelodysplastic syndromes and acute myeloid leukemia. We examined its effect on differentiation, proliferation, and gene expression in primary human CD34+ hematopoietic cells. Colony-forming cell (CFC) assays in semisolid medium combined with morphologic examination and flow cytometric immunophenotyping revealed that NUP98-HOXA9 increased the numbers of erythroid precursors and impaired both myeloid and erythroid differentiation. In continuous liquid culture, cells transduced with NUP98-HOXA9 exhibited a biphasic growth curve with initial growth inhibition followed by enhanced long-term proliferation, suggesting an increase in the numbers of primitive self-renewing cells. This was confirmed by a dramatic increase in the numbers of long-term culture-initiating cells, the most primitive hematopoietic cells detectable in vitro. To understand the molecular mechanisms underlying the effects of NUP98-HOXA9 on hematopoietic cell proliferation and differentiation, oligonucleotide microarray analysis was done at several time points over 16 days, starting at 6 hours posttransduction. The early growth suppression was preceded by up-regulation of IFNbeta1 and accompanied by marked up-regulation of IFN-induced genes, peaking at 3 days posttransduction. In contrast, oncogenes such as homeobox transcription factors, FLT3, KIT, and WT1 peaked at 8 days or beyond, coinciding with increased proliferation. In addition, several putative tumor suppressors and genes associated with hematopoietic differentiation were repressed at later time points. These findings provide a comprehensive picture of the changes in proliferation, differentiation, and global gene expression that underlie the leukemic transformation of human hematopoietic cells by NUP98-HOXA9.

Standard name | LOPEZ_MESOTELIOMA_SURVIVAL_TIME_UP
Systematic name | M540
Organism | Homo sapiens
PMID | 16540645
Authors | López-Ríos F,Chuai S,Flores R,Shimizu S,Ohno T,Wakahara K,Illei PB,Hussain S,Krug L,Zakowski MF,Rusch V,Olshen AB,Ladanyi M
Category | C2
Sub-category | CGP
Brief description | Top genes higher expressed in short term mesothelioma survivors.
Full description | Most gene expression profiling studies of mesothelioma have been based on relatively small sample numbers, limiting their statistical power. We did Affymetrix U133A microarray analysis on 99 pleural mesotheliomas, in which multivariate analysis showed advanced-stage, sarcomatous histology and P16/CDKN2A homozygous deletion to be significant independent adverse prognostic factors. Comparison of the expression profiles of epithelioid versus sarcomatous mesotheliomas identified many genes significantly overexpressed among the former, including previously unrecognized ones, such as uroplakins and kallikrein 11, both confirmed by immunohistochemistry. Examination of the gene expression correlates of survival showed that more aggressive mesotheliomas expressed higher levels of Aurora kinases A and B and functionally related genes involved in mitosis and cell cycle control. Independent confirmation of the negative effect of Aurora kinase B was obtained by immunohistochemistry in a separate patient cohort. A role for Aurora kinases in the aggressive behavior of mesotheliomas is of potential clinical interest because of the recent development of small-molecule inhibitors. We then used our data to develop microarray-based predictors of 1 year survival; these achieved a maximal accuracy of 68% in cross-validation. However, this was inferior to prognostic prediction based on standard clinicopathologic variables and P16/CDNK2A status (accuracy, 73%), and adding the microarray model to the latter did not improve overall accuracy. Finally, we evaluated three recently published microarray-based outcome prediction models, but their accuracies ranged from 63% to 67%, consistently lower than reported. Gene expression profiling of mesotheliomas is an important discovery tool, but its power in clinical prognostication has been overestimated.

Standard name | LOPEZ_MESOTELIOMA_SURVIVAL_TIME_DN
Systematic name | M5899
Organism | Homo sapiens
PMID | 16540645
Authors | López-Ríos F,Chuai S,Flores R,Shimizu S,Ohno T,Wakahara K,Illei PB,Hussain S,Krug L,Zakowski MF,Rusch V,Olshen AB,Ladanyi M
Category | C2
Sub-category | CGP
Brief description | Top genes higher expressed in long term mesothelioma survivors.
Full description | Most gene expression profiling studies of mesothelioma have been based on relatively small sample numbers, limiting their statistical power. We did Affymetrix U133A microarray analysis on 99 pleural mesotheliomas, in which multivariate analysis showed advanced-stage, sarcomatous histology and P16/CDKN2A homozygous deletion to be significant independent adverse prognostic factors. Comparison of the expression profiles of epithelioid versus sarcomatous mesotheliomas identified many genes significantly overexpressed among the former, including previously unrecognized ones, such as uroplakins and kallikrein 11, both confirmed by immunohistochemistry. Examination of the gene expression correlates of survival showed that more aggressive mesotheliomas expressed higher levels of Aurora kinases A and B and functionally related genes involved in mitosis and cell cycle control. Independent confirmation of the negative effect of Aurora kinase B was obtained by immunohistochemistry in a separate patient cohort. A role for Aurora kinases in the aggressive behavior of mesotheliomas is of potential clinical interest because of the recent development of small-molecule inhibitors. We then used our data to develop microarray-based predictors of 1 year survival; these achieved a maximal accuracy of 68% in cross-validation. However, this was inferior to prognostic prediction based on standard clinicopathologic variables and P16/CDNK2A status (accuracy, 73%), and adding the microarray model to the latter did not improve overall accuracy. Finally, we evaluated three recently published microarray-based outcome prediction models, but their accuracies ranged from 63% to 67%, consistently lower than reported. Gene expression profiling of mesotheliomas is an important discovery tool, but its power in clinical prognostication has been overestimated.

Standard name | BOGNI_TREATMENT_RELATED_MYELOID_LEUKEMIA_UP
Systematic name | M14736
Organism | Homo sapiens
PMID | 16341039
Authors | Bogni A,Cheng C,Liu W,Yang W,Pfeffer J,Mukatira S,French D,Downing JR,Pui CH,Relling MV
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ALL (acute lymphoblastic leukemia) patients who developed t-ML (treatment related myeloid leukemia).
Full description | Using a target gene approach, only a few host genetic risk factors for treatment-related myeloid leukemia (t-ML) have been defined. Gene expression microarrays allow for a more genome-wide approach to assess possible genetic risk factors for t-ML. We assessed gene expression profiles (n=12 625 probe sets) in diagnostic acute lymphoblastic leukemic cells from 228 children treated on protocols that included leukemogenic agents such as etoposide, 13 of whom developed t-ML. Expression of 68 probes, corresponding to 63 genes, was significantly related to risk of t-ML. Hierarchical clustering of these probe sets clustered patients into three groups with 94, 122 and 12 patients, respectively; 12 of the 13 patients who went on to develop t-ML were overrepresented in the latter group (P<0.0001). A permutation test indicated a low likelihood that these probe sets and clusters were obtained by chance (P<0.001). Distinguishing genes included transcription-related oncogenes (v-Myb, Pax-5), cyclins (CCNG1, CCNG2 and CCND1) and histone HIST1H4C. Common transcription factor recognition elements among similarly up- or downregulated genes included several involved in hematopoietic differentiation or leukemogenesis (Maz, PU.1, ARNT). This approach has identified several genes whose expression distinguishes patients at risk of t-ML, and suggests targets for assessing germline predisposition to leukemogenesis.

Standard name | BOGNI_TREATMENT_RELATED_MYELOID_LEUKEMIA_DN
Systematic name | M8981
Organism | Homo sapiens
PMID | 16341039
Authors | Bogni A,Cheng C,Liu W,Yang W,Pfeffer J,Mukatira S,French D,Downing JR,Pui CH,Relling MV
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ALL (acute lymphoblastic leukemia) patients who developed t-ML (treatment related myeloid leukemia).
Full description | Using a target gene approach, only a few host genetic risk factors for treatment-related myeloid leukemia (t-ML) have been defined. Gene expression microarrays allow for a more genome-wide approach to assess possible genetic risk factors for t-ML. We assessed gene expression profiles (n=12 625 probe sets) in diagnostic acute lymphoblastic leukemic cells from 228 children treated on protocols that included leukemogenic agents such as etoposide, 13 of whom developed t-ML. Expression of 68 probes, corresponding to 63 genes, was significantly related to risk of t-ML. Hierarchical clustering of these probe sets clustered patients into three groups with 94, 122 and 12 patients, respectively; 12 of the 13 patients who went on to develop t-ML were overrepresented in the latter group (P<0.0001). A permutation test indicated a low likelihood that these probe sets and clusters were obtained by chance (P<0.001). Distinguishing genes included transcription-related oncogenes (v-Myb, Pax-5), cyclins (CCNG1, CCNG2 and CCND1) and histone HIST1H4C. Common transcription factor recognition elements among similarly up- or downregulated genes included several involved in hematopoietic differentiation or leukemogenesis (Maz, PU.1, ARNT). This approach has identified several genes whose expression distinguishes patients at risk of t-ML, and suggests targets for assessing germline predisposition to leukemogenesis.

Standard name | BILBAN_B_CLL_LPL_UP
Systematic name | M19930
Organism | Homo sapiens
PMID | 16617321
Authors | Bilban M,Heintel D,Scharl T,Woelfel T,Auer MM,Porpaczy E,Kainz B,Kröber A,Carey VJ,Shehata M,Zielinski C,Pickl W,Stilgenbauer S,Gaiger A,Wagner O,Jäger U,LastName M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in B-CLL (B-cell chronic leukemia) samples expressing high levels of LPL [GeneID=4023] compared with those expressing low levels of the gene.
Full description | Lipoprotein lipase (LPL) is a prognostic marker in B-cell chronic lymphocytic leukemia (B-CLL) related to immunoglobulin V(H) gene (IgV(H))mutational status. We determined gene expression profiles using Affymetrix U133A GeneChips in two groups of B-CLLs selected for either high ('LPL+', n=10) or low ('LPL-', n=10) LPL mRNA expression. Selected genes were verified by real-time PCR in an extended patient cohort (n=42). A total of 111 genes discriminated LPL+ from LPL- B-CLLs. Of these, the top three genes associated with time to first treatment were Septin10, DMD and Gravin (P</=0.01). The relationship of LPL+ and LPL- B-CLL gene expression signatures to 52 tissues was statistically analyzed. The LPL+ B-CLL expression signature, represented by 64 genes was significantly related to fat, muscle and PB dendritic cells (P<0.001). Exploration of microarray data to define functional alterations related to the biology of LPL+ CLL identified two functional modules, fatty acid degradation and MTA3 signaling, as being altered with higher statistical significance. Our data show that LPL+ B-CLL cells have not only acquired gene expression changes in fat and muscle-associated genes but also in functional pathways related to fatty acid degradation and signaling which may ultimately influence CLL biology and clinical outcome.

Standard name | BILBAN_B_CLL_LPL_DN
Systematic name | M14940
Organism | Homo sapiens
PMID | 16617321
Authors | Bilban M,Heintel D,Scharl T,Woelfel T,Auer MM,Porpaczy E,Kainz B,Kröber A,Carey VJ,Shehata M,Zielinski C,Pickl W,Stilgenbauer S,Gaiger A,Wagner O,Jäger U,LastName M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in B-CLL (B-cell chronic leukemia) samples expressing high levels of LPL [GeneID=4023] compared with those expressing low levels of the gene.
Full description | Lipoprotein lipase (LPL) is a prognostic marker in B-cell chronic lymphocytic leukemia (B-CLL) related to immunoglobulin V(H) gene (IgV(H))mutational status. We determined gene expression profiles using Affymetrix U133A GeneChips in two groups of B-CLLs selected for either high ('LPL+', n=10) or low ('LPL-', n=10) LPL mRNA expression. Selected genes were verified by real-time PCR in an extended patient cohort (n=42). A total of 111 genes discriminated LPL+ from LPL- B-CLLs. Of these, the top three genes associated with time to first treatment were Septin10, DMD and Gravin (P</=0.01). The relationship of LPL+ and LPL- B-CLL gene expression signatures to 52 tissues was statistically analyzed. The LPL+ B-CLL expression signature, represented by 64 genes was significantly related to fat, muscle and PB dendritic cells (P<0.001). Exploration of microarray data to define functional alterations related to the biology of LPL+ CLL identified two functional modules, fatty acid degradation and MTA3 signaling, as being altered with higher statistical significance. Our data show that LPL+ B-CLL cells have not only acquired gene expression changes in fat and muscle-associated genes but also in functional pathways related to fatty acid degradation and signaling which may ultimately influence CLL biology and clinical outcome.

Standard name | HOEBEKE_LYMPHOID_STEM_CELL_UP
Systematic name | M14698
Organism | Homo sapiens
PMID | 17170726
Authors | Hoebeke I,De Smedt M,Stolz F,Pike-Overzet K,Staal FJ,Plum J,Leclercq G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the common lymphoid progenitor (CLP, defined as CD34+CD38-CD7+ [GeneID=947;952;924]) compared to a multipotent cord blood cell (defined as CD34+CD38+CD7-).
Full description | Hematopoietic stem cells in the bone marrow (BM) give rise to all blood cells. According to the classic model of hematopoiesis, the differentiation paths leading to the myeloid and lymphoid lineages segregate early. A candidate 'common lymphoid progenitor' (CLP) has been isolated from CD34(+)CD38(-) human cord blood cells based on CD7 expression. Here, we confirm the B- and NK-differentiation potential of CD34(+)CD38(-)CD7(+) cells and show in addition that this population has strong capacity to differentiate into T cells. As CD34(+)CD38(-)CD7(+) cells are virtually devoid of myeloid differentiation potential, these cells represent true CLPs. To unravel the molecular mechanisms underlying lymphoid commitment, we performed genome-wide gene expression profiling on sorted CD34(+)CD38(-)CD7(+) and CD34(+)CD38(-)CD7(-) cells. Interestingly, lymphoid-affiliated genes were mainly upregulated in the CD7(+) population, while myeloid-specific genes were downregulated. This supports the hypothesis that lineage commitment is accompanied by the shutdown of inappropriate gene expression and the upregulation of lineage-specific genes. In addition, we identified several highly expressed genes that have not been described in hematopoiesis before.

Standard name | HOEBEKE_LYMPHOID_STEM_CELL_DN
Systematic name | M7435
Organism | Homo sapiens
PMID | 17170726
Authors | Hoebeke I,De Smedt M,Stolz F,Pike-Overzet K,Staal FJ,Plum J,Leclercq G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the common lymphoid progenitor (CLP, defined as CD34+CD38-CD7+ [GeneID=947;952;924]) compared to a multipotent cord blood cell (defined as CD34+CD38+CD7-).
Full description | Hematopoietic stem cells in the bone marrow (BM) give rise to all blood cells. According to the classic model of hematopoiesis, the differentiation paths leading to the myeloid and lymphoid lineages segregate early. A candidate 'common lymphoid progenitor' (CLP) has been isolated from CD34(+)CD38(-) human cord blood cells based on CD7 expression. Here, we confirm the B- and NK-differentiation potential of CD34(+)CD38(-)CD7(+) cells and show in addition that this population has strong capacity to differentiate into T cells. As CD34(+)CD38(-)CD7(+) cells are virtually devoid of myeloid differentiation potential, these cells represent true CLPs. To unravel the molecular mechanisms underlying lymphoid commitment, we performed genome-wide gene expression profiling on sorted CD34(+)CD38(-)CD7(+) and CD34(+)CD38(-)CD7(-) cells. Interestingly, lymphoid-affiliated genes were mainly upregulated in the CD7(+) population, while myeloid-specific genes were downregulated. This supports the hypothesis that lineage commitment is accompanied by the shutdown of inappropriate gene expression and the upregulation of lineage-specific genes. In addition, we identified several highly expressed genes that have not been described in hematopoiesis before.

Standard name | PEPPER_CHRONIC_LYMPHOCYTIC_LEUKEMIA_UP
Systematic name | M3340
Organism | Homo sapiens
PMID | 17287849
Authors | Pepper C,Ward R,Lin TT,Brennan P,Starczynski J,Musson M,Rowntree C,Bentley P,Mills K,Pratt G,Fegan C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD38+ [GeneID=952] CLL (chronic lymphocytic leukemia) cells.
Full description | CD38 expression is an important prognostic marker in chronic lymphocytic leukemia (CLL) with high levels of CD38 associated with shorter overall survival. In this study, we used gene expression profiling and protein analysis of highly purified cell-sorted CD38(+) and CD38(-) chronic lymphocytic leukemia cells to elucidate a molecular basis for the association between CD38 expression and inferior clinical outcome. Paired CD38(+) and CD38(-) CLL cells derived from the same patient were shown to be monoclonal by V(H) gene sequencing but despite this, CD38(+) CLL cells possessed a distinct gene expression profile when compared with their CD38(-) sub-clones. Importantly, CD38(+) CLL cells relatively over expressed vascular endothelial growth factor (VEGF) and appeared to preferentially utilize an internal autocrine VEGF survival loop. Elevated VEGF expression was associated with increased expression of the anti-apoptotic protein Mcl-1. Inhibition of VEGF receptor signaling also resulted in a reduction in cell viability. In contrast, exogenous VEGF caused a significant increase in CD38(-) CLL cell viability and a marked induction of Mcl-1; both effects were less obvious in CD38(+) CLL cells. Taken together, our data provide a biological rationale for the poor prognosis of CD38(+) CLL and indicate that both VEGF and Mcl-1 may prove to be useful therapeutic targets.

Standard name | PEPPER_CHRONIC_LYMPHOCYTIC_LEUKEMIA_DN
Systematic name | M4038
Organism | Homo sapiens
PMID | 17287849
Authors | Pepper C,Ward R,Lin TT,Brennan P,Starczynski J,Musson M,Rowntree C,Bentley P,Mills K,Pratt G,Fegan C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD38+ [GeneID=952] CLL (chronic lymphocytic leukemia) cells.
Full description | CD38 expression is an important prognostic marker in chronic lymphocytic leukemia (CLL) with high levels of CD38 associated with shorter overall survival. In this study, we used gene expression profiling and protein analysis of highly purified cell-sorted CD38(+) and CD38(-) chronic lymphocytic leukemia cells to elucidate a molecular basis for the association between CD38 expression and inferior clinical outcome. Paired CD38(+) and CD38(-) CLL cells derived from the same patient were shown to be monoclonal by V(H) gene sequencing but despite this, CD38(+) CLL cells possessed a distinct gene expression profile when compared with their CD38(-) sub-clones. Importantly, CD38(+) CLL cells relatively over expressed vascular endothelial growth factor (VEGF) and appeared to preferentially utilize an internal autocrine VEGF survival loop. Elevated VEGF expression was associated with increased expression of the anti-apoptotic protein Mcl-1. Inhibition of VEGF receptor signaling also resulted in a reduction in cell viability. In contrast, exogenous VEGF caused a significant increase in CD38(-) CLL cell viability and a marked induction of Mcl-1; both effects were less obvious in CD38(+) CLL cells. Taken together, our data provide a biological rationale for the poor prognosis of CD38(+) CLL and indicate that both VEGF and Mcl-1 may prove to be useful therapeutic targets.

Standard name | AKL_HTLV1_INFECTION_UP
Systematic name | M7705
Organism | Homo sapiens
PMID | 17287851
Authors | Akl H,Badran BM,Zein NE,Bex F,Sotiriou C,Willard-Gallo KE,Burny A,Martiat P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in WE17/10 cells (CD4+ [GeneID=920] T lymphocytes) infected by HTLV1 (and thus displaying low CD7 [GeneID=924]) compared to the uninfected (i.e., CD7+) cells.
Full description | Adult T-cell leukemia/lymphoma (ATLL) is a malignancy slowly emerging from human T-cell leukemia virus type 1 (HTLV-I)-infected mature CD4(+) T-cells. To characterize the molecular modifications induced by HTLV-I infection, we compared HTLV-I-infected WE17/10 cells with control cells, using micro-arrays. Many calcium-related genes were progressively downmodulated over a period of 2 years. Infected cells acquired a profound decrease of intracellular calcium levels in response to ionomycin, timely correlated with decreased CD7 expression. Focusing on apoptosis-related genes and their relationship with CD7, we observed an underexpression of most antiapoptotic genes. Western blotting revealed increasing Akt and Bad phosphorylation, timely correlated with CD7 loss. This was shown to be phosphatidylinositol 3-kinase (PI3K)-dependent. Activation of PI3K/Akt induced resistance to the apoptotic effect of interleukin-2 deprivation. We thus propose the following model: HTLV-I infection induces a progressive decrease in CD3 genes expression, which eventually abrogates CD3 expression; loss of CD3 is known to perturb calcium transport. This perturbation correlates with loss of CD7 expression and induction of Akt and Bad phosphorylation via activation of PI3K. The activation of the Akt/Bad pathway generates a progressive resistance to apoptosis, at a time HTLV-I genes expression is silenced, thus avoiding immune surveillance. This could be a major event in the process of the malignant transformation into ATLL.

Standard name | AKL_HTLV1_INFECTION_DN
Systematic name | M9815
Organism | Homo sapiens
PMID | 17287851
Authors | Akl H,Badran BM,Zein NE,Bex F,Sotiriou C,Willard-Gallo KE,Burny A,Martiat P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in WE17/10 cells (CD4+ [GeneID=920] T lymphocytes) infected by HTLV1 (and thus displaying low CD7 [GeneID=924]) compared to the uninfected (i.e., CD7+) cells.
Full description | Adult T-cell leukemia/lymphoma (ATLL) is a malignancy slowly emerging from human T-cell leukemia virus type 1 (HTLV-I)-infected mature CD4(+) T-cells. To characterize the molecular modifications induced by HTLV-I infection, we compared HTLV-I-infected WE17/10 cells with control cells, using micro-arrays. Many calcium-related genes were progressively downmodulated over a period of 2 years. Infected cells acquired a profound decrease of intracellular calcium levels in response to ionomycin, timely correlated with decreased CD7 expression. Focusing on apoptosis-related genes and their relationship with CD7, we observed an underexpression of most antiapoptotic genes. Western blotting revealed increasing Akt and Bad phosphorylation, timely correlated with CD7 loss. This was shown to be phosphatidylinositol 3-kinase (PI3K)-dependent. Activation of PI3K/Akt induced resistance to the apoptotic effect of interleukin-2 deprivation. We thus propose the following model: HTLV-I infection induces a progressive decrease in CD3 genes expression, which eventually abrogates CD3 expression; loss of CD3 is known to perturb calcium transport. This perturbation correlates with loss of CD7 expression and induction of Akt and Bad phosphorylation via activation of PI3K. The activation of the Akt/Bad pathway generates a progressive resistance to apoptosis, at a time HTLV-I genes expression is silenced, thus avoiding immune surveillance. This could be a major event in the process of the malignant transformation into ATLL.

Standard name | RHEIN_ALL_GLUCOCORTICOID_THERAPY_UP
Systematic name | M12784
Organism | Homo sapiens
PMID | 17330098
Authors | Rhein P,Scheid S,Ratei R,Hagemeier C,Seeger K,Kirschner-Schwabe R,Moericke A,Schrappe M,Spang R,Ludwig WD,Karawajew L
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ALL (acute lymphoblastic leukemia) blasts after 1 week of treatment with glucocorticoids.
Full description | In childhood acute lymphoblastic leukemia (ALL), persistence of leukemic blasts during therapy is of crucial prognostic significance. In the present study, we address molecular and cell biologic features of blasts persisting after 1 week of induction glucocorticoid therapy. Genome-wide gene expression analysis of leukemic samples from precursor B-cell ALL patients (n=18) identified a set of genes differentially expressed in blasts at diagnosis day 0 (d0) and persisting on day 8 (d8). Expression changes indicate a shift towards mature B cells, inhibition of cell cycling and increased expression of adhesion (CD11b/ITGAM) and cytokine (CD119/IFNGR1) receptors. A direct comparison with normal B cells, which are largely therapy resistant, confirmed the differentiation shift at the mRNA (n=10) and protein (n=109) levels. Flow cytometric analysis in independent cohorts of patients confirmed both a decreased proliferative activity (n=13) and the upregulation of CD11b and CD119 (n=29) in d8 blasts. The differentiation shift and low proliferative activity in d8 blasts may account for the persistence of blasts during therapy and affect their sensitivity to further therapeutic treatment. CD11b and CD119 are potential specific markers for d8 blast persistence and detection of minimal residual disease, which warrant further investigation.

Standard name | RHEIN_ALL_GLUCOCORTICOID_THERAPY_DN
Systematic name | M1859
Organism | Homo sapiens
PMID | 17330098
Authors | Rhein P,Scheid S,Ratei R,Hagemeier C,Seeger K,Kirschner-Schwabe R,Moericke A,Schrappe M,Spang R,Ludwig WD,Karawajew L
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ALL (acute lymphoblastic leukemia) blasts after 1 week of treatment with glucocorticoids.
Full description | In childhood acute lymphoblastic leukemia (ALL), persistence of leukemic blasts during therapy is of crucial prognostic significance. In the present study, we address molecular and cell biologic features of blasts persisting after 1 week of induction glucocorticoid therapy. Genome-wide gene expression analysis of leukemic samples from precursor B-cell ALL patients (n=18) identified a set of genes differentially expressed in blasts at diagnosis day 0 (d0) and persisting on day 8 (d8). Expression changes indicate a shift towards mature B cells, inhibition of cell cycling and increased expression of adhesion (CD11b/ITGAM) and cytokine (CD119/IFNGR1) receptors. A direct comparison with normal B cells, which are largely therapy resistant, confirmed the differentiation shift at the mRNA (n=10) and protein (n=109) levels. Flow cytometric analysis in independent cohorts of patients confirmed both a decreased proliferative activity (n=13) and the upregulation of CD11b and CD119 (n=29) in d8 blasts. The differentiation shift and low proliferative activity in d8 blasts may account for the persistence of blasts during therapy and affect their sensitivity to further therapeutic treatment. CD11b and CD119 are potential specific markers for d8 blast persistence and detection of minimal residual disease, which warrant further investigation.

Standard name | MULLIGHAN_NPM1_MUTATED_SIGNATURE_1_UP
Systematic name | M19170
Organism | Homo sapiens
PMID | 17597811
Authors | Mullighan CG,Kennedy A,Zhou X,Radtke I,Phillips LA,Shurtleff SA,Downing JR
Category | C2
Sub-category | CGP
Brief description | The 'NPM1-mutated signature 1': genes up-regulated in pediatric AML (acute myeloid leukemia) samples with mutated NPM1 [GeneID=4869] compared to all AML cases with the intact gene.
Full description | Somatic mutations in nucleophosmin (NPM1) occur in approximately 35% of adult acute myeloid leukemia (AML). To assess the frequency of NPM1 mutations in pediatric AML, we sequenced NPM1 in the diagnostic blasts from 93 pediatric AML patients. Six cases harbored NPM1 mutations, with each case lacking common cytogenetic abnormalities. To explore the phenotype of the AMLs with NPM1 mutations, gene expression profiles were obtained using Affymetrix U133A microarrays. NPM1 mutations were associated with increased expression of multiple homeobox genes including HOXA9, A10, B2, B6 and MEIS1. As dysregulated homeobox gene expression is also a feature of MLL-rearranged leukemia, the gene expression signatures of NPM1-mutated and MLL-rearranged leukemias were compared. Significant differences were identified between these leukemia subtypes including the expression of different HOX genes, with NPM1-mutated AML showing higher levels of expression of HOXB2, B3, B6 and D4. These results confirm recent reports of perturbed HOX expression in NPM1-mutated adult AML, and provide the first evidence that the NPM1-mutated signature is distinct from MLL-rearranged AML. These findings suggest that mutated NPM1 leads to dysregulated HOX expression via a different mechanism than MLL rearrangement.

Standard name | MULLIGHAN_NPM1_MUTATED_SIGNATURE_1_DN
Systematic name | M19629
Organism | Homo sapiens
PMID | 17597811
Authors | Mullighan CG,Kennedy A,Zhou X,Radtke I,Phillips LA,Shurtleff SA,Downing JR
Category | C2
Sub-category | CGP
Brief description | The 'NPM1-mutated signature 1': genes down-regulated in pediatric AML (acute myeloid leukemia) samples with mutated NPM1 [GeneID=4869] compared to all AML cases with the intact gene.
Full description | Somatic mutations in nucleophosmin (NPM1) occur in approximately 35% of adult acute myeloid leukemia (AML). To assess the frequency of NPM1 mutations in pediatric AML, we sequenced NPM1 in the diagnostic blasts from 93 pediatric AML patients. Six cases harbored NPM1 mutations, with each case lacking common cytogenetic abnormalities. To explore the phenotype of the AMLs with NPM1 mutations, gene expression profiles were obtained using Affymetrix U133A microarrays. NPM1 mutations were associated with increased expression of multiple homeobox genes including HOXA9, A10, B2, B6 and MEIS1. As dysregulated homeobox gene expression is also a feature of MLL-rearranged leukemia, the gene expression signatures of NPM1-mutated and MLL-rearranged leukemias were compared. Significant differences were identified between these leukemia subtypes including the expression of different HOX genes, with NPM1-mutated AML showing higher levels of expression of HOXB2, B3, B6 and D4. These results confirm recent reports of perturbed HOX expression in NPM1-mutated adult AML, and provide the first evidence that the NPM1-mutated signature is distinct from MLL-rearranged AML. These findings suggest that mutated NPM1 leads to dysregulated HOX expression via a different mechanism than MLL rearrangement.

Standard name | MULLIGHAN_NPM1_MUTATED_SIGNATURE_2_UP
Systematic name | M6590
Organism | Homo sapiens
PMID | 17597811
Authors | Mullighan CG,Kennedy A,Zhou X,Radtke I,Phillips LA,Shurtleff SA,Downing JR
Category | C2
Sub-category | CGP
Brief description | The 'NPM1-mutated signature 2': genes up-regulated in pediatric AML (acute myeloid leukemia) samples with mutated NPM1 [GeneID=4869] compared to the AML cases with the intact gene and without recurring cytogenetic anomalities or M7 phenotype.
Full description | Somatic mutations in nucleophosmin (NPM1) occur in approximately 35% of adult acute myeloid leukemia (AML). To assess the frequency of NPM1 mutations in pediatric AML, we sequenced NPM1 in the diagnostic blasts from 93 pediatric AML patients. Six cases harbored NPM1 mutations, with each case lacking common cytogenetic abnormalities. To explore the phenotype of the AMLs with NPM1 mutations, gene expression profiles were obtained using Affymetrix U133A microarrays. NPM1 mutations were associated with increased expression of multiple homeobox genes including HOXA9, A10, B2, B6 and MEIS1. As dysregulated homeobox gene expression is also a feature of MLL-rearranged leukemia, the gene expression signatures of NPM1-mutated and MLL-rearranged leukemias were compared. Significant differences were identified between these leukemia subtypes including the expression of different HOX genes, with NPM1-mutated AML showing higher levels of expression of HOXB2, B3, B6 and D4. These results confirm recent reports of perturbed HOX expression in NPM1-mutated adult AML, and provide the first evidence that the NPM1-mutated signature is distinct from MLL-rearranged AML. These findings suggest that mutated NPM1 leads to dysregulated HOX expression via a different mechanism than MLL rearrangement.

Standard name | MULLIGHAN_NPM1_MUTATED_SIGNATURE_2_DN
Systematic name | M8315
Organism | Homo sapiens
PMID | 17597811
Authors | Mullighan CG,Kennedy A,Zhou X,Radtke I,Phillips LA,Shurtleff SA,Downing JR
Category | C2
Sub-category | CGP
Brief description | The 'NPM1-mutated signature 2': genes down-regulated in pediatric AML (acute myeloid leukemia) samples with mutated NPM1 [GeneID=4869] compared to the AML cases with the intact gene and without recurring cytogenetic anomalities or M7 phenotype.
Full description | Somatic mutations in nucleophosmin (NPM1) occur in approximately 35% of adult acute myeloid leukemia (AML). To assess the frequency of NPM1 mutations in pediatric AML, we sequenced NPM1 in the diagnostic blasts from 93 pediatric AML patients. Six cases harbored NPM1 mutations, with each case lacking common cytogenetic abnormalities. To explore the phenotype of the AMLs with NPM1 mutations, gene expression profiles were obtained using Affymetrix U133A microarrays. NPM1 mutations were associated with increased expression of multiple homeobox genes including HOXA9, A10, B2, B6 and MEIS1. As dysregulated homeobox gene expression is also a feature of MLL-rearranged leukemia, the gene expression signatures of NPM1-mutated and MLL-rearranged leukemias were compared. Significant differences were identified between these leukemia subtypes including the expression of different HOX genes, with NPM1-mutated AML showing higher levels of expression of HOXB2, B3, B6 and D4. These results confirm recent reports of perturbed HOX expression in NPM1-mutated adult AML, and provide the first evidence that the NPM1-mutated signature is distinct from MLL-rearranged AML. These findings suggest that mutated NPM1 leads to dysregulated HOX expression via a different mechanism than MLL rearrangement.

Standard name | MULLIGHAN_MLL_SIGNATURE_1_UP
Systematic name | M17856
Organism | Homo sapiens
PMID | 17597811
Authors | Mullighan CG,Kennedy A,Zhou X,Radtke I,Phillips LA,Shurtleff SA,Downing JR
Category | C2
Sub-category | CGP
Brief description | The 'MLL signature 1': genes up-regulated in pediatric AML (acute myeloid leukemia) with rearranged MLL [GeneID=4297] compared to all AML cases with the intact gene.
Full description | Somatic mutations in nucleophosmin (NPM1) occur in approximately 35% of adult acute myeloid leukemia (AML). To assess the frequency of NPM1 mutations in pediatric AML, we sequenced NPM1 in the diagnostic blasts from 93 pediatric AML patients. Six cases harbored NPM1 mutations, with each case lacking common cytogenetic abnormalities. To explore the phenotype of the AMLs with NPM1 mutations, gene expression profiles were obtained using Affymetrix U133A microarrays. NPM1 mutations were associated with increased expression of multiple homeobox genes including HOXA9, A10, B2, B6 and MEIS1. As dysregulated homeobox gene expression is also a feature of MLL-rearranged leukemia, the gene expression signatures of NPM1-mutated and MLL-rearranged leukemias were compared. Significant differences were identified between these leukemia subtypes including the expression of different HOX genes, with NPM1-mutated AML showing higher levels of expression of HOXB2, B3, B6 and D4. These results confirm recent reports of perturbed HOX expression in NPM1-mutated adult AML, and provide the first evidence that the NPM1-mutated signature is distinct from MLL-rearranged AML. These findings suggest that mutated NPM1 leads to dysregulated HOX expression via a different mechanism than MLL rearrangement.

Standard name | MULLIGHAN_MLL_SIGNATURE_1_DN
Systematic name | M18841
Organism | Homo sapiens
PMID | 17597811
Authors | Mullighan CG,Kennedy A,Zhou X,Radtke I,Phillips LA,Shurtleff SA,Downing JR
Category | C2
Sub-category | CGP
Brief description | The 'MLL signature 1': genes down-regulated in pediatric AML (acute myeloid leukemia) with rearranged MLL [GeneID=4297] compared to all AML cases with the intact gene.
Full description | Somatic mutations in nucleophosmin (NPM1) occur in approximately 35% of adult acute myeloid leukemia (AML). To assess the frequency of NPM1 mutations in pediatric AML, we sequenced NPM1 in the diagnostic blasts from 93 pediatric AML patients. Six cases harbored NPM1 mutations, with each case lacking common cytogenetic abnormalities. To explore the phenotype of the AMLs with NPM1 mutations, gene expression profiles were obtained using Affymetrix U133A microarrays. NPM1 mutations were associated with increased expression of multiple homeobox genes including HOXA9, A10, B2, B6 and MEIS1. As dysregulated homeobox gene expression is also a feature of MLL-rearranged leukemia, the gene expression signatures of NPM1-mutated and MLL-rearranged leukemias were compared. Significant differences were identified between these leukemia subtypes including the expression of different HOX genes, with NPM1-mutated AML showing higher levels of expression of HOXB2, B3, B6 and D4. These results confirm recent reports of perturbed HOX expression in NPM1-mutated adult AML, and provide the first evidence that the NPM1-mutated signature is distinct from MLL-rearranged AML. These findings suggest that mutated NPM1 leads to dysregulated HOX expression via a different mechanism than MLL rearrangement.

Standard name | MULLIGHAN_MLL_SIGNATURE_2_UP
Systematic name | M3053
Organism | Homo sapiens
PMID | 17597811
Authors | Mullighan CG,Kennedy A,Zhou X,Radtke I,Phillips LA,Shurtleff SA,Downing JR
Category | C2
Sub-category | CGP
Brief description | The 'MLL signature 2': genes up-regulated in pediatric AML (acute myeloid leukemia) with rearranged MLL [GeneID=4297] compared to the AML cases with intact MLL and NPM1 [GeneID=4869].
Full description | Somatic mutations in nucleophosmin (NPM1) occur in approximately 35% of adult acute myeloid leukemia (AML). To assess the frequency of NPM1 mutations in pediatric AML, we sequenced NPM1 in the diagnostic blasts from 93 pediatric AML patients. Six cases harbored NPM1 mutations, with each case lacking common cytogenetic abnormalities. To explore the phenotype of the AMLs with NPM1 mutations, gene expression profiles were obtained using Affymetrix U133A microarrays. NPM1 mutations were associated with increased expression of multiple homeobox genes including HOXA9, A10, B2, B6 and MEIS1. As dysregulated homeobox gene expression is also a feature of MLL-rearranged leukemia, the gene expression signatures of NPM1-mutated and MLL-rearranged leukemias were compared. Significant differences were identified between these leukemia subtypes including the expression of different HOX genes, with NPM1-mutated AML showing higher levels of expression of HOXB2, B3, B6 and D4. These results confirm recent reports of perturbed HOX expression in NPM1-mutated adult AML, and provide the first evidence that the NPM1-mutated signature is distinct from MLL-rearranged AML. These findings suggest that mutated NPM1 leads to dysregulated HOX expression via a different mechanism than MLL rearrangement.

Standard name | MULLIGHAN_MLL_SIGNATURE_2_DN
Systematic name | M16867
Organism | Homo sapiens
PMID | 17597811
Authors | Mullighan CG,Kennedy A,Zhou X,Radtke I,Phillips LA,Shurtleff SA,Downing JR
Category | C2
Sub-category | CGP
Brief description | The 'MLL signature 2': genes down-regulated in pediatric AML (acute myeloid leukemia) with rearranged MLL [GeneID=4297] compared to the AML cases with intact MLL and NPM1 [GeneID=4869].
Full description | Somatic mutations in nucleophosmin (NPM1) occur in approximately 35% of adult acute myeloid leukemia (AML). To assess the frequency of NPM1 mutations in pediatric AML, we sequenced NPM1 in the diagnostic blasts from 93 pediatric AML patients. Six cases harbored NPM1 mutations, with each case lacking common cytogenetic abnormalities. To explore the phenotype of the AMLs with NPM1 mutations, gene expression profiles were obtained using Affymetrix U133A microarrays. NPM1 mutations were associated with increased expression of multiple homeobox genes including HOXA9, A10, B2, B6 and MEIS1. As dysregulated homeobox gene expression is also a feature of MLL-rearranged leukemia, the gene expression signatures of NPM1-mutated and MLL-rearranged leukemias were compared. Significant differences were identified between these leukemia subtypes including the expression of different HOX genes, with NPM1-mutated AML showing higher levels of expression of HOXB2, B3, B6 and D4. These results confirm recent reports of perturbed HOX expression in NPM1-mutated adult AML, and provide the first evidence that the NPM1-mutated signature is distinct from MLL-rearranged AML. These findings suggest that mutated NPM1 leads to dysregulated HOX expression via a different mechanism than MLL rearrangement.

Standard name | MULLIGHAN_NPM1_SIGNATURE_3_UP
Systematic name | M10277
Organism | Homo sapiens
PMID | 17597811
Authors | Mullighan CG,Kennedy A,Zhou X,Radtke I,Phillips LA,Shurtleff SA,Downing JR
Category | C2
Sub-category | CGP
Brief description | The 'NPM1 signature 3': genes up-regulated in pediatric AML (acute myeloid leukemia) with mutated NPM1 [GeneID=4869] compared to the AML cases with intact NPM1 and MLL [GeneID=4297].
Full description | Somatic mutations in nucleophosmin (NPM1) occur in approximately 35% of adult acute myeloid leukemia (AML). To assess the frequency of NPM1 mutations in pediatric AML, we sequenced NPM1 in the diagnostic blasts from 93 pediatric AML patients. Six cases harbored NPM1 mutations, with each case lacking common cytogenetic abnormalities. To explore the phenotype of the AMLs with NPM1 mutations, gene expression profiles were obtained using Affymetrix U133A microarrays. NPM1 mutations were associated with increased expression of multiple homeobox genes including HOXA9, A10, B2, B6 and MEIS1. As dysregulated homeobox gene expression is also a feature of MLL-rearranged leukemia, the gene expression signatures of NPM1-mutated and MLL-rearranged leukemias were compared. Significant differences were identified between these leukemia subtypes including the expression of different HOX genes, with NPM1-mutated AML showing higher levels of expression of HOXB2, B3, B6 and D4. These results confirm recent reports of perturbed HOX expression in NPM1-mutated adult AML, and provide the first evidence that the NPM1-mutated signature is distinct from MLL-rearranged AML. These findings suggest that mutated NPM1 leads to dysregulated HOX expression via a different mechanism than MLL rearrangement.

Standard name | MULLIGHAN_NPM1_SIGNATURE_3_DN
Systematic name | M15047
Organism | Homo sapiens
PMID | 17597811
Authors | Mullighan CG,Kennedy A,Zhou X,Radtke I,Phillips LA,Shurtleff SA,Downing JR
Category | C2
Sub-category | CGP
Brief description | The 'NPM1 signature 3': genes down-regulated in pediatric AML (acute myeloid leukemia) with mutated NPM1 [GeneID=4869] compared to the AML cases with intact NPM1 and MLL [GeneID=4297].
Full description | Somatic mutations in nucleophosmin (NPM1) occur in approximately 35% of adult acute myeloid leukemia (AML). To assess the frequency of NPM1 mutations in pediatric AML, we sequenced NPM1 in the diagnostic blasts from 93 pediatric AML patients. Six cases harbored NPM1 mutations, with each case lacking common cytogenetic abnormalities. To explore the phenotype of the AMLs with NPM1 mutations, gene expression profiles were obtained using Affymetrix U133A microarrays. NPM1 mutations were associated with increased expression of multiple homeobox genes including HOXA9, A10, B2, B6 and MEIS1. As dysregulated homeobox gene expression is also a feature of MLL-rearranged leukemia, the gene expression signatures of NPM1-mutated and MLL-rearranged leukemias were compared. Significant differences were identified between these leukemia subtypes including the expression of different HOX genes, with NPM1-mutated AML showing higher levels of expression of HOXB2, B3, B6 and D4. These results confirm recent reports of perturbed HOX expression in NPM1-mutated adult AML, and provide the first evidence that the NPM1-mutated signature is distinct from MLL-rearranged AML. These findings suggest that mutated NPM1 leads to dysregulated HOX expression via a different mechanism than MLL rearrangement.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_SUSTAINED_IN_GRANULOCYTE_UP
Systematic name | M5395
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by RUNX1-RUNX1T1 [GeneID=861;862] fusion protein in normal hematopoietic progenitors; their expression was sustained in subsequently developing granulocytes.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_SUSTAINED_IN_GRANULOCYTE_DN
Systematic name | M6161
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by RUNX1-RUNX1T1 [GeneID=861;862] fusion protein in normal hematopoietic progenitors; their expression was sustained in subsequently developing granulocytes.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_HSC_UP
Systematic name | M3804
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in normal hematopoietic progenitors by RUNX1-RUNX1T1 [GeneID=861;862] fusion.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_HSC_DN
Systematic name | M4723
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in normal hematopoietic progenitors by RUNX1-RUNX1T1 [GeneID=861;862] fusion.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_GRANULOCYTE_UP
Systematic name | M4661
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in granulocytes by RUNX1-RUNX1T1 [GeneID=861;862] fusion.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_GRANULOCYTE_DN
Systematic name | M17148
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in granulocytes by RUNX1-RUNX1T1 [GeneID=861;862] fusion.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_MONOCYTE_UP
Systematic name | M10184
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in monocytes by RUNX1-RUNX1T1 [GeneID=861;862] fusion.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_MONOCYTE_DN
Systematic name | M14036
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in monocytes by RUNX1-RUNX1T1 [GeneID=861;862] fusion.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_ERYTHROCYTE_UP
Systematic name | M12138
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in erythroid lineage cells by RUNX1-RUNX1T1 [GeneID=861;862] fusion .
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_ERYTHROCYTE_DN
Systematic name | M12090
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in erythroid lineage cells by RUNX1-RUNX1T1 [GeneID=861;862] fusion .
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_SUSTAINED_IN_MONOCYTE_UP
Systematic name | M7176
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by RUNX1-RUNX1T1 [GeneID=861;862] fusion protein in normal hematopoietic progenitors; their expression was sustained in subsequently developing monocytes.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_SUSTAINED_IN_MONOCYTE_DN
Systematic name | M4223
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by RUNX1-RUNX1T1 [GeneID=861;862] fusion protein in normal hematopoietic progenitors; their expression was sustained in subsequently developing monocytes.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | TONKS_TARGETS_OF_RUNX1_RUNX1T1_FUSION_SUSTAINDED_IN_ERYTHROCYTE_UP
Systematic name | M12085
Organism | Homo sapiens
PMID | 17898786
Authors | Tonks A,Pearn L,Musson M,Gilkes A,Mills KI,Burnett AK,Darley RL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by RUNX1-RUNX1T1 [GeneID=861;862] fusion protein in normal hematopoietic progenitors; their expression was sustained in subsequently developing erythroid lineage.
Full description | The t(8;21)(q22;q22) occurs frequently in acute myelogenous leukaemia and gives rise to the transcription factor fusion protein, RUNX1-RUNX1T1 (also known as AML1-ETO). To identify the genes dysregulated by the aberrant transcriptional activity of RUNX1-RUNX1T1, we used microarrays to determine the effect of this mutation on gene expression in human progenitor cells and during subsequent development. Gene signatures of these developmental subsets were very dissimilar indicating that effects of RUNX1-RUNX1T1 are highly context dependent. We focused on gene changes associated with the granulocytic lineage and identified a clinically relevant subset of these by comparison with 235 leukaemia patient transcriptional signatures. We confirmed the overexpression of a number of significant genes (Sox4, IL-17BR, CD200 and gamma-catenin). Further, we show that overexpression of CD200 and gamma-catenin is also associated with the inv(16) abnormality which like RUNX1-RUNX1T1 disrupts core binding factor activity. We investigated the functional significance of CD200 and gamma-catenin overexpression in normal human progenitor cells. The effect of IL17 on growth was also assessed. Individually, none of these changes were sufficient to recapitulate the effects of RUNX1-RUNX1T1 on normal development. These data provide the most comprehensive and pertinent assessment of the effect of RUNX1-RUNX1T1 on gene expression and demonstrate the highly context-dependent effects of this fusion gene.

Standard name | LOPEZ_MESOTHELIOMA_SURVIVAL_WORST_VS_BEST_UP
Systematic name | M15226
Organism | Homo sapiens
PMID | 16540645
Authors | López-Ríos F,Chuai S,Flores R,Shimizu S,Ohno T,Wakahara K,Illei PB,Hussain S,Krug L,Zakowski MF,Rusch V,Olshen AB,Ladanyi M
Category | C2
Sub-category | CGP
Brief description | Genes higher expressed in the worst 25 mesothelioma survivors compared to the 25 best ones.
Full description | Most gene expression profiling studies of mesothelioma have been based on relatively small sample numbers, limiting their statistical power. We did Affymetrix U133A microarray analysis on 99 pleural mesotheliomas, in which multivariate analysis showed advanced-stage, sarcomatous histology and P16/CDKN2A homozygous deletion to be significant independent adverse prognostic factors. Comparison of the expression profiles of epithelioid versus sarcomatous mesotheliomas identified many genes significantly overexpressed among the former, including previously unrecognized ones, such as uroplakins and kallikrein 11, both confirmed by immunohistochemistry. Examination of the gene expression correlates of survival showed that more aggressive mesotheliomas expressed higher levels of Aurora kinases A and B and functionally related genes involved in mitosis and cell cycle control. Independent confirmation of the negative effect of Aurora kinase B was obtained by immunohistochemistry in a separate patient cohort. A role for Aurora kinases in the aggressive behavior of mesotheliomas is of potential clinical interest because of the recent development of small-molecule inhibitors. We then used our data to develop microarray-based predictors of 1 year survival; these achieved a maximal accuracy of 68% in cross-validation. However, this was inferior to prognostic prediction based on standard clinicopathologic variables and P16/CDNK2A status (accuracy, 73%), and adding the microarray model to the latter did not improve overall accuracy. Finally, we evaluated three recently published microarray-based outcome prediction models, but their accuracies ranged from 63% to 67%, consistently lower than reported. Gene expression profiling of mesotheliomas is an important discovery tool, but its power in clinical prognostication has been overestimated.

Standard name | LOPEZ_MESOTHELIOMA_SURVIVAL_WORST_VS_BEST_DN
Systematic name | M7057
Organism | Homo sapiens
PMID | 16540645
Authors | López-Ríos F,Chuai S,Flores R,Shimizu S,Ohno T,Wakahara K,Illei PB,Hussain S,Krug L,Zakowski MF,Rusch V,Olshen AB,Ladanyi M
Category | C2
Sub-category | CGP
Brief description | Genes higher expressed in the best 25 mesothelioma survivors compared to the 25 worst ones.
Full description | Most gene expression profiling studies of mesothelioma have been based on relatively small sample numbers, limiting their statistical power. We did Affymetrix U133A microarray analysis on 99 pleural mesotheliomas, in which multivariate analysis showed advanced-stage, sarcomatous histology and P16/CDKN2A homozygous deletion to be significant independent adverse prognostic factors. Comparison of the expression profiles of epithelioid versus sarcomatous mesotheliomas identified many genes significantly overexpressed among the former, including previously unrecognized ones, such as uroplakins and kallikrein 11, both confirmed by immunohistochemistry. Examination of the gene expression correlates of survival showed that more aggressive mesotheliomas expressed higher levels of Aurora kinases A and B and functionally related genes involved in mitosis and cell cycle control. Independent confirmation of the negative effect of Aurora kinase B was obtained by immunohistochemistry in a separate patient cohort. A role for Aurora kinases in the aggressive behavior of mesotheliomas is of potential clinical interest because of the recent development of small-molecule inhibitors. We then used our data to develop microarray-based predictors of 1 year survival; these achieved a maximal accuracy of 68% in cross-validation. However, this was inferior to prognostic prediction based on standard clinicopathologic variables and P16/CDNK2A status (accuracy, 73%), and adding the microarray model to the latter did not improve overall accuracy. Finally, we evaluated three recently published microarray-based outcome prediction models, but their accuracies ranged from 63% to 67%, consistently lower than reported. Gene expression profiling of mesotheliomas is an important discovery tool, but its power in clinical prognostication has been overestimated.

Standard name | PAPASPYRIDONOS_UNSTABLE_ATEROSCLEROTIC_PLAQUE_UP
Systematic name | M9936
Organism | Homo sapiens
PMID | 16741146
Authors | Papaspyridonos M,Smith A,Burnand KG,Taylor P,Padayachee S,Suckling KE,James CH,Greaves DR,Patel L
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in unstable ateroslerotic plaques compared to the stable ones.
Full description | OBJECTIVE: Comparison of gene expression in stable versus unstable atherosclerotic plaque may be confounded by interpatient variability. The aim of this study was to identify differences in gene expression between stable and unstable segments of plaque obtained from the same patient. METHODS AND RESULTS: Human carotid endarterectomy specimens were segmented and macroscopically classified using a morphological classification system. Two analytical methods, an intraplaque and an interplaque analysis, revealed 170 and 1916 differentially expressed genes, respectively using Affymetrix gene chip analysis. A total of 115 genes were identified from both analyses. The differential expression of 27 genes was also confirmed using quantitative-polymerase chain reaction on a larger panel of samples. Eighteen of these genes have not been associated previously with plaque instability, including the metalloproteinase, ADAMDEC1 (approximately 37-fold), retinoic acid receptor responder-1 (approximately 5-fold), and cysteine protease legumain (approximately 3-fold). Matrix metalloproteinase-9 (MMP-9), cathepsin B, and a novel gene, legumain, a potential activator of MMPs and cathepsins, were also confirmed at the protein level. CONCLUSIONS: The differential expression of 18 genes not previously associated with plaque rupture has been confirmed in stable and unstable regions of the same atherosclerotic plaque. These genes may represent novel targets for the treatment of unstable plaque or useful diagnostic markers of plaque instability.

Standard name | PAPASPYRIDONOS_UNSTABLE_ATEROSCLEROTIC_PLAQUE_DN
Systematic name | M12432
Organism | Homo sapiens
PMID | 16741146
Authors | Papaspyridonos M,Smith A,Burnand KG,Taylor P,Padayachee S,Suckling KE,James CH,Greaves DR,Patel L
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in unstable ateroslerotic plaques compared to the stable ones.
Full description | OBJECTIVE: Comparison of gene expression in stable versus unstable atherosclerotic plaque may be confounded by interpatient variability. The aim of this study was to identify differences in gene expression between stable and unstable segments of plaque obtained from the same patient. METHODS AND RESULTS: Human carotid endarterectomy specimens were segmented and macroscopically classified using a morphological classification system. Two analytical methods, an intraplaque and an interplaque analysis, revealed 170 and 1916 differentially expressed genes, respectively using Affymetrix gene chip analysis. A total of 115 genes were identified from both analyses. The differential expression of 27 genes was also confirmed using quantitative-polymerase chain reaction on a larger panel of samples. Eighteen of these genes have not been associated previously with plaque instability, including the metalloproteinase, ADAMDEC1 (approximately 37-fold), retinoic acid receptor responder-1 (approximately 5-fold), and cysteine protease legumain (approximately 3-fold). Matrix metalloproteinase-9 (MMP-9), cathepsin B, and a novel gene, legumain, a potential activator of MMPs and cathepsins, were also confirmed at the protein level. CONCLUSIONS: The differential expression of 18 genes not previously associated with plaque rupture has been confirmed in stable and unstable regions of the same atherosclerotic plaque. These genes may represent novel targets for the treatment of unstable plaque or useful diagnostic markers of plaque instability.

Standard name | DITTMER_PTHLH_TARGETS_UP
Systematic name | M11090
Organism | Homo sapiens
PMID | 16551631
Authors | Dittmer A,Vetter M,Schunke D,Span PN,Sweep F,Thomssen C,Dittmer J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MDA-MB-231 cells (breast cancer) after knockdown of PTHLH [GeneID=5744] by RNAi.
Full description | The effect of endogenous parathyroid hormone-related protein (PTHrP) on gene expression in breast cancer cells was studied. We suppressed PTHrP expression in MDA-MB-231 cells by RNA interference and analyzed changes in gene expression by microarray analysis. More than 200 genes showed altered expression in response to a PTHrP-specific small interfering (si) RNA (siPTHrP). Cell cycle-regulating gene CDC2 and genes (CDC25B and Tome-1) that control CDC2 activity showed increased expression in the presence of siPTHrP. CDC2 activity was also found to be higher in siPTHrP-treated cells. Studies with PTHrP peptides 1-34 and 67-86, forskolin, and a PTH1 receptor (PTH1R)-specific siRNA showed that PTHrP regulates CDC2 and CDC25B, at least in part, via PTH1R in a cAMP-independent manner. Other siPTHrP-responsive genes included integrin alpha6 (ITGA6), KISS-1, and PAI-1. When combined, siRNAs against ITGA6, PAI-1, and KISS-1 could mimic the negative effect of siPTHrP on migration, whereas siKISS-1 and siPTHrP similarly reduced the proliferative activity of the cells. Comparative expression analyses with 50 primary breast carcinomas revealed that the RNA level of ITGA6 correlates with that of PTHrP, and higher CDC2 and CDC25B values are found at low PTHrP expression. Our data suggest that PTHrP has a profound effect on gene expression in breast cancer cells and, as a consequence, contributes to the regulation of important cellular activities, such as migration and proliferation.

Standard name | DITTMER_PTHLH_TARGETS_DN
Systematic name | M18667
Organism | Homo sapiens
PMID | 16551631
Authors | Dittmer A,Vetter M,Schunke D,Span PN,Sweep F,Thomssen C,Dittmer J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MDA-MB-231 cells (breast cancer) after knockdown of PTHLH [GeneID=5744] by RNAi.
Full description | The effect of endogenous parathyroid hormone-related protein (PTHrP) on gene expression in breast cancer cells was studied. We suppressed PTHrP expression in MDA-MB-231 cells by RNA interference and analyzed changes in gene expression by microarray analysis. More than 200 genes showed altered expression in response to a PTHrP-specific small interfering (si) RNA (siPTHrP). Cell cycle-regulating gene CDC2 and genes (CDC25B and Tome-1) that control CDC2 activity showed increased expression in the presence of siPTHrP. CDC2 activity was also found to be higher in siPTHrP-treated cells. Studies with PTHrP peptides 1-34 and 67-86, forskolin, and a PTH1 receptor (PTH1R)-specific siRNA showed that PTHrP regulates CDC2 and CDC25B, at least in part, via PTH1R in a cAMP-independent manner. Other siPTHrP-responsive genes included integrin alpha6 (ITGA6), KISS-1, and PAI-1. When combined, siRNAs against ITGA6, PAI-1, and KISS-1 could mimic the negative effect of siPTHrP on migration, whereas siKISS-1 and siPTHrP similarly reduced the proliferative activity of the cells. Comparative expression analyses with 50 primary breast carcinomas revealed that the RNA level of ITGA6 correlates with that of PTHrP, and higher CDC2 and CDC25B values are found at low PTHrP expression. Our data suggest that PTHrP has a profound effect on gene expression in breast cancer cells and, as a consequence, contributes to the regulation of important cellular activities, such as migration and proliferation.

Standard name | UDAYAKUMAR_MED1_TARGETS_UP
Systematic name | M3909
Organism | Homo sapiens
PMID | 16574658
Authors | Udayakumar TS,Belakavadi M,Choi KH,Pandey PK,Fondell JD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HeLa cells after knockdown of MED1 [GeneID=5469] by RNAi.
Full description | The TRAP/Mediator coactivator complex serves as a functional interface between DNA-bound transactivators and the RNA polymerase II-associated basal transcription apparatus. TRAP220/MED1 is a variably associated subunit of the complex that plays a specialized role in selectively targeting TRAP/Mediator to specific genes. Ablation of the Trap220/Med1 gene in mice impairs embryonic cell growth, yet the underlying mechanism is unknown. In this report, we identified distinct cell growth regulatory genes whose expression is affected by the loss of TRAP220/MED1 by RNA interference. Among the down-regulated genes revealed by cDNA microarray analyses, we identified Aurora-A, a centrosome kinase that plays a critical role in regulating M phase events and is frequently amplified in several types of cancer. In general, we found that TRAP220/MED1 expression is required for high basal levels of Aurora-A gene expression and that ectopic overexpression of TRAP220/MED1 coactivates transcription from the Aurora-A gene promoter. Furthermore, chromatin immunoprecipitation assays show that TRAP220/MED1-containing TRAP/Mediator complexes directly bind to the Aurora-A promoter in vivo. Finally, we present evidence suggesting that TRAP/Mediator is recruited to the Aurora-A gene via direct interactions between TRAP220/MED1 and the Ets-related transcription factor GABP. Taken together, these findings suggest that TRAP220/MED1 plays a novel coregulatory role in facilitating the recruitment of TRAP/Mediator to specific target genes involved in growth and cell cycle progression.

Standard name | UDAYAKUMAR_MED1_TARGETS_DN
Systematic name | M9945
Organism | Homo sapiens
PMID | 16574658
Authors | Udayakumar TS,Belakavadi M,Choi KH,Pandey PK,Fondell JD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HeLa cells after knockdown of MED1 [GeneID=5469] by RNAi.
Full description | The TRAP/Mediator coactivator complex serves as a functional interface between DNA-bound transactivators and the RNA polymerase II-associated basal transcription apparatus. TRAP220/MED1 is a variably associated subunit of the complex that plays a specialized role in selectively targeting TRAP/Mediator to specific genes. Ablation of the Trap220/Med1 gene in mice impairs embryonic cell growth, yet the underlying mechanism is unknown. In this report, we identified distinct cell growth regulatory genes whose expression is affected by the loss of TRAP220/MED1 by RNA interference. Among the down-regulated genes revealed by cDNA microarray analyses, we identified Aurora-A, a centrosome kinase that plays a critical role in regulating M phase events and is frequently amplified in several types of cancer. In general, we found that TRAP220/MED1 expression is required for high basal levels of Aurora-A gene expression and that ectopic overexpression of TRAP220/MED1 coactivates transcription from the Aurora-A gene promoter. Furthermore, chromatin immunoprecipitation assays show that TRAP220/MED1-containing TRAP/Mediator complexes directly bind to the Aurora-A promoter in vivo. Finally, we present evidence suggesting that TRAP/Mediator is recruited to the Aurora-A gene via direct interactions between TRAP220/MED1 and the Ets-related transcription factor GABP. Taken together, these findings suggest that TRAP220/MED1 plays a novel coregulatory role in facilitating the recruitment of TRAP/Mediator to specific target genes involved in growth and cell cycle progression.

Standard name | ODONNELL_TFRC_TARGETS_UP
Systematic name | M6753
Organism | Homo sapiens
PMID | 16508012
Authors | O'Donnell KA,Yu D,Zeller KI,Kim JW,Racke F,Thomas-Tikhonenko A,Dang CV
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in P493-6 cells (B lymphocyte, Burkitt's lymphoma model) upon knockdown of TFRC [GeneID=7037] by RNAi.
Full description | Overexpression of transferrin receptor 1 (TFRC1), a major mediator of iron uptake in mammalian cells, is a common feature of human malignancies. Therapeutic strategies designed to interfere with tumor iron metabolism have targeted TFRC1. The c-Myc oncogenic transcription factor stimulates proliferation and growth by activating thousands of target genes. Here we demonstrate that TFRC1 is a critical downstream target of c-Myc. Using in vitro and in vivo models of B-cell lymphoma, we show that TFRC1 expression is activated by c-Myc. Chromatin immunoprecipitation experiments reveal that c-Myc directly binds a conserved region of TFRC1. In light of these findings, we sought to determine whether TFRC1 is required for c-Myc-mediated cellular proliferation and cell size control. TFRC1 inhibition decreases cellular proliferation and results in G1 arrest without affecting cell size. Consistent with these findings, expression profiling reveals that TFRC1 depletion alters expression of genes that regulate the cell cycle. Furthermore, enforced TFRC1 expression confers a growth advantage to cells and significantly enhances the rate of c-Myc-mediated tumor formation in vivo. These findings provide a molecular basis for increased TFRC1 expression in human tumors, illuminate the role of TFRC1 in the c-Myc target gene network, and support strategies that target TFRC1 for cancer therapy.

Standard name | ODONNELL_TFRC_TARGETS_DN
Systematic name | M6451
Organism | Homo sapiens
PMID | 16508012
Authors | O'Donnell KA,Yu D,Zeller KI,Kim JW,Racke F,Thomas-Tikhonenko A,Dang CV
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in P493-6 cells (B lymphocyte, Burkitt's lymphoma model) upon knockdown of TFRC [GeneID=7037] by RNAi.
Full description | Overexpression of transferrin receptor 1 (TFRC1), a major mediator of iron uptake in mammalian cells, is a common feature of human malignancies. Therapeutic strategies designed to interfere with tumor iron metabolism have targeted TFRC1. The c-Myc oncogenic transcription factor stimulates proliferation and growth by activating thousands of target genes. Here we demonstrate that TFRC1 is a critical downstream target of c-Myc. Using in vitro and in vivo models of B-cell lymphoma, we show that TFRC1 expression is activated by c-Myc. Chromatin immunoprecipitation experiments reveal that c-Myc directly binds a conserved region of TFRC1. In light of these findings, we sought to determine whether TFRC1 is required for c-Myc-mediated cellular proliferation and cell size control. TFRC1 inhibition decreases cellular proliferation and results in G1 arrest without affecting cell size. Consistent with these findings, expression profiling reveals that TFRC1 depletion alters expression of genes that regulate the cell cycle. Furthermore, enforced TFRC1 expression confers a growth advantage to cells and significantly enhances the rate of c-Myc-mediated tumor formation in vivo. These findings provide a molecular basis for increased TFRC1 expression in human tumors, illuminate the role of TFRC1 in the c-Myc target gene network, and support strategies that target TFRC1 for cancer therapy.

Standard name | ODONNELL_TARGETS_OF_MYC_AND_TFRC_UP
Systematic name | M13183
Organism | Homo sapiens
PMID | 16508012
Authors | O'Donnell KA,Yu D,Zeller KI,Kim JW,Racke F,Thomas-Tikhonenko A,Dang CV
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in P493-6 cells (B lymphocyte, Burkitt's lymphoma model) by MYC [GeneID=4609] and up-regulated by RNAi knockdown of TFRC [GeneID=7037].
Full description | Overexpression of transferrin receptor 1 (TFRC1), a major mediator of iron uptake in mammalian cells, is a common feature of human malignancies. Therapeutic strategies designed to interfere with tumor iron metabolism have targeted TFRC1. The c-Myc oncogenic transcription factor stimulates proliferation and growth by activating thousands of target genes. Here we demonstrate that TFRC1 is a critical downstream target of c-Myc. Using in vitro and in vivo models of B-cell lymphoma, we show that TFRC1 expression is activated by c-Myc. Chromatin immunoprecipitation experiments reveal that c-Myc directly binds a conserved region of TFRC1. In light of these findings, we sought to determine whether TFRC1 is required for c-Myc-mediated cellular proliferation and cell size control. TFRC1 inhibition decreases cellular proliferation and results in G1 arrest without affecting cell size. Consistent with these findings, expression profiling reveals that TFRC1 depletion alters expression of genes that regulate the cell cycle. Furthermore, enforced TFRC1 expression confers a growth advantage to cells and significantly enhances the rate of c-Myc-mediated tumor formation in vivo. These findings provide a molecular basis for increased TFRC1 expression in human tumors, illuminate the role of TFRC1 in the c-Myc target gene network, and support strategies that target TFRC1 for cancer therapy.

Standard name | ODONNELL_TARGETS_OF_MYC_AND_TFRC_DN
Systematic name | M6792
Organism | Homo sapiens
PMID | 16508012
Authors | O'Donnell KA,Yu D,Zeller KI,Kim JW,Racke F,Thomas-Tikhonenko A,Dang CV
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in P493-6 cells (B lymphocyte, Burkitt's lymphoma model) by MYC [GeneID=4609] and down-regulated by RNAi knockdown of TFRC [GeneID=7037].
Full description | Overexpression of transferrin receptor 1 (TFRC1), a major mediator of iron uptake in mammalian cells, is a common feature of human malignancies. Therapeutic strategies designed to interfere with tumor iron metabolism have targeted TFRC1. The c-Myc oncogenic transcription factor stimulates proliferation and growth by activating thousands of target genes. Here we demonstrate that TFRC1 is a critical downstream target of c-Myc. Using in vitro and in vivo models of B-cell lymphoma, we show that TFRC1 expression is activated by c-Myc. Chromatin immunoprecipitation experiments reveal that c-Myc directly binds a conserved region of TFRC1. In light of these findings, we sought to determine whether TFRC1 is required for c-Myc-mediated cellular proliferation and cell size control. TFRC1 inhibition decreases cellular proliferation and results in G1 arrest without affecting cell size. Consistent with these findings, expression profiling reveals that TFRC1 depletion alters expression of genes that regulate the cell cycle. Furthermore, enforced TFRC1 expression confers a growth advantage to cells and significantly enhances the rate of c-Myc-mediated tumor formation in vivo. These findings provide a molecular basis for increased TFRC1 expression in human tumors, illuminate the role of TFRC1 in the c-Myc target gene network, and support strategies that target TFRC1 for cancer therapy.

Standard name | SENESE_HDAC1_TARGETS_UP
Systematic name | M14973
Organism | Homo sapiens
PMID | 17470557
Authors | Senese S,Zaragoza K,Minardi S,Muradore I,Ronzoni S,Passafaro A,Bernard L,Draetta GF,Alcalay M,Seiser C,Chiocca S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in U2OS cells (osteosarcoma) upon knockdown of HDAC1 [GeneID=3065] by RNAi.
Full description | Posttranslational modifications of core histones are central to the regulation of gene expression. Histone deacetylases (HDACs) repress transcription by deacetylating histones, and class I HDACs have a crucial role in mouse, Xenopus laevis, zebra fish, and Caenorhabditis elegans development. The role of individual class I HDACs in tumor cell proliferation was investigated using RNA interference-mediated protein knockdown. We show here that in the absence of HDAC1 cells can arrest either at the G(1) phase of the cell cycle or at the G(2)/M transition, resulting in the loss of mitotic cells, cell growth inhibition, and an increase in the percentage of apoptotic cells. On the contrary, HDAC2 knockdown showed no effect on cell proliferation unless we concurrently knocked down HDAC1. Using gene expression profiling analysis, we found that inactivation of HDAC1 affected the transcription of specific target genes involved in proliferation and apoptosis. Furthermore, HDAC2 downregulation did not cause significant changes compared to control cells, while inactivation of HDAC1, HDAC1 plus HDAC2, or HDAC3 resulted in more distinct clusters. Loss of these HDACs might impair cell cycle progression by affecting not only the transcription of specific target genes but also other biological processes. Our data support the idea that a drug targeting specific HDACs could be highly beneficial in the treatment of cancer.

Standard name | SENESE_HDAC1_TARGETS_DN
Systematic name | M6100
Organism | Homo sapiens
PMID | 17470557
Authors | Senese S,Zaragoza K,Minardi S,Muradore I,Ronzoni S,Passafaro A,Bernard L,Draetta GF,Alcalay M,Seiser C,Chiocca S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in U2OS cells (osteosarcoma) upon knockdown of HDAC1 [GeneID=3065] by RNAi.
Full description | Posttranslational modifications of core histones are central to the regulation of gene expression. Histone deacetylases (HDACs) repress transcription by deacetylating histones, and class I HDACs have a crucial role in mouse, Xenopus laevis, zebra fish, and Caenorhabditis elegans development. The role of individual class I HDACs in tumor cell proliferation was investigated using RNA interference-mediated protein knockdown. We show here that in the absence of HDAC1 cells can arrest either at the G(1) phase of the cell cycle or at the G(2)/M transition, resulting in the loss of mitotic cells, cell growth inhibition, and an increase in the percentage of apoptotic cells. On the contrary, HDAC2 knockdown showed no effect on cell proliferation unless we concurrently knocked down HDAC1. Using gene expression profiling analysis, we found that inactivation of HDAC1 affected the transcription of specific target genes involved in proliferation and apoptosis. Furthermore, HDAC2 downregulation did not cause significant changes compared to control cells, while inactivation of HDAC1, HDAC1 plus HDAC2, or HDAC3 resulted in more distinct clusters. Loss of these HDACs might impair cell cycle progression by affecting not only the transcription of specific target genes but also other biological processes. Our data support the idea that a drug targeting specific HDACs could be highly beneficial in the treatment of cancer.

Standard name | SENESE_HDAC1_AND_HDAC2_TARGETS_UP
Systematic name | M18938
Organism | Homo sapiens
PMID | 17470557
Authors | Senese S,Zaragoza K,Minardi S,Muradore I,Ronzoni S,Passafaro A,Bernard L,Draetta GF,Alcalay M,Seiser C,Chiocca S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in U2OS cells (osteosarcoma) upon knockdown of both HDAC1 and HDAC2 [GeneID=3065;3066] by RNAi.
Full description | Posttranslational modifications of core histones are central to the regulation of gene expression. Histone deacetylases (HDACs) repress transcription by deacetylating histones, and class I HDACs have a crucial role in mouse, Xenopus laevis, zebra fish, and Caenorhabditis elegans development. The role of individual class I HDACs in tumor cell proliferation was investigated using RNA interference-mediated protein knockdown. We show here that in the absence of HDAC1 cells can arrest either at the G(1) phase of the cell cycle or at the G(2)/M transition, resulting in the loss of mitotic cells, cell growth inhibition, and an increase in the percentage of apoptotic cells. On the contrary, HDAC2 knockdown showed no effect on cell proliferation unless we concurrently knocked down HDAC1. Using gene expression profiling analysis, we found that inactivation of HDAC1 affected the transcription of specific target genes involved in proliferation and apoptosis. Furthermore, HDAC2 downregulation did not cause significant changes compared to control cells, while inactivation of HDAC1, HDAC1 plus HDAC2, or HDAC3 resulted in more distinct clusters. Loss of these HDACs might impair cell cycle progression by affecting not only the transcription of specific target genes but also other biological processes. Our data support the idea that a drug targeting specific HDACs could be highly beneficial in the treatment of cancer.

Standard name | SENESE_HDAC1_AND_HDAC2_TARGETS_DN
Systematic name | M12004
Organism | Homo sapiens
PMID | 17470557
Authors | Senese S,Zaragoza K,Minardi S,Muradore I,Ronzoni S,Passafaro A,Bernard L,Draetta GF,Alcalay M,Seiser C,Chiocca S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in U2OS cells (osteosarcoma) upon knockdown of both HDAC1 and HDAC2 [GeneID=3065;3066] by RNAi.
Full description | Posttranslational modifications of core histones are central to the regulation of gene expression. Histone deacetylases (HDACs) repress transcription by deacetylating histones, and class I HDACs have a crucial role in mouse, Xenopus laevis, zebra fish, and Caenorhabditis elegans development. The role of individual class I HDACs in tumor cell proliferation was investigated using RNA interference-mediated protein knockdown. We show here that in the absence of HDAC1 cells can arrest either at the G(1) phase of the cell cycle or at the G(2)/M transition, resulting in the loss of mitotic cells, cell growth inhibition, and an increase in the percentage of apoptotic cells. On the contrary, HDAC2 knockdown showed no effect on cell proliferation unless we concurrently knocked down HDAC1. Using gene expression profiling analysis, we found that inactivation of HDAC1 affected the transcription of specific target genes involved in proliferation and apoptosis. Furthermore, HDAC2 downregulation did not cause significant changes compared to control cells, while inactivation of HDAC1, HDAC1 plus HDAC2, or HDAC3 resulted in more distinct clusters. Loss of these HDACs might impair cell cycle progression by affecting not only the transcription of specific target genes but also other biological processes. Our data support the idea that a drug targeting specific HDACs could be highly beneficial in the treatment of cancer.

Standard name | SENESE_HDAC2_TARGETS_UP
Systematic name | M4113
Organism | Homo sapiens
PMID | 17470557
Authors | Senese S,Zaragoza K,Minardi S,Muradore I,Ronzoni S,Passafaro A,Bernard L,Draetta GF,Alcalay M,Seiser C,Chiocca S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in U2OS cells (osteosarcoma) upon knockdown of HDAC2 [GeneID=3066] by RNAi.
Full description | Posttranslational modifications of core histones are central to the regulation of gene expression. Histone deacetylases (HDACs) repress transcription by deacetylating histones, and class I HDACs have a crucial role in mouse, Xenopus laevis, zebra fish, and Caenorhabditis elegans development. The role of individual class I HDACs in tumor cell proliferation was investigated using RNA interference-mediated protein knockdown. We show here that in the absence of HDAC1 cells can arrest either at the G(1) phase of the cell cycle or at the G(2)/M transition, resulting in the loss of mitotic cells, cell growth inhibition, and an increase in the percentage of apoptotic cells. On the contrary, HDAC2 knockdown showed no effect on cell proliferation unless we concurrently knocked down HDAC1. Using gene expression profiling analysis, we found that inactivation of HDAC1 affected the transcription of specific target genes involved in proliferation and apoptosis. Furthermore, HDAC2 downregulation did not cause significant changes compared to control cells, while inactivation of HDAC1, HDAC1 plus HDAC2, or HDAC3 resulted in more distinct clusters. Loss of these HDACs might impair cell cycle progression by affecting not only the transcription of specific target genes but also other biological processes. Our data support the idea that a drug targeting specific HDACs could be highly beneficial in the treatment of cancer.

Standard name | SENESE_HDAC2_TARGETS_DN
Systematic name | M6906
Organism | Homo sapiens
PMID | 17470557
Authors | Senese S,Zaragoza K,Minardi S,Muradore I,Ronzoni S,Passafaro A,Bernard L,Draetta GF,Alcalay M,Seiser C,Chiocca S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in U2OS cells (osteosarcoma) upon knockdown of HDAC2 [GeneID=3066] by RNAi.
Full description | Posttranslational modifications of core histones are central to the regulation of gene expression. Histone deacetylases (HDACs) repress transcription by deacetylating histones, and class I HDACs have a crucial role in mouse, Xenopus laevis, zebra fish, and Caenorhabditis elegans development. The role of individual class I HDACs in tumor cell proliferation was investigated using RNA interference-mediated protein knockdown. We show here that in the absence of HDAC1 cells can arrest either at the G(1) phase of the cell cycle or at the G(2)/M transition, resulting in the loss of mitotic cells, cell growth inhibition, and an increase in the percentage of apoptotic cells. On the contrary, HDAC2 knockdown showed no effect on cell proliferation unless we concurrently knocked down HDAC1. Using gene expression profiling analysis, we found that inactivation of HDAC1 affected the transcription of specific target genes involved in proliferation and apoptosis. Furthermore, HDAC2 downregulation did not cause significant changes compared to control cells, while inactivation of HDAC1, HDAC1 plus HDAC2, or HDAC3 resulted in more distinct clusters. Loss of these HDACs might impair cell cycle progression by affecting not only the transcription of specific target genes but also other biological processes. Our data support the idea that a drug targeting specific HDACs could be highly beneficial in the treatment of cancer.

Standard name | SENESE_HDAC3_TARGETS_UP
Systematic name | M8451
Organism | Homo sapiens
PMID | 17470557
Authors | Senese S,Zaragoza K,Minardi S,Muradore I,Ronzoni S,Passafaro A,Bernard L,Draetta GF,Alcalay M,Seiser C,Chiocca S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in U2OS cells (osteosarcoma) upon knockdown of HDAC3 [GeneID=8841] by RNAi.
Full description | Posttranslational modifications of core histones are central to the regulation of gene expression. Histone deacetylases (HDACs) repress transcription by deacetylating histones, and class I HDACs have a crucial role in mouse, Xenopus laevis, zebra fish, and Caenorhabditis elegans development. The role of individual class I HDACs in tumor cell proliferation was investigated using RNA interference-mediated protein knockdown. We show here that in the absence of HDAC1 cells can arrest either at the G(1) phase of the cell cycle or at the G(2)/M transition, resulting in the loss of mitotic cells, cell growth inhibition, and an increase in the percentage of apoptotic cells. On the contrary, HDAC2 knockdown showed no effect on cell proliferation unless we concurrently knocked down HDAC1. Using gene expression profiling analysis, we found that inactivation of HDAC1 affected the transcription of specific target genes involved in proliferation and apoptosis. Furthermore, HDAC2 downregulation did not cause significant changes compared to control cells, while inactivation of HDAC1, HDAC1 plus HDAC2, or HDAC3 resulted in more distinct clusters. Loss of these HDACs might impair cell cycle progression by affecting not only the transcription of specific target genes but also other biological processes. Our data support the idea that a drug targeting specific HDACs could be highly beneficial in the treatment of cancer.

Standard name | SENESE_HDAC3_TARGETS_DN
Systematic name | M16859
Organism | Homo sapiens
PMID | 17470557
Authors | Senese S,Zaragoza K,Minardi S,Muradore I,Ronzoni S,Passafaro A,Bernard L,Draetta GF,Alcalay M,Seiser C,Chiocca S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in U2OS cells (osteosarcoma) upon knockdown of HDAC3 [GeneID=8841] by RNAi.
Full description | Posttranslational modifications of core histones are central to the regulation of gene expression. Histone deacetylases (HDACs) repress transcription by deacetylating histones, and class I HDACs have a crucial role in mouse, Xenopus laevis, zebra fish, and Caenorhabditis elegans development. The role of individual class I HDACs in tumor cell proliferation was investigated using RNA interference-mediated protein knockdown. We show here that in the absence of HDAC1 cells can arrest either at the G(1) phase of the cell cycle or at the G(2)/M transition, resulting in the loss of mitotic cells, cell growth inhibition, and an increase in the percentage of apoptotic cells. On the contrary, HDAC2 knockdown showed no effect on cell proliferation unless we concurrently knocked down HDAC1. Using gene expression profiling analysis, we found that inactivation of HDAC1 affected the transcription of specific target genes involved in proliferation and apoptosis. Furthermore, HDAC2 downregulation did not cause significant changes compared to control cells, while inactivation of HDAC1, HDAC1 plus HDAC2, or HDAC3 resulted in more distinct clusters. Loss of these HDACs might impair cell cycle progression by affecting not only the transcription of specific target genes but also other biological processes. Our data support the idea that a drug targeting specific HDACs could be highly beneficial in the treatment of cancer.

Standard name | LEE_NEURAL_CREST_STEM_CELL_UP
Systematic name | M2506
Organism | Homo sapiens
PMID | 18037878
Authors | Lee G,Kim H,Elkabetz Y,Al Shamy G,Panagiotakos G,Barberi T,Tabar V,Studer L
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the neural crest stem cells (NCS), defined as p75+/HNK1+ [GeneID=4804;27087].
Full description | Vertebrate neural crest development depends on pluripotent, migratory precursor cells. Although avian and murine neural crest stem (NCS) cells have been identified, the isolation of human NCS cells has remained elusive. Here we report the derivation of NCS cells from human embryonic stem cells at the neural rosette stage. We show that NCS cells plated at clonal density give rise to multiple neural crest lineages. The human NCS cells can be propagated in vitro and directed toward peripheral nervous system lineages (peripheral neurons, Schwann cells) and mesenchymal lineages (smooth muscle, adipogenic, osteogenic and chondrogenic cells). Transplantation of human NCS cells into the developing chick embryo and adult mouse hosts demonstrates survival, migration and differentiation compatible with neural crest identity. The availability of unlimited numbers of human NCS cells offers new opportunities for studies of neural crest development and for efforts to model and treat neural crest-related disorders.

Standard name | LEE_NEURAL_CREST_STEM_CELL_DN
Systematic name | M10276
Organism | Homo sapiens
PMID | 18037878
Authors | Lee G,Kim H,Elkabetz Y,Al Shamy G,Panagiotakos G,Barberi T,Tabar V,Studer L
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the neural crest stem cells (NCS), defined as p75+/HNK1+ [GeneID=4804;27087].
Full description | Vertebrate neural crest development depends on pluripotent, migratory precursor cells. Although avian and murine neural crest stem (NCS) cells have been identified, the isolation of human NCS cells has remained elusive. Here we report the derivation of NCS cells from human embryonic stem cells at the neural rosette stage. We show that NCS cells plated at clonal density give rise to multiple neural crest lineages. The human NCS cells can be propagated in vitro and directed toward peripheral nervous system lineages (peripheral neurons, Schwann cells) and mesenchymal lineages (smooth muscle, adipogenic, osteogenic and chondrogenic cells). Transplantation of human NCS cells into the developing chick embryo and adult mouse hosts demonstrates survival, migration and differentiation compatible with neural crest identity. The availability of unlimited numbers of human NCS cells offers new opportunities for studies of neural crest development and for efforts to model and treat neural crest-related disorders.

Standard name | HUMMEL_BURKITTS_LYMPHOMA_UP
Systematic name | M3134
Organism | Homo sapiens
PMID | 16760442
Authors | Hummel M,Bentink S,Berger H,Klapper W,Wessendorf S,Barth TF,Bernd HW,Cogliatti SB,Dierlamm J,Feller AC,Hansmann ML,Haralambieva E,Harder L,Hasenclever D,Kühn M,Lenze D,Lichter P,Martin-Subero JI,Möller P,Müller-Hermelink HK,Ott G,Parwaresch RM,Pott C,Rosenwald A,Rosolowski M,Schwaenen C,Stürzenhofecker B,Szczepanowski M,Trautmann H,Wacker HH,Spang R,Loeffler M,Trümper L,Stein H,Siebert R,LastName M
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes constituting the molecular signature of Burkitt 's lymphoma.
Full description | BACKGROUND: The distinction between Burkitt's lymphoma and diffuse large-B-cell lymphoma is unclear. We used transcriptional and genomic profiling to define Burkitt's lymphoma more precisely and to distinguish subgroups in other types of mature aggressive B-cell lymphomas. METHODS: We performed gene-expression profiling using Affymetrix U133A GeneChips with RNA from 220 mature aggressive B-cell lymphomas, including a core group of 8 Burkitt's lymphomas that met all World Health Organization (WHO) criteria. A molecular signature for Burkitt's lymphoma was generated, and chromosomal abnormalities were detected with interphase fluorescence in situ hybridization and array-based comparative genomic hybridization. RESULTS: We used the molecular signature for Burkitt's lymphoma to identify 44 cases: 11 had the morphologic features of diffuse large-B-cell lymphomas, 4 were unclassifiable mature aggressive B-cell lymphomas, and 29 had a classic or atypical Burkitt's morphologic appearance. Also, five did not have a detectable IG-myc Burkitt's translocation, whereas the others contained an IG-myc fusion, mostly in simple karyotypes. Of the 176 lymphomas without the molecular signature for Burkitt's lymphoma, 155 were diffuse large-B-cell lymphomas. Of these 155 cases, 21 percent had a chromosomal breakpoint at the myc locus associated with complex chromosomal changes and an unfavorable clinical course. CONCLUSIONS: Our molecular definition of Burkitt's lymphoma clarifies and extends the spectrum of the WHO criteria for Burkitt's lymphoma. In mature aggressive B-cell lymphomas without a gene signature for Burkitt's lymphoma, chromosomal breakpoints at the myc locus were associated with an adverse clinical outcome.

Standard name | HUMMEL_BURKITTS_LYMPHOMA_DN
Systematic name | M18181
Organism | Homo sapiens
PMID | 16760442
Authors | Hummel M,Bentink S,Berger H,Klapper W,Wessendorf S,Barth TF,Bernd HW,Cogliatti SB,Dierlamm J,Feller AC,Hansmann ML,Haralambieva E,Harder L,Hasenclever D,Kühn M,Lenze D,Lichter P,Martin-Subero JI,Möller P,Müller-Hermelink HK,Ott G,Parwaresch RM,Pott C,Rosenwald A,Rosolowski M,Schwaenen C,Stürzenhofecker B,Szczepanowski M,Trautmann H,Wacker HH,Spang R,Loeffler M,Trümper L,Stein H,Siebert R,LastName M
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes constituting the molecular signature of Burkitt 's lymphoma.
Full description | BACKGROUND: The distinction between Burkitt's lymphoma and diffuse large-B-cell lymphoma is unclear. We used transcriptional and genomic profiling to define Burkitt's lymphoma more precisely and to distinguish subgroups in other types of mature aggressive B-cell lymphomas. METHODS: We performed gene-expression profiling using Affymetrix U133A GeneChips with RNA from 220 mature aggressive B-cell lymphomas, including a core group of 8 Burkitt's lymphomas that met all World Health Organization (WHO) criteria. A molecular signature for Burkitt's lymphoma was generated, and chromosomal abnormalities were detected with interphase fluorescence in situ hybridization and array-based comparative genomic hybridization. RESULTS: We used the molecular signature for Burkitt's lymphoma to identify 44 cases: 11 had the morphologic features of diffuse large-B-cell lymphomas, 4 were unclassifiable mature aggressive B-cell lymphomas, and 29 had a classic or atypical Burkitt's morphologic appearance. Also, five did not have a detectable IG-myc Burkitt's translocation, whereas the others contained an IG-myc fusion, mostly in simple karyotypes. Of the 176 lymphomas without the molecular signature for Burkitt's lymphoma, 155 were diffuse large-B-cell lymphomas. Of these 155 cases, 21 percent had a chromosomal breakpoint at the myc locus associated with complex chromosomal changes and an unfavorable clinical course. CONCLUSIONS: Our molecular definition of Burkitt's lymphoma clarifies and extends the spectrum of the WHO criteria for Burkitt's lymphoma. In mature aggressive B-cell lymphomas without a gene signature for Burkitt's lymphoma, chromosomal breakpoints at the myc locus were associated with an adverse clinical outcome.

Standard name | TIEN_INTESTINE_PROBIOTICS_2HR_UP
Systematic name | M15196
Organism | Homo sapiens
PMID | 16394013
Authors | Tien MT,Girardin SE,Regnault B,Bourhis Le L,Dillies MA,Coppée JY,Bourdet-Sicard R,Sansonetti PJ,Pédron T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Caco-2 cells (intestinal epithelium) after coculture with the probiotic bacteria L. casei for 2h.
Full description | Shigella invades the human intestinal mucosa, thus causing bacillary dysentery, an acute recto-colitis responsible for lethal complications, mostly in infants and toddlers. Conversely, commensal bacteria live in a mutualistic relationship with the intestinal mucosa that is characterized by homeostatic control of innate responses, thereby contributing to tolerance to the flora. Cross-talk established between commensals and the intestinal epithelium mediate this active process, the mechanisms of which remain largely uncharacterized. Probiotics such as Lactobacillus casei belong to a subclass of these commensals that modulate mucosal innate responses and possibly display anti-inflammatory properties. We analyzed whether L. casei could attenuate the pro-inflammatory signaling induced by Shigella flexneri after invasion of the epithelial lining. Cultured epithelial cells were infected with L. casei, followed by a challenge with S. flexneri. Using macroarray DNA chips, we observed that L. casei down-regulated the transcription of a number of genes encoding pro-inflammatory effectors such as cytokines and chemokines and adherence molecules induced by invasive S. flexneri. This resulted in an anti-inflammatory effect that appeared mediated by the inhibition of the NF-kappaB pathway, particularly through stabilization of I-kappaBalpha. In a time-course experiment using GeneChip hybridization analysis, the expression of many genes involved in ubiquitination and proteasome processes were modulated during L. casei treatment. Thus, L. casei has developed a sophisticated means to maintain intestinal homeostasis through a process that involves manipulation of the ubiquitin/proteasome pathway upstream of I-kappaBalpha.

Standard name | TIEN_INTESTINE_PROBIOTICS_2HR_DN
Systematic name | M8916
Organism | Homo sapiens
PMID | 16394013
Authors | Tien MT,Girardin SE,Regnault B,Bourhis Le L,Dillies MA,Coppée JY,Bourdet-Sicard R,Sansonetti PJ,Pédron T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Caco-2 cells (intestinal epithelium) after coculture with the probiotic bacteria L. casei for 2h.
Full description | Shigella invades the human intestinal mucosa, thus causing bacillary dysentery, an acute recto-colitis responsible for lethal complications, mostly in infants and toddlers. Conversely, commensal bacteria live in a mutualistic relationship with the intestinal mucosa that is characterized by homeostatic control of innate responses, thereby contributing to tolerance to the flora. Cross-talk established between commensals and the intestinal epithelium mediate this active process, the mechanisms of which remain largely uncharacterized. Probiotics such as Lactobacillus casei belong to a subclass of these commensals that modulate mucosal innate responses and possibly display anti-inflammatory properties. We analyzed whether L. casei could attenuate the pro-inflammatory signaling induced by Shigella flexneri after invasion of the epithelial lining. Cultured epithelial cells were infected with L. casei, followed by a challenge with S. flexneri. Using macroarray DNA chips, we observed that L. casei down-regulated the transcription of a number of genes encoding pro-inflammatory effectors such as cytokines and chemokines and adherence molecules induced by invasive S. flexneri. This resulted in an anti-inflammatory effect that appeared mediated by the inhibition of the NF-kappaB pathway, particularly through stabilization of I-kappaBalpha. In a time-course experiment using GeneChip hybridization analysis, the expression of many genes involved in ubiquitination and proteasome processes were modulated during L. casei treatment. Thus, L. casei has developed a sophisticated means to maintain intestinal homeostasis through a process that involves manipulation of the ubiquitin/proteasome pathway upstream of I-kappaBalpha.

Standard name | TIEN_INTESTINE_PROBIOTICS_6HR_UP
Systematic name | M19251
Organism | Homo sapiens
PMID | 16394013
Authors | Tien MT,Girardin SE,Regnault B,Bourhis Le L,Dillies MA,Coppée JY,Bourdet-Sicard R,Sansonetti PJ,Pédron T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Caco-2 cells (intestinal epithelium) after coculture with the probiotic bacteria L. casei for 6h.
Full description | Shigella invades the human intestinal mucosa, thus causing bacillary dysentery, an acute recto-colitis responsible for lethal complications, mostly in infants and toddlers. Conversely, commensal bacteria live in a mutualistic relationship with the intestinal mucosa that is characterized by homeostatic control of innate responses, thereby contributing to tolerance to the flora. Cross-talk established between commensals and the intestinal epithelium mediate this active process, the mechanisms of which remain largely uncharacterized. Probiotics such as Lactobacillus casei belong to a subclass of these commensals that modulate mucosal innate responses and possibly display anti-inflammatory properties. We analyzed whether L. casei could attenuate the pro-inflammatory signaling induced by Shigella flexneri after invasion of the epithelial lining. Cultured epithelial cells were infected with L. casei, followed by a challenge with S. flexneri. Using macroarray DNA chips, we observed that L. casei down-regulated the transcription of a number of genes encoding pro-inflammatory effectors such as cytokines and chemokines and adherence molecules induced by invasive S. flexneri. This resulted in an anti-inflammatory effect that appeared mediated by the inhibition of the NF-kappaB pathway, particularly through stabilization of I-kappaBalpha. In a time-course experiment using GeneChip hybridization analysis, the expression of many genes involved in ubiquitination and proteasome processes were modulated during L. casei treatment. Thus, L. casei has developed a sophisticated means to maintain intestinal homeostasis through a process that involves manipulation of the ubiquitin/proteasome pathway upstream of I-kappaBalpha.

Standard name | TIEN_INTESTINE_PROBIOTICS_6HR_DN
Systematic name | M19990
Organism | Homo sapiens
PMID | 16394013
Authors | Tien MT,Girardin SE,Regnault B,Bourhis Le L,Dillies MA,Coppée JY,Bourdet-Sicard R,Sansonetti PJ,Pédron T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Caco-2 cells (intestinal epithelium) after coculture with the probiotic bacteria L. casei for 6h.
Full description | Shigella invades the human intestinal mucosa, thus causing bacillary dysentery, an acute recto-colitis responsible for lethal complications, mostly in infants and toddlers. Conversely, commensal bacteria live in a mutualistic relationship with the intestinal mucosa that is characterized by homeostatic control of innate responses, thereby contributing to tolerance to the flora. Cross-talk established between commensals and the intestinal epithelium mediate this active process, the mechanisms of which remain largely uncharacterized. Probiotics such as Lactobacillus casei belong to a subclass of these commensals that modulate mucosal innate responses and possibly display anti-inflammatory properties. We analyzed whether L. casei could attenuate the pro-inflammatory signaling induced by Shigella flexneri after invasion of the epithelial lining. Cultured epithelial cells were infected with L. casei, followed by a challenge with S. flexneri. Using macroarray DNA chips, we observed that L. casei down-regulated the transcription of a number of genes encoding pro-inflammatory effectors such as cytokines and chemokines and adherence molecules induced by invasive S. flexneri. This resulted in an anti-inflammatory effect that appeared mediated by the inhibition of the NF-kappaB pathway, particularly through stabilization of I-kappaBalpha. In a time-course experiment using GeneChip hybridization analysis, the expression of many genes involved in ubiquitination and proteasome processes were modulated during L. casei treatment. Thus, L. casei has developed a sophisticated means to maintain intestinal homeostasis through a process that involves manipulation of the ubiquitin/proteasome pathway upstream of I-kappaBalpha.

Standard name | TIEN_INTESTINE_PROBIOTICS_24HR_UP
Systematic name | M1463
Organism | Homo sapiens
PMID | 16394013
Authors | Tien MT,Girardin SE,Regnault B,Bourhis Le L,Dillies MA,Coppée JY,Bourdet-Sicard R,Sansonetti PJ,Pédron T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Caco-2 cells (intestinal epithelium) after coculture with the probiotic bacteria L. casei for 24h.
Full description | Shigella invades the human intestinal mucosa, thus causing bacillary dysentery, an acute recto-colitis responsible for lethal complications, mostly in infants and toddlers. Conversely, commensal bacteria live in a mutualistic relationship with the intestinal mucosa that is characterized by homeostatic control of innate responses, thereby contributing to tolerance to the flora. Cross-talk established between commensals and the intestinal epithelium mediate this active process, the mechanisms of which remain largely uncharacterized. Probiotics such as Lactobacillus casei belong to a subclass of these commensals that modulate mucosal innate responses and possibly display anti-inflammatory properties. We analyzed whether L. casei could attenuate the pro-inflammatory signaling induced by Shigella flexneri after invasion of the epithelial lining. Cultured epithelial cells were infected with L. casei, followed by a challenge with S. flexneri. Using macroarray DNA chips, we observed that L. casei down-regulated the transcription of a number of genes encoding pro-inflammatory effectors such as cytokines and chemokines and adherence molecules induced by invasive S. flexneri. This resulted in an anti-inflammatory effect that appeared mediated by the inhibition of the NF-kappaB pathway, particularly through stabilization of I-kappaBalpha. In a time-course experiment using GeneChip hybridization analysis, the expression of many genes involved in ubiquitination and proteasome processes were modulated during L. casei treatment. Thus, L. casei has developed a sophisticated means to maintain intestinal homeostasis through a process that involves manipulation of the ubiquitin/proteasome pathway upstream of I-kappaBalpha.

Standard name | TIEN_INTESTINE_PROBIOTICS_24HR_DN
Systematic name | M19666
Organism | Homo sapiens
PMID | 16394013
Authors | Tien MT,Girardin SE,Regnault B,Bourhis Le L,Dillies MA,Coppée JY,Bourdet-Sicard R,Sansonetti PJ,Pédron T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Caco-2 cells (intestinal epithelium) after coculture with the probiotic bacteria L. casei for 24h.
Full description | Shigella invades the human intestinal mucosa, thus causing bacillary dysentery, an acute recto-colitis responsible for lethal complications, mostly in infants and toddlers. Conversely, commensal bacteria live in a mutualistic relationship with the intestinal mucosa that is characterized by homeostatic control of innate responses, thereby contributing to tolerance to the flora. Cross-talk established between commensals and the intestinal epithelium mediate this active process, the mechanisms of which remain largely uncharacterized. Probiotics such as Lactobacillus casei belong to a subclass of these commensals that modulate mucosal innate responses and possibly display anti-inflammatory properties. We analyzed whether L. casei could attenuate the pro-inflammatory signaling induced by Shigella flexneri after invasion of the epithelial lining. Cultured epithelial cells were infected with L. casei, followed by a challenge with S. flexneri. Using macroarray DNA chips, we observed that L. casei down-regulated the transcription of a number of genes encoding pro-inflammatory effectors such as cytokines and chemokines and adherence molecules induced by invasive S. flexneri. This resulted in an anti-inflammatory effect that appeared mediated by the inhibition of the NF-kappaB pathway, particularly through stabilization of I-kappaBalpha. In a time-course experiment using GeneChip hybridization analysis, the expression of many genes involved in ubiquitination and proteasome processes were modulated during L. casei treatment. Thus, L. casei has developed a sophisticated means to maintain intestinal homeostasis through a process that involves manipulation of the ubiquitin/proteasome pathway upstream of I-kappaBalpha.

Standard name | ZHOU_INFLAMMATORY_RESPONSE_FIMA_UP
Systematic name | M7140
Organism | Homo sapiens
PMID | 18025224
Authors | Zhou Q,Amar S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in macrophages by P.gingivalis FimA pathogen.
Full description | Porphyromonas gingivalis (P. gingivalis) can trigger an inflammatory condition leading to the destruction of periodontal tissues. However P. gingivalis LPS and its fimbriae (FimA) play different roles compared with the live bacteria in the context of intracellular molecule induction and cytokine secretion. To elucidate whether this difference results from different signaling pathways in host immune response to P. gingivalis, its LPS, or its FimA, we examined gene expression profile of human macrophages exposed to P. gingivalis, its LPS, or its FimA. A comparison of gene expression resulted in the identification of three distinct groups of expressed genes. Furthermore, computer-assisted promoter analysis of a subset of each group of differentially regulated genes revealed four putative transcriptional regulation models that associate with transcription factors NFkappaB, IRF7, and KLF4. Using gene knockout mice and siRNA to silence mouse genes, we showed that both TLR2 and TLR7 are essential for the induction of NFkappaB-containing genes and NFkappaB-IFN-sensitive response element (ISRE) cocontaining genes by either P. gingivalis or its purified components. The gene induction via either TLR2 or TLR7 is dependent on both MyD88 and p38 MAPK. However, the unique induction of IFN-beta by P. gingivalis LPS requires TLR7 and IFNalphabetaR cosignaling, and the induction of ISRE-containing gene is dependent on the activation of IFN-beta autocrine loop. Taken together, these data demonstrate that P. gingivalis and its components induce NFkappaB-containing genes through either TLR2- or TLR7-MyD88-p38 MAPK pathway, while P. gingivalis LPS uniquely induces ISRE-containing genes, which requires IFNalphabetaR signaling involving IRF7, KLF4, and pY701 STAT1.

Standard name | ZHOU_INFLAMMATORY_RESPONSE_FIMA_DN
Systematic name | M250
Organism | Homo sapiens
PMID | 18025224
Authors | Zhou Q,Amar S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in macrophages by P.gingivalis FimA pathogen.
Full description | Porphyromonas gingivalis (P. gingivalis) can trigger an inflammatory condition leading to the destruction of periodontal tissues. However P. gingivalis LPS and its fimbriae (FimA) play different roles compared with the live bacteria in the context of intracellular molecule induction and cytokine secretion. To elucidate whether this difference results from different signaling pathways in host immune response to P. gingivalis, its LPS, or its FimA, we examined gene expression profile of human macrophages exposed to P. gingivalis, its LPS, or its FimA. A comparison of gene expression resulted in the identification of three distinct groups of expressed genes. Furthermore, computer-assisted promoter analysis of a subset of each group of differentially regulated genes revealed four putative transcriptional regulation models that associate with transcription factors NFkappaB, IRF7, and KLF4. Using gene knockout mice and siRNA to silence mouse genes, we showed that both TLR2 and TLR7 are essential for the induction of NFkappaB-containing genes and NFkappaB-IFN-sensitive response element (ISRE) cocontaining genes by either P. gingivalis or its purified components. The gene induction via either TLR2 or TLR7 is dependent on both MyD88 and p38 MAPK. However, the unique induction of IFN-beta by P. gingivalis LPS requires TLR7 and IFNalphabetaR cosignaling, and the induction of ISRE-containing gene is dependent on the activation of IFN-beta autocrine loop. Taken together, these data demonstrate that P. gingivalis and its components induce NFkappaB-containing genes through either TLR2- or TLR7-MyD88-p38 MAPK pathway, while P. gingivalis LPS uniquely induces ISRE-containing genes, which requires IFNalphabetaR signaling involving IRF7, KLF4, and pY701 STAT1.

Standard name | ZHOU_INFLAMMATORY_RESPONSE_LPS_UP
Systematic name | M9673
Organism | Homo sapiens
PMID | 18025224
Authors | Zhou Q,Amar S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in macrophages by P.gingivalis LPS (lipopolysaccharide).
Full description | Porphyromonas gingivalis (P. gingivalis) can trigger an inflammatory condition leading to the destruction of periodontal tissues. However P. gingivalis LPS and its fimbriae (FimA) play different roles compared with the live bacteria in the context of intracellular molecule induction and cytokine secretion. To elucidate whether this difference results from different signaling pathways in host immune response to P. gingivalis, its LPS, or its FimA, we examined gene expression profile of human macrophages exposed to P. gingivalis, its LPS, or its FimA. A comparison of gene expression resulted in the identification of three distinct groups of expressed genes. Furthermore, computer-assisted promoter analysis of a subset of each group of differentially regulated genes revealed four putative transcriptional regulation models that associate with transcription factors NFkappaB, IRF7, and KLF4. Using gene knockout mice and siRNA to silence mouse genes, we showed that both TLR2 and TLR7 are essential for the induction of NFkappaB-containing genes and NFkappaB-IFN-sensitive response element (ISRE) cocontaining genes by either P. gingivalis or its purified components. The gene induction via either TLR2 or TLR7 is dependent on both MyD88 and p38 MAPK. However, the unique induction of IFN-beta by P. gingivalis LPS requires TLR7 and IFNalphabetaR cosignaling, and the induction of ISRE-containing gene is dependent on the activation of IFN-beta autocrine loop. Taken together, these data demonstrate that P. gingivalis and its components induce NFkappaB-containing genes through either TLR2- or TLR7-MyD88-p38 MAPK pathway, while P. gingivalis LPS uniquely induces ISRE-containing genes, which requires IFNalphabetaR signaling involving IRF7, KLF4, and pY701 STAT1.

Standard name | KINSEY_TARGETS_OF_EWSR1_FLII_FUSION_UP
Systematic name | M80
Organism | Homo sapiens
PMID | 17114343
Authors | Kinsey M,Smith R,Lessnick SL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in TC71 and EWS502 cells (Ewing's sarcoma) by EWSR1-FLI1 [GeneID=2130;2314] as inferred from RNAi knockdown of this fusion protein.
Full description | A number of solid tumors, such as alveolar rhabdomyosarcoma, synovial sarcoma, and myxoid liposarcoma, are associated with recurrent translocation events that encode fusion proteins. Ewing's sarcoma is a pediatric tumor that serves as a prototype for this tumor class. Ewing's sarcomas usually harbor the (11;22)(q24;q12) translocation. The t(11;22) encodes the EWS/FLI fusion oncoprotein. EWS/FLI functions as an aberrant transcription factor, but the key target genes that are involved in oncogenesis are largely unknown. Although some target genes have been defined, many of these have been identified in heterologous model systems with uncertain relevance to the human disease. To understand the function of EWS/FLI and its targets in a more clinically relevant system, we used retroviral-mediated RNAi to knock-down the fusion protein in patient-derived Ewing's sarcoma cell lines. By combining transcriptional profiling data from three of these lines, we identified a conserved transcriptional response to EWS/FLI. The gene that was most reproducibly up-regulated by EWS/FLI was NR0B1. NR0B1 is a developmentally important orphan nuclear receptor with no previously defined role in oncogenesis. We validated NR0B1 as an EWS/FLI-dysregulated gene and confirmed its expression in primary human tumor samples. Functional studies revealed that ongoing NR0B1 expression is required for the transformed phenotype of Ewing's sarcoma. These studies define a new role for NR0B1 in oncogenic transformation and emphasize the utility of analyzing the function of EWS/FLI in Ewing's sarcoma cells.

Standard name | KINSEY_TARGETS_OF_EWSR1_FLII_FUSION_DN
Systematic name | M13206
Organism | Homo sapiens
PMID | 17114343
Authors | Kinsey M,Smith R,Lessnick SL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in TC71 and EWS502 cells (Ewing's sarcoma) by EWSR1-FLI1 [GeneID=2130;2314] as inferred from RNAi knockdown of this fusion protein.
Full description | A number of solid tumors, such as alveolar rhabdomyosarcoma, synovial sarcoma, and myxoid liposarcoma, are associated with recurrent translocation events that encode fusion proteins. Ewing's sarcoma is a pediatric tumor that serves as a prototype for this tumor class. Ewing's sarcomas usually harbor the (11;22)(q24;q12) translocation. The t(11;22) encodes the EWS/FLI fusion oncoprotein. EWS/FLI functions as an aberrant transcription factor, but the key target genes that are involved in oncogenesis are largely unknown. Although some target genes have been defined, many of these have been identified in heterologous model systems with uncertain relevance to the human disease. To understand the function of EWS/FLI and its targets in a more clinically relevant system, we used retroviral-mediated RNAi to knock-down the fusion protein in patient-derived Ewing's sarcoma cell lines. By combining transcriptional profiling data from three of these lines, we identified a conserved transcriptional response to EWS/FLI. The gene that was most reproducibly up-regulated by EWS/FLI was NR0B1. NR0B1 is a developmentally important orphan nuclear receptor with no previously defined role in oncogenesis. We validated NR0B1 as an EWS/FLI-dysregulated gene and confirmed its expression in primary human tumor samples. Functional studies revealed that ongoing NR0B1 expression is required for the transformed phenotype of Ewing's sarcoma. These studies define a new role for NR0B1 in oncogenic transformation and emphasize the utility of analyzing the function of EWS/FLI in Ewing's sarcoma cells.

Standard name | SABATES_COLORECTAL_ADENOMA_SIZE_UP
Systematic name | M6740
Organism | Homo sapiens
PMID | 18171984
Authors | Sabates-Bellver J,Van der Flier LG,de Palo M,Cattaneo E,Maake C,Rehrauer H,Laczko E,Kurowski MA,Bujnicki JM,Menigatti M,Luz J,Ranalli TV,Gomes V,Pastorelli A,Faggiani R,Anti M,Jiricny J,Clevers H,Marra G
Category | C2
Sub-category | CGP
Brief description | A selection of genes whose expression displayed significant positive correlation with size of colorectal adenoma.
Full description | Colorectal cancers are believed to arise predominantly from adenomas. Although these precancerous lesions have been subjected to extensive clinical, pathologic, and molecular analyses, little is currently known about the global gene expression changes accompanying their formation. To characterize the molecular processes underlying the transformation of normal colonic epithelium, we compared the transcriptomes of 32 prospectively collected adenomas with those of normal mucosa from the same individuals. Important differences emerged not only between the expression profiles of normal and adenomatous tissues but also between those of small and large adenomas. A key feature of the transformation process was the remodeling of the Wnt pathway reflected in patent overexpression and underexpression of 78 known components of this signaling cascade. The expression of 19 Wnt targets was closely correlated with clear up-regulation of KIAA1199, whose function is currently unknown. In normal mucosa, KIAA1199 expression was confined to cells in the lower portion of intestinal crypts, where Wnt signaling is physiologically active, but it was markedly increased in all adenomas, where it was expressed in most of the epithelial cells, and in colon cancer cell lines, it was markedly reduced by inactivation of the beta-catenin/T-cell factor(s) transcription complex, the pivotal mediator of Wnt signaling. Our transcriptomic profiles of normal colonic mucosa and colorectal adenomas shed new light on the early stages of colorectal tumorigenesis and identified KIAA1199 as a novel target of the Wnt signaling pathway and a putative marker of colorectal adenomatous transformation.

Standard name | SABATES_COLORECTAL_ADENOMA_SIZE_DN
Systematic name | M11303
Organism | Homo sapiens
PMID | 18171984
Authors | Sabates-Bellver J,Van der Flier LG,de Palo M,Cattaneo E,Maake C,Rehrauer H,Laczko E,Kurowski MA,Bujnicki JM,Menigatti M,Luz J,Ranalli TV,Gomes V,Pastorelli A,Faggiani R,Anti M,Jiricny J,Clevers H,Marra G
Category | C2
Sub-category | CGP
Brief description | A selection of genes whose expression displayed significant negative correlation with size of colorectal adenoma.
Full description | Colorectal cancers are believed to arise predominantly from adenomas. Although these precancerous lesions have been subjected to extensive clinical, pathologic, and molecular analyses, little is currently known about the global gene expression changes accompanying their formation. To characterize the molecular processes underlying the transformation of normal colonic epithelium, we compared the transcriptomes of 32 prospectively collected adenomas with those of normal mucosa from the same individuals. Important differences emerged not only between the expression profiles of normal and adenomatous tissues but also between those of small and large adenomas. A key feature of the transformation process was the remodeling of the Wnt pathway reflected in patent overexpression and underexpression of 78 known components of this signaling cascade. The expression of 19 Wnt targets was closely correlated with clear up-regulation of KIAA1199, whose function is currently unknown. In normal mucosa, KIAA1199 expression was confined to cells in the lower portion of intestinal crypts, where Wnt signaling is physiologically active, but it was markedly increased in all adenomas, where it was expressed in most of the epithelial cells, and in colon cancer cell lines, it was markedly reduced by inactivation of the beta-catenin/T-cell factor(s) transcription complex, the pivotal mediator of Wnt signaling. Our transcriptomic profiles of normal colonic mucosa and colorectal adenomas shed new light on the early stages of colorectal tumorigenesis and identified KIAA1199 as a novel target of the Wnt signaling pathway and a putative marker of colorectal adenomatous transformation.

Standard name | SABATES_COLORECTAL_ADENOMA_UP
Systematic name | M929
Organism | Homo sapiens
PMID | 18171984
Authors | Sabates-Bellver J,Van der Flier LG,de Palo M,Cattaneo E,Maake C,Rehrauer H,Laczko E,Kurowski MA,Bujnicki JM,Menigatti M,Luz J,Ranalli TV,Gomes V,Pastorelli A,Faggiani R,Anti M,Jiricny J,Clevers H,Marra G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in colorectal adenoma compared to normal mucosa samples.
Full description | Colorectal cancers are believed to arise predominantly from adenomas. Although these precancerous lesions have been subjected to extensive clinical, pathologic, and molecular analyses, little is currently known about the global gene expression changes accompanying their formation. To characterize the molecular processes underlying the transformation of normal colonic epithelium, we compared the transcriptomes of 32 prospectively collected adenomas with those of normal mucosa from the same individuals. Important differences emerged not only between the expression profiles of normal and adenomatous tissues but also between those of small and large adenomas. A key feature of the transformation process was the remodeling of the Wnt pathway reflected in patent overexpression and underexpression of 78 known components of this signaling cascade. The expression of 19 Wnt targets was closely correlated with clear up-regulation of KIAA1199, whose function is currently unknown. In normal mucosa, KIAA1199 expression was confined to cells in the lower portion of intestinal crypts, where Wnt signaling is physiologically active, but it was markedly increased in all adenomas, where it was expressed in most of the epithelial cells, and in colon cancer cell lines, it was markedly reduced by inactivation of the beta-catenin/T-cell factor(s) transcription complex, the pivotal mediator of Wnt signaling. Our transcriptomic profiles of normal colonic mucosa and colorectal adenomas shed new light on the early stages of colorectal tumorigenesis and identified KIAA1199 as a novel target of the Wnt signaling pathway and a putative marker of colorectal adenomatous transformation.

Standard name | SABATES_COLORECTAL_ADENOMA_DN
Systematic name | M14791
Organism | Homo sapiens
PMID | 18171984
Authors | Sabates-Bellver J,Van der Flier LG,de Palo M,Cattaneo E,Maake C,Rehrauer H,Laczko E,Kurowski MA,Bujnicki JM,Menigatti M,Luz J,Ranalli TV,Gomes V,Pastorelli A,Faggiani R,Anti M,Jiricny J,Clevers H,Marra G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in colorectal adenoma compared to normal mucosa samples.
Full description | Colorectal cancers are believed to arise predominantly from adenomas. Although these precancerous lesions have been subjected to extensive clinical, pathologic, and molecular analyses, little is currently known about the global gene expression changes accompanying their formation. To characterize the molecular processes underlying the transformation of normal colonic epithelium, we compared the transcriptomes of 32 prospectively collected adenomas with those of normal mucosa from the same individuals. Important differences emerged not only between the expression profiles of normal and adenomatous tissues but also between those of small and large adenomas. A key feature of the transformation process was the remodeling of the Wnt pathway reflected in patent overexpression and underexpression of 78 known components of this signaling cascade. The expression of 19 Wnt targets was closely correlated with clear up-regulation of KIAA1199, whose function is currently unknown. In normal mucosa, KIAA1199 expression was confined to cells in the lower portion of intestinal crypts, where Wnt signaling is physiologically active, but it was markedly increased in all adenomas, where it was expressed in most of the epithelial cells, and in colon cancer cell lines, it was markedly reduced by inactivation of the beta-catenin/T-cell factor(s) transcription complex, the pivotal mediator of Wnt signaling. Our transcriptomic profiles of normal colonic mucosa and colorectal adenomas shed new light on the early stages of colorectal tumorigenesis and identified KIAA1199 as a novel target of the Wnt signaling pathway and a putative marker of colorectal adenomatous transformation.

Standard name | SCIBETTA_KDM5B_TARGETS_UP
Systematic name | M1142
Organism | Homo sapiens
PMID | 17709396
Authors | Scibetta AG,Santangelo S,Coleman J,Hall D,Chaplin T,Copier J,Catchpole S,Burchell J,Taylor-Papadimitriou J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HB2 cells (mammary epithelium) upon expression of KDM5B [GeneID=10765] off an adenoviral vector.
Full description | The PLU-1/JARID1B nuclear protein, which is upregulated in breast cancers, belongs to the ARID family of DNA binding proteins and has strong transcriptional repression activity. To identify the target genes regulated by PLU-1/JARID1B, we overexpressed or silenced the human PLU-1/JARID1B gene in human mammary epithelial cells by using adenovirus and RNA interference systems, respectively, and then applied microarray analysis to identify candidate genes. A total of 100 genes showed inversely correlated differential expression in the two systems. Most of the candidate genes were downregulated by the overexpression of PLU-1/JARID1B, including the MT genes, the tumor suppressor gene BRCA1, and genes involved in the regulation of the M phase of the mitotic cell cycle. Chromatin immunoprecipitation assays confirmed that the metallothionein 1H (MT1H), -1F, and -1X genes are direct transcriptional targets of PLU-1/JARID1B in vivo. Furthermore, the level of trimethyl H3K4 of the MT1H promoter was increased following silencing of PLU-1/JARID1B. Both the PLU-1/JARID1B protein and the ARID domain selectively bound CG-rich DNA. The GCACA/C motif, which is abundant in metallothionein promoters, was identified as a consensus binding sequence of the PLU-1/JARID1B ARID domain. As expected from the microarray data, cells overexpressing PLU-1/JARID1B have an impaired G(2)/M checkpoint. Our study provides insight into the molecular function of the breast cancer-associated transcriptional repressor PLU-1/JARID1B.

Standard name | SCIBETTA_KDM5B_TARGETS_DN
Systematic name | M6787
Organism | Homo sapiens
PMID | 17709396
Authors | Scibetta AG,Santangelo S,Coleman J,Hall D,Chaplin T,Copier J,Catchpole S,Burchell J,Taylor-Papadimitriou J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HB2 cells (mammary epithelium) upon expression of KDM5B [GeneID=10765] off an adenoviral vector.
Full description | The PLU-1/JARID1B nuclear protein, which is upregulated in breast cancers, belongs to the ARID family of DNA binding proteins and has strong transcriptional repression activity. To identify the target genes regulated by PLU-1/JARID1B, we overexpressed or silenced the human PLU-1/JARID1B gene in human mammary epithelial cells by using adenovirus and RNA interference systems, respectively, and then applied microarray analysis to identify candidate genes. A total of 100 genes showed inversely correlated differential expression in the two systems. Most of the candidate genes were downregulated by the overexpression of PLU-1/JARID1B, including the MT genes, the tumor suppressor gene BRCA1, and genes involved in the regulation of the M phase of the mitotic cell cycle. Chromatin immunoprecipitation assays confirmed that the metallothionein 1H (MT1H), -1F, and -1X genes are direct transcriptional targets of PLU-1/JARID1B in vivo. Furthermore, the level of trimethyl H3K4 of the MT1H promoter was increased following silencing of PLU-1/JARID1B. Both the PLU-1/JARID1B protein and the ARID domain selectively bound CG-rich DNA. The GCACA/C motif, which is abundant in metallothionein promoters, was identified as a consensus binding sequence of the PLU-1/JARID1B ARID domain. As expected from the microarray data, cells overexpressing PLU-1/JARID1B have an impaired G(2)/M checkpoint. Our study provides insight into the molecular function of the breast cancer-associated transcriptional repressor PLU-1/JARID1B.

Standard name | NAGASHIMA_NRG1_SIGNALING_UP
Systematic name | M11585
Organism | Homo sapiens
PMID | 17142811
Authors | Nagashima T,Shimodaira H,Ide K,Nakakuki T,Tani Y,Takahashi K,Yumoto N,Hatakeyama M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) after stimulation with NRG1 [GeneID=3084].
Full description | ErbB receptor ligands, epidermal growth factor (EGF) and heregulin (HRG), induce dose-dependent transient and sustained intracellular signaling, proliferation, and differentiation of MCF-7 breast cancer cells, respectively. In an effort to delineate the ligand-specific cell determination mechanism, we investigated time course gene expressions induced by EGF and HRG that induce distinct cellular phenotypes in MCF-7 cells. To analyze independently the effects of ligand dosage and time for gene expression, we developed a statistical method for estimating the two effects. Our results indicated that signal transduction pathways convey quantitative properties of the dose-dependent activation of ErbB receptor to early transcription. The results also implied that moderate changes in the expression levels of a number of genes, not the predominant regulation of a few specific genes, might cooperatively work at the early stage of the transcription for determining cell fate. However, the EGF- and HRG-induced distinct signal durations resulted in the ligand-oriented biphasic induction of proteins after 20 min. The selected gene list and HRG-induced prolonged signaling suggested that transcriptional feedback to the intracellular signaling results in a graded to biphasic response in the cell determination process and that each ErbB receptor is inextricably responsible for the control of amplitude and duration of cellular biochemical reactions.

Standard name | NAGASHIMA_NRG1_SIGNALING_DN
Systematic name | M17600
Organism | Homo sapiens
PMID | 17142811
Authors | Nagashima T,Shimodaira H,Ide K,Nakakuki T,Tani Y,Takahashi K,Yumoto N,Hatakeyama M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) after stimulation with NRG1 [GeneID=3084].
Full description | ErbB receptor ligands, epidermal growth factor (EGF) and heregulin (HRG), induce dose-dependent transient and sustained intracellular signaling, proliferation, and differentiation of MCF-7 breast cancer cells, respectively. In an effort to delineate the ligand-specific cell determination mechanism, we investigated time course gene expressions induced by EGF and HRG that induce distinct cellular phenotypes in MCF-7 cells. To analyze independently the effects of ligand dosage and time for gene expression, we developed a statistical method for estimating the two effects. Our results indicated that signal transduction pathways convey quantitative properties of the dose-dependent activation of ErbB receptor to early transcription. The results also implied that moderate changes in the expression levels of a number of genes, not the predominant regulation of a few specific genes, might cooperatively work at the early stage of the transcription for determining cell fate. However, the EGF- and HRG-induced distinct signal durations resulted in the ligand-oriented biphasic induction of proteins after 20 min. The selected gene list and HRG-induced prolonged signaling suggested that transcriptional feedback to the intracellular signaling results in a graded to biphasic response in the cell determination process and that each ErbB receptor is inextricably responsible for the control of amplitude and duration of cellular biochemical reactions.

Standard name | NAGASHIMA_EGF_SIGNALING_UP
Systematic name | M16311
Organism | Homo sapiens
PMID | 17142811
Authors | Nagashima T,Shimodaira H,Ide K,Nakakuki T,Tani Y,Takahashi K,Yumoto N,Hatakeyama M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) after stimulation with EGF [GeneID=1950].
Full description | ErbB receptor ligands, epidermal growth factor (EGF) and heregulin (HRG), induce dose-dependent transient and sustained intracellular signaling, proliferation, and differentiation of MCF-7 breast cancer cells, respectively. In an effort to delineate the ligand-specific cell determination mechanism, we investigated time course gene expressions induced by EGF and HRG that induce distinct cellular phenotypes in MCF-7 cells. To analyze independently the effects of ligand dosage and time for gene expression, we developed a statistical method for estimating the two effects. Our results indicated that signal transduction pathways convey quantitative properties of the dose-dependent activation of ErbB receptor to early transcription. The results also implied that moderate changes in the expression levels of a number of genes, not the predominant regulation of a few specific genes, might cooperatively work at the early stage of the transcription for determining cell fate. However, the EGF- and HRG-induced distinct signal durations resulted in the ligand-oriented biphasic induction of proteins after 20 min. The selected gene list and HRG-induced prolonged signaling suggested that transcriptional feedback to the intracellular signaling results in a graded to biphasic response in the cell determination process and that each ErbB receptor is inextricably responsible for the control of amplitude and duration of cellular biochemical reactions.

Standard name | KIM_WT1_TARGETS_UP
Systematic name | M9128
Organism | Homo sapiens
PMID | 17430890
Authors | Kim HS,Kim MS,Hancock AL,Harper JC,Park JY,Poy G,Perantoni AO,Cam M,Malik K,Lee SB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in UB27 cells (osteosarcoma) at any time point after inducing the expression of a mutant form of WT1 [GeneID=7490].
Full description | The Wilms' tumor suppressor gene (WT1) encodes a zinc finger transcription factor that is vital during development of several organs including metanephric kidneys. Despite the critical regulatory role of WT1, the pathways and mechanisms by which WT1 orchestrates development remain elusive. To identify WT1 target genes, we performed a genome-wide expression profiling analysis in cells expressing inducible WT1. We identified a number of direct WT1 target genes, including the epidermal growth factor (EGF)-family ligands epiregulin and HB-EGF, the chemokine CX3CL1, and the transcription factors SLUG and JUNB. The target genes were validated using quantitative reverse transcriptase-polymerase chain reaction, small interfering RNA knockdowns, chromatin immunoprecipitation, and luciferase reporter analyses. Immunohistochemistry of fetal kidneys confirmed that a number of the WT1 target genes had overlapping expression patterns with the highly restricted spatiotemporal expression of WT1. Finally, using an in vitro embryonic kidney culture assay, we found that the addition of recombinant epiregulin, amphiregulin, CX3CL1, and interleukin-11 significantly enhanced ureteric bud branching morphogenesis. Our genome-wide screen implicates WT1 in the transcriptional regulation of the EGF-family of growth factors as well as the CX3CL1 chemokine during nephrogenesis.

Standard name | KIM_WT1_TARGETS_DN
Systematic name | M17859
Organism | Homo sapiens
PMID | 17430890
Authors | Kim HS,Kim MS,Hancock AL,Harper JC,Park JY,Poy G,Perantoni AO,Cam M,Malik K,Lee SB
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in UB27 cells (osteosarcoma) at any time point after inducing the expression of a mutant form of WT1 [GeneID=7490].
Full description | The Wilms' tumor suppressor gene (WT1) encodes a zinc finger transcription factor that is vital during development of several organs including metanephric kidneys. Despite the critical regulatory role of WT1, the pathways and mechanisms by which WT1 orchestrates development remain elusive. To identify WT1 target genes, we performed a genome-wide expression profiling analysis in cells expressing inducible WT1. We identified a number of direct WT1 target genes, including the epidermal growth factor (EGF)-family ligands epiregulin and HB-EGF, the chemokine CX3CL1, and the transcription factors SLUG and JUNB. The target genes were validated using quantitative reverse transcriptase-polymerase chain reaction, small interfering RNA knockdowns, chromatin immunoprecipitation, and luciferase reporter analyses. Immunohistochemistry of fetal kidneys confirmed that a number of the WT1 target genes had overlapping expression patterns with the highly restricted spatiotemporal expression of WT1. Finally, using an in vitro embryonic kidney culture assay, we found that the addition of recombinant epiregulin, amphiregulin, CX3CL1, and interleukin-11 significantly enhanced ureteric bud branching morphogenesis. Our genome-wide screen implicates WT1 in the transcriptional regulation of the EGF-family of growth factors as well as the CX3CL1 chemokine during nephrogenesis.

Standard name | KIM_WT1_TARGETS_8HR_UP
Systematic name | M8857
Organism | Homo sapiens
PMID | 17430890
Authors | Kim HS,Kim MS,Hancock AL,Harper JC,Park JY,Poy G,Perantoni AO,Cam M,Malik K,Lee SB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in UB27 cells (osteosarcoma) at 8 hr after inducing the expression of a mutant form of WT1 [GeneID=7490].
Full description | The Wilms' tumor suppressor gene (WT1) encodes a zinc finger transcription factor that is vital during development of several organs including metanephric kidneys. Despite the critical regulatory role of WT1, the pathways and mechanisms by which WT1 orchestrates development remain elusive. To identify WT1 target genes, we performed a genome-wide expression profiling analysis in cells expressing inducible WT1. We identified a number of direct WT1 target genes, including the epidermal growth factor (EGF)-family ligands epiregulin and HB-EGF, the chemokine CX3CL1, and the transcription factors SLUG and JUNB. The target genes were validated using quantitative reverse transcriptase-polymerase chain reaction, small interfering RNA knockdowns, chromatin immunoprecipitation, and luciferase reporter analyses. Immunohistochemistry of fetal kidneys confirmed that a number of the WT1 target genes had overlapping expression patterns with the highly restricted spatiotemporal expression of WT1. Finally, using an in vitro embryonic kidney culture assay, we found that the addition of recombinant epiregulin, amphiregulin, CX3CL1, and interleukin-11 significantly enhanced ureteric bud branching morphogenesis. Our genome-wide screen implicates WT1 in the transcriptional regulation of the EGF-family of growth factors as well as the CX3CL1 chemokine during nephrogenesis.

Standard name | KIM_WT1_TARGETS_8HR_DN
Systematic name | M9948
Organism | Homo sapiens
PMID | 17430890
Authors | Kim HS,Kim MS,Hancock AL,Harper JC,Park JY,Poy G,Perantoni AO,Cam M,Malik K,Lee SB
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in UB27 cells (osteosarcoma) at 8 hr after inducing the expression of a mutant form of WT1 [GeneID=7490].
Full description | The Wilms' tumor suppressor gene (WT1) encodes a zinc finger transcription factor that is vital during development of several organs including metanephric kidneys. Despite the critical regulatory role of WT1, the pathways and mechanisms by which WT1 orchestrates development remain elusive. To identify WT1 target genes, we performed a genome-wide expression profiling analysis in cells expressing inducible WT1. We identified a number of direct WT1 target genes, including the epidermal growth factor (EGF)-family ligands epiregulin and HB-EGF, the chemokine CX3CL1, and the transcription factors SLUG and JUNB. The target genes were validated using quantitative reverse transcriptase-polymerase chain reaction, small interfering RNA knockdowns, chromatin immunoprecipitation, and luciferase reporter analyses. Immunohistochemistry of fetal kidneys confirmed that a number of the WT1 target genes had overlapping expression patterns with the highly restricted spatiotemporal expression of WT1. Finally, using an in vitro embryonic kidney culture assay, we found that the addition of recombinant epiregulin, amphiregulin, CX3CL1, and interleukin-11 significantly enhanced ureteric bud branching morphogenesis. Our genome-wide screen implicates WT1 in the transcriptional regulation of the EGF-family of growth factors as well as the CX3CL1 chemokine during nephrogenesis.

Standard name | KIM_WT1_TARGETS_12HR_UP
Systematic name | M15535
Organism | Homo sapiens
PMID | 17430890
Authors | Kim HS,Kim MS,Hancock AL,Harper JC,Park JY,Poy G,Perantoni AO,Cam M,Malik K,Lee SB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in UB27 cells (osteosarcoma) at 12 hr after inducing the expression of a mutated form of WT1 [GeneID=7490].
Full description | The Wilms' tumor suppressor gene (WT1) encodes a zinc finger transcription factor that is vital during development of several organs including metanephric kidneys. Despite the critical regulatory role of WT1, the pathways and mechanisms by which WT1 orchestrates development remain elusive. To identify WT1 target genes, we performed a genome-wide expression profiling analysis in cells expressing inducible WT1. We identified a number of direct WT1 target genes, including the epidermal growth factor (EGF)-family ligands epiregulin and HB-EGF, the chemokine CX3CL1, and the transcription factors SLUG and JUNB. The target genes were validated using quantitative reverse transcriptase-polymerase chain reaction, small interfering RNA knockdowns, chromatin immunoprecipitation, and luciferase reporter analyses. Immunohistochemistry of fetal kidneys confirmed that a number of the WT1 target genes had overlapping expression patterns with the highly restricted spatiotemporal expression of WT1. Finally, using an in vitro embryonic kidney culture assay, we found that the addition of recombinant epiregulin, amphiregulin, CX3CL1, and interleukin-11 significantly enhanced ureteric bud branching morphogenesis. Our genome-wide screen implicates WT1 in the transcriptional regulation of the EGF-family of growth factors as well as the CX3CL1 chemokine during nephrogenesis.

Standard name | KIM_WT1_TARGETS_12HR_DN
Systematic name | M4987
Organism | Homo sapiens
PMID | 17430890
Authors | Kim HS,Kim MS,Hancock AL,Harper JC,Park JY,Poy G,Perantoni AO,Cam M,Malik K,Lee SB
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in UB27 cells (osteosarcoma) at 12 hr after inducing the expression of a mutated form of WT1 [GeneID=7490].
Full description | The Wilms' tumor suppressor gene (WT1) encodes a zinc finger transcription factor that is vital during development of several organs including metanephric kidneys. Despite the critical regulatory role of WT1, the pathways and mechanisms by which WT1 orchestrates development remain elusive. To identify WT1 target genes, we performed a genome-wide expression profiling analysis in cells expressing inducible WT1. We identified a number of direct WT1 target genes, including the epidermal growth factor (EGF)-family ligands epiregulin and HB-EGF, the chemokine CX3CL1, and the transcription factors SLUG and JUNB. The target genes were validated using quantitative reverse transcriptase-polymerase chain reaction, small interfering RNA knockdowns, chromatin immunoprecipitation, and luciferase reporter analyses. Immunohistochemistry of fetal kidneys confirmed that a number of the WT1 target genes had overlapping expression patterns with the highly restricted spatiotemporal expression of WT1. Finally, using an in vitro embryonic kidney culture assay, we found that the addition of recombinant epiregulin, amphiregulin, CX3CL1, and interleukin-11 significantly enhanced ureteric bud branching morphogenesis. Our genome-wide screen implicates WT1 in the transcriptional regulation of the EGF-family of growth factors as well as the CX3CL1 chemokine during nephrogenesis.

Standard name | ELVIDGE_HYPOXIA_UP
Systematic name | M7363
Organism | Homo sapiens
PMID | 16565084
Authors | Elvidge GP,Glenny L,Appelhoff RJ,Ratcliffe PJ,Ragoussis J,Gleadle JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) under hypoxia conditions.
Full description | Studies of gene regulation by oxygen have revealed novel signal pathways that regulate the hypoxia-inducible factor (HIF) transcriptional system through post-translational hydroxylation of specific prolyl and asparaginyl residues in HIF-alpha subunits. These oxygen-sensitive modifications are catalyzed by members of the 2-oxoglutarate (2-OG) dioxygenase family (PHD1, PHD2, PHD3, and FIH-1), raising an important question regarding the extent of involvement of these and other enzymes of the same family in directing the global changes in gene expression that are induced by hypoxia. To address this, we compared patterns of gene expression induced by hypoxia and by a nonspecific 2-OG-dependent dioxygenase inhibitor, dimethyloxalylglycine (DMOG), among a set of 22,000 transcripts, by microarray analysis of MCF7 cells. By using short interfering RNA-based suppression of HIF-alpha subunits, we also compared responses that were dependent on, or independent of, the HIF system. Results revealed striking concordance between patterns of gene expression induced by hypoxia and by DMOG, indicating the central involvement of 2-OG-dependent dioxygenases in oxygen-regulated gene expression. Many of these responses were suppressed by short interfering RNAs directed against HIF-1alpha and HIF-2alpha, with HIF-1alpha suppression manifesting substantially greater effects than HIF-2alpha suppression, supporting the importance of HIF pathways. Nevertheless, the definition of genes regulated by both hypoxia and DMOG, but not HIF, distinguished other pathways most likely involving the action of 2-OG-dependent dioxygenases on non-HIF substrates.

Standard name | ELVIDGE_HYPOXIA_DN
Systematic name | M10175
Organism | Homo sapiens
PMID | 16565084
Authors | Elvidge GP,Glenny L,Appelhoff RJ,Ratcliffe PJ,Ragoussis J,Gleadle JM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) under hypoxia conditions.
Full description | Studies of gene regulation by oxygen have revealed novel signal pathways that regulate the hypoxia-inducible factor (HIF) transcriptional system through post-translational hydroxylation of specific prolyl and asparaginyl residues in HIF-alpha subunits. These oxygen-sensitive modifications are catalyzed by members of the 2-oxoglutarate (2-OG) dioxygenase family (PHD1, PHD2, PHD3, and FIH-1), raising an important question regarding the extent of involvement of these and other enzymes of the same family in directing the global changes in gene expression that are induced by hypoxia. To address this, we compared patterns of gene expression induced by hypoxia and by a nonspecific 2-OG-dependent dioxygenase inhibitor, dimethyloxalylglycine (DMOG), among a set of 22,000 transcripts, by microarray analysis of MCF7 cells. By using short interfering RNA-based suppression of HIF-alpha subunits, we also compared responses that were dependent on, or independent of, the HIF system. Results revealed striking concordance between patterns of gene expression induced by hypoxia and by DMOG, indicating the central involvement of 2-OG-dependent dioxygenases in oxygen-regulated gene expression. Many of these responses were suppressed by short interfering RNAs directed against HIF-1alpha and HIF-2alpha, with HIF-1alpha suppression manifesting substantially greater effects than HIF-2alpha suppression, supporting the importance of HIF pathways. Nevertheless, the definition of genes regulated by both hypoxia and DMOG, but not HIF, distinguished other pathways most likely involving the action of 2-OG-dependent dioxygenases on non-HIF substrates.

Standard name | ELVIDGE_HYPOXIA_BY_DMOG_UP
Systematic name | M9197
Organism | Homo sapiens
PMID | 16565084
Authors | Elvidge GP,Glenny L,Appelhoff RJ,Ratcliffe PJ,Ragoussis J,Gleadle JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) treated with hypoxia mimetic DMOG [PubChem=3080614].
Full description | Studies of gene regulation by oxygen have revealed novel signal pathways that regulate the hypoxia-inducible factor (HIF) transcriptional system through post-translational hydroxylation of specific prolyl and asparaginyl residues in HIF-alpha subunits. These oxygen-sensitive modifications are catalyzed by members of the 2-oxoglutarate (2-OG) dioxygenase family (PHD1, PHD2, PHD3, and FIH-1), raising an important question regarding the extent of involvement of these and other enzymes of the same family in directing the global changes in gene expression that are induced by hypoxia. To address this, we compared patterns of gene expression induced by hypoxia and by a nonspecific 2-OG-dependent dioxygenase inhibitor, dimethyloxalylglycine (DMOG), among a set of 22,000 transcripts, by microarray analysis of MCF7 cells. By using short interfering RNA-based suppression of HIF-alpha subunits, we also compared responses that were dependent on, or independent of, the HIF system. Results revealed striking concordance between patterns of gene expression induced by hypoxia and by DMOG, indicating the central involvement of 2-OG-dependent dioxygenases in oxygen-regulated gene expression. Many of these responses were suppressed by short interfering RNAs directed against HIF-1alpha and HIF-2alpha, with HIF-1alpha suppression manifesting substantially greater effects than HIF-2alpha suppression, supporting the importance of HIF pathways. Nevertheless, the definition of genes regulated by both hypoxia and DMOG, but not HIF, distinguished other pathways most likely involving the action of 2-OG-dependent dioxygenases on non-HIF substrates.

Standard name | ELVIDGE_HYPOXIA_BY_DMOG_DN
Systematic name | M7030
Organism | Homo sapiens
PMID | 16565084
Authors | Elvidge GP,Glenny L,Appelhoff RJ,Ratcliffe PJ,Ragoussis J,Gleadle JM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) treated with hypoxia mimetic DMOG [PubChem=3080614].
Full description | Studies of gene regulation by oxygen have revealed novel signal pathways that regulate the hypoxia-inducible factor (HIF) transcriptional system through post-translational hydroxylation of specific prolyl and asparaginyl residues in HIF-alpha subunits. These oxygen-sensitive modifications are catalyzed by members of the 2-oxoglutarate (2-OG) dioxygenase family (PHD1, PHD2, PHD3, and FIH-1), raising an important question regarding the extent of involvement of these and other enzymes of the same family in directing the global changes in gene expression that are induced by hypoxia. To address this, we compared patterns of gene expression induced by hypoxia and by a nonspecific 2-OG-dependent dioxygenase inhibitor, dimethyloxalylglycine (DMOG), among a set of 22,000 transcripts, by microarray analysis of MCF7 cells. By using short interfering RNA-based suppression of HIF-alpha subunits, we also compared responses that were dependent on, or independent of, the HIF system. Results revealed striking concordance between patterns of gene expression induced by hypoxia and by DMOG, indicating the central involvement of 2-OG-dependent dioxygenases in oxygen-regulated gene expression. Many of these responses were suppressed by short interfering RNAs directed against HIF-1alpha and HIF-2alpha, with HIF-1alpha suppression manifesting substantially greater effects than HIF-2alpha suppression, supporting the importance of HIF pathways. Nevertheless, the definition of genes regulated by both hypoxia and DMOG, but not HIF, distinguished other pathways most likely involving the action of 2-OG-dependent dioxygenases on non-HIF substrates.

Standard name | ELVIDGE_HIF1A_TARGETS_UP
Systematic name | M17905
Organism | Homo sapiens
PMID | 16565084
Authors | Elvidge GP,Glenny L,Appelhoff RJ,Ratcliffe PJ,Ragoussis J,Gleadle JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) after knockdown of HIF1A [GeneID=3091] by RNAi.
Full description | Studies of gene regulation by oxygen have revealed novel signal pathways that regulate the hypoxia-inducible factor (HIF) transcriptional system through post-translational hydroxylation of specific prolyl and asparaginyl residues in HIF-alpha subunits. These oxygen-sensitive modifications are catalyzed by members of the 2-oxoglutarate (2-OG) dioxygenase family (PHD1, PHD2, PHD3, and FIH-1), raising an important question regarding the extent of involvement of these and other enzymes of the same family in directing the global changes in gene expression that are induced by hypoxia. To address this, we compared patterns of gene expression induced by hypoxia and by a nonspecific 2-OG-dependent dioxygenase inhibitor, dimethyloxalylglycine (DMOG), among a set of 22,000 transcripts, by microarray analysis of MCF7 cells. By using short interfering RNA-based suppression of HIF-alpha subunits, we also compared responses that were dependent on, or independent of, the HIF system. Results revealed striking concordance between patterns of gene expression induced by hypoxia and by DMOG, indicating the central involvement of 2-OG-dependent dioxygenases in oxygen-regulated gene expression. Many of these responses were suppressed by short interfering RNAs directed against HIF-1alpha and HIF-2alpha, with HIF-1alpha suppression manifesting substantially greater effects than HIF-2alpha suppression, supporting the importance of HIF pathways. Nevertheless, the definition of genes regulated by both hypoxia and DMOG, but not HIF, distinguished other pathways most likely involving the action of 2-OG-dependent dioxygenases on non-HIF substrates.

Standard name | ELVIDGE_HIF1A_TARGETS_DN
Systematic name | M2513
Organism | Homo sapiens
PMID | 16565084
Authors | Elvidge GP,Glenny L,Appelhoff RJ,Ratcliffe PJ,Ragoussis J,Gleadle JM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) after knockdown of HIF1A [GeneID=3091] by RNAi.
Full description | Studies of gene regulation by oxygen have revealed novel signal pathways that regulate the hypoxia-inducible factor (HIF) transcriptional system through post-translational hydroxylation of specific prolyl and asparaginyl residues in HIF-alpha subunits. These oxygen-sensitive modifications are catalyzed by members of the 2-oxoglutarate (2-OG) dioxygenase family (PHD1, PHD2, PHD3, and FIH-1), raising an important question regarding the extent of involvement of these and other enzymes of the same family in directing the global changes in gene expression that are induced by hypoxia. To address this, we compared patterns of gene expression induced by hypoxia and by a nonspecific 2-OG-dependent dioxygenase inhibitor, dimethyloxalylglycine (DMOG), among a set of 22,000 transcripts, by microarray analysis of MCF7 cells. By using short interfering RNA-based suppression of HIF-alpha subunits, we also compared responses that were dependent on, or independent of, the HIF system. Results revealed striking concordance between patterns of gene expression induced by hypoxia and by DMOG, indicating the central involvement of 2-OG-dependent dioxygenases in oxygen-regulated gene expression. Many of these responses were suppressed by short interfering RNAs directed against HIF-1alpha and HIF-2alpha, with HIF-1alpha suppression manifesting substantially greater effects than HIF-2alpha suppression, supporting the importance of HIF pathways. Nevertheless, the definition of genes regulated by both hypoxia and DMOG, but not HIF, distinguished other pathways most likely involving the action of 2-OG-dependent dioxygenases on non-HIF substrates.

Standard name | ELVIDGE_HIF2A_TARGETS_UP
Systematic name | M8397
Organism | Homo sapiens
PMID | 16565084
Authors | Elvidge GP,Glenny L,Appelhoff RJ,Ratcliffe PJ,Ragoussis J,Gleadle JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) after knockdown of HIF2A [GeneID=2034] by RNAi.
Full description | Studies of gene regulation by oxygen have revealed novel signal pathways that regulate the hypoxia-inducible factor (HIF) transcriptional system through post-translational hydroxylation of specific prolyl and asparaginyl residues in HIF-alpha subunits. These oxygen-sensitive modifications are catalyzed by members of the 2-oxoglutarate (2-OG) dioxygenase family (PHD1, PHD2, PHD3, and FIH-1), raising an important question regarding the extent of involvement of these and other enzymes of the same family in directing the global changes in gene expression that are induced by hypoxia. To address this, we compared patterns of gene expression induced by hypoxia and by a nonspecific 2-OG-dependent dioxygenase inhibitor, dimethyloxalylglycine (DMOG), among a set of 22,000 transcripts, by microarray analysis of MCF7 cells. By using short interfering RNA-based suppression of HIF-alpha subunits, we also compared responses that were dependent on, or independent of, the HIF system. Results revealed striking concordance between patterns of gene expression induced by hypoxia and by DMOG, indicating the central involvement of 2-OG-dependent dioxygenases in oxygen-regulated gene expression. Many of these responses were suppressed by short interfering RNAs directed against HIF-1alpha and HIF-2alpha, with HIF-1alpha suppression manifesting substantially greater effects than HIF-2alpha suppression, supporting the importance of HIF pathways. Nevertheless, the definition of genes regulated by both hypoxia and DMOG, but not HIF, distinguished other pathways most likely involving the action of 2-OG-dependent dioxygenases on non-HIF substrates.

Standard name | ELVIDGE_HIF1A_AND_HIF2A_TARGETS_UP
Systematic name | M7062
Organism | Homo sapiens
PMID | 16565084
Authors | Elvidge GP,Glenny L,Appelhoff RJ,Ratcliffe PJ,Ragoussis J,Gleadle JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) after knockdown of both HIF1A and HIF2A [GeneID=3091;2034] by RNAi.
Full description | Studies of gene regulation by oxygen have revealed novel signal pathways that regulate the hypoxia-inducible factor (HIF) transcriptional system through post-translational hydroxylation of specific prolyl and asparaginyl residues in HIF-alpha subunits. These oxygen-sensitive modifications are catalyzed by members of the 2-oxoglutarate (2-OG) dioxygenase family (PHD1, PHD2, PHD3, and FIH-1), raising an important question regarding the extent of involvement of these and other enzymes of the same family in directing the global changes in gene expression that are induced by hypoxia. To address this, we compared patterns of gene expression induced by hypoxia and by a nonspecific 2-OG-dependent dioxygenase inhibitor, dimethyloxalylglycine (DMOG), among a set of 22,000 transcripts, by microarray analysis of MCF7 cells. By using short interfering RNA-based suppression of HIF-alpha subunits, we also compared responses that were dependent on, or independent of, the HIF system. Results revealed striking concordance between patterns of gene expression induced by hypoxia and by DMOG, indicating the central involvement of 2-OG-dependent dioxygenases in oxygen-regulated gene expression. Many of these responses were suppressed by short interfering RNAs directed against HIF-1alpha and HIF-2alpha, with HIF-1alpha suppression manifesting substantially greater effects than HIF-2alpha suppression, supporting the importance of HIF pathways. Nevertheless, the definition of genes regulated by both hypoxia and DMOG, but not HIF, distinguished other pathways most likely involving the action of 2-OG-dependent dioxygenases on non-HIF substrates.

Standard name | ELVIDGE_HIF1A_AND_HIF2A_TARGETS_DN
Systematic name | M6189
Organism | Homo sapiens
PMID | 16565084
Authors | Elvidge GP,Glenny L,Appelhoff RJ,Ratcliffe PJ,Ragoussis J,Gleadle JM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) after knockdown of both HIF1A and HIF2A [GeneID=3091;2034] by RNAi.
Full description | Studies of gene regulation by oxygen have revealed novel signal pathways that regulate the hypoxia-inducible factor (HIF) transcriptional system through post-translational hydroxylation of specific prolyl and asparaginyl residues in HIF-alpha subunits. These oxygen-sensitive modifications are catalyzed by members of the 2-oxoglutarate (2-OG) dioxygenase family (PHD1, PHD2, PHD3, and FIH-1), raising an important question regarding the extent of involvement of these and other enzymes of the same family in directing the global changes in gene expression that are induced by hypoxia. To address this, we compared patterns of gene expression induced by hypoxia and by a nonspecific 2-OG-dependent dioxygenase inhibitor, dimethyloxalylglycine (DMOG), among a set of 22,000 transcripts, by microarray analysis of MCF7 cells. By using short interfering RNA-based suppression of HIF-alpha subunits, we also compared responses that were dependent on, or independent of, the HIF system. Results revealed striking concordance between patterns of gene expression induced by hypoxia and by DMOG, indicating the central involvement of 2-OG-dependent dioxygenases in oxygen-regulated gene expression. Many of these responses were suppressed by short interfering RNAs directed against HIF-1alpha and HIF-2alpha, with HIF-1alpha suppression manifesting substantially greater effects than HIF-2alpha suppression, supporting the importance of HIF pathways. Nevertheless, the definition of genes regulated by both hypoxia and DMOG, but not HIF, distinguished other pathways most likely involving the action of 2-OG-dependent dioxygenases on non-HIF substrates.

Standard name | JAATINEN_HEMATOPOIETIC_STEM_CELL_UP
Systematic name | M15107
Organism | Homo sapiens
PMID | 16210406
Authors | Jaatinen T,Hemmoranta H,Hautaniemi S,Niemi J,Nicorici D,Laine J,Yli-Harja O,Partanen J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD133+ [GeneID=8842] cells (hematopoietic stem cells, HSC) compared to the CD133- cells.
Full description | Human cord blood (CB)-derived CD133+ cells carry characteristics of primitive hematopoietic cells and proffer an alternative for CD34+ cells in hematopoietic stem cell (HSC) transplantation. To characterize the CD133+ cell population on a genetic level, a global expression analysis of CD133+ cells was performed using oligonucleotide microarrays. CD133+ cells were purified from four fresh CB units by immunomagnetic selection. All four CD133+ samples showed significant similarity in their gene expression pattern, whereas they differed clearly from the CD133- control samples. In all, 690 transcripts were differentially expressed between CD133+ and CD133- cells. Of these, 393 were increased and 297 were decreased in CD133+ cells. The highest overexpression was noted in genes associated with metabolism, cellular physiological processes, cell communication, and development. A set of 257 transcripts expressed solely in the CD133+ cell population was identified. Colony-forming unit (CFU) assay was used to detect the clonal progeny of precursors present in the studied cell populations. The results demonstrate that CD133+ cells express primitive markers and possess clonogenic progenitor capacity. This study provides a gene expression profile for human CD133+ cells. It presents a set of genes that may be used to unravel the properties of the CD133+ cell population, assumed to be highly enriched in HSCs.

Standard name | JAATINEN_HEMATOPOIETIC_STEM_CELL_DN
Systematic name | M6905
Organism | Homo sapiens
PMID | 16210406
Authors | Jaatinen T,Hemmoranta H,Hautaniemi S,Niemi J,Nicorici D,Laine J,Yli-Harja O,Partanen J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD133+ [GeneID=8842] cells (hematopoietic stem cells, HSC) compared to the CD133- cells.
Full description | Human cord blood (CB)-derived CD133+ cells carry characteristics of primitive hematopoietic cells and proffer an alternative for CD34+ cells in hematopoietic stem cell (HSC) transplantation. To characterize the CD133+ cell population on a genetic level, a global expression analysis of CD133+ cells was performed using oligonucleotide microarrays. CD133+ cells were purified from four fresh CB units by immunomagnetic selection. All four CD133+ samples showed significant similarity in their gene expression pattern, whereas they differed clearly from the CD133- control samples. In all, 690 transcripts were differentially expressed between CD133+ and CD133- cells. Of these, 393 were increased and 297 were decreased in CD133+ cells. The highest overexpression was noted in genes associated with metabolism, cellular physiological processes, cell communication, and development. A set of 257 transcripts expressed solely in the CD133+ cell population was identified. Colony-forming unit (CFU) assay was used to detect the clonal progeny of precursors present in the studied cell populations. The results demonstrate that CD133+ cells express primitive markers and possess clonogenic progenitor capacity. This study provides a gene expression profile for human CD133+ cells. It presents a set of genes that may be used to unravel the properties of the CD133+ cell population, assumed to be highly enriched in HSCs.

Standard name | MOROSETTI_FACIOSCAPULOHUMERAL_MUSCULAR_DISTROPHY_UP
Systematic name | M5409
Organism | Homo sapiens
PMID | 17761758
Authors | Morosetti R,Mirabella M,Gliubizzi C,Broccolini A,Sancricca C,Pescatori M,Gidaro T,Tasca G,Frusciante R,Tonali PA,Cossu G,Ricci E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in FSHD (facioscapulohumeral muscular dystrophy) mesoangioblasts.
Full description | Facioscapulohumeral muscular dystrophy (FSHD) is the third most frequent inherited muscle disease. Because in FSHD patients the coexistence of affected and unaffected muscles is common, myoblasts expanded from unaffected FSHD muscles have been proposed as suitable tools for autologous cell transplantation. Mesoangioblasts are a new class of adult stem cells of mesodermal origin, potentially useful for the treatment of primitive myopathies of different etiology. Here, we report the isolation and characterization of mesoangioblasts from FSHD muscle biopsies and describe morphology, proliferation, and differentiation abilities of both mesoangioblasts and myoblasts derived from various affected and unaffected muscles of nine representative FSHD patients. We demonstrate that mesoangioblasts can be efficiently isolated from FSHD muscle biopsies and expanded to an amount of cells necessary to transplant into an adult patient. Proliferating mesoangioblasts from all muscles examined did not differ from controls in terms of morphology, phenotype, proliferation rate, or clonogenicity. However, their differentiation ability into skeletal muscle was variably impaired, and this defect correlated with the overall disease severity and the degree of histopathologic abnormalities of the muscle of origin. A remarkable differentiation defect was observed in mesoangioblasts from all mildly to severely affected FSHD muscles, whereas mesoangioblasts from morphologically normal muscles showed no myogenic differentiation block. Our study could open the way to cell therapy for FSHD patients to limit muscle damage in vivo through the use of autologous mesoangioblasts capable of reaching damaged muscles and engrafting into them, without requiring immune suppression or genetic correction in vitro. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | MOROSETTI_FACIOSCAPULOHUMERAL_MUSCULAR_DISTROPHY_DN
Systematic name | M15593
Organism | Homo sapiens
PMID | 17761758
Authors | Morosetti R,Mirabella M,Gliubizzi C,Broccolini A,Sancricca C,Pescatori M,Gidaro T,Tasca G,Frusciante R,Tonali PA,Cossu G,Ricci E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in FSHD (facioscapulohumeral muscular dystrophy) mesoangioblasts.
Full description | Facioscapulohumeral muscular dystrophy (FSHD) is the third most frequent inherited muscle disease. Because in FSHD patients the coexistence of affected and unaffected muscles is common, myoblasts expanded from unaffected FSHD muscles have been proposed as suitable tools for autologous cell transplantation. Mesoangioblasts are a new class of adult stem cells of mesodermal origin, potentially useful for the treatment of primitive myopathies of different etiology. Here, we report the isolation and characterization of mesoangioblasts from FSHD muscle biopsies and describe morphology, proliferation, and differentiation abilities of both mesoangioblasts and myoblasts derived from various affected and unaffected muscles of nine representative FSHD patients. We demonstrate that mesoangioblasts can be efficiently isolated from FSHD muscle biopsies and expanded to an amount of cells necessary to transplant into an adult patient. Proliferating mesoangioblasts from all muscles examined did not differ from controls in terms of morphology, phenotype, proliferation rate, or clonogenicity. However, their differentiation ability into skeletal muscle was variably impaired, and this defect correlated with the overall disease severity and the degree of histopathologic abnormalities of the muscle of origin. A remarkable differentiation defect was observed in mesoangioblasts from all mildly to severely affected FSHD muscles, whereas mesoangioblasts from morphologically normal muscles showed no myogenic differentiation block. Our study could open the way to cell therapy for FSHD patients to limit muscle damage in vivo through the use of autologous mesoangioblasts capable of reaching damaged muscles and engrafting into them, without requiring immune suppression or genetic correction in vitro. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_CML_QUIESCENT_VS_CML_DIVIDING_UP
Systematic name | M19744
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in quiescent (G0) vs dividing (M) CD34+ [GeneID=8842] cells isolated from peripheral blood of CML (chronic myeloid leukemia) patients.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_CML_QUIESCENT_VS_CML_DIVIDING_DN
Systematic name | M629
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in quiescent (G0) vs dividing (M) CD34+ [GeneID=8842] cells isolated from peripheral blood of CML (chronic myeloid leukemia) patients.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_CML_QUIESCENT_VS_NORMAL_QUIESCENT_UP
Systematic name | M18983
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in quiescent (G0) CD34+ [GeneID=8842] cells isolated from peripheral blood of CML (chronic myeloid leukemia) patients compared to the quiescent cells from normal donors.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_CML_QUIESCENT_VS_NORMAL_QUIESCENT_DN
Systematic name | M11636
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in quiescent (G0) CD34+ [GeneID=8842] cells isolated from peripheral blood of CML (chronic myeloid leukemia) patients compared to the quiescent cells from normal donors.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_CML_QUIESCENT_VS_NORMAL_DIVIDING_UP
Systematic name | M17730
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in quescent CD34+ [GeneID=8842] cells isolated from peripheral blood of CML (chronic myeloblastic leukemia) patients compared to the dividing cells from normal donors.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_CML_QUIESCENT_VS_NORMAL_DIVIDING_DN
Systematic name | M13254
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in quescent CD34+ [GeneID=8842] cells isolated from peripheral blood of CML (chronic myeloblastic leukemia) patients compared to the dividing cells from normal donors.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_CML_DIVIDING_VS_NORMAL_DIVIDING_UP
Systematic name | M19476
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in dividing CD34+ [GeneID=8842] cells isolated from peripheral blood of CML (chronic myeloid leukemia) patients compared to the dividing cells from normal donors.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_CML_DIVIDING_VS_NORMAL_DIVIDING_DN
Systematic name | M19367
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in dividing CD34+ [GeneID=8842] cells isolated from peripheral blood of CML (chronic myeloid leukemia) patients compared to the dividing cells from normal donors.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_CML_DIVIDING_VS_NORMAL_QUIESCENT_UP
Systematic name | M3155
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in quiescent CD34+ [GeneID=8842] cells isolated from peripheral blood of normal donors compared to the dividing cells from CML (chronic myeloid leukemia) patients.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_CML_DIVIDING_VS_NORMAL_QUIESCENT_DN
Systematic name | M4235
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in quiescent CD34+ [GeneID=8842] cells isolated from peripheral blood of normal donors compared to the dividing cells from CML (chronic myeloid leukemia) patients.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_NORMAL_QUIESCENT_VS_NORMAL_DIVIDING_UP
Systematic name | M4406
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in quiescent vs dividing CD34+ [GeneID=8842] cells isolated from peripheral blood of normal donors.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | GRAHAM_NORMAL_QUIESCENT_VS_NORMAL_DIVIDING_DN
Systematic name | M5198
Organism | Homo sapiens
PMID | 17717066
Authors | Graham SM,Vass JK,Holyoake TL,Graham GJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in quiescent vs dividing CD34+ [GeneID=8842] cells isolated from peripheral blood of normal donors.
Full description | Quiescent and dividing hemopoietic stem cells (HSC) display marked differences in their ability to move between the peripheral circulation and the bone marrow. Specifically, long-term engraftment potential predominantly resides in the quiescent HSC subfraction, and G-CSF mobilization results in the preferential accumulation of quiescent HSC in the periphery. In contrast, stem cells from chronic myeloid leukemia (CML) patients display a constitutive presence in the circulation. To understand the molecular basis for this, we have used microarray technology to analyze the transcriptional differences between dividing and quiescent, normal, and CML-derived CD34+ cells. Our data show a remarkable transcriptional similarity between normal and CML dividing cells, suggesting that the effects of BCR-ABL on the CD34+ cell transcriptome are more limited than previously thought. In addition, we show that quiescent CML cells are more similar to their dividing counterparts than quiescent normal cells are to theirs. We also show these transcriptional differences to be reflected in the altered proliferative activity of normal and CML CD34+ cells. Of the most interest is that the major class of genes that is more abundant in the quiescent cells compared with the dividing cells encodes members of the chemokine family. We propose a role for chemokines expressed by quiescent HSC in the orchestration of CD34+ cell mobilization. Disclosure of potential conflicts of interest is found at the end of this article.

Standard name | BIDUS_METASTASIS_UP
Systematic name | M15866
Organism | Homo sapiens
PMID | 16397028
Authors | Bidus MA,Risinger JI,Chandramouli GV,Dainty LA,Litzi TJ,Berchuck A,Barrett JC,Maxwell GL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in endometroid endometrial tumors from patients with lymph node metastases compared to those without the metastases.
Full description | PURPOSE: To characterize the gene expression profiles of endometrioid endometrial cancers associated with lymph node metastasis in an effort to identify genes associated with metastatic spread. EXPERIMENTAL DESIGN: Tumors from 41 patients with endometrioid endometrial cancer grossly confined to the uterine cavity were evaluated. Positive lymph nodes were noted in 12 of 41 patients. RNA was analyzed for gene expression using the Affymetrix HG133A and HG133B GeneChip set, representing 45,000 array features covering >28,000 UniGene clusters. Data analysis was done using multidimensional scaling, binary comparison, and hierarchical clustering. Gene expression for several differentially expressed genes was examined using quantitative PCR. RESULTS: Gene expression data was obtained from 30,964 genes that were detected in at least 5% of the cases. Supervised analysis of node-positive versus node-negative cases indicated that 450 genes were significantly differentially expressed between the two classes at P < 0.005, 81 of which were differentially expressed by at least 2-fold at P < 0.005. Overexpressed genes included two cell cycle checkpoint genes, CDC2 and MAD2L1, which have previously been described in association with lymph node metastasis in other cancer types. The ZIC2 zinc finger gene was overexpressed in endometrial cancers with positive nodes versus those with negative nodes. CONCLUSION: Gene expression profiling of the primary tumors in patients with endometrioid endometrial cancers seems promising for identifying genes associated with lymph node metastasis. Future studies should address whether the status of nodal metastasis can be determined from the expression profiles of preoperative tissue specimens.

Standard name | BIDUS_METASTASIS_DN
Systematic name | M8818
Organism | Homo sapiens
PMID | 16397028
Authors | Bidus MA,Risinger JI,Chandramouli GV,Dainty LA,Litzi TJ,Berchuck A,Barrett JC,Maxwell GL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in endometroid endometrial tumors from patients with lymph node metastases compared to those without the metastases.
Full description | PURPOSE: To characterize the gene expression profiles of endometrioid endometrial cancers associated with lymph node metastasis in an effort to identify genes associated with metastatic spread. EXPERIMENTAL DESIGN: Tumors from 41 patients with endometrioid endometrial cancer grossly confined to the uterine cavity were evaluated. Positive lymph nodes were noted in 12 of 41 patients. RNA was analyzed for gene expression using the Affymetrix HG133A and HG133B GeneChip set, representing 45,000 array features covering >28,000 UniGene clusters. Data analysis was done using multidimensional scaling, binary comparison, and hierarchical clustering. Gene expression for several differentially expressed genes was examined using quantitative PCR. RESULTS: Gene expression data was obtained from 30,964 genes that were detected in at least 5% of the cases. Supervised analysis of node-positive versus node-negative cases indicated that 450 genes were significantly differentially expressed between the two classes at P < 0.005, 81 of which were differentially expressed by at least 2-fold at P < 0.005. Overexpressed genes included two cell cycle checkpoint genes, CDC2 and MAD2L1, which have previously been described in association with lymph node metastasis in other cancer types. The ZIC2 zinc finger gene was overexpressed in endometrial cancers with positive nodes versus those with negative nodes. CONCLUSION: Gene expression profiling of the primary tumors in patients with endometrioid endometrial cancers seems promising for identifying genes associated with lymph node metastasis. Future studies should address whether the status of nodal metastasis can be determined from the expression profiles of preoperative tissue specimens.

Standard name | WAMUNYOKOLI_OVARIAN_CANCER_LMP_UP
Systematic name | M19982
Organism | Homo sapiens
PMID | 16467078
Authors | Wamunyokoli FW,Bonome T,Lee JY,Feltmate CM,Welch WR,Radonovich M,Pise-Masison C,Brady J,Hao K,Berkowitz RS,Mok S,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mucinous ovarian carcinoma tumors of low malignant potential (LMP) compared to normal ovarian surface epithelium tissue.
Full description | PURPOSE: To elucidate the molecular mechanisms contributing to the unique clinicopathologic characteristics of mucinous ovarian carcinoma, global gene expression profiling of mucinous ovarian tumors was carried out. EXPERIMENTAL DESIGN: Gene expression profiling was completed for 25 microdissected mucinous tumors [6 cystadenomas, 10 low malignant potential (LMP) tumors, and 9 adenocarcinomas] using Affymetrix U133 Plus 2.0 oligonucleotide microarrays. Hierarchical clustering and binary tree prediction analysis were used to determine the relationships among mucinous specimens and a series of previously profiled microdissected serous tumors and normal ovarian surface epithelium. PathwayAssist software was used to identify putative signaling pathways involved in the development of mucinous LMP tumors and adenocarcinomas. RESULTS: Comparison of the gene profiles between mucinous tumors and normal ovarian epithelial cells identified 1,599, 2,916, and 1,765 differentially expressed in genes in the cystadenomas, LMP tumors, and adenocarcinomas, respectively. Hierarchical clustering showed that mucinous and serous LMP tumors are distinct. In addition, there was a close association of mucinous LMP tumors and adenocarcinomas with serous adenocarcinomas. Binary tree prediction revealed increased heterogeneity among mucinous tumors compared with their serous counterparts. Furthermore, the cystadenomas coexpressed a subset of genes that were differentially regulated in LMP and adenocarcinoma specimens compared with normal ovarian surface epithelium. PathwayAssist highlighted pathways with expression of genes involved in drug resistance in both LMP and adenocarcinoma samples. In addition, genes involved in cytoskeletal regulation were specifically up-regulated in the mucinous adenocarcinomas. CONCLUSIONS: These data provide a useful basis for understanding the molecular events leading to the development and progression of mucinous ovarian cancer.

Standard name | WAMUNYOKOLI_OVARIAN_CANCER_LMP_DN
Systematic name | M10091
Organism | Homo sapiens
PMID | 16467078
Authors | Wamunyokoli FW,Bonome T,Lee JY,Feltmate CM,Welch WR,Radonovich M,Pise-Masison C,Brady J,Hao K,Berkowitz RS,Mok S,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mucinous ovarian carcinoma tumors of low malignant potential (LMP) compared to normal ovarian surface epithelium tissue.
Full description | PURPOSE: To elucidate the molecular mechanisms contributing to the unique clinicopathologic characteristics of mucinous ovarian carcinoma, global gene expression profiling of mucinous ovarian tumors was carried out. EXPERIMENTAL DESIGN: Gene expression profiling was completed for 25 microdissected mucinous tumors [6 cystadenomas, 10 low malignant potential (LMP) tumors, and 9 adenocarcinomas] using Affymetrix U133 Plus 2.0 oligonucleotide microarrays. Hierarchical clustering and binary tree prediction analysis were used to determine the relationships among mucinous specimens and a series of previously profiled microdissected serous tumors and normal ovarian surface epithelium. PathwayAssist software was used to identify putative signaling pathways involved in the development of mucinous LMP tumors and adenocarcinomas. RESULTS: Comparison of the gene profiles between mucinous tumors and normal ovarian epithelial cells identified 1,599, 2,916, and 1,765 differentially expressed in genes in the cystadenomas, LMP tumors, and adenocarcinomas, respectively. Hierarchical clustering showed that mucinous and serous LMP tumors are distinct. In addition, there was a close association of mucinous LMP tumors and adenocarcinomas with serous adenocarcinomas. Binary tree prediction revealed increased heterogeneity among mucinous tumors compared with their serous counterparts. Furthermore, the cystadenomas coexpressed a subset of genes that were differentially regulated in LMP and adenocarcinoma specimens compared with normal ovarian surface epithelium. PathwayAssist highlighted pathways with expression of genes involved in drug resistance in both LMP and adenocarcinoma samples. In addition, genes involved in cytoskeletal regulation were specifically up-regulated in the mucinous adenocarcinomas. CONCLUSIONS: These data provide a useful basis for understanding the molecular events leading to the development and progression of mucinous ovarian cancer.

Standard name | WAMUNYOKOLI_OVARIAN_CANCER_GRADES_1_2_UP
Systematic name | M2435
Organism | Homo sapiens
PMID | 16467078
Authors | Wamunyokoli FW,Bonome T,Lee JY,Feltmate CM,Welch WR,Radonovich M,Pise-Masison C,Brady J,Hao K,Berkowitz RS,Mok S,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mucinous ovarian carcinoma tumors of grades 1 and 2 compared to the normal ovarian survace epithelium tissue.
Full description | PURPOSE: To elucidate the molecular mechanisms contributing to the unique clinicopathologic characteristics of mucinous ovarian carcinoma, global gene expression profiling of mucinous ovarian tumors was carried out. EXPERIMENTAL DESIGN: Gene expression profiling was completed for 25 microdissected mucinous tumors [6 cystadenomas, 10 low malignant potential (LMP) tumors, and 9 adenocarcinomas] using Affymetrix U133 Plus 2.0 oligonucleotide microarrays. Hierarchical clustering and binary tree prediction analysis were used to determine the relationships among mucinous specimens and a series of previously profiled microdissected serous tumors and normal ovarian surface epithelium. PathwayAssist software was used to identify putative signaling pathways involved in the development of mucinous LMP tumors and adenocarcinomas. RESULTS: Comparison of the gene profiles between mucinous tumors and normal ovarian epithelial cells identified 1,599, 2,916, and 1,765 differentially expressed in genes in the cystadenomas, LMP tumors, and adenocarcinomas, respectively. Hierarchical clustering showed that mucinous and serous LMP tumors are distinct. In addition, there was a close association of mucinous LMP tumors and adenocarcinomas with serous adenocarcinomas. Binary tree prediction revealed increased heterogeneity among mucinous tumors compared with their serous counterparts. Furthermore, the cystadenomas coexpressed a subset of genes that were differentially regulated in LMP and adenocarcinoma specimens compared with normal ovarian surface epithelium. PathwayAssist highlighted pathways with expression of genes involved in drug resistance in both LMP and adenocarcinoma samples. In addition, genes involved in cytoskeletal regulation were specifically up-regulated in the mucinous adenocarcinomas. CONCLUSIONS: These data provide a useful basis for understanding the molecular events leading to the development and progression of mucinous ovarian cancer.

Standard name | WAMUNYOKOLI_OVARIAN_CANCER_GRADES_1_2_DN
Systematic name | M707
Organism | Homo sapiens
PMID | 16467078
Authors | Wamunyokoli FW,Bonome T,Lee JY,Feltmate CM,Welch WR,Radonovich M,Pise-Masison C,Brady J,Hao K,Berkowitz RS,Mok S,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mucinous ovarian carcinoma tumors of grades 1 and 2 compared to the normal ovarian survace epithelium tissue.
Full description | PURPOSE: To elucidate the molecular mechanisms contributing to the unique clinicopathologic characteristics of mucinous ovarian carcinoma, global gene expression profiling of mucinous ovarian tumors was carried out. EXPERIMENTAL DESIGN: Gene expression profiling was completed for 25 microdissected mucinous tumors [6 cystadenomas, 10 low malignant potential (LMP) tumors, and 9 adenocarcinomas] using Affymetrix U133 Plus 2.0 oligonucleotide microarrays. Hierarchical clustering and binary tree prediction analysis were used to determine the relationships among mucinous specimens and a series of previously profiled microdissected serous tumors and normal ovarian surface epithelium. PathwayAssist software was used to identify putative signaling pathways involved in the development of mucinous LMP tumors and adenocarcinomas. RESULTS: Comparison of the gene profiles between mucinous tumors and normal ovarian epithelial cells identified 1,599, 2,916, and 1,765 differentially expressed in genes in the cystadenomas, LMP tumors, and adenocarcinomas, respectively. Hierarchical clustering showed that mucinous and serous LMP tumors are distinct. In addition, there was a close association of mucinous LMP tumors and adenocarcinomas with serous adenocarcinomas. Binary tree prediction revealed increased heterogeneity among mucinous tumors compared with their serous counterparts. Furthermore, the cystadenomas coexpressed a subset of genes that were differentially regulated in LMP and adenocarcinoma specimens compared with normal ovarian surface epithelium. PathwayAssist highlighted pathways with expression of genes involved in drug resistance in both LMP and adenocarcinoma samples. In addition, genes involved in cytoskeletal regulation were specifically up-regulated in the mucinous adenocarcinomas. CONCLUSIONS: These data provide a useful basis for understanding the molecular events leading to the development and progression of mucinous ovarian cancer.

Standard name | MAYBURD_RESPONSE_TO_L663536_UP
Systematic name | M12002
Organism | Homo sapiens
PMID | 16551867
Authors | Mayburd AL,Martlínez A,Sackett D,Liu H,Shih J,Tauler J,Avis I,Mulshine JL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in H720 cells (lung cancer) after treatment with L663536 (MK886) [PubChem=105049], an inhibitor of leukotriene biosynthesis.
Full description | The small molecular inhibitor MK886 is known to block 5-lipoxygenase-activating protein ALOX5AP and shows antitumor activity in multiple human cell lines. The broad antitumor therapeutic window reported in vivo for MK886 in rodents supports further consideration of this structural class. Better understanding of the mode of action of the drug is important for application in humans to take place. Affymetrix microarray study was conducted to explore MK886 pharmacologic mechanism. Ingenuity Pathway Analysis software was applied to validate the results at the transcriptional level by putting them in the context of an experimental proteomic network. Genes most affected by MK886 included actin B and focal adhesion components. A subsequent National Cancer Institute-60 panel study, RT-PCR validation followed by confocal microscopy, and Western blotting also pointed to actin B down-regulation, filamentous actin loss, and disorganization of the transcription machinery. In agreement with these observations, MK886 was found to enhance the effect of UV radiation in H720 lung cancer cell line. In light of the modification of cytoskeleton and cell motility by lipid phosphoinositide 3-kinase products, MK886 interaction with actin B might be biologically important. The low toxicity of MK886 in vivo was modeled and explained by binding and transport by dietary lipids. The rate of lipid absorbance is generally higher for tumors, suggesting a promise of a targeted liposome-based delivery system for this drug. These results suggest a novel antitumor pharmacologic mechanism.

Standard name | MAYBURD_RESPONSE_TO_L663536_DN
Systematic name | M14796
Organism | Homo sapiens
PMID | 16551867
Authors | Mayburd AL,Martlínez A,Sackett D,Liu H,Shih J,Tauler J,Avis I,Mulshine JL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in H720 cells (lung cancer) after treatment with L663536 (MK886) [PubChem=105049], an inhibitor of leukotriene biosynthesis.
Full description | The small molecular inhibitor MK886 is known to block 5-lipoxygenase-activating protein ALOX5AP and shows antitumor activity in multiple human cell lines. The broad antitumor therapeutic window reported in vivo for MK886 in rodents supports further consideration of this structural class. Better understanding of the mode of action of the drug is important for application in humans to take place. Affymetrix microarray study was conducted to explore MK886 pharmacologic mechanism. Ingenuity Pathway Analysis software was applied to validate the results at the transcriptional level by putting them in the context of an experimental proteomic network. Genes most affected by MK886 included actin B and focal adhesion components. A subsequent National Cancer Institute-60 panel study, RT-PCR validation followed by confocal microscopy, and Western blotting also pointed to actin B down-regulation, filamentous actin loss, and disorganization of the transcription machinery. In agreement with these observations, MK886 was found to enhance the effect of UV radiation in H720 lung cancer cell line. In light of the modification of cytoskeleton and cell motility by lipid phosphoinositide 3-kinase products, MK886 interaction with actin B might be biologically important. The low toxicity of MK886 in vivo was modeled and explained by binding and transport by dietary lipids. The rate of lipid absorbance is generally higher for tumors, suggesting a promise of a targeted liposome-based delivery system for this drug. These results suggest a novel antitumor pharmacologic mechanism.

Standard name | WATANABE_ULCERATIVE_COLITIS_WITH_CANCER_UP
Systematic name | M12084
Organism | Homo sapiens
PMID | 17255260
Authors | Watanabe T,Kobunai T,Toda E,Kanazawa T,Kazama Y,Tanaka J,Tanaka T,Yamamoto Y,Hata K,Kojima T,Yokoyama T,Konishi T,Okayama Y,Sugimoto Y,Oka T,Sasaki S,Ajioka Y,Muto T,Nagawa H
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in non-neoplastic rectal mucosa samples from patients having cancer associated with ulcerative collitis, compared to those who did not have the cancer.
Full description | PURPOSE: Ulcerative colitis (UC) is associated with a high risk of colorectal cancer. To identify genes that could predict the development of cancer in UC, we conducted a DNA microarray analysis using nonneoplastic rectal mucosa of UC patients. EXPERIMENTAL DESIGN: Gene expression in nonneoplastic mucosa of 53 UC patients were examined. Gene expression profiles were examined using human Genome U133 Plus 2.0 gene chip array (Affymetrix). Among 53 UC patients, 10 had UC-associated cancer (UC-Ca group) whereas 43 did not (UC-NonCa group). RESULTS: By comparing gene expression profiles of nonneoplastic rectal mucosae between the UC-Ca and UC-NonCa groups, we could identify 40 genes that were differentially expressed between two groups. The list of discriminating genes included low-density lipoprotein receptor-related protein (LRP5 and LRP6). Previous studies suggested that LRP5 and LRP6 expression promotes cancer cell proliferation and tumorigenesis and are considered as candidate oncogenes. In the present study, both LRP5 and LRP6 showed significantly higher expression in the UC-Ca group, which suggests the importance of these genes in the development of UC-associated colorectal cancers. With the 40 selected discriminating genes, we did class prediction of the development of colorectal neoplasms in UC patients. Using the k-nearest neighbor method and the support vector machine, we could predict the development of UC-associated neoplasms with an accuracy of 86.8% and 98.1%, respectively. CONCLUSIONS: These findings have important implications for the early detection of malignant lesions in UC and may provide directions for future research into the molecular mechanisms of UC-associated cancer.

Standard name | WATANABE_ULCERATIVE_COLITIS_WITH_CANCER_DN
Systematic name | M15662
Organism | Homo sapiens
PMID | 17255260
Authors | Watanabe T,Kobunai T,Toda E,Kanazawa T,Kazama Y,Tanaka J,Tanaka T,Yamamoto Y,Hata K,Kojima T,Yokoyama T,Konishi T,Okayama Y,Sugimoto Y,Oka T,Sasaki S,Ajioka Y,Muto T,Nagawa H
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in non-neoplastic rectal mucosa samples from patients having cancer associated with ulcerative collitis, compared to those who did not have the cancer.
Full description | PURPOSE: Ulcerative colitis (UC) is associated with a high risk of colorectal cancer. To identify genes that could predict the development of cancer in UC, we conducted a DNA microarray analysis using nonneoplastic rectal mucosa of UC patients. EXPERIMENTAL DESIGN: Gene expression in nonneoplastic mucosa of 53 UC patients were examined. Gene expression profiles were examined using human Genome U133 Plus 2.0 gene chip array (Affymetrix). Among 53 UC patients, 10 had UC-associated cancer (UC-Ca group) whereas 43 did not (UC-NonCa group). RESULTS: By comparing gene expression profiles of nonneoplastic rectal mucosae between the UC-Ca and UC-NonCa groups, we could identify 40 genes that were differentially expressed between two groups. The list of discriminating genes included low-density lipoprotein receptor-related protein (LRP5 and LRP6). Previous studies suggested that LRP5 and LRP6 expression promotes cancer cell proliferation and tumorigenesis and are considered as candidate oncogenes. In the present study, both LRP5 and LRP6 showed significantly higher expression in the UC-Ca group, which suggests the importance of these genes in the development of UC-associated colorectal cancers. With the 40 selected discriminating genes, we did class prediction of the development of colorectal neoplasms in UC patients. Using the k-nearest neighbor method and the support vector machine, we could predict the development of UC-associated neoplasms with an accuracy of 86.8% and 98.1%, respectively. CONCLUSIONS: These findings have important implications for the early detection of malignant lesions in UC and may provide directions for future research into the molecular mechanisms of UC-associated cancer.

Standard name | DODD_NASOPHARYNGEAL_CARCINOMA_UP
Systematic name | M19062
Organism | Homo sapiens
PMID | 17119049
Authors | Dodd LE,Sengupta S,Chen IH,den Boon JA,Cheng YJ,Westra W,Newton MA,Mittl BF,McShane L,Chen CJ,Ahlquist P,Hildesheim A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in nasopharyngeal carcinoma (NPC) compared to the normal tissue.
Full description | Polymorphisms in nitrosamine metabolism, DNA repair, and immune response genes have been associated with nasopharyngeal carcinoma (NPC). Studies have suggested chromosomal regions involved in NPC. To shed light on NPC etiology, we evaluated host gene expression patterns in 31 NPC and 10 normal nasopharyngeal tissue specimens using the Affymetrix Human Genome U133 Plus 2.0 Array. We focused on genes in five a priori biological pathways and chromosomal locations. Rates of differential expression within these prespecified lists and overall were tested using a bootstrap method. Differential expression was observed for 7.6% of probe sets overall. Elevations in rate of differential expression were observed within the DNA repair (13.7%; P = 0.01) and nitrosamine metabolism (17.5%; P = 0.04) pathways. Differentially expressed probe sets within the DNA repair pathway were consistently overexpressed (93%), with strong effects observed for PRKDC, PCNA, and CHEK1. Differentially expressed probe sets within the nitrosamine metabolism pathway were consistently underexpressed (100%), with strong effects observed for NQ01, CYP2B6, and CYP2E1. No significant evidence of increases in rate of differential expression was seen within the immune/inflammatory pathway. A significant elevation in rate of differential expression was noted for chromosome 4p15.1-4q12 (13.0%; P = 0.04); both overexpression and underexpression were evident (38% and 62%, respectively). An elevation in the rate of differential expression on chromosome 14q32 was observed (11.3%; P = 0.06) with a consistent pattern of gene underexpression (100%; P < 0.0001). These effects were similar when excluding late-stage tumors. Our results suggest that nitrosamine activation and DNA repair are important in NPC. The consistent down-regulation of expression on chromosome 14q32 suggests loss of heterozygosity in this region.

Standard name | DODD_NASOPHARYNGEAL_CARCINOMA_DN
Systematic name | M14427
Organism | Homo sapiens
PMID | 17119049
Authors | Dodd LE,Sengupta S,Chen IH,den Boon JA,Cheng YJ,Westra W,Newton MA,Mittl BF,McShane L,Chen CJ,Ahlquist P,Hildesheim A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in nasopharyngeal carcinoma (NPC) compared to the normal tissue.
Full description | Polymorphisms in nitrosamine metabolism, DNA repair, and immune response genes have been associated with nasopharyngeal carcinoma (NPC). Studies have suggested chromosomal regions involved in NPC. To shed light on NPC etiology, we evaluated host gene expression patterns in 31 NPC and 10 normal nasopharyngeal tissue specimens using the Affymetrix Human Genome U133 Plus 2.0 Array. We focused on genes in five a priori biological pathways and chromosomal locations. Rates of differential expression within these prespecified lists and overall were tested using a bootstrap method. Differential expression was observed for 7.6% of probe sets overall. Elevations in rate of differential expression were observed within the DNA repair (13.7%; P = 0.01) and nitrosamine metabolism (17.5%; P = 0.04) pathways. Differentially expressed probe sets within the DNA repair pathway were consistently overexpressed (93%), with strong effects observed for PRKDC, PCNA, and CHEK1. Differentially expressed probe sets within the nitrosamine metabolism pathway were consistently underexpressed (100%), with strong effects observed for NQ01, CYP2B6, and CYP2E1. No significant evidence of increases in rate of differential expression was seen within the immune/inflammatory pathway. A significant elevation in rate of differential expression was noted for chromosome 4p15.1-4q12 (13.0%; P = 0.04); both overexpression and underexpression were evident (38% and 62%, respectively). An elevation in the rate of differential expression on chromosome 14q32 was observed (11.3%; P = 0.06) with a consistent pattern of gene underexpression (100%; P < 0.0001). These effects were similar when excluding late-stage tumors. Our results suggest that nitrosamine activation and DNA repair are important in NPC. The consistent down-regulation of expression on chromosome 14q32 suggests loss of heterozygosity in this region.

Standard name | RODRIGUES_THYROID_CARCINOMA_POORLY_DIFFERENTIATED_UP
Systematic name | M10501
Organism | Homo sapiens
PMID | 17406368
Authors | Rodrigues RF,Roque L,Krug T,Leite V
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in poorly differentiated thyroid carcinoma (PDTC) compared to normal thyroid tissue.
Full description | Information on gene alterations associated to poorly differentiated (PDTC) and anaplastic thyroid carcinomas (ATC) is scarce. Using human cancer cell lines as a tool for gene discovery, we performed a cytogenetic and oligo-array analysis in five new cell lines derived from two PDTC and three ATC. In PDTC we evidenced, as important, the involvement of the MAPK/ERK kinase pathway, and downregulation of a group of suppressor genes that include E-cadherin. In ATC, downregulation of a specific group of oncosuppressor genes was also observed. Our ATC cell lines presented chromosomal markers of gene amplification, and we were able to identify for the first time the nature of the involved amplicon target genes. We found that the main molecular differences between the two cell line types were related to signal transduction pathways, cell adhesion and motility process. TaqMan experiments performed for five amplicon target genes and for two genes, which allowed a clear distinction between ATC and PDTC: CDH13 and PLAU corroborated array results, not only in the cell lines, but also in an additional set of primary 14 PDTC and three ATC. We suggest that our findings may represent new tools for the development of more effective therapies to the hitherto untreatable ATC.

Standard name | RODRIGUES_THYROID_CARCINOMA_POORLY_DIFFERENTIATED_DN
Systematic name | M16651
Organism | Homo sapiens
PMID | 17406368
Authors | Rodrigues RF,Roque L,Krug T,Leite V
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in poorly differentiated thyroid carcinoma (PDTC) compared to normal thyroid tissue.
Full description | Information on gene alterations associated to poorly differentiated (PDTC) and anaplastic thyroid carcinomas (ATC) is scarce. Using human cancer cell lines as a tool for gene discovery, we performed a cytogenetic and oligo-array analysis in five new cell lines derived from two PDTC and three ATC. In PDTC we evidenced, as important, the involvement of the MAPK/ERK kinase pathway, and downregulation of a group of suppressor genes that include E-cadherin. In ATC, downregulation of a specific group of oncosuppressor genes was also observed. Our ATC cell lines presented chromosomal markers of gene amplification, and we were able to identify for the first time the nature of the involved amplicon target genes. We found that the main molecular differences between the two cell line types were related to signal transduction pathways, cell adhesion and motility process. TaqMan experiments performed for five amplicon target genes and for two genes, which allowed a clear distinction between ATC and PDTC: CDH13 and PLAU corroborated array results, not only in the cell lines, but also in an additional set of primary 14 PDTC and three ATC. We suggest that our findings may represent new tools for the development of more effective therapies to the hitherto untreatable ATC.

Standard name | RODRIGUES_THYROID_CARCINOMA_ANAPLASTIC_UP
Systematic name | M10237
Organism | Homo sapiens
PMID | 17406368
Authors | Rodrigues RF,Roque L,Krug T,Leite V
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in anaplastic thyroid carcinoma (ATC) compared to normal thyroid tissue.
Full description | Information on gene alterations associated to poorly differentiated (PDTC) and anaplastic thyroid carcinomas (ATC) is scarce. Using human cancer cell lines as a tool for gene discovery, we performed a cytogenetic and oligo-array analysis in five new cell lines derived from two PDTC and three ATC. In PDTC we evidenced, as important, the involvement of the MAPK/ERK kinase pathway, and downregulation of a group of suppressor genes that include E-cadherin. In ATC, downregulation of a specific group of oncosuppressor genes was also observed. Our ATC cell lines presented chromosomal markers of gene amplification, and we were able to identify for the first time the nature of the involved amplicon target genes. We found that the main molecular differences between the two cell line types were related to signal transduction pathways, cell adhesion and motility process. TaqMan experiments performed for five amplicon target genes and for two genes, which allowed a clear distinction between ATC and PDTC: CDH13 and PLAU corroborated array results, not only in the cell lines, but also in an additional set of primary 14 PDTC and three ATC. We suggest that our findings may represent new tools for the development of more effective therapies to the hitherto untreatable ATC.

Standard name | RODRIGUES_THYROID_CARCINOMA_ANAPLASTIC_DN
Systematic name | M19529
Organism | Homo sapiens
PMID | 17406368
Authors | Rodrigues RF,Roque L,Krug T,Leite V
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in anaplastic thyroid carcinoma (ATC) compared to normal thyroid tissue.
Full description | Information on gene alterations associated to poorly differentiated (PDTC) and anaplastic thyroid carcinomas (ATC) is scarce. Using human cancer cell lines as a tool for gene discovery, we performed a cytogenetic and oligo-array analysis in five new cell lines derived from two PDTC and three ATC. In PDTC we evidenced, as important, the involvement of the MAPK/ERK kinase pathway, and downregulation of a group of suppressor genes that include E-cadherin. In ATC, downregulation of a specific group of oncosuppressor genes was also observed. Our ATC cell lines presented chromosomal markers of gene amplification, and we were able to identify for the first time the nature of the involved amplicon target genes. We found that the main molecular differences between the two cell line types were related to signal transduction pathways, cell adhesion and motility process. TaqMan experiments performed for five amplicon target genes and for two genes, which allowed a clear distinction between ATC and PDTC: CDH13 and PLAU corroborated array results, not only in the cell lines, but also in an additional set of primary 14 PDTC and three ATC. We suggest that our findings may represent new tools for the development of more effective therapies to the hitherto untreatable ATC.

Standard name | RODRIGUES_THYROID_CARCINOMA_UP
Systematic name | M3910
Organism | Homo sapiens
PMID | 17406368
Authors | Rodrigues RF,Roque L,Krug T,Leite V
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in poorly differentiated thyroid carcinoma (PDTC) compared to anaplastic thyroid carcinoma (ATC).
Full description | Information on gene alterations associated to poorly differentiated (PDTC) and anaplastic thyroid carcinomas (ATC) is scarce. Using human cancer cell lines as a tool for gene discovery, we performed a cytogenetic and oligo-array analysis in five new cell lines derived from two PDTC and three ATC. In PDTC we evidenced, as important, the involvement of the MAPK/ERK kinase pathway, and downregulation of a group of suppressor genes that include E-cadherin. In ATC, downregulation of a specific group of oncosuppressor genes was also observed. Our ATC cell lines presented chromosomal markers of gene amplification, and we were able to identify for the first time the nature of the involved amplicon target genes. We found that the main molecular differences between the two cell line types were related to signal transduction pathways, cell adhesion and motility process. TaqMan experiments performed for five amplicon target genes and for two genes, which allowed a clear distinction between ATC and PDTC: CDH13 and PLAU corroborated array results, not only in the cell lines, but also in an additional set of primary 14 PDTC and three ATC. We suggest that our findings may represent new tools for the development of more effective therapies to the hitherto untreatable ATC.

Standard name | RODRIGUES_THYROID_CARCINOMA_DN
Systematic name | M9814
Organism | Homo sapiens
PMID | 17406368
Authors | Rodrigues RF,Roque L,Krug T,Leite V
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in poorly differentiated thyroid carcinoma (PDTC) compared to anaplastic thyroid carcinoma (ATC).
Full description | Information on gene alterations associated to poorly differentiated (PDTC) and anaplastic thyroid carcinomas (ATC) is scarce. Using human cancer cell lines as a tool for gene discovery, we performed a cytogenetic and oligo-array analysis in five new cell lines derived from two PDTC and three ATC. In PDTC we evidenced, as important, the involvement of the MAPK/ERK kinase pathway, and downregulation of a group of suppressor genes that include E-cadherin. In ATC, downregulation of a specific group of oncosuppressor genes was also observed. Our ATC cell lines presented chromosomal markers of gene amplification, and we were able to identify for the first time the nature of the involved amplicon target genes. We found that the main molecular differences between the two cell line types were related to signal transduction pathways, cell adhesion and motility process. TaqMan experiments performed for five amplicon target genes and for two genes, which allowed a clear distinction between ATC and PDTC: CDH13 and PLAU corroborated array results, not only in the cell lines, but also in an additional set of primary 14 PDTC and three ATC. We suggest that our findings may represent new tools for the development of more effective therapies to the hitherto untreatable ATC.

Standard name | GOZGIT_ESR1_TARGETS_UP
Systematic name | M13944
Organism | Homo sapiens
PMID | 17726467
Authors | Gozgit JM,Pentecost BT,Marconi SA,Ricketts-Loriaux RS,Otis CN,Arcaro KF
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in TMX2-28 cells (breast cancer) which do not express ESR1 [GeneID=2099]) compared to the parental MCF7 cells which do.
Full description | We have used a novel variant of the human oestrogen receptor (ER)-positive MCF-7 cell line, TMX2-28, as a model to study breast cancer. TMX2-28 cells show no detectable levels of mRNA or protein expression for the ER and express basal cytokeratins (CKs) 5, 14, and 17. cDNA microarray comparison between TMX2-28 and its parent cell line, MCF-7, identified 1402 differentially expressed transcripts, one of which was, phospholipase D1 (PLD1). Using real-time RT-PCR, we confirmed that PLD1 mRNA levels are 10-fold higher in TMX2-28 cells than in MCF-7 cells. We next examined PLD1 expression in human breast carcinomas. Phospholipase D1 mRNA levels were higher in breast tumours that expressed high-mRNA levels of basal CKs 5 and/or 17, but PLD1 mRNA levels were not significantly higher in ER-negative tumours. Phospholipase D1 protein was overexpressed in 10 of 42 (24%) breast tumours examined by IHC. Phospholipase D1 was overexpressed in 6 of 31 ER-positive tumours and 4 of 11 ER-negative tumours. Phospholipase D1 was overexpressed in three of the four tumours that showed high CK5/17 expression. Five PLD1-positive tumours were negative for phospho-Akt expression, but positive for phospho-mammalian target of rapamycin (mTOR) expression. The other five PLD1-positive breast tumours showed positive expression for phospho-Akt; however, only two of these cases were positive for phospho-mTOR. In this study, we report that PLD1 and phospho-mTOR are coexpressed in a subset of phospho-Akt-negative breast carcinomas.

Standard name | GOZGIT_ESR1_TARGETS_DN
Systematic name | M10961
Organism | Homo sapiens
PMID | 17726467
Authors | Gozgit JM,Pentecost BT,Marconi SA,Ricketts-Loriaux RS,Otis CN,Arcaro KF
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in TMX2-28 cells (breast cancer) which do not express ESR1 [GeneID=2099]) compared to the parental MCF7 cells which do.
Full description | We have used a novel variant of the human oestrogen receptor (ER)-positive MCF-7 cell line, TMX2-28, as a model to study breast cancer. TMX2-28 cells show no detectable levels of mRNA or protein expression for the ER and express basal cytokeratins (CKs) 5, 14, and 17. cDNA microarray comparison between TMX2-28 and its parent cell line, MCF-7, identified 1402 differentially expressed transcripts, one of which was, phospholipase D1 (PLD1). Using real-time RT-PCR, we confirmed that PLD1 mRNA levels are 10-fold higher in TMX2-28 cells than in MCF-7 cells. We next examined PLD1 expression in human breast carcinomas. Phospholipase D1 mRNA levels were higher in breast tumours that expressed high-mRNA levels of basal CKs 5 and/or 17, but PLD1 mRNA levels were not significantly higher in ER-negative tumours. Phospholipase D1 protein was overexpressed in 10 of 42 (24%) breast tumours examined by IHC. Phospholipase D1 was overexpressed in 6 of 31 ER-positive tumours and 4 of 11 ER-negative tumours. Phospholipase D1 was overexpressed in three of the four tumours that showed high CK5/17 expression. Five PLD1-positive tumours were negative for phospho-Akt expression, but positive for phospho-mammalian target of rapamycin (mTOR) expression. The other five PLD1-positive breast tumours showed positive expression for phospho-Akt; however, only two of these cases were positive for phospho-mTOR. In this study, we report that PLD1 and phospho-mTOR are coexpressed in a subset of phospho-Akt-negative breast carcinomas.

Standard name | HAHTOLA_SEZARY_SYNDROM_UP
Systematic name | M14577
Organism | Homo sapiens
PMID | 16914566
Authors | Hahtola S,Tuomela S,Elo L,Häkkinen T,Karenko L,Nedoszytko B,Heikkilä H,Saarialho-Kere U,Roszkiewicz J,Aittokallio T,Lahesmaa R,Ranki A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in monocytes isolated from peripheral blood samples of Sezary syndrom patients compared to those from healthy normal donors.
Full description | PURPOSE: Increased production of Th2 cytokines characterizes Sezary syndrome, the leukemic form of cutaneous T-cell lymphomas (CTCL). To identify the molecular background and to study whether shared by the most common CTCL subtype, mycosis fungoides, we analyzed the gene expression profiles in both subtypes. EXPERIMENTAL DESIGN: Freshly isolated cells from 30 samples, representing skin, blood, and enriched CD4(+) cell populations of mycosis fungoides and Sezary syndrome, were analyzed with Affymetrix (Santa Clara, CA) oligonucleotide microarrays, quantitative PCR, or immunohistochemistry. The gene expression profiles were combined with findings of comparative genomic hybridization of the same samples to identify chromosomal changes affecting the aberrant gene expression. RESULTS: We identified a set of Th1-specific genes [e.g., TBX21 (T-bet), NKG7, and SCYA5 (RANTES)] to be down-regulated in Sezary syndrome as well as in a proportion of mycosis fungoides samples. In both Sezary syndrome and mycosis fungoides blood samples, the S100P and LIR9 gene expression was up-regulated. In lesional skin, IL7R and CD52 were up-regulated. Integration of comparative genomic hybridization and transcriptomic data identified chromosome arms 1q, 3p, 3q, 4q, 12q, 16p, and 16q as likely targets for new CTCL-associated gene aberrations. CONCLUSIONS: Our findings revealed several new genes involved in CTCL pathogenesis and potential therapeutic targets. Down-regulation of a set of genes involved in Th1 polarization, including the major Th1-polarizing factor, TBX21, was for the first time associated with CTCL. In addition, a plausible explanation for the proliferative response of CTCL cells to locally produced interleukin-7 was revealed.

Standard name | HAHTOLA_SEZARY_SYNDROM_DN
Systematic name | M18968
Organism | Homo sapiens
PMID | 16914566
Authors | Hahtola S,Tuomela S,Elo L,Häkkinen T,Karenko L,Nedoszytko B,Heikkilä H,Saarialho-Kere U,Roszkiewicz J,Aittokallio T,Lahesmaa R,Ranki A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in monocytes isolated from peripheral blood samples of Sezary syndrom patients compared to those from healthy normal donors.
Full description | PURPOSE: Increased production of Th2 cytokines characterizes Sezary syndrome, the leukemic form of cutaneous T-cell lymphomas (CTCL). To identify the molecular background and to study whether shared by the most common CTCL subtype, mycosis fungoides, we analyzed the gene expression profiles in both subtypes. EXPERIMENTAL DESIGN: Freshly isolated cells from 30 samples, representing skin, blood, and enriched CD4(+) cell populations of mycosis fungoides and Sezary syndrome, were analyzed with Affymetrix (Santa Clara, CA) oligonucleotide microarrays, quantitative PCR, or immunohistochemistry. The gene expression profiles were combined with findings of comparative genomic hybridization of the same samples to identify chromosomal changes affecting the aberrant gene expression. RESULTS: We identified a set of Th1-specific genes [e.g., TBX21 (T-bet), NKG7, and SCYA5 (RANTES)] to be down-regulated in Sezary syndrome as well as in a proportion of mycosis fungoides samples. In both Sezary syndrome and mycosis fungoides blood samples, the S100P and LIR9 gene expression was up-regulated. In lesional skin, IL7R and CD52 were up-regulated. Integration of comparative genomic hybridization and transcriptomic data identified chromosome arms 1q, 3p, 3q, 4q, 12q, 16p, and 16q as likely targets for new CTCL-associated gene aberrations. CONCLUSIONS: Our findings revealed several new genes involved in CTCL pathogenesis and potential therapeutic targets. Down-regulation of a set of genes involved in Th1 polarization, including the major Th1-polarizing factor, TBX21, was for the first time associated with CTCL. In addition, a plausible explanation for the proliferative response of CTCL cells to locally produced interleukin-7 was revealed.

Standard name | HAHTOLA_MYCOSIS_FUNGOIDES_SKIN_UP
Systematic name | M6564
Organism | Homo sapiens
PMID | 16914566
Authors | Hahtola S,Tuomela S,Elo L,Häkkinen T,Karenko L,Nedoszytko B,Heikkilä H,Saarialho-Kere U,Roszkiewicz J,Aittokallio T,Lahesmaa R,Ranki A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in lesional skin biopsies from mycosis fundoides patients compared to the normal skin samples.
Full description | PURPOSE: Increased production of Th2 cytokines characterizes Sezary syndrome, the leukemic form of cutaneous T-cell lymphomas (CTCL). To identify the molecular background and to study whether shared by the most common CTCL subtype, mycosis fungoides, we analyzed the gene expression profiles in both subtypes. EXPERIMENTAL DESIGN: Freshly isolated cells from 30 samples, representing skin, blood, and enriched CD4(+) cell populations of mycosis fungoides and Sezary syndrome, were analyzed with Affymetrix (Santa Clara, CA) oligonucleotide microarrays, quantitative PCR, or immunohistochemistry. The gene expression profiles were combined with findings of comparative genomic hybridization of the same samples to identify chromosomal changes affecting the aberrant gene expression. RESULTS: We identified a set of Th1-specific genes [e.g., TBX21 (T-bet), NKG7, and SCYA5 (RANTES)] to be down-regulated in Sezary syndrome as well as in a proportion of mycosis fungoides samples. In both Sezary syndrome and mycosis fungoides blood samples, the S100P and LIR9 gene expression was up-regulated. In lesional skin, IL7R and CD52 were up-regulated. Integration of comparative genomic hybridization and transcriptomic data identified chromosome arms 1q, 3p, 3q, 4q, 12q, 16p, and 16q as likely targets for new CTCL-associated gene aberrations. CONCLUSIONS: Our findings revealed several new genes involved in CTCL pathogenesis and potential therapeutic targets. Down-regulation of a set of genes involved in Th1 polarization, including the major Th1-polarizing factor, TBX21, was for the first time associated with CTCL. In addition, a plausible explanation for the proliferative response of CTCL cells to locally produced interleukin-7 was revealed.

Standard name | HAHTOLA_MYCOSIS_FUNGOIDES_SKIN_DN
Systematic name | M5570
Organism | Homo sapiens
PMID | 16914566
Authors | Hahtola S,Tuomela S,Elo L,Häkkinen T,Karenko L,Nedoszytko B,Heikkilä H,Saarialho-Kere U,Roszkiewicz J,Aittokallio T,Lahesmaa R,Ranki A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in lesional skin biopsies from mycosis fundoides patients compared to the normal skin samples.
Full description | PURPOSE: Increased production of Th2 cytokines characterizes Sezary syndrome, the leukemic form of cutaneous T-cell lymphomas (CTCL). To identify the molecular background and to study whether shared by the most common CTCL subtype, mycosis fungoides, we analyzed the gene expression profiles in both subtypes. EXPERIMENTAL DESIGN: Freshly isolated cells from 30 samples, representing skin, blood, and enriched CD4(+) cell populations of mycosis fungoides and Sezary syndrome, were analyzed with Affymetrix (Santa Clara, CA) oligonucleotide microarrays, quantitative PCR, or immunohistochemistry. The gene expression profiles were combined with findings of comparative genomic hybridization of the same samples to identify chromosomal changes affecting the aberrant gene expression. RESULTS: We identified a set of Th1-specific genes [e.g., TBX21 (T-bet), NKG7, and SCYA5 (RANTES)] to be down-regulated in Sezary syndrome as well as in a proportion of mycosis fungoides samples. In both Sezary syndrome and mycosis fungoides blood samples, the S100P and LIR9 gene expression was up-regulated. In lesional skin, IL7R and CD52 were up-regulated. Integration of comparative genomic hybridization and transcriptomic data identified chromosome arms 1q, 3p, 3q, 4q, 12q, 16p, and 16q as likely targets for new CTCL-associated gene aberrations. CONCLUSIONS: Our findings revealed several new genes involved in CTCL pathogenesis and potential therapeutic targets. Down-regulation of a set of genes involved in Th1 polarization, including the major Th1-polarizing factor, TBX21, was for the first time associated with CTCL. In addition, a plausible explanation for the proliferative response of CTCL cells to locally produced interleukin-7 was revealed.

Standard name | HAHTOLA_MYCOSIS_FUNGOIDES_CD4_UP
Systematic name | M9775
Organism | Homo sapiens
PMID | 16914566
Authors | Hahtola S,Tuomela S,Elo L,Häkkinen T,Karenko L,Nedoszytko B,Heikkilä H,Saarialho-Kere U,Roszkiewicz J,Aittokallio T,Lahesmaa R,Ranki A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T helper cells (defines as CD4+) isolated from patients with mucosis fungoides compared to those from normal control donors.
Full description | PURPOSE: Increased production of Th2 cytokines characterizes Sezary syndrome, the leukemic form of cutaneous T-cell lymphomas (CTCL). To identify the molecular background and to study whether shared by the most common CTCL subtype, mycosis fungoides, we analyzed the gene expression profiles in both subtypes. EXPERIMENTAL DESIGN: Freshly isolated cells from 30 samples, representing skin, blood, and enriched CD4(+) cell populations of mycosis fungoides and Sezary syndrome, were analyzed with Affymetrix (Santa Clara, CA) oligonucleotide microarrays, quantitative PCR, or immunohistochemistry. The gene expression profiles were combined with findings of comparative genomic hybridization of the same samples to identify chromosomal changes affecting the aberrant gene expression. RESULTS: We identified a set of Th1-specific genes [e.g., TBX21 (T-bet), NKG7, and SCYA5 (RANTES)] to be down-regulated in Sezary syndrome as well as in a proportion of mycosis fungoides samples. In both Sezary syndrome and mycosis fungoides blood samples, the S100P and LIR9 gene expression was up-regulated. In lesional skin, IL7R and CD52 were up-regulated. Integration of comparative genomic hybridization and transcriptomic data identified chromosome arms 1q, 3p, 3q, 4q, 12q, 16p, and 16q as likely targets for new CTCL-associated gene aberrations. CONCLUSIONS: Our findings revealed several new genes involved in CTCL pathogenesis and potential therapeutic targets. Down-regulation of a set of genes involved in Th1 polarization, including the major Th1-polarizing factor, TBX21, was for the first time associated with CTCL. In addition, a plausible explanation for the proliferative response of CTCL cells to locally produced interleukin-7 was revealed.

Standard name | HAHTOLA_MYCOSIS_FUNGOIDES_CD4_DN
Systematic name | M19849
Organism | Homo sapiens
PMID | 16914566
Authors | Hahtola S,Tuomela S,Elo L,Häkkinen T,Karenko L,Nedoszytko B,Heikkilä H,Saarialho-Kere U,Roszkiewicz J,Aittokallio T,Lahesmaa R,Ranki A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T helper cells (defines as CD4+) isolated from patients with mucosis fungoides compared to those from normal control donors.
Full description | PURPOSE: Increased production of Th2 cytokines characterizes Sezary syndrome, the leukemic form of cutaneous T-cell lymphomas (CTCL). To identify the molecular background and to study whether shared by the most common CTCL subtype, mycosis fungoides, we analyzed the gene expression profiles in both subtypes. EXPERIMENTAL DESIGN: Freshly isolated cells from 30 samples, representing skin, blood, and enriched CD4(+) cell populations of mycosis fungoides and Sezary syndrome, were analyzed with Affymetrix (Santa Clara, CA) oligonucleotide microarrays, quantitative PCR, or immunohistochemistry. The gene expression profiles were combined with findings of comparative genomic hybridization of the same samples to identify chromosomal changes affecting the aberrant gene expression. RESULTS: We identified a set of Th1-specific genes [e.g., TBX21 (T-bet), NKG7, and SCYA5 (RANTES)] to be down-regulated in Sezary syndrome as well as in a proportion of mycosis fungoides samples. In both Sezary syndrome and mycosis fungoides blood samples, the S100P and LIR9 gene expression was up-regulated. In lesional skin, IL7R and CD52 were up-regulated. Integration of comparative genomic hybridization and transcriptomic data identified chromosome arms 1q, 3p, 3q, 4q, 12q, 16p, and 16q as likely targets for new CTCL-associated gene aberrations. CONCLUSIONS: Our findings revealed several new genes involved in CTCL pathogenesis and potential therapeutic targets. Down-regulation of a set of genes involved in Th1 polarization, including the major Th1-polarizing factor, TBX21, was for the first time associated with CTCL. In addition, a plausible explanation for the proliferative response of CTCL cells to locally produced interleukin-7 was revealed.

Standard name | HAHTOLA_MYCOSIS_FUNGOIDES_UP
Systematic name | M6714
Organism | Homo sapiens
PMID | 16914566
Authors | Hahtola S,Tuomela S,Elo L,Häkkinen T,Karenko L,Nedoszytko B,Heikkilä H,Saarialho-Kere U,Roszkiewicz J,Aittokallio T,Lahesmaa R,Ranki A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in monocytes isolated from peripheral blood samples of patients with mucosis fungoides compared to those from normal healthy donors.
Full description | PURPOSE: Increased production of Th2 cytokines characterizes Sezary syndrome, the leukemic form of cutaneous T-cell lymphomas (CTCL). To identify the molecular background and to study whether shared by the most common CTCL subtype, mycosis fungoides, we analyzed the gene expression profiles in both subtypes. EXPERIMENTAL DESIGN: Freshly isolated cells from 30 samples, representing skin, blood, and enriched CD4(+) cell populations of mycosis fungoides and Sezary syndrome, were analyzed with Affymetrix (Santa Clara, CA) oligonucleotide microarrays, quantitative PCR, or immunohistochemistry. The gene expression profiles were combined with findings of comparative genomic hybridization of the same samples to identify chromosomal changes affecting the aberrant gene expression. RESULTS: We identified a set of Th1-specific genes [e.g., TBX21 (T-bet), NKG7, and SCYA5 (RANTES)] to be down-regulated in Sezary syndrome as well as in a proportion of mycosis fungoides samples. In both Sezary syndrome and mycosis fungoides blood samples, the S100P and LIR9 gene expression was up-regulated. In lesional skin, IL7R and CD52 were up-regulated. Integration of comparative genomic hybridization and transcriptomic data identified chromosome arms 1q, 3p, 3q, 4q, 12q, 16p, and 16q as likely targets for new CTCL-associated gene aberrations. CONCLUSIONS: Our findings revealed several new genes involved in CTCL pathogenesis and potential therapeutic targets. Down-regulation of a set of genes involved in Th1 polarization, including the major Th1-polarizing factor, TBX21, was for the first time associated with CTCL. In addition, a plausible explanation for the proliferative response of CTCL cells to locally produced interleukin-7 was revealed.

Standard name | HAHTOLA_MYCOSIS_FUNGOIDES_DN
Systematic name | M12073
Organism | Homo sapiens
PMID | 16914566
Authors | Hahtola S,Tuomela S,Elo L,Häkkinen T,Karenko L,Nedoszytko B,Heikkilä H,Saarialho-Kere U,Roszkiewicz J,Aittokallio T,Lahesmaa R,Ranki A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in monocytes isolated from peripheral blood samples of patients with mucosis fungoides compared to those from normal healthy donors.
Full description | PURPOSE: Increased production of Th2 cytokines characterizes Sezary syndrome, the leukemic form of cutaneous T-cell lymphomas (CTCL). To identify the molecular background and to study whether shared by the most common CTCL subtype, mycosis fungoides, we analyzed the gene expression profiles in both subtypes. EXPERIMENTAL DESIGN: Freshly isolated cells from 30 samples, representing skin, blood, and enriched CD4(+) cell populations of mycosis fungoides and Sezary syndrome, were analyzed with Affymetrix (Santa Clara, CA) oligonucleotide microarrays, quantitative PCR, or immunohistochemistry. The gene expression profiles were combined with findings of comparative genomic hybridization of the same samples to identify chromosomal changes affecting the aberrant gene expression. RESULTS: We identified a set of Th1-specific genes [e.g., TBX21 (T-bet), NKG7, and SCYA5 (RANTES)] to be down-regulated in Sezary syndrome as well as in a proportion of mycosis fungoides samples. In both Sezary syndrome and mycosis fungoides blood samples, the S100P and LIR9 gene expression was up-regulated. In lesional skin, IL7R and CD52 were up-regulated. Integration of comparative genomic hybridization and transcriptomic data identified chromosome arms 1q, 3p, 3q, 4q, 12q, 16p, and 16q as likely targets for new CTCL-associated gene aberrations. CONCLUSIONS: Our findings revealed several new genes involved in CTCL pathogenesis and potential therapeutic targets. Down-regulation of a set of genes involved in Th1 polarization, including the major Th1-polarizing factor, TBX21, was for the first time associated with CTCL. In addition, a plausible explanation for the proliferative response of CTCL cells to locally produced interleukin-7 was revealed.

Standard name | PROVENZANI_METASTASIS_UP
Systematic name | M4100
Organism | Homo sapiens
PMID | 16531451
Authors | Provenzani A,Fronza R,Loreni F,Pascale A,Amadio M,Quattrone A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in polysomal and total RNA samples from SW480 cells (primary colorectal carcinoma, CRC) compared to the SW620 cells (lymph node metastasis from the same individual).
Full description | Tumour onset and progression are due to the accumulation of genomic lesions, which alter gene expression and ultimately proteome activities. These lesions are thought to affect primarily the transcriptional control of gene expression. In the present study, we aimed at evaluating the genome-wide occurrence of alterations in the translational control exploiting an isogenic, phenotypically validated cellular model of colorectal cancer (CRC) transition from invasive carcinoma to metastasis. In this model, microarray profiling shows that changes in the level of messenger ribonucleic acid (mRNA) association with polysomes occur more than 2-fold than changes in the level of total cellular mRNA. When common to both the total and polysomal compartments, these changes are also homodirectional, being amplified in magnitude at the polysomal level. Comparison between the transcriptional and the translational fluctuations revealed distinct signatures of statistically over-represented gene functions, involving the program of cell proliferation for both levels of analysis, while the apoptosis and the translation programs were affected mainly at translation. Looking for an upstream determinant of translational deregulation, we found an increase in the hyperphosphorylated form of the 4E-BP1 protein in the metastatic cell line, possibly resulting in an increased activation of cap-dependent translation due to increased activity of the eIF4E protein. Analysis of the distribution profiles for the 5' untranslated region (5'-UTR) length of the changed genes showed an association between longer 5'-UTRs and the probability for the relevant gene to be altered translationally, consistent with enhanced eIF4E function. This genome-wide analysis is in favour of a model of profound alteration of translational control in late CRC progression. It also suggests polysomal mRNA profiles as a new, informative dimension for the study of transcriptome imbalance in cancer.

Standard name | PROVENZANI_METASTASIS_DN
Systematic name | M9016
Organism | Homo sapiens
PMID | 16531451
Authors | Provenzani A,Fronza R,Loreni F,Pascale A,Amadio M,Quattrone A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in polysomal and total RNA samples from SW480 cells (primary colorectal carcinoma, CRC) compared to the SW620 cells (lymph node metastasis from the same individual).
Full description | Tumour onset and progression are due to the accumulation of genomic lesions, which alter gene expression and ultimately proteome activities. These lesions are thought to affect primarily the transcriptional control of gene expression. In the present study, we aimed at evaluating the genome-wide occurrence of alterations in the translational control exploiting an isogenic, phenotypically validated cellular model of colorectal cancer (CRC) transition from invasive carcinoma to metastasis. In this model, microarray profiling shows that changes in the level of messenger ribonucleic acid (mRNA) association with polysomes occur more than 2-fold than changes in the level of total cellular mRNA. When common to both the total and polysomal compartments, these changes are also homodirectional, being amplified in magnitude at the polysomal level. Comparison between the transcriptional and the translational fluctuations revealed distinct signatures of statistically over-represented gene functions, involving the program of cell proliferation for both levels of analysis, while the apoptosis and the translation programs were affected mainly at translation. Looking for an upstream determinant of translational deregulation, we found an increase in the hyperphosphorylated form of the 4E-BP1 protein in the metastatic cell line, possibly resulting in an increased activation of cap-dependent translation due to increased activity of the eIF4E protein. Analysis of the distribution profiles for the 5' untranslated region (5'-UTR) length of the changed genes showed an association between longer 5'-UTRs and the probability for the relevant gene to be altered translationally, consistent with enhanced eIF4E function. This genome-wide analysis is in favour of a model of profound alteration of translational control in late CRC progression. It also suggests polysomal mRNA profiles as a new, informative dimension for the study of transcriptome imbalance in cancer.

Standard name | PACHER_TARGETS_OF_IGF1_AND_IGF2_UP
Systematic name | M16574
Organism | Homo sapiens
PMID | 16774935
Authors | Pacher M,Seewald MJ,Mikula M,Oehler S,Mogg M,Vinatzer U,Eger A,Schweifer N,Varecka R,Sommergruber W,Mikulits W,Schreiber M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) by IGF1 and IGF2 [GeneID=3479;3481].
Full description | Insulin-like growth factor (IGF) signaling is a key regulator of breast development and breast cancer. We have analyzed the expression of the IGF signaling cascade in 17 human breast cancer and 4 mammary epithelial cell lines. Five cell lines expressed high levels of IGF1 receptor, insulin (INS)/IGF receptor substrate 1, IGF-binding proteins 2 and 4, as well as the estrogen receptor (ESR), indicating a co-activation of IGF and ESR signaling. Next, we stably overexpressed IGF1 and IGF2 in MCF7 breast cancer cells, which did not affect their epithelial characteristics and the expression and localization of the epithelial marker genes E-cadherin and beta-catenin. Conversely, IGF1 and IGF2 overexpression potently increased cellular proliferation rates and the efficiency of tumor formation in mouse xenograft experiments, whereas the resistance to chemotherapeutic drugs such as taxol was unaltered. Expression profiling of overexpressing cells with whole-genome oligonucleotide microarrays revealed that 21 genes were upregulated >2-fold by both IGF1 and IGF2, 9 by IGF1, and 9 by IGF2. Half of the genes found to be upregulated are involved in transport and biosynthesis of amino acids, including several amino acid transport proteins, argininosuccinate and asparagine synthetases, and methionyl-tRNA synthetase. Upregulation of these genes constitutes a novel mechanism apparently contributing to the stimulatory effects of IGF signaling on the global protein synthesis rate. We conclude that the induction of cell proliferation and tumor formation by long-term IGF stimulation may primarily be due to anabolic effects, in particular increased amino acid production and uptake.

Standard name | LIU_CDX2_TARGETS_UP
Systematic name | M16637
Organism | Homo sapiens
PMID | 16990345
Authors | Liu T,Zhang X,So CK,Wang S,Wang P,Yan L,Myers R,Chen Z,Patterson AP,Yang CS,Chen X
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HET1A cells (esophagus epithelium) engineered to stably express CDX2 [GeneID=1045].
Full description | Caudal-related homeobox 2 (Cdx2) has been suggested as an early marker of Barrett's esophagus (BE), which is the premalignant lesion of esophageal adenocarcinoma (EAC). However, the mechanism of ectopic Cdx2 expression in the esophageal epithelial cells and its role in the development of BE remained unclear. RT-PCR, pyrosequencing and methylation-specific PCR were used to determine expression and promoter methylation of Cdx2 in human esophageal epithelial cells (HET1A and SEG1) after treatment with 5-aza-2'-deoxycytidine (DAC), acid, bile acids and their combination. HET1A cells with stable transfection of Cdx2 were characterized for morphology and gene expression profiles with Affymetrix array. We found Cdx2 was expressed in most human EAC cell lines, but not in squamous epithelial cell lines. DAC-induced demethylation and expression of Cdx2 in HET1A and SEG1 cells, and treatment with a DNA methylating agent counteracted the effect of DAC. Treatment of HET1A and SEG1 cells with acid, bile acids or both also resulted in promoter demethylation and expression of Cdx2. HET1A cells with stable transfection of human Cdx2 formed crypt-like structures in vitro. Microarray analysis and quantitative real-time PCR showed that stable transfection of Cdx2 up-regulated differentiation markers of intestinal columnar epithelial cells and goblet cells in HET1A cells. This may be partially due to modulation of Notch signaling pathway, as western blotting confirmed down-regulation of Hes1 and up-regulation of Atoh1 and Muc2. Our data suggest that exposure to acid and/or bile acids may activate Cdx2 expression in human esophageal epithelial cells through promoter demethylation, and ectopic Cdx2 expression in esophageal squamous epithelial cells may contribute to intestinal metaplasia of the esophagus.

Standard name | LIU_CDX2_TARGETS_DN
Systematic name | M19218
Organism | Homo sapiens
PMID | 16990345
Authors | Liu T,Zhang X,So CK,Wang S,Wang P,Yan L,Myers R,Chen Z,Patterson AP,Yang CS,Chen X
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HET1A cells (esophagus epithelium) engineered to stably express CDX2 [GeneID=1045].
Full description | Caudal-related homeobox 2 (Cdx2) has been suggested as an early marker of Barrett's esophagus (BE), which is the premalignant lesion of esophageal adenocarcinoma (EAC). However, the mechanism of ectopic Cdx2 expression in the esophageal epithelial cells and its role in the development of BE remained unclear. RT-PCR, pyrosequencing and methylation-specific PCR were used to determine expression and promoter methylation of Cdx2 in human esophageal epithelial cells (HET1A and SEG1) after treatment with 5-aza-2'-deoxycytidine (DAC), acid, bile acids and their combination. HET1A cells with stable transfection of Cdx2 were characterized for morphology and gene expression profiles with Affymetrix array. We found Cdx2 was expressed in most human EAC cell lines, but not in squamous epithelial cell lines. DAC-induced demethylation and expression of Cdx2 in HET1A and SEG1 cells, and treatment with a DNA methylating agent counteracted the effect of DAC. Treatment of HET1A and SEG1 cells with acid, bile acids or both also resulted in promoter demethylation and expression of Cdx2. HET1A cells with stable transfection of human Cdx2 formed crypt-like structures in vitro. Microarray analysis and quantitative real-time PCR showed that stable transfection of Cdx2 up-regulated differentiation markers of intestinal columnar epithelial cells and goblet cells in HET1A cells. This may be partially due to modulation of Notch signaling pathway, as western blotting confirmed down-regulation of Hes1 and up-regulation of Atoh1 and Muc2. Our data suggest that exposure to acid and/or bile acids may activate Cdx2 expression in human esophageal epithelial cells through promoter demethylation, and ectopic Cdx2 expression in esophageal squamous epithelial cells may contribute to intestinal metaplasia of the esophagus.

Standard name | COLDREN_GEFITINIB_RESISTANCE_UP
Systematic name | M18134
Organism | Homo sapiens
PMID | 16877703
Authors | Coldren CD,Helfrich BA,Witta SE,Sugita M,Lapadat R,Zeng C,Barón A,Franklin WA,Hirsch FR,Geraci MW,Bunn PA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NSCLC (non-small cell lung carcinoma) cell lines resistant to gefitinib [PubChem=123631] compared to the sensitive ones.
Full description | Tyrosine kinase inhibitors (TKI) of the epidermal growth factor receptor (EGFR) produce objective responses in a minority of patients with advanced-stage non-small cell lung cancer (NSCLC), and about half of all treated patients progress within 6 weeks of instituting therapy. Because the target of these agents is known, it should be possible to develop biological predictors of response, but EGFR protein levels have not been proven useful as a predictor of TKI response in patients and the mechanism of primary resistance is unclear. We used microarray gene expression profiling to uncover a pattern of gene expression associated with sensitivity to EGFR-TKIs by comparing NSCLC cell lines that were either highly sensitive or highly resistant to gefitinib. This sensitivity-associated expression profile was used to predict gefitinib sensitivity in a panel of NSCLC cell lines with known gene expression profiles but unknown gefitinib sensitivity. Gefitinib sensitivity was then determined for members of this test panel, and the microarray-based sensitivity prediction was correct in eight of nine NSCLC cell lines. Gene and protein expression differences were confirmed with a combination of quantitative reverse transcription-PCR, flow cytometry, and immunohistochemistry. This gene expression pattern related to gefitinib sensitivity was independent from sensitivity associated with EGFR mutations. Several genes associated with sensitivity encode proteins involved in HER pathway signaling or pathways that interrelate to the HER signaling pathway. Some of these genes could be targets of pharmacologic interventions to overcome primary resistance.

Standard name | COLDREN_GEFITINIB_RESISTANCE_DN
Systematic name | M6744
Organism | Homo sapiens
PMID | 16877703
Authors | Coldren CD,Helfrich BA,Witta SE,Sugita M,Lapadat R,Zeng C,Barón A,Franklin WA,Hirsch FR,Geraci MW,Bunn PA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NSCLC (non-small cell lung carcinoma) cell lines resistant to gefitinib [PubChem=123631] compared to the sensitive ones.
Full description | Tyrosine kinase inhibitors (TKI) of the epidermal growth factor receptor (EGFR) produce objective responses in a minority of patients with advanced-stage non-small cell lung cancer (NSCLC), and about half of all treated patients progress within 6 weeks of instituting therapy. Because the target of these agents is known, it should be possible to develop biological predictors of response, but EGFR protein levels have not been proven useful as a predictor of TKI response in patients and the mechanism of primary resistance is unclear. We used microarray gene expression profiling to uncover a pattern of gene expression associated with sensitivity to EGFR-TKIs by comparing NSCLC cell lines that were either highly sensitive or highly resistant to gefitinib. This sensitivity-associated expression profile was used to predict gefitinib sensitivity in a panel of NSCLC cell lines with known gene expression profiles but unknown gefitinib sensitivity. Gefitinib sensitivity was then determined for members of this test panel, and the microarray-based sensitivity prediction was correct in eight of nine NSCLC cell lines. Gene and protein expression differences were confirmed with a combination of quantitative reverse transcription-PCR, flow cytometry, and immunohistochemistry. This gene expression pattern related to gefitinib sensitivity was independent from sensitivity associated with EGFR mutations. Several genes associated with sensitivity encode proteins involved in HER pathway signaling or pathways that interrelate to the HER signaling pathway. Some of these genes could be targets of pharmacologic interventions to overcome primary resistance.

Standard name | KOKKINAKIS_METHIONINE_DEPRIVATION_48HR_UP
Systematic name | M13537
Organism | Homo sapiens
PMID | 16908595
Authors | Kokkinakis DM,Brickner AG,Kirkwood JM,Liu X,Goldwasser JE,Kastrama A,Sander C,Bocangel D,Chada S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEWO cells (melanoma) after 48h of methionine [PubChem=876] deprivation.
Full description | Methionine deprivation stress (MDS) eliminates mitotic activity in melanoma cells regardless of stage, grade, or TP53 status, whereas it has a negligible effect on normal skin fibroblasts. In most cases, apoptosis accounts for the elimination of up to 90% of tumor cells from the culture within 72 hours after MDS, leaving a scattered population of multinucleated resistant cells. Loss of mitosis in tumor cells is associated with marked reduction of cyclin-dependent kinase (CDK) 1 transcription and/or loss of its active form (CDK1-P-Thr(161)), which is coincident with up-regulation of CDKN1A, CDKN1B, and CDKN1C (p21, p27, and p57). Expression of the proapoptotic LITAF, IFNGR, EREG, TNFSF/TNFRSF10 and TNFRSF12, FAS, and RNASEL is primarily up-regulated/induced in cells destined to undergo apoptosis. Loss of Aurora kinase B and BIRC5, which are required for histone H3 phosphorylation, is associated with the accumulation of surviving multinucleated cells. Nevertheless, noncycling survivors of MDS are sensitized to temozolomide, carmustin, and cisplatin to a much greater extent than normal skin fibroblasts possibly because of the suppression of MGMT/TOP1/POLB, MGMT/RAD52/RAD54, and cMET/RADD52, respectively. Sensitivity to these and additional genotoxic agents and radiation may also be acquired due to loss of cMET/OGG1, reduced glutathione reductase levels, and a G(2)-phase block that is a crucial step in the damage response associated with enhancement of drug toxicity. Although the genes controlling mitotic arrest and/or apoptosis in response to low extracellular methionine levels are unknown, it is likely that such control is exerted via the induction/up-regulation of tumor suppressors/growth inhibitor genes, such as TGFB, PTEN, GAS1, EGR3, BTG3, MDA7, and the proteoglycans (LUM, BGN, and DCN), as well as the down-regulation/loss of function of prosurvival genes, such as NFkappaB, MYC, and ERBB2. Although MDS targets several common genes in tumors, mutational variability among melanomas may decide which metabolic and signal transduction pathways will be activated or shutdown.

Standard name | KOKKINAKIS_METHIONINE_DEPRIVATION_48HR_DN
Systematic name | M16639
Organism | Homo sapiens
PMID | 16908595
Authors | Kokkinakis DM,Brickner AG,Kirkwood JM,Liu X,Goldwasser JE,Kastrama A,Sander C,Bocangel D,Chada S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEWO cells (melanoma) after 48h of methionine [PubChem=876] deprivation.
Full description | Methionine deprivation stress (MDS) eliminates mitotic activity in melanoma cells regardless of stage, grade, or TP53 status, whereas it has a negligible effect on normal skin fibroblasts. In most cases, apoptosis accounts for the elimination of up to 90% of tumor cells from the culture within 72 hours after MDS, leaving a scattered population of multinucleated resistant cells. Loss of mitosis in tumor cells is associated with marked reduction of cyclin-dependent kinase (CDK) 1 transcription and/or loss of its active form (CDK1-P-Thr(161)), which is coincident with up-regulation of CDKN1A, CDKN1B, and CDKN1C (p21, p27, and p57). Expression of the proapoptotic LITAF, IFNGR, EREG, TNFSF/TNFRSF10 and TNFRSF12, FAS, and RNASEL is primarily up-regulated/induced in cells destined to undergo apoptosis. Loss of Aurora kinase B and BIRC5, which are required for histone H3 phosphorylation, is associated with the accumulation of surviving multinucleated cells. Nevertheless, noncycling survivors of MDS are sensitized to temozolomide, carmustin, and cisplatin to a much greater extent than normal skin fibroblasts possibly because of the suppression of MGMT/TOP1/POLB, MGMT/RAD52/RAD54, and cMET/RADD52, respectively. Sensitivity to these and additional genotoxic agents and radiation may also be acquired due to loss of cMET/OGG1, reduced glutathione reductase levels, and a G(2)-phase block that is a crucial step in the damage response associated with enhancement of drug toxicity. Although the genes controlling mitotic arrest and/or apoptosis in response to low extracellular methionine levels are unknown, it is likely that such control is exerted via the induction/up-regulation of tumor suppressors/growth inhibitor genes, such as TGFB, PTEN, GAS1, EGR3, BTG3, MDA7, and the proteoglycans (LUM, BGN, and DCN), as well as the down-regulation/loss of function of prosurvival genes, such as NFkappaB, MYC, and ERBB2. Although MDS targets several common genes in tumors, mutational variability among melanomas may decide which metabolic and signal transduction pathways will be activated or shutdown.

Standard name | KOKKINAKIS_METHIONINE_DEPRIVATION_96HR_UP
Systematic name | M12313
Organism | Homo sapiens
PMID | 16908595
Authors | Kokkinakis DM,Brickner AG,Kirkwood JM,Liu X,Goldwasser JE,Kastrama A,Sander C,Bocangel D,Chada S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEWO cells (melanoma) after 96 h of methionine [PubChem=876] deprivation.
Full description | Methionine deprivation stress (MDS) eliminates mitotic activity in melanoma cells regardless of stage, grade, or TP53 status, whereas it has a negligible effect on normal skin fibroblasts. In most cases, apoptosis accounts for the elimination of up to 90% of tumor cells from the culture within 72 hours after MDS, leaving a scattered population of multinucleated resistant cells. Loss of mitosis in tumor cells is associated with marked reduction of cyclin-dependent kinase (CDK) 1 transcription and/or loss of its active form (CDK1-P-Thr(161)), which is coincident with up-regulation of CDKN1A, CDKN1B, and CDKN1C (p21, p27, and p57). Expression of the proapoptotic LITAF, IFNGR, EREG, TNFSF/TNFRSF10 and TNFRSF12, FAS, and RNASEL is primarily up-regulated/induced in cells destined to undergo apoptosis. Loss of Aurora kinase B and BIRC5, which are required for histone H3 phosphorylation, is associated with the accumulation of surviving multinucleated cells. Nevertheless, noncycling survivors of MDS are sensitized to temozolomide, carmustin, and cisplatin to a much greater extent than normal skin fibroblasts possibly because of the suppression of MGMT/TOP1/POLB, MGMT/RAD52/RAD54, and cMET/RADD52, respectively. Sensitivity to these and additional genotoxic agents and radiation may also be acquired due to loss of cMET/OGG1, reduced glutathione reductase levels, and a G(2)-phase block that is a crucial step in the damage response associated with enhancement of drug toxicity. Although the genes controlling mitotic arrest and/or apoptosis in response to low extracellular methionine levels are unknown, it is likely that such control is exerted via the induction/up-regulation of tumor suppressors/growth inhibitor genes, such as TGFB, PTEN, GAS1, EGR3, BTG3, MDA7, and the proteoglycans (LUM, BGN, and DCN), as well as the down-regulation/loss of function of prosurvival genes, such as NFkappaB, MYC, and ERBB2. Although MDS targets several common genes in tumors, mutational variability among melanomas may decide which metabolic and signal transduction pathways will be activated or shutdown.

Standard name | KOKKINAKIS_METHIONINE_DEPRIVATION_96HR_DN
Systematic name | M170
Organism | Homo sapiens
PMID | 16908595
Authors | Kokkinakis DM,Brickner AG,Kirkwood JM,Liu X,Goldwasser JE,Kastrama A,Sander C,Bocangel D,Chada S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEWO cells (melanoma) after 96 h of methionine [PubChem=876] deprivation.
Full description | Methionine deprivation stress (MDS) eliminates mitotic activity in melanoma cells regardless of stage, grade, or TP53 status, whereas it has a negligible effect on normal skin fibroblasts. In most cases, apoptosis accounts for the elimination of up to 90% of tumor cells from the culture within 72 hours after MDS, leaving a scattered population of multinucleated resistant cells. Loss of mitosis in tumor cells is associated with marked reduction of cyclin-dependent kinase (CDK) 1 transcription and/or loss of its active form (CDK1-P-Thr(161)), which is coincident with up-regulation of CDKN1A, CDKN1B, and CDKN1C (p21, p27, and p57). Expression of the proapoptotic LITAF, IFNGR, EREG, TNFSF/TNFRSF10 and TNFRSF12, FAS, and RNASEL is primarily up-regulated/induced in cells destined to undergo apoptosis. Loss of Aurora kinase B and BIRC5, which are required for histone H3 phosphorylation, is associated with the accumulation of surviving multinucleated cells. Nevertheless, noncycling survivors of MDS are sensitized to temozolomide, carmustin, and cisplatin to a much greater extent than normal skin fibroblasts possibly because of the suppression of MGMT/TOP1/POLB, MGMT/RAD52/RAD54, and cMET/RADD52, respectively. Sensitivity to these and additional genotoxic agents and radiation may also be acquired due to loss of cMET/OGG1, reduced glutathione reductase levels, and a G(2)-phase block that is a crucial step in the damage response associated with enhancement of drug toxicity. Although the genes controlling mitotic arrest and/or apoptosis in response to low extracellular methionine levels are unknown, it is likely that such control is exerted via the induction/up-regulation of tumor suppressors/growth inhibitor genes, such as TGFB, PTEN, GAS1, EGR3, BTG3, MDA7, and the proteoglycans (LUM, BGN, and DCN), as well as the down-regulation/loss of function of prosurvival genes, such as NFkappaB, MYC, and ERBB2. Although MDS targets several common genes in tumors, mutational variability among melanomas may decide which metabolic and signal transduction pathways will be activated or shutdown.

Standard name | PASTURAL_RIZ1_TARGETS_UP
Systematic name | M19828
Organism | Homo sapiens
PMID | 16953217
Authors | Pastural E,Takahashi N,Dong WF,Bainbridge M,Hull A,Pearson D,Huang S,Lowsky R,DeCoteau JF,Geyer CR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in K562 (chronic myelogenous leukemia, CML) cells engineered to stably express RIZ1 [GeneID=7799].
Full description | RIZ1 is a histone methyltransferase whose expression and activity are reduced in many cancers. In chronic myelogenous leukemia (CML), blastic transformation is associated with loss of heterozygosity in the region where RIZ1 is located and with decreased RIZ1 expression. Forced RIZ1 expression in model CML blast crisis (BC) cell lines decreases proliferation, increases apoptosis and enhances differentiation. We characterized molecular mechanisms that may contribute to potential CML tumor suppressor properties of RIZ1. Several RIZ1-regulated genes involved in insulin-like growth factor-1 (IGF-1) signaling were identified using cDNA microarrays. RIZ1 was shown to associate with promoter regions of IGF-1 and to increase histone H3 lysine 9 methylation using chromatin immunoprecipitation assays. IGF-1-blocking antibody was used to demonstrate the importance of autocrine IGF-1 signaling in CML-BC cell line viability. Forced RIZ1 expression in CML-BC cell lines decreases IGF-1 receptor activation and activation of downstream signaling components extracellular signal-regulated kinase 1/2 and AKT. These results highlight the therapeutic potential of inhibiting IGF-1 pathway in the acute phase of CML.

Standard name | PASTURAL_RIZ1_TARGETS_DN
Systematic name | M4364
Organism | Homo sapiens
PMID | 16953217
Authors | Pastural E,Takahashi N,Dong WF,Bainbridge M,Hull A,Pearson D,Huang S,Lowsky R,DeCoteau JF,Geyer CR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in K562 (chronic myelogenous leukemia, CML) cells engineered to stably express RIZ1 [GeneID=7799].
Full description | RIZ1 is a histone methyltransferase whose expression and activity are reduced in many cancers. In chronic myelogenous leukemia (CML), blastic transformation is associated with loss of heterozygosity in the region where RIZ1 is located and with decreased RIZ1 expression. Forced RIZ1 expression in model CML blast crisis (BC) cell lines decreases proliferation, increases apoptosis and enhances differentiation. We characterized molecular mechanisms that may contribute to potential CML tumor suppressor properties of RIZ1. Several RIZ1-regulated genes involved in insulin-like growth factor-1 (IGF-1) signaling were identified using cDNA microarrays. RIZ1 was shown to associate with promoter regions of IGF-1 and to increase histone H3 lysine 9 methylation using chromatin immunoprecipitation assays. IGF-1-blocking antibody was used to demonstrate the importance of autocrine IGF-1 signaling in CML-BC cell line viability. Forced RIZ1 expression in CML-BC cell lines decreases IGF-1 receptor activation and activation of downstream signaling components extracellular signal-regulated kinase 1/2 and AKT. These results highlight the therapeutic potential of inhibiting IGF-1 pathway in the acute phase of CML.

Standard name | CHOW_RASSF1_TARGETS_UP
Systematic name | M2626
Organism | Homo sapiens
PMID | 16116475
Authors | Chow LS,Lam CW,Chan SY,Tsao SW,To KF,Tong SF,Hung WK,Dammann R,Huang DP,Lo KW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in C666-1 cells (nasopharyngeal carcinoma) by stable expression of RASSF1 [GeneID=11186].
Full description | RASSF1A is a tumor suppressor gene on 3p21.3 frequently inactivated by promoter hypermethylation in nasopharyngeal carcinoma (NPC). To identify RASSF1A target genes in NPC, we have investigated the expression profile of the stable RASSF1A transfectants and controls by high-density oligonucleotide array. A total of 57 genes showed differential expression in the RASSF1A-expressing cells. These RASSF1A target genes were involved in multiple cellular regulatory processes such as transcription, signal transduction, cell adhesion and RNA processing. The RASSF1A-modulated expression of eight selected genes with the highest fold changes (ATF5, TCRB, RGS1, activin betaE, HNRPH1, HNRPD, Id2 and CKS2) by RASSF1A was confirmed in both stable and transient transfectants. Compared with the RASSF1A transfectants, an inverse expression pattern of activin betaE, Id2 and ATF5 was shown in the immortalized nasopharyngeal epithelial cells treated with siRNA against RASSF1A. The findings imply that the expression of activin betaE, Id2 and ATF5 was tightly regulated by RASSF1A and may associate with its tumor suppressor function. Strikingly, overexpression of Id2 is common in NPC and RASSF1A-induced repression of Id2 was mediated by the overexpression of activin betaE. The results suggest a novel RASSF1A pathway in which both activin betaE and Id2 are involved.

Standard name | CHOW_RASSF1_TARGETS_DN
Systematic name | M905
Organism | Homo sapiens
PMID | 16116475
Authors | Chow LS,Lam CW,Chan SY,Tsao SW,To KF,Tong SF,Hung WK,Dammann R,Huang DP,Lo KW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in C666-1 cells (nasopharyngeal carcinoma) by stable expression of RASSF1 [GeneID=11186].
Full description | RASSF1A is a tumor suppressor gene on 3p21.3 frequently inactivated by promoter hypermethylation in nasopharyngeal carcinoma (NPC). To identify RASSF1A target genes in NPC, we have investigated the expression profile of the stable RASSF1A transfectants and controls by high-density oligonucleotide array. A total of 57 genes showed differential expression in the RASSF1A-expressing cells. These RASSF1A target genes were involved in multiple cellular regulatory processes such as transcription, signal transduction, cell adhesion and RNA processing. The RASSF1A-modulated expression of eight selected genes with the highest fold changes (ATF5, TCRB, RGS1, activin betaE, HNRPH1, HNRPD, Id2 and CKS2) by RASSF1A was confirmed in both stable and transient transfectants. Compared with the RASSF1A transfectants, an inverse expression pattern of activin betaE, Id2 and ATF5 was shown in the immortalized nasopharyngeal epithelial cells treated with siRNA against RASSF1A. The findings imply that the expression of activin betaE, Id2 and ATF5 was tightly regulated by RASSF1A and may associate with its tumor suppressor function. Strikingly, overexpression of Id2 is common in NPC and RASSF1A-induced repression of Id2 was mediated by the overexpression of activin betaE. The results suggest a novel RASSF1A pathway in which both activin betaE and Id2 are involved.

Standard name | ENK_UV_RESPONSE_EPIDERMIS_UP
Systematic name | M19848
Organism | Homo sapiens
PMID | 16434974
Authors | Enk CD,Jacob-Hirsch J,Gal H,Verbovetski I,Amariglio N,Mevorach D,Ingber A,Givol D,Rechavi G,Hochberg M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in epidermis after to UVB irradiation.
Full description | In order to obtain a comprehensive picture of the molecular events regulating cutaneous photodamage of intact human epidermis, suction blister roofs obtained after a single dose of in vivo ultraviolet (UV)B exposure were used for microarray profiling. We found a changed expression of 619 genes. Half of the UVB-regulated genes had returned to pre-exposure baseline levels at 72 h, underscoring the transient character of the molecular cutaneous UVB response. Of special interest was our finding that several of the central p53 target genes remained unaffected following UVB exposure in spite of p53 protein accumulation. We next compared the in vivo expression profiles of epidermal sheets to that of cultured human epidermal keratinocytes exposed to UVB in vitro. We found 1931 genes that differed in their expression profiles between the two groups. The expression profile in intact epidemis was geared mainly towards DNA repair, whereas cultured keratinocytes responded predominantly by activating genes associated with cell-cycle arrest and apoptosis. These differences in expression profiles might reflect differences between mature differentiating keratinocytes in the suprabasal epidermal layers versus exponentially proliferating keratinocytes in cell culture. Our findings show that extreme care should be taken when extrapolating from findings based on keratinocyte cultures to changes in intact epidermis.

Standard name | ENK_UV_RESPONSE_EPIDERMIS_DN
Systematic name | M4508
Organism | Homo sapiens
PMID | 16434974
Authors | Enk CD,Jacob-Hirsch J,Gal H,Verbovetski I,Amariglio N,Mevorach D,Ingber A,Givol D,Rechavi G,Hochberg M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in epidermis after to UVB irradiation.
Full description | In order to obtain a comprehensive picture of the molecular events regulating cutaneous photodamage of intact human epidermis, suction blister roofs obtained after a single dose of in vivo ultraviolet (UV)B exposure were used for microarray profiling. We found a changed expression of 619 genes. Half of the UVB-regulated genes had returned to pre-exposure baseline levels at 72 h, underscoring the transient character of the molecular cutaneous UVB response. Of special interest was our finding that several of the central p53 target genes remained unaffected following UVB exposure in spite of p53 protein accumulation. We next compared the in vivo expression profiles of epidermal sheets to that of cultured human epidermal keratinocytes exposed to UVB in vitro. We found 1931 genes that differed in their expression profiles between the two groups. The expression profile in intact epidemis was geared mainly towards DNA repair, whereas cultured keratinocytes responded predominantly by activating genes associated with cell-cycle arrest and apoptosis. These differences in expression profiles might reflect differences between mature differentiating keratinocytes in the suprabasal epidermal layers versus exponentially proliferating keratinocytes in cell culture. Our findings show that extreme care should be taken when extrapolating from findings based on keratinocyte cultures to changes in intact epidermis.

Standard name | ENK_UV_RESPONSE_KERATINOCYTE_UP
Systematic name | M10791
Organism | Homo sapiens
PMID | 16434974
Authors | Enk CD,Jacob-Hirsch J,Gal H,Verbovetski I,Amariglio N,Mevorach D,Ingber A,Givol D,Rechavi G,Hochberg M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NHEK cells (normal epidermal keratinocytes) after UVB irradiation.
Full description | In order to obtain a comprehensive picture of the molecular events regulating cutaneous photodamage of intact human epidermis, suction blister roofs obtained after a single dose of in vivo ultraviolet (UV)B exposure were used for microarray profiling. We found a changed expression of 619 genes. Half of the UVB-regulated genes had returned to pre-exposure baseline levels at 72 h, underscoring the transient character of the molecular cutaneous UVB response. Of special interest was our finding that several of the central p53 target genes remained unaffected following UVB exposure in spite of p53 protein accumulation. We next compared the in vivo expression profiles of epidermal sheets to that of cultured human epidermal keratinocytes exposed to UVB in vitro. We found 1931 genes that differed in their expression profiles between the two groups. The expression profile in intact epidemis was geared mainly towards DNA repair, whereas cultured keratinocytes responded predominantly by activating genes associated with cell-cycle arrest and apoptosis. These differences in expression profiles might reflect differences between mature differentiating keratinocytes in the suprabasal epidermal layers versus exponentially proliferating keratinocytes in cell culture. Our findings show that extreme care should be taken when extrapolating from findings based on keratinocyte cultures to changes in intact epidermis.

Standard name | ENK_UV_RESPONSE_KERATINOCYTE_DN
Systematic name | M3898
Organism | Homo sapiens
PMID | 16434974
Authors | Enk CD,Jacob-Hirsch J,Gal H,Verbovetski I,Amariglio N,Mevorach D,Ingber A,Givol D,Rechavi G,Hochberg M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NHEK cells (normal epidermal keratinocytes) after UVB irradiation.
Full description | In order to obtain a comprehensive picture of the molecular events regulating cutaneous photodamage of intact human epidermis, suction blister roofs obtained after a single dose of in vivo ultraviolet (UV)B exposure were used for microarray profiling. We found a changed expression of 619 genes. Half of the UVB-regulated genes had returned to pre-exposure baseline levels at 72 h, underscoring the transient character of the molecular cutaneous UVB response. Of special interest was our finding that several of the central p53 target genes remained unaffected following UVB exposure in spite of p53 protein accumulation. We next compared the in vivo expression profiles of epidermal sheets to that of cultured human epidermal keratinocytes exposed to UVB in vitro. We found 1931 genes that differed in their expression profiles between the two groups. The expression profile in intact epidemis was geared mainly towards DNA repair, whereas cultured keratinocytes responded predominantly by activating genes associated with cell-cycle arrest and apoptosis. These differences in expression profiles might reflect differences between mature differentiating keratinocytes in the suprabasal epidermal layers versus exponentially proliferating keratinocytes in cell culture. Our findings show that extreme care should be taken when extrapolating from findings based on keratinocyte cultures to changes in intact epidermis.

Standard name | LANDIS_BREAST_CANCER_PROGRESSION_UP
Systematic name | M6875
Organism | Mus musculus
PMID | 16434967
Authors | Landis MD,Seachrist DD,Abdul-Karim FW,Keri RA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in preneoplastic mammary tissues and whose expression is maintained in tumors.
Full description | Epidemiological studies indicate that parity enhances HER2/ErbB2/Neu-induced breast tumorigenesis. Furthermore, recent studies using multiparous, ErbB2/Neu-overexpressing mouse mammary tumor virus (MMTV-Neu) mice have shown that parity induces a population of cells that are targeted for ErbB2/Neu-induced transformation. Although parity accelerates mammary tumorigenesis, the pattern of tumor development in multiparous MMTV-Neu mice remains stochastic, suggesting that additional events are required for ErbB2/Neu to cause mammary tumors. Whether such events are genetic in nature or reflective of the dynamic hormonal control of the gland that occurs with pregnancy remains unclear. We postulated that young age at pregnancy initiation or chronic trophic maintenance of mammary epithelial cells might provide a cellular environment that significantly increases susceptibility to ErbB2/Neu-induced tumorigenesis. MMTV-Neu mice that were maintained pregnant or lactating beginning at 3 weeks of age demonstrated accelerated tumorigenesis, but this process was still stochastic, indicating that early pregnancy does not provide the requisite events of tumorigenesis. However, bitransgenic mice that were generated by breeding MMTV-Neu mice with a luteinizing hormone-overexpressing mouse model of ovarian hyperstimulation developed multifocal mammary tumors in an accelerated, synchronous manner compared to virgin MMTV-Neu animals. This synchrony of tumor development in the bitransgenic mice suggests that trophic maintenance of the mammary gland provides the additional events required for tumor formation and maintains the population of cells that are targeted by ErbB2/Neu for transformation. Both the synchrony of tumor appearance and the ability to characterize a window of commitment by ovariectomy/palpation studies permitted microarray analysis to evaluate changes in gene expression over a defined timeline that spans the progression from normal to preneoplastic mammary tissue. These approaches led to identification of several candidate genes whose expression changes in the mammary gland with commitment to ErbB2/Neu-induced tumorigenesis, suggesting that they may either be regulated by ErbB2/Neu and/or contribute to tumor formation.

Standard name | LANDIS_BREAST_CANCER_PROGRESSION_DN
Systematic name | M9908
Organism | Mus musculus
PMID | 16434967
Authors | Landis MD,Seachrist DD,Abdul-Karim FW,Keri RA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in preneoplastic mammary tissues and whose expression is maintained in tumors.
Full description | Epidemiological studies indicate that parity enhances HER2/ErbB2/Neu-induced breast tumorigenesis. Furthermore, recent studies using multiparous, ErbB2/Neu-overexpressing mouse mammary tumor virus (MMTV-Neu) mice have shown that parity induces a population of cells that are targeted for ErbB2/Neu-induced transformation. Although parity accelerates mammary tumorigenesis, the pattern of tumor development in multiparous MMTV-Neu mice remains stochastic, suggesting that additional events are required for ErbB2/Neu to cause mammary tumors. Whether such events are genetic in nature or reflective of the dynamic hormonal control of the gland that occurs with pregnancy remains unclear. We postulated that young age at pregnancy initiation or chronic trophic maintenance of mammary epithelial cells might provide a cellular environment that significantly increases susceptibility to ErbB2/Neu-induced tumorigenesis. MMTV-Neu mice that were maintained pregnant or lactating beginning at 3 weeks of age demonstrated accelerated tumorigenesis, but this process was still stochastic, indicating that early pregnancy does not provide the requisite events of tumorigenesis. However, bitransgenic mice that were generated by breeding MMTV-Neu mice with a luteinizing hormone-overexpressing mouse model of ovarian hyperstimulation developed multifocal mammary tumors in an accelerated, synchronous manner compared to virgin MMTV-Neu animals. This synchrony of tumor development in the bitransgenic mice suggests that trophic maintenance of the mammary gland provides the additional events required for tumor formation and maintains the population of cells that are targeted by ErbB2/Neu for transformation. Both the synchrony of tumor appearance and the ability to characterize a window of commitment by ovariectomy/palpation studies permitted microarray analysis to evaluate changes in gene expression over a defined timeline that spans the progression from normal to preneoplastic mammary tissue. These approaches led to identification of several candidate genes whose expression changes in the mammary gland with commitment to ErbB2/Neu-induced tumorigenesis, suggesting that they may either be regulated by ErbB2/Neu and/or contribute to tumor formation.

Standard name | GESERICK_TERT_TARGETS_DN
Systematic name | M15891
Organism | Mus musculus
PMID | 16501597
Authors | Geserick C,Tejera A,González-Suárez E,Klatt P,Blasco MA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblasts) with TERT [GeneID=7015] knockout, after expression of the gene off a retroviral vector.
Full description | Here, we show that ectopic expression of the catalytic subunit of mouse telomerase (mTert) confers a growth advantage to primary murine embryonic fibroblasts (MEFs), which have very long telomeres, as well as facilitates their spontaneous immortalization and increases their colony-forming capacity upon activation of oncogenes. We demonstrate that these telomere length-independent growth-promoting effects of mTert overexpression require catalytically active mTert, as well as the formation of mTert/Terc complexes. The gene expression profile of mTert-overexpressing MEFs indicates that telomerase enhances growth in these cells through the repression of growth-inhibiting genes of the transforming growth factor-beta (TGF-beta) signaling network. We functionally validate this result by showing that mTert abrogates the growth-inhibitory effect of TGF-beta in MEFs, thus demonstrating that telomerase increments the proliferative potential of primary mouse embryonic fibroblasts by targeting the TGF-beta pathway.

Standard name | YEMELYANOV_GR_TARGETS_DN
Systematic name | M17211
Organism | Homo sapiens
PMID | 17016446
Authors | Yemelyanov A,Czwornog J,Chebotaev D,Karseladze A,Kulevitch E,Yang X,Budunova I
Category | C2
Sub-category | CGP
Brief description | Transcription factors down-regulated in LNCaP cells (prostate cancer) by expression of GR [GeneID=2908] off a lentiviral vector.
Full description | Glucocorticoids are extensively used in combination chemotherapy of advanced prostate cancer (PC). Little is known, however, about the status of the glucocorticoid receptor (GR) in PC. We evaluated over 200 prostate samples and determined that GR expression was strongly decreased or absent in 70-85% of PC. Similar to PC tumors, some PC cell lines, including LNCaP, also lack GR. To understand the role of GR, we reconstituted its expression in LNCaP cells using lentiviral approach. Treatment of LNCaP-GR cells with the glucocorticoids strongly inhibited proliferation in the monolayer cultures and blocked anchorage-independent growth. This was accompanied by upregulation of p21 and p27, down-regulation of cyclin D1 expression and c-Myc phosphorylation. Importantly, the activation of GR resulted in normalized expression of PC markers hepsin, AMACR, and maspin. On the signaling level, GR decreased expression and inhibited activity of the MAP-kinases (MAPKs) including p38, JNK/SAPK, Mek1/2 and Erk1/2. We also found that activation of GR inhibited activity of numerous transcription factors (TF) including AP-1, SRF, NF-kappaB, p53, ATF-2, CEBPalpha, Ets-1, Elk-1, STAT1 and others, many of which are regulated via MAPK cascade. The structural analysis of hepsin and AMACR promoters provided the mechanistic rationale for PC marker downregulation by glucocorticoids via inhibition of specific TFs. Our data suggest that GR functions as a tumor suppressor in prostate, and inhibits multiple signaling pathways and transcriptional factors involved in proliferation and transformation.

Standard name | LAU_APOPTOSIS_CDKN2A_UP
Systematic name | M1411
Organism | Homo sapiens
PMID | 17369842
Authors | Lau WM,Ho TH,Hui KM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by UV-irradiation in cervical cancer cells after knockdown of CDKN2A [GeneID=1029].
Full description | p16(INK4A) (p16) has been suggested to be an early biomarker for the detection of cervical cancer. However, its functional role in cervical cancer is not well characterized. In this study, we reported the consistent and significant upregulation of p16 in cervical cancer tissues when compared to both matched non-tumourous tissues of the same patient and normal cervical tissues from non-cancer patients. We have employed p16 small interfering RNA (siRNA) to dissect the role of p16 in cervical carcinogenesis. Although the silencing of p16 was accompanied by the upregulation of p53, p21 and RB in the p16 siRNA-transfected cells, no significant effect on cell cycle progression was observed. When the p16 siRNA-silenced cells were subjected to DNA damage stress including ultraviolet-irradiation and cisplatin treatments, a significantly higher percentage of apoptotic cells could be observed in the p16-siRNA silenced cells compared to control siRNA-treated cells. Moreover, induction of apoptosis was associated with the activation of p53 through phosphorylation, and this process, when studied by gene profiling experiments, involved both the intrinsic and extrinsic apoptotic pathways. The observation that silencing of p16 expression augments DNA damage-induced apoptosis in cervical cancer cells offers alternative strategies for anti-cancer therapies for human cervical cancer.

Standard name | LAU_APOPTOSIS_CDKN2A_DN
Systematic name | M19275
Organism | Homo sapiens
PMID | 17369842
Authors | Lau WM,Ho TH,Hui KM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by UV-irradiation in cervical cancer cells after knockdown of CDKN2A [GeneID=1029].
Full description | p16(INK4A) (p16) has been suggested to be an early biomarker for the detection of cervical cancer. However, its functional role in cervical cancer is not well characterized. In this study, we reported the consistent and significant upregulation of p16 in cervical cancer tissues when compared to both matched non-tumourous tissues of the same patient and normal cervical tissues from non-cancer patients. We have employed p16 small interfering RNA (siRNA) to dissect the role of p16 in cervical carcinogenesis. Although the silencing of p16 was accompanied by the upregulation of p53, p21 and RB in the p16 siRNA-transfected cells, no significant effect on cell cycle progression was observed. When the p16 siRNA-silenced cells were subjected to DNA damage stress including ultraviolet-irradiation and cisplatin treatments, a significantly higher percentage of apoptotic cells could be observed in the p16-siRNA silenced cells compared to control siRNA-treated cells. Moreover, induction of apoptosis was associated with the activation of p53 through phosphorylation, and this process, when studied by gene profiling experiments, involved both the intrinsic and extrinsic apoptotic pathways. The observation that silencing of p16 expression augments DNA damage-induced apoptosis in cervical cancer cells offers alternative strategies for anti-cancer therapies for human cervical cancer.

Standard name | DELYS_THYROID_CANCER_UP
Systematic name | M3645
Organism | Homo sapiens
PMID | 17621275
Authors | Delys L,Detours V,Franc B,Thomas G,Bogdanova T,Tronko M,Libert F,Dumont JE,Maenhaut C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in papillary thyroid carcinoma (PTC) compared to normal tissue.
Full description | The purpose of this paper is to correlate the molecular phenotype of papillary thyroid carcinoma (PTC) to their biological pathology. We hybridized 26 PTC on microarrays and showed that nearly 44% of the transcriptome was regulated in these tumors. We then combined our data set with two published PTC microarray studies to produce a platform- and study-independent list of PTC-associated genes. We further confirmed the mRNA regulation of 15 genes from this list by quantitative reverse transcription-PCR. Analysis of this list with statistical tools led to several conclusions: (1) there is a change in cell population with an increased expression of genes involved in the immune response, reflecting lymphocyte infiltration in the tumor compared to the normal tissue. (2) The c-jun N-terminal kinase pathway is activated by overexpression of its components. (3) The activation of ERKK1/2 by genetic alterations is supplemented by activation of the epidermal growth factor but not of the insulin-like growth factor signaling pathway. (4) There is a downregulation of immediate early genes. (5) We observed an overexpression of many proteases in accordance with tumor remodeling, and suggested a probable role of S100 proteins and annexin A2 in this process. (6) Numerous overexpressed genes favor the hypothesis of a collective migration mode of tumor cells.

Standard name | DELYS_THYROID_CANCER_DN
Systematic name | M13273
Organism | Homo sapiens
PMID | 17621275
Authors | Delys L,Detours V,Franc B,Thomas G,Bogdanova T,Tronko M,Libert F,Dumont JE,Maenhaut C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in papillary thyroid carcinoma (PTC) compared to normal tissue.
Full description | The purpose of this paper is to correlate the molecular phenotype of papillary thyroid carcinoma (PTC) to their biological pathology. We hybridized 26 PTC on microarrays and showed that nearly 44% of the transcriptome was regulated in these tumors. We then combined our data set with two published PTC microarray studies to produce a platform- and study-independent list of PTC-associated genes. We further confirmed the mRNA regulation of 15 genes from this list by quantitative reverse transcription-PCR. Analysis of this list with statistical tools led to several conclusions: (1) there is a change in cell population with an increased expression of genes involved in the immune response, reflecting lymphocyte infiltration in the tumor compared to the normal tissue. (2) The c-jun N-terminal kinase pathway is activated by overexpression of its components. (3) The activation of ERKK1/2 by genetic alterations is supplemented by activation of the epidermal growth factor but not of the insulin-like growth factor signaling pathway. (4) There is a downregulation of immediate early genes. (5) We observed an overexpression of many proteases in accordance with tumor remodeling, and suggested a probable role of S100 proteins and annexin A2 in this process. (6) Numerous overexpressed genes favor the hypothesis of a collective migration mode of tumor cells.

Standard name | CHIARADONNA_NEOPLASTIC_TRANSFORMATION_KRAS_CDC25_UP
Systematic name | M8599
Organism | Mus musculus
PMID | 16607279
Authors | Chiaradonna F,Sacco E,Manzoni R,Giorgio M,Vanoni M,Alberghina L
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NIH3T3 cells (fibroblasts) transformed by activated KRAS [GeneID=3845] vs those reverted to normal cells upon over-expression of a dominant negative form of CDC25 [GeneID=5923].
Full description | Mutational activation of ras genes is required for the onset and maintenance of different malignancies. Here we show, using a combination of molecular physiology, nutritional perturbations and transcriptional profiling, that full penetrance of phenotypes related to oncogenic Ras activation, including the shift of carbon metabolism towards fermentation and upregulation of key cell cycle regulators, is dependent upon glucose availability. These responses are induced by Ras activation, being specifically reverted by downregulation of the Ras pathway obtained through the expression of a dominant-negative Ras-specific guanine nucleotide exchange protein. Our data allow to link directly to ras activation the alteration in energy metabolism of cancer cells, their fragility towards glucose shortage and ensuing apoptotic death.

Standard name | CHIARADONNA_NEOPLASTIC_TRANSFORMATION_KRAS_CDC25_DN
Systematic name | M5312
Organism | Mus musculus
PMID | 16607279
Authors | Chiaradonna F,Sacco E,Manzoni R,Giorgio M,Vanoni M,Alberghina L
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NIH3T3 cells (fibroblasts) transformed by activated KRAS [GeneID=3845] vs those reverted to normal cells upon over-expression of a dominant negative form of CDC25 [GeneID=5923].
Full description | Mutational activation of ras genes is required for the onset and maintenance of different malignancies. Here we show, using a combination of molecular physiology, nutritional perturbations and transcriptional profiling, that full penetrance of phenotypes related to oncogenic Ras activation, including the shift of carbon metabolism towards fermentation and upregulation of key cell cycle regulators, is dependent upon glucose availability. These responses are induced by Ras activation, being specifically reverted by downregulation of the Ras pathway obtained through the expression of a dominant-negative Ras-specific guanine nucleotide exchange protein. Our data allow to link directly to ras activation the alteration in energy metabolism of cancer cells, their fragility towards glucose shortage and ensuing apoptotic death.

Standard name | CHIARADONNA_NEOPLASTIC_TRANSFORMATION_KRAS_UP
Systematic name | M8795
Organism | Mus musculus
PMID | 16607279
Authors | Chiaradonna F,Sacco E,Manzoni R,Giorgio M,Vanoni M,Alberghina L
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in transformed NIH3T3 cells (fibroblasts transformed by activated KRAS [GeneID=3845]) vs normal cells.
Full description | Mutational activation of ras genes is required for the onset and maintenance of different malignancies. Here we show, using a combination of molecular physiology, nutritional perturbations and transcriptional profiling, that full penetrance of phenotypes related to oncogenic Ras activation, including the shift of carbon metabolism towards fermentation and upregulation of key cell cycle regulators, is dependent upon glucose availability. These responses are induced by Ras activation, being specifically reverted by downregulation of the Ras pathway obtained through the expression of a dominant-negative Ras-specific guanine nucleotide exchange protein. Our data allow to link directly to ras activation the alteration in energy metabolism of cancer cells, their fragility towards glucose shortage and ensuing apoptotic death.

Standard name | CHIARADONNA_NEOPLASTIC_TRANSFORMATION_KRAS_DN
Systematic name | M10381
Organism | Mus musculus
PMID | 16607279
Authors | Chiaradonna F,Sacco E,Manzoni R,Giorgio M,Vanoni M,Alberghina L
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in transformed NIH3T3 cells (fibroblasts transformed by activated KRAS [GeneID=3845]) vs normal cells.
Full description | Mutational activation of ras genes is required for the onset and maintenance of different malignancies. Here we show, using a combination of molecular physiology, nutritional perturbations and transcriptional profiling, that full penetrance of phenotypes related to oncogenic Ras activation, including the shift of carbon metabolism towards fermentation and upregulation of key cell cycle regulators, is dependent upon glucose availability. These responses are induced by Ras activation, being specifically reverted by downregulation of the Ras pathway obtained through the expression of a dominant-negative Ras-specific guanine nucleotide exchange protein. Our data allow to link directly to ras activation the alteration in energy metabolism of cancer cells, their fragility towards glucose shortage and ensuing apoptotic death.

Standard name | CHIARADONNA_NEOPLASTIC_TRANSFORMATION_CDC25_UP
Systematic name | M12828
Organism | Mus musculus
PMID | 16607279
Authors | Chiaradonna F,Sacco E,Manzoni R,Giorgio M,Vanoni M,Alberghina L
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in reverted NIH3T3 cells (fibroblasts transformed by activated KRAS [GeneID=3845] which then reverted to normal cells upon stable over-expression of a dominant negative form of CDC25 [GeneID=5923]) vs normal fibroblasts.
Full description | Mutational activation of ras genes is required for the onset and maintenance of different malignancies. Here we show, using a combination of molecular physiology, nutritional perturbations and transcriptional profiling, that full penetrance of phenotypes related to oncogenic Ras activation, including the shift of carbon metabolism towards fermentation and upregulation of key cell cycle regulators, is dependent upon glucose availability. These responses are induced by Ras activation, being specifically reverted by downregulation of the Ras pathway obtained through the expression of a dominant-negative Ras-specific guanine nucleotide exchange protein. Our data allow to link directly to ras activation the alteration in energy metabolism of cancer cells, their fragility towards glucose shortage and ensuing apoptotic death.

Standard name | CHIARADONNA_NEOPLASTIC_TRANSFORMATION_CDC25_DN
Systematic name | M16842
Organism | Mus musculus
PMID | 16607279
Authors | Chiaradonna F,Sacco E,Manzoni R,Giorgio M,Vanoni M,Alberghina L
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in reverted NIH3T3 cells (fibroblasts transformed by activated KRAS [GeneID=3845] which then reverted to normal cells upon stable over-expression of a dominant negative form of CDC25 [GeneID=5923]) vs normal fibroblasts.
Full description | Mutational activation of ras genes is required for the onset and maintenance of different malignancies. Here we show, using a combination of molecular physiology, nutritional perturbations and transcriptional profiling, that full penetrance of phenotypes related to oncogenic Ras activation, including the shift of carbon metabolism towards fermentation and upregulation of key cell cycle regulators, is dependent upon glucose availability. These responses are induced by Ras activation, being specifically reverted by downregulation of the Ras pathway obtained through the expression of a dominant-negative Ras-specific guanine nucleotide exchange protein. Our data allow to link directly to ras activation the alteration in energy metabolism of cancer cells, their fragility towards glucose shortage and ensuing apoptotic death.

Standard name | CASTELLANO_HRAS_TARGETS_DN
Systematic name | M17040
Organism | Mus musculus
PMID | 16909116
Authors | Castellano E,De Las Rivas J,Guerrero C,Santos E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblast) isolated from HRAS [GeneID=3265] knockout mice.
Full description | We characterized differential gene expression profiles of fibroblast cell lines harboring single or double-homozygous null mutations in H-ras and N-ras. Whereas the expression level of the individual H-, N- and K-ras genes appeared unaffected by the presence or absence of the other ras loci, significant differences were observed between the expression profiles of cells missing N-ras and/or H-ras. Absence of N-ras produced much stronger effects than absence of H-ras over the profile of the cellular transcriptome. N-ras(-/-) and H-ras(-/-) fibroblasts displayed rather antagonistic expression profiles and the transcriptome of H-ras(-/-) cells was significantly closer to that of wild-type fibroblasts than to that of N-ras(-/-) cells. Classifying all differentially expressed genes into functional categories suggested specific roles for H-Ras and N-Ras. It was particularly striking in N-ras(-/-) cells the upregulation of a remarkable number of immunity-related genes, as well as of several loci involved in apoptosis. Reverse-phase protein array assays demonstrated in the same N-ras(-/-) cells the overexpression and nuclear migration of tyrosine phosphorylated signal transducer and activator of transcription 1 (Stat1) which was concomitant with transcriptional activation mediated by interferon-stimulated response elements. Significantly enhanced numbers of apoptotic cells were also detected in cultures of N-ras(-/-) cells. Our data support the notion that different Ras isoforms play functionally distinct cellular roles and indicate that N-Ras is significantly involved in immune modulation/host defense and apoptotic responses.

Standard name | CASTELLANO_HRAS_AND_NRAS_TARGETS_UP
Systematic name | M18773
Organism | Mus musculus
PMID | 16909116
Authors | Castellano E,De Las Rivas J,Guerrero C,Santos E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblasts) isolated from HRAS and NRAS [GeneID=3265;4893] double knockout mice.
Full description | We characterized differential gene expression profiles of fibroblast cell lines harboring single or double-homozygous null mutations in H-ras and N-ras. Whereas the expression level of the individual H-, N- and K-ras genes appeared unaffected by the presence or absence of the other ras loci, significant differences were observed between the expression profiles of cells missing N-ras and/or H-ras. Absence of N-ras produced much stronger effects than absence of H-ras over the profile of the cellular transcriptome. N-ras(-/-) and H-ras(-/-) fibroblasts displayed rather antagonistic expression profiles and the transcriptome of H-ras(-/-) cells was significantly closer to that of wild-type fibroblasts than to that of N-ras(-/-) cells. Classifying all differentially expressed genes into functional categories suggested specific roles for H-Ras and N-Ras. It was particularly striking in N-ras(-/-) cells the upregulation of a remarkable number of immunity-related genes, as well as of several loci involved in apoptosis. Reverse-phase protein array assays demonstrated in the same N-ras(-/-) cells the overexpression and nuclear migration of tyrosine phosphorylated signal transducer and activator of transcription 1 (Stat1) which was concomitant with transcriptional activation mediated by interferon-stimulated response elements. Significantly enhanced numbers of apoptotic cells were also detected in cultures of N-ras(-/-) cells. Our data support the notion that different Ras isoforms play functionally distinct cellular roles and indicate that N-Ras is significantly involved in immune modulation/host defense and apoptotic responses.

Standard name | CASTELLANO_HRAS_AND_NRAS_TARGETS_DN
Systematic name | M5355
Organism | Mus musculus
PMID | 16909116
Authors | Castellano E,De Las Rivas J,Guerrero C,Santos E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblasts) isolated from HRAS and NRAS [GeneID=3265;4893] double knockout mice.
Full description | We characterized differential gene expression profiles of fibroblast cell lines harboring single or double-homozygous null mutations in H-ras and N-ras. Whereas the expression level of the individual H-, N- and K-ras genes appeared unaffected by the presence or absence of the other ras loci, significant differences were observed between the expression profiles of cells missing N-ras and/or H-ras. Absence of N-ras produced much stronger effects than absence of H-ras over the profile of the cellular transcriptome. N-ras(-/-) and H-ras(-/-) fibroblasts displayed rather antagonistic expression profiles and the transcriptome of H-ras(-/-) cells was significantly closer to that of wild-type fibroblasts than to that of N-ras(-/-) cells. Classifying all differentially expressed genes into functional categories suggested specific roles for H-Ras and N-Ras. It was particularly striking in N-ras(-/-) cells the upregulation of a remarkable number of immunity-related genes, as well as of several loci involved in apoptosis. Reverse-phase protein array assays demonstrated in the same N-ras(-/-) cells the overexpression and nuclear migration of tyrosine phosphorylated signal transducer and activator of transcription 1 (Stat1) which was concomitant with transcriptional activation mediated by interferon-stimulated response elements. Significantly enhanced numbers of apoptotic cells were also detected in cultures of N-ras(-/-) cells. Our data support the notion that different Ras isoforms play functionally distinct cellular roles and indicate that N-Ras is significantly involved in immune modulation/host defense and apoptotic responses.

Standard name | CASTELLANO_NRAS_TARGETS_UP
Systematic name | M18168
Organism | Mus musculus
PMID | 16909116
Authors | Castellano E,De Las Rivas J,Guerrero C,Santos E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) isolated from NRAS [GeneID=4893] knockout mice.
Full description | We characterized differential gene expression profiles of fibroblast cell lines harboring single or double-homozygous null mutations in H-ras and N-ras. Whereas the expression level of the individual H-, N- and K-ras genes appeared unaffected by the presence or absence of the other ras loci, significant differences were observed between the expression profiles of cells missing N-ras and/or H-ras. Absence of N-ras produced much stronger effects than absence of H-ras over the profile of the cellular transcriptome. N-ras(-/-) and H-ras(-/-) fibroblasts displayed rather antagonistic expression profiles and the transcriptome of H-ras(-/-) cells was significantly closer to that of wild-type fibroblasts than to that of N-ras(-/-) cells. Classifying all differentially expressed genes into functional categories suggested specific roles for H-Ras and N-Ras. It was particularly striking in N-ras(-/-) cells the upregulation of a remarkable number of immunity-related genes, as well as of several loci involved in apoptosis. Reverse-phase protein array assays demonstrated in the same N-ras(-/-) cells the overexpression and nuclear migration of tyrosine phosphorylated signal transducer and activator of transcription 1 (Stat1) which was concomitant with transcriptional activation mediated by interferon-stimulated response elements. Significantly enhanced numbers of apoptotic cells were also detected in cultures of N-ras(-/-) cells. Our data support the notion that different Ras isoforms play functionally distinct cellular roles and indicate that N-Ras is significantly involved in immune modulation/host defense and apoptotic responses.

Standard name | CASTELLANO_NRAS_TARGETS_DN
Systematic name | M12848
Organism | Mus musculus
PMID | 16909116
Authors | Castellano E,De Las Rivas J,Guerrero C,Santos E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblast) isolated from NRAS [GeneID=4893] knockout mice.
Full description | We characterized differential gene expression profiles of fibroblast cell lines harboring single or double-homozygous null mutations in H-ras and N-ras. Whereas the expression level of the individual H-, N- and K-ras genes appeared unaffected by the presence or absence of the other ras loci, significant differences were observed between the expression profiles of cells missing N-ras and/or H-ras. Absence of N-ras produced much stronger effects than absence of H-ras over the profile of the cellular transcriptome. N-ras(-/-) and H-ras(-/-) fibroblasts displayed rather antagonistic expression profiles and the transcriptome of H-ras(-/-) cells was significantly closer to that of wild-type fibroblasts than to that of N-ras(-/-) cells. Classifying all differentially expressed genes into functional categories suggested specific roles for H-Ras and N-Ras. It was particularly striking in N-ras(-/-) cells the upregulation of a remarkable number of immunity-related genes, as well as of several loci involved in apoptosis. Reverse-phase protein array assays demonstrated in the same N-ras(-/-) cells the overexpression and nuclear migration of tyrosine phosphorylated signal transducer and activator of transcription 1 (Stat1) which was concomitant with transcriptional activation mediated by interferon-stimulated response elements. Significantly enhanced numbers of apoptotic cells were also detected in cultures of N-ras(-/-) cells. Our data support the notion that different Ras isoforms play functionally distinct cellular roles and indicate that N-Ras is significantly involved in immune modulation/host defense and apoptotic responses.

Standard name | CHEBOTAEV_GR_TARGETS_UP
Systematic name | M4263
Organism | Mus musculus
PMID | 17146443
Authors | Chebotaev D,Yemelyanov A,Zhu L,Lavker RM,Budunova I
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in follicular epithelial stem cells after transgenic expression of GR [GeneID=2908] under control of the keratin5 (K5) [GeneID=3852] promoter.
Full description | Glucocorticoids are potent inhibitors of mouse skin tumorigenesis. The glucocorticoid control of cellular functions is mediated via the glucocorticoid receptor (GR), a well-known transcription factor. Recently, we generated transgenic mice overexpressing GR under control of the keratin5 (K5) promoter, and showed that K5.GR animals are resistant to skin carcinogenesis. Follicular epithelial stem cells (SCs), located in the bulge region of the hair follicle, are believed to be one of the target cells for skin carcinogenesis. We found that the number of putative hair follicle SC detected as label-retaining cells was significantly less in the K5.GR transgenics compared to wild type (w.t.) littermates. We also showed that GR overexpression led to a reduction in the clonogenicity of the follicular epithelial SCs. We evaluated the global effect of GR on gene expression in a population of follicular SC-enriched bulge keratinocytes isolated by fluorescence activated cell sorting. We found that GR affected the expression of numerous bulge SC 'signature' genes, genes involved in the maintenance of SC and progenitor cells of non-epidermal origin and proapoptotic genes. Our findings underscore the important role of GR signaling in the homeostasis of follicular epithelial SCs, and suggest that the reduction in their number may underlie the tumor suppressor effect of GR in the skin.

Standard name | CHEBOTAEV_GR_TARGETS_DN
Systematic name | M7876
Organism | Mus musculus
PMID | 17146443
Authors | Chebotaev D,Yemelyanov A,Zhu L,Lavker RM,Budunova I
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in follicular epithelial stem cells after transgenic expression of GR [GeneID=2908] under control of the keratin5 (K5) [GeneID=3852] promoter.
Full description | Glucocorticoids are potent inhibitors of mouse skin tumorigenesis. The glucocorticoid control of cellular functions is mediated via the glucocorticoid receptor (GR), a well-known transcription factor. Recently, we generated transgenic mice overexpressing GR under control of the keratin5 (K5) promoter, and showed that K5.GR animals are resistant to skin carcinogenesis. Follicular epithelial stem cells (SCs), located in the bulge region of the hair follicle, are believed to be one of the target cells for skin carcinogenesis. We found that the number of putative hair follicle SC detected as label-retaining cells was significantly less in the K5.GR transgenics compared to wild type (w.t.) littermates. We also showed that GR overexpression led to a reduction in the clonogenicity of the follicular epithelial SCs. We evaluated the global effect of GR on gene expression in a population of follicular SC-enriched bulge keratinocytes isolated by fluorescence activated cell sorting. We found that GR affected the expression of numerous bulge SC 'signature' genes, genes involved in the maintenance of SC and progenitor cells of non-epidermal origin and proapoptotic genes. Our findings underscore the important role of GR signaling in the homeostasis of follicular epithelial SCs, and suggest that the reduction in their number may underlie the tumor suppressor effect of GR in the skin.

Standard name | BERENJENO_ROCK_SIGNALING_NOT_VIA_RHOA_UP
Systematic name | M5392
Organism | Mus musculus
PMID | 17213802
Authors | Berenjeno IM,Núñez F,Bustelo XR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NIH3T3 cells (fibroblasts) after treatment with Y27632 [PubChem=123862], an inhibitor of ROCK proteins; the changes did not depend on expression of constitutively active (Q63L) form of RHOA [GeneID=387].
Full description | We have used microarray technology to identify the transcriptional targets of Rho subfamily guanosine 5'-triphosphate (GTP)ases in NIH3T3 cells. This analysis indicated that murine fibroblasts transformed by these proteins show similar transcriptomal profiles. Functional annotation of the regulated genes indicate that Rho subfamily GTPases target a wide spectrum of functions, although loci encoding proteins linked to proliferation and DNA synthesis/transcription are upregulated preferentially. Rho proteins promote four main networks of interacting proteins nucleated around E2F, c-Jun, c-Myc and p53. Of those, E2F, c-Jun and c-Myc are essential for the maintenance of cell transformation. Inhibition of Rock, one of the main Rho GTPase targets, leads to small changes in the transcriptome of Rho-transformed cells. Rock inhibition decreases c-myc gene expression without affecting the E2F and c-Jun pathways. Loss-of-function studies demonstrate that c-Myc is important for the blockage of cell-contact inhibition rather than for promoting the proliferation of Rho-transformed cells. However, c-Myc overexpression does not bypass the inhibition of cell transformation induced by Rock blockage, indicating that c-Myc is essential, but not sufficient, for Rock-dependent transformation. These results reveal the complexity of the genetic program orchestrated by the Rho subfamily and pinpoint protein networks that mediate different aspects of the malignant phenotype of Rho-transformed cells.

Standard name | BERENJENO_ROCK_SIGNALING_NOT_VIA_RHOA_DN
Systematic name | M10253
Organism | Mus musculus
PMID | 17213802
Authors | Berenjeno IM,Núñez F,Bustelo XR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NIH3T3 cells (fibroblasts) after treatment with Y27632 [PubChem=123862], an inhibitor of ROCK proteins; the changes did not depend on expression of constitutively active (Q63L) form of RHOA [GeneID=387].
Full description | We have used microarray technology to identify the transcriptional targets of Rho subfamily guanosine 5'-triphosphate (GTP)ases in NIH3T3 cells. This analysis indicated that murine fibroblasts transformed by these proteins show similar transcriptomal profiles. Functional annotation of the regulated genes indicate that Rho subfamily GTPases target a wide spectrum of functions, although loci encoding proteins linked to proliferation and DNA synthesis/transcription are upregulated preferentially. Rho proteins promote four main networks of interacting proteins nucleated around E2F, c-Jun, c-Myc and p53. Of those, E2F, c-Jun and c-Myc are essential for the maintenance of cell transformation. Inhibition of Rock, one of the main Rho GTPase targets, leads to small changes in the transcriptome of Rho-transformed cells. Rock inhibition decreases c-myc gene expression without affecting the E2F and c-Jun pathways. Loss-of-function studies demonstrate that c-Myc is important for the blockage of cell-contact inhibition rather than for promoting the proliferation of Rho-transformed cells. However, c-Myc overexpression does not bypass the inhibition of cell transformation induced by Rock blockage, indicating that c-Myc is essential, but not sufficient, for Rock-dependent transformation. These results reveal the complexity of the genetic program orchestrated by the Rho subfamily and pinpoint protein networks that mediate different aspects of the malignant phenotype of Rho-transformed cells.

Standard name | BERENJENO_TRANSFORMED_BY_RHOA_REVERSIBLY_UP
Systematic name | M16834
Organism | Mus musculus
PMID | 17213802
Authors | Berenjeno IM,Núñez F,Bustelo XR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NIH3T3 cells (fibroblasts) transformed by expression of contitutively active (Q63L) form of RHOA [GeneID=387] off plasmid vector; their expression reverted completely after treatment with Y27632 [PubChem=123862], an inhibitor of ROCK proteins.
Full description | We have used microarray technology to identify the transcriptional targets of Rho subfamily guanosine 5'-triphosphate (GTP)ases in NIH3T3 cells. This analysis indicated that murine fibroblasts transformed by these proteins show similar transcriptomal profiles. Functional annotation of the regulated genes indicate that Rho subfamily GTPases target a wide spectrum of functions, although loci encoding proteins linked to proliferation and DNA synthesis/transcription are upregulated preferentially. Rho proteins promote four main networks of interacting proteins nucleated around E2F, c-Jun, c-Myc and p53. Of those, E2F, c-Jun and c-Myc are essential for the maintenance of cell transformation. Inhibition of Rock, one of the main Rho GTPase targets, leads to small changes in the transcriptome of Rho-transformed cells. Rock inhibition decreases c-myc gene expression without affecting the E2F and c-Jun pathways. Loss-of-function studies demonstrate that c-Myc is important for the blockage of cell-contact inhibition rather than for promoting the proliferation of Rho-transformed cells. However, c-Myc overexpression does not bypass the inhibition of cell transformation induced by Rock blockage, indicating that c-Myc is essential, but not sufficient, for Rock-dependent transformation. These results reveal the complexity of the genetic program orchestrated by the Rho subfamily and pinpoint protein networks that mediate different aspects of the malignant phenotype of Rho-transformed cells.

Standard name | BERENJENO_TRANSFORMED_BY_RHOA_REVERSIBLY_DN
Systematic name | M3034
Organism | Mus musculus
PMID | 17213802
Authors | Berenjeno IM,Núñez F,Bustelo XR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NIH3T3 cells (fibroblasts) transformed by expression of contitutively active (Q63L) form of RHOA [GeneID=387] off plasmid vector; their expression reverted completely after treatment with Y27632 [PubChem=123862], an inhibitor of ROCK proteins.
Full description | We have used microarray technology to identify the transcriptional targets of Rho subfamily guanosine 5'-triphosphate (GTP)ases in NIH3T3 cells. This analysis indicated that murine fibroblasts transformed by these proteins show similar transcriptomal profiles. Functional annotation of the regulated genes indicate that Rho subfamily GTPases target a wide spectrum of functions, although loci encoding proteins linked to proliferation and DNA synthesis/transcription are upregulated preferentially. Rho proteins promote four main networks of interacting proteins nucleated around E2F, c-Jun, c-Myc and p53. Of those, E2F, c-Jun and c-Myc are essential for the maintenance of cell transformation. Inhibition of Rock, one of the main Rho GTPase targets, leads to small changes in the transcriptome of Rho-transformed cells. Rock inhibition decreases c-myc gene expression without affecting the E2F and c-Jun pathways. Loss-of-function studies demonstrate that c-Myc is important for the blockage of cell-contact inhibition rather than for promoting the proliferation of Rho-transformed cells. However, c-Myc overexpression does not bypass the inhibition of cell transformation induced by Rock blockage, indicating that c-Myc is essential, but not sufficient, for Rock-dependent transformation. These results reveal the complexity of the genetic program orchestrated by the Rho subfamily and pinpoint protein networks that mediate different aspects of the malignant phenotype of Rho-transformed cells.

Standard name | LINDGREN_BLADDER_CANCER_CLUSTER_1_UP
Systematic name | M2250
Organism | Homo sapiens
PMID | 16532037
Authors | Lindgren D,Liedberg F,Andersson A,Chebil G,Gudjonsson S,Borg A,Månsson W,Fioretos T,Höglund M
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes whose expression profile is specific to Custer I of urothelial cell carcinoma (UCC) tumors.
Full description | We used gene expression profiling, mutation analyses of FGFR3 and TP53, and LOH analyses of chromosome 9 and the TP53 region on chromosome arm 17p, to molecularly characterize 75 Ta and T1 bladder carcinomas. We identified four major cellular processes related to cell cycle, protein synthesis, immune response, and extra cellular components that contribute to the expressional heterogeneity of early-stage urothelial cell carcinoma (UCC). Activating FGFR3 mutations were found at the highest frequency in G1 tumors (80%), and showed a strong correlation with FGFR3 expression. In contrast, G3 tumors displayed mutations in less than 10% of the cases and a low level of FGFR3 expression. Even though LOH on chromosome 9 was not associated with any specific expression pattern, our data indicate that loss of chromosome 9 is associated with tumor development rather than initiation. The combined analyses suggest the existence of two types of UCC tumors, one which is characterized by FGFR3 mutation or expression, high expression of protein synthesis genes, and low expression of cell cycle genes. Furthermore, the presented data underscore FGFR3 receptor involvement in urothelial cell transformation as the presence of FGFR3 mutations has a major impact on the global gene expression profile of bladder carcinomas.

Standard name | LINDGREN_BLADDER_CANCER_CLUSTER_1_DN
Systematic name | M17788
Organism | Homo sapiens
PMID | 16532037
Authors | Lindgren D,Liedberg F,Andersson A,Chebil G,Gudjonsson S,Borg A,Månsson W,Fioretos T,Höglund M
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes whose expression profile is specific to Custer I of urothelial cell carcinoma (UCC) tumors.
Full description | We used gene expression profiling, mutation analyses of FGFR3 and TP53, and LOH analyses of chromosome 9 and the TP53 region on chromosome arm 17p, to molecularly characterize 75 Ta and T1 bladder carcinomas. We identified four major cellular processes related to cell cycle, protein synthesis, immune response, and extra cellular components that contribute to the expressional heterogeneity of early-stage urothelial cell carcinoma (UCC). Activating FGFR3 mutations were found at the highest frequency in G1 tumors (80%), and showed a strong correlation with FGFR3 expression. In contrast, G3 tumors displayed mutations in less than 10% of the cases and a low level of FGFR3 expression. Even though LOH on chromosome 9 was not associated with any specific expression pattern, our data indicate that loss of chromosome 9 is associated with tumor development rather than initiation. The combined analyses suggest the existence of two types of UCC tumors, one which is characterized by FGFR3 mutation or expression, high expression of protein synthesis genes, and low expression of cell cycle genes. Furthermore, the presented data underscore FGFR3 receptor involvement in urothelial cell transformation as the presence of FGFR3 mutations has a major impact on the global gene expression profile of bladder carcinomas.

Standard name | LINDGREN_BLADDER_CANCER_CLUSTER_2A_UP
Systematic name | M12889
Organism | Homo sapiens
PMID | 16532037
Authors | Lindgren D,Liedberg F,Andersson A,Chebil G,Gudjonsson S,Borg A,Månsson W,Fioretos T,Höglund M
Category | C2
Sub-category | CGP
Brief description | Genes whose expression profile is specific to Cluster IIa of urothelial cell carcinoma (UCC) tumors.
Full description | We used gene expression profiling, mutation analyses of FGFR3 and TP53, and LOH analyses of chromosome 9 and the TP53 region on chromosome arm 17p, to molecularly characterize 75 Ta and T1 bladder carcinomas. We identified four major cellular processes related to cell cycle, protein synthesis, immune response, and extra cellular components that contribute to the expressional heterogeneity of early-stage urothelial cell carcinoma (UCC). Activating FGFR3 mutations were found at the highest frequency in G1 tumors (80%), and showed a strong correlation with FGFR3 expression. In contrast, G3 tumors displayed mutations in less than 10% of the cases and a low level of FGFR3 expression. Even though LOH on chromosome 9 was not associated with any specific expression pattern, our data indicate that loss of chromosome 9 is associated with tumor development rather than initiation. The combined analyses suggest the existence of two types of UCC tumors, one which is characterized by FGFR3 mutation or expression, high expression of protein synthesis genes, and low expression of cell cycle genes. Furthermore, the presented data underscore FGFR3 receptor involvement in urothelial cell transformation as the presence of FGFR3 mutations has a major impact on the global gene expression profile of bladder carcinomas.

Standard name | LINDGREN_BLADDER_CANCER_CLUSTER_2A_DN
Systematic name | M11896
Organism | Homo sapiens
PMID | 16532037
Authors | Lindgren D,Liedberg F,Andersson A,Chebil G,Gudjonsson S,Borg A,Månsson W,Fioretos T,Höglund M
Category | C2
Sub-category | CGP
Brief description | Genes whose expression profile is specific to Cluster IIa of urothelial cell carcinoma (UCC) tumors.
Full description | We used gene expression profiling, mutation analyses of FGFR3 and TP53, and LOH analyses of chromosome 9 and the TP53 region on chromosome arm 17p, to molecularly characterize 75 Ta and T1 bladder carcinomas. We identified four major cellular processes related to cell cycle, protein synthesis, immune response, and extra cellular components that contribute to the expressional heterogeneity of early-stage urothelial cell carcinoma (UCC). Activating FGFR3 mutations were found at the highest frequency in G1 tumors (80%), and showed a strong correlation with FGFR3 expression. In contrast, G3 tumors displayed mutations in less than 10% of the cases and a low level of FGFR3 expression. Even though LOH on chromosome 9 was not associated with any specific expression pattern, our data indicate that loss of chromosome 9 is associated with tumor development rather than initiation. The combined analyses suggest the existence of two types of UCC tumors, one which is characterized by FGFR3 mutation or expression, high expression of protein synthesis genes, and low expression of cell cycle genes. Furthermore, the presented data underscore FGFR3 receptor involvement in urothelial cell transformation as the presence of FGFR3 mutations has a major impact on the global gene expression profile of bladder carcinomas.

Standard name | LINDGREN_BLADDER_CANCER_CLUSTER_3_UP
Systematic name | M854
Organism | Homo sapiens
PMID | 16532037
Authors | Lindgren D,Liedberg F,Andersson A,Chebil G,Gudjonsson S,Borg A,Månsson W,Fioretos T,Höglund M
Category | C2
Sub-category | CGP
Brief description | Genes whose expression profile is specific to Cluster III of urothelial cell carcinoma (UCC) tumors.
Full description | We used gene expression profiling, mutation analyses of FGFR3 and TP53, and LOH analyses of chromosome 9 and the TP53 region on chromosome arm 17p, to molecularly characterize 75 Ta and T1 bladder carcinomas. We identified four major cellular processes related to cell cycle, protein synthesis, immune response, and extra cellular components that contribute to the expressional heterogeneity of early-stage urothelial cell carcinoma (UCC). Activating FGFR3 mutations were found at the highest frequency in G1 tumors (80%), and showed a strong correlation with FGFR3 expression. In contrast, G3 tumors displayed mutations in less than 10% of the cases and a low level of FGFR3 expression. Even though LOH on chromosome 9 was not associated with any specific expression pattern, our data indicate that loss of chromosome 9 is associated with tumor development rather than initiation. The combined analyses suggest the existence of two types of UCC tumors, one which is characterized by FGFR3 mutation or expression, high expression of protein synthesis genes, and low expression of cell cycle genes. Furthermore, the presented data underscore FGFR3 receptor involvement in urothelial cell transformation as the presence of FGFR3 mutations has a major impact on the global gene expression profile of bladder carcinomas.

Standard name | LINDGREN_BLADDER_CANCER_CLUSTER_3_DN
Systematic name | M11238
Organism | Homo sapiens
PMID | 16532037
Authors | Lindgren D,Liedberg F,Andersson A,Chebil G,Gudjonsson S,Borg A,Månsson W,Fioretos T,Höglund M
Category | C2
Sub-category | CGP
Brief description | Genes whose expression profile is specific to Cluster III of urothelial cell carcinoma (UCC) tumors.
Full description | We used gene expression profiling, mutation analyses of FGFR3 and TP53, and LOH analyses of chromosome 9 and the TP53 region on chromosome arm 17p, to molecularly characterize 75 Ta and T1 bladder carcinomas. We identified four major cellular processes related to cell cycle, protein synthesis, immune response, and extra cellular components that contribute to the expressional heterogeneity of early-stage urothelial cell carcinoma (UCC). Activating FGFR3 mutations were found at the highest frequency in G1 tumors (80%), and showed a strong correlation with FGFR3 expression. In contrast, G3 tumors displayed mutations in less than 10% of the cases and a low level of FGFR3 expression. Even though LOH on chromosome 9 was not associated with any specific expression pattern, our data indicate that loss of chromosome 9 is associated with tumor development rather than initiation. The combined analyses suggest the existence of two types of UCC tumors, one which is characterized by FGFR3 mutation or expression, high expression of protein synthesis genes, and low expression of cell cycle genes. Furthermore, the presented data underscore FGFR3 receptor involvement in urothelial cell transformation as the presence of FGFR3 mutations has a major impact on the global gene expression profile of bladder carcinomas.

Standard name | KOINUMA_COLON_CANCER_MSI_UP
Systematic name | M1096
Organism | Homo sapiens
PMID | 16247484
Authors | Koinuma K,Yamashita Y,Liu W,Hatanaka H,Kurashina K,Wada T,Takada S,Kaneda R,Choi YL,Fujiwara SI,Miyakura Y,Nagai H,Mano H
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in colorectal carcinoma samples positive for MSI (microsatellite instability) compared to the MSI negative ones.
Full description | Mutation or epigenetic silencing of mismatch repair genes, such as MLH1 and MSH2, results in microsatellite instability (MSI) in the genome of a subset of colorectal carcinomas (CRCs). However, little is yet known of genes that directly contribute to tumor formation in such cancers. To characterize MSI-dependent changes in gene expression, we have now compared transcriptomes between fresh CRC specimens positive or negative for MSI (n=10 for each) with the use of high-density oligonucleotide microarrays harboring >44,000 probe sets. Correspondence analysis of the expression patterns of isolated MSI-associated genes revealed that the transcriptome of MSI+ CRCs is clearly distinct from that of MSI- CRCs. Such MSI-associated genes included that for AXIN2, an important component of the WNT signaling pathway. AXIN2 was silenced, apparently as a result of extensive methylation of its promoter region, specifically in MSI+ CRC specimens. Forced expression of AXIN2, either by treatment with 5'-azacytidine or by transfection with AXIN2 cDNA, resulted in rapid cell death in an MSI+ CRC cell line. These data indicate that epigenetic silencing of AXIN2 is specifically associated with carcinogenesis in MSI+ CRCs.

Standard name | KOINUMA_COLON_CANCER_MSI_DN
Systematic name | M1177
Organism | Homo sapiens
PMID | 16247484
Authors | Koinuma K,Yamashita Y,Liu W,Hatanaka H,Kurashina K,Wada T,Takada S,Kaneda R,Choi YL,Fujiwara SI,Miyakura Y,Nagai H,Mano H
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in colorectal carcinoma samples positive for MSI (microsatellite instability) compared to the MSI negative ones.
Full description | Mutation or epigenetic silencing of mismatch repair genes, such as MLH1 and MSH2, results in microsatellite instability (MSI) in the genome of a subset of colorectal carcinomas (CRCs). However, little is yet known of genes that directly contribute to tumor formation in such cancers. To characterize MSI-dependent changes in gene expression, we have now compared transcriptomes between fresh CRC specimens positive or negative for MSI (n=10 for each) with the use of high-density oligonucleotide microarrays harboring >44,000 probe sets. Correspondence analysis of the expression patterns of isolated MSI-associated genes revealed that the transcriptome of MSI+ CRCs is clearly distinct from that of MSI- CRCs. Such MSI-associated genes included that for AXIN2, an important component of the WNT signaling pathway. AXIN2 was silenced, apparently as a result of extensive methylation of its promoter region, specifically in MSI+ CRC specimens. Forced expression of AXIN2, either by treatment with 5'-azacytidine or by transfection with AXIN2 cDNA, resulted in rapid cell death in an MSI+ CRC cell line. These data indicate that epigenetic silencing of AXIN2 is specifically associated with carcinogenesis in MSI+ CRCs.

Standard name | CREIGHTON_AKT1_SIGNALING_VIA_MTOR_UP
Systematic name | M16515
Organism | Homo sapiens
PMID | 17213801
Authors | Creighton CJ
Category | C2
Sub-category | CGP
Brief description | Genes in the AKT1 [GeneID=207] pathway which are independent of MTOR [GeneID=2475], insensitive to RAD001 (everolimus) [PubChem=6442177].
Full description | The Akt pathway is commonly deregulated in many cancers. Clinical trials are currently underway to test the effectiveness of breast cancer treatment by inhibition of various Akt pathway intermediates. A set of genes induced by Akt in a transgenic mouse model, a subset of which were sensitive to mammalian target of rapamycin (mTOR) inhibitor RAD001, was examined in five public gene expression profile data sets of clinical breast tumor specimens (representing >1000 different samples in all). In each of the clinical data sets, the Akt mouse model genes as a group were significantly overexpressed in human tumors having high levels of AKT1 mRNA. The subset of genes both upregulated by Akt and dependent on mTOR activity were associated with estrogen receptor-negative status, higher grade, increasing tumor size and poor prognosis in multiple patient cohorts; these associations were either not present or not as strong for the Akt-induced, mTOR-independent genes or for AKT1 expression alone. The genes shown here to be relevant to Akt-mTOR both experimentally and pathologically have the potential for use in a molecular diagnostic to determine which patients should receive mTOR antagonist treatment.

Standard name | CREIGHTON_AKT1_SIGNALING_VIA_MTOR_DN
Systematic name | M15377
Organism | Homo sapiens
PMID | 17213801
Authors | Creighton CJ
Category | C2
Sub-category | CGP
Brief description | Genes in the AKT1 [GeneID=207] pathway which depend on MTOR [GeneID=2475], sensitive to RAD001 (everolimus) [PubChem=6442177].
Full description | The Akt pathway is commonly deregulated in many cancers. Clinical trials are currently underway to test the effectiveness of breast cancer treatment by inhibition of various Akt pathway intermediates. A set of genes induced by Akt in a transgenic mouse model, a subset of which were sensitive to mammalian target of rapamycin (mTOR) inhibitor RAD001, was examined in five public gene expression profile data sets of clinical breast tumor specimens (representing >1000 different samples in all). In each of the clinical data sets, the Akt mouse model genes as a group were significantly overexpressed in human tumors having high levels of AKT1 mRNA. The subset of genes both upregulated by Akt and dependent on mTOR activity were associated with estrogen receptor-negative status, higher grade, increasing tumor size and poor prognosis in multiple patient cohorts; these associations were either not present or not as strong for the Akt-induced, mTOR-independent genes or for AKT1 expression alone. The genes shown here to be relevant to Akt-mTOR both experimentally and pathologically have the potential for use in a molecular diagnostic to determine which patients should receive mTOR antagonist treatment.

Standard name | NADERI_BREAST_CANCER_PROGNOSIS_UP
Systematic name | M6862
Organism | Homo sapiens
PMID | 16936776
Authors | Naderi A,Teschendorff AE,Barbosa-Morais NL,Pinder SE,Green AR,Powe DG,Robertson JF,Aparicio S,Ellis IO,Brenton JD,Caldas C
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the breast cancer prognostic signature of 70 genes that significantly correlated with survival.
Full description | Prognostic signatures in breast cancer derived from microarray expression profiling have been reported by two independent groups. These signatures, however, have not been validated in external studies, making clinical application problematic. We performed microarray expression profiling of 135 early-stage tumors, from a cohort representative of the demographics of breast cancer. Using a recently proposed semisupervised method, we identified a prognostic signature of 70 genes that significantly correlated with survival (hazard ratio (HR): 5.97, 95% confidence interval: 3.0-11.9, P = 2.7e-07). In multivariate analysis, the signature performed independently of other standard prognostic classifiers such as the Nottingham Prognostic Index and the 'Adjuvant!' software. Using two different prognostic classification schemes and measures, nearest centroid (HR) and risk ordering (D-index), the 70-gene classifier was also found to be prognostic in two independent external data sets. Overall, the 70-gene set was prognostic in our study and the two external studies which collectively include 715 patients. In contrast, we found that the two previously described prognostic gene sets performed less optimally in external validation. Finally, a common prognostic module of 29 genes that associated with survival in both our cohort and the two external data sets was identified. In spite of these results, further studies that profile larger cohorts using a single microarray platform, will be needed before prospective clinical use of molecular classifiers can be contemplated.

Standard name | NADERI_BREAST_CANCER_PROGNOSIS_DN
Systematic name | M8629
Organism | Homo sapiens
PMID | 16936776
Authors | Naderi A,Teschendorff AE,Barbosa-Morais NL,Pinder SE,Green AR,Powe DG,Robertson JF,Aparicio S,Ellis IO,Brenton JD,Caldas C
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the breast cancer prognostic signature of 70 genes that significantly correlated with survival.
Full description | Prognostic signatures in breast cancer derived from microarray expression profiling have been reported by two independent groups. These signatures, however, have not been validated in external studies, making clinical application problematic. We performed microarray expression profiling of 135 early-stage tumors, from a cohort representative of the demographics of breast cancer. Using a recently proposed semisupervised method, we identified a prognostic signature of 70 genes that significantly correlated with survival (hazard ratio (HR): 5.97, 95% confidence interval: 3.0-11.9, P = 2.7e-07). In multivariate analysis, the signature performed independently of other standard prognostic classifiers such as the Nottingham Prognostic Index and the 'Adjuvant!' software. Using two different prognostic classification schemes and measures, nearest centroid (HR) and risk ordering (D-index), the 70-gene classifier was also found to be prognostic in two independent external data sets. Overall, the 70-gene set was prognostic in our study and the two external studies which collectively include 715 patients. In contrast, we found that the two previously described prognostic gene sets performed less optimally in external validation. Finally, a common prognostic module of 29 genes that associated with survival in both our cohort and the two external data sets was identified. In spite of these results, further studies that profile larger cohorts using a single microarray platform, will be needed before prospective clinical use of molecular classifiers can be contemplated.

Standard name | MARKEY_RB1_CHRONIC_LOF_UP
Systematic name | M2895
Organism | Mus musculus
PMID | 17452985
Authors | Markey MP,Bergseid J,Bosco EE,Stengel K,Xu H,Mayhew CN,Schwemberger SJ,Braden WA,Jiang Y,Babcock GF,Jegga AG,Aronow BJ,Reed MF,Wang JY,Knudsen ES
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblasts) isolated from RB1 [GeneID=5925] knockout mice: chronic loss of function (LOF) of RB1.
Full description | Functional inactivation of the retinoblastoma tumor suppressor gene product (RB) is a common event in human cancers. Classically, RB functions to constrain cellular proliferation, and loss of RB is proposed to facilitate the hyperplastic proliferation associated with tumorigenesis. To understand the repertoire of regulatory processes governed by RB, two models of RB loss were utilized to perform microarray analysis. In murine embryonic fibroblasts harboring germline loss of RB, there was a striking deregulation of gene expression, wherein distinct biological pathways were altered. Specifically, genes involved in cell cycle control and classically associated with E2F-dependent gene regulation were upregulated via RB loss. In contrast, a program of gene expression associated with immune function and response to pathogens was significantly downregulated with the loss of RB. To determine the specific influence of RB loss during a defined period and without the possibility of developmental compensation as occurs in embryonic fibroblasts, a second system was employed wherein Rb was acutely knocked out in adult fibroblasts. This model confirmed the distinct regulation of cell cycle and immune modulatory genes through RB loss. Analyses of cis-elements supported the hypothesis that the majority of those genes upregulated with RB loss are regulated via the E2F family of transcription factors. In contrast, those genes whose expression was reduced with the loss of RB harbored different promoter elements. Consistent with these analyses, we found that disruption of E2F-binding function of RB was associated with the upregulation of gene expression. In contrast, cells harboring an RB mutant protein (RB-750F) that retains E2F-binding activity, but is specifically deficient in the association with LXCXE-containing proteins, failed to upregulate these same target genes. However, downregulation of genes involved in immune function was readily observed with disruption of the LXCXE-binding function of RB. Thus, these studies demonstrate that RB plays a significant role in both the positive and negative regulations of transcriptional programs and indicate that loss of RB has distinct biological effects related to both cell cycle control and immune function.

Standard name | MARKEY_RB1_CHRONIC_LOF_DN
Systematic name | M5686
Organism | Mus musculus
PMID | 17452985
Authors | Markey MP,Bergseid J,Bosco EE,Stengel K,Xu H,Mayhew CN,Schwemberger SJ,Braden WA,Jiang Y,Babcock GF,Jegga AG,Aronow BJ,Reed MF,Wang JY,Knudsen ES
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblasts) isolated from RB1 [GeneID=5925] knockout mice: chronic loss of function (LOF) of RB1.
Full description | Functional inactivation of the retinoblastoma tumor suppressor gene product (RB) is a common event in human cancers. Classically, RB functions to constrain cellular proliferation, and loss of RB is proposed to facilitate the hyperplastic proliferation associated with tumorigenesis. To understand the repertoire of regulatory processes governed by RB, two models of RB loss were utilized to perform microarray analysis. In murine embryonic fibroblasts harboring germline loss of RB, there was a striking deregulation of gene expression, wherein distinct biological pathways were altered. Specifically, genes involved in cell cycle control and classically associated with E2F-dependent gene regulation were upregulated via RB loss. In contrast, a program of gene expression associated with immune function and response to pathogens was significantly downregulated with the loss of RB. To determine the specific influence of RB loss during a defined period and without the possibility of developmental compensation as occurs in embryonic fibroblasts, a second system was employed wherein Rb was acutely knocked out in adult fibroblasts. This model confirmed the distinct regulation of cell cycle and immune modulatory genes through RB loss. Analyses of cis-elements supported the hypothesis that the majority of those genes upregulated with RB loss are regulated via the E2F family of transcription factors. In contrast, those genes whose expression was reduced with the loss of RB harbored different promoter elements. Consistent with these analyses, we found that disruption of E2F-binding function of RB was associated with the upregulation of gene expression. In contrast, cells harboring an RB mutant protein (RB-750F) that retains E2F-binding activity, but is specifically deficient in the association with LXCXE-containing proteins, failed to upregulate these same target genes. However, downregulation of genes involved in immune function was readily observed with disruption of the LXCXE-binding function of RB. Thus, these studies demonstrate that RB plays a significant role in both the positive and negative regulations of transcriptional programs and indicate that loss of RB has distinct biological effects related to both cell cycle control and immune function.

Standard name | MARKEY_RB1_ACUTE_LOF_UP
Systematic name | M15606
Organism | Mus musculus
PMID | 17452985
Authors | Markey MP,Bergseid J,Bosco EE,Stengel K,Xu H,Mayhew CN,Schwemberger SJ,Braden WA,Jiang Y,Babcock GF,Jegga AG,Aronow BJ,Reed MF,Wang JY,Knudsen ES
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in adult fibroblasts with inactivated RB1 [GeneID=5925] by Cre-lox: acute loss of function (LOF) of RB1.
Full description | Functional inactivation of the retinoblastoma tumor suppressor gene product (RB) is a common event in human cancers. Classically, RB functions to constrain cellular proliferation, and loss of RB is proposed to facilitate the hyperplastic proliferation associated with tumorigenesis. To understand the repertoire of regulatory processes governed by RB, two models of RB loss were utilized to perform microarray analysis. In murine embryonic fibroblasts harboring germline loss of RB, there was a striking deregulation of gene expression, wherein distinct biological pathways were altered. Specifically, genes involved in cell cycle control and classically associated with E2F-dependent gene regulation were upregulated via RB loss. In contrast, a program of gene expression associated with immune function and response to pathogens was significantly downregulated with the loss of RB. To determine the specific influence of RB loss during a defined period and without the possibility of developmental compensation as occurs in embryonic fibroblasts, a second system was employed wherein Rb was acutely knocked out in adult fibroblasts. This model confirmed the distinct regulation of cell cycle and immune modulatory genes through RB loss. Analyses of cis-elements supported the hypothesis that the majority of those genes upregulated with RB loss are regulated via the E2F family of transcription factors. In contrast, those genes whose expression was reduced with the loss of RB harbored different promoter elements. Consistent with these analyses, we found that disruption of E2F-binding function of RB was associated with the upregulation of gene expression. In contrast, cells harboring an RB mutant protein (RB-750F) that retains E2F-binding activity, but is specifically deficient in the association with LXCXE-containing proteins, failed to upregulate these same target genes. However, downregulation of genes involved in immune function was readily observed with disruption of the LXCXE-binding function of RB. Thus, these studies demonstrate that RB plays a significant role in both the positive and negative regulations of transcriptional programs and indicate that loss of RB has distinct biological effects related to both cell cycle control and immune function.

Standard name | MARKEY_RB1_ACUTE_LOF_DN
Systematic name | M7094
Organism | Mus musculus
PMID | 17452985
Authors | Markey MP,Bergseid J,Bosco EE,Stengel K,Xu H,Mayhew CN,Schwemberger SJ,Braden WA,Jiang Y,Babcock GF,Jegga AG,Aronow BJ,Reed MF,Wang JY,Knudsen ES
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in adult fibroblasts with inactivated RB1 [GeneID=5925] by Cre-lox: acute loss of function (LOF) of RB1.
Full description | Functional inactivation of the retinoblastoma tumor suppressor gene product (RB) is a common event in human cancers. Classically, RB functions to constrain cellular proliferation, and loss of RB is proposed to facilitate the hyperplastic proliferation associated with tumorigenesis. To understand the repertoire of regulatory processes governed by RB, two models of RB loss were utilized to perform microarray analysis. In murine embryonic fibroblasts harboring germline loss of RB, there was a striking deregulation of gene expression, wherein distinct biological pathways were altered. Specifically, genes involved in cell cycle control and classically associated with E2F-dependent gene regulation were upregulated via RB loss. In contrast, a program of gene expression associated with immune function and response to pathogens was significantly downregulated with the loss of RB. To determine the specific influence of RB loss during a defined period and without the possibility of developmental compensation as occurs in embryonic fibroblasts, a second system was employed wherein Rb was acutely knocked out in adult fibroblasts. This model confirmed the distinct regulation of cell cycle and immune modulatory genes through RB loss. Analyses of cis-elements supported the hypothesis that the majority of those genes upregulated with RB loss are regulated via the E2F family of transcription factors. In contrast, those genes whose expression was reduced with the loss of RB harbored different promoter elements. Consistent with these analyses, we found that disruption of E2F-binding function of RB was associated with the upregulation of gene expression. In contrast, cells harboring an RB mutant protein (RB-750F) that retains E2F-binding activity, but is specifically deficient in the association with LXCXE-containing proteins, failed to upregulate these same target genes. However, downregulation of genes involved in immune function was readily observed with disruption of the LXCXE-binding function of RB. Thus, these studies demonstrate that RB plays a significant role in both the positive and negative regulations of transcriptional programs and indicate that loss of RB has distinct biological effects related to both cell cycle control and immune function.

Standard name | CHIN_BREAST_CANCER_COPY_NUMBER_UP
Systematic name | M672
Organism | Homo sapiens
PMID | 17001317
Authors | Chin SF,Wang Y,Thorne NP,Teschendorff AE,Pinder SE,Vias M,Naderi A,Roberts I,Barbosa-Morais NL,Garcia MJ,Iyer NG,Kranjac T,Robertson JF,Aparicio S,Tavaré S,Ellis I,Brenton JD,Caldas C
Category | C2
Sub-category | CGP
Brief description | Genes from common regions of gains observed in more than 15% of 148 primary breast cancer tumors.
Full description | We analysed 148 primary breast cancers using BAC-arrays containing 287 clones representing cancer-related gene/loci to obtain genomic molecular portraits. Gains were detected in 136 tumors (91.9%) and losses in 123 tumors (83.1%). Eight tumors (5.4%) did not have any genomic aberrations in the 281 clones analysed. Common (more than 15% of the samples) gains were observed at 8q11-qtel, 1q21-qtel, 17q11-q12 and 11q13, whereas common losses were observed at 16q12-qtel, 11ptel-p15.5, 1p36-ptel, 17p11.2-p12 and 8ptel-p22. Patients with tumors registering either less than 5% (median value) or less than 11% (third quartile) total copy number changes had a better overall survival (log-rank test: P=0.0417 and P=0.0375, respectively). Unsupervised hierarchical clustering based on copy number changes identified four clusters. Women with tumors from the cluster with amplification of three regions containing known breast oncogenes (11q13, 17q12 and 20q13) had a worse prognosis. The good prognosis group (Nottingham Prognostic Index (NPI) <or=3.4) tumors had frequent loss of 16q24-qtel. Genes significantly associated with estrogen receptor (ER), Grade and NPI were used to build k-nearest neighbor (KNN) classifiers that predicted ER, Grade and NPI status in the test set with an average misclassification rate of 24.7, 25.7 and 35.7%, respectively. These data raise the prospect of generating a molecular taxonomy of breast cancer based on copy number profiling using tumor DNA, which may be more generally applicable than expression microarray analysis.

Standard name | CHIN_BREAST_CANCER_COPY_NUMBER_DN
Systematic name | M8845
Organism | Homo sapiens
PMID | 17001317
Authors | Chin SF,Wang Y,Thorne NP,Teschendorff AE,Pinder SE,Vias M,Naderi A,Roberts I,Barbosa-Morais NL,Garcia MJ,Iyer NG,Kranjac T,Robertson JF,Aparicio S,Tavaré S,Ellis I,Brenton JD,Caldas C
Category | C2
Sub-category | CGP
Brief description | Genes from common regions of losses observed in more than 15% of 148 primary breast cancer tumors.
Full description | We analysed 148 primary breast cancers using BAC-arrays containing 287 clones representing cancer-related gene/loci to obtain genomic molecular portraits. Gains were detected in 136 tumors (91.9%) and losses in 123 tumors (83.1%). Eight tumors (5.4%) did not have any genomic aberrations in the 281 clones analysed. Common (more than 15% of the samples) gains were observed at 8q11-qtel, 1q21-qtel, 17q11-q12 and 11q13, whereas common losses were observed at 16q12-qtel, 11ptel-p15.5, 1p36-ptel, 17p11.2-p12 and 8ptel-p22. Patients with tumors registering either less than 5% (median value) or less than 11% (third quartile) total copy number changes had a better overall survival (log-rank test: P=0.0417 and P=0.0375, respectively). Unsupervised hierarchical clustering based on copy number changes identified four clusters. Women with tumors from the cluster with amplification of three regions containing known breast oncogenes (11q13, 17q12 and 20q13) had a worse prognosis. The good prognosis group (Nottingham Prognostic Index (NPI) <or=3.4) tumors had frequent loss of 16q24-qtel. Genes significantly associated with estrogen receptor (ER), Grade and NPI were used to build k-nearest neighbor (KNN) classifiers that predicted ER, Grade and NPI status in the test set with an average misclassification rate of 24.7, 25.7 and 35.7%, respectively. These data raise the prospect of generating a molecular taxonomy of breast cancer based on copy number profiling using tumor DNA, which may be more generally applicable than expression microarray analysis.

Standard name | GRAESSMANN_APOPTOSIS_BY_SERUM_DEPRIVATION_UP
Systematic name | M1097
Organism | Mus musculus
PMID | 17160024
Authors | Graessmann M,Berg B,Fuchs B,Klein A,Graessmann A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ME-A cells (breast cancer) undergoing apoptosis upon serum starvation (5% to 0% FCS) for 22 hr.
Full description | Impairment of the complex regulatory network of cell death and survival is frequently the reason for therapy resistance of breast cancer cells and a major cause of tumor progression. We established two independent cell lines from a fast growing mouse breast tumor (WAP-SVT/t transgenic animal). Cells from one line (ME-A cells) are sensitive to apoptotic stimuli such as growth factor depletion or treatment with antitumor agents (e.g. doxorubicin). Cells from the second line (ME-C cells), which carry a missense mutation at the p53 codon 242, are very insensitive to apoptotic stimuli. Co-cultivation experiments revealed that the ME-C cells mediate cell death resistance to the ME-A cells. Microarray and Western blot analysis showed that osteopontin (OPN) is selectively overexpressed by the ME-C cells. This glycoprotein is the most abundant protein secreted by the ME-C cells and we obtained strong indications that OPN is the main antiapoptotic factor. However, the OPN containing ME-C cell medium does not alter the expression level of pro- or antiapoptotic genes or known inhibitors of apoptosis (IAPs). Its signaling involves mitogen-activated protein kinase (MAPK)/extracellular signal-regulated kinase (ERK) kinase (MEK)1/2 as the kinase inhibitor PD98059 restores apoptosis but not the Akt inhibitor. In the ME-A cells, mitochondrial cytochrome c release occurs with and without external apoptotic stimuli. OPN containing ME-C cell medium does not prevent the mitochondrial cytochrome c release and caspase-9 processing. In serum starved ME-A cells, the OPN containing ME-C cell medium prevents caspase-3 activation. However, in doxorubicin-treated cells, although apoptosis is blocked, it does not inhibit caspase-3. This indicates that the ME-A cells distinguish between the initial apoptotic stimuli and that the cells possess a further uncharacterized control element acting downstream from caspase-3.

Standard name | GRAESSMANN_APOPTOSIS_BY_SERUM_DEPRIVATION_DN
Systematic name | M1098
Organism | Mus musculus
PMID | 17160024
Authors | Graessmann M,Berg B,Fuchs B,Klein A,Graessmann A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ME-A cells (breast cancer) undergoing apoptosis upon serum starvation (5% to 0% FCS) for 22 hr.
Full description | Impairment of the complex regulatory network of cell death and survival is frequently the reason for therapy resistance of breast cancer cells and a major cause of tumor progression. We established two independent cell lines from a fast growing mouse breast tumor (WAP-SVT/t transgenic animal). Cells from one line (ME-A cells) are sensitive to apoptotic stimuli such as growth factor depletion or treatment with antitumor agents (e.g. doxorubicin). Cells from the second line (ME-C cells), which carry a missense mutation at the p53 codon 242, are very insensitive to apoptotic stimuli. Co-cultivation experiments revealed that the ME-C cells mediate cell death resistance to the ME-A cells. Microarray and Western blot analysis showed that osteopontin (OPN) is selectively overexpressed by the ME-C cells. This glycoprotein is the most abundant protein secreted by the ME-C cells and we obtained strong indications that OPN is the main antiapoptotic factor. However, the OPN containing ME-C cell medium does not alter the expression level of pro- or antiapoptotic genes or known inhibitors of apoptosis (IAPs). Its signaling involves mitogen-activated protein kinase (MAPK)/extracellular signal-regulated kinase (ERK) kinase (MEK)1/2 as the kinase inhibitor PD98059 restores apoptosis but not the Akt inhibitor. In the ME-A cells, mitochondrial cytochrome c release occurs with and without external apoptotic stimuli. OPN containing ME-C cell medium does not prevent the mitochondrial cytochrome c release and caspase-9 processing. In serum starved ME-A cells, the OPN containing ME-C cell medium prevents caspase-3 activation. However, in doxorubicin-treated cells, although apoptosis is blocked, it does not inhibit caspase-3. This indicates that the ME-A cells distinguish between the initial apoptotic stimuli and that the cells possess a further uncharacterized control element acting downstream from caspase-3.

Standard name | VANHARANTA_UTERINE_FIBROID_UP
Systematic name | M18274
Organism | Homo sapiens
PMID | 15940248
Authors | Vanharanta S,Wortham NC,Laiho P,Sjöberg J,Aittomäki K,Arola J,Tomlinson IP,Karhu A,Arango D,Aaltonen LA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in uterine fibroids vs normal myometrium samples.
Full description | Uterine fibroids are some of the most common tumours of females, but relatively little is known about their molecular basis. Several studies have suggested that deletions on chromosome 7q could have a role in fibroid formation. We analysed 165 sporadic uterine fibroids to define a small 3.2 megabase (Mb) commonly deleted region on 7q22.3-q31.1, flanked by clones AC005070 and AC007567. We also used oligonucleotide microarrays to compare the expression profiles of 10 samples of normal myometrium and 15 fibroids, nine of which displayed 7q-deletions. Activating transcription factor 3, patched homolog (Drosophila), homeo box A5, death-associated protein kinase 1, and retinoic acid receptor responder 3 were downregulated, and excision repair crosscomplementing 3, transcription factor AP-2 gamma and protein kinase C beta 1 were upregulated in fibroids. New pathways were discovered related to fibroid formation. The presence or absence of 7q-deletions did not dramatically affect the global expression pattern of the tumours; changes, however, were observed in genes related to vesicular transport and nucleic acid binding.

Standard name | VANHARANTA_UTERINE_FIBROID_DN
Systematic name | M13879
Organism | Homo sapiens
PMID | 15940248
Authors | Vanharanta S,Wortham NC,Laiho P,Sjöberg J,Aittomäki K,Arola J,Tomlinson IP,Karhu A,Arango D,Aaltonen LA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in uterine fibroids vs normal myometrium samples.
Full description | Uterine fibroids are some of the most common tumours of females, but relatively little is known about their molecular basis. Several studies have suggested that deletions on chromosome 7q could have a role in fibroid formation. We analysed 165 sporadic uterine fibroids to define a small 3.2 megabase (Mb) commonly deleted region on 7q22.3-q31.1, flanked by clones AC005070 and AC007567. We also used oligonucleotide microarrays to compare the expression profiles of 10 samples of normal myometrium and 15 fibroids, nine of which displayed 7q-deletions. Activating transcription factor 3, patched homolog (Drosophila), homeo box A5, death-associated protein kinase 1, and retinoic acid receptor responder 3 were downregulated, and excision repair crosscomplementing 3, transcription factor AP-2 gamma and protein kinase C beta 1 were upregulated in fibroids. New pathways were discovered related to fibroid formation. The presence or absence of 7q-deletions did not dramatically affect the global expression pattern of the tumours; changes, however, were observed in genes related to vesicular transport and nucleic acid binding.

Standard name | VANHARANTA_UTERINE_FIBROID_WITH_7Q_DELETION_UP
Systematic name | M1752
Organism | Homo sapiens
PMID | 15940248
Authors | Vanharanta S,Wortham NC,Laiho P,Sjöberg J,Aittomäki K,Arola J,Tomlinson IP,Karhu A,Arango D,Aaltonen LA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in uterine fibroids with deletions in the 7q region vs those without the deletion.
Full description | Uterine fibroids are some of the most common tumours of females, but relatively little is known about their molecular basis. Several studies have suggested that deletions on chromosome 7q could have a role in fibroid formation. We analysed 165 sporadic uterine fibroids to define a small 3.2 megabase (Mb) commonly deleted region on 7q22.3-q31.1, flanked by clones AC005070 and AC007567. We also used oligonucleotide microarrays to compare the expression profiles of 10 samples of normal myometrium and 15 fibroids, nine of which displayed 7q-deletions. Activating transcription factor 3, patched homolog (Drosophila), homeo box A5, death-associated protein kinase 1, and retinoic acid receptor responder 3 were downregulated, and excision repair crosscomplementing 3, transcription factor AP-2 gamma and protein kinase C beta 1 were upregulated in fibroids. New pathways were discovered related to fibroid formation. The presence or absence of 7q-deletions did not dramatically affect the global expression pattern of the tumours; changes, however, were observed in genes related to vesicular transport and nucleic acid binding.

Standard name | VANHARANTA_UTERINE_FIBROID_WITH_7Q_DELETION_DN
Systematic name | M13327
Organism | Homo sapiens
PMID | 15940248
Authors | Vanharanta S,Wortham NC,Laiho P,Sjöberg J,Aittomäki K,Arola J,Tomlinson IP,Karhu A,Arango D,Aaltonen LA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in uterine fibroids with deletions in the 7q region vs those without the deletion.
Full description | Uterine fibroids are some of the most common tumours of females, but relatively little is known about their molecular basis. Several studies have suggested that deletions on chromosome 7q could have a role in fibroid formation. We analysed 165 sporadic uterine fibroids to define a small 3.2 megabase (Mb) commonly deleted region on 7q22.3-q31.1, flanked by clones AC005070 and AC007567. We also used oligonucleotide microarrays to compare the expression profiles of 10 samples of normal myometrium and 15 fibroids, nine of which displayed 7q-deletions. Activating transcription factor 3, patched homolog (Drosophila), homeo box A5, death-associated protein kinase 1, and retinoic acid receptor responder 3 were downregulated, and excision repair crosscomplementing 3, transcription factor AP-2 gamma and protein kinase C beta 1 were upregulated in fibroids. New pathways were discovered related to fibroid formation. The presence or absence of 7q-deletions did not dramatically affect the global expression pattern of the tumours; changes, however, were observed in genes related to vesicular transport and nucleic acid binding.

Standard name | LANDIS_ERBB2_BREAST_TUMORS_65_UP
Systematic name | M6384
Organism | Mus musculus
PMID | 15897883
Authors | Landis MD,Seachrist DD,Montañez-Wiscovich ME,Danielpour D,Keri RA
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the 65 most significantly changed (p<0.01) genes identified by two analytical methods in the mammary tumors induced by transgenic expression of ERBB2 [GeneID=2064].
Full description | Upregulation of HER2/ErbB2/Neu occurs in 15-30% of human breast cancers and correlates with poor prognosis. Identification of ErbB2/Neu transcriptional targets should facilitate development of novel therapeutic approaches. Development of breast cancer is a multistep process; thus, to identify the transcriptomes associated with different stages of progression of tumorigenesis, we compared expression profiles of mammary tumors and preneoplastic mammary tissue from MMTV-Neu transgenic mice to expression profiles of wild-type mammary glands using Affymetrix microarrays. We identified 324 candidate genes that were unique to ErbB2/Neu-induced tumors relative to normal mammary gland tissue from wild-type controls. Expression of a subset of these genes (82) was also changed in the preneoplastic mammary glands compared to wild-type controls, indicating that they may play a pivotal role during early events of ErbB2/Neu-initiated mammary tumorigenesis. Further analysis of the microarray data revealed that expression of several known transforming growth factor (TGF)-beta target genes was altered, suggesting that the TGF-beta signaling cascade is downregulated in ErbB2/Neu-induced tumors. Western blot analysis for TGF-beta-Receptor-I/ALK5 and immunohistochemistry for TGF-beta-Receptor-I/ALK5 and phosphorylated/activated Smad2 confirmed that the Smad-dependent TGF-beta signaling cascade was inactive in these tumors. Although absent in most of the tumor, phosphorylated Smad2 was present in the periphery of tumors. Interestingly, presence of phosphorylated/activated Smad2 correlated with expression of Activin-Receptor-IB/ALK4, suggesting that although Smad-dependent TGF-beta signaling is absent in ErbB2/Neu-induced tumors, Activin signaling may be active at the leading edge of these tumors. Cumulatively, these data indicate that the TGF-beta pathway is intrinsically suppressed in ErbB2/Neu tumors via a mechanism involving loss of TGF-beta-Receptor-I/ALK5.

Standard name | LANDIS_ERBB2_BREAST_TUMORS_65_DN
Systematic name | M13715
Organism | Mus musculus
PMID | 15897883
Authors | Landis MD,Seachrist DD,Montañez-Wiscovich ME,Danielpour D,Keri RA
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the 65 most significantly changed (p<0.01) genes identified by two analytical methods in the mammary tumors induced by transgenic expression of ERBB2 [GeneID=2064].
Full description | Upregulation of HER2/ErbB2/Neu occurs in 15-30% of human breast cancers and correlates with poor prognosis. Identification of ErbB2/Neu transcriptional targets should facilitate development of novel therapeutic approaches. Development of breast cancer is a multistep process; thus, to identify the transcriptomes associated with different stages of progression of tumorigenesis, we compared expression profiles of mammary tumors and preneoplastic mammary tissue from MMTV-Neu transgenic mice to expression profiles of wild-type mammary glands using Affymetrix microarrays. We identified 324 candidate genes that were unique to ErbB2/Neu-induced tumors relative to normal mammary gland tissue from wild-type controls. Expression of a subset of these genes (82) was also changed in the preneoplastic mammary glands compared to wild-type controls, indicating that they may play a pivotal role during early events of ErbB2/Neu-initiated mammary tumorigenesis. Further analysis of the microarray data revealed that expression of several known transforming growth factor (TGF)-beta target genes was altered, suggesting that the TGF-beta signaling cascade is downregulated in ErbB2/Neu-induced tumors. Western blot analysis for TGF-beta-Receptor-I/ALK5 and immunohistochemistry for TGF-beta-Receptor-I/ALK5 and phosphorylated/activated Smad2 confirmed that the Smad-dependent TGF-beta signaling cascade was inactive in these tumors. Although absent in most of the tumor, phosphorylated Smad2 was present in the periphery of tumors. Interestingly, presence of phosphorylated/activated Smad2 correlated with expression of Activin-Receptor-IB/ALK4, suggesting that although Smad-dependent TGF-beta signaling is absent in ErbB2/Neu-induced tumors, Activin signaling may be active at the leading edge of these tumors. Cumulatively, these data indicate that the TGF-beta pathway is intrinsically suppressed in ErbB2/Neu tumors via a mechanism involving loss of TGF-beta-Receptor-I/ALK5.

Standard name | LANDIS_ERBB2_BREAST_PRENEOPLASTIC_UP
Systematic name | M15209
Organism | Mus musculus
PMID | 15897883
Authors | Landis MD,Seachrist DD,Montañez-Wiscovich ME,Danielpour D,Keri RA
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from top 82 genes out of the 324-gene signature identified in the pre-neoplastic tissue adjacent to the mammary tumors induced by transgenic expression of ERBB2 [GeneID=2064].
Full description | Upregulation of HER2/ErbB2/Neu occurs in 15-30% of human breast cancers and correlates with poor prognosis. Identification of ErbB2/Neu transcriptional targets should facilitate development of novel therapeutic approaches. Development of breast cancer is a multistep process; thus, to identify the transcriptomes associated with different stages of progression of tumorigenesis, we compared expression profiles of mammary tumors and preneoplastic mammary tissue from MMTV-Neu transgenic mice to expression profiles of wild-type mammary glands using Affymetrix microarrays. We identified 324 candidate genes that were unique to ErbB2/Neu-induced tumors relative to normal mammary gland tissue from wild-type controls. Expression of a subset of these genes (82) was also changed in the preneoplastic mammary glands compared to wild-type controls, indicating that they may play a pivotal role during early events of ErbB2/Neu-initiated mammary tumorigenesis. Further analysis of the microarray data revealed that expression of several known transforming growth factor (TGF)-beta target genes was altered, suggesting that the TGF-beta signaling cascade is downregulated in ErbB2/Neu-induced tumors. Western blot analysis for TGF-beta-Receptor-I/ALK5 and immunohistochemistry for TGF-beta-Receptor-I/ALK5 and phosphorylated/activated Smad2 confirmed that the Smad-dependent TGF-beta signaling cascade was inactive in these tumors. Although absent in most of the tumor, phosphorylated Smad2 was present in the periphery of tumors. Interestingly, presence of phosphorylated/activated Smad2 correlated with expression of Activin-Receptor-IB/ALK4, suggesting that although Smad-dependent TGF-beta signaling is absent in ErbB2/Neu-induced tumors, Activin signaling may be active at the leading edge of these tumors. Cumulatively, these data indicate that the TGF-beta pathway is intrinsically suppressed in ErbB2/Neu tumors via a mechanism involving loss of TGF-beta-Receptor-I/ALK5.

Standard name | LANDIS_ERBB2_BREAST_PRENEOPLASTIC_DN
Systematic name | M13447
Organism | Mus musculus
PMID | 15897883
Authors | Landis MD,Seachrist DD,Montañez-Wiscovich ME,Danielpour D,Keri RA
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from top 82 genes out of the 324-gene signature identified in the pre-neoplastic tissue adjacent to the mammary tumors induced by transgenic expression of ERBB2 [GeneID=2064].
Full description | Upregulation of HER2/ErbB2/Neu occurs in 15-30% of human breast cancers and correlates with poor prognosis. Identification of ErbB2/Neu transcriptional targets should facilitate development of novel therapeutic approaches. Development of breast cancer is a multistep process; thus, to identify the transcriptomes associated with different stages of progression of tumorigenesis, we compared expression profiles of mammary tumors and preneoplastic mammary tissue from MMTV-Neu transgenic mice to expression profiles of wild-type mammary glands using Affymetrix microarrays. We identified 324 candidate genes that were unique to ErbB2/Neu-induced tumors relative to normal mammary gland tissue from wild-type controls. Expression of a subset of these genes (82) was also changed in the preneoplastic mammary glands compared to wild-type controls, indicating that they may play a pivotal role during early events of ErbB2/Neu-initiated mammary tumorigenesis. Further analysis of the microarray data revealed that expression of several known transforming growth factor (TGF)-beta target genes was altered, suggesting that the TGF-beta signaling cascade is downregulated in ErbB2/Neu-induced tumors. Western blot analysis for TGF-beta-Receptor-I/ALK5 and immunohistochemistry for TGF-beta-Receptor-I/ALK5 and phosphorylated/activated Smad2 confirmed that the Smad-dependent TGF-beta signaling cascade was inactive in these tumors. Although absent in most of the tumor, phosphorylated Smad2 was present in the periphery of tumors. Interestingly, presence of phosphorylated/activated Smad2 correlated with expression of Activin-Receptor-IB/ALK4, suggesting that although Smad-dependent TGF-beta signaling is absent in ErbB2/Neu-induced tumors, Activin signaling may be active at the leading edge of these tumors. Cumulatively, these data indicate that the TGF-beta pathway is intrinsically suppressed in ErbB2/Neu tumors via a mechanism involving loss of TGF-beta-Receptor-I/ALK5.

Standard name | CONCANNON_APOPTOSIS_BY_EPOXOMICIN_UP
Systematic name | M4716
Organism | Homo sapiens
PMID | 16983338
Authors | Concannon CG,Koehler BF,Reimertz C,Murphy BM,Bonner C,Thurow N,Ward MW,Villunger A,Strasser A,Kögel D,Prehn JH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SH-SY5Y cells (neuroblastoma) after treatment with epoxomicin [PubChem=3035402], a protease inhibitor causing apoptosis.
Full description | The proteasome has emerged as a novel target for antineoplastic treatment of hematological malignancies and solid tumors, including those of the central nervous system. To identify cell death pathways activated in response to inhibition of the proteasome system in cancer cells, we treated human SH-SY5Y neuroblastoma cells with the selective proteasome inhibitor (PI) epoxomicin (Epoxo). Prolonged exposure to Epoxo was associated with increased levels of poly-ubiquitinylated proteins and p53, release of cytochrome c from the mitochondria, and activation of caspases. Analysis of global gene expression using high-density oligonucleotide microarrays revealed that Epoxo triggered transcriptional activation of the two Bcl-2-homology domain-3-only (BH3-only) genes p53 upregulated modulator of apoptosis (PUMA) and Bim. Subsequent studies in PUMA- and Bim-deficient cells indicated that Epoxo-induced caspase activation and apoptosis was predominantly PUMA-dependent. Further characterization of the transcriptional response to Epoxo in HCT116 human colon cancer cells demonstrated that PUMA induction was p53-dependent; with deficiency in either p53 or PUMA significantly protected HCT116 cells against Epoxo-induced apoptosis. Our data suggest that p53 activation and the transcriptional induction of its target gene PUMA play an important role in the sensitivity of cancer cells to apoptosis induced by proteasome inhibition, and imply that antineoplastic therapies with PIs might be especially useful in cancers with functional p53.

Standard name | CONCANNON_APOPTOSIS_BY_EPOXOMICIN_DN
Systematic name | M16108
Organism | Homo sapiens
PMID | 16983338
Authors | Concannon CG,Koehler BF,Reimertz C,Murphy BM,Bonner C,Thurow N,Ward MW,Villunger A,Strasser A,Kögel D,Prehn JH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SH-SY5Y cells (neuroblastoma) after treatment with epoxomicin [PubChem=3035402], a protease inhibitor causing apoptosis.
Full description | The proteasome has emerged as a novel target for antineoplastic treatment of hematological malignancies and solid tumors, including those of the central nervous system. To identify cell death pathways activated in response to inhibition of the proteasome system in cancer cells, we treated human SH-SY5Y neuroblastoma cells with the selective proteasome inhibitor (PI) epoxomicin (Epoxo). Prolonged exposure to Epoxo was associated with increased levels of poly-ubiquitinylated proteins and p53, release of cytochrome c from the mitochondria, and activation of caspases. Analysis of global gene expression using high-density oligonucleotide microarrays revealed that Epoxo triggered transcriptional activation of the two Bcl-2-homology domain-3-only (BH3-only) genes p53 upregulated modulator of apoptosis (PUMA) and Bim. Subsequent studies in PUMA- and Bim-deficient cells indicated that Epoxo-induced caspase activation and apoptosis was predominantly PUMA-dependent. Further characterization of the transcriptional response to Epoxo in HCT116 human colon cancer cells demonstrated that PUMA induction was p53-dependent; with deficiency in either p53 or PUMA significantly protected HCT116 cells against Epoxo-induced apoptosis. Our data suggest that p53 activation and the transcriptional induction of its target gene PUMA play an important role in the sensitivity of cancer cells to apoptosis induced by proteasome inhibition, and imply that antineoplastic therapies with PIs might be especially useful in cancers with functional p53.

Standard name | ODONNELL_METASTASIS_UP
Systematic name | M265
Organism | Homo sapiens
PMID | 15558013
Authors | O'Donnell RK,Kupferman M,Wei SJ,Singhal S,Weber R,O'Malley B,Cheng Y,Putt M,Feldman M,Ziober B,Muschel RJ
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the signature set for lymph node metastasis in head and neck squamous cell carcinoma (HNSCC).
Full description | Metastasis via the lymphatics is a major risk factor in squamous cell carcinoma of the oral cavity (OSCC). We sought to determine whether the presence of metastasis in the regional lymph node could be predicted by a gene expression signature of the primary tumor. A total of 18 OSCCs were characterized for gene expression by hybridizing RNA to Affymetrix U133A gene chips. Genes with differential expression were identified using a permutation technique and verified by quantitative RT-PCR and immunohistochemistry. A predictive rule was built using a support vector machine, and the accuracy of the rule was evaluated using crossvalidation on the original data set and prediction of an independent set of four patients. Metastatic primary tumors could be differentiated from nonmetastatic primary tumors by a signature gene set of 116 genes. This signature gene set correctly predicted the four independent patients as well as associating five lymph node metastases from the original patient set with the metastatic primary tumor group. We concluded that lymph node metastasis could be predicted by gene expression profiles of primary oral cavity squamous cell carcinomas. The presence of a gene expression signature for lymph node metastasis indicates that clinical testing to assess risk for lymph node metastasis should be possible.

Standard name | ODONNELL_METASTASIS_DN
Systematic name | M6311
Organism | Homo sapiens
PMID | 15558013
Authors | O'Donnell RK,Kupferman M,Wei SJ,Singhal S,Weber R,O'Malley B,Cheng Y,Putt M,Feldman M,Ziober B,Muschel RJ
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the signature set for lymph node metastasis in head and neck squamous cell carcinoma (HNSCC).
Full description | Metastasis via the lymphatics is a major risk factor in squamous cell carcinoma of the oral cavity (OSCC). We sought to determine whether the presence of metastasis in the regional lymph node could be predicted by a gene expression signature of the primary tumor. A total of 18 OSCCs were characterized for gene expression by hybridizing RNA to Affymetrix U133A gene chips. Genes with differential expression were identified using a permutation technique and verified by quantitative RT-PCR and immunohistochemistry. A predictive rule was built using a support vector machine, and the accuracy of the rule was evaluated using crossvalidation on the original data set and prediction of an independent set of four patients. Metastatic primary tumors could be differentiated from nonmetastatic primary tumors by a signature gene set of 116 genes. This signature gene set correctly predicted the four independent patients as well as associating five lymph node metastases from the original patient set with the metastatic primary tumor group. We concluded that lymph node metastasis could be predicted by gene expression profiles of primary oral cavity squamous cell carcinomas. The presence of a gene expression signature for lymph node metastasis indicates that clinical testing to assess risk for lymph node metastasis should be possible.

Standard name | GRAESSMANN_RESPONSE_TO_MC_AND_SERUM_DEPRIVATION_UP
Systematic name | M1099
Organism | Mus musculus
PMID | 17160024
Authors | Graessmann M,Berg B,Fuchs B,Klein A,Graessmann A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ME-A cells (breast cancer, sensitive to apoptotic stimuli) upon serum deprivation for 22 hr in the presence of medium concentrate (MC) from ME-C cells (breast cancer, resistant to apoptotic stimuli).
Full description | Impairment of the complex regulatory network of cell death and survival is frequently the reason for therapy resistance of breast cancer cells and a major cause of tumor progression. We established two independent cell lines from a fast growing mouse breast tumor (WAP-SVT/t transgenic animal). Cells from one line (ME-A cells) are sensitive to apoptotic stimuli such as growth factor depletion or treatment with antitumor agents (e.g. doxorubicin). Cells from the second line (ME-C cells), which carry a missense mutation at the p53 codon 242, are very insensitive to apoptotic stimuli. Co-cultivation experiments revealed that the ME-C cells mediate cell death resistance to the ME-A cells. Microarray and Western blot analysis showed that osteopontin (OPN) is selectively overexpressed by the ME-C cells. This glycoprotein is the most abundant protein secreted by the ME-C cells and we obtained strong indications that OPN is the main antiapoptotic factor. However, the OPN containing ME-C cell medium does not alter the expression level of pro- or antiapoptotic genes or known inhibitors of apoptosis (IAPs). Its signaling involves mitogen-activated protein kinase (MAPK)/extracellular signal-regulated kinase (ERK) kinase (MEK)1/2 as the kinase inhibitor PD98059 restores apoptosis but not the Akt inhibitor. In the ME-A cells, mitochondrial cytochrome c release occurs with and without external apoptotic stimuli. OPN containing ME-C cell medium does not prevent the mitochondrial cytochrome c release and caspase-9 processing. In serum starved ME-A cells, the OPN containing ME-C cell medium prevents caspase-3 activation. However, in doxorubicin-treated cells, although apoptosis is blocked, it does not inhibit caspase-3. This indicates that the ME-A cells distinguish between the initial apoptotic stimuli and that the cells possess a further uncharacterized control element acting downstream from caspase-3.

Standard name | GRAESSMANN_RESPONSE_TO_MC_AND_SERUM_DEPRIVATION_DN
Systematic name | M1102
Organism | Mus musculus
PMID | 17160024
Authors | Graessmann M,Berg B,Fuchs B,Klein A,Graessmann A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ME-A cells (breast cancer, sensitive to apoptotic stimuli) upon serum deprivation for 22 hr in the presence of medium concentrate (MC) from ME-C cells (breast cancer, resistant to apoptotic stimuli).
Full description | Impairment of the complex regulatory network of cell death and survival is frequently the reason for therapy resistance of breast cancer cells and a major cause of tumor progression. We established two independent cell lines from a fast growing mouse breast tumor (WAP-SVT/t transgenic animal). Cells from one line (ME-A cells) are sensitive to apoptotic stimuli such as growth factor depletion or treatment with antitumor agents (e.g. doxorubicin). Cells from the second line (ME-C cells), which carry a missense mutation at the p53 codon 242, are very insensitive to apoptotic stimuli. Co-cultivation experiments revealed that the ME-C cells mediate cell death resistance to the ME-A cells. Microarray and Western blot analysis showed that osteopontin (OPN) is selectively overexpressed by the ME-C cells. This glycoprotein is the most abundant protein secreted by the ME-C cells and we obtained strong indications that OPN is the main antiapoptotic factor. However, the OPN containing ME-C cell medium does not alter the expression level of pro- or antiapoptotic genes or known inhibitors of apoptosis (IAPs). Its signaling involves mitogen-activated protein kinase (MAPK)/extracellular signal-regulated kinase (ERK) kinase (MEK)1/2 as the kinase inhibitor PD98059 restores apoptosis but not the Akt inhibitor. In the ME-A cells, mitochondrial cytochrome c release occurs with and without external apoptotic stimuli. OPN containing ME-C cell medium does not prevent the mitochondrial cytochrome c release and caspase-9 processing. In serum starved ME-A cells, the OPN containing ME-C cell medium prevents caspase-3 activation. However, in doxorubicin-treated cells, although apoptosis is blocked, it does not inhibit caspase-3. This indicates that the ME-A cells distinguish between the initial apoptotic stimuli and that the cells possess a further uncharacterized control element acting downstream from caspase-3.

Standard name | GRAESSMANN_APOPTOSIS_BY_DOXORUBICIN_UP
Systematic name | M1103
Organism | Mus musculus
PMID | 17160024
Authors | Graessmann M,Berg B,Fuchs B,Klein A,Graessmann A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ME-A cells (breast cancer) undergoing apoptosis in response to doxorubicin [PubChem=31703].
Full description | Impairment of the complex regulatory network of cell death and survival is frequently the reason for therapy resistance of breast cancer cells and a major cause of tumor progression. We established two independent cell lines from a fast growing mouse breast tumor (WAP-SVT/t transgenic animal). Cells from one line (ME-A cells) are sensitive to apoptotic stimuli such as growth factor depletion or treatment with antitumor agents (e.g. doxorubicin). Cells from the second line (ME-C cells), which carry a missense mutation at the p53 codon 242, are very insensitive to apoptotic stimuli. Co-cultivation experiments revealed that the ME-C cells mediate cell death resistance to the ME-A cells. Microarray and Western blot analysis showed that osteopontin (OPN) is selectively overexpressed by the ME-C cells. This glycoprotein is the most abundant protein secreted by the ME-C cells and we obtained strong indications that OPN is the main antiapoptotic factor. However, the OPN containing ME-C cell medium does not alter the expression level of pro- or antiapoptotic genes or known inhibitors of apoptosis (IAPs). Its signaling involves mitogen-activated protein kinase (MAPK)/extracellular signal-regulated kinase (ERK) kinase (MEK)1/2 as the kinase inhibitor PD98059 restores apoptosis but not the Akt inhibitor. In the ME-A cells, mitochondrial cytochrome c release occurs with and without external apoptotic stimuli. OPN containing ME-C cell medium does not prevent the mitochondrial cytochrome c release and caspase-9 processing. In serum starved ME-A cells, the OPN containing ME-C cell medium prevents caspase-3 activation. However, in doxorubicin-treated cells, although apoptosis is blocked, it does not inhibit caspase-3. This indicates that the ME-A cells distinguish between the initial apoptotic stimuli and that the cells possess a further uncharacterized control element acting downstream from caspase-3.

Standard name | GRAESSMANN_APOPTOSIS_BY_DOXORUBICIN_DN
Systematic name | M1105
Organism | Mus musculus
PMID | 17160024
Authors | Graessmann M,Berg B,Fuchs B,Klein A,Graessmann A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ME-A cells (breast cancer) undergoing apoptosis in response to doxorubicin [PubChem=31703].
Full description | Impairment of the complex regulatory network of cell death and survival is frequently the reason for therapy resistance of breast cancer cells and a major cause of tumor progression. We established two independent cell lines from a fast growing mouse breast tumor (WAP-SVT/t transgenic animal). Cells from one line (ME-A cells) are sensitive to apoptotic stimuli such as growth factor depletion or treatment with antitumor agents (e.g. doxorubicin). Cells from the second line (ME-C cells), which carry a missense mutation at the p53 codon 242, are very insensitive to apoptotic stimuli. Co-cultivation experiments revealed that the ME-C cells mediate cell death resistance to the ME-A cells. Microarray and Western blot analysis showed that osteopontin (OPN) is selectively overexpressed by the ME-C cells. This glycoprotein is the most abundant protein secreted by the ME-C cells and we obtained strong indications that OPN is the main antiapoptotic factor. However, the OPN containing ME-C cell medium does not alter the expression level of pro- or antiapoptotic genes or known inhibitors of apoptosis (IAPs). Its signaling involves mitogen-activated protein kinase (MAPK)/extracellular signal-regulated kinase (ERK) kinase (MEK)1/2 as the kinase inhibitor PD98059 restores apoptosis but not the Akt inhibitor. In the ME-A cells, mitochondrial cytochrome c release occurs with and without external apoptotic stimuli. OPN containing ME-C cell medium does not prevent the mitochondrial cytochrome c release and caspase-9 processing. In serum starved ME-A cells, the OPN containing ME-C cell medium prevents caspase-3 activation. However, in doxorubicin-treated cells, although apoptosis is blocked, it does not inhibit caspase-3. This indicates that the ME-A cells distinguish between the initial apoptotic stimuli and that the cells possess a further uncharacterized control element acting downstream from caspase-3.

Standard name | GRAESSMANN_RESPONSE_TO_MC_AND_DOXORUBICIN_UP
Systematic name | M1106
Organism | Mus musculus
PMID | 17160024
Authors | Graessmann M,Berg B,Fuchs B,Klein A,Graessmann A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ME-A cells (breast cancer, sensitive to apoptotic stimuli) exposed to doxorubicin [PubChem=31703] in the presence of medium concentrate (MC) from ME-C cells (breast cancer, resistant to apoptotic stimuli).
Full description | Impairment of the complex regulatory network of cell death and survival is frequently the reason for therapy resistance of breast cancer cells and a major cause of tumor progression. We established two independent cell lines from a fast growing mouse breast tumor (WAP-SVT/t transgenic animal). Cells from one line (ME-A cells) are sensitive to apoptotic stimuli such as growth factor depletion or treatment with antitumor agents (e.g. doxorubicin). Cells from the second line (ME-C cells), which carry a missense mutation at the p53 codon 242, are very insensitive to apoptotic stimuli. Co-cultivation experiments revealed that the ME-C cells mediate cell death resistance to the ME-A cells. Microarray and Western blot analysis showed that osteopontin (OPN) is selectively overexpressed by the ME-C cells. This glycoprotein is the most abundant protein secreted by the ME-C cells and we obtained strong indications that OPN is the main antiapoptotic factor. However, the OPN containing ME-C cell medium does not alter the expression level of pro- or antiapoptotic genes or known inhibitors of apoptosis (IAPs). Its signaling involves mitogen-activated protein kinase (MAPK)/extracellular signal-regulated kinase (ERK) kinase (MEK)1/2 as the kinase inhibitor PD98059 restores apoptosis but not the Akt inhibitor. In the ME-A cells, mitochondrial cytochrome c release occurs with and without external apoptotic stimuli. OPN containing ME-C cell medium does not prevent the mitochondrial cytochrome c release and caspase-9 processing. In serum starved ME-A cells, the OPN containing ME-C cell medium prevents caspase-3 activation. However, in doxorubicin-treated cells, although apoptosis is blocked, it does not inhibit caspase-3. This indicates that the ME-A cells distinguish between the initial apoptotic stimuli and that the cells possess a further uncharacterized control element acting downstream from caspase-3.

Standard name | GRAESSMANN_RESPONSE_TO_MC_AND_DOXORUBICIN_DN
Systematic name | M1107
Organism | Mus musculus
PMID | 17160024
Authors | Graessmann M,Berg B,Fuchs B,Klein A,Graessmann A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ME-A cells (breast cancer, sensitive to apoptotic stimuli) exposed to doxorubicin [PubChem=31703] in the presence of medium concentrate (MC) from ME-C cells (breast cancer, resistant to apoptotic stimuli).
Full description | Impairment of the complex regulatory network of cell death and survival is frequently the reason for therapy resistance of breast cancer cells and a major cause of tumor progression. We established two independent cell lines from a fast growing mouse breast tumor (WAP-SVT/t transgenic animal). Cells from one line (ME-A cells) are sensitive to apoptotic stimuli such as growth factor depletion or treatment with antitumor agents (e.g. doxorubicin). Cells from the second line (ME-C cells), which carry a missense mutation at the p53 codon 242, are very insensitive to apoptotic stimuli. Co-cultivation experiments revealed that the ME-C cells mediate cell death resistance to the ME-A cells. Microarray and Western blot analysis showed that osteopontin (OPN) is selectively overexpressed by the ME-C cells. This glycoprotein is the most abundant protein secreted by the ME-C cells and we obtained strong indications that OPN is the main antiapoptotic factor. However, the OPN containing ME-C cell medium does not alter the expression level of pro- or antiapoptotic genes or known inhibitors of apoptosis (IAPs). Its signaling involves mitogen-activated protein kinase (MAPK)/extracellular signal-regulated kinase (ERK) kinase (MEK)1/2 as the kinase inhibitor PD98059 restores apoptosis but not the Akt inhibitor. In the ME-A cells, mitochondrial cytochrome c release occurs with and without external apoptotic stimuli. OPN containing ME-C cell medium does not prevent the mitochondrial cytochrome c release and caspase-9 processing. In serum starved ME-A cells, the OPN containing ME-C cell medium prevents caspase-3 activation. However, in doxorubicin-treated cells, although apoptosis is blocked, it does not inhibit caspase-3. This indicates that the ME-A cells distinguish between the initial apoptotic stimuli and that the cells possess a further uncharacterized control element acting downstream from caspase-3.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_A_UP
Systematic name | M1110
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the set A (Fig. 5a): specific to cells expressing MLL-AF4 [GeneID=4297;4299] fusion protein alone.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_A_DN
Systematic name | M1111
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the set A (Fig. 5a): specific to cells expressing MLL-AF4 [GeneID=4297;4299] fusion protein alone.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_B_UP
Systematic name | M14833
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the set B (Fig. 5a): specific signature shared by cells expressing either AF4-MLL or MLL-AF4 [GeneID=4299;4297] fusion proteins.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_B_DN
Systematic name | M9012
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the set B (Fig. 5a): specific signature shared by cells expressing either AF4-MLL or MLL-AF4 [GeneID=4299;4297] fusion proteins.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_C_UP
Systematic name | M1113
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the set C (Fig. 5a): specific to cells expressing AF4-MLL [GeneID=4299;4297] fusion protein alone.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_C_DN
Systematic name | M1115
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the set C (Fig. 5a): specific to cells expressing AF4-MLL [GeneID=4299;4297] fusion protein alone.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_D_UP
Systematic name | M1801
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the set D (Fig. 5a): specific signature shared by cells expressing MLL-AF4 [GeneID=4297;4299] alone and those expressing both MLL-AF4 and AF4-MLL fusion proteins.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_D_DN
Systematic name | M527
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the set D (Fig. 5a): specific signature shared by cells expressing MLL-AF4 [GeneID=4297;4299] alone and those expressing both MLL-AF4 and AF4-MLL fusion proteins.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_E_UP
Systematic name | M11319
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the set E (Fig. 5a): specific signature shared by cells expressing either MLL-AF4 [GeneID=4297;4299] or AF4-MLL fusion proteins alone, and those expressing both fusion proteins.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_E_DN
Systematic name | M2039
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the set E (Fig. 5a): specific signature shared by cells expressing either MLL-AF4 [GeneID=4297;4299] or AF4-MLL fusion proteins alone, and those expressing both fusion proteins.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_F_UP
Systematic name | M8544
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Up-regualted genes from the set F (Fig. 5a): specific signature shared by cells expressing AF4-MLL [GeneID=4299;4297] alone and those expressing both AF4-MLL and MLL-AF4 fusion proteins.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_F_DN
Systematic name | M588
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Down-regualted genes from the set F (Fig. 5a): specific signature shared by cells expressing AF4-MLL [GeneID=4299;4297] alone and those expressing both AF4-MLL and MLL-AF4 fusion proteins.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_G_UP
Systematic name | M18095
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the set G (Fig. 5a): specific to cells expressing both MLL-AF4 [GeneID=4297;4299] and AF4-MLL fusion proteins.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | GAUSSMANN_MLL_AF4_FUSION_TARGETS_G_DN
Systematic name | M11023
Organism | Mus musculus
PMID | 17130830
Authors | Gaussmann A,Wenger T,Eberle I,Bursen A,Bracharz S,Herr I,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the set G (Fig. 5a): specific to cells expressing both MLL-AF4 [GeneID=4297;4299] and AF4-MLL fusion proteins.
Full description | The reciprocal chromosomal translocation t(4;11) is correlated with infant, childhood, adult and therapy-related high-risk acute leukemia. Here, we investigated the biological effects of MLL.AF4, AF4.MLL or the combination of both reciprocal fusion proteins in a conditional in vitro cell culture model system. Several parameters like cell growth, cell cycling capacity, apoptotic behavior and growth transformation were investigated under physiological and stress conditions. Co-transfected cells displayed the highest resistance against apoptotic triggers, cell cycling capacity and loss-of-contact inhibition. These analyses were complemented by gene expression profiling experiments and specific gene signatures were established for each of the three cell lines. Interestingly, co-transfected cells strongly upregulate the homeobox gene Nanog. In combination with Oct4, the Nanog homeoprotein is steering maintenance of pluripotency and self-renewal in embryonic stem cells. Transcription of Nanog and other stem cell factors, like Oct4 and Bmi1, was verified in biopsy material of t(4;11) patient cells which express both reciprocal t(4;11) fusion genes. In conclusion, the presence of both reciprocal MLL fusion proteins confers biological properties known from t(4;11) leukemia, suggesting that each of the two fusion proteins contribute specific properties and, in combination, also synergistic effects to the leukemic phenotype.

Standard name | BERENJENO_TRANSFORMED_BY_RHOA_FOREVER_UP
Systematic name | M7919
Organism | Mus musculus
PMID | 17213802
Authors | Berenjeno IM,Núñez F,Bustelo XR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NIH3T3 cells (fibroblasts) transfrormed by expression of constitutively active (Q63L) form of RHOA [GeneID=387] off plasmid vector; their expression did NOT reverted completely after treatment with Y27632 [PubChem=123862], an inhibitor of ROCK proteins.
Full description | We have used microarray technology to identify the transcriptional targets of Rho subfamily guanosine 5'-triphosphate (GTP)ases in NIH3T3 cells. This analysis indicated that murine fibroblasts transformed by these proteins show similar transcriptomal profiles. Functional annotation of the regulated genes indicate that Rho subfamily GTPases target a wide spectrum of functions, although loci encoding proteins linked to proliferation and DNA synthesis/transcription are upregulated preferentially. Rho proteins promote four main networks of interacting proteins nucleated around E2F, c-Jun, c-Myc and p53. Of those, E2F, c-Jun and c-Myc are essential for the maintenance of cell transformation. Inhibition of Rock, one of the main Rho GTPase targets, leads to small changes in the transcriptome of Rho-transformed cells. Rock inhibition decreases c-myc gene expression without affecting the E2F and c-Jun pathways. Loss-of-function studies demonstrate that c-Myc is important for the blockage of cell-contact inhibition rather than for promoting the proliferation of Rho-transformed cells. However, c-Myc overexpression does not bypass the inhibition of cell transformation induced by Rock blockage, indicating that c-Myc is essential, but not sufficient, for Rock-dependent transformation. These results reveal the complexity of the genetic program orchestrated by the Rho subfamily and pinpoint protein networks that mediate different aspects of the malignant phenotype of Rho-transformed cells.

Standard name | BERENJENO_TRANSFORMED_BY_RHOA_FOREVER_DN
Systematic name | M16101
Organism | Mus musculus
PMID | 17213802
Authors | Berenjeno IM,Núñez F,Bustelo XR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NIH3T3 cells (fibroblasts) transfrormed by expression of constitutively active (Q63L) form of RHOA [GeneID=387] off plasmid vector; their expression did NOT reverted completely after treatment with Y27632 [PubChem=123862], an inhibitor of ROCK proteins.
Full description | We have used microarray technology to identify the transcriptional targets of Rho subfamily guanosine 5'-triphosphate (GTP)ases in NIH3T3 cells. This analysis indicated that murine fibroblasts transformed by these proteins show similar transcriptomal profiles. Functional annotation of the regulated genes indicate that Rho subfamily GTPases target a wide spectrum of functions, although loci encoding proteins linked to proliferation and DNA synthesis/transcription are upregulated preferentially. Rho proteins promote four main networks of interacting proteins nucleated around E2F, c-Jun, c-Myc and p53. Of those, E2F, c-Jun and c-Myc are essential for the maintenance of cell transformation. Inhibition of Rock, one of the main Rho GTPase targets, leads to small changes in the transcriptome of Rho-transformed cells. Rock inhibition decreases c-myc gene expression without affecting the E2F and c-Jun pathways. Loss-of-function studies demonstrate that c-Myc is important for the blockage of cell-contact inhibition rather than for promoting the proliferation of Rho-transformed cells. However, c-Myc overexpression does not bypass the inhibition of cell transformation induced by Rock blockage, indicating that c-Myc is essential, but not sufficient, for Rock-dependent transformation. These results reveal the complexity of the genetic program orchestrated by the Rho subfamily and pinpoint protein networks that mediate different aspects of the malignant phenotype of Rho-transformed cells.

Standard name | CAIRO_PML_TARGETS_BOUND_BY_MYC_UP
Systematic name | M1116
Organism | Mus musculus
PMID | 15735755
Authors | Cairo S,De Falco F,Pizzo M,Salomoni P,Pandolfi PP,Meroni G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblasts) after knockout of PML [GeneID=5371] and whose promoters were bound by MYC [GeneID=4609].
Full description | c-myc is a well-known proto-oncogene encoding for a transcription factor that needs to be tightly regulated in order to preserve cell homeostasis. The Promyelocytic Leukaemia gene product PML plays an important role in cell growth and survival, and resides in discrete subnuclear structures called Nuclear Bodies (NB). We performed comparative analysis of the expression of 40 Myc target genes and of Myc binding to their regulatory regions both in wild-type and PML knockout cells. We demonstrate that if PML is absent, despite Myc binding to the DNA regulatory sequences is unchanged, the expression profile of several Myc target genes is altered. PML is largely involved in gene regulation, via recruitment of several transcription factors and cofactors to the NB. Consistently, we show that Myc partially localizes to the NB and physically interacts with PML, and that this localization depends on Myc expression levels. As deregulation occurs to both activated and repressed Myc target genes, we propose that PML influences Myc transcriptional activity through a mechanism that involves the control of Myc post-translational modifications.

Standard name | CAIRO_PML_TARGETS_BOUND_BY_MYC_DN
Systematic name | M1117
Organism | Mus musculus
PMID | 15735755
Authors | Cairo S,De Falco F,Pizzo M,Salomoni P,Pandolfi PP,Meroni G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblasts) after knockout of PML [GeneID=5371] and whose promoters were bound by MYC [GeneID=4609].
Full description | c-myc is a well-known proto-oncogene encoding for a transcription factor that needs to be tightly regulated in order to preserve cell homeostasis. The Promyelocytic Leukaemia gene product PML plays an important role in cell growth and survival, and resides in discrete subnuclear structures called Nuclear Bodies (NB). We performed comparative analysis of the expression of 40 Myc target genes and of Myc binding to their regulatory regions both in wild-type and PML knockout cells. We demonstrate that if PML is absent, despite Myc binding to the DNA regulatory sequences is unchanged, the expression profile of several Myc target genes is altered. PML is largely involved in gene regulation, via recruitment of several transcription factors and cofactors to the NB. Consistently, we show that Myc partially localizes to the NB and physically interacts with PML, and that this localization depends on Myc expression levels. As deregulation occurs to both activated and repressed Myc target genes, we propose that PML influences Myc transcriptional activity through a mechanism that involves the control of Myc post-translational modifications.

Standard name | OUELLET_OVARIAN_CANCER_INVASIVE_VS_LMP_UP
Systematic name | M12016
Organism | Homo sapiens
PMID | 15940270
Authors | Ouellet V,Provencher DM,Maugard CM,Le Page C,Ren F,Lussier C,Novak J,Ge B,Hudson TJ,Tonin PN,Mes-Masson AM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in epithelial ovarian cancer (EOC) biopsies: invasive (TOV) vs low malignant potential (LMP) tumors.
Full description | Tumors of low malignant potential (LMP) represent 20% of epithelial ovarian cancers (EOCs) and are associated with a better prognosis than the invasive tumors (TOV). Defining the relationship between LMPs and TOVs remains an important goal towards understanding the molecular pathways that contribute to prognosis, as well as providing molecular markers, for these EOCs. To this end, DNA microarray analyses were performed either in a primary culture or a tumor tissue model system and selected candidate genes showing a distinctive expression profile between LMPs and TOVs were identified using a class prediction approach based on three statistical methods of analysis. Both model systems appear relevant as candidate genes identified by either model allowed the proper reclassification of samples as either LMPs or TOVs. Selected candidate genes (CAS, CCNE1, LGALS8, ITGbeta3, ATP1B1, FLIP, KRT7 and KRT19) were validated by real-time quantitative PCR analysis and show differential expression between LMPs and TOVs. Immunohistochemistry analyses showed that the two tumor classes were distinguishable by their expression of CAS, TNFR1A, FLIP, CKS1 and CCNE1. These results define signature patterns for gene expression of LMPs and TOVs and identify gene candidates that warrant further study to deepen our understanding of the biology of EOC.

Standard name | OUELLET_OVARIAN_CANCER_INVASIVE_VS_LMP_DN
Systematic name | M10336
Organism | Homo sapiens
PMID | 15940270
Authors | Ouellet V,Provencher DM,Maugard CM,Le Page C,Ren F,Lussier C,Novak J,Ge B,Hudson TJ,Tonin PN,Mes-Masson AM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in epithelial ovarian cancer (EOC) biopsies: invasive (TOV) vs low malignant potential (LMP) tumors.
Full description | Tumors of low malignant potential (LMP) represent 20% of epithelial ovarian cancers (EOCs) and are associated with a better prognosis than the invasive tumors (TOV). Defining the relationship between LMPs and TOVs remains an important goal towards understanding the molecular pathways that contribute to prognosis, as well as providing molecular markers, for these EOCs. To this end, DNA microarray analyses were performed either in a primary culture or a tumor tissue model system and selected candidate genes showing a distinctive expression profile between LMPs and TOVs were identified using a class prediction approach based on three statistical methods of analysis. Both model systems appear relevant as candidate genes identified by either model allowed the proper reclassification of samples as either LMPs or TOVs. Selected candidate genes (CAS, CCNE1, LGALS8, ITGbeta3, ATP1B1, FLIP, KRT7 and KRT19) were validated by real-time quantitative PCR analysis and show differential expression between LMPs and TOVs. Immunohistochemistry analyses showed that the two tumor classes were distinguishable by their expression of CAS, TNFR1A, FLIP, CKS1 and CCNE1. These results define signature patterns for gene expression of LMPs and TOVs and identify gene candidates that warrant further study to deepen our understanding of the biology of EOC.

Standard name | LANDIS_ERBB2_BREAST_TUMORS_324_UP
Systematic name | M366
Organism | Mus musculus
PMID | 15897883
Authors | Landis MD,Seachrist DD,Montañez-Wiscovich ME,Danielpour D,Keri RA
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the 324 genes identified by two analytical methods as changed in the mammary tumors induced by transgenic expression of ERBB2 [GeneID=2064].
Full description | Upregulation of HER2/ErbB2/Neu occurs in 15-30% of human breast cancers and correlates with poor prognosis. Identification of ErbB2/Neu transcriptional targets should facilitate development of novel therapeutic approaches. Development of breast cancer is a multistep process; thus, to identify the transcriptomes associated with different stages of progression of tumorigenesis, we compared expression profiles of mammary tumors and preneoplastic mammary tissue from MMTV-Neu transgenic mice to expression profiles of wild-type mammary glands using Affymetrix microarrays. We identified 324 candidate genes that were unique to ErbB2/Neu-induced tumors relative to normal mammary gland tissue from wild-type controls. Expression of a subset of these genes (82) was also changed in the preneoplastic mammary glands compared to wild-type controls, indicating that they may play a pivotal role during early events of ErbB2/Neu-initiated mammary tumorigenesis. Further analysis of the microarray data revealed that expression of several known transforming growth factor (TGF)-beta target genes was altered, suggesting that the TGF-beta signaling cascade is downregulated in ErbB2/Neu-induced tumors. Western blot analysis for TGF-beta-Receptor-I/ALK5 and immunohistochemistry for TGF-beta-Receptor-I/ALK5 and phosphorylated/activated Smad2 confirmed that the Smad-dependent TGF-beta signaling cascade was inactive in these tumors. Although absent in most of the tumor, phosphorylated Smad2 was present in the periphery of tumors. Interestingly, presence of phosphorylated/activated Smad2 correlated with expression of Activin-Receptor-IB/ALK4, suggesting that although Smad-dependent TGF-beta signaling is absent in ErbB2/Neu-induced tumors, Activin signaling may be active at the leading edge of these tumors. Cumulatively, these data indicate that the TGF-beta pathway is intrinsically suppressed in ErbB2/Neu tumors via a mechanism involving loss of TGF-beta-Receptor-I/ALK5.

Standard name | LANDIS_ERBB2_BREAST_TUMORS_324_DN
Systematic name | M8901
Organism | Mus musculus
PMID | 15897883
Authors | Landis MD,Seachrist DD,Montañez-Wiscovich ME,Danielpour D,Keri RA
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the 324 genes identified by two analytical methods as changed in the mammary tumors induced by transgenic expression of ERBB2 [GeneID=2064].
Full description | Upregulation of HER2/ErbB2/Neu occurs in 15-30% of human breast cancers and correlates with poor prognosis. Identification of ErbB2/Neu transcriptional targets should facilitate development of novel therapeutic approaches. Development of breast cancer is a multistep process; thus, to identify the transcriptomes associated with different stages of progression of tumorigenesis, we compared expression profiles of mammary tumors and preneoplastic mammary tissue from MMTV-Neu transgenic mice to expression profiles of wild-type mammary glands using Affymetrix microarrays. We identified 324 candidate genes that were unique to ErbB2/Neu-induced tumors relative to normal mammary gland tissue from wild-type controls. Expression of a subset of these genes (82) was also changed in the preneoplastic mammary glands compared to wild-type controls, indicating that they may play a pivotal role during early events of ErbB2/Neu-initiated mammary tumorigenesis. Further analysis of the microarray data revealed that expression of several known transforming growth factor (TGF)-beta target genes was altered, suggesting that the TGF-beta signaling cascade is downregulated in ErbB2/Neu-induced tumors. Western blot analysis for TGF-beta-Receptor-I/ALK5 and immunohistochemistry for TGF-beta-Receptor-I/ALK5 and phosphorylated/activated Smad2 confirmed that the Smad-dependent TGF-beta signaling cascade was inactive in these tumors. Although absent in most of the tumor, phosphorylated Smad2 was present in the periphery of tumors. Interestingly, presence of phosphorylated/activated Smad2 correlated with expression of Activin-Receptor-IB/ALK4, suggesting that although Smad-dependent TGF-beta signaling is absent in ErbB2/Neu-induced tumors, Activin signaling may be active at the leading edge of these tumors. Cumulatively, these data indicate that the TGF-beta pathway is intrinsically suppressed in ErbB2/Neu tumors via a mechanism involving loss of TGF-beta-Receptor-I/ALK5.

Standard name | BARRIER_CANCER_RELAPSE_NORMAL_SAMPLE_UP
Systematic name | M1595
Organism | Homo sapiens
PMID | 16091735
Authors | Barrier A,Lemoine A,Boelle PY,Tse C,Brault D,Chiappini F,Breittschneider J,Lacaine F,Houry S,Huguier M,Van der Laan MJ,Speed T,Debuire B,Flahault A,Dudoit S
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in non-neoplastic mucosa samples from colon cancer patients who developed recurrence of the disease.
Full description | This study assessed the possibility to build a prognosis predictor, based on microarray gene expression measures, in stage II and III colon cancer patients. Tumour (T) and non-neoplastic mucosa (NM) mRNA samples from 18 patients (nine with a recurrence, nine with no recurrence) were profiled using the Affymetrix HGU133A GeneChip. The k-nearest neighbour method was used for prognosis prediction using T and NM gene expression measures. Six-fold cross-validation was applied to select the number of neighbours and the number of informative genes to include in the predictors. Based on this information, one T-based and one NM-based predictor were proposed and their accuracies were estimated by double cross-validation. In six-fold cross-validation, the lowest numbers of informative genes giving the lowest numbers of false predictions (two out of 18) were 30 and 70 with the T and NM gene expression measures, respectively. A 30-gene T-based predictor and a 70-gene NM-based predictor were then built, with estimated accuracies of 78 and 83%, respectively. This study suggests that one can build an accurate prognosis predictor for stage II and III colon cancer patients, based on gene expression measures, and one can use either tumour or non-neoplastic mucosa for this purpose.

Standard name | BARRIER_CANCER_RELAPSE_NORMAL_SAMPLE_DN
Systematic name | M4671
Organism | Homo sapiens
PMID | 16091735
Authors | Barrier A,Lemoine A,Boelle PY,Tse C,Brault D,Chiappini F,Breittschneider J,Lacaine F,Houry S,Huguier M,Van der Laan MJ,Speed T,Debuire B,Flahault A,Dudoit S
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in non-neoplastic mucosa samples from colon cancer patients who developed recurrence of the disease.
Full description | This study assessed the possibility to build a prognosis predictor, based on microarray gene expression measures, in stage II and III colon cancer patients. Tumour (T) and non-neoplastic mucosa (NM) mRNA samples from 18 patients (nine with a recurrence, nine with no recurrence) were profiled using the Affymetrix HGU133A GeneChip. The k-nearest neighbour method was used for prognosis prediction using T and NM gene expression measures. Six-fold cross-validation was applied to select the number of neighbours and the number of informative genes to include in the predictors. Based on this information, one T-based and one NM-based predictor were proposed and their accuracies were estimated by double cross-validation. In six-fold cross-validation, the lowest numbers of informative genes giving the lowest numbers of false predictions (two out of 18) were 30 and 70 with the T and NM gene expression measures, respectively. A 30-gene T-based predictor and a 70-gene NM-based predictor were then built, with estimated accuracies of 78 and 83%, respectively. This study suggests that one can build an accurate prognosis predictor for stage II and III colon cancer patients, based on gene expression measures, and one can use either tumour or non-neoplastic mucosa for this purpose.

Standard name | BARRIER_CANCER_RELAPSE_TUMOR_SAMPLE_UP
Systematic name | M6046
Organism | Homo sapiens
PMID | 16091735
Authors | Barrier A,Lemoine A,Boelle PY,Tse C,Brault D,Chiappini F,Breittschneider J,Lacaine F,Houry S,Huguier M,Van der Laan MJ,Speed T,Debuire B,Flahault A,Dudoit S
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in tumor samples from colon cancer patients who developed recurrence of the disease.
Full description | This study assessed the possibility to build a prognosis predictor, based on microarray gene expression measures, in stage II and III colon cancer patients. Tumour (T) and non-neoplastic mucosa (NM) mRNA samples from 18 patients (nine with a recurrence, nine with no recurrence) were profiled using the Affymetrix HGU133A GeneChip. The k-nearest neighbour method was used for prognosis prediction using T and NM gene expression measures. Six-fold cross-validation was applied to select the number of neighbours and the number of informative genes to include in the predictors. Based on this information, one T-based and one NM-based predictor were proposed and their accuracies were estimated by double cross-validation. In six-fold cross-validation, the lowest numbers of informative genes giving the lowest numbers of false predictions (two out of 18) were 30 and 70 with the T and NM gene expression measures, respectively. A 30-gene T-based predictor and a 70-gene NM-based predictor were then built, with estimated accuracies of 78 and 83%, respectively. This study suggests that one can build an accurate prognosis predictor for stage II and III colon cancer patients, based on gene expression measures, and one can use either tumour or non-neoplastic mucosa for this purpose.

Standard name | BARRIER_CANCER_RELAPSE_TUMOR_SAMPLE_DN
Systematic name | M17068
Organism | Homo sapiens
PMID | 16091735
Authors | Barrier A,Lemoine A,Boelle PY,Tse C,Brault D,Chiappini F,Breittschneider J,Lacaine F,Houry S,Huguier M,Van der Laan MJ,Speed T,Debuire B,Flahault A,Dudoit S
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in tumor samples from colon cancer patients who developed recurrence of the disease.
Full description | This study assessed the possibility to build a prognosis predictor, based on microarray gene expression measures, in stage II and III colon cancer patients. Tumour (T) and non-neoplastic mucosa (NM) mRNA samples from 18 patients (nine with a recurrence, nine with no recurrence) were profiled using the Affymetrix HGU133A GeneChip. The k-nearest neighbour method was used for prognosis prediction using T and NM gene expression measures. Six-fold cross-validation was applied to select the number of neighbours and the number of informative genes to include in the predictors. Based on this information, one T-based and one NM-based predictor were proposed and their accuracies were estimated by double cross-validation. In six-fold cross-validation, the lowest numbers of informative genes giving the lowest numbers of false predictions (two out of 18) were 30 and 70 with the T and NM gene expression measures, respectively. A 30-gene T-based predictor and a 70-gene NM-based predictor were then built, with estimated accuracies of 78 and 83%, respectively. This study suggests that one can build an accurate prognosis predictor for stage II and III colon cancer patients, based on gene expression measures, and one can use either tumour or non-neoplastic mucosa for this purpose.

Standard name | BARIS_THYROID_CANCER_UP
Systematic name | M2837
Organism | Homo sapiens
PMID | 15806164
Authors | Baris O,Mirebeau-Prunier D,Savagner F,Rodien P,Ballester B,Loriod B,Granjeaud S,Guyetant S,Franc B,Houlgatte R,Reynier P,Malthiery Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in oncocytic follicular carcinoma (FTC) vs mitochondrial-rich papillary carcinoma (PTC) types of thyroid cancer.
Full description | The oncogenic pathways in mitochondrial-rich thyroid carcinomas are not clearly understood. To investigate the possible implication of mitochondrial abundance in the genesis of thyroid tumors, we have explored the gene expression profile of six oncocytic carcinomas and six mitochondrial-rich papillary carcinomas using cDNA-microarray technology. A supervised approach allowed us to identify 83 genes differentially expressed in the two types of carcinoma. These genes were classified according to their ontologic profiles. Three genes, NOS3, alpha-actinin-2 and alpha-catenin, suspected of playing a role in tumor genesis, were explored by quantitative RT-PCR analysis and immunohistochemistry. Of the 59 genes overexpressed in papillary carcinomas, 51% were involved in cell communication. Of the 24 genes overexpressed in oncocytic carcinomas, 84% were involved in mitochondrial and cellular metabolism. Our results suggest that mitochondrial respiratory chain complexes III and IV play a significant role in the regulation of reactive oxygen species production by oncocytic tumors.

Standard name | BARIS_THYROID_CANCER_DN
Systematic name | M15411
Organism | Homo sapiens
PMID | 15806164
Authors | Baris O,Mirebeau-Prunier D,Savagner F,Rodien P,Ballester B,Loriod B,Granjeaud S,Guyetant S,Franc B,Houlgatte R,Reynier P,Malthiery Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in oncocytic follicular carcinoma (FTC) vs mitochondrial-rich papillary carcinoma (PTC) types of thyroid cancer.
Full description | The oncogenic pathways in mitochondrial-rich thyroid carcinomas are not clearly understood. To investigate the possible implication of mitochondrial abundance in the genesis of thyroid tumors, we have explored the gene expression profile of six oncocytic carcinomas and six mitochondrial-rich papillary carcinomas using cDNA-microarray technology. A supervised approach allowed us to identify 83 genes differentially expressed in the two types of carcinoma. These genes were classified according to their ontologic profiles. Three genes, NOS3, alpha-actinin-2 and alpha-catenin, suspected of playing a role in tumor genesis, were explored by quantitative RT-PCR analysis and immunohistochemistry. Of the 59 genes overexpressed in papillary carcinomas, 51% were involved in cell communication. Of the 24 genes overexpressed in oncocytic carcinomas, 84% were involved in mitochondrial and cellular metabolism. Our results suggest that mitochondrial respiratory chain complexes III and IV play a significant role in the regulation of reactive oxygen species production by oncocytic tumors.

Standard name | BERENJENO_TRANSFORMED_BY_RHOA_UP
Systematic name | M16189
Organism | Mus musculus
PMID | 17213802
Authors | Berenjeno IM,Núñez F,Bustelo XR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NIH3T3 cells (fibroblasts) transformed by expression of contitutively active (Q63L) form of RHOA [GeneID=387] off plasmid vector.
Full description | We have used microarray technology to identify the transcriptional targets of Rho subfamily guanosine 5'-triphosphate (GTP)ases in NIH3T3 cells. This analysis indicated that murine fibroblasts transformed by these proteins show similar transcriptomal profiles. Functional annotation of the regulated genes indicate that Rho subfamily GTPases target a wide spectrum of functions, although loci encoding proteins linked to proliferation and DNA synthesis/transcription are upregulated preferentially. Rho proteins promote four main networks of interacting proteins nucleated around E2F, c-Jun, c-Myc and p53. Of those, E2F, c-Jun and c-Myc are essential for the maintenance of cell transformation. Inhibition of Rock, one of the main Rho GTPase targets, leads to small changes in the transcriptome of Rho-transformed cells. Rock inhibition decreases c-myc gene expression without affecting the E2F and c-Jun pathways. Loss-of-function studies demonstrate that c-Myc is important for the blockage of cell-contact inhibition rather than for promoting the proliferation of Rho-transformed cells. However, c-Myc overexpression does not bypass the inhibition of cell transformation induced by Rock blockage, indicating that c-Myc is essential, but not sufficient, for Rock-dependent transformation. These results reveal the complexity of the genetic program orchestrated by the Rho subfamily and pinpoint protein networks that mediate different aspects of the malignant phenotype of Rho-transformed cells.

Standard name | BERENJENO_TRANSFORMED_BY_RHOA_DN
Systematic name | M7514
Organism | Mus musculus
PMID | 17213802
Authors | Berenjeno IM,Núñez F,Bustelo XR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NIH3T3 cells (fibroblasts) transformed by expression of contitutively active (Q63L) form of RHOA [GeneID=387] off plasmid vector.
Full description | We have used microarray technology to identify the transcriptional targets of Rho subfamily guanosine 5'-triphosphate (GTP)ases in NIH3T3 cells. This analysis indicated that murine fibroblasts transformed by these proteins show similar transcriptomal profiles. Functional annotation of the regulated genes indicate that Rho subfamily GTPases target a wide spectrum of functions, although loci encoding proteins linked to proliferation and DNA synthesis/transcription are upregulated preferentially. Rho proteins promote four main networks of interacting proteins nucleated around E2F, c-Jun, c-Myc and p53. Of those, E2F, c-Jun and c-Myc are essential for the maintenance of cell transformation. Inhibition of Rock, one of the main Rho GTPase targets, leads to small changes in the transcriptome of Rho-transformed cells. Rock inhibition decreases c-myc gene expression without affecting the E2F and c-Jun pathways. Loss-of-function studies demonstrate that c-Myc is important for the blockage of cell-contact inhibition rather than for promoting the proliferation of Rho-transformed cells. However, c-Myc overexpression does not bypass the inhibition of cell transformation induced by Rock blockage, indicating that c-Myc is essential, but not sufficient, for Rock-dependent transformation. These results reveal the complexity of the genetic program orchestrated by the Rho subfamily and pinpoint protein networks that mediate different aspects of the malignant phenotype of Rho-transformed cells.

Standard name | TAKADA_GASTRIC_CANCER_COPY_NUMBER_UP
Systematic name | M2212
Organism | Homo sapiens
PMID | 16103878
Authors | Takada H,Imoto I,Tsuda H,Nakanishi Y,Ichikura T,Mochizuki H,Mitsufuji S,Hosoda F,Hirohashi S,Ohki M,Inazawa J
Category | C2
Sub-category | CGP
Brief description | Candidate genes in the regions of copy number gain in gastric cancer cell lines.
Full description | Array-based comparative genomic hybridization (CGH-array) has a powerful potential for high-throughput identification of genetic aberrations in cell genomes. We identified a homozygous loss of ADAM23 (2q33.3) in the course of a program to screen a panel of gastric cancer (GC) cell lines (1/32, 3.1%) for genomic copy-number aberrations using our custom-made CGH-array. Infrequent homozygous deletion of ADAM23 was also seen in primary gastric tumors (1/39, 2.6%). ADAM23 mRNA was expressed in normal stomach tissue, but not in the majority of GC cell lines without homozygous deletion of this gene. Expression of ADAM23 mRNA was restored to gene-silenced GC cells after treatment with 5-aza 2'-deoxycytidine. The methylation status of the ADAM23 CpG island, which showed promoter activity, correlated inversely with its expression. Methylation of this CpG island was observed both in GC cell lines and in primary GC tissues; in primary tumors with a hypermethylated CpG island, expression of ADAM23 was lower than in adjacent noncancerous tissues. Moreover, restoration of ADAM23 in GC cells reduced their numbers in colony-formation assays. These results suggest that genetic or epigenetic silencing by hypermethylation of the ADAM23 CpG-rich promoter region leads to loss of ADAM23 function, which may be a factor in gastric carcinogenesis.

Standard name | TAKADA_GASTRIC_CANCER_COPY_NUMBER_DN
Systematic name | M11405
Organism | Homo sapiens
PMID | 16103878
Authors | Takada H,Imoto I,Tsuda H,Nakanishi Y,Ichikura T,Mochizuki H,Mitsufuji S,Hosoda F,Hirohashi S,Ohki M,Inazawa J
Category | C2
Sub-category | CGP
Brief description | Candidate genes in the regions of copy number loss in gastric cancer cell lines.
Full description | Array-based comparative genomic hybridization (CGH-array) has a powerful potential for high-throughput identification of genetic aberrations in cell genomes. We identified a homozygous loss of ADAM23 (2q33.3) in the course of a program to screen a panel of gastric cancer (GC) cell lines (1/32, 3.1%) for genomic copy-number aberrations using our custom-made CGH-array. Infrequent homozygous deletion of ADAM23 was also seen in primary gastric tumors (1/39, 2.6%). ADAM23 mRNA was expressed in normal stomach tissue, but not in the majority of GC cell lines without homozygous deletion of this gene. Expression of ADAM23 mRNA was restored to gene-silenced GC cells after treatment with 5-aza 2'-deoxycytidine. The methylation status of the ADAM23 CpG island, which showed promoter activity, correlated inversely with its expression. Methylation of this CpG island was observed both in GC cell lines and in primary GC tissues; in primary tumors with a hypermethylated CpG island, expression of ADAM23 was lower than in adjacent noncancerous tissues. Moreover, restoration of ADAM23 in GC cells reduced their numbers in colony-formation assays. These results suggest that genetic or epigenetic silencing by hypermethylation of the ADAM23 CpG-rich promoter region leads to loss of ADAM23 function, which may be a factor in gastric carcinogenesis.

Standard name | WANG_BARRETTS_ESOPHAGUS_AND_ESOPHAGUS_CANCER_UP
Systematic name | M8924
Organism | Homo sapiens
PMID | 16449976
Authors | Wang S,Zhan M,Yin J,Abraham JM,Mori Y,Sato F,Xu Y,Olaru A,Berki AT,Li H,Schulmann K,Kan T,Hamilton JP,Paun B,Yu MM,Jin Z,Cheng Y,Ito T,Mantzur C,Greenwald BD,Meltzer SJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in esophageal adenocarcinoma (EAC) and Barret's esophagus (BE) relative to normal esophagi.
Full description | To investigate the relationship between Barrett's esophagus (BE) and esophageal adenocarcinoma (EAC), we determined gene expression profiles of discrete pathological stages of esophageal neoplasia using a sequence-verified human cDNA microarray. Fifty one RNAs, comprising 24 normal esophagi (NE), 18 BEs, and nine EACs were hybridized to cDNA microarrays. Five statistical analyses were used for the data analysis. Genes showing significantly different expression levels among the three sample groups were identified. Genes were grouped into functional categories based on the Gene Ontology Consortium. Surprisingly, the expression pattern of BE was significantly more similar to EAC than to NE, notwithstanding the known histopathologic differences between BE and EAC. The pattern of NE was clearly distinct from that of EAC. Thirty-six genes were the most differentially modulated, according to these microarray data, in BE-associated neoplastic progression. Twelve genes were significantly differentially expressed in cancer-associated BE's plus EAC (as a single combined tissue group) vs noncancer-associated BE's. These genes represent potential biomarkers to diagnose EAC at its early stages. Our results demonstrate that molecular events at the transcriptional level in BE are remarkably similar to BE's-associated adenocarcinoma of the esophagus. This finding alarmingly implies that BE is biologically closer to cancer than to normal esophagus, and that the cancer risk of BE is perhaps higher than we had imagined. These findings suggest that changes modulated at the molecular biologic level supervene earlier than histologic changes, and that BE is an early intermediate stage in the process of EAC.

Standard name | WANG_BARRETTS_ESOPHAGUS_AND_ESOPHAGUS_CANCER_DN
Systematic name | M16944
Organism | Homo sapiens
PMID | 16449976
Authors | Wang S,Zhan M,Yin J,Abraham JM,Mori Y,Sato F,Xu Y,Olaru A,Berki AT,Li H,Schulmann K,Kan T,Hamilton JP,Paun B,Yu MM,Jin Z,Cheng Y,Ito T,Mantzur C,Greenwald BD,Meltzer SJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in esophageal adenocarcinoma (EAC) and Barret's esophagus (BE) relative to normal esophagi.
Full description | To investigate the relationship between Barrett's esophagus (BE) and esophageal adenocarcinoma (EAC), we determined gene expression profiles of discrete pathological stages of esophageal neoplasia using a sequence-verified human cDNA microarray. Fifty one RNAs, comprising 24 normal esophagi (NE), 18 BEs, and nine EACs were hybridized to cDNA microarrays. Five statistical analyses were used for the data analysis. Genes showing significantly different expression levels among the three sample groups were identified. Genes were grouped into functional categories based on the Gene Ontology Consortium. Surprisingly, the expression pattern of BE was significantly more similar to EAC than to NE, notwithstanding the known histopathologic differences between BE and EAC. The pattern of NE was clearly distinct from that of EAC. Thirty-six genes were the most differentially modulated, according to these microarray data, in BE-associated neoplastic progression. Twelve genes were significantly differentially expressed in cancer-associated BE's plus EAC (as a single combined tissue group) vs noncancer-associated BE's. These genes represent potential biomarkers to diagnose EAC at its early stages. Our results demonstrate that molecular events at the transcriptional level in BE are remarkably similar to BE's-associated adenocarcinoma of the esophagus. This finding alarmingly implies that BE is biologically closer to cancer than to normal esophagus, and that the cancer risk of BE is perhaps higher than we had imagined. These findings suggest that changes modulated at the molecular biologic level supervene earlier than histologic changes, and that BE is an early intermediate stage in the process of EAC.

Standard name | KERLEY_RESPONSE_TO_CISPLATIN_UP
Systematic name | M16812
Organism | Homo sapiens
PMID | 15940259
Authors | Kerley-Hamilton JS,Pike AM,Li N,DiRenzo J,Spinella MJ
Category | C2
Sub-category | CGP
Brief description | Genes genes up-regulated in NT2/D1 cells (embryonal carcinoma) in response to treatment with cisplatin [PubChem=2767].
Full description | Testicular germ cell cancers remain one of the few solid tumors routinely cured in advanced stages with conventional cisplatin-based chemotherapy. The mechanisms remain largely unknown. Through use of gene-expression array profiling we define immediate transcriptional targets in response to cisplatin in testicular germ cell-derived human embryonal carcinoma cells. We report 46 genes upregulated and five genes repressed by cisplatin. Several of these gene products, including FAS, TRAILR3, PHLDA3, LRDD, and IER3 are previously implicated in the apoptotic death receptor pathway, while others including SESN1, FDXR, PLK3, and DDIT4 are known mediators of reactive oxygen species generation. Approximately 54% of the upregulated genes are established or suspected downstream targets of p53. Specific siRNA to p53 prevents cisplatin-mediated activation of p53 and p53 pathway genes and renders embryonal carcinoma cells relatively resistant to cisplatin cytotoxicity. Interestingly, in p53 knockdown cells nearly the entire set of identified cisplatin targets fail to respond or have a diminished response to cisplatin, suggesting that many are new direct or indirect targets of p53 including GPR87, STK17A, INPP5D, FLJ11259, and EPS8L2. The data indicate that robust transcriptional activation of p53 is linked to the known hypersensitivity of testicular germ cell tumors to chemotherapy. Many of the gene products may participate in the unique curability of this disease.

Standard name | KERLEY_RESPONSE_TO_CISPLATIN_DN
Systematic name | M17702
Organism | Homo sapiens
PMID | 15940259
Authors | Kerley-Hamilton JS,Pike AM,Li N,DiRenzo J,Spinella MJ
Category | C2
Sub-category | CGP
Brief description | Genes genes down-regulated in NT2/D1 cells (embryonal carcinoma) in response to treatment with cisplatin [PubChem=2767].
Full description | Testicular germ cell cancers remain one of the few solid tumors routinely cured in advanced stages with conventional cisplatin-based chemotherapy. The mechanisms remain largely unknown. Through use of gene-expression array profiling we define immediate transcriptional targets in response to cisplatin in testicular germ cell-derived human embryonal carcinoma cells. We report 46 genes upregulated and five genes repressed by cisplatin. Several of these gene products, including FAS, TRAILR3, PHLDA3, LRDD, and IER3 are previously implicated in the apoptotic death receptor pathway, while others including SESN1, FDXR, PLK3, and DDIT4 are known mediators of reactive oxygen species generation. Approximately 54% of the upregulated genes are established or suspected downstream targets of p53. Specific siRNA to p53 prevents cisplatin-mediated activation of p53 and p53 pathway genes and renders embryonal carcinoma cells relatively resistant to cisplatin cytotoxicity. Interestingly, in p53 knockdown cells nearly the entire set of identified cisplatin targets fail to respond or have a diminished response to cisplatin, suggesting that many are new direct or indirect targets of p53 including GPR87, STK17A, INPP5D, FLJ11259, and EPS8L2. The data indicate that robust transcriptional activation of p53 is linked to the known hypersensitivity of testicular germ cell tumors to chemotherapy. Many of the gene products may participate in the unique curability of this disease.

Standard name | MISSIAGLIA_REGULATED_BY_METHYLATION_UP
Systematic name | M12272
Organism | Homo sapiens
PMID | 15637593
Authors | Missiaglia E,Donadelli M,Palmieri M,Crnogorac-Jurcevic T,Scarpa A,Lemoine NR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in PaCa44 and CFPAC1 cells (pancreatic cancer) after treatment with decitabine [PubChem=451668], a DNA hypomethylating agent similar to azacitidine [PubChem=9444].
Full description | Alteration of methylation status has been recognized as a possible epigenetic mechanism of selection during tumorigenesis in pancreatic cancer. This type of cancer is characterized by poor prognosis partly due to resistance to conventional drug treatments. We have used microarray technology to investigate the changes in global gene expression observed after treatment of different pancreatic cancer cell lines with the methylase inhibitor 5-aza-2'-deoxycytidine (5-aza-CdR). We have observed that this agent is able to inhibit to various degrees the growth of three pancreatic cancer cell lines. In particular, this inhibition was associated with induction of interferon (IFN)-related genes, as observed in other tumour types. Thus, expression of STAT1 seems to play a key role in the cellular response to treatment with the cytosine analogue. Moreover, we found increased p21(WAF1) and gadd45A expression to be associated with the efficacy of the treatment; this induction may correlate with activation of the IFN signalling pathway. Expression of the p16(INK) protein was also linked to the ability of cells to respond to 5-aza-CdR. Finally, genome-wide demethylation induced sensitization that significantly increased response to further treatment with various chemotherapy agents.

Standard name | MISSIAGLIA_REGULATED_BY_METHYLATION_DN
Systematic name | M6866
Organism | Homo sapiens
PMID | 15637593
Authors | Missiaglia E,Donadelli M,Palmieri M,Crnogorac-Jurcevic T,Scarpa A,Lemoine NR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in PaCa44 and CFPAC1 cells (pancreatic cancer) after treatment with decitabine [PubChem=451668], a DNA hypomethylating agent similar to azacitidine [PubChem=9444].
Full description | Alteration of methylation status has been recognized as a possible epigenetic mechanism of selection during tumorigenesis in pancreatic cancer. This type of cancer is characterized by poor prognosis partly due to resistance to conventional drug treatments. We have used microarray technology to investigate the changes in global gene expression observed after treatment of different pancreatic cancer cell lines with the methylase inhibitor 5-aza-2'-deoxycytidine (5-aza-CdR). We have observed that this agent is able to inhibit to various degrees the growth of three pancreatic cancer cell lines. In particular, this inhibition was associated with induction of interferon (IFN)-related genes, as observed in other tumour types. Thus, expression of STAT1 seems to play a key role in the cellular response to treatment with the cytosine analogue. Moreover, we found increased p21(WAF1) and gadd45A expression to be associated with the efficacy of the treatment; this induction may correlate with activation of the IFN signalling pathway. Expression of the p16(INK) protein was also linked to the ability of cells to respond to 5-aza-CdR. Finally, genome-wide demethylation induced sensitization that significantly increased response to further treatment with various chemotherapy agents.

Standard name | TANG_SENESCENCE_TP53_TARGETS_UP
Systematic name | M11850
Organism | Homo sapiens
PMID | 17533371
Authors | Tang X,Milyavsky M,Goldfinger N,Rotter V
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in WI-38 cells (senescent primary fibroblasts) after inactivation of TP53 [GeneID=7157] by GSE56 polypeptide.
Full description | The tumor suppressor p53 is a key modulator of the cellular stress response, inducing cell-cycle arrest, apoptosis, senescence and cell differentiation. To evaluate further the molecular mechanism underlying p53 function, the transcriptional profiles of proliferating and senescent WI-38 cells, both wild-type p53 expressers and counterparts with an inactivated p53, were compared by DNA microarray analysis. In particular, the amyloid-beta precursor-like protein 1 (APLP1) is induced in senescent cells in a p53-dependent manner. APLP1 was confirmed to be a novel transcriptional target of p53 by in vivo and in vitro characterization of a p53 responsive element found in the first intron of the APLP1 gene locus. APLP1 knockdown experiments demonstrate that APLP1 is required for the proliferation of fibroblastic and epithelial cells. Moreover, depletion of APLP1 expression diminishes stress-induced apoptosis of neural cells, whereas ectopic APLP1 expression augments apoptosis. Based on these data, a mechanism is proposed whereby p53-dependent induction of APLP1 is involved in neural cell death, and which may exacerbate neuronal cell loss in some acute or chronic neurodegenerative disorders.

Standard name | TANG_SENESCENCE_TP53_TARGETS_DN
Systematic name | M6171
Organism | Homo sapiens
PMID | 17533371
Authors | Tang X,Milyavsky M,Goldfinger N,Rotter V
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in WI-38 cells (senescent primary fibroblasts) after inactivation of TP53 [GeneID=7157] by GSE56 polypeptide.
Full description | The tumor suppressor p53 is a key modulator of the cellular stress response, inducing cell-cycle arrest, apoptosis, senescence and cell differentiation. To evaluate further the molecular mechanism underlying p53 function, the transcriptional profiles of proliferating and senescent WI-38 cells, both wild-type p53 expressers and counterparts with an inactivated p53, were compared by DNA microarray analysis. In particular, the amyloid-beta precursor-like protein 1 (APLP1) is induced in senescent cells in a p53-dependent manner. APLP1 was confirmed to be a novel transcriptional target of p53 by in vivo and in vitro characterization of a p53 responsive element found in the first intron of the APLP1 gene locus. APLP1 knockdown experiments demonstrate that APLP1 is required for the proliferation of fibroblastic and epithelial cells. Moreover, depletion of APLP1 expression diminishes stress-induced apoptosis of neural cells, whereas ectopic APLP1 expression augments apoptosis. Based on these data, a mechanism is proposed whereby p53-dependent induction of APLP1 is involved in neural cell death, and which may exacerbate neuronal cell loss in some acute or chronic neurodegenerative disorders.

Standard name | WANG_BARRETTS_ESOPHAGUS_UP
Systematic name | M6225
Organism | Homo sapiens
PMID | 16449976
Authors | Wang S,Zhan M,Yin J,Abraham JM,Mori Y,Sato F,Xu Y,Olaru A,Berki AT,Li H,Schulmann K,Kan T,Hamilton JP,Paun B,Yu MM,Jin Z,Cheng Y,Ito T,Mantzur C,Greenwald BD,Meltzer SJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Barrett's esophagus compared to the normal tissue.
Full description | To investigate the relationship between Barrett's esophagus (BE) and esophageal adenocarcinoma (EAC), we determined gene expression profiles of discrete pathological stages of esophageal neoplasia using a sequence-verified human cDNA microarray. Fifty one RNAs, comprising 24 normal esophagi (NE), 18 BEs, and nine EACs were hybridized to cDNA microarrays. Five statistical analyses were used for the data analysis. Genes showing significantly different expression levels among the three sample groups were identified. Genes were grouped into functional categories based on the Gene Ontology Consortium. Surprisingly, the expression pattern of BE was significantly more similar to EAC than to NE, notwithstanding the known histopathologic differences between BE and EAC. The pattern of NE was clearly distinct from that of EAC. Thirty-six genes were the most differentially modulated, according to these microarray data, in BE-associated neoplastic progression. Twelve genes were significantly differentially expressed in cancer-associated BE's plus EAC (as a single combined tissue group) vs noncancer-associated BE's. These genes represent potential biomarkers to diagnose EAC at its early stages. Our results demonstrate that molecular events at the transcriptional level in BE are remarkably similar to BE's-associated adenocarcinoma of the esophagus. This finding alarmingly implies that BE is biologically closer to cancer than to normal esophagus, and that the cancer risk of BE is perhaps higher than we had imagined. These findings suggest that changes modulated at the molecular biologic level supervene earlier than histologic changes, and that BE is an early intermediate stage in the process of EAC.

Standard name | WANG_BARRETTS_ESOPHAGUS_DN
Systematic name | M18213
Organism | Homo sapiens
PMID | 16449976
Authors | Wang S,Zhan M,Yin J,Abraham JM,Mori Y,Sato F,Xu Y,Olaru A,Berki AT,Li H,Schulmann K,Kan T,Hamilton JP,Paun B,Yu MM,Jin Z,Cheng Y,Ito T,Mantzur C,Greenwald BD,Meltzer SJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Barrett's esophagus compared to the normal tissue.
Full description | To investigate the relationship between Barrett's esophagus (BE) and esophageal adenocarcinoma (EAC), we determined gene expression profiles of discrete pathological stages of esophageal neoplasia using a sequence-verified human cDNA microarray. Fifty one RNAs, comprising 24 normal esophagi (NE), 18 BEs, and nine EACs were hybridized to cDNA microarrays. Five statistical analyses were used for the data analysis. Genes showing significantly different expression levels among the three sample groups were identified. Genes were grouped into functional categories based on the Gene Ontology Consortium. Surprisingly, the expression pattern of BE was significantly more similar to EAC than to NE, notwithstanding the known histopathologic differences between BE and EAC. The pattern of NE was clearly distinct from that of EAC. Thirty-six genes were the most differentially modulated, according to these microarray data, in BE-associated neoplastic progression. Twelve genes were significantly differentially expressed in cancer-associated BE's plus EAC (as a single combined tissue group) vs noncancer-associated BE's. These genes represent potential biomarkers to diagnose EAC at its early stages. Our results demonstrate that molecular events at the transcriptional level in BE are remarkably similar to BE's-associated adenocarcinoma of the esophagus. This finding alarmingly implies that BE is biologically closer to cancer than to normal esophagus, and that the cancer risk of BE is perhaps higher than we had imagined. These findings suggest that changes modulated at the molecular biologic level supervene earlier than histologic changes, and that BE is an early intermediate stage in the process of EAC.

Standard name | WANG_ESOPHAGUS_CANCER_VS_NORMAL_UP
Systematic name | M8475
Organism | Homo sapiens
PMID | 16449976
Authors | Wang S,Zhan M,Yin J,Abraham JM,Mori Y,Sato F,Xu Y,Olaru A,Berki AT,Li H,Schulmann K,Kan T,Hamilton JP,Paun B,Yu MM,Jin Z,Cheng Y,Ito T,Mantzur C,Greenwald BD,Meltzer SJ
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes specific to esophageal adenocarcinoma (EAC) relative to normal tissue.
Full description | To investigate the relationship between Barrett's esophagus (BE) and esophageal adenocarcinoma (EAC), we determined gene expression profiles of discrete pathological stages of esophageal neoplasia using a sequence-verified human cDNA microarray. Fifty one RNAs, comprising 24 normal esophagi (NE), 18 BEs, and nine EACs were hybridized to cDNA microarrays. Five statistical analyses were used for the data analysis. Genes showing significantly different expression levels among the three sample groups were identified. Genes were grouped into functional categories based on the Gene Ontology Consortium. Surprisingly, the expression pattern of BE was significantly more similar to EAC than to NE, notwithstanding the known histopathologic differences between BE and EAC. The pattern of NE was clearly distinct from that of EAC. Thirty-six genes were the most differentially modulated, according to these microarray data, in BE-associated neoplastic progression. Twelve genes were significantly differentially expressed in cancer-associated BE's plus EAC (as a single combined tissue group) vs noncancer-associated BE's. These genes represent potential biomarkers to diagnose EAC at its early stages. Our results demonstrate that molecular events at the transcriptional level in BE are remarkably similar to BE's-associated adenocarcinoma of the esophagus. This finding alarmingly implies that BE is biologically closer to cancer than to normal esophagus, and that the cancer risk of BE is perhaps higher than we had imagined. These findings suggest that changes modulated at the molecular biologic level supervene earlier than histologic changes, and that BE is an early intermediate stage in the process of EAC.

Standard name | WANG_ESOPHAGUS_CANCER_VS_NORMAL_DN
Systematic name | M12212
Organism | Homo sapiens
PMID | 16449976
Authors | Wang S,Zhan M,Yin J,Abraham JM,Mori Y,Sato F,Xu Y,Olaru A,Berki AT,Li H,Schulmann K,Kan T,Hamilton JP,Paun B,Yu MM,Jin Z,Cheng Y,Ito T,Mantzur C,Greenwald BD,Meltzer SJ
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes specific to esophageal adenocarcinoma (EAC) relative to normal tissue.
Full description | To investigate the relationship between Barrett's esophagus (BE) and esophageal adenocarcinoma (EAC), we determined gene expression profiles of discrete pathological stages of esophageal neoplasia using a sequence-verified human cDNA microarray. Fifty one RNAs, comprising 24 normal esophagi (NE), 18 BEs, and nine EACs were hybridized to cDNA microarrays. Five statistical analyses were used for the data analysis. Genes showing significantly different expression levels among the three sample groups were identified. Genes were grouped into functional categories based on the Gene Ontology Consortium. Surprisingly, the expression pattern of BE was significantly more similar to EAC than to NE, notwithstanding the known histopathologic differences between BE and EAC. The pattern of NE was clearly distinct from that of EAC. Thirty-six genes were the most differentially modulated, according to these microarray data, in BE-associated neoplastic progression. Twelve genes were significantly differentially expressed in cancer-associated BE's plus EAC (as a single combined tissue group) vs noncancer-associated BE's. These genes represent potential biomarkers to diagnose EAC at its early stages. Our results demonstrate that molecular events at the transcriptional level in BE are remarkably similar to BE's-associated adenocarcinoma of the esophagus. This finding alarmingly implies that BE is biologically closer to cancer than to normal esophagus, and that the cancer risk of BE is perhaps higher than we had imagined. These findings suggest that changes modulated at the molecular biologic level supervene earlier than histologic changes, and that BE is an early intermediate stage in the process of EAC.

Standard name | WANG_ESOPHAGUS_CANCER_PROGRESSION_UP
Systematic name | M19661
Organism | Homo sapiens
PMID | 16449976
Authors | Wang S,Zhan M,Yin J,Abraham JM,Mori Y,Sato F,Xu Y,Olaru A,Berki AT,Li H,Schulmann K,Kan T,Hamilton JP,Paun B,Yu MM,Jin Z,Cheng Y,Ito T,Mantzur C,Greenwald BD,Meltzer SJ
Category | C2
Sub-category | CGP
Brief description | Candidate progression biomarkers up-regulated in transition from non-tumor-risk associated to tumor-risk associated Barrett's esophagus and then to esophageal adenocarcinoma (EAC).
Full description | To investigate the relationship between Barrett's esophagus (BE) and esophageal adenocarcinoma (EAC), we determined gene expression profiles of discrete pathological stages of esophageal neoplasia using a sequence-verified human cDNA microarray. Fifty one RNAs, comprising 24 normal esophagi (NE), 18 BEs, and nine EACs were hybridized to cDNA microarrays. Five statistical analyses were used for the data analysis. Genes showing significantly different expression levels among the three sample groups were identified. Genes were grouped into functional categories based on the Gene Ontology Consortium. Surprisingly, the expression pattern of BE was significantly more similar to EAC than to NE, notwithstanding the known histopathologic differences between BE and EAC. The pattern of NE was clearly distinct from that of EAC. Thirty-six genes were the most differentially modulated, according to these microarray data, in BE-associated neoplastic progression. Twelve genes were significantly differentially expressed in cancer-associated BE's plus EAC (as a single combined tissue group) vs noncancer-associated BE's. These genes represent potential biomarkers to diagnose EAC at its early stages. Our results demonstrate that molecular events at the transcriptional level in BE are remarkably similar to BE's-associated adenocarcinoma of the esophagus. This finding alarmingly implies that BE is biologically closer to cancer than to normal esophagus, and that the cancer risk of BE is perhaps higher than we had imagined. These findings suggest that changes modulated at the molecular biologic level supervene earlier than histologic changes, and that BE is an early intermediate stage in the process of EAC.

Standard name | SILIGAN_TARGETS_OF_EWS_FLI1_FUSION_UP
Systematic name | M9251
Organism | Homo sapiens
PMID | 15735734
Authors | Siligan C,Ban J,Bachmaier R,Spahn L,Kreppel M,Schaefer KL,Poremba C,Aryee DN,Kovar H
Category | C2
Sub-category | CGP
Brief description | Genes bound by EWSR1-FLT1 [GeneID=2130;2321] fusion and up-regulated in STA-ET-7.2 cells (Ewing's sarcoma) after knockdown of EWSR1-FLT1 by RNAi.
Full description | In all, 85% of Ewing's sarcoma family tumors (ESFT), a neoplasm of unknown histogenesis, express EWS-FLI1 transcription factor gene fusions. To characterize direct target genes avoiding artificial model systems, we cloned genomic DNA from ESFT chromatin precipitating with EWS-FLI1. We now present a comprehensive list of 99 putative transcription factor targets identified, for the first time, by a hypothesis-free approach based on physical interaction. Gene-derived chromatin fragments co-precipitating with EWS-FLI1 were nonrandomly distributed over the human genome and localized predominantly to the upstream region and the first two introns of the genes. At least 20% of putative direct EWS-FLI1 targets were neural genes. One-third of genes recovered showed a significant ESFT-specific expression pattern and were found to be altered upon RNAi-mediated knockdown of EWS-FLI1. Among them, MK-STYX, encoding a MAP kinase phosphatase-like protein, was consistently expressed in ESFT. EWS-FLI1 was found to drive MK-STYX expression by binding to a single ETS binding motif within the first gene intron. MK-STYX serves as precedence for successful recovery of direct EWS-FLI1 targets from the authentic ESFT cellular context, the most relevant system to study oncogenic mechanisms for the discovery of new therapeutic targets in this disease.

Standard name | SILIGAN_TARGETS_OF_EWS_FLI1_FUSION_DN
Systematic name | M16533
Organism | Homo sapiens
PMID | 15735734
Authors | Siligan C,Ban J,Bachmaier R,Spahn L,Kreppel M,Schaefer KL,Poremba C,Aryee DN,Kovar H
Category | C2
Sub-category | CGP
Brief description | Genes bound by EWSR1-FLT1 [GeneID=2130;2321] fusion and down-regulated in STA-ET-7.2 cells (Ewing's sarcoma) after knockdown of EWSR1-FLT1 by RNAi.
Full description | In all, 85% of Ewing's sarcoma family tumors (ESFT), a neoplasm of unknown histogenesis, express EWS-FLI1 transcription factor gene fusions. To characterize direct target genes avoiding artificial model systems, we cloned genomic DNA from ESFT chromatin precipitating with EWS-FLI1. We now present a comprehensive list of 99 putative transcription factor targets identified, for the first time, by a hypothesis-free approach based on physical interaction. Gene-derived chromatin fragments co-precipitating with EWS-FLI1 were nonrandomly distributed over the human genome and localized predominantly to the upstream region and the first two introns of the genes. At least 20% of putative direct EWS-FLI1 targets were neural genes. One-third of genes recovered showed a significant ESFT-specific expression pattern and were found to be altered upon RNAi-mediated knockdown of EWS-FLI1. Among them, MK-STYX, encoding a MAP kinase phosphatase-like protein, was consistently expressed in ESFT. EWS-FLI1 was found to drive MK-STYX expression by binding to a single ETS binding motif within the first gene intron. MK-STYX serves as precedence for successful recovery of direct EWS-FLI1 targets from the authentic ESFT cellular context, the most relevant system to study oncogenic mechanisms for the discovery of new therapeutic targets in this disease.

Standard name | ROYLANCE_BREAST_CANCER_16Q_COPY_NUMBER_UP
Systematic name | M18394
Organism | Homo sapiens
PMID | 16702952
Authors | Roylance R,Gorman P,Papior T,Wan YL,Ives M,Watson JE,Collins C,Wortham N,Langford C,Fiegler H,Carter N,Gillett C,Sasieni P,Pinder S,Hanby A,Tomlinson I
Category | C2
Sub-category | CGP
Brief description | Genes in discrete regions of gain within 16q region detected in individual invasive breast cancer tumors.
Full description | We analysed chromosome 16q in 106 breast cancers using tiling-path array-comparative genomic hybridization (aCGH). About 80% of ductal cancers (IDCs) and all lobular cancers (ILCs) lost at least part of 16q. Grade I (GI) IDCs and ILCs often lost the whole chromosome arm. Grade II (GII) and grade III (GIII) IDCs showed less frequent whole-arm loss, but often had complex changes, typically small regions of gain together with larger regions of loss. The boundaries of gains/losses tended to cluster, common sites being 54.5-55.5 Mb and 57.4-58.8 Mb. Overall, the peak frequency of loss (83% cancers) occurred at 61.9-62.9 Mb. We also found several 'minimal' regions of loss/gain. However, no mutations in candidate genes (TRADD, CDH5, CDH8 and CDH11) were detected. Cluster analysis based on copy number changes identified a large group of cancers that had lost most of 16q, and two smaller groups (one with few changes, one with a tendency to show copy number gain). Although all morphological types occurred in each cluster group, IDCs (especially GII/GIII) were relatively overrepresented in the smaller groups. Cluster groups were not independently associated with survival. Use of tiling-path aCGH prompted re-evaluation of the hypothetical pathways of breast carcinogenesis. ILCs have the simplest changes on 16q and probably diverge from the IDC lineage close to the stage of 16q loss. Higher-grade IDCs probably develop from low-grade lesions in most cases, but there remains evidence that some GII/GIII IDCs arise without a GI precursor.

Standard name | ROYLANCE_BREAST_CANCER_16Q_COPY_NUMBER_DN
Systematic name | M8224
Organism | Homo sapiens
PMID | 16702952
Authors | Roylance R,Gorman P,Papior T,Wan YL,Ives M,Watson JE,Collins C,Wortham N,Langford C,Fiegler H,Carter N,Gillett C,Sasieni P,Pinder S,Hanby A,Tomlinson I
Category | C2
Sub-category | CGP
Brief description | Genes in discrete regions of loss within 16q region detected in individual invasive breast cancer tumors.
Full description | We analysed chromosome 16q in 106 breast cancers using tiling-path array-comparative genomic hybridization (aCGH). About 80% of ductal cancers (IDCs) and all lobular cancers (ILCs) lost at least part of 16q. Grade I (GI) IDCs and ILCs often lost the whole chromosome arm. Grade II (GII) and grade III (GIII) IDCs showed less frequent whole-arm loss, but often had complex changes, typically small regions of gain together with larger regions of loss. The boundaries of gains/losses tended to cluster, common sites being 54.5-55.5 Mb and 57.4-58.8 Mb. Overall, the peak frequency of loss (83% cancers) occurred at 61.9-62.9 Mb. We also found several 'minimal' regions of loss/gain. However, no mutations in candidate genes (TRADD, CDH5, CDH8 and CDH11) were detected. Cluster analysis based on copy number changes identified a large group of cancers that had lost most of 16q, and two smaller groups (one with few changes, one with a tendency to show copy number gain). Although all morphological types occurred in each cluster group, IDCs (especially GII/GIII) were relatively overrepresented in the smaller groups. Cluster groups were not independently associated with survival. Use of tiling-path aCGH prompted re-evaluation of the hypothetical pathways of breast carcinogenesis. ILCs have the simplest changes on 16q and probably diverge from the IDC lineage close to the stage of 16q loss. Higher-grade IDCs probably develop from low-grade lesions in most cases, but there remains evidence that some GII/GIII IDCs arise without a GI precursor.

Standard name | JOHANSSON_GLIOMAGENESIS_BY_PDGFB_UP
Systematic name | M1120
Organism | Mus musculus
PMID | 15750623
Authors | Johansson FK,Göransson H,Westermark B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in brain tumors induced by retroviral delivery of PDGFB [GeneID=5155].
Full description | Retroviral tagging previously identified putative cancer-causing genes in a mouse brain tumor model where a recombinant Moloney murine leukemia virus encoding the platelet-derived growth factor B-chain (MMLV/PDGFB) was intracerebrally injected in newborn mice. In the present study, expression analysis using cDNA arrays revealed several similarities of virus-induced mouse gliomas with human brain tumors. Brain tumors with short latency contained on average 8.0 retroviral insertions and resembled human glioblastoma multiforme (GBM) whereas long-latency gliomas were of lower grade, similar to human oligodendroglioma (OD) and had 2.3 insertions per tumor. Several known and novel genes of tumor progression or cell markers were differentially expressed between OD- and GBM-like tumors. Array and quantitative real-time PCR analysis demonstrated elevated expression similar to Pdgfralpha of retrovirally tagged genes Abhd2, Ddr1, Fos, Ng2, Ppfibp1, Rad51b and Sulf2 in both glioma types compared to neonatal and adult normal brain. The retrovirally tagged genes Plekhb1, Prex1, Prkg2, Sox10 and 1200004M23Rik were upregulated in the tumors but had a different expression profile than Pdgfralpha whereas Rap1gap, Gli1, Neurl and Camk2b were downregulated in the tumors. The present study accentuates the proposed role of the retrovirally tagged genes in PDGF-driven gliomagenesis and indicates that insertional mutagenesis can promote glioma progression.

Standard name | JOHANSSON_GLIOMAGENESIS_BY_PDGFB_DN
Systematic name | M1121
Organism | Mus musculus
PMID | 15750623
Authors | Johansson FK,Göransson H,Westermark B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in brain tumors induced by retroviral delivery of PDGFB [GeneID=5155].
Full description | Retroviral tagging previously identified putative cancer-causing genes in a mouse brain tumor model where a recombinant Moloney murine leukemia virus encoding the platelet-derived growth factor B-chain (MMLV/PDGFB) was intracerebrally injected in newborn mice. In the present study, expression analysis using cDNA arrays revealed several similarities of virus-induced mouse gliomas with human brain tumors. Brain tumors with short latency contained on average 8.0 retroviral insertions and resembled human glioblastoma multiforme (GBM) whereas long-latency gliomas were of lower grade, similar to human oligodendroglioma (OD) and had 2.3 insertions per tumor. Several known and novel genes of tumor progression or cell markers were differentially expressed between OD- and GBM-like tumors. Array and quantitative real-time PCR analysis demonstrated elevated expression similar to Pdgfralpha of retrovirally tagged genes Abhd2, Ddr1, Fos, Ng2, Ppfibp1, Rad51b and Sulf2 in both glioma types compared to neonatal and adult normal brain. The retrovirally tagged genes Plekhb1, Prex1, Prkg2, Sox10 and 1200004M23Rik were upregulated in the tumors but had a different expression profile than Pdgfralpha whereas Rap1gap, Gli1, Neurl and Camk2b were downregulated in the tumors. The present study accentuates the proposed role of the retrovirally tagged genes in PDGF-driven gliomagenesis and indicates that insertional mutagenesis can promote glioma progression.

Standard name | MCBRYAN_PUBERTAL_BREAST_3_4WK_UP
Systematic name | M13186
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during pubertal mammary gland development between weeks 3 and 4.
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | MCBRYAN_PUBERTAL_BREAST_3_4WK_DN
Systematic name | M8155
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during pubertal mammary gland development between weeks 3 and 4.
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | MCBRYAN_PUBERTAL_BREAST_4_5WK_UP
Systematic name | M19432
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during pubertal mammary gland development between week 4 and 5.
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | MCBRYAN_PUBERTAL_BREAST_4_5WK_DN
Systematic name | M12428
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during pubertal mammary gland development between week 4 and 5.
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | MCBRYAN_PUBERTAL_BREAST_5_6WK_UP
Systematic name | M13788
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during pubertal mammary gland development between week 5 and 6.
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | MCBRYAN_PUBERTAL_BREAST_5_6WK_DN
Systematic name | M8880
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during pubertal mammary gland development between week 5 and 6.
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | MCBRYAN_PUBERTAL_BREAST_6_7WK_UP
Systematic name | M2155
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during pubertal mammary gland development between week 6 and 7.
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | MCBRYAN_PUBERTAL_BREAST_6_7WK_DN
Systematic name | M19636
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during pubertal mammary gland development between week 6 and 7.
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | VETTER_TARGETS_OF_PRKCA_AND_ETS1_UP
Systematic name | M14495
Organism | Homo sapiens
PMID | 15531915
Authors | Vetter M,Blumenthal SG,Lindemann RK,Manns J,Wesselborg S,Thomssen C,Dittmer J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MDA-MB-231 cells (breast cancer) after knockdown of PRKCA and ETS1 [GeneID=5578;2113] by RNAi.
Full description | PKCalpha and Ets1 are both associated with breast cancer progression. Our previous studies suggested that these proteins are likely to functionally interact with one another. Here, we show that attenuation of endogenous PKCalpha expression (siPalpha) by RNA interference leads to reduced Ets1 protein expression in a variety of cancer cells. Pulse-chase experiments and treatment with proteasome inhibitor MG-132 revealed that siPalpha interferes with both Ets1 protein synthesis and stability. The effect of siPalpha on Ets1 expression could be partially prevented by KN-93, suggesting that calcium/calmodulin-dependent kinase II (CaMKII), a modulator of Ets1 activity, may play a role in PKCalpha-dependent Ets1 regulation. In contrast, Ets1-regulating kinases ERK1/2 were not found to be involved in this process. To assess the importance of the PKCalpha/Ets1 interaction, we compared the biological responses of MDA-MB-231 cells to PKCalpha- and Ets1-specific siRNAs (siE1). While only siPalpha induced changes in cellular morphology and anchorage-independent growth, both siRNAs similarly affected cellular responses to the antitumor drug mithramycin A and to UV light. Microarray analyses further showed that the expression of a certain set of genes was equally affected by siPalpha and siE1. The data suggest that Ets1 serves as an effector for PKCalpha to fulfil certain functions in cancer cells.

Standard name | VETTER_TARGETS_OF_PRKCA_AND_ETS1_DN
Systematic name | M11619
Organism | Homo sapiens
PMID | 15531915
Authors | Vetter M,Blumenthal SG,Lindemann RK,Manns J,Wesselborg S,Thomssen C,Dittmer J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MDA-MB-231 cells (breast cancer) after knockdown of PRKCA and ETS1 [GeneID=5578;2113] by RNAi.
Full description | PKCalpha and Ets1 are both associated with breast cancer progression. Our previous studies suggested that these proteins are likely to functionally interact with one another. Here, we show that attenuation of endogenous PKCalpha expression (siPalpha) by RNA interference leads to reduced Ets1 protein expression in a variety of cancer cells. Pulse-chase experiments and treatment with proteasome inhibitor MG-132 revealed that siPalpha interferes with both Ets1 protein synthesis and stability. The effect of siPalpha on Ets1 expression could be partially prevented by KN-93, suggesting that calcium/calmodulin-dependent kinase II (CaMKII), a modulator of Ets1 activity, may play a role in PKCalpha-dependent Ets1 regulation. In contrast, Ets1-regulating kinases ERK1/2 were not found to be involved in this process. To assess the importance of the PKCalpha/Ets1 interaction, we compared the biological responses of MDA-MB-231 cells to PKCalpha- and Ets1-specific siRNAs (siE1). While only siPalpha induced changes in cellular morphology and anchorage-independent growth, both siRNAs similarly affected cellular responses to the antitumor drug mithramycin A and to UV light. Microarray analyses further showed that the expression of a certain set of genes was equally affected by siPalpha and siE1. The data suggest that Ets1 serves as an effector for PKCalpha to fulfil certain functions in cancer cells.

Standard name | DUNNE_TARGETS_OF_AML1_MTG8_FUSION_UP
Systematic name | M2546
Organism | Homo sapiens
PMID | 16652140
Authors | Dunne J,Cullmann C,Ritter M,Soria NM,Drescher B,Debernardi S,Skoulakis S,Hartmann O,Krause M,Krauter J,Neubauer A,Young BD,Heidenreich O
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Kasumi-1 cells (acute myeloid leukaemia (AML) with the t(8;21) translocation) after knockdown of the AML1 MTG8 fusion [GeneID=861;862] by RNAi.
Full description | The chromosomal translocation t(8;21) is associated with 10-15% of all cases of acute myeloid leukaemia (AML). The resultant fusion protein AML1/MTG8 interferes with haematopoietic gene expression and is an important regulator of leukaemogenesis. We studied the effects of small interfering RNA (siRNA)-mediated AML1/MTG8 depletion on global gene expression in t(8;21)-positive leukaemic cell lines and in primary AML blasts using cDNA arrays, oligonucleotide arrays and real-time reverse transcription-polymerase chain reaction (RT-PCR). Suppression of AML1/MTG8 results in the increased expression of genes associated with myeloid differentiation, such as AZU1, BPI, CTSG, LYZ and RNASE2 as well as of antiproliferative genes such as IGFBP7, MS4A3 and SLA both in blasts and in cell lines. Furthermore, expression levels of several genes affiliated with drug resistance or indicative of poor prognosis AML (BAALC, CD34, PRG2, TSPAN7) are affected by AML1/MTG8 depletion. In conclusion, siRNA-mediated suppression of AML1/MTG8 cause very similar changes in gene expression pattern in t(8;21)-positive cell lines and in primary AML blasts. Furthermore, the results suggest that the specific targeting of AML1/MTG8 function may be a promising approach for complementing existing treatment strategies.

Standard name | DUNNE_TARGETS_OF_AML1_MTG8_FUSION_DN
Systematic name | M6469
Organism | Homo sapiens
PMID | 16652140
Authors | Dunne J,Cullmann C,Ritter M,Soria NM,Drescher B,Debernardi S,Skoulakis S,Hartmann O,Krause M,Krauter J,Neubauer A,Young BD,Heidenreich O
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Kasumi-1 cells (acute myeloid leukaemia (AML) with the t(8;21) translocation) after knockdown of the AML1 MTG8 fusion [GeneID=861;862] by RNAi.
Full description | The chromosomal translocation t(8;21) is associated with 10-15% of all cases of acute myeloid leukaemia (AML). The resultant fusion protein AML1/MTG8 interferes with haematopoietic gene expression and is an important regulator of leukaemogenesis. We studied the effects of small interfering RNA (siRNA)-mediated AML1/MTG8 depletion on global gene expression in t(8;21)-positive leukaemic cell lines and in primary AML blasts using cDNA arrays, oligonucleotide arrays and real-time reverse transcription-polymerase chain reaction (RT-PCR). Suppression of AML1/MTG8 results in the increased expression of genes associated with myeloid differentiation, such as AZU1, BPI, CTSG, LYZ and RNASE2 as well as of antiproliferative genes such as IGFBP7, MS4A3 and SLA both in blasts and in cell lines. Furthermore, expression levels of several genes affiliated with drug resistance or indicative of poor prognosis AML (BAALC, CD34, PRG2, TSPAN7) are affected by AML1/MTG8 depletion. In conclusion, siRNA-mediated suppression of AML1/MTG8 cause very similar changes in gene expression pattern in t(8;21)-positive cell lines and in primary AML blasts. Furthermore, the results suggest that the specific targeting of AML1/MTG8 function may be a promising approach for complementing existing treatment strategies.

Standard name | LUI_THYROID_CANCER_PAX8_PPARG_UP
Systematic name | M4381
Organism | Homo sapiens
PMID | 15608688
Authors | Lui WO,Foukakis T,Lidén J,Thoppe SR,Dwight T,Höög A,Zedenius J,Wallin G,Reimers M,Larsson C
Category | C2
Sub-category | CGP
Brief description | Top up-regulated genes distinguishing between follicular thyroid carcinoma (FTC) samples by the presence or absence of the PAX8-PPARG [GeneID=7849;5468] fusion protein.
Full description | The demonstration of the PAX8-PPAR(gamma) fusion oncogene in a subset of follicular thyroid tumors provides a new and promising starting point to dissect the molecular genetic events involved in the development of this tumor form. In the present study, we compared the gene expression profiles of follicular thyroid carcinomas (FTCs) bearing a PAX8-PPAR(gamma) fusion against FTCs that lack this fusion. Using unsupervised clustering and multidimensional scaling analyses, we show that FTCs possessing a PAX8-PPAR(gamma) fusion have a highly uniform and distinct gene expression signature that clearly distinguishes them from FTCs without the fusion. The PAX8-PPAR(gamma)(+) FTCs grouped in a defined cluster, where highly ranked genes were mostly associated with signal transduction, cell growth and translation control. Notably, a large number of ribosomal protein and translation-associated genes were concurrently underexpressed in the FTCs with the fusion. Taken together, our findings further support that follicular carcinomas with a PAX8-PPAR(gamma) rearrangement constitute a distinct biological entity. The current data represent one step to elucidate the molecular pathways in the development of FTCs with the specific PAX8-PPAR(gamma) fusion.

Standard name | LUI_THYROID_CANCER_PAX8_PPARG_DN
Systematic name | M4902
Organism | Homo sapiens
PMID | 15608688
Authors | Lui WO,Foukakis T,Lidén J,Thoppe SR,Dwight T,Höög A,Zedenius J,Wallin G,Reimers M,Larsson C
Category | C2
Sub-category | CGP
Brief description | Top down-regulated genes distinguishing between follicular thyroid carcinoma (FTC) samples by the presence or absence of the PAX8-PPARG [GeneID=7849;5468] fusion protein.
Full description | The demonstration of the PAX8-PPAR(gamma) fusion oncogene in a subset of follicular thyroid tumors provides a new and promising starting point to dissect the molecular genetic events involved in the development of this tumor form. In the present study, we compared the gene expression profiles of follicular thyroid carcinomas (FTCs) bearing a PAX8-PPAR(gamma) fusion against FTCs that lack this fusion. Using unsupervised clustering and multidimensional scaling analyses, we show that FTCs possessing a PAX8-PPAR(gamma) fusion have a highly uniform and distinct gene expression signature that clearly distinguishes them from FTCs without the fusion. The PAX8-PPAR(gamma)(+) FTCs grouped in a defined cluster, where highly ranked genes were mostly associated with signal transduction, cell growth and translation control. Notably, a large number of ribosomal protein and translation-associated genes were concurrently underexpressed in the FTCs with the fusion. Taken together, our findings further support that follicular carcinomas with a PAX8-PPAR(gamma) rearrangement constitute a distinct biological entity. The current data represent one step to elucidate the molecular pathways in the development of FTCs with the specific PAX8-PPAR(gamma) fusion.

Standard name | HAMAI_APOPTOSIS_VIA_TRAIL_UP
Systematic name | M18979
Organism | Homo sapiens
PMID | 16983347
Authors | Hamaï A,Richon C,Meslin F,Faure F,Kauffmann A,Lecluse Y,Jalil A,Larue L,Avril MF,Chouaib S,Mehrpour M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T1 cells (primary melanoma, sensitive to TRAIL [GeneID=8743]) compared to G1 cells (metastatic melanoma, resistant to TRAIL).
Full description | In order to define genetic determinants of primary and metastatic melanoma cell susceptibility to tumor necrosis factor-related apoptosis-inducing ligand (TRAIL), we have applied oligonucleotide microarrays to TRAIL-sensitive primary T1 cells and TRAIL-resistant metastatic G1 cells treated or not with TRAIL. T1 and G1 cells are isogenic melanoma cell subclones. We examined 22 000 spots, 4.2% of which displayed differential expression in G1 and T1 cells. Cell susceptibility to TRAIL-mediated apoptosis was found to be correlated with gene expression signatures in this model. Some of the differentially expressed genes were identified as involved in ATP-binding and signaling pathways, based on previously published data. Further analysis provided evidences that c-kit was overexpressed in G1 cells while it was absent in T1 cells. The c-kit inhibitor, imatinib, did not restore TRAIL sensitivity, excluding a role for c-kit in TRAIL resistance in G1 cells. Surprisingly, imatinib inhibited cell proliferation and TRAIL-mediated apoptosis in melanoma cells. We investigated the possible involvement of several molecules, including c-ABL, platelet-derived growth factor receptor (PDGFR), cellular FADD-like interleukin-1 alpha-converting enzyme-like inhibitory protein (c-FLIP)(L/S), Fas-associated DD kinase, p53, p21(WAF1), proteins of B-cell leukemia/lymphoma 2 (Bcl-2) family and cytochrome c. Imatinib did not modulate the expression or activation of its own targets, such as c-ABL, PDGFRalpha and PDGFRbeta, but it did affect the expression of c-FLIP(L), BCL2-associated X protein (Bax) and Bcl-2. Moreover, c-FLIP(L) knockdown sensitized T1 cells to TRAIL-mediated apoptosis, with a sensitivity similar to that of cells previously treated with imatinib. More notably, we found that the resistance to TRAIL in G1 cells was correlated with constitutive c-FLIP(L) recruitment to the DISC and the inhibition of caspase 8, 3 and 9 processing. Moreover, c-FLIP(L) knockdown partly restored TRAIL sensitivity in G1 cells, indicating that the expression level of c-FLIP(L) and its interaction with TRAIL receptor2 play a crucial role in determining TRAIL resistance in metastatic melanoma cells. Our results also show that imatinib enhances TRAIL-induced cell death independently of BH3-interacting domain death agonist translocation, in a process involving the Bax:Bcl-X(L) ratio, Bax:Bcl-X(L)/Bcl-2 translocation, cytochrome c release and caspase activation. Our data indicate that imatinib sensitizes T1 cells by directly downregulating c-FLIP(L), with the use of an alternative pathway for antitumor activity, because PDGFRalpha is not activated in T1 cells and these cells do not express c-kit, c-ABL or PDGFRbeta. Caspase cascade activation and mitochondria also play a key role in the imatinib-mediated sensitization of melanoma cells to the proapoptotic action of TRAIL.

Standard name | HAMAI_APOPTOSIS_VIA_TRAIL_DN
Systematic name | M15912
Organism | Homo sapiens
PMID | 16983347
Authors | Hamaï A,Richon C,Meslin F,Faure F,Kauffmann A,Lecluse Y,Jalil A,Larue L,Avril MF,Chouaib S,Mehrpour M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T1 cells (primary melanoma, sensitive to TRAIL [GeneID=8743]) compared to G1 cells (metastatic melanoma, resistant to TRAIL).
Full description | In order to define genetic determinants of primary and metastatic melanoma cell susceptibility to tumor necrosis factor-related apoptosis-inducing ligand (TRAIL), we have applied oligonucleotide microarrays to TRAIL-sensitive primary T1 cells and TRAIL-resistant metastatic G1 cells treated or not with TRAIL. T1 and G1 cells are isogenic melanoma cell subclones. We examined 22 000 spots, 4.2% of which displayed differential expression in G1 and T1 cells. Cell susceptibility to TRAIL-mediated apoptosis was found to be correlated with gene expression signatures in this model. Some of the differentially expressed genes were identified as involved in ATP-binding and signaling pathways, based on previously published data. Further analysis provided evidences that c-kit was overexpressed in G1 cells while it was absent in T1 cells. The c-kit inhibitor, imatinib, did not restore TRAIL sensitivity, excluding a role for c-kit in TRAIL resistance in G1 cells. Surprisingly, imatinib inhibited cell proliferation and TRAIL-mediated apoptosis in melanoma cells. We investigated the possible involvement of several molecules, including c-ABL, platelet-derived growth factor receptor (PDGFR), cellular FADD-like interleukin-1 alpha-converting enzyme-like inhibitory protein (c-FLIP)(L/S), Fas-associated DD kinase, p53, p21(WAF1), proteins of B-cell leukemia/lymphoma 2 (Bcl-2) family and cytochrome c. Imatinib did not modulate the expression or activation of its own targets, such as c-ABL, PDGFRalpha and PDGFRbeta, but it did affect the expression of c-FLIP(L), BCL2-associated X protein (Bax) and Bcl-2. Moreover, c-FLIP(L) knockdown sensitized T1 cells to TRAIL-mediated apoptosis, with a sensitivity similar to that of cells previously treated with imatinib. More notably, we found that the resistance to TRAIL in G1 cells was correlated with constitutive c-FLIP(L) recruitment to the DISC and the inhibition of caspase 8, 3 and 9 processing. Moreover, c-FLIP(L) knockdown partly restored TRAIL sensitivity in G1 cells, indicating that the expression level of c-FLIP(L) and its interaction with TRAIL receptor2 play a crucial role in determining TRAIL resistance in metastatic melanoma cells. Our results also show that imatinib enhances TRAIL-induced cell death independently of BH3-interacting domain death agonist translocation, in a process involving the Bax:Bcl-X(L) ratio, Bax:Bcl-X(L)/Bcl-2 translocation, cytochrome c release and caspase activation. Our data indicate that imatinib sensitizes T1 cells by directly downregulating c-FLIP(L), with the use of an alternative pathway for antitumor activity, because PDGFRalpha is not activated in T1 cells and these cells do not express c-kit, c-ABL or PDGFRbeta. Caspase cascade activation and mitochondria also play a key role in the imatinib-mediated sensitization of melanoma cells to the proapoptotic action of TRAIL.

Standard name | OUELLET_CULTURED_OVARIAN_CANCER_INVASIVE_VS_LMP_UP
Systematic name | M836
Organism | Homo sapiens
PMID | 15940270
Authors | Ouellet V,Provencher DM,Maugard CM,Le Page C,Ren F,Lussier C,Novak J,Ge B,Hudson TJ,Tonin PN,Mes-Masson AM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pirmary cultures of epithelial ovarian cancer (EOC): invasive (TOV) vs low malignant potential (LMP) tumors.
Full description | Tumors of low malignant potential (LMP) represent 20% of epithelial ovarian cancers (EOCs) and are associated with a better prognosis than the invasive tumors (TOV). Defining the relationship between LMPs and TOVs remains an important goal towards understanding the molecular pathways that contribute to prognosis, as well as providing molecular markers, for these EOCs. To this end, DNA microarray analyses were performed either in a primary culture or a tumor tissue model system and selected candidate genes showing a distinctive expression profile between LMPs and TOVs were identified using a class prediction approach based on three statistical methods of analysis. Both model systems appear relevant as candidate genes identified by either model allowed the proper reclassification of samples as either LMPs or TOVs. Selected candidate genes (CAS, CCNE1, LGALS8, ITGbeta3, ATP1B1, FLIP, KRT7 and KRT19) were validated by real-time quantitative PCR analysis and show differential expression between LMPs and TOVs. Immunohistochemistry analyses showed that the two tumor classes were distinguishable by their expression of CAS, TNFR1A, FLIP, CKS1 and CCNE1. These results define signature patterns for gene expression of LMPs and TOVs and identify gene candidates that warrant further study to deepen our understanding of the biology of EOC.

Standard name | OUELLET_CULTURED_OVARIAN_CANCER_INVASIVE_VS_LMP_DN
Systematic name | M13220
Organism | Homo sapiens
PMID | 15940270
Authors | Ouellet V,Provencher DM,Maugard CM,Le Page C,Ren F,Lussier C,Novak J,Ge B,Hudson TJ,Tonin PN,Mes-Masson AM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pirmary cultures of epithelial ovarian cancer (EOC): invasive (TOV) vs low malignant potential (LMP) tumors.
Full description | Tumors of low malignant potential (LMP) represent 20% of epithelial ovarian cancers (EOCs) and are associated with a better prognosis than the invasive tumors (TOV). Defining the relationship between LMPs and TOVs remains an important goal towards understanding the molecular pathways that contribute to prognosis, as well as providing molecular markers, for these EOCs. To this end, DNA microarray analyses were performed either in a primary culture or a tumor tissue model system and selected candidate genes showing a distinctive expression profile between LMPs and TOVs were identified using a class prediction approach based on three statistical methods of analysis. Both model systems appear relevant as candidate genes identified by either model allowed the proper reclassification of samples as either LMPs or TOVs. Selected candidate genes (CAS, CCNE1, LGALS8, ITGbeta3, ATP1B1, FLIP, KRT7 and KRT19) were validated by real-time quantitative PCR analysis and show differential expression between LMPs and TOVs. Immunohistochemistry analyses showed that the two tumor classes were distinguishable by their expression of CAS, TNFR1A, FLIP, CKS1 and CCNE1. These results define signature patterns for gene expression of LMPs and TOVs and identify gene candidates that warrant further study to deepen our understanding of the biology of EOC.

Standard name | HUMMERICH_BENIGN_SKIN_TUMOR_UP
Systematic name | M1122
Organism | Mus musculus
PMID | 16247483
Authors | Hummerich L,Müller R,Hess J,Kokocinski F,Hahn M,Fürstenberger G,Mauch C,Lichter P,Angel P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in benign skin tumors (papilloma) induced by treatment with DMBA and TPA [PubChem=6001;4792] chemicals in the two stage skin carcinogenesis model.
Full description | Chemically induced mouse skin carcinogenesis represents the most extensively utilized animal model to unravel the multistage nature of tumour development and to design novel therapeutic concepts of human epithelial neoplasia. We combined this tumour model with comprehensive gene expression analysis and could identify a large set of novel tumour-associated genes that have not been associated with epithelial skin cancer development yet. Expression data of selected genes were confirmed by semiquantitative and quantitative RT-PCR as well as in situ hybridization and immunofluorescence analysis on mouse tumour sections. Enhanced expression of genes identified in our screen was also demonstrated in mouse keratinocyte cell lines that form tumours in vivo. Self-organizing map clustering was performed to identify different kinetics of gene expression and coregulation during skin cancer progression. Detailed analysis of differential expressed genes according to their functional annotation confirmed the involvement of several biological processes, such as regulation of cell cycle, apoptosis, extracellular proteolysis and cell adhesion, during skin malignancy. Finally, we detected high transcript levels of ANXA1, LCN2 and S100A8 as well as reduced levels for NDR2 protein in human skin tumour specimens demonstrating that tumour-associated genes identified in the chemically induced tumour model might be of great relevance for the understanding of human epithelial malignancies as well.

Standard name | HUMMERICH_BENIGN_SKIN_TUMOR_DN
Systematic name | M1123
Organism | Mus musculus
PMID | 16247483
Authors | Hummerich L,Müller R,Hess J,Kokocinski F,Hahn M,Fürstenberger G,Mauch C,Lichter P,Angel P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in benign skin tumors (papilloma) induced by treatment with DMBA and TPA [PubChem=6001;4792] chemicals in the two stage skin carcinogenesis model.
Full description | Chemically induced mouse skin carcinogenesis represents the most extensively utilized animal model to unravel the multistage nature of tumour development and to design novel therapeutic concepts of human epithelial neoplasia. We combined this tumour model with comprehensive gene expression analysis and could identify a large set of novel tumour-associated genes that have not been associated with epithelial skin cancer development yet. Expression data of selected genes were confirmed by semiquantitative and quantitative RT-PCR as well as in situ hybridization and immunofluorescence analysis on mouse tumour sections. Enhanced expression of genes identified in our screen was also demonstrated in mouse keratinocyte cell lines that form tumours in vivo. Self-organizing map clustering was performed to identify different kinetics of gene expression and coregulation during skin cancer progression. Detailed analysis of differential expressed genes according to their functional annotation confirmed the involvement of several biological processes, such as regulation of cell cycle, apoptosis, extracellular proteolysis and cell adhesion, during skin malignancy. Finally, we detected high transcript levels of ANXA1, LCN2 and S100A8 as well as reduced levels for NDR2 protein in human skin tumour specimens demonstrating that tumour-associated genes identified in the chemically induced tumour model might be of great relevance for the understanding of human epithelial malignancies as well.

Standard name | MCBRYAN_PUBERTAL_TGFB1_TARGETS_UP
Systematic name | M1124
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Pubertal genes up-regulated by TGFB1 [GeneID=7040].
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | MCBRYAN_PUBERTAL_TGFB1_TARGETS_DN
Systematic name | M1125
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Pubertal genes down-regulated by TGFB1 [GeneID=7040].
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | HUMMERICH_MALIGNANT_SKIN_TUMOR_UP
Systematic name | M1126
Organism | Mus musculus
PMID | 16247483
Authors | Hummerich L,Müller R,Hess J,Kokocinski F,Hahn M,Fürstenberger G,Mauch C,Lichter P,Angel P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in malignant skin tumors (squamous cell carcinoma, SCC) formed by treatment with DMBA and TPA [PubChem=6001;4792] in the two stage skin carcinogenesis model.
Full description | Chemically induced mouse skin carcinogenesis represents the most extensively utilized animal model to unravel the multistage nature of tumour development and to design novel therapeutic concepts of human epithelial neoplasia. We combined this tumour model with comprehensive gene expression analysis and could identify a large set of novel tumour-associated genes that have not been associated with epithelial skin cancer development yet. Expression data of selected genes were confirmed by semiquantitative and quantitative RT-PCR as well as in situ hybridization and immunofluorescence analysis on mouse tumour sections. Enhanced expression of genes identified in our screen was also demonstrated in mouse keratinocyte cell lines that form tumours in vivo. Self-organizing map clustering was performed to identify different kinetics of gene expression and coregulation during skin cancer progression. Detailed analysis of differential expressed genes according to their functional annotation confirmed the involvement of several biological processes, such as regulation of cell cycle, apoptosis, extracellular proteolysis and cell adhesion, during skin malignancy. Finally, we detected high transcript levels of ANXA1, LCN2 and S100A8 as well as reduced levels for NDR2 protein in human skin tumour specimens demonstrating that tumour-associated genes identified in the chemically induced tumour model might be of great relevance for the understanding of human epithelial malignancies as well.

Standard name | HUMMERICH_MALIGNANT_SKIN_TUMOR_DN
Systematic name | M1127
Organism | Mus musculus
PMID | 16247483
Authors | Hummerich L,Müller R,Hess J,Kokocinski F,Hahn M,Fürstenberger G,Mauch C,Lichter P,Angel P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in malignant skin tumors (squamous cell carcinoma, SCC) formed by treatment with DMBA and TPA [PubChem=6001;4792] in the two stage skin carcinogenesis model.
Full description | Chemically induced mouse skin carcinogenesis represents the most extensively utilized animal model to unravel the multistage nature of tumour development and to design novel therapeutic concepts of human epithelial neoplasia. We combined this tumour model with comprehensive gene expression analysis and could identify a large set of novel tumour-associated genes that have not been associated with epithelial skin cancer development yet. Expression data of selected genes were confirmed by semiquantitative and quantitative RT-PCR as well as in situ hybridization and immunofluorescence analysis on mouse tumour sections. Enhanced expression of genes identified in our screen was also demonstrated in mouse keratinocyte cell lines that form tumours in vivo. Self-organizing map clustering was performed to identify different kinetics of gene expression and coregulation during skin cancer progression. Detailed analysis of differential expressed genes according to their functional annotation confirmed the involvement of several biological processes, such as regulation of cell cycle, apoptosis, extracellular proteolysis and cell adhesion, during skin malignancy. Finally, we detected high transcript levels of ANXA1, LCN2 and S100A8 as well as reduced levels for NDR2 protein in human skin tumour specimens demonstrating that tumour-associated genes identified in the chemically induced tumour model might be of great relevance for the understanding of human epithelial malignancies as well.

Standard name | LUCAS_HNF4A_TARGETS_UP
Systematic name | M11410
Organism | Homo sapiens
PMID | 16007190
Authors | Lucas B,Grigo K,Erdmann S,Lausen J,Klein-Hitpass L,Ryffel GU
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Tet-On HEK293 cells (embryonic kidney) by expression of HNF4A [GeneID=3172].
Full description | Hepatocyte nuclear factor 4alpha (HNF4alpha) is a tissue-specific transcription factor known to regulate a large number of genes in hepatocytes and pancreatic beta cells. Although HNF4alpha is highly expressed in some sections of the kidney, little is known about its role in this organ and about HNF4alpha-regulated genes in the kidney cells. The abundance and activity of HNF4alpha are frequently reduced in renal cell carcinoma (RCC) indicating some tumor suppressing function of HNF4alpha in renal cells. To determine the potential role of HNF4alpha in RCC, we used Flp recombinase-mediated gene integration to generate human embryonic kidney cells (HEK293) that conditionally express wild-type or mutated HNF4alpha. Expression of wild-type HNF4alpha but not of the mutants led to reduction of proliferation and alterations of cell morphology. These effects were reversible and induced at physiological concentrations of HNF4alpha. Using gene expression profiling by microarrays, we determined genes regulated by HNF4alpha. Interestingly, many of the genes regulated by HNF4alpha have been shown to be deregulated in RCC microarray studies. These genes (ACY1, WT1, SELENBP1, COBL, EFHD1, AGXT2L1, ALDH5A1, THEM2, ABCB1, FLJ14146, CSPG2, TRIM9 and HEY1) are good candidates for genes whose activity is changed upon the decrease of HNF4alpha in RCC.

Standard name | LUCAS_HNF4A_TARGETS_DN
Systematic name | M10457
Organism | Homo sapiens
PMID | 16007190
Authors | Lucas B,Grigo K,Erdmann S,Lausen J,Klein-Hitpass L,Ryffel GU
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Tet-On HEK293 cells (embryonic kidney) by expression of HNF4A [GeneID=3172].
Full description | Hepatocyte nuclear factor 4alpha (HNF4alpha) is a tissue-specific transcription factor known to regulate a large number of genes in hepatocytes and pancreatic beta cells. Although HNF4alpha is highly expressed in some sections of the kidney, little is known about its role in this organ and about HNF4alpha-regulated genes in the kidney cells. The abundance and activity of HNF4alpha are frequently reduced in renal cell carcinoma (RCC) indicating some tumor suppressing function of HNF4alpha in renal cells. To determine the potential role of HNF4alpha in RCC, we used Flp recombinase-mediated gene integration to generate human embryonic kidney cells (HEK293) that conditionally express wild-type or mutated HNF4alpha. Expression of wild-type HNF4alpha but not of the mutants led to reduction of proliferation and alterations of cell morphology. These effects were reversible and induced at physiological concentrations of HNF4alpha. Using gene expression profiling by microarrays, we determined genes regulated by HNF4alpha. Interestingly, many of the genes regulated by HNF4alpha have been shown to be deregulated in RCC microarray studies. These genes (ACY1, WT1, SELENBP1, COBL, EFHD1, AGXT2L1, ALDH5A1, THEM2, ABCB1, FLJ14146, CSPG2, TRIM9 and HEY1) are good candidates for genes whose activity is changed upon the decrease of HNF4alpha in RCC.

Standard name | ZIRN_TRETINOIN_RESPONSE_WT1_UP
Systematic name | M17312
Organism | Homo sapiens
PMID | 15897880
Authors | Zirn B,Samans B,Spangenberg C,Graf N,Eilers M,Gessler M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MZ128 cells (Wilms tumor with mutated WT1 [GeneID=7490]) after treatment with 10 microM tretinoin (ATRA) [PubChem=444795] for 24 h.
Full description | Wilms tumor is one of the most frequent neoplasias in children. Our previous microarray screening in a large series of Wilms tumors revealed several candidate genes that are deregulated in advanced tumors and are part of the retinoic acid signaling pathway. To investigate whether retinoic acid could be employed as a novel therapeutic agent in these tumors, we treated cultured Wilms tumor cells with different concentrations of all-trans retinoic acid (ATRA) and assessed gene expression changes by real-time RT-PCR as well as microarray analysis. Several genes like RARRES1, RARRES3, CTGF, CKS2, CCNA2, IGFBP3, UBE2C, CCL2 or ITM2B that were previously found to be deregulated in advanced tumors exhibited opposite expression changes after ATRA treatment. In addition to enhanced retinoid signaling, the transforming growth factor-beta (TGFbeta) pathway was strongly activated by ATRA treatment of Wilms tumor cells. Both the retinoic acid and the TGFbeta pathway mediate inhibition of cell growth. These findings represent the first molecular evidence of a potential benefit from ATRA treatment in Wilms tumors.

Standard name | ZIRN_TRETINOIN_RESPONSE_WT1_DN
Systematic name | M7641
Organism | Homo sapiens
PMID | 15897880
Authors | Zirn B,Samans B,Spangenberg C,Graf N,Eilers M,Gessler M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MZ128 cells (Wilms tumor with mutated WT1 [GeneID=7490]) after treatment with 10 microM tretinoin (ATRA) [PubChem=444795] for 24 h.
Full description | Wilms tumor is one of the most frequent neoplasias in children. Our previous microarray screening in a large series of Wilms tumors revealed several candidate genes that are deregulated in advanced tumors and are part of the retinoic acid signaling pathway. To investigate whether retinoic acid could be employed as a novel therapeutic agent in these tumors, we treated cultured Wilms tumor cells with different concentrations of all-trans retinoic acid (ATRA) and assessed gene expression changes by real-time RT-PCR as well as microarray analysis. Several genes like RARRES1, RARRES3, CTGF, CKS2, CCNA2, IGFBP3, UBE2C, CCL2 or ITM2B that were previously found to be deregulated in advanced tumors exhibited opposite expression changes after ATRA treatment. In addition to enhanced retinoid signaling, the transforming growth factor-beta (TGFbeta) pathway was strongly activated by ATRA treatment of Wilms tumor cells. Both the retinoic acid and the TGFbeta pathway mediate inhibition of cell growth. These findings represent the first molecular evidence of a potential benefit from ATRA treatment in Wilms tumors.

Standard name | ZIRN_TRETINOIN_RESPONSE_UP
Systematic name | M581
Organism | Homo sapiens
PMID | 15897880
Authors | Zirn B,Samans B,Spangenberg C,Graf N,Eilers M,Gessler M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MS427 cells (Wilms tumor with normal WT1 [GeneID=7490]) after treatment with 10 microM tretinoin (ATRA) [PubChem=444795] for 24 h.
Full description | Wilms tumor is one of the most frequent neoplasias in children. Our previous microarray screening in a large series of Wilms tumors revealed several candidate genes that are deregulated in advanced tumors and are part of the retinoic acid signaling pathway. To investigate whether retinoic acid could be employed as a novel therapeutic agent in these tumors, we treated cultured Wilms tumor cells with different concentrations of all-trans retinoic acid (ATRA) and assessed gene expression changes by real-time RT-PCR as well as microarray analysis. Several genes like RARRES1, RARRES3, CTGF, CKS2, CCNA2, IGFBP3, UBE2C, CCL2 or ITM2B that were previously found to be deregulated in advanced tumors exhibited opposite expression changes after ATRA treatment. In addition to enhanced retinoid signaling, the transforming growth factor-beta (TGFbeta) pathway was strongly activated by ATRA treatment of Wilms tumor cells. Both the retinoic acid and the TGFbeta pathway mediate inhibition of cell growth. These findings represent the first molecular evidence of a potential benefit from ATRA treatment in Wilms tumors.

Standard name | ZIRN_TRETINOIN_RESPONSE_DN
Systematic name | M8292
Organism | Homo sapiens
PMID | 15897880
Authors | Zirn B,Samans B,Spangenberg C,Graf N,Eilers M,Gessler M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MS427 cells (Wilms tumor with normal WT1 [GeneID=7490]) after treatment with 10 microM tretinoin (ATRA) [PubChem=444795] for 24 h.
Full description | Wilms tumor is one of the most frequent neoplasias in children. Our previous microarray screening in a large series of Wilms tumors revealed several candidate genes that are deregulated in advanced tumors and are part of the retinoic acid signaling pathway. To investigate whether retinoic acid could be employed as a novel therapeutic agent in these tumors, we treated cultured Wilms tumor cells with different concentrations of all-trans retinoic acid (ATRA) and assessed gene expression changes by real-time RT-PCR as well as microarray analysis. Several genes like RARRES1, RARRES3, CTGF, CKS2, CCNA2, IGFBP3, UBE2C, CCL2 or ITM2B that were previously found to be deregulated in advanced tumors exhibited opposite expression changes after ATRA treatment. In addition to enhanced retinoid signaling, the transforming growth factor-beta (TGFbeta) pathway was strongly activated by ATRA treatment of Wilms tumor cells. Both the retinoic acid and the TGFbeta pathway mediate inhibition of cell growth. These findings represent the first molecular evidence of a potential benefit from ATRA treatment in Wilms tumors.

Standard name | STREICHER_LSM1_TARGETS_UP
Systematic name | M15031
Organism | Homo sapiens
PMID | 17001308
Authors | Streicher KL,Yang ZQ,Draghici S,Ethier SP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF10A cells (breast cancer) by expression of LSM1 [GeneID=27257] off a letiviral vector.
Full description | Amplification of the 8p11-12 region occurs in 15-20% of breast cancers, but the driving oncogene at this locus has yet to be definitively identified. We mapped the 8p11-12 amplicon in breast cancer cell lines and primary human breast cancers and identified the candidate oncogene human Sm-like protein (hLsm1, LSM1) based on increases in copy number and expression level relative to human mammary epithelial cells. To examine the oncogenic role of LSM1, we overexpressed this gene in MCF10A mammary epithelial cells and inhibited its production in the SUM44 breast cancer cell line, which has a natural amplification and overexpression of LSM1. Our data confirmed that LSM1 is an oncogene from the 8p11-12 amplicon by showing that hLsm1 overexpression induced growth factor-independent proliferation and soft agar colony formation in MCF10A cells, and hLsm1 inhibition in SUM44 cells dramatically reduced soft agar growth. Little is known about hLsm1 function other than its involvement in mRNA degradation; therefore, we used expression microarray analysis to investigate how hLsm1 affects cell transformation in MCF10A and SUM44 cells. We identified numerous genes altered following hLsm1 overexpression common to SUM44 breast cancer cells that play important roles in cell cycle regulation, cell proliferation and other cancer-promoting processes. Future work will continue to characterize these important changes to achieve a more complete understanding of the mechanism of hLsm1's effect on cancer progression.

Standard name | STREICHER_LSM1_TARGETS_DN
Systematic name | M8637
Organism | Homo sapiens
PMID | 17001308
Authors | Streicher KL,Yang ZQ,Draghici S,Ethier SP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF10A cells (breast cancer) by expression of LSM1 [GeneID=27257] off a letiviral vector.
Full description | Amplification of the 8p11-12 region occurs in 15-20% of breast cancers, but the driving oncogene at this locus has yet to be definitively identified. We mapped the 8p11-12 amplicon in breast cancer cell lines and primary human breast cancers and identified the candidate oncogene human Sm-like protein (hLsm1, LSM1) based on increases in copy number and expression level relative to human mammary epithelial cells. To examine the oncogenic role of LSM1, we overexpressed this gene in MCF10A mammary epithelial cells and inhibited its production in the SUM44 breast cancer cell line, which has a natural amplification and overexpression of LSM1. Our data confirmed that LSM1 is an oncogene from the 8p11-12 amplicon by showing that hLsm1 overexpression induced growth factor-independent proliferation and soft agar colony formation in MCF10A cells, and hLsm1 inhibition in SUM44 cells dramatically reduced soft agar growth. Little is known about hLsm1 function other than its involvement in mRNA degradation; therefore, we used expression microarray analysis to investigate how hLsm1 affects cell transformation in MCF10A and SUM44 cells. We identified numerous genes altered following hLsm1 overexpression common to SUM44 breast cancer cells that play important roles in cell cycle regulation, cell proliferation and other cancer-promoting processes. Future work will continue to characterize these important changes to achieve a more complete understanding of the mechanism of hLsm1's effect on cancer progression.

Standard name | KAN_RESPONSE_TO_ARSENIC_TRIOXIDE
Systematic name | M1784
Organism | Homo sapiens
PMID | 15592527
Authors | Kanzawa T,Zhang L,Xiao L,Germano IM,Kondo Y,Kondo S
Category | C2
Sub-category | CGP
Brief description | Genes changed in U373-MG cells (malignant glioma) upon treatment with arsenic trioxide [PubChem=14888], a chemical that can cause autophagic cell death.
Full description | Arsenic trioxide (As(2)O(3)) has shown considerable efficacy in treating hematological malignancies with induction of programmed cell death (PCD) type I, apoptosis. However, the mechanisms underlying the antitumor effect of As(2)O(3) on solid tumors are poorly defined. Previously, we reported that As(2)O(3) induced autophagic cell death (PCD type II) but not apoptosis in human malignant glioma cell lines. The purpose of this study was to elucidate the molecular pathway leading to autophagic cell death. In this study, we demonstrated that the cell death was accompanied by involvement of autophagy-specific marker, microtubule-associated protein light chain 3 (LC3), and damage of mitochondrial membrane integrity, but not by caspase activation. Analysis by cDNA microarray, RT-PCR, and Western blot showed that cell death members of Bcl-2 family, Bcl-2/adenovirus E1B 19-kDa-interacting protein 3 (BNIP3) and its homologue BNIP3-like (BNIP3L), were upregulated in As(2)O(3)-induced autophagic cell death. Exogenous expression of BNIP3, but not BNIP3L, induced autophagic cell death in malignant glioma cells without As(2)O(3) treatment. When upregulation of BNIP3 induced by As(2)O(3) was suppressed by a dominant-negative effect of the transmembrane-deleted BNIP3 (BNIP3 Delta TM), autophagic cell death was inhibited. In contrast, BNIP3 transfection augmented As(2)O(3)-induced autophagic cell death. These results suggest that BNIP3 plays a central role in As(2)O(3)-induced autophagic cell death in malignant glioma cells. This study adds a new concept to characterize the pathways by which As(2)O(3) acts to induce autophagic cell death in malignant glioma cells.

Standard name | LANG_MYB_FAMILY_TARGETS
Systematic name | M1128
Organism | Mus musculus
PMID | 15608679
Authors | Lang G,White JR,Argent-Katwala MJ,Allinson CG,Weston K
Category | C2
Sub-category | CGP
Brief description | Myb family target genes.
Full description | Hematopoiesis, the process by which mature blood cells arise, is controlled by multiple transcription factors, which act in stage- and lineage-specific complexes. It is a major goal to elucidate the genes regulated by these transcription factors, in order to obtain a full understanding of the process and its malignant counterpart, leukemia. Myb family transcription factors play a central role in hematopoiesis. To identify new Myb family target genes, we have used an inducible dominant-negative protein for a subtraction cloning protocol in a model cell system (FDCP-Mix) with many characteristics of normal hematopoiesis. We present here a novel group of 29 validated Myb family target genes of diverse functions.

Standard name | MCBRYAN_TERMINAL_END_BUD_UP
Systematic name | M1129
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | The 'TEB profile genes': up-regulated during pubertal mammary gland development specifically in the TEB (terminal end bud) structures.
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | MCBRYAN_TERMINAL_END_BUD_DN
Systematic name | M1130
Organism | Mus musculus
PMID | 17486082
Authors | McBryan J,Howlin J,Kenny PA,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | The 'TEB profile genes': down-regulated during pubertal mammary gland development specifically in the TEB (terminal end bud) structures.
Full description | Expression microarray analysis identified over 930 genes regulated during puberty in the mouse mammary gland. Most prominent were genes whose expression increased in parallel with pubertal development and remained high thereafter. Members of the Wnt, transforming growth factor-beta and oestrogen-signalling pathways were significantly overrepresented. Comparison to expression data from CITED1 knockout mice identified a subset of oestrogen-responsive genes displaying altered expression in the absence of CITED1. Included in this subset are stanniocalcin2 (Stc2) and amphiregulin (Areg). Chromatin immunoprecipitation revealed that ERalpha binds to oestrogen response elements in both the Stc2 and Areg genes in the mammary gland during puberty. Additionally, CITED1 and ERalpha localize to the same epithelial cells of the pubertal mammary gland, supporting a role for interaction of these two proteins during normal development. In a human breast cancer data set, expression of Stc2, Areg and CITED1 parallel that of ERalpha. Similar to ERalpha, CITED1 expression correlates with good outcome in breast cancer, implying that potential maintenance of the ERalpha-CITED1 co-regulated signalling pathway in breast tumours can indicate good prognosis.

Standard name | NUNODA_RESPONSE_TO_DASATINIB_IMATINIB_UP
Systematic name | M15510
Organism | Homo sapiens
PMID | 17213809
Authors | Nunoda K,Tauchi T,Takaku T,Okabe S,Akahane D,Sashida G,Ohyashiki JH,Ohyashiki K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in K562 cells (bone marrow) after treatment with dasatinib [PubChem=3062316] or imatinib [PubChem=5291].
Full description | Dasatinib is an ATP-competitive, multi-targeted SRC and ABL kinase inhibitor that can bind BCR-ABL in both the active and inactive conformations. From a clinical standpoint, dasatinib is particularly attractive because it has been shown to induce hematologic and cytogenetic responses in imatinib-resistant chronic myeloid leukemia patients. The fact because the combination of imatinib and dasatinib shows the additive/synergistic growth inhibition on wild-type p210 BCR-ABL-expressing cells, we reasoned that these ABL kinase inhibitors might induce the different molecular pathways. To address this question, we used DNA microarrays to identify genes whose transcription was altered by imatinib and dasatinib. K562 cells were cultured with imatinib or dasatinib for 16 h, and gene expression data were obtained from three independent microarray hybridizations. Almost all of the imatinib- and dasatinib-responsive genes appeared to be similarly increased or decreased in K562 cells; however, small subsets of genes were identified as selectively altered expression by either imatinib or dasatinib. The distinct genes that are selectively modulated by dasatinib are cyclin-dependent kinase 2 (CDK2) and CDK8, which had a maximal reduction of <5-fold in microarray screen. To assess the functional importance of dasatinib regulated genes, we used RNA interference to determine whether reduction of CDK2 and CDK8 affected the growth inhibition. K562 and TF-1BCR-ABL cells, pretreated with CDK2 or CDK8 small interfering RNA, showed additive growth inhibition with imatinib, but not with dasatinib. These findings demonstrate that the additive/synergistic growth inhibition by imatinib and dasatinib may be mediated in part by CDK2 and CDK8.

Standard name | NUNODA_RESPONSE_TO_DASATINIB_IMATINIB_DN
Systematic name | M14174
Organism | Homo sapiens
PMID | 17213809
Authors | Nunoda K,Tauchi T,Takaku T,Okabe S,Akahane D,Sashida G,Ohyashiki JH,Ohyashiki K
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in K562 cells (bone marrow) after treatment with dasatinib [PubChem=3062316] or imatinib [PubChem=5291].
Full description | Dasatinib is an ATP-competitive, multi-targeted SRC and ABL kinase inhibitor that can bind BCR-ABL in both the active and inactive conformations. From a clinical standpoint, dasatinib is particularly attractive because it has been shown to induce hematologic and cytogenetic responses in imatinib-resistant chronic myeloid leukemia patients. The fact because the combination of imatinib and dasatinib shows the additive/synergistic growth inhibition on wild-type p210 BCR-ABL-expressing cells, we reasoned that these ABL kinase inhibitors might induce the different molecular pathways. To address this question, we used DNA microarrays to identify genes whose transcription was altered by imatinib and dasatinib. K562 cells were cultured with imatinib or dasatinib for 16 h, and gene expression data were obtained from three independent microarray hybridizations. Almost all of the imatinib- and dasatinib-responsive genes appeared to be similarly increased or decreased in K562 cells; however, small subsets of genes were identified as selectively altered expression by either imatinib or dasatinib. The distinct genes that are selectively modulated by dasatinib are cyclin-dependent kinase 2 (CDK2) and CDK8, which had a maximal reduction of <5-fold in microarray screen. To assess the functional importance of dasatinib regulated genes, we used RNA interference to determine whether reduction of CDK2 and CDK8 affected the growth inhibition. K562 and TF-1BCR-ABL cells, pretreated with CDK2 or CDK8 small interfering RNA, showed additive growth inhibition with imatinib, but not with dasatinib. These findings demonstrate that the additive/synergistic growth inhibition by imatinib and dasatinib may be mediated in part by CDK2 and CDK8.

Standard name | DARWICHE_SKIN_TUMOR_PROMOTER_UP
Systematic name | M1131
Organism | Mus musculus
PMID | 17525749
Authors | Darwiche N,Ryscavage A,Perez-Lorenzo R,Wright L,Bae DS,Hennings H,Yuspa SH,Glick AB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during skin tumor progression: epidermis treated with the carcinogen DMBA [PubChem=6001] followed by 20 weekly applications of the tumor promoter TPA [PubChem=4792], compared to the untreated skin.
Full description | Chemical induction of squamous tumors in the mouse skin induces multiple benign papillomas: high-frequency terminally benign low-risk papillomas and low-frequency high-risk papillomas, the putative precursor lesions to squamous cell carcinoma (SCC). We have compared the gene expression profile of twenty different early low- and high-risk papillomas with normal skin and SCC. Unsupervised clustering of 514 differentially expressed genes (P<0.001) showed that 9/10 high-risk papillomas clustered with SCC, while 1/10 clustered with low-risk papillomas, and this correlated with keratin markers of tumor progression. Prediction analysis for microarrays (PAM) identified 87 genes that distinguished the two papilloma classes, and a majority of these had a similar expression pattern in both high-risk papillomas and SCC. Additional classifier algorithms generated a gene list that correctly classified unknown benign tumors as low- or high-risk concordant with promotion protocol and keratin profiling. Reduced expression of immune function genes characterized the high-risk papillomas and SCC. Immunohistochemistry confirmed reduced T-cell number in high-risk papillomas, suggesting that reduced adaptive immunity defines papillomas that progress to SCC. These results demonstrate that murine premalignant lesions can be segregated into subgroups by gene expression patterns that correlate with risk for malignant conversion, and suggest a paradigm for generating diagnostic biomarkers for human premalignant lesions with unknown individual risk for malignant conversion.

Standard name | DARWICHE_SKIN_TUMOR_PROMOTER_DN
Systematic name | M1132
Organism | Mus musculus
PMID | 17525749
Authors | Darwiche N,Ryscavage A,Perez-Lorenzo R,Wright L,Bae DS,Hennings H,Yuspa SH,Glick AB
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during skin tumor progression: epidermis treated with the carcinogen DMBA [PubChem=6001] followed by 20 weekly applications of the tumor promoter TPA [PubChem=4792], compared to the untreated skin.
Full description | Chemical induction of squamous tumors in the mouse skin induces multiple benign papillomas: high-frequency terminally benign low-risk papillomas and low-frequency high-risk papillomas, the putative precursor lesions to squamous cell carcinoma (SCC). We have compared the gene expression profile of twenty different early low- and high-risk papillomas with normal skin and SCC. Unsupervised clustering of 514 differentially expressed genes (P<0.001) showed that 9/10 high-risk papillomas clustered with SCC, while 1/10 clustered with low-risk papillomas, and this correlated with keratin markers of tumor progression. Prediction analysis for microarrays (PAM) identified 87 genes that distinguished the two papilloma classes, and a majority of these had a similar expression pattern in both high-risk papillomas and SCC. Additional classifier algorithms generated a gene list that correctly classified unknown benign tumors as low- or high-risk concordant with promotion protocol and keratin profiling. Reduced expression of immune function genes characterized the high-risk papillomas and SCC. Immunohistochemistry confirmed reduced T-cell number in high-risk papillomas, suggesting that reduced adaptive immunity defines papillomas that progress to SCC. These results demonstrate that murine premalignant lesions can be segregated into subgroups by gene expression patterns that correlate with risk for malignant conversion, and suggest a paradigm for generating diagnostic biomarkers for human premalignant lesions with unknown individual risk for malignant conversion.

Standard name | DARWICHE_PAPILLOMA_RISK_LOW_UP
Systematic name | M1133
Organism | Mus musculus
PMID | 17525749
Authors | Darwiche N,Ryscavage A,Perez-Lorenzo R,Wright L,Bae DS,Hennings H,Yuspa SH,Glick AB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during skin tumor progression from low risk papilloma vs normal skin.
Full description | Chemical induction of squamous tumors in the mouse skin induces multiple benign papillomas: high-frequency terminally benign low-risk papillomas and low-frequency high-risk papillomas, the putative precursor lesions to squamous cell carcinoma (SCC). We have compared the gene expression profile of twenty different early low- and high-risk papillomas with normal skin and SCC. Unsupervised clustering of 514 differentially expressed genes (P<0.001) showed that 9/10 high-risk papillomas clustered with SCC, while 1/10 clustered with low-risk papillomas, and this correlated with keratin markers of tumor progression. Prediction analysis for microarrays (PAM) identified 87 genes that distinguished the two papilloma classes, and a majority of these had a similar expression pattern in both high-risk papillomas and SCC. Additional classifier algorithms generated a gene list that correctly classified unknown benign tumors as low- or high-risk concordant with promotion protocol and keratin profiling. Reduced expression of immune function genes characterized the high-risk papillomas and SCC. Immunohistochemistry confirmed reduced T-cell number in high-risk papillomas, suggesting that reduced adaptive immunity defines papillomas that progress to SCC. These results demonstrate that murine premalignant lesions can be segregated into subgroups by gene expression patterns that correlate with risk for malignant conversion, and suggest a paradigm for generating diagnostic biomarkers for human premalignant lesions with unknown individual risk for malignant conversion.

Standard name | DARWICHE_PAPILLOMA_RISK_LOW_DN
Systematic name | M1134
Organism | Mus musculus
PMID | 17525749
Authors | Darwiche N,Ryscavage A,Perez-Lorenzo R,Wright L,Bae DS,Hennings H,Yuspa SH,Glick AB
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during skin tumor progression from low risk papilloma vs normal skin.
Full description | Chemical induction of squamous tumors in the mouse skin induces multiple benign papillomas: high-frequency terminally benign low-risk papillomas and low-frequency high-risk papillomas, the putative precursor lesions to squamous cell carcinoma (SCC). We have compared the gene expression profile of twenty different early low- and high-risk papillomas with normal skin and SCC. Unsupervised clustering of 514 differentially expressed genes (P<0.001) showed that 9/10 high-risk papillomas clustered with SCC, while 1/10 clustered with low-risk papillomas, and this correlated with keratin markers of tumor progression. Prediction analysis for microarrays (PAM) identified 87 genes that distinguished the two papilloma classes, and a majority of these had a similar expression pattern in both high-risk papillomas and SCC. Additional classifier algorithms generated a gene list that correctly classified unknown benign tumors as low- or high-risk concordant with promotion protocol and keratin profiling. Reduced expression of immune function genes characterized the high-risk papillomas and SCC. Immunohistochemistry confirmed reduced T-cell number in high-risk papillomas, suggesting that reduced adaptive immunity defines papillomas that progress to SCC. These results demonstrate that murine premalignant lesions can be segregated into subgroups by gene expression patterns that correlate with risk for malignant conversion, and suggest a paradigm for generating diagnostic biomarkers for human premalignant lesions with unknown individual risk for malignant conversion.

Standard name | DARWICHE_PAPILLOMA_RISK_HIGH_UP
Systematic name | M1135
Organism | Mus musculus
PMID | 17525749
Authors | Darwiche N,Ryscavage A,Perez-Lorenzo R,Wright L,Bae DS,Hennings H,Yuspa SH,Glick AB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during skin tumor progression from normal skin to high risk papilloma.
Full description | Chemical induction of squamous tumors in the mouse skin induces multiple benign papillomas: high-frequency terminally benign low-risk papillomas and low-frequency high-risk papillomas, the putative precursor lesions to squamous cell carcinoma (SCC). We have compared the gene expression profile of twenty different early low- and high-risk papillomas with normal skin and SCC. Unsupervised clustering of 514 differentially expressed genes (P<0.001) showed that 9/10 high-risk papillomas clustered with SCC, while 1/10 clustered with low-risk papillomas, and this correlated with keratin markers of tumor progression. Prediction analysis for microarrays (PAM) identified 87 genes that distinguished the two papilloma classes, and a majority of these had a similar expression pattern in both high-risk papillomas and SCC. Additional classifier algorithms generated a gene list that correctly classified unknown benign tumors as low- or high-risk concordant with promotion protocol and keratin profiling. Reduced expression of immune function genes characterized the high-risk papillomas and SCC. Immunohistochemistry confirmed reduced T-cell number in high-risk papillomas, suggesting that reduced adaptive immunity defines papillomas that progress to SCC. These results demonstrate that murine premalignant lesions can be segregated into subgroups by gene expression patterns that correlate with risk for malignant conversion, and suggest a paradigm for generating diagnostic biomarkers for human premalignant lesions with unknown individual risk for malignant conversion.

Standard name | DARWICHE_PAPILLOMA_RISK_HIGH_DN
Systematic name | M1137
Organism | Mus musculus
PMID | 17525749
Authors | Darwiche N,Ryscavage A,Perez-Lorenzo R,Wright L,Bae DS,Hennings H,Yuspa SH,Glick AB
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during skin tumor progression from normal skin to high risk papilloma.
Full description | Chemical induction of squamous tumors in the mouse skin induces multiple benign papillomas: high-frequency terminally benign low-risk papillomas and low-frequency high-risk papillomas, the putative precursor lesions to squamous cell carcinoma (SCC). We have compared the gene expression profile of twenty different early low- and high-risk papillomas with normal skin and SCC. Unsupervised clustering of 514 differentially expressed genes (P<0.001) showed that 9/10 high-risk papillomas clustered with SCC, while 1/10 clustered with low-risk papillomas, and this correlated with keratin markers of tumor progression. Prediction analysis for microarrays (PAM) identified 87 genes that distinguished the two papilloma classes, and a majority of these had a similar expression pattern in both high-risk papillomas and SCC. Additional classifier algorithms generated a gene list that correctly classified unknown benign tumors as low- or high-risk concordant with promotion protocol and keratin profiling. Reduced expression of immune function genes characterized the high-risk papillomas and SCC. Immunohistochemistry confirmed reduced T-cell number in high-risk papillomas, suggesting that reduced adaptive immunity defines papillomas that progress to SCC. These results demonstrate that murine premalignant lesions can be segregated into subgroups by gene expression patterns that correlate with risk for malignant conversion, and suggest a paradigm for generating diagnostic biomarkers for human premalignant lesions with unknown individual risk for malignant conversion.

Standard name | DARWICHE_SQUAMOUS_CELL_CARCINOMA_UP
Systematic name | M1139
Organism | Mus musculus
PMID | 17525749
Authors | Darwiche N,Ryscavage A,Perez-Lorenzo R,Wright L,Bae DS,Hennings H,Yuspa SH,Glick AB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in squamous cell carcinoma (SCC) compared to normal skin.
Full description | Chemical induction of squamous tumors in the mouse skin induces multiple benign papillomas: high-frequency terminally benign low-risk papillomas and low-frequency high-risk papillomas, the putative precursor lesions to squamous cell carcinoma (SCC). We have compared the gene expression profile of twenty different early low- and high-risk papillomas with normal skin and SCC. Unsupervised clustering of 514 differentially expressed genes (P<0.001) showed that 9/10 high-risk papillomas clustered with SCC, while 1/10 clustered with low-risk papillomas, and this correlated with keratin markers of tumor progression. Prediction analysis for microarrays (PAM) identified 87 genes that distinguished the two papilloma classes, and a majority of these had a similar expression pattern in both high-risk papillomas and SCC. Additional classifier algorithms generated a gene list that correctly classified unknown benign tumors as low- or high-risk concordant with promotion protocol and keratin profiling. Reduced expression of immune function genes characterized the high-risk papillomas and SCC. Immunohistochemistry confirmed reduced T-cell number in high-risk papillomas, suggesting that reduced adaptive immunity defines papillomas that progress to SCC. These results demonstrate that murine premalignant lesions can be segregated into subgroups by gene expression patterns that correlate with risk for malignant conversion, and suggest a paradigm for generating diagnostic biomarkers for human premalignant lesions with unknown individual risk for malignant conversion.

Standard name | DARWICHE_SQUAMOUS_CELL_CARCINOMA_DN
Systematic name | M1140
Organism | Mus musculus
PMID | 17525749
Authors | Darwiche N,Ryscavage A,Perez-Lorenzo R,Wright L,Bae DS,Hennings H,Yuspa SH,Glick AB
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in squamous cell carcinoma (SCC) compared to normal skin.
Full description | Chemical induction of squamous tumors in the mouse skin induces multiple benign papillomas: high-frequency terminally benign low-risk papillomas and low-frequency high-risk papillomas, the putative precursor lesions to squamous cell carcinoma (SCC). We have compared the gene expression profile of twenty different early low- and high-risk papillomas with normal skin and SCC. Unsupervised clustering of 514 differentially expressed genes (P<0.001) showed that 9/10 high-risk papillomas clustered with SCC, while 1/10 clustered with low-risk papillomas, and this correlated with keratin markers of tumor progression. Prediction analysis for microarrays (PAM) identified 87 genes that distinguished the two papilloma classes, and a majority of these had a similar expression pattern in both high-risk papillomas and SCC. Additional classifier algorithms generated a gene list that correctly classified unknown benign tumors as low- or high-risk concordant with promotion protocol and keratin profiling. Reduced expression of immune function genes characterized the high-risk papillomas and SCC. Immunohistochemistry confirmed reduced T-cell number in high-risk papillomas, suggesting that reduced adaptive immunity defines papillomas that progress to SCC. These results demonstrate that murine premalignant lesions can be segregated into subgroups by gene expression patterns that correlate with risk for malignant conversion, and suggest a paradigm for generating diagnostic biomarkers for human premalignant lesions with unknown individual risk for malignant conversion.

Standard name | MAHADEVAN_IMATINIB_RESISTANCE_UP
Systematic name | M18876
Organism | Homo sapiens
PMID | 17325667
Authors | Mahadevan D,Cooke L,Riley C,Swart R,Simons B,Della Croce K,Wisner L,Iorio M,Shakalya K,Garewal H,Nagle R,Bearss D
Category | C2
Sub-category | CGP
Brief description | Top genes up-regulated in the GIST (gastrointestinal stromal tumor) cell line resistant to imatinib [PubChem=5291] compared to the parental cell line sensitive to the drug.
Full description | KIT or alpha-platelet-derived growth factor receptor (alpha-PDGFR) activating mutations are the pathogenic mechanisms that characterize gastrointestinal stromal tumors (GIST). Despite excellent responses to imatinib mesylate (IM), patients are relapsing. We developed an IM-resistant GIST cell line (GIST-R) from the IM-sensitive GIST882 cell line (GIST-S) by growing these cells in IM. Gene expression profiling (GEP) of GIST-S, GIST-R cells and two IM resistant GIST patients demonstrated that KIT is downregulated implying a major role in IM resistance. Instead, GIST-R cells have acquired IM resistance by overexpressing the oncogenic receptor tyrosine kinase - AXL - in a 'kinase switch'. Further, the two IM resistant GIST patients express AXL and not c-Kit, seen by immunohistochemistry (IHC). Real time reverse transcriptase-polymerase chain reaction and Western blotting of the GIST-S and GIST-R cells confirmed the switch from Kit to AXL. In GIST-R, AXL is tyrosine phosphorylated and its ligand growth-arrest-specific gene 6 is overexpressed implying autocrine activation. The kinase switch is associated with a morphological change from spindle to epithelioid. Molecular modeling of the kinase domain of mutant c-Kit (V654A) and AXL showed no binding to IM but efficient binding to MP470, a novel c-Kit/AXL kinase inhibitor. MP470 synergizes with docetaxel (taxotere) and is cytotoxic to GIST cells.

Standard name | MAHADEVAN_IMATINIB_RESISTANCE_DN
Systematic name | M11367
Organism | Homo sapiens
PMID | 17325667
Authors | Mahadevan D,Cooke L,Riley C,Swart R,Simons B,Della Croce K,Wisner L,Iorio M,Shakalya K,Garewal H,Nagle R,Bearss D
Category | C2
Sub-category | CGP
Brief description | Top genes down-regulated in the GIST (gastrointestinal stromal tumor) cell line resistant to imatinib [PubChem=5291] compared to the parental cell line sensitive to the drug.
Full description | KIT or alpha-platelet-derived growth factor receptor (alpha-PDGFR) activating mutations are the pathogenic mechanisms that characterize gastrointestinal stromal tumors (GIST). Despite excellent responses to imatinib mesylate (IM), patients are relapsing. We developed an IM-resistant GIST cell line (GIST-R) from the IM-sensitive GIST882 cell line (GIST-S) by growing these cells in IM. Gene expression profiling (GEP) of GIST-S, GIST-R cells and two IM resistant GIST patients demonstrated that KIT is downregulated implying a major role in IM resistance. Instead, GIST-R cells have acquired IM resistance by overexpressing the oncogenic receptor tyrosine kinase - AXL - in a 'kinase switch'. Further, the two IM resistant GIST patients express AXL and not c-Kit, seen by immunohistochemistry (IHC). Real time reverse transcriptase-polymerase chain reaction and Western blotting of the GIST-S and GIST-R cells confirmed the switch from Kit to AXL. In GIST-R, AXL is tyrosine phosphorylated and its ligand growth-arrest-specific gene 6 is overexpressed implying autocrine activation. The kinase switch is associated with a morphological change from spindle to epithelioid. Molecular modeling of the kinase domain of mutant c-Kit (V654A) and AXL showed no binding to IM but efficient binding to MP470, a novel c-Kit/AXL kinase inhibitor. MP470 synergizes with docetaxel (taxotere) and is cytotoxic to GIST cells.

Standard name | TOMIDA_METASTASIS_UP
Systematic name | M17830
Organism | Homo sapiens
PMID | 17260014
Authors | Tomida S,Yanagisawa K,Koshikawa K,Yatabe Y,Mitsudomi T,Osada H,Takahashi T
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes associated with the acquision of metastatic potential in LNM35 cells (large cell lung cancer).
Full description | Although widespread metastasis is the major cause of human lung cancer-related deaths, its underlying mechanism remains largely unclear. Our genome-wide comparison of the expression profiles of a highly metastatic lung cancer cell line, NCI-H460-LNM35 (LNM35), and its parental clone, NCI-H460-N15 (N15), resulted in the identification of a cancer metastasis signature composed of 45 genes. Through gene ontology analysis, our study also provided insights into how this 45-gene metastasis signature may contribute to the acquisition of metastatic potential. By applying the signature to datasets of human cancer cases, we could demonstrate significant associations with a subset of cases with poor prognosis not only for the two datasets of cancers of the lung but also for cancers of the breast. Furthermore, we were able to show that enforced expression of the DLX4 homeobox gene, which was identified as a gene with significant downregulation in LNM35 as well as with significant association with favorable prognosis for lung cancer patients, markedly inhibited in vitro motility and invasion as well as in vivo metastasis via both hematogenous and lymphogenous routes. Taken together, these findings indicate that our combined transcriptome analysis is an efficient approach in the search for genes possessing both clinical usefulness in terms of prognostic prediction in human cancer cases and clear functional relevance for studying cancer biology in relation to metastasis.

Standard name | TOMIDA_METASTASIS_DN
Systematic name | M2583
Organism | Homo sapiens
PMID | 17260014
Authors | Tomida S,Yanagisawa K,Koshikawa K,Yatabe Y,Mitsudomi T,Osada H,Takahashi T
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes associated with the acquision of metastatic potential in LNM35 cells (large cell lung cancer).
Full description | Although widespread metastasis is the major cause of human lung cancer-related deaths, its underlying mechanism remains largely unclear. Our genome-wide comparison of the expression profiles of a highly metastatic lung cancer cell line, NCI-H460-LNM35 (LNM35), and its parental clone, NCI-H460-N15 (N15), resulted in the identification of a cancer metastasis signature composed of 45 genes. Through gene ontology analysis, our study also provided insights into how this 45-gene metastasis signature may contribute to the acquisition of metastatic potential. By applying the signature to datasets of human cancer cases, we could demonstrate significant associations with a subset of cases with poor prognosis not only for the two datasets of cancers of the lung but also for cancers of the breast. Furthermore, we were able to show that enforced expression of the DLX4 homeobox gene, which was identified as a gene with significant downregulation in LNM35 as well as with significant association with favorable prognosis for lung cancer patients, markedly inhibited in vitro motility and invasion as well as in vivo metastasis via both hematogenous and lymphogenous routes. Taken together, these findings indicate that our combined transcriptome analysis is an efficient approach in the search for genes possessing both clinical usefulness in terms of prognostic prediction in human cancer cases and clear functional relevance for studying cancer biology in relation to metastasis.

Standard name | SAENZ_DETOX_PATHWAY_AND_CARCINOGENESIS_DN
Systematic name | M1141
Organism | Mus musculus
PMID | 17334401
Authors | Sáenz-Robles MT,Toma D,Cantalupo P,Zhou J,Gong H,Edwards C,Pipas JM,Xie W
Category | C2
Sub-category | CGP
Brief description | Detoxification pathway genes down-regulated in enterocytes of transgenic mice expressing SV40 T antigen.
Full description | Toxic compounds such as carcinogens are removed from the body by the action of a series of detoxifying enzymes and transporters expressed in the liver and the small intestine. We have found that intestinal epithelial cells expressing the SV40 large T antigen (TAg) contain significantly lower levels of mRNAs, encoding several drug metabolizing/detoxifying enzymes and transporters compared to their non-transgenic littermates. In addition, TAg blocks the induction of these mRNAs by xenobiotics. The repression depends on an intact LXCXE motif in TAg, suggesting that inactivation of the retinoblastoma (Rb) family of tumor suppressors plays a role in the process. These results imply that a functional Rb pathway in the intestine is necessary for the expression of the detoxification system used to clear carcinogens, and suggest that loss of this tumor suppressor might alter susceptibility to chemical injury. In addition, the effect of TAg on the detoxification pathway appears to be tissue-specific, as its ectopic expression in the liver failed to suppress the P450 enzymes. The TAg-mediated suppression of drug metabolizing/detoxifying enzymes may have broad implications in the metabolism and mechanism of action of both carcinogens and prescription drugs.

Standard name | OZANNE_AP1_TARGETS_UP
Systematic name | M15822
Organism | Homo sapiens
PMID | 16799638
Authors | Ozanne BW,Spence HJ,McGarry LC,Hennigan RF
Category | C2
Sub-category | CGP
Brief description | Cancer motility and invasion genes up-regulated by the AP-1 transcription factor.
Full description | Metastasis, the aggressive spread of a malignant tumor to distant organs, is a major cause of death in cancer patients. Despite this critical role in cancer outcomes, the molecular mechanisms that control this process are just beginning to be understood. Metastasis is largely dependent upon the ability of tumor cells to invade the barrier formed by the basement membrane and to migrate through neighboring tissues. This review will summarize the evidence that tumor cell invasion is the result of oncogene-mediated signal transduction pathways that control the expression of a specific set of genes that together mediate tumor cell invasion. We focus on the role of the transcription factor AP-1 to both induce the expression of genes that function as invasion effectors and repress other genes that function as invasion suppressors. This identifies AP-1 as a critical regulator of a complex program of gene expression that defines the invasive phenotype.

Standard name | HWANG_PROSTATE_CANCER_MARKERS
Systematic name | M6195
Organism | Homo sapiens
PMID | 16799640
Authors | Hwang SI,Thumar J,Lundgren DH,Rezaul K,Mayya V,Wu L,Eng J,Wright ME,Han DK
Category | C2
Sub-category | CGP
Brief description | Proteins implicated in prostate carcinogenesis.
Full description | Successful treatment of multiple cancer types requires early detection and identification of reliable biomarkers present in specific cancer tissues. To test the feasibility of identifying proteins from archival cancer tissues, we have developed a methodology, termed direct tissue proteomics (DTP), which can be used to identify proteins directly from formalin-fixed paraffin-embedded prostate cancer tissue samples. Using minute prostate biopsy sections, we demonstrate the identification of 428 prostate-expressed proteins using the shotgun method. Because the DTP method is not quantitative, we employed the absolute quantification method and demonstrate picogram level quantification of prostate-specific antigen. In depth bioinformatics analysis of these expressed proteins affords the categorization of metabolic pathways that may be important for distinct stages of prostate carcinogenesis. Furthermore, we validate Wnt-3 as an upregulated protein in cancerous prostate cells by immunohistochemistry. We propose that this general strategy provides a roadmap for successful identification of critical molecular targets of multiple cancer types.

Standard name | HU_ANGIOGENESIS_UP
Systematic name | M6967
Organism | Homo sapiens
PMID | 15592519
Authors | Hu J,Bianchi F,Ferguson M,Cesario A,Margaritora S,Granone P,Goldstraw P,Tetlow M,Ratcliffe C,Nicholson AG,Harris A,Gatter K,Pezzella F
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes that separate angiogenic from non-angiogenic non-small cell lung carcinoma (NSCLC) samples.
Full description | Angiogenesis is regarded as essential for tumour growth. However, we have demonstrated that some other aggressive non-small-cell lung carcinomas (n-SCLC) do not have angiogenesis. In this study, using cDNA microarray analysis, we demonstrate that angiogenic and nonangiogenic tumour types can be distinguished by their gene expression profiles. Tissue samples from 42 n-SCLC patients were obtained with consent. In all, 12 tumours were nonangiogenic and 30 angiogenic. The two groups were matched by age, sex, smoking and tumour stage. Total RNAs were extracted followed by microarray hybridization and image scan procedure. Data were analysed using GeneSpring 5.1 software. A total of 62 genes were found to be able to separate angiogenic from nonangiogenic tumours. Nonangiogenic tumours have higher levels of genes concerned with mitochondrial metabolism, mRNA transcription, protein synthesis and the cell cycle. Angiogenic tumours have higher levels of genes coding for membrane vesicles, integrins, remodelling, angiogenesis and apoptosis. These results further support our first finding that nonangiogenic lung tumours are fast-growing tumours filling the alveoli in the absence of vascular remodelling. We raise the hypothesis that in nonangiogenic tumours, hypoxia leads to a higher activation of the mitochondrial respiratory chain, which allows tumour growth without triggering angiogenesis.

Standard name | HU_ANGIOGENESIS_DN
Systematic name | M18833
Organism | Homo sapiens
PMID | 15592519
Authors | Hu J,Bianchi F,Ferguson M,Cesario A,Margaritora S,Granone P,Goldstraw P,Tetlow M,Ratcliffe C,Nicholson AG,Harris A,Gatter K,Pezzella F
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes that separate angiogenic from non-angiogenic non-small cell lung carcinoma (NSCLC) samples.
Full description | Angiogenesis is regarded as essential for tumour growth. However, we have demonstrated that some other aggressive non-small-cell lung carcinomas (n-SCLC) do not have angiogenesis. In this study, using cDNA microarray analysis, we demonstrate that angiogenic and nonangiogenic tumour types can be distinguished by their gene expression profiles. Tissue samples from 42 n-SCLC patients were obtained with consent. In all, 12 tumours were nonangiogenic and 30 angiogenic. The two groups were matched by age, sex, smoking and tumour stage. Total RNAs were extracted followed by microarray hybridization and image scan procedure. Data were analysed using GeneSpring 5.1 software. A total of 62 genes were found to be able to separate angiogenic from nonangiogenic tumours. Nonangiogenic tumours have higher levels of genes concerned with mitochondrial metabolism, mRNA transcription, protein synthesis and the cell cycle. Angiogenic tumours have higher levels of genes coding for membrane vesicles, integrins, remodelling, angiogenesis and apoptosis. These results further support our first finding that nonangiogenic lung tumours are fast-growing tumours filling the alveoli in the absence of vascular remodelling. We raise the hypothesis that in nonangiogenic tumours, hypoxia leads to a higher activation of the mitochondrial respiratory chain, which allows tumour growth without triggering angiogenesis.

Standard name | BEGUM_TARGETS_OF_PAX3_FOXO1_FUSION_UP
Systematic name | M10156
Organism | Homo sapiens
PMID | 15688035
Authors | Begum S,Emami N,Cheung A,Wilkins O,Der S,Hamel PA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SaOS-2 cells (osteosarcoma) upon expression of PAX3-FOXO1 [GeneID=5077;2308] fusion protein off an adenoviral vector.
Full description | The oncogenic fusion protein, Pax3/FKHR, is a more potent transcription factor relative to its normal counterpart, Pax3. Since Pax3 induced a mesenchymal to epithelial transition (MET) in human SaOS-2 osteosarcomas, we hypothesized that Pax3/FKHR would also induce a morphological change in SaOS-2 cells. We demonstrate here that Pax3/FKHR more potently induces a MET in SaOS-2 cells than Pax3. This greater potency was further evident where Pax3/FKHR, but not Pax3, induced a morphological alteration in U2-OS osteosarcoma cells. By microarray analysis, we determined that Pax3/FKHR altered the expression of gene targets in a manner quantitatively and qualitatively distinct from Pax3. Three classes of genes were identified: (i) genes induced or repressed by Pax3 and Pax3/FKHR, (ii) genes induced or repressed by Pax3/FKHR but not Pax3 and (iii) genes induced by Pax3/FKHR but repressed by Pax3. Chromatin immunoprecipitations confirmed the direct binding of Pax3/FKHR to the promoter region of several factors including cannabinoid receptor-1, EPHA2 and EPHA4. Verification of the microarray data also revealed coordinate alteration in the expression of factors involved in BMP4 signalling. Regulation of gene expression by Pax3 and Pax3/FKHR is, however, cell-type specific. BMP4 expression, for example, was repressed by both Pax3 and Pax3/FKHR in SaOS-2 cells, while in the rhabdomyosarcoma, RD, Pax3/FKHR, but not Pax3, induced BMP4 expression. Thus, our data reveal that Pax3/FKHR regulates a distinct but overlapping set of genes relative to Pax3 and that the global set of Pax3 and Pax3/FKHR gene targets is cell-type specific.

Standard name | BEGUM_TARGETS_OF_PAX3_FOXO1_FUSION_DN
Systematic name | M6679
Organism | Homo sapiens
PMID | 15688035
Authors | Begum S,Emami N,Cheung A,Wilkins O,Der S,Hamel PA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SaOS-2 cells (osteosarcoma) upon expression of PAX3-FOXO1 [GeneID=5077;2308] fusion protein off an adenoviral vector.
Full description | The oncogenic fusion protein, Pax3/FKHR, is a more potent transcription factor relative to its normal counterpart, Pax3. Since Pax3 induced a mesenchymal to epithelial transition (MET) in human SaOS-2 osteosarcomas, we hypothesized that Pax3/FKHR would also induce a morphological change in SaOS-2 cells. We demonstrate here that Pax3/FKHR more potently induces a MET in SaOS-2 cells than Pax3. This greater potency was further evident where Pax3/FKHR, but not Pax3, induced a morphological alteration in U2-OS osteosarcoma cells. By microarray analysis, we determined that Pax3/FKHR altered the expression of gene targets in a manner quantitatively and qualitatively distinct from Pax3. Three classes of genes were identified: (i) genes induced or repressed by Pax3 and Pax3/FKHR, (ii) genes induced or repressed by Pax3/FKHR but not Pax3 and (iii) genes induced by Pax3/FKHR but repressed by Pax3. Chromatin immunoprecipitations confirmed the direct binding of Pax3/FKHR to the promoter region of several factors including cannabinoid receptor-1, EPHA2 and EPHA4. Verification of the microarray data also revealed coordinate alteration in the expression of factors involved in BMP4 signalling. Regulation of gene expression by Pax3 and Pax3/FKHR is, however, cell-type specific. BMP4 expression, for example, was repressed by both Pax3 and Pax3/FKHR in SaOS-2 cells, while in the rhabdomyosarcoma, RD, Pax3/FKHR, but not Pax3, induced BMP4 expression. Thus, our data reveal that Pax3/FKHR regulates a distinct but overlapping set of genes relative to Pax3 and that the global set of Pax3 and Pax3/FKHR gene targets is cell-type specific.

Standard name | DARWICHE_PAPILLOMA_PROGRESSION_RISK
Systematic name | M1147
Organism | Mus musculus
PMID | 17525749
Authors | Darwiche N,Ryscavage A,Perez-Lorenzo R,Wright L,Bae DS,Hennings H,Yuspa SH,Glick AB
Category | C2
Sub-category | CGP
Brief description | Genes that classify progression risk of benign papilloma samples: low vs high risk.
Full description | Chemical induction of squamous tumors in the mouse skin induces multiple benign papillomas: high-frequency terminally benign low-risk papillomas and low-frequency high-risk papillomas, the putative precursor lesions to squamous cell carcinoma (SCC). We have compared the gene expression profile of twenty different early low- and high-risk papillomas with normal skin and SCC. Unsupervised clustering of 514 differentially expressed genes (P<0.001) showed that 9/10 high-risk papillomas clustered with SCC, while 1/10 clustered with low-risk papillomas, and this correlated with keratin markers of tumor progression. Prediction analysis for microarrays (PAM) identified 87 genes that distinguished the two papilloma classes, and a majority of these had a similar expression pattern in both high-risk papillomas and SCC. Additional classifier algorithms generated a gene list that correctly classified unknown benign tumors as low- or high-risk concordant with promotion protocol and keratin profiling. Reduced expression of immune function genes characterized the high-risk papillomas and SCC. Immunohistochemistry confirmed reduced T-cell number in high-risk papillomas, suggesting that reduced adaptive immunity defines papillomas that progress to SCC. These results demonstrate that murine premalignant lesions can be segregated into subgroups by gene expression patterns that correlate with risk for malignant conversion, and suggest a paradigm for generating diagnostic biomarkers for human premalignant lesions with unknown individual risk for malignant conversion.

Standard name | SHIRAISHI_PLZF_TARGETS_UP
Systematic name | M1168
Organism | Homo sapiens
PMID | 16862184
Authors | Shiraishi K,Yamasaki K,Nanba D,Inoue H,Hanakawa Y,Shirakata Y,Hashimoto K,Higashiyama S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A375 and 397 cells (melanoma) by forced expression of PLZF [GeneID=7704] off adenovirus vector.
Full description | Promyelocytic leukemia zinc-finger (PLZF) is a transcriptional repressor and tumor suppressor. PLZF is expressed in melanocytes but not in melanoma cells, and recovery of PLZF expression markedly suppresses melanoma cell growth. Several target genes regulated by PLZF have been identified, but the precise function of PLZF remains uncertain. Here, we searched for candidate target genes of PLZF by DNA microarray analysis. Pre-B-cell leukemia transcription factor 1 (Pbx1) was one of the prominently suppressed genes. Pbx1 was highly expressed in melanoma cells, and its expression was reduced by transduction with the PLZF gene. Moreover, the growth suppression mediated by PLZF was reversed by enforced expression of Pbx1. Knockdown of Pbx1 by specific small interfering RNAs suppressed melanoma cell growth. We also found that Pbx1 binds HoxB7. Reverse transcription-polymerase chain reaction analysis demonstrated that repression of Pbx1 by PLZF reduces the expression of HoxB7 target genes, including tumor-associated neoangiogenesis factors such as basic fibroblast growth factor, angiopoietin-2 and matrix metalloprotease 9. These findings suggest that deregulation of Pbx1 expression owing to loss of PLZF expression contributes to the progression and/or pathogenesis of melanoma.

Standard name | SHIRAISHI_PLZF_TARGETS_DN
Systematic name | M2530
Organism | Homo sapiens
PMID | 16862184
Authors | Shiraishi K,Yamasaki K,Nanba D,Inoue H,Hanakawa Y,Shirakata Y,Hashimoto K,Higashiyama S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A375 and 397 cells (melanoma) by forced expression of PLZF [GeneID=7704] off adenovirus vector.
Full description | Promyelocytic leukemia zinc-finger (PLZF) is a transcriptional repressor and tumor suppressor. PLZF is expressed in melanocytes but not in melanoma cells, and recovery of PLZF expression markedly suppresses melanoma cell growth. Several target genes regulated by PLZF have been identified, but the precise function of PLZF remains uncertain. Here, we searched for candidate target genes of PLZF by DNA microarray analysis. Pre-B-cell leukemia transcription factor 1 (Pbx1) was one of the prominently suppressed genes. Pbx1 was highly expressed in melanoma cells, and its expression was reduced by transduction with the PLZF gene. Moreover, the growth suppression mediated by PLZF was reversed by enforced expression of Pbx1. Knockdown of Pbx1 by specific small interfering RNAs suppressed melanoma cell growth. We also found that Pbx1 binds HoxB7. Reverse transcription-polymerase chain reaction analysis demonstrated that repression of Pbx1 by PLZF reduces the expression of HoxB7 target genes, including tumor-associated neoangiogenesis factors such as basic fibroblast growth factor, angiopoietin-2 and matrix metalloprotease 9. These findings suggest that deregulation of Pbx1 expression owing to loss of PLZF expression contributes to the progression and/or pathogenesis of melanoma.

Standard name | MOTAMED_RESPONSE_TO_ANDROGEN_UP
Systematic name | M1148
Organism | Homo sapiens
PMID | 16832351
Authors | Motamed-Khorasani A,Jurisica I,Letarte M,Shaw PA,Parkes RK,Zhang X,Evangelou A,Rosen B,Murphy KJ,Brown TJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ovarian epithelial cells in response to dihydrotestosterone (DHT) [PubChem=10635].
Full description | Epidemiological studies have implicated androgens in the etiology and progression of epithelial ovarian cancer. We previously reported that some androgen responses were dysregulated in malignant ovarian epithelial cells relative to control, non-malignant ovarian surface epithelial (OSE) cells. Moreover, dysregulated androgen responses were observed in OSE cells derived from patients with germline BRCA-1 or -2 mutations (OSEb), which account for the majority of familial ovarian cancer predisposition, and such altered responses may be involved in ovarian carcinogenesis or progression. In the present study, gene expression profiling using cDNA microarrays identified 17 genes differentially expressed in response to continuous androgen exposure in OSEb cells and ovarian cancer cells as compared to OSE cells derived from control patients. A subset of these differentially affected genes was selected and verified by quantitative real-time reverse transcription-polymerase chain reaction. Six of the gene products mapped to the OPHID protein-protein interaction database, and five were networked within two interacting partners. Basic leucine zipper transcription factor 2 (BACH2) and acetylcholinesterase (ACHE), which were upregulated by androgen in OSEb cells relative to OSE cells, were further investigated using an ovarian cancer tissue microarray from a separate set of 149 clinical samples. Both cytoplasmic ACHE and BACH2 immunostaining were significantly increased in ovarian cancer relative to benign cases. High levels of cytoplasmic ACHE staining correlated with decreased survival, whereas nuclear BACH2 staining correlated with decreased time to disease recurrence. The finding that products of genes differentially responsive to androgen in OSEb cells may predict survival and disease progression supports a role for altered androgen effects in ovarian cancer. In addition to BACH2 and ACHE, this study highlights a set of potentially functionally related genes for further investigation in ovarian cancer.

Standard name | MOTAMED_RESPONSE_TO_ANDROGEN_DN
Systematic name | M1149
Organism | Homo sapiens
PMID | 16832351
Authors | Motamed-Khorasani A,Jurisica I,Letarte M,Shaw PA,Parkes RK,Zhang X,Evangelou A,Rosen B,Murphy KJ,Brown TJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ovarian epithelial cells in response to dihydrotestosterone (DHT) [PubChem=10635].
Full description | Epidemiological studies have implicated androgens in the etiology and progression of epithelial ovarian cancer. We previously reported that some androgen responses were dysregulated in malignant ovarian epithelial cells relative to control, non-malignant ovarian surface epithelial (OSE) cells. Moreover, dysregulated androgen responses were observed in OSE cells derived from patients with germline BRCA-1 or -2 mutations (OSEb), which account for the majority of familial ovarian cancer predisposition, and such altered responses may be involved in ovarian carcinogenesis or progression. In the present study, gene expression profiling using cDNA microarrays identified 17 genes differentially expressed in response to continuous androgen exposure in OSEb cells and ovarian cancer cells as compared to OSE cells derived from control patients. A subset of these differentially affected genes was selected and verified by quantitative real-time reverse transcription-polymerase chain reaction. Six of the gene products mapped to the OPHID protein-protein interaction database, and five were networked within two interacting partners. Basic leucine zipper transcription factor 2 (BACH2) and acetylcholinesterase (ACHE), which were upregulated by androgen in OSEb cells relative to OSE cells, were further investigated using an ovarian cancer tissue microarray from a separate set of 149 clinical samples. Both cytoplasmic ACHE and BACH2 immunostaining were significantly increased in ovarian cancer relative to benign cases. High levels of cytoplasmic ACHE staining correlated with decreased survival, whereas nuclear BACH2 staining correlated with decreased time to disease recurrence. The finding that products of genes differentially responsive to androgen in OSEb cells may predict survival and disease progression supports a role for altered androgen effects in ovarian cancer. In addition to BACH2 and ACHE, this study highlights a set of potentially functionally related genes for further investigation in ovarian cancer.

Standard name | RAMJAUN_APOPTOSIS_BY_TGFB1_VIA_SMAD4_UP
Systematic name | M1150
Organism | Mus musculus
PMID | 16909112
Authors | Ramjaun AR,Tomlinson S,Eddaoudi A,Downward J
Category | C2
Sub-category | CGP
Brief description | Apoptotic genes dependent on SMAD4 [GeneID=4089] and up-regulated in AML12 cells (hepatocytes) after stimulation with TGFB1 [GeneID=7040].
Full description | Transforming growth factor-beta (TGFbeta)-activated signalling pathways can lead to apoptosis, growth arrest or promotion of malignant behaviour, dependent on cellular context. The molecular mechanisms involved in TGFbeta-induced apoptosis remain controversial; although changes in gene expression are thought to be pivotal to the process, several different candidate apoptotic initiators and mediators have been proposed. Smad4, a critical component of the TGFbeta-induced transcriptional machinery, is shown here to be essential for induction of apoptosis. Gene expression analysis identified the proapoptotic Bcl-2 family members, Bmf and Bim, as induced by TGFbeta, dependent on both Smad4 and p38 function and the generation of reactive oxygen species. TGFbeta-induced Bmf and Bim localize to cellular membranes implicated in apoptosis. Inhibition of the TGFbeta-induced expression of both these proteins together provides significant protection of cells from apoptosis. The TGFbeta-triggered cell death programme thus involves induction of multiple BH3-only proteins during the induction of apoptosis.

Standard name | RAMJAUN_APOPTOSIS_BY_TGFB1_VIA_SMAD4_DN
Systematic name | M1151
Organism | Mus musculus
PMID | 16909112
Authors | Ramjaun AR,Tomlinson S,Eddaoudi A,Downward J
Category | C2
Sub-category | CGP
Brief description | Apoptotic genes dependent on SMAD4 [GeneID=4089] and down-regulated in AML12 cells (hepatocytes) after stimulation with TGFB1 [GeneID=7040].
Full description | Transforming growth factor-beta (TGFbeta)-activated signalling pathways can lead to apoptosis, growth arrest or promotion of malignant behaviour, dependent on cellular context. The molecular mechanisms involved in TGFbeta-induced apoptosis remain controversial; although changes in gene expression are thought to be pivotal to the process, several different candidate apoptotic initiators and mediators have been proposed. Smad4, a critical component of the TGFbeta-induced transcriptional machinery, is shown here to be essential for induction of apoptosis. Gene expression analysis identified the proapoptotic Bcl-2 family members, Bmf and Bim, as induced by TGFbeta, dependent on both Smad4 and p38 function and the generation of reactive oxygen species. TGFbeta-induced Bmf and Bim localize to cellular membranes implicated in apoptosis. Inhibition of the TGFbeta-induced expression of both these proteins together provides significant protection of cells from apoptosis. The TGFbeta-triggered cell death programme thus involves induction of multiple BH3-only proteins during the induction of apoptosis.

Standard name | RAMJAUN_APOPTOSIS_BY_TGFB1_VIA_MAPK1_UP
Systematic name | M1152
Organism | Mus musculus
PMID | 16909112
Authors | Ramjaun AR,Tomlinson S,Eddaoudi A,Downward J
Category | C2
Sub-category | CGP
Brief description | Apoptotic genes dependent on MAPK1 [GeneID=5594] and up-regulated in AML12 cells (hepatocytes) after stimulation with TGFB1 [GeneID=7040].
Full description | Transforming growth factor-beta (TGFbeta)-activated signalling pathways can lead to apoptosis, growth arrest or promotion of malignant behaviour, dependent on cellular context. The molecular mechanisms involved in TGFbeta-induced apoptosis remain controversial; although changes in gene expression are thought to be pivotal to the process, several different candidate apoptotic initiators and mediators have been proposed. Smad4, a critical component of the TGFbeta-induced transcriptional machinery, is shown here to be essential for induction of apoptosis. Gene expression analysis identified the proapoptotic Bcl-2 family members, Bmf and Bim, as induced by TGFbeta, dependent on both Smad4 and p38 function and the generation of reactive oxygen species. TGFbeta-induced Bmf and Bim localize to cellular membranes implicated in apoptosis. Inhibition of the TGFbeta-induced expression of both these proteins together provides significant protection of cells from apoptosis. The TGFbeta-triggered cell death programme thus involves induction of multiple BH3-only proteins during the induction of apoptosis.

Standard name | RAMJAUN_APOPTOSIS_BY_TGFB1_VIA_MAPK1_DN
Systematic name | M1154
Organism | Mus musculus
PMID | 16909112
Authors | Ramjaun AR,Tomlinson S,Eddaoudi A,Downward J
Category | C2
Sub-category | CGP
Brief description | Apoptotic genes dependent on MAPK1 [GeneID=5594] and down-regulated in AML12 cells (hepatocytes) after stimulation with TGFB1 [GeneID=7040].
Full description | Transforming growth factor-beta (TGFbeta)-activated signalling pathways can lead to apoptosis, growth arrest or promotion of malignant behaviour, dependent on cellular context. The molecular mechanisms involved in TGFbeta-induced apoptosis remain controversial; although changes in gene expression are thought to be pivotal to the process, several different candidate apoptotic initiators and mediators have been proposed. Smad4, a critical component of the TGFbeta-induced transcriptional machinery, is shown here to be essential for induction of apoptosis. Gene expression analysis identified the proapoptotic Bcl-2 family members, Bmf and Bim, as induced by TGFbeta, dependent on both Smad4 and p38 function and the generation of reactive oxygen species. TGFbeta-induced Bmf and Bim localize to cellular membranes implicated in apoptosis. Inhibition of the TGFbeta-induced expression of both these proteins together provides significant protection of cells from apoptosis. The TGFbeta-triggered cell death programme thus involves induction of multiple BH3-only proteins during the induction of apoptosis.

Standard name | OLSSON_E2F3_TARGETS_UP
Systematic name | M18325
Organism | Homo sapiens
PMID | 16909110
Authors | Olsson AY,Feber A,Edwards S,Te Poele R,Giddings I,Merson S,Cooper CS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the 5637 cell line (bladder cancer) after knockdown of E2F3 [GeneID=1871] by RNAi.
Full description | Amplification and overexpression of the E2F3 gene at 6p22 in human bladder cancer is associated with increased tumour stage, grade and proliferation index, and in prostate cancer E2F3 overexpression is linked to tumour aggressiveness. We first used small interfering RNA technology to confirm the potential importance of E2F3 overexpression in bladder cancer development. Knockdown of E2F3 expression in bladder cells containing the 6p22 amplicon strongly reduced the extent of bromodeoxyuridine (BrdU) incorporation and the rate of cellular proliferation. In contrast, knockdown of CDKAL1/FLJ20342, another proposed oncogene, from this amplicon had no effect. Expression cDNA microarray analysis on bladder cancer cells following E2F3 knockdown was then used to identify genes regulated by E2F3, leading to the identification of known E2F3 targets such as Cyclin A and CDC2 and novel targets including pituitary tumour transforming gene 1, Polo-like kinase 1 (PLK1) and Caveolin-2. For both bladder and prostate cancer, we have proposed that E2F3 protein overexpression may cooperate with removal of the E2F inhibitor retinoblastoma tumor suppressor protein (pRB) to drive cellular proliferation. In support of this model, we found that ectopic expression of E2F3a enhanced the BrdU incorporation, a marker of cellular proliferation rate, of prostate cancer DU145 cells, which lack pRB, but had no effect on the proliferation rate of PC3 prostate cancer cells that express wild-type pRB. BrdU incorporation in PC3 cells could, however, be increased by overexpressing E2F3a in cells depleted of pRB. When taken together, these observations indicate that E2F3 levels have a critical role in modifying cellular proliferation rate in human bladder and prostate cancer.

Standard name | OLSSON_E2F3_TARGETS_DN
Systematic name | M952
Organism | Homo sapiens
PMID | 16909110
Authors | Olsson AY,Feber A,Edwards S,Te Poele R,Giddings I,Merson S,Cooper CS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the 5637 cell line (bladder cancer) after knockdown of E2F3 [GeneID=1871] by RNAi.
Full description | Amplification and overexpression of the E2F3 gene at 6p22 in human bladder cancer is associated with increased tumour stage, grade and proliferation index, and in prostate cancer E2F3 overexpression is linked to tumour aggressiveness. We first used small interfering RNA technology to confirm the potential importance of E2F3 overexpression in bladder cancer development. Knockdown of E2F3 expression in bladder cells containing the 6p22 amplicon strongly reduced the extent of bromodeoxyuridine (BrdU) incorporation and the rate of cellular proliferation. In contrast, knockdown of CDKAL1/FLJ20342, another proposed oncogene, from this amplicon had no effect. Expression cDNA microarray analysis on bladder cancer cells following E2F3 knockdown was then used to identify genes regulated by E2F3, leading to the identification of known E2F3 targets such as Cyclin A and CDC2 and novel targets including pituitary tumour transforming gene 1, Polo-like kinase 1 (PLK1) and Caveolin-2. For both bladder and prostate cancer, we have proposed that E2F3 protein overexpression may cooperate with removal of the E2F inhibitor retinoblastoma tumor suppressor protein (pRB) to drive cellular proliferation. In support of this model, we found that ectopic expression of E2F3a enhanced the BrdU incorporation, a marker of cellular proliferation rate, of prostate cancer DU145 cells, which lack pRB, but had no effect on the proliferation rate of PC3 prostate cancer cells that express wild-type pRB. BrdU incorporation in PC3 cells could, however, be increased by overexpressing E2F3a in cells depleted of pRB. When taken together, these observations indicate that E2F3 levels have a critical role in modifying cellular proliferation rate in human bladder and prostate cancer.

Standard name | MARKS_HDAC_TARGETS_UP
Systematic name | M8023
Organism | Homo sapiens
PMID | 17322921
Authors | Marks PA
Category | C2
Sub-category | CGP
Brief description | Genes whose transcription is up-regulated by histone deacetylase inhibitors.
Full description | The path to the discovery of suberoylanilide hydroxamic acid (SAHA, vorinostat) began over three decades ago with our studies designed to understand why dimethylsulfoxide causes terminal differentiation of the virus-transformed cells, murine erythroleukemia cells. SAHA can cause growth arrest and death of a broad variety of transformed cells both in vitro and in vivo at concentrations that have little or no toxic effects on normal cells. It was discovered that SAHA inhibits the activity of histone deacetylases (HDACs), including all 11 known human class I and class II HDACs. HDACs have many protein targets whose structure and function are altered by acetylation including histones and non-histone proteins component of transcription factors controlling gene expression and proteins that regulate cell proliferation, migration and death. SAHA is in clinical trials and has significant anticancer activity against both hematologic and solid tumors at doses well tolerated by patients. A new drug application has been approved for SAHA (vorinostat) treatment of cutaneous T-cell lymphoma.

Standard name | MARKS_HDAC_TARGETS_DN
Systematic name | M3362
Organism | Homo sapiens
PMID | 17322921
Authors | Marks PA
Category | C2
Sub-category | CGP
Brief description | Genes whose transcription is down-regulated by histone deacetylase inhibitors.
Full description | The path to the discovery of suberoylanilide hydroxamic acid (SAHA, vorinostat) began over three decades ago with our studies designed to understand why dimethylsulfoxide causes terminal differentiation of the virus-transformed cells, murine erythroleukemia cells. SAHA can cause growth arrest and death of a broad variety of transformed cells both in vitro and in vivo at concentrations that have little or no toxic effects on normal cells. It was discovered that SAHA inhibits the activity of histone deacetylases (HDACs), including all 11 known human class I and class II HDACs. HDACs have many protein targets whose structure and function are altered by acetylation including histones and non-histone proteins component of transcription factors controlling gene expression and proteins that regulate cell proliferation, migration and death. SAHA is in clinical trials and has significant anticancer activity against both hematologic and solid tumors at doses well tolerated by patients. A new drug application has been approved for SAHA (vorinostat) treatment of cutaneous T-cell lymphoma.

Standard name | CHOI_ATL_ACUTE_STAGE
Systematic name | M10100
Organism | Homo sapiens
PMID | 16909099
Authors | Choi YL,Tsukasaki K,O'Neill MC,Yamada Y,Onimaru Y,Matsumoto K,Ohashi J,Yamashita Y,Tsutsumi S,Kaneda R,Takada S,Aburatani H,Kamihira S,Nakamura T,Tomonaga M,Mano H
Category | C2
Sub-category | CGP
Brief description | Acute stage-specific genes for adult T cell leukemia (ATL).
Full description | Adult T-cell leukemia (ATL) is an intractable malignancy of CD4+ T cells that is etiologically associated with infection by human T-cell leukemia virus-type I. Most individuals in the chronic stage of ATL eventually undergo progression to a highly aggressive acute stage. To clarify the mechanism responsible for this stage progression, we isolated CD4+ cells from individuals in the chronic (n=19) or acute (n=22) stages of ATL and subjected them to profiling of gene expression with DNA microarrays containing >44,000 probe sets. Changes in chromosome copy number were also examined for 24 cell specimens with the use of microarrays harboring approximately 50,000 probe sets. Stage-dependent changes in gene expression profile and chromosome copy number were apparent. Furthermore, expression of the gene for MET, a receptor tyrosine kinase for hepatocyte growth factor (HGF), was shown to be specific to the acute stage of ATL, and the plasma concentration of HGF was increased in individuals in either the acute or chronic stage. HGF induced proliferation of a MET-positive ATL cell line, and this effect was blocked by antibodies to HGF. The HGF-MET signaling pathway is thus a potential therapeutic target for ATL.

Standard name | CHOI_ATL_STAGE_PREDICTOR
Systematic name | M7507
Organism | Homo sapiens
PMID | 16909099
Authors | Choi YL,Tsukasaki K,O'Neill MC,Yamada Y,Onimaru Y,Matsumoto K,Ohashi J,Yamashita Y,Tsutsumi S,Kaneda R,Takada S,Aburatani H,Kamihira S,Nakamura T,Tomonaga M,Mano H
Category | C2
Sub-category | CGP
Brief description | Genes used to predict the clinical stages of acute T-cell leukemia (ATL): chronic vs acute.
Full description | Adult T-cell leukemia (ATL) is an intractable malignancy of CD4+ T cells that is etiologically associated with infection by human T-cell leukemia virus-type I. Most individuals in the chronic stage of ATL eventually undergo progression to a highly aggressive acute stage. To clarify the mechanism responsible for this stage progression, we isolated CD4+ cells from individuals in the chronic (n=19) or acute (n=22) stages of ATL and subjected them to profiling of gene expression with DNA microarrays containing >44,000 probe sets. Changes in chromosome copy number were also examined for 24 cell specimens with the use of microarrays harboring approximately 50,000 probe sets. Stage-dependent changes in gene expression profile and chromosome copy number were apparent. Furthermore, expression of the gene for MET, a receptor tyrosine kinase for hepatocyte growth factor (HGF), was shown to be specific to the acute stage of ATL, and the plasma concentration of HGF was increased in individuals in either the acute or chronic stage. HGF induced proliferation of a MET-positive ATL cell line, and this effect was blocked by antibodies to HGF. The HGF-MET signaling pathway is thus a potential therapeutic target for ATL.

Standard name | WONG_ENDMETRIUM_CANCER_UP
Systematic name | M16201
Organism | Homo sapiens
PMID | 17043662
Authors | Wong YF,Cheung TH,Lo KW,Yim SF,Siu NS,Chan SC,Ho TW,Wong KW,Yu MY,Wang VW,Li C,Gardner GJ,Bonome T,Johnson WB,Smith DI,Chung TK,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in cancer endometrium samples compared to the normal endometrium.
Full description | Endometrial cancer is the third most common gynecologic malignancy and the ninth most common malignancy for females overall in Hong Kong. Approximately 80% or more of these cancers are endometrioid endometrial adenocarcinomas. The aim of this study was to reveal genes contributing to the development of endometrioid endometrial cancer, which may impact diagnosis, prognosis and treatment of the disease. Whole-genome gene expression analysis was completed for a set of 55 microdissected sporadic endometrioid endometrial adenocarcinomas and 29 microdissected normal endometrium specimens using the Affymetrix Human U133 Plus 2.0 oligonucleotide microarray. Selected genes of interest were validated by quantitative real-time-polymerase chain reaction (qRT-PCR). Pathway analysis was performed to reveal gene interactions involved in endometrial tumorigenesis. Unsupervised hierarchical clustering displayed a distinct separation between the endometrioid adenocarcinomas and normal endometrium samples. Supervised analysis identified 117 highly differentially regulated genes (>or=4.0-fold change), which distinguished the endometrial cancer specimens from normal endometrium. Twelve novel genes including DKK4, ZIC1, KIF1A, SAA2, LOC16378, ALPP2, CCL20, CXCL5, BST2, OLFM1, KLRC1 and MBC45780 were deregulated in the endometrial cancer, and further validated in an independent set of 56 cancer and 29 normal samples using qRT-PCR. In addition, 10 genes were differentially regulated in late-stage cancer, as compared to early-stage disease, and may be involved in tumor progression. Pathway analysis of the expression data from this tumor revealed an interconnected network consisting of 21 aberrantly regulated genes involved in angiogenesis, cell proliferation and chromosomal instability. The results of this study highlight the molecular features of endometrioid endometrial cancer and provide insight into the events underlying the development and progression of endometrioid endometrial cancer.

Standard name | WONG_ENDMETRIUM_CANCER_DN
Systematic name | M1311
Organism | Homo sapiens
PMID | 17043662
Authors | Wong YF,Cheung TH,Lo KW,Yim SF,Siu NS,Chan SC,Ho TW,Wong KW,Yu MY,Wang VW,Li C,Gardner GJ,Bonome T,Johnson WB,Smith DI,Chung TK,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in cancer endometrium samples compared to the normal endometrium.
Full description | Endometrial cancer is the third most common gynecologic malignancy and the ninth most common malignancy for females overall in Hong Kong. Approximately 80% or more of these cancers are endometrioid endometrial adenocarcinomas. The aim of this study was to reveal genes contributing to the development of endometrioid endometrial cancer, which may impact diagnosis, prognosis and treatment of the disease. Whole-genome gene expression analysis was completed for a set of 55 microdissected sporadic endometrioid endometrial adenocarcinomas and 29 microdissected normal endometrium specimens using the Affymetrix Human U133 Plus 2.0 oligonucleotide microarray. Selected genes of interest were validated by quantitative real-time-polymerase chain reaction (qRT-PCR). Pathway analysis was performed to reveal gene interactions involved in endometrial tumorigenesis. Unsupervised hierarchical clustering displayed a distinct separation between the endometrioid adenocarcinomas and normal endometrium samples. Supervised analysis identified 117 highly differentially regulated genes (>or=4.0-fold change), which distinguished the endometrial cancer specimens from normal endometrium. Twelve novel genes including DKK4, ZIC1, KIF1A, SAA2, LOC16378, ALPP2, CCL20, CXCL5, BST2, OLFM1, KLRC1 and MBC45780 were deregulated in the endometrial cancer, and further validated in an independent set of 56 cancer and 29 normal samples using qRT-PCR. In addition, 10 genes were differentially regulated in late-stage cancer, as compared to early-stage disease, and may be involved in tumor progression. Pathway analysis of the expression data from this tumor revealed an interconnected network consisting of 21 aberrantly regulated genes involved in angiogenesis, cell proliferation and chromosomal instability. The results of this study highlight the molecular features of endometrioid endometrial cancer and provide insight into the events underlying the development and progression of endometrioid endometrial cancer.

Standard name | WONG_ENDOMETRIAL_CANCER_LATE
Systematic name | M9464
Organism | Homo sapiens
PMID | 17043662
Authors | Wong YF,Cheung TH,Lo KW,Yim SF,Siu NS,Chan SC,Ho TW,Wong KW,Yu MY,Wang VW,Li C,Gardner GJ,Bonome T,Johnson WB,Smith DI,Chung TK,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in late stage (stage 3) endometrial cancers compared to the earlier stages (stage 1 and 2).
Full description | Endometrial cancer is the third most common gynecologic malignancy and the ninth most common malignancy for females overall in Hong Kong. Approximately 80% or more of these cancers are endometrioid endometrial adenocarcinomas. The aim of this study was to reveal genes contributing to the development of endometrioid endometrial cancer, which may impact diagnosis, prognosis and treatment of the disease. Whole-genome gene expression analysis was completed for a set of 55 microdissected sporadic endometrioid endometrial adenocarcinomas and 29 microdissected normal endometrium specimens using the Affymetrix Human U133 Plus 2.0 oligonucleotide microarray. Selected genes of interest were validated by quantitative real-time-polymerase chain reaction (qRT-PCR). Pathway analysis was performed to reveal gene interactions involved in endometrial tumorigenesis. Unsupervised hierarchical clustering displayed a distinct separation between the endometrioid adenocarcinomas and normal endometrium samples. Supervised analysis identified 117 highly differentially regulated genes (>or=4.0-fold change), which distinguished the endometrial cancer specimens from normal endometrium. Twelve novel genes including DKK4, ZIC1, KIF1A, SAA2, LOC16378, ALPP2, CCL20, CXCL5, BST2, OLFM1, KLRC1 and MBC45780 were deregulated in the endometrial cancer, and further validated in an independent set of 56 cancer and 29 normal samples using qRT-PCR. In addition, 10 genes were differentially regulated in late-stage cancer, as compared to early-stage disease, and may be involved in tumor progression. Pathway analysis of the expression data from this tumor revealed an interconnected network consisting of 21 aberrantly regulated genes involved in angiogenesis, cell proliferation and chromosomal instability. The results of this study highlight the molecular features of endometrioid endometrial cancer and provide insight into the events underlying the development and progression of endometrioid endometrial cancer.

Standard name | ABDULRAHMAN_KIDNEY_CANCER_VHL_DN
Systematic name | M2096
Organism | Homo sapiens
PMID | 17001320
Authors | Abdulrahman M,Maina EN,Morris MR,Zatyka M,Raval RR,Banks RE,Wiesener MS,Richards FM,Johnson CM,Latif F,Maher ER
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the RCC4 cells (renal cell carcinoma, RCC) expressing VHL [GeneID=7428] mutants Type 1 and 2B (associated with RCC) but not those of Type 2A and 2C (not associated with RCC).
Full description | von Hippel-Lindau (VHL) disease is a dominantly inherited family cancer syndrome characterized by the development of retinal and central nervous system haemangioblastomas, renal cell carcinoma (RCC) and phaeochromocytoma. Specific germline VHL mutations may predispose to haemangioblastomas, RCC and phaeochromocytoma to a varying extent. Although dysregulation of the hypoxia-inducible transcription factor-2 and JunB have been linked to the development of RCC and phaeochromocytoma, respectively, the precise basis for genotype-phenotype correlations in VHL disease have not been defined. To gain insights into the pathogenesis of RCC in VHL disease we compared gene expression microarray profiles in a RCC cell line expressing a Type 1 or Type 2B mutant pVHL (RCC-associated) to those of a Type 2A or 2C mutant (not associated with RCC). We identified 19 differentially expressed novel VHL target genes linked to RCC development. Eight targets were studied in detail by quantitative real-time polymerase chain reaction (three downregulated and five upregulated by wild-type VHL) and for six genes the effect of VHL inactivation was mimicked by hypoxia (but hypoxic-induction of smooth muscle alpha-actin 2 was specific for a RCC cell line). The potential role of four RCC-associated VHL target genes was assessed in vitro. NB thymosin beta (TMSNB) and proteinase-activated receptor 2 (PAR2) (both downregulated by wt pVHL) increased cell growth and motility in a RCC cell line, but aldehyde dehydrogenase (ALDH)1 and ALDH7 had no effect. These findings implicate TMSNB and PAR2 candidate oncogenes in the pathogenesis of VHL-associated RCC.

Standard name | KONG_E2F1_TARGETS
Systematic name | M1156
Organism | Mus musculus
PMID | 16909124
Authors | Kong LJ,Chang JT,Bild AH,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) at 16 h after serum stimulation and knockdown of E2F1 [GeneID=1869] by RNAi.
Full description | Functions encoded by single genes in lower organisms are often represented by multiple related genes in the mammalian genome. An example is the retinoblastoma and E2F families of proteins that regulate transcription during the cell cycle. Analysis of gene function using germline mutations is often confounded by overlapping function resulting in compensation. Indeed, in cells deleted of the E2F1 or E2F3 genes, there is an increase in the expression of the other family member. To avoid complications of compensatory effects, we have used small-interfering RNAs that target individual E2F proteins to generate a temporary loss of E2F function. We find that both E2F1 and E2F3 are required for cells to enter the S phase from a quiescent state, whereas only E2F3 is necessary for the S phase in growing cells. We also find that the acute loss of E2F3 activity affects the expression of genes encoding DNA replication and mitotic activities, whereas loss of E2F1 affects a limited number of genes that are distinct from those regulated by E2F3. We conclude that the long-term loss of E2F activity does lead to compensation by other family members and that the analysis of acute loss of function reveals specific and distinct roles for these proteins.

Standard name | KONG_E2F3_TARGETS
Systematic name | M1157
Organism | Mus musculus
PMID | 16909124
Authors | Kong LJ,Chang JT,Bild AH,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblasts) at 16 hr after serum stimulation and knockdown of E2F3 [GeneID=1871] by RNAi.
Full description | Functions encoded by single genes in lower organisms are often represented by multiple related genes in the mammalian genome. An example is the retinoblastoma and E2F families of proteins that regulate transcription during the cell cycle. Analysis of gene function using germline mutations is often confounded by overlapping function resulting in compensation. Indeed, in cells deleted of the E2F1 or E2F3 genes, there is an increase in the expression of the other family member. To avoid complications of compensatory effects, we have used small-interfering RNAs that target individual E2F proteins to generate a temporary loss of E2F function. We find that both E2F1 and E2F3 are required for cells to enter the S phase from a quiescent state, whereas only E2F3 is necessary for the S phase in growing cells. We also find that the acute loss of E2F3 activity affects the expression of genes encoding DNA replication and mitotic activities, whereas loss of E2F1 affects a limited number of genes that are distinct from those regulated by E2F3. We conclude that the long-term loss of E2F activity does lead to compensation by other family members and that the analysis of acute loss of function reveals specific and distinct roles for these proteins.

Standard name | TANAKA_METHYLATED_IN_ESOPHAGEAL_CARCINOMA
Systematic name | M14455
Organism | Homo sapiens
PMID | 17438526
Authors | Tanaka K,Imoto I,Inoue J,Kozaki K,Tsuda H,Shimada Y,Aiko S,Yoshizumi Y,Iwai T,Kawano T,Inazawa J
Category | C2
Sub-category | CGP
Brief description | Genes with hypermethylated DNA in all four esophageal squamous cell carcinoma (ESCC) lines analyzed.
Full description | Epigenetic alterations and the resulting inactivation of tumor suppressor genes often contribute to the development of various cancers. To identify novel candidates that may be silenced by aberrant methylation in esophageal squamous-cell carcinoma (ESCC), we analysed ESCC cell lines by a recently developed method known as bacterial artificial chromosome array-based methylated CpG island amplification (BAMCA), and selected candidates through BAMCA-assisted strategy. In the course of this program, we identified frequent CpG methylation-dependent silencing of the gene encoding cellular retinoic acid binding protein 1 (CRABP1) in our panel of ESCC cell lines. Expression of CRABP1 mRNA was restored in gene-silenced ESCC cells after treatment with 5-aza 2'-deoxycytidine. The DNA methylation status of the CRABP1 CpG island with clear promoter activity correlated inversely with expression of this gene. CpG methylation of CRABP1 was frequently observed in primary ESCC tissues as well. Restoration of CRABP1 expression in ESCC cells lacking the protein reduced cell growth by inducing arrest at G(0)-G(1), whereas knockdown of the gene in cells expressing CRABP1 promoted cell growth. Among 113 primary ESCC tumors, the absence of immunoreactive CRABP1 was significantly associated with de-differentiation of cancer cells and with distant lymph-node metastases in the patients. These results indicate that CRABP1 appears to have a tumor-suppressor function in esophageal epithelium, and its epigenetic silencing may play a pivotal role during esophageal carcinogenesis. Its expression status in biopsies or resected tumors might serve as an index for identifying ESCC patients for whom combined therapeutic modalities would be recommended.

Standard name | EGUCHI_CELL_CYCLE_RB1_TARGETS
Systematic name | M4455
Organism | Homo sapiens
PMID | 16862181
Authors | Eguchi T,Takaki T,Itadani H,Kotani H
Category | C2
Sub-category | CGP
Brief description | RB1 [GeneID=5925] target genes involved in cell cycle regulation: genes down-regulated by doxorubicin [PubChem=31703] only in cells expressing RB1.
Full description | As alterations in retinoblastoma (RB)/E2F pathway are commonly found in human cancers, the molecular mechanism underlying cell cycle deregulation caused by the mutations in the RB/E2F pathway needs to be investigated extensively. Compared with good understanding of RB/E2F functions in G1-S cell cycle progression, it is not fully understood how an abrogated RB pathway affects the G2-M phase of the cell cycle. Here, we report that disruption of RB accelerated G2-M progression in the presence of DNA damage by elevating the expression of a set of mitotic regulatory genes. We generated RB(+)- and (-)-matched cells using short hairpin RNA. In the RB(-) cells, the G2/M checkpoint mediated by a DNA-damaging agent was over-ridden. With microarray analysis, we found that the expression of key G2-M regulatory genes was upregulated in RB(-) cells. In particular, we demonstrated that the proto-oncogene ECT2 was directly regulated by E2Fs. Furthermore, suppression of ECT2 expression by small interfering RNA in RB(-) cells resulted in cytokinesis arrest, suggesting that RB(-) cells lack the regulation of E2F-mediated cytokinesis. These results indicate that aberrant ECT2 expression, observed in various human tumors, could be the direct result of RB/E2F pathway deficiency, thereby contributing to cell division in cancers.

Standard name | CROSBY_E2F4_TARGETS
Systematic name | M1158
Organism | Homo sapiens
PMID | 17043659
Authors | Crosby ME,Jacobberger J,Gupta D,Macklis RM,Almasan A
Category | C2
Sub-category | CGP
Brief description | Putative E2F4 [GeneID=1874] target genes identified as mitotic genes down-regulated in the LNCaP C4-2 cells (prostate cancer) at both 6 and 24 h following irradiation.
Full description | The retinoblastoma (pRB) family proteins regulate the E2F transcription factors; their complexes regulate critical transitions through the cell cycle. The function of these pRB family/E2F complexes, which includes p130/E2F4, in response to genotoxic agents, is not well understood. We investigated the role of E2F4 in the genotoxic stress response. Following radiation treatment, E2F4 colocalized with p130 in the nucleus during a radiation-induced stable G(2)-phase arrest. Arrested cells had significantly decreased expression of Cyclins A2 and B1 and decreased phosphorylation of mitotic protein monoclonal-2 (MPM-2) mitotic proteins. Small interference RNA (siRNA)-mediated knockdown of E2F4 sensitized cells to subsequent irradiation, resulting in enhanced cellular DNA damage and cell death, as determined by caspase activation and decreased clonogenic cell survival. Downstream E2F4 targets potentially involved in the progression from G(2) into M phase were identified by oligonucleotide microarray expression profiling. Chromatin immunoprecipitation localized E2F4 at promoter regions of the Bub3 and Pttg1 mitotic genes following irradiation, which were among the downregulated genes identified by the microarray. These data suggest that in response to radiation, E2F4 becomes active in the nucleus, enforces a stable G(2) arrest by target gene repression, and thus provides increased cell survival ability by minimizing propagation of cells that have irreparable DNA damage.

Standard name | MARKS_ACETYLATED_NON_HISTONE_PROTEINS
Systematic name | M1160
Organism | Homo sapiens
PMID | 17322921
Authors | Marks PA
Category | C2
Sub-category | CGP
Brief description | Non-histone proteins that are acetylated.
Full description | The path to the discovery of suberoylanilide hydroxamic acid (SAHA, vorinostat) began over three decades ago with our studies designed to understand why dimethylsulfoxide causes terminal differentiation of the virus-transformed cells, murine erythroleukemia cells. SAHA can cause growth arrest and death of a broad variety of transformed cells both in vitro and in vivo at concentrations that have little or no toxic effects on normal cells. It was discovered that SAHA inhibits the activity of histone deacetylases (HDACs), including all 11 known human class I and class II HDACs. HDACs have many protein targets whose structure and function are altered by acetylation including histones and non-histone proteins component of transcription factors controlling gene expression and proteins that regulate cell proliferation, migration and death. SAHA is in clinical trials and has significant anticancer activity against both hematologic and solid tumors at doses well tolerated by patients. A new drug application has been approved for SAHA (vorinostat) treatment of cutaneous T-cell lymphoma.

Standard name | IVANOV_MUTATED_IN_COLON_CANCER
Systematic name | M5989
Organism | Homo sapiens
PMID | 17086209
Authors | Ivanov I,Lo KC,Hawthorn L,Cowell JK,Ionov Y
Category | C2
Sub-category | CGP
Brief description | Genes mutated in colon cancer cell lines, identified using the GINI method described in the paper.
Full description | Inhibition of the nonsense-mediated decay (NMD) mechanism in cells results in stabilization of transcripts carrying premature translation termination codons. A strategy referred to as gene identification by NMD inhibition (GINI) has been proposed to identify genes carrying nonsense mutations. Genes containing frameshift mutations in colon cancer cell line have been identified using a modified version of GINI. To increase the efficiency of identifying mutant genes using GINI, we have now further improved the strategy. In this approach, inhibition of NMD with emetine is complemented with inhibiting NMD by blocking the phosphorylation of the hUpf1 protein with caffeine. In addition, to enhance the GINI strategy, comparing mRNA level alterations produced by inhibiting transcription alone or inhibiting transcription together with NMD following caffeine pretreatment were used for the efficient identification of false positives produced as a result of stress response to NMD inhibition. To demonstrate the improved efficiency of this approach, we analysed colon cancer cell lines showing microsatellite instability. Bi-allelic inactivating mutations were found in the FXR1, SEC31L1, NCOR1, BAT3, PHF14, ZNF294, C19ORF5 genes as well as genes coding for proteins with yet unknown functions.

Standard name | TAKAYAMA_BOUND_BY_AR
Systematic name | M5315
Organism | Homo sapiens
PMID | 17297473
Authors | Takayama K,Kaneshiro K,Tsutsumi S,Horie-Inoue K,Ikeda K,Urano T,Ijichi N,Ouchi Y,Shirahige K,Aburatani H,Inoue S
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters bound AR [GeneID=367] in LNCaP cells (prostate cancer) after exposure to the synthetic androgen R1881 [PubChem=13766], based on ChIP-chip analysis.
Full description | The androgen receptor (AR) plays a key role as a transcriptional factor in prostate development and carcinogenesis. Identification of androgen-regulated genes is essential to elucidate the AR pathophysiology in prostate cancer. Here, we identified androgen target genes that are directly regulated by AR in LNCaP cells, by combining chromatin immunoprecipitation (ChIP) with tiling microarrays (ChIP-chip). ChIP-enriched or control DNAs from the cells treated with R1881 were hybridized with the ENCODE array, in which a set of regions representing approximately 1% of the whole genome. We chose 10 bona fide AR-binding sites (ARBSs) (P<1e-5) and validated their significant AR recruitment ligand dependently. Eight upregulated genes by R1881 were identified in the vicinity of the ARBSs. Among the upregulated genes, we focused on UGT1A and CDH2 as AR target genes, because the ARBSs close to these genes (in UGT1A distal promoter and CDH2 intron 1) were most significantly associated with acetylated histone H3/H4, RNA polymerase II and p160 family co-activators. Luciferase reporter constructs including those two ARBSs exhibited ligand-dependent transcriptional regulator/enhancer activities. The present study would be powerful to extend our knowledge of the diversity of androgen genetic network and steroid action in prostate cancer cells.

Standard name | RIZ_ERYTHROID_DIFFERENTIATION
Systematic name | M16458
Organism | Mus musculus
PMID | 17213805
Authors | Riz I,Akimov SS,Eaker SS,Baxter KK,Lee HJ,Mariño-Ramírez L,Landsman D,Hawley TS,Hawley RG
Category | C2
Sub-category | CGP
Brief description | Selected gradually up-regulated genes in the TLX1 [GeneID=3195] Tet On iEBHX15-4 cells (pro-erythroblasts).
Full description | Aberrant expression of the human homeobox-containing proto-oncogene TLX1/HOX11 inhibits hematopoietic differentiation programs in a number of murine model systems. Here, we report the establishment of a murine erythroid progenitor cell line, iEBHX1S-4, developmentally arrested by regulatable TLX1 expression. Extinction of TLX1 expression released the iEBHX1S-4 differentiation block, allowing erythropoietin-dependent acquisition of erythroid markers and hemoglobin synthesis. Coordinated activation of erythroid transcriptional networks integrated by the acetyltransferase co-activator CREB-binding protein (CBP) was suggested by bioinformatic analysis of the upstream regulatory regions of several conditionally induced iEBHX1S-4 gene sets. In accord with this notion, CBP-associated acetylation of GATA-1, an essential regulator of erythroid differentiation, increased concomitantly with TLX1 downregulation. Coimmunoprecipitation experiments and glutathione-S-transferase pull-down assays revealed that TLX1 directly binds to CBP, and confocal laser microscopy demonstrated that the two proteins partially colocalize at intranuclear sites in iEBHX1S-4 cells. Notably, the distribution of CBP in conditionally blocked iEBHX1S-4 cells partially overlapped with chromatin marked by a repressive histone methylation pattern, and downregulation of TLX1 coincided with exit of CBP from these heterochromatic regions. Thus, we propose that TLX1-mediated differentiation arrest may be achieved in part through a mechanism that involves redirection of CBP and/or its sequestration in repressive chromatin domains.

Standard name | RIZ_ERYTHROID_DIFFERENTIATION_CCNE1
Systematic name | M11048
Organism | Mus musculus
PMID | 17213805
Authors | Riz I,Akimov SS,Eaker SS,Baxter KK,Lee HJ,Mariño-Ramírez L,Landsman D,Hawley TS,Hawley RG
Category | C2
Sub-category | CGP
Brief description | Selected gradually up-regulated genes whose expression profile follows that of CCNE1 [GeneID=898] in the TLX1 [GeneID=3195] Tet On iEBHX15-4 cells (pro-erythroblasts).
Full description | Aberrant expression of the human homeobox-containing proto-oncogene TLX1/HOX11 inhibits hematopoietic differentiation programs in a number of murine model systems. Here, we report the establishment of a murine erythroid progenitor cell line, iEBHX1S-4, developmentally arrested by regulatable TLX1 expression. Extinction of TLX1 expression released the iEBHX1S-4 differentiation block, allowing erythropoietin-dependent acquisition of erythroid markers and hemoglobin synthesis. Coordinated activation of erythroid transcriptional networks integrated by the acetyltransferase co-activator CREB-binding protein (CBP) was suggested by bioinformatic analysis of the upstream regulatory regions of several conditionally induced iEBHX1S-4 gene sets. In accord with this notion, CBP-associated acetylation of GATA-1, an essential regulator of erythroid differentiation, increased concomitantly with TLX1 downregulation. Coimmunoprecipitation experiments and glutathione-S-transferase pull-down assays revealed that TLX1 directly binds to CBP, and confocal laser microscopy demonstrated that the two proteins partially colocalize at intranuclear sites in iEBHX1S-4 cells. Notably, the distribution of CBP in conditionally blocked iEBHX1S-4 cells partially overlapped with chromatin marked by a repressive histone methylation pattern, and downregulation of TLX1 coincided with exit of CBP from these heterochromatic regions. Thus, we propose that TLX1-mediated differentiation arrest may be achieved in part through a mechanism that involves redirection of CBP and/or its sequestration in repressive chromatin domains.

Standard name | RIZ_ERYTHROID_DIFFERENTIATION_HBZ
Systematic name | M802
Organism | Mus musculus
PMID | 17213805
Authors | Riz I,Akimov SS,Eaker SS,Baxter KK,Lee HJ,Mariño-Ramírez L,Landsman D,Hawley TS,Hawley RG
Category | C2
Sub-category | CGP
Brief description | Selected gradually up-regulated genes whose expression profile follows that of HBZ [GeneID=3050] in the TLX1 [GeneID=3195] Tet On iEBHX15-4 cells (pro-erythroblasts).
Full description | Aberrant expression of the human homeobox-containing proto-oncogene TLX1/HOX11 inhibits hematopoietic differentiation programs in a number of murine model systems. Here, we report the establishment of a murine erythroid progenitor cell line, iEBHX1S-4, developmentally arrested by regulatable TLX1 expression. Extinction of TLX1 expression released the iEBHX1S-4 differentiation block, allowing erythropoietin-dependent acquisition of erythroid markers and hemoglobin synthesis. Coordinated activation of erythroid transcriptional networks integrated by the acetyltransferase co-activator CREB-binding protein (CBP) was suggested by bioinformatic analysis of the upstream regulatory regions of several conditionally induced iEBHX1S-4 gene sets. In accord with this notion, CBP-associated acetylation of GATA-1, an essential regulator of erythroid differentiation, increased concomitantly with TLX1 downregulation. Coimmunoprecipitation experiments and glutathione-S-transferase pull-down assays revealed that TLX1 directly binds to CBP, and confocal laser microscopy demonstrated that the two proteins partially colocalize at intranuclear sites in iEBHX1S-4 cells. Notably, the distribution of CBP in conditionally blocked iEBHX1S-4 cells partially overlapped with chromatin marked by a repressive histone methylation pattern, and downregulation of TLX1 coincided with exit of CBP from these heterochromatic regions. Thus, we propose that TLX1-mediated differentiation arrest may be achieved in part through a mechanism that involves redirection of CBP and/or its sequestration in repressive chromatin domains.

Standard name | CHASSOT_SKIN_WOUND
Systematic name | M13038
Organism | Homo sapiens
PMID | 17404577
Authors | Chassot AA,Turchi L,Virolle T,Fitsialos G,Batoz M,Deckert M,Dulic V,Meneguzzi G,Buscà R,Ponzio G
Category | C2
Sub-category | CGP
Brief description | List of the transcription factors up-regulated 1 hr after wounding HDF cells (dermal fibroblasts).
Full description | P27kip is a key inhibitory protein of the cell-cycle progression, which is rapidly downregulated in early G1 phase by a post-translational mechanism involving the proteosomal degradation. In this study, using a wounding model that induces cell-cycle entry of human dermal fibroblasts, we demonstrate that p27mRNA is downregulated when cells progress into the G1 phase, and then it returns to its basal level when cells approach the S phase. By using a quantitative polymerase chain reaction screening we identified inhibitors of differentiation (Id3), a bHLH transcriptional repressor, as a candidate mediator accounting for p27 mRNA decrease. Id3 silencing, using an small interfering RNA approach, reversed the injury mediated p27 downregulation demonstrating that Id3 is involved in the transcriptional repression of p27. Reporter gene experiments and a chromatin immunoprecipitation assay showed that Id3 likely exerts its repressive action through ELK1 inhibition. By inhibiting early p27 downregulation, Id3 depletion blocked (i) the G1-phase progression as assessed by the inhibition of pRb phosphorylation and p130 degradation and (ii) the G1/S transition as observed by the inhibition of cyclin A induction, demonstrating that p27 mRNA decrease is required for cell proliferation. Apart from its effect on the early p27 diminution, Id3 appears also involved in the control of the steady-state level of p27 at the G1/S boundary. In conclusion, this study identifies a novel mechanism of p27 regulation which besides p27 protein degradation also implicates a transcriptional mechanism mediated by Id3.

Standard name | LASTOWSKA_NEUROBLASTOMA_COPY_NUMBER_UP
Systematic name | M4203
Organism | Homo sapiens
PMID | 17533364
Authors | Łastowska M,Viprey V,Santibanez-Koref M,Wappler I,Peters H,Cullinane C,Roberts P,Hall AG,Tweddle DA,Pearson AD,Lewis I,Burchill SA,Jackson MS
Category | C2
Sub-category | CGP
Brief description | Genes with copy number gains in primary neuroblastoma tumors.
Full description | Identifying genes, whose expression is consistently altered by chromosomal gains or losses, is an important step in defining genes of biological relevance in a wide variety of tumour types. However, additional criteria are needed to discriminate further among the large number of candidate genes identified. This is particularly true for neuroblastoma, where multiple genomic copy number changes of proven prognostic value exist. We have used Affymetrix microarrays and a combination of fluorescent in situ hybridization and single nucleotide polymorphism (SNP) microarrays to establish expression profiles and delineate copy number alterations in 30 primary neuroblastomas. Correlation of microarray data with patient survival and analysis of expression within rodent neuroblastoma cell lines were then used to define further genes likely to be involved in the disease process. Using this approach, we identify >1000 genes within eight recurrent genomic alterations (loss of 1p, 3p, 4p, 10q and 11q, 2p gain, 17q gain, and the MYCN amplicon) whose expression is consistently altered by copy number change. Of these, 84 correlate with patient survival, with the minimal regions of 17q gain and 4p loss being enriched significantly for such genes. These include genes involved in RNA and DNA metabolism, and apoptosis. Orthologues of all but one of these genes on 17q are overexpressed in rodent neuroblastoma cell lines. A significant excess of SNPs whose copy number correlates with survival is also observed on proximal 4p in stage 4 tumours, and we find that deletion of 4p is associated with improved outcome in an extended cohort of tumours. These results define the major impact of genomic copy number alterations upon transcription within neuroblastoma, and highlight genes on distal 17q and proximal 4p for downstream analyses. They also suggest that integration of discriminators, such as survival and comparative gene expression, with microarray data may be useful in the identification of critical genes within regions of loss or gain in many human cancers.

Standard name | LASTOWSKA_NEUROBLASTOMA_COPY_NUMBER_DN
Systematic name | M14594
Organism | Homo sapiens
PMID | 17533364
Authors | Łastowska M,Viprey V,Santibanez-Koref M,Wappler I,Peters H,Cullinane C,Roberts P,Hall AG,Tweddle DA,Pearson AD,Lewis I,Burchill SA,Jackson MS
Category | C2
Sub-category | CGP
Brief description | Genes with copy number losses in primary neuroblastoma tumors.
Full description | Identifying genes, whose expression is consistently altered by chromosomal gains or losses, is an important step in defining genes of biological relevance in a wide variety of tumour types. However, additional criteria are needed to discriminate further among the large number of candidate genes identified. This is particularly true for neuroblastoma, where multiple genomic copy number changes of proven prognostic value exist. We have used Affymetrix microarrays and a combination of fluorescent in situ hybridization and single nucleotide polymorphism (SNP) microarrays to establish expression profiles and delineate copy number alterations in 30 primary neuroblastomas. Correlation of microarray data with patient survival and analysis of expression within rodent neuroblastoma cell lines were then used to define further genes likely to be involved in the disease process. Using this approach, we identify >1000 genes within eight recurrent genomic alterations (loss of 1p, 3p, 4p, 10q and 11q, 2p gain, 17q gain, and the MYCN amplicon) whose expression is consistently altered by copy number change. Of these, 84 correlate with patient survival, with the minimal regions of 17q gain and 4p loss being enriched significantly for such genes. These include genes involved in RNA and DNA metabolism, and apoptosis. Orthologues of all but one of these genes on 17q are overexpressed in rodent neuroblastoma cell lines. A significant excess of SNPs whose copy number correlates with survival is also observed on proximal 4p in stage 4 tumours, and we find that deletion of 4p is associated with improved outcome in an extended cohort of tumours. These results define the major impact of genomic copy number alterations upon transcription within neuroblastoma, and highlight genes on distal 17q and proximal 4p for downstream analyses. They also suggest that integration of discriminators, such as survival and comparative gene expression, with microarray data may be useful in the identification of critical genes within regions of loss or gain in many human cancers.

Standard name | MUELLER_METHYLATED_IN_GLIOBLASTOMA
Systematic name | M912
Organism | Homo sapiens
PMID | 16909125
Authors | Mueller W,Nutt CL,Ehrich M,Riemenschneider MJ,von Deimling A,van den Boom D,Louis DN
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in short-term cultured glioblastomas after azacitidine [PubChem=9444] treatment.
Full description | Glioblastoma, the most aggressive and least treatable form of malignant glioma, is the most common human brain tumor. Although many regions of allelic loss occur in glioblastomas, relatively few tumor suppressor genes have been found mutated at such loci. To address the possibility that epigenetic alterations are an alternative means of glioblastoma gene inactivation, we coupled pharmacological manipulation of methylation with gene profiling to identify potential methylation-regulated, tumor-related genes. Duplicates of three short-term cultured glioblastomas were exposed to 5 microM 5-aza-dC for 96 h followed by cRNA hybridization to an oligonucleotide microarray (Affymetrix U133A). We based candidate gene selection on bioinformatics, reverse transcription-polymerase chain reaction (RT-PCR), bisulfite sequencing, methylation-specific PCR and matrix-assisted laser desorption/ionization time-of-flight mass spectrometry. Two genes identified in this manner, RUNX3 and Testin (TES), were subsequently shown to harbor frequent tumor-specific epigenetic alterations in primary glioblastomas. This overall approach therefore provides a powerful means to identify candidate tumor-suppressor genes for subsequent evaluation and may lead to the identification of genes whose epigenetic dysregulation is integral to glioblastoma tumorigenesis.

Standard name | RIZ_ERYTHROID_DIFFERENTIATION_HEMGN
Systematic name | M7999
Organism | Mus musculus
PMID | 17213805
Authors | Riz I,Akimov SS,Eaker SS,Baxter KK,Lee HJ,Mariño-Ramírez L,Landsman D,Hawley TS,Hawley RG
Category | C2
Sub-category | CGP
Brief description | Selected gradually up-regulated genes whose expression profile follows that of HEMGN [GeneID=55363] in the TLX1 [GeneID=3195] Tet On iEBHX15-4 cells (pro-erythroblasts).
Full description | Aberrant expression of the human homeobox-containing proto-oncogene TLX1/HOX11 inhibits hematopoietic differentiation programs in a number of murine model systems. Here, we report the establishment of a murine erythroid progenitor cell line, iEBHX1S-4, developmentally arrested by regulatable TLX1 expression. Extinction of TLX1 expression released the iEBHX1S-4 differentiation block, allowing erythropoietin-dependent acquisition of erythroid markers and hemoglobin synthesis. Coordinated activation of erythroid transcriptional networks integrated by the acetyltransferase co-activator CREB-binding protein (CBP) was suggested by bioinformatic analysis of the upstream regulatory regions of several conditionally induced iEBHX1S-4 gene sets. In accord with this notion, CBP-associated acetylation of GATA-1, an essential regulator of erythroid differentiation, increased concomitantly with TLX1 downregulation. Coimmunoprecipitation experiments and glutathione-S-transferase pull-down assays revealed that TLX1 directly binds to CBP, and confocal laser microscopy demonstrated that the two proteins partially colocalize at intranuclear sites in iEBHX1S-4 cells. Notably, the distribution of CBP in conditionally blocked iEBHX1S-4 cells partially overlapped with chromatin marked by a repressive histone methylation pattern, and downregulation of TLX1 coincided with exit of CBP from these heterochromatic regions. Thus, we propose that TLX1-mediated differentiation arrest may be achieved in part through a mechanism that involves redirection of CBP and/or its sequestration in repressive chromatin domains.

Standard name | RIZ_ERYTHROID_DIFFERENTIATION_APOBEC2
Systematic name | M15638
Organism | Mus musculus
PMID | 17213805
Authors | Riz I,Akimov SS,Eaker SS,Baxter KK,Lee HJ,Mariño-Ramírez L,Landsman D,Hawley TS,Hawley RG
Category | C2
Sub-category | CGP
Brief description | Selected genes whose expression profile follows that of APOBEC2 [GeneID=10930] in the TLX1 [GeneID=3195] Tet On iEBHX15-4 cells (pro-erythroblasts).
Full description | Aberrant expression of the human homeobox-containing proto-oncogene TLX1/HOX11 inhibits hematopoietic differentiation programs in a number of murine model systems. Here, we report the establishment of a murine erythroid progenitor cell line, iEBHX1S-4, developmentally arrested by regulatable TLX1 expression. Extinction of TLX1 expression released the iEBHX1S-4 differentiation block, allowing erythropoietin-dependent acquisition of erythroid markers and hemoglobin synthesis. Coordinated activation of erythroid transcriptional networks integrated by the acetyltransferase co-activator CREB-binding protein (CBP) was suggested by bioinformatic analysis of the upstream regulatory regions of several conditionally induced iEBHX1S-4 gene sets. In accord with this notion, CBP-associated acetylation of GATA-1, an essential regulator of erythroid differentiation, increased concomitantly with TLX1 downregulation. Coimmunoprecipitation experiments and glutathione-S-transferase pull-down assays revealed that TLX1 directly binds to CBP, and confocal laser microscopy demonstrated that the two proteins partially colocalize at intranuclear sites in iEBHX1S-4 cells. Notably, the distribution of CBP in conditionally blocked iEBHX1S-4 cells partially overlapped with chromatin marked by a repressive histone methylation pattern, and downregulation of TLX1 coincided with exit of CBP from these heterochromatic regions. Thus, we propose that TLX1-mediated differentiation arrest may be achieved in part through a mechanism that involves redirection of CBP and/or its sequestration in repressive chromatin domains.

Standard name | RIZ_ERYTHROID_DIFFERENTIATION_6HR
Systematic name | M1854
Organism | Mus musculus
PMID | 17213805
Authors | Riz I,Akimov SS,Eaker SS,Baxter KK,Lee HJ,Mariño-Ramírez L,Landsman D,Hawley TS,Hawley RG
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated in the TLX1 [GeneID=3195] Tet On iEBHX15-4 cells (pro-erythroblasts) at 6 h time point.
Full description | Aberrant expression of the human homeobox-containing proto-oncogene TLX1/HOX11 inhibits hematopoietic differentiation programs in a number of murine model systems. Here, we report the establishment of a murine erythroid progenitor cell line, iEBHX1S-4, developmentally arrested by regulatable TLX1 expression. Extinction of TLX1 expression released the iEBHX1S-4 differentiation block, allowing erythropoietin-dependent acquisition of erythroid markers and hemoglobin synthesis. Coordinated activation of erythroid transcriptional networks integrated by the acetyltransferase co-activator CREB-binding protein (CBP) was suggested by bioinformatic analysis of the upstream regulatory regions of several conditionally induced iEBHX1S-4 gene sets. In accord with this notion, CBP-associated acetylation of GATA-1, an essential regulator of erythroid differentiation, increased concomitantly with TLX1 downregulation. Coimmunoprecipitation experiments and glutathione-S-transferase pull-down assays revealed that TLX1 directly binds to CBP, and confocal laser microscopy demonstrated that the two proteins partially colocalize at intranuclear sites in iEBHX1S-4 cells. Notably, the distribution of CBP in conditionally blocked iEBHX1S-4 cells partially overlapped with chromatin marked by a repressive histone methylation pattern, and downregulation of TLX1 coincided with exit of CBP from these heterochromatic regions. Thus, we propose that TLX1-mediated differentiation arrest may be achieved in part through a mechanism that involves redirection of CBP and/or its sequestration in repressive chromatin domains.

Standard name | RIZ_ERYTHROID_DIFFERENTIATION_12HR
Systematic name | M4389
Organism | Mus musculus
PMID | 17213805
Authors | Riz I,Akimov SS,Eaker SS,Baxter KK,Lee HJ,Mariño-Ramírez L,Landsman D,Hawley TS,Hawley RG
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated in the TLX1 [GeneID=3195] Tet On iEBHX15-4 cells (pro-erythroblasts) at 12 h time point.
Full description | Aberrant expression of the human homeobox-containing proto-oncogene TLX1/HOX11 inhibits hematopoietic differentiation programs in a number of murine model systems. Here, we report the establishment of a murine erythroid progenitor cell line, iEBHX1S-4, developmentally arrested by regulatable TLX1 expression. Extinction of TLX1 expression released the iEBHX1S-4 differentiation block, allowing erythropoietin-dependent acquisition of erythroid markers and hemoglobin synthesis. Coordinated activation of erythroid transcriptional networks integrated by the acetyltransferase co-activator CREB-binding protein (CBP) was suggested by bioinformatic analysis of the upstream regulatory regions of several conditionally induced iEBHX1S-4 gene sets. In accord with this notion, CBP-associated acetylation of GATA-1, an essential regulator of erythroid differentiation, increased concomitantly with TLX1 downregulation. Coimmunoprecipitation experiments and glutathione-S-transferase pull-down assays revealed that TLX1 directly binds to CBP, and confocal laser microscopy demonstrated that the two proteins partially colocalize at intranuclear sites in iEBHX1S-4 cells. Notably, the distribution of CBP in conditionally blocked iEBHX1S-4 cells partially overlapped with chromatin marked by a repressive histone methylation pattern, and downregulation of TLX1 coincided with exit of CBP from these heterochromatic regions. Thus, we propose that TLX1-mediated differentiation arrest may be achieved in part through a mechanism that involves redirection of CBP and/or its sequestration in repressive chromatin domains.

Standard name | EBAUER_TARGETS_OF_PAX3_FOXO1_FUSION_UP
Systematic name | M78
Organism | Homo sapiens
PMID | 17525748
Authors | Ebauer M,Wachtel M,Niggli FK,Schäfer BW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Rh4 cells (alveolar rhabdomyosarcoma, ARMS) after knockdown of the PAX3-FOXO1 [GeneiD=5077;2308] fusion protein by RNAi for 72 hr.
Full description | The chromosomal translocation t(2;13), characteristic for the aggressive childhood cancer alveolar rhabdomyosarcoma (aRMS), generates the chimeric transcription factor PAX3/FKHR with a well known oncogenic role. However, the molecular mechanisms mediating essential pathophysiological functions remain poorly defined. Here, we used comparative expression profiling of PAX3/FKHR silencing in vitro and PAX3/FKHR-specific gene signatures in vivo to identify physiologically important target genes. Hereby, 51 activated genes, both novel and known, were identified. We also found repression of skeletal muscle-specific genes suggesting that PAX3/FKHR blocks further differentiation of aRMS cells. Importantly, TFAP2B was validated as direct target gene mediating the anti-apoptotic function of PAX3/FKHR. Hence, we developed a pathophysiologically relevant transcriptional profile of PAX3/FKHR and identified a critical target gene for aRMS development.

Standard name | PEREZ_TP53_TARGETS
Systematic name | M4391
Organism | Homo sapiens
PMID | 17563751
Authors | Perez CA,Ott J,Mays DJ,Pietenpol JA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the HMEC cells (primary mammary epithelium) upon expression of TP53 [GeneID=7157] off adenoviral vector.
Full description | p53 and p63 belong to a family of sequence-specific transcription factors regulating key cellular processes. Differential composition of the p53 and p63 DNA-binding sites may contribute to distinct functions of these protein homologues. We used SELEX (systematic evolution of ligands by exponential enrichment) methodology to identify nucleic acid ligands for p63. We found that p63 bound preferentially to DNA fragments conforming to the 20 bp sequence 5'-RRRC(A/G)(A/T)GYYYRRRC(A/T)(C/T)GYYY-3'. Relative to the p53 consensus, the p63 consensus DNA-binding site (DBS) was more degenerate, particularly at positions 10 and 11, and was enriched for A/G at position 5 and C/T at position 16 of the consensus. The differences in DNA-binding site preferences between p63 and p53 influenced their ability to activate transcription from select response elements (REs) in cells. A computer algorithm, p63MH, was developed to find candidate p63-binding motifs on input sequences. We identified genes responsive to p63 regulation that contain functional p63 REs. Our results suggest that the sequence composition of REs could be one contributing factor to target gene discrimination between p63 and p53.

Standard name | PEREZ_TP63_TARGETS
Systematic name | M10761
Organism | Homo sapiens
PMID | 17563751
Authors | Perez CA,Ott J,Mays DJ,Pietenpol JA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the HMEC cells (primary mammary epithelium) upon expression of the transcriptionally active isoform of TP63 [GeneID=8626] off adenoviral vector.
Full description | p53 and p63 belong to a family of sequence-specific transcription factors regulating key cellular processes. Differential composition of the p53 and p63 DNA-binding sites may contribute to distinct functions of these protein homologues. We used SELEX (systematic evolution of ligands by exponential enrichment) methodology to identify nucleic acid ligands for p63. We found that p63 bound preferentially to DNA fragments conforming to the 20 bp sequence 5'-RRRC(A/G)(A/T)GYYYRRRC(A/T)(C/T)GYYY-3'. Relative to the p53 consensus, the p63 consensus DNA-binding site (DBS) was more degenerate, particularly at positions 10 and 11, and was enriched for A/G at position 5 and C/T at position 16 of the consensus. The differences in DNA-binding site preferences between p63 and p53 influenced their ability to activate transcription from select response elements (REs) in cells. A computer algorithm, p63MH, was developed to find candidate p63-binding motifs on input sequences. We identified genes responsive to p63 regulation that contain functional p63 REs. Our results suggest that the sequence composition of REs could be one contributing factor to target gene discrimination between p63 and p53.

Standard name | PEREZ_TP53_AND_TP63_TARGETS
Systematic name | M14566
Organism | Homo sapiens
PMID | 17563751
Authors | Perez CA,Ott J,Mays DJ,Pietenpol JA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HMEC cells (primary mammary epithelium) upon expression of both of TP53 [GeneID=7157] and the transcriptionally active isoform of TP63 [GeneID=8626] off adenoviral vectors.
Full description | p53 and p63 belong to a family of sequence-specific transcription factors regulating key cellular processes. Differential composition of the p53 and p63 DNA-binding sites may contribute to distinct functions of these protein homologues. We used SELEX (systematic evolution of ligands by exponential enrichment) methodology to identify nucleic acid ligands for p63. We found that p63 bound preferentially to DNA fragments conforming to the 20 bp sequence 5'-RRRC(A/G)(A/T)GYYYRRRC(A/T)(C/T)GYYY-3'. Relative to the p53 consensus, the p63 consensus DNA-binding site (DBS) was more degenerate, particularly at positions 10 and 11, and was enriched for A/G at position 5 and C/T at position 16 of the consensus. The differences in DNA-binding site preferences between p63 and p53 influenced their ability to activate transcription from select response elements (REs) in cells. A computer algorithm, p63MH, was developed to find candidate p63-binding motifs on input sequences. We identified genes responsive to p63 regulation that contain functional p63 REs. Our results suggest that the sequence composition of REs could be one contributing factor to target gene discrimination between p63 and p53.

Standard name | WAKASUGI_HAVE_ZNF143_BINDING_SITES
Systematic name | M9575
Organism | Homo sapiens
PMID | 17297437
Authors | Wakasugi T,Izumi H,Uchiumi T,Suzuki H,Arao T,Nishio K,Kohno K
Category | C2
Sub-category | CGP
Brief description | DNA repair genes whose promoters contain putative ZNF143 [GeneID=7702] binding sites.
Full description | Zinc-finger protein 143 (ZNF143) is a human homolog of Xenopus transcriptional activator staf that is involved in selenocystyl tRNA transcription. We previously showed that ZNF143 expression is induced by treatment with DNA-damaging agents and that it preferentially binds to cisplatin-modified DNA. In this study, the potential function of ZNF143 was investigated. ZNF143 was overexpressed in cisplatin-resistant cells. ZNF143 knockdown in prostate cancer caused increased sensitivity for cisplatin, but not for oxaliplatin, etoposide and vincristine. We also showed that ZNF143 is associated with tumor suppressor gene product p73 but not with p53. p73 could stimulate the binding of ZNF143 to both ZNF143 binding site and cisplatin-modified DNA, and modulate the function of ZNF143. We provide a direct evidence that both Rad51 and flap endonuclease-1 are target genes of ZNF143 and overexpressed in cisplatin-resistant cells. Taken together, these experiments demonstrate that an interplay of ZNF143, p73 and ZNF143 target genes is involved in DNA repair gene expression and cisplatin resistance.

Standard name | RODRIGUES_NTN1_AND_DCC_TARGETS
Systematic name | M3346
Organism | Homo sapiens
PMID | 17334389
Authors | Rodrigues S,De Wever O,Bruyneel E,Rooney RJ,Gespach C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HCT8/S11 cells (colon cancer) which lack DCC [GeneID=9423] and stably express NTN1 [GeneID=1630].
Full description | Deleted in colon cancer (DCC) and UNC5 function as netrin dependence receptors by inducing apoptosis in the absence of their ligand and accordingly were recently designated as putative conditional tumor suppressors. Herein, we determined whether netrin-1 and its receptors are implicated in cancer cell invasion and tumor progression. Expression of DCC, UNC5 and adenosine A2B-receptors (A2B-Rs) was investigated by reverse transcription polymerase chain reaction in human colon cancer cells. The impact of DCC restitution and netrin-1 was evaluated on collagen type I invasion, tumor growth and metastasis in nude mice, cancer cell survival and gene expression profiling. Flow cytometry, poly(ADP-ribose)polymerase-1 and caspase-8 activation were used to evaluate the impact of DCC on cell death. Both netrin-1 and A2B-R activation induced the invasive phenotype through the Rho-Rho kinase axis in DCC-deficient human colorectal cancer cells. Restitution of wild-type DCC blocked invasion induced by netrin-1, A2B-R agonist and other agents. Ectopic expression of netrin-1 led to increased growth of human colon tumor xenografts in athymic mice. Conversely, introduction of wt-DCC in kidney MDCKts.src-ggl cells strongly inhibited metastasis in lymph nodes and lungs and increased sensitivity to apoptosis in hypoxia. DNA microarrays revealed that netrin and DCC had common and divergent impacts on gene expression linked to cell cycle, survival, surface signaling and adhesion. Our findings underscore that netrin is a potent invasion and tumor growth-promoting agent and that DCC is a metastasis suppressor gene targeting both proinvasive and survival pathways in a cumulative manner.

Standard name | DACOSTA_UV_RESPONSE_VIA_ERCC3_XPCS_UP
Systematic name | M18122
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes exclusively up-regulated in fibroblasts expressing the XP/CS mutant form of ERCC3 [GeneID=2071] after high dose UVC irradiation.
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | DACOSTA_UV_RESPONSE_VIA_ERCC3_XPCS_DN
Systematic name | M10575
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes exclusively down-regulated in fibroblasts expressing the XP/CS mutant form of ERCC3 [GeneID=2071] after high dose UVC irradiation.
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | DACOSTA_UV_RESPONSE_VIA_ERCC3_TTD_UP
Systematic name | M15844
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes exclusively up-regulated in fibroblasts expressing the TTD mutant form of ERCC3 [GeneID=2071], after UVC irradiation.
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | DACOSTA_UV_RESPONSE_VIA_ERCC3_TTD_DN
Systematic name | M13008
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes exclusively down-regulated in fibroblasts expressing the TTD mutant form of ERCC3 [GeneID=2071], after UVC irradiation.
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | TURJANSKI_MAPK1_AND_MAPK2_TARGETS
Systematic name | M15804
Organism | Homo sapiens
PMID | 17496919
Authors | Turjanski AG,Vaqué JP,Gutkind JS
Category | C2
Sub-category | CGP
Brief description | Examples of transcription factors whose activities are regulated by MAPK1 and MAPK3 [GeneID=5594;5595] phosphorylation.
Full description | The mitogen-activated protein kinases (MAPKs) are a family of serine/threonine kinases that play an essential role in signal transduction by modulating gene transcription in the nucleus in response to changes in the cellular environment. They include the extracellular signal-regulated protein kinases (ERK1 and ERK2); c-Jun N-terminal kinases (JNK1, JNK2, JNK3); p38s (p38alpha, p38beta, p38gamma, p38delta) and ERK5. The molecular events in which MAPKs function can be separated in discrete and yet interrelated steps: activation of the MAPK by their upstream kinases, changes in the subcellular localization of MAPKs, and recognition, binding and phosphorylation of MAPK downstream targets. The resulting pattern of gene expression will ultimately depend on the integration of the combinatorial signals provided by the temporal activation of each group of MAPKs. This review will focus on how the specificity of signal transmission by MAPKs is achieved by scaffolding molecules and by the presence of structural motifs in MAPKs that are dynamically regulated by phosphorylation and protein-protein interactions. We discuss also how MAPKs recognize and phosphorylate their target nuclear proteins, including transcription factors, co-activators and repressors and chromatin-remodeling molecules, thereby affecting an intricate balance of nuclear regulatory molecules that ultimately control gene expression in response to environmental cues.

Standard name | TURJANSKI_MAPK8_AND_MAPK9_TARGETS
Systematic name | M9841
Organism | Homo sapiens
PMID | 17496919
Authors | Turjanski AG,Vaqué JP,Gutkind JS
Category | C2
Sub-category | CGP
Brief description | Examples of transcription factors whose activities are regulated by MAPK8 and MAPK9 [GeneID=5599;5601].
Full description | The mitogen-activated protein kinases (MAPKs) are a family of serine/threonine kinases that play an essential role in signal transduction by modulating gene transcription in the nucleus in response to changes in the cellular environment. They include the extracellular signal-regulated protein kinases (ERK1 and ERK2); c-Jun N-terminal kinases (JNK1, JNK2, JNK3); p38s (p38alpha, p38beta, p38gamma, p38delta) and ERK5. The molecular events in which MAPKs function can be separated in discrete and yet interrelated steps: activation of the MAPK by their upstream kinases, changes in the subcellular localization of MAPKs, and recognition, binding and phosphorylation of MAPK downstream targets. The resulting pattern of gene expression will ultimately depend on the integration of the combinatorial signals provided by the temporal activation of each group of MAPKs. This review will focus on how the specificity of signal transmission by MAPKs is achieved by scaffolding molecules and by the presence of structural motifs in MAPKs that are dynamically regulated by phosphorylation and protein-protein interactions. We discuss also how MAPKs recognize and phosphorylate their target nuclear proteins, including transcription factors, co-activators and repressors and chromatin-remodeling molecules, thereby affecting an intricate balance of nuclear regulatory molecules that ultimately control gene expression in response to environmental cues.

Standard name | TURJANSKI_MAPK7_TARGETS
Systematic name | M11218
Organism | Homo sapiens
PMID | 17496919
Authors | Turjanski AG,Vaqué JP,Gutkind JS
Category | C2
Sub-category | CGP
Brief description | Examples of transcription factors whose activities are regulated by MAPK7 [GeneID=5598] phosphorylation.
Full description | The mitogen-activated protein kinases (MAPKs) are a family of serine/threonine kinases that play an essential role in signal transduction by modulating gene transcription in the nucleus in response to changes in the cellular environment. They include the extracellular signal-regulated protein kinases (ERK1 and ERK2); c-Jun N-terminal kinases (JNK1, JNK2, JNK3); p38s (p38alpha, p38beta, p38gamma, p38delta) and ERK5. The molecular events in which MAPKs function can be separated in discrete and yet interrelated steps: activation of the MAPK by their upstream kinases, changes in the subcellular localization of MAPKs, and recognition, binding and phosphorylation of MAPK downstream targets. The resulting pattern of gene expression will ultimately depend on the integration of the combinatorial signals provided by the temporal activation of each group of MAPKs. This review will focus on how the specificity of signal transmission by MAPKs is achieved by scaffolding molecules and by the presence of structural motifs in MAPKs that are dynamically regulated by phosphorylation and protein-protein interactions. We discuss also how MAPKs recognize and phosphorylate their target nuclear proteins, including transcription factors, co-activators and repressors and chromatin-remodeling molecules, thereby affecting an intricate balance of nuclear regulatory molecules that ultimately control gene expression in response to environmental cues.

Standard name | TURJANSKI_MAPK11_TARGETS
Systematic name | M2492
Organism | Homo sapiens
PMID | 17496919
Authors | Turjanski AG,Vaqué JP,Gutkind JS
Category | C2
Sub-category | CGP
Brief description | Examples of transcription factors whose activities are regulated by MAPK11 [GeneID=5600] phosphorylation.
Full description | The mitogen-activated protein kinases (MAPKs) are a family of serine/threonine kinases that play an essential role in signal transduction by modulating gene transcription in the nucleus in response to changes in the cellular environment. They include the extracellular signal-regulated protein kinases (ERK1 and ERK2); c-Jun N-terminal kinases (JNK1, JNK2, JNK3); p38s (p38alpha, p38beta, p38gamma, p38delta) and ERK5. The molecular events in which MAPKs function can be separated in discrete and yet interrelated steps: activation of the MAPK by their upstream kinases, changes in the subcellular localization of MAPKs, and recognition, binding and phosphorylation of MAPK downstream targets. The resulting pattern of gene expression will ultimately depend on the integration of the combinatorial signals provided by the temporal activation of each group of MAPKs. This review will focus on how the specificity of signal transmission by MAPKs is achieved by scaffolding molecules and by the presence of structural motifs in MAPKs that are dynamically regulated by phosphorylation and protein-protein interactions. We discuss also how MAPKs recognize and phosphorylate their target nuclear proteins, including transcription factors, co-activators and repressors and chromatin-remodeling molecules, thereby affecting an intricate balance of nuclear regulatory molecules that ultimately control gene expression in response to environmental cues.

Standard name | TURJANSKI_MAPK14_TARGETS
Systematic name | M14718
Organism | Homo sapiens
PMID | 17496919
Authors | Turjanski AG,Vaqué JP,Gutkind JS
Category | C2
Sub-category | CGP
Brief description | Examples of transcription factors whose activities are regulated by MAPK14 [GeneID=1432] phosphorylation.
Full description | The mitogen-activated protein kinases (MAPKs) are a family of serine/threonine kinases that play an essential role in signal transduction by modulating gene transcription in the nucleus in response to changes in the cellular environment. They include the extracellular signal-regulated protein kinases (ERK1 and ERK2); c-Jun N-terminal kinases (JNK1, JNK2, JNK3); p38s (p38alpha, p38beta, p38gamma, p38delta) and ERK5. The molecular events in which MAPKs function can be separated in discrete and yet interrelated steps: activation of the MAPK by their upstream kinases, changes in the subcellular localization of MAPKs, and recognition, binding and phosphorylation of MAPK downstream targets. The resulting pattern of gene expression will ultimately depend on the integration of the combinatorial signals provided by the temporal activation of each group of MAPKs. This review will focus on how the specificity of signal transmission by MAPKs is achieved by scaffolding molecules and by the presence of structural motifs in MAPKs that are dynamically regulated by phosphorylation and protein-protein interactions. We discuss also how MAPKs recognize and phosphorylate their target nuclear proteins, including transcription factors, co-activators and repressors and chromatin-remodeling molecules, thereby affecting an intricate balance of nuclear regulatory molecules that ultimately control gene expression in response to environmental cues.

Standard name | MAHADEVAN_GIST_MORPHOLOGICAL_SWITCH
Systematic name | M6900
Organism | Homo sapiens
PMID | 17325667
Authors | Mahadevan D,Cooke L,Riley C,Swart R,Simons B,Della Croce K,Wisner L,Iorio M,Shakalya K,Garewal H,Nagle R,Bearss D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the GIST (gastrointestinal stromal tumor) cell line resistant to imatinib [PubChem=5291] that may correlate with the morphological switch in these cells.
Full description | KIT or alpha-platelet-derived growth factor receptor (alpha-PDGFR) activating mutations are the pathogenic mechanisms that characterize gastrointestinal stromal tumors (GIST). Despite excellent responses to imatinib mesylate (IM), patients are relapsing. We developed an IM-resistant GIST cell line (GIST-R) from the IM-sensitive GIST882 cell line (GIST-S) by growing these cells in IM. Gene expression profiling (GEP) of GIST-S, GIST-R cells and two IM resistant GIST patients demonstrated that KIT is downregulated implying a major role in IM resistance. Instead, GIST-R cells have acquired IM resistance by overexpressing the oncogenic receptor tyrosine kinase - AXL - in a 'kinase switch'. Further, the two IM resistant GIST patients express AXL and not c-Kit, seen by immunohistochemistry (IHC). Real time reverse transcriptase-polymerase chain reaction and Western blotting of the GIST-S and GIST-R cells confirmed the switch from Kit to AXL. In GIST-R, AXL is tyrosine phosphorylated and its ligand growth-arrest-specific gene 6 is overexpressed implying autocrine activation. The kinase switch is associated with a morphological change from spindle to epithelioid. Molecular modeling of the kinase domain of mutant c-Kit (V654A) and AXL showed no binding to IM but efficient binding to MP470, a novel c-Kit/AXL kinase inhibitor. MP470 synergizes with docetaxel (taxotere) and is cytotoxic to GIST cells.

Standard name | APPIERTO_RESPONSE_TO_FENRETINIDE_UP
Systematic name | M1546
Organism | Homo sapiens
PMID | 17213814
Authors | Appierto V,Villani MG,Cavadini E,Gariboldi M,De Cecco L,Pierotti MA,Lambert JR,Reid J,Tiberio P,Colombo N,Formelli F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A2780 cells (ovarian carcinoma) exposed to fenretinide [PubChem=1744].
Full description | Fenretinide (4-HPR) is a synthetic retinoid with antitumor activity, which induces apoptosis in cancer cell lines of different histotypes. To identify genes contributing to its apoptotic activity in ovarian cancer cells, we monitored, by cDNA arrays, gene expression changes after 4-HPR exposure in A2780, a human ovarian carcinoma cell line sensitive to the retinoid. Among the differentially expressed transcripts, PLAcental Bone morphogenetic protein (PLAB), a proapoptotic gene, was the most highly induced. In a panel of ovarian carcinoma cell lines with different 4-HPR sensitivities, PLAB upregulation was associated with cellular response to 4-HPR, its overexpression increased basal apoptosis and its silencing by small interfering RNA decreased the ability of 4-HPR to induce apoptosis. PLAB induction by 4-HPR was p53- and EGR-1 independent and was regulated, at least in part, by increased stability of PLAB mRNA. PLAB up-modulation by 4-HPR also occurred in vivo: in ascitic cells collected from patients with ovarian cancer before and after 4-HPR treatment, PLAB was upmodulated in 2/4 patients. Our results in certain ovarian cancer cell lines indicate a role for PLAB as a mediator of 4-HPR-induced apoptosis. The correlation of increased PLAB in vivo with antitumor activity remains to be established.

Standard name | APPIERTO_RESPONSE_TO_FENRETINIDE_DN
Systematic name | M14265
Organism | Homo sapiens
PMID | 17213814
Authors | Appierto V,Villani MG,Cavadini E,Gariboldi M,De Cecco L,Pierotti MA,Lambert JR,Reid J,Tiberio P,Colombo N,Formelli F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A2780 cells (ovarian carcinoma) exposed to fenretinide [PubChem=1744].
Full description | Fenretinide (4-HPR) is a synthetic retinoid with antitumor activity, which induces apoptosis in cancer cell lines of different histotypes. To identify genes contributing to its apoptotic activity in ovarian cancer cells, we monitored, by cDNA arrays, gene expression changes after 4-HPR exposure in A2780, a human ovarian carcinoma cell line sensitive to the retinoid. Among the differentially expressed transcripts, PLAcental Bone morphogenetic protein (PLAB), a proapoptotic gene, was the most highly induced. In a panel of ovarian carcinoma cell lines with different 4-HPR sensitivities, PLAB upregulation was associated with cellular response to 4-HPR, its overexpression increased basal apoptosis and its silencing by small interfering RNA decreased the ability of 4-HPR to induce apoptosis. PLAB induction by 4-HPR was p53- and EGR-1 independent and was regulated, at least in part, by increased stability of PLAB mRNA. PLAB up-modulation by 4-HPR also occurred in vivo: in ascitic cells collected from patients with ovarian cancer before and after 4-HPR treatment, PLAB was upmodulated in 2/4 patients. Our results in certain ovarian cancer cell lines indicate a role for PLAB as a mediator of 4-HPR-induced apoptosis. The correlation of increased PLAB in vivo with antitumor activity remains to be established.

Standard name | NAGY_TFTC_COMPONENTS_HUMAN
Systematic name | M2974
Organism | Homo sapiens
PMID | 17694077
Authors | Nagy Z,Tora L
Category | C2
Sub-category | CGP
Brief description | Composition of the 2 MDa human TFTC complex containing KAT2A [GeneID=2648].
Full description | Transcription in eukaryotes is a tightly regulated, multistep process. Gene-specific transcriptional activators, several different co-activators and general transcription factors are necessary to access specific loci to allow precise initiation of RNA polymerase II transcription. As the dense chromatin folding of the genome does not allow the access of these sites by the huge multiprotein transcription machinery, remodelling is required to loosen up the chromatin structure for successful transcription initiation. In the present review, we summarize the recent evolution of our understanding of the function of two histone acetyl transferases (ATs) from metazoan organisms: GCN5 and PCAF. Their overall structure and the multiprotein complexes in which they are carrying out their activities are discussed. Metazoan GCN5 and PCAF are subunits of at least two types of multiprotein complexes, one having a molecular weight of 2 MDa (SPT3-TAF9-GCN5 acetyl transferase/TATA binding protein (TBP)-free-TAF complex/PCAF complexes) and a second type with about a size of 700 kDa (ATAC complex). These complexes possess global histone acetylation activity and locus-specific co-activator functions together with AT activity on non-histone substrates. Thus, their biological functions cover a wide range of tasks and render them indispensable for the normal function of cells. That deregulation of the global and/or specific AT activities of these complexes leads to the cancerous transformation of the cells highlights their importance in cellular processes. The possible effects of GCN5 and PCAF in tumorigenesis are also discussed.

Standard name | NAGY_STAGA_COMPONENTS_HUMAN
Systematic name | M10514
Organism | Homo sapiens
PMID | 17694077
Authors | Nagy Z,Tora L
Category | C2
Sub-category | CGP
Brief description | Composition of the 2 MDa human STAGA complex containing KAT2A [GeneID=2648].
Full description | Transcription in eukaryotes is a tightly regulated, multistep process. Gene-specific transcriptional activators, several different co-activators and general transcription factors are necessary to access specific loci to allow precise initiation of RNA polymerase II transcription. As the dense chromatin folding of the genome does not allow the access of these sites by the huge multiprotein transcription machinery, remodelling is required to loosen up the chromatin structure for successful transcription initiation. In the present review, we summarize the recent evolution of our understanding of the function of two histone acetyl transferases (ATs) from metazoan organisms: GCN5 and PCAF. Their overall structure and the multiprotein complexes in which they are carrying out their activities are discussed. Metazoan GCN5 and PCAF are subunits of at least two types of multiprotein complexes, one having a molecular weight of 2 MDa (SPT3-TAF9-GCN5 acetyl transferase/TATA binding protein (TBP)-free-TAF complex/PCAF complexes) and a second type with about a size of 700 kDa (ATAC complex). These complexes possess global histone acetylation activity and locus-specific co-activator functions together with AT activity on non-histone substrates. Thus, their biological functions cover a wide range of tasks and render them indispensable for the normal function of cells. That deregulation of the global and/or specific AT activities of these complexes leads to the cancerous transformation of the cells highlights their importance in cellular processes. The possible effects of GCN5 and PCAF in tumorigenesis are also discussed.

Standard name | NAGY_PCAF_COMPONENTS_HUMAN
Systematic name | M5039
Organism | Homo sapiens
PMID | 17694077
Authors | Nagy Z,Tora L
Category | C2
Sub-category | CGP
Brief description | Composition of the 2 MDa human PCAF complex.
Full description | Transcription in eukaryotes is a tightly regulated, multistep process. Gene-specific transcriptional activators, several different co-activators and general transcription factors are necessary to access specific loci to allow precise initiation of RNA polymerase II transcription. As the dense chromatin folding of the genome does not allow the access of these sites by the huge multiprotein transcription machinery, remodelling is required to loosen up the chromatin structure for successful transcription initiation. In the present review, we summarize the recent evolution of our understanding of the function of two histone acetyl transferases (ATs) from metazoan organisms: GCN5 and PCAF. Their overall structure and the multiprotein complexes in which they are carrying out their activities are discussed. Metazoan GCN5 and PCAF are subunits of at least two types of multiprotein complexes, one having a molecular weight of 2 MDa (SPT3-TAF9-GCN5 acetyl transferase/TATA binding protein (TBP)-free-TAF complex/PCAF complexes) and a second type with about a size of 700 kDa (ATAC complex). These complexes possess global histone acetylation activity and locus-specific co-activator functions together with AT activity on non-histone substrates. Thus, their biological functions cover a wide range of tasks and render them indispensable for the normal function of cells. That deregulation of the global and/or specific AT activities of these complexes leads to the cancerous transformation of the cells highlights their importance in cellular processes. The possible effects of GCN5 and PCAF in tumorigenesis are also discussed.

Standard name | BAKER_HEMATOPOESIS_STAT1_TARGETS
Systematic name | M1162
Organism | Mus musculus
PMID | 17934481
Authors | Baker SJ,Rane SG,Reddy EP
Category | C2
Sub-category | CGP
Brief description | STAT1 [GeneID=6772] targets in hematopoetic signaling.
Full description | Hematopoiesis is the cumulative result of intricately regulated signaling pathways that are mediated by cytokines and their receptors. Proper culmination of these diverse pathways forms the basis for an orderly generation of different cell types. Recent studies conducted over the past 10-15 years have revealed that hematopoietic cytokine receptor signaling is largely mediated by a family of tyrosine kinases termed Janus kinases (JAKs) and their downstream transcription factors termed STATs (signal transducers and activators of transcription). Aberration in these pathways, such as that caused by the recently identified JAK2V617F mutation, is an underlying cause for diseases such as leukemias and other myeloproliferative disorders. This recent discovery, when coupled with the fact that STATs are activated by oncoproteins such as BCR-ABL, underscores the importance of the JAK-STAT pathway in both normal cellular development and disease states.

Standard name | BAKER_HEMATOPOIESIS_STAT3_TARGETS
Systematic name | M1163
Organism | Mus musculus
PMID | 17934481
Authors | Baker SJ,Rane SG,Reddy EP
Category | C2
Sub-category | CGP
Brief description | STAT3 [GeneID=6774] targets in hematopoietic signaling.
Full description | Hematopoiesis is the cumulative result of intricately regulated signaling pathways that are mediated by cytokines and their receptors. Proper culmination of these diverse pathways forms the basis for an orderly generation of different cell types. Recent studies conducted over the past 10-15 years have revealed that hematopoietic cytokine receptor signaling is largely mediated by a family of tyrosine kinases termed Janus kinases (JAKs) and their downstream transcription factors termed STATs (signal transducers and activators of transcription). Aberration in these pathways, such as that caused by the recently identified JAK2V617F mutation, is an underlying cause for diseases such as leukemias and other myeloproliferative disorders. This recent discovery, when coupled with the fact that STATs are activated by oncoproteins such as BCR-ABL, underscores the importance of the JAK-STAT pathway in both normal cellular development and disease states.

Standard name | BAKER_HEMATOPOESIS_STAT5_TARGETS
Systematic name | M1165
Organism | Mus musculus
PMID | 17934481
Authors | Baker SJ,Rane SG,Reddy EP
Category | C2
Sub-category | CGP
Brief description | STAT5 [GeneID=6777] targets in hematopoietic signaling.
Full description | Hematopoiesis is the cumulative result of intricately regulated signaling pathways that are mediated by cytokines and their receptors. Proper culmination of these diverse pathways forms the basis for an orderly generation of different cell types. Recent studies conducted over the past 10-15 years have revealed that hematopoietic cytokine receptor signaling is largely mediated by a family of tyrosine kinases termed Janus kinases (JAKs) and their downstream transcription factors termed STATs (signal transducers and activators of transcription). Aberration in these pathways, such as that caused by the recently identified JAK2V617F mutation, is an underlying cause for diseases such as leukemias and other myeloproliferative disorders. This recent discovery, when coupled with the fact that STATs are activated by oncoproteins such as BCR-ABL, underscores the importance of the JAK-STAT pathway in both normal cellular development and disease states.

Standard name | SEIDEN_MET_SIGNALING
Systematic name | M16468
Organism | Homo sapiens
PMID | 16158056
Authors | Seiden-Long IM,Brown KR,Shih W,Wigle DA,Radulovich N,Jurisica I,Tsao MS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated both in vivo and in vitro upon activation of MET [GeneID=4233] signaling.
Full description | Both Ki-ras mutation and hepatocyte growth factor (HGF) receptor Met overexpression occur at high frequency in colon cancer. This study investigates the transcriptional changes induced by Ki-ras oncogene and HGF/Met signaling activation in colon cancer cell lines in vitro and in vivo. The model system used in these studies included the DLD-1 colon cancer cell line with a mutated Ki-ras allele, and the DKO-4 cell line generated from DLD-1, with its mutant Ki-ras allele inactivated by targeted disruption. These cell lines were transduced with cDNAs of full-length Met receptor. Microarray transcriptional profiling was conducted on cell lines stimulated with HGF, as well as on tumor xenograft tissues. Overlapping genes between in vitro and in vivo microarray data sets were selected as a subset of HGF/Met and Ki-ras oncogene-regulated targets. Using the Online Predicted Human Interaction Database, novel HGF/Met and Ki-ras regulated proteins with putative functional linkage were identified. Novel proteins identified included histone acetyltransferase 1, phosphoribosyl pyrophosphate synthetase 2, chaperonin containing TCP1, subunit 8, CSE1 chromosome segregation 1-like (yeast)/cellular apoptosis susceptibility (mammals), CCR4-NOT transcription complex, subunit 8, and cyclin H. Transcript levels for these Met-signaling targets were correlated with Met expression levels, and were significantly elevated in both primary and metastatic human colorectal cancer samples compared to normal colorectal mucosa. These genes represent novel Met and/or Ki-ras transcriptionally coregulated genes with a high degree of validation in human colorectal cancers.

Standard name | AUNG_GASTRIC_CANCER
Systematic name | M4322
Organism | Homo sapiens
PMID | 16331256
Authors | Aung PP,Oue N,Mitani Y,Nakayama H,Yoshida K,Noguchi T,Bosserhoff AK,Yasui W
Category | C2
Sub-category | CGP
Brief description | Selected genes specifically expressed in gastric cancer.
Full description | Gastric cancer (GC) is one of the most common malignancies worldwide. Genes expressed only in cancer tissue will be useful molecular markers for diagnosis and may also be good therapeutic targets. However, little is known about cancer-specific genes, at least in GC. In this study, we searched for GC-specific genes by serial analysis of gene expression (SAGE) data analysis and quantitative reverse transcription (RT)-PCR. Comparing GC SAGE libraries with those of various normal tissues in the SAGEmap database, we identified 54 candidate GC-specific genes. Quantitative RT-PCR analysis of these candidates revealed that APin protein (APIN), taxol resistance-associated gene 3 (TRAG3), cytochrome P450, family 2, subfamily W, polypeptide 1 (CYP2W1), melanoma inhibitory activity (MIA), matrix metalloproteinase-10 (MMP-10), dickkopf homolog 4 (DKK4), GW112, regenerating islet-derived family, member 4 (REGIV), and HORMA domain-containing 1 (HORMAD1) were expressed much more highly in GC than in 14 kinds of normal tissues. Immunohistochemical staining for MIA, MMP-10, and DKK4 was found in 47 (31.1%), 68 (45.0%), and two (1.3%) of 151 GCs, respectively, and staining for both MIA and MMP-10 was correlated with poor prognosis in advanced GC (P=0.0001 and 0.0141, respectively). Moreover, enzyme-linked immunosorbent assay showed high levels of MMP-10 (65/69, 94.2%) in serum samples from patients with GC. Levels of MIA were raised in a small proportion of serum samples from patients with GC (4/69, 5.8%). In Boyden chamber invasion assays, MIA-transfected GC cells were up to three times more invasive than cells transfected with empty vector. Taken together, these results suggest that MMP-10 is a good marker for the detection of GC and that MIA and MMP-10 are prognostic factors for GC. As expression of MIA and MMP-10 is narrowly restricted in cancer, these two molecules may be good therapeutic targets for GC.

Standard name | SANCHEZ_MDM2_TARGETS
Systematic name | M3206
Organism | Homo sapiens
PMID | 16331255
Authors | Sánchez-Aguilera A,García JF,Sánchez-Beato M,Piris MA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in BJ cells (forskin fibroblasts) upon overexpression of the most abundant alternative splicing forms of MDM2 [GeneID=4193], HDM2-A and HDM2-B, off a retroviral vector.
Full description | The HDM2 oncoprotein is a cellular inhibitor of p53 and is frequently deregulated in human cancer. However, the HDM2 gene encodes alternatively spliced variants whose functional significance is poorly understood. We had previously reported the detection of alternative HDM2 forms in Hodgkin's lymphoma (HL)-derived cell lines. Here, we have cloned several of these transcripts, including the previously described HDM2-A, -B and -C (which encode the COOH terminus of HDM2), and two novel variants (HDM2-HL1 and -HL2) containing a complete p53 interaction domain. Real-time PCR assays demonstrated that HDM2-A and -B were selectively expressed by HL cell lines and primary tumors, compared with their non-neoplastic counterparts. In transient transfection experiments, alternatively spliced HDM2 isoforms were partially or totally localized within the cytoplasm. HDM2-HL2 was able to inhibit transactivation of a p53-inducible reporter construct and induced a partial relocalization of p53 to the cytoplasm. Expression of HDM2-A and -B caused the activation of p53/p21 and induced growth arrest in primary cells, but also increased the expression levels of cyclins D1 and E. Other possible genes regulated by HDM2-A and -B were identified using cDNA microarray technology. These results imply that HDM2 isoforms may have multiple effects on cell cycle control, and provide insight into the mechanisms through which these molecules contribute to tumorigenesis.

Standard name | BREUHAHN_GROWTH_FACTOR_SIGNALING_IN_LIVER_CANCER
Systematic name | M18219
Organism | Homo sapiens
PMID | 16799620
Authors | Breuhahn K,Longerich T,Schirmacher P
Category | C2
Sub-category | CGP
Brief description | Growth factor signaling components up-regulated in hepatocellular carcinoma (HCC).
Full description | Dysregulation of pleiotropic growth factors, receptors and their downstream signaling pathway components represent a central protumorigenic principle in human hepatocarcinogenesis. Especially the Insulin-like Growth Factor/IGF-1 receptor (IGF/IGF-1R), Hepatocyte Growth Factor (HGF/MET), Wingless (Wnt/beta-catenin/FZD), Transforming Growth Factor alpha/Epidermal Growth Factor receptor (TGFalpha/EGFR) and Transforming Growth Factor beta (TGFbeta/TbetaR) pathways contribute to proliferation, antiapoptosis and invasive behavior of tumor cells. This review focuses on the relevant alterations in these pathways identified in human human hepatocellular carcinomas (HCCs). Resultant functional effects are modulated by multiple cross-talks between the different signaling pathways and additional tumor-relevant factors, such as cyclooxygenase-2 and p53. Several specific strategies are currently under development such as receptor kinase inhibitors, neutralizing antibodies and antagonistic proteins, which may improve the systemic treatment of human HCCs.

Standard name | NAKAMURA_LUNG_CANCER
Systematic name | M6362
Organism | Homo sapiens
PMID | 16491115
Authors | Nakamura N,Kobayashi K,Nakamoto M,Kohno T,Sasaki H,Matsuno Y,Yokota J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in lung adenocarcinoma cell lines and not expressed in non-cancerous lung epithelial cells.
Full description | To identify tumor markers and differentiation markers for lung adenocarcinoma (AdC), we analysed expression profiles of 14,500 genes against three cases of type II alveolar epithelial cells, bronchiolar epithelial cells, and bronchial epithelial cells, respectively, and 10 cases of AdC cells isolated by laser capture microdissection. Hierarchical clustering analysis indicated that AdC cells and noncancerous lung epithelial cells are significantly different in their expression profiles, and that different sets of differentiation markers are expressed among alveolar, bronchiolar and bronchial epithelial cells. Nine genes were identified as being highly expressed in AdC cells, but not expressed in noncancerous lung epithelial cells. Sixteen genes were identified as differentiation markers for lung epithelial cells. Real-time RT-PCR analysis of 45 lung AdC cases further revealed that expression of four tumor markers in AdC cells was significantly higher than that in noncancerous lung cells and that expression of ten differentiation markers was retained in a considerable fraction of lung AdC cases. Five tumor markers and seven differentiation markers were not expressed in peripheral blood cells. Similarities and differences in expression profiles between normal epithelial cells from different lung respiratory compartments and AdC cells demonstrated in this study will be informative for the molecular diagnosis of lung AdC.

Standard name | GALLUZZI_PERMEABILIZE_MITOCHONDRIA
Systematic name | M9642
Organism | Homo sapiens
PMID | 16892093
Authors | Galluzzi L,Larochette N,Zamzami N,Kroemer G
Category | C2
Sub-category | CGP
Brief description | Proteins that permeabilize mitochondria.
Full description | Mitochondria are vital for cellular bioenergetics and play a central role in determining the point-of-no-return of the apoptotic process. As a consequence, mitochondria exert a dual function in carcinogenesis. Cancer-associated changes in cellular metabolism (the Warburg effect) influence mitochondrial function, and the invalidation of apoptosis is linked to an inhibition of mitochondrial outer membrane permeabilization (MOMP). On theoretical grounds, it is tempting to develop specific therapeutic interventions that target the mitochondrial Achilles' heel, rendering cancer cells metabolically unviable or subverting endogenous MOMP inhibitors. A variety of experimental therapeutic agents can directly target mitochondria, causing apoptosis induction. This applies to a heterogeneous collection of chemically unrelated compounds including positively charged alpha-helical peptides, agents designed to mimic the Bcl-2 homology domain 3 of Bcl-2-like proteins, ampholytic cations, metals and steroid-like compounds. Such MOMP inducers or facilitators can induce apoptosis by themselves (monotherapy) or facilitate apoptosis induction in combination therapies, bypassing chemoresistance against DNA-damaging agents. In addition, it is possible to design molecules that neutralize inhibitor of apoptosis proteins (IAPs) or heat shock protein 70 (HSP70). Such IAP or HSP70 inhibitors can mimic the action of mitochondrion-derived mediators (Smac/DIABLO, that is, second mitochondria-derived activator of caspases/direct inhibitor of apoptosis-binding protein with a low isoelectric point, in the case of IAPs; AIF, that is apoptosis-inducing factor, in the case of HSP70) and exert potent chemosensitizing effects.

Standard name | HAEGERSTRAND_RESPONSE_TO_IMATINIB
Systematic name | M16300
Organism | Homo sapiens
PMID | 16547494
Authors | Hägerstrand D,Hesselager G,Achterberg S,Bolin Wickenberg U,Kowanetz M,Kastemar M,Heldin CH,Isaksson A,Nistér M,Ostman A
Category | C2
Sub-category | CGP
Brief description | Genes with the highest differential expression in primary tissue cultures of high grade glioma: responders vs non-responders to imatinib [PubChem=5291] treatment.
Full description | High-grade gliomas, including glioblastomas, are malignant brain tumors for which improved treatment is urgently needed. Genetic studies have demonstrated the existence of biologically distinct subsets. Preliminary studies have indicated that platelet-derived growth factor (PDGF) receptor signaling contributes to the growth of some of these tumors. In this study, human high-grade glioma primary cultures were analysed for sensitivity to treatment with the PDGF receptor inhibitor imatinib/Glivec/Gleevec/STI571. Six out of 15 cultures displayed more than 40% growth inhibition after imatinib treatment, whereas seven cultures showed less than 20% growth inhibition. In the sensitive cultures, apoptosis contributed to growth inhibition. Platelet-derived growth factor receptor status correlated with imatinib sensitivity. Supervised analyses of gene expression profiles and real-time PCR analyses identified expression of the chemokine CXCL12/SDF-1 (stromal cell-derived factor 1) as a predictor of imatinib sensitivity. Exogenous addition of CXCL12 to imatinib-insensitive cultures conferred some imatinib sensitivity. Finally, coregulation of CXCL12 and PDGF alpha-receptor was observed in glioblastoma biopsies. We have thus defined the characteristics of a novel imatinib-sensitive subset of glioma cultures, and provided evidence for a functional relationship between imatinib sensitivity and chemokine signaling. These findings will assist in the design and evaluation of clinical trials exploring therapeutic effects of imatinib on malignant brain tumors.

Standard name | MATHEW_FANCONI_ANEMIA_GENES
Systematic name | M12972
Organism | Homo sapiens
PMID | 16998502
Authors | Mathew CG
Category | C2
Sub-category | CGP
Brief description | Genes identified with the Fanconi anemia (FA) and the FA pathway.
Full description | Fanconi anaemia (FA) is a rare recessive disorder associated with chromosomal fragility, aplastic anaemia, congenital abnormalities and a high risk of cancer, including acute myeloid leukaemia and squamous cell carcinomas. The identification of 11 different FA genes has revealed a complex web of interacting proteins that are involved in the recognition or repair of DNA interstrand crosslinks and perhaps other forms of DNA damage. Bi-allelic mutations in BRCA2 are associated with a rare and highly cancer-prone form of FA, and the DNA helicase BRIP1 (formerly BACH1) is mutated in FA group J. There is little convincing evidence that FA heterozygotes are at increased risk of cancer, but larger studies are needed to address the possibility of modest risk effects. Somatic inactivation of the FA pathway by mutation or epigenetic silencing has been observed in several different types of sporadic cancer, and this may have important implications for targeted chemotherapy. Inhibition of this pathway represents a possible route to sensitization of tumours to DNA crosslinking drugs such as cisplatin.

Standard name | MIDORIKAWA_AMPLIFIED_IN_LIVER_CANCER
Systematic name | M1065
Organism | Homo sapiens
PMID | 16785998
Authors | Midorikawa Y,Yamamoto S,Ishikawa S,Kamimura N,Igarashi H,Sugimura H,Makuuchi M,Aburatani H
Category | C2
Sub-category | CGP
Brief description | Candidate genes in genomic amplification regions in hepatocellular carcinoma (HCC) samples.
Full description | Genomic amplification of oncogenes and inactivation of suppressor genes are critical in the pathogenesis of human cancer. To identify chromosomal alterations associated with hepatocarcinogenesis, we performed allelic gene dosage analysis on 36 hepatocellular carcinomas (HCCs). Data from high-density single-nucleotide polymorphism arrays were analysed using the Genome Imbalance Map (GIM) algorithm, which simultaneously detects DNA copy number alterations and loss of heterozygosity (LOH) events. Genome Imbalance Map analysis identified allelic imbalance regions, including uniparental disomy, and predicted the coexistence of a heterozygous population of cancer cells. We observed that gains of 1q, 5p, 5q, 6p, 7q, 8q, 17q and 20q, and LOH of 1p, 4q, 6q, 8p, 10q, 13q, 16p, 16q and 17p were significantly associated with HCC. On 6q24-25, which contains imprinting gene clusters, we observed reduced levels of PLAGL1 expression owing to loss of the unmethylated allele. Finally, we integrated the copy number data with gene expression intensity, and found that genome dosage is correlated with alteration in gene expression. These observations indicated that high-resolution GIM analysis can accurately determine the localizations of genomic regions with allelic imbalance, and when integrated with epigenetic information, a mechanistic basis for inactivation of a tumor suppressor gene in HCC was elucidated.

Standard name | GILMORE_CORE_NFKB_PATHWAY
Systematic name | M8804
Organism | Homo sapiens
PMID | 17072321
Authors | Gilmore TD
Category | C2
Sub-category | CGP
Brief description | Genes encoding the NF-kB core signaling proteins.
Full description | This article serves as an introduction to the collection of reviews on nuclear factor-kappaB (NF-kappaB). It provides an overview of the discovery and current status of NF-kappaB as a research topic. Described are the structures, activities and regulation of the proteins in the NF-kappaB family of transcription factors. NF-kappaB signaling is primarily regulated by inhibitor kappaB (IkappaB) proteins and the IkappaB kinase complex through two major pathways: the canonical and non-canonical NF-kappaB pathways. The organization and focus of articles included in the following reviews are described, as well as likely future areas of research interest on NF-kappaB.

Standard name | SCHEIDEREIT_IKK_TARGETS
Systematic name | M17115
Organism | Homo sapiens
PMID | 17072322
Authors | Scheidereit C
Category | C2
Sub-category | CGP
Brief description | Genes encoding substrates of IkappaB kinase (IKK) complex.
Full description | Transcription factors of the NF-kappaB family regulate hundreds of genes in the context of multiple important physiological and pathological processes. NF-kappaB activation depends on phosphorylation-induced proteolysis of inhibitory IkappaB molecules and NF-kappaB precursors by the ubiquitin-proteasome system. Most of the diverse signaling pathways that activate NF-kappaB converge on IkappaB kinases (IKK), which are essential for signal transmission. Many important details of the composition, regulation and biological function of IKK have been revealed in the last years. This review summarizes current aspects of structure and function of the regular stoichiometric components, the regulatory transient protein interactions of IKK and the mechanisms that contribute to its activation, deactivation and homeostasis. Both phosphorylation and ubiquitinatin (destructive as well as non-destructive) are crucial post-translational events in these processes. In addition to controlling induced IkappaB degradation in the cytoplasm and processing of the NF-kappaB precursor p100, nuclear IKK components have been found to act directly at the chromatin level of induced genes and to mediate responses to DNA damage. Finally, IKK is engaged in cross talk with other pathways and confers functions independently of NF-kappaB.

Standard name | DUTTA_APOPTOSIS_VIA_NFKB
Systematic name | M9440
Organism | Homo sapiens
PMID | 17072329
Authors | Dutta J,Fan Y,Gupta N,Fan G,Gélinas C
Category | C2
Sub-category | CGP
Brief description | NF-kB target genes involved in the regulation of programmed cell death.
Full description | The nuclear factor-kappaB (NF-kappaB) transcription factors have emerged as major regulators of programmed cell death (PCD) whether via apoptosis or necrosis. In this context, NF-kappaB's activity has important ramifications for normal tissue development, homoeostasis and the physiological functions of various cell systems including the immune, hepatic, epidermal and nervous systems. However, improper regulation of PCD by NF-kappaB can have severe pathologic consequences, ranging from neurodegeneration to cancer, where its activity often precludes effective therapy. Although NF-kappaB generally protects cells by inducing the expression genes encoding antiapoptotic and antioxidizing proteins, its role in apoptosis and necrosis can vary markedly in different cell contexts, and NF-kappaB can sensitize cells to death-inducing stimuli in some instances. This article describes our current knowledge of the role of NF-kappaB in apoptosis and necrosis, and focuses on the many advances since we last reviewed this rapidly evolving topic in Oncogene 3 years ago. There has been substantial progress in understanding NF-kappaB's mode of action in apoptosis and necrosis and the mechanisms that regulate its anti- vs proapoptotic activities. These recent developments shed new light on the role of NF-kappaB in many disease conditions including tumor development, tumor progression and anticancer treatment.

Standard name | DEBOSSCHER_NFKB_TARGETS_REPRESSED_BY_GLUCOCORTICOIDS
Systematic name | M17340
Organism | Homo sapiens
PMID | 17072333
Authors | De Bosscher K,Vanden Berghe W,Haegeman G
Category | C2
Sub-category | CGP
Brief description | NF-kB-driven pro-inflammatory genes that are negatively regulated by glucocorticoids.
Full description | A variety of studies have shown that some activated nuclear receptors (NRs), especially the glucorticoid receptor, the estrogen receptor and peroxisome proliferator-activated receptor, can inhibit the activity of the transcription factor nuclear factor kappaB (NF-kappaB), which plays a key role in the control of genes involved in inflammation, cell proliferation and apoptosis. This review describes the molecular mechanisms of cross-talk between NRs and NF-kappaB and the biological relevance of this cross-talk. The importance and mechanistic aspects of selective NR modulation are discussed. Also included are future research prospects, which will lead to a new era in the field of NR research with the aim of specifically inhibiting NF-kappaB-driven gene expression for anti-inflammatory, anti-tumor and immune-modulatory purposes.

Standard name | ROVERSI_GLIOMA_COPY_NUMBER_DN
Systematic name | M18630
Organism | Homo sapiens
PMID | 16247447
Authors | Roversi G,Pfundt R,Moroni RF,Magnani I,van Reijmersdal S,Pollo B,Straatman H,Larizza L,Schoenmakers EF
Category | C2
Sub-category | CGP
Brief description | Genes in the most frequently homozygous deleted loci in a panel of glioma cell lines.
Full description | Identification of genetic copy number changes in glial tumors is of importance in the context of improved/refined diagnostic, prognostic procedures and therapeutic decision-making. In order to detect recurrent genomic copy number changes that might play a role in glioma pathogenesis and/or progression, we characterized 25 primary glioma cell lines including 15 non glioblastoma (non GBM) (I-III WHO grade) and 10 GBM (IV WHO grade), by array comparative genomic hybridization, using a DNA microarray comprising approx. 3500 BACs covering the entire genome with a 1 Mb resolution and additional 800 BACs covering chromosome 19 at tiling path resolution. Combined evaluation by single clone and whole chromosome analysis plus 'moving average (MA) approach' enabled us to confirm most of the genetic abnormalities previously identified to be associated with glioma progression, including +1q32, +7, -10, -22q, PTEN and p16 loss, and to disclose new small genomic regions, some correlating with grade malignancy. Grade I-III gliomas exclusively showed losses at 3p26 (53%), 4q13-21 (33%) and 7p15-p21 (26%), whereas only GBMs exhibited 4p16.1 losses (40%). Other recurrent imbalances, such as losses at 4p15, 5q22-q23, 6p23-25, 12p13 and gains at 11p11-q13, were shared by different glioma grades. Three intervals with peak of loss could be further refined for chromosome 10 by our MA approach. Data analysis of full-coverage chromosome 19 highlighted two main regions of copy number gain, never described before in gliomas, at 19p13.11 and 19q13.13-13.2. The well-known 19q13.3 loss of heterozygosity area in gliomas was not frequently affected in our cell lines. Genomic hotspot detection facilitated the identification of small intervals resulting in positional candidate genes such as PRDM2 (1p36.21), LRP1B (2q22.3), ADARB2 (10p15.3), BCCIP (10q26.2) and ING1 (13q34) for losses and ECT2 (3q26.3), MDK, DDB2, IG20 (11p11.2) for gains. These data increase our current knowledge about cryptic genetic changes in gliomas and may facilitate the further identification of novel genetic elements, which may provide us with molecular tools for the improved diagnostics and therapeutic decision-making in these tumors.

Standard name | SEIDEN_ONCOGENESIS_BY_MET
Systematic name | M3231
Organism | Homo sapiens
PMID | 16158056
Authors | Seiden-Long IM,Brown KR,Shih W,Wigle DA,Radulovich N,Jurisica I,Tsao MS
Category | C2
Sub-category | CGP
Brief description | Genes changed in xenograft tumors formed by DLD-1 or DKO-4 cells (colon cancer) overexpressing MET [GeneID=4233].
Full description | Both Ki-ras mutation and hepatocyte growth factor (HGF) receptor Met overexpression occur at high frequency in colon cancer. This study investigates the transcriptional changes induced by Ki-ras oncogene and HGF/Met signaling activation in colon cancer cell lines in vitro and in vivo. The model system used in these studies included the DLD-1 colon cancer cell line with a mutated Ki-ras allele, and the DKO-4 cell line generated from DLD-1, with its mutant Ki-ras allele inactivated by targeted disruption. These cell lines were transduced with cDNAs of full-length Met receptor. Microarray transcriptional profiling was conducted on cell lines stimulated with HGF, as well as on tumor xenograft tissues. Overlapping genes between in vitro and in vivo microarray data sets were selected as a subset of HGF/Met and Ki-ras oncogene-regulated targets. Using the Online Predicted Human Interaction Database, novel HGF/Met and Ki-ras regulated proteins with putative functional linkage were identified. Novel proteins identified included histone acetyltransferase 1, phosphoribosyl pyrophosphate synthetase 2, chaperonin containing TCP1, subunit 8, CSE1 chromosome segregation 1-like (yeast)/cellular apoptosis susceptibility (mammals), CCR4-NOT transcription complex, subunit 8, and cyclin H. Transcript levels for these Met-signaling targets were correlated with Met expression levels, and were significantly elevated in both primary and metastatic human colorectal cancer samples compared to normal colorectal mucosa. These genes represent novel Met and/or Ki-ras transcriptionally coregulated genes with a high degree of validation in human colorectal cancers.

Standard name | HUMMERICH_SKIN_CANCER_PROGRESSION_UP
Systematic name | M1167
Organism | Mus musculus
PMID | 16247483
Authors | Hummerich L,Müller R,Hess J,Kokocinski F,Hahn M,Fürstenberger G,Mauch C,Lichter P,Angel P
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated during progression through benign to malignant skin tumors formed by treatment with DMBA and TPA [PubChem=6001;4792] chemicals in the two stage skin carcinogenesis model.
Full description | Chemically induced mouse skin carcinogenesis represents the most extensively utilized animal model to unravel the multistage nature of tumour development and to design novel therapeutic concepts of human epithelial neoplasia. We combined this tumour model with comprehensive gene expression analysis and could identify a large set of novel tumour-associated genes that have not been associated with epithelial skin cancer development yet. Expression data of selected genes were confirmed by semiquantitative and quantitative RT-PCR as well as in situ hybridization and immunofluorescence analysis on mouse tumour sections. Enhanced expression of genes identified in our screen was also demonstrated in mouse keratinocyte cell lines that form tumours in vivo. Self-organizing map clustering was performed to identify different kinetics of gene expression and coregulation during skin cancer progression. Detailed analysis of differential expressed genes according to their functional annotation confirmed the involvement of several biological processes, such as regulation of cell cycle, apoptosis, extracellular proteolysis and cell adhesion, during skin malignancy. Finally, we detected high transcript levels of ANXA1, LCN2 and S100A8 as well as reduced levels for NDR2 protein in human skin tumour specimens demonstrating that tumour-associated genes identified in the chemically induced tumour model might be of great relevance for the understanding of human epithelial malignancies as well.

Standard name | HUMMERICH_SKIN_CANCER_PROGRESSION_DN
Systematic name | M1170
Organism | Mus musculus
PMID | 16247483
Authors | Hummerich L,Müller R,Hess J,Kokocinski F,Hahn M,Fürstenberger G,Mauch C,Lichter P,Angel P
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated during progression through benign to malignant skin tumors formed by treatment with DMBA and TPA [PubChem=6001;4792] chemicals in the two stage skin carcinogenesis model.
Full description | Chemically induced mouse skin carcinogenesis represents the most extensively utilized animal model to unravel the multistage nature of tumour development and to design novel therapeutic concepts of human epithelial neoplasia. We combined this tumour model with comprehensive gene expression analysis and could identify a large set of novel tumour-associated genes that have not been associated with epithelial skin cancer development yet. Expression data of selected genes were confirmed by semiquantitative and quantitative RT-PCR as well as in situ hybridization and immunofluorescence analysis on mouse tumour sections. Enhanced expression of genes identified in our screen was also demonstrated in mouse keratinocyte cell lines that form tumours in vivo. Self-organizing map clustering was performed to identify different kinetics of gene expression and coregulation during skin cancer progression. Detailed analysis of differential expressed genes according to their functional annotation confirmed the involvement of several biological processes, such as regulation of cell cycle, apoptosis, extracellular proteolysis and cell adhesion, during skin malignancy. Finally, we detected high transcript levels of ANXA1, LCN2 and S100A8 as well as reduced levels for NDR2 protein in human skin tumour specimens demonstrating that tumour-associated genes identified in the chemically induced tumour model might be of great relevance for the understanding of human epithelial malignancies as well.

Standard name | CAVARD_LIVER_CANCER_MALIGNANT_VS_BENIGN
Systematic name | M9719
Organism | Homo sapiens
PMID | 16314847
Authors | Cavard C,Terris B,Grimber G,Christa L,Audard V,Radenen-Bussiere B,Simon MT,Renard CA,Buendia MA,Perret C
Category | C2
Sub-category | CGP
Brief description | Genes identified by subtractive hybridization comparing malignant and benign components of a hepatocellular carcinoma (HCC) in a pre-existing liver adenoma in a morphologically normal liver.
Full description | The Wnt/beta-catenin signaling pathway is activated in many human hepatocellular carcinomas (HCC). We tried to identify the genes involved in carcinogenesis and progression of HCC with beta-catenin mutations. We used PCR-based subtractive hybridization to compare gene expression between malignant and benign components of a human HCC occurring in pre-existing adenoma activated for beta-catenin. Two of the genes identified belong to the Regenerating gene (REG) family. They encode the Regenerating islet-derived 3 alpha (REG3A/HIP/PAP/REG-III) and 1 alpha (REG1A) proteins, both involved in liver and pancreatic regeneration and proliferation. Using siRNA directed against beta-catenin, we demonstrated that REG3A is a target of beta-catenin signaling in Huh7 hepatoma cells. The upregulation of REG3A and REG1A expression is significantly correlated to the beta-catenin status in 42 HCC and 28 hepatoblastomas characterized for their beta-catenin status. Thus, we report strong evidence that both genes are downstream targets of the Wnt pathway during liver tumorigenesis.

Standard name | KLEIN_TARGETS_OF_BCR_ABL1_FUSION
Systematic name | M2569
Organism | Homo sapiens
PMID | 16205638
Authors | Klein F,Feldhahn N,Herzog S,Sprangers M,Mooster JL,Jumaa H,Müschen M
Category | C2
Sub-category | CGP
Brief description | Genes changed in pre-B lymphoblastic leukemia cells with BCR-ABL1 fusion [GeneID=613, 25] vs normal pre-B lymphocytes.
Full description | Pre-B lymphoblastic leukemia cells carrying a BCR-ABL1 gene rearrangement exhibit an undifferentiated phenotype. Comparing the genome-wide gene expression profiles of normal B-cell subsets and BCR-ABL1+ pre-B lymphoblastic leukemia cells by SAGE, the leukemia cells show loss of B lymphoid identity and aberrant expression of myeloid lineage-specific molecules. Consistent with this, BCR-ABL1+ pre-B lymphoblastic leukemia cells exhibit defective expression of IKAROS, a transcription factor needed for early lymphoid lineage commitment. As shown by inducible expression of BCR-ABL1 in human and murine B-cell precursor cell lines, BCR-ABL1 induces the expression of a dominant-negative IKAROS splice variant, termed IK6. Comparing matched leukemia sample pairs from patients before and during therapy with the BCR-ABL1 kinase inhibitor STI571 (Imatinib), inhibition of BCR-ABL1 partially corrected aberrant expression of IK6 and lineage infidelity of the leukemia cells. To elucidate the contribution of IK6 to lineage infidelity in BCR-ABL1+ cell lines, IK6 expression was silenced by RNA interference. Upon inhibition of IK6, BCR-ABL1+ leukemia cells partially restored B lymphoid lineage commitment. Therefore, we propose that BCR-ABL1 induces aberrant splicing of IKAROS, which interferes with lineage identity and differentiation of pre-B lymphoblastic leukemia cells.

Standard name | ROVERSI_GLIOMA_LOH_REGIONS
Systematic name | M6712
Organism | Homo sapiens
PMID | 16247447
Authors | Roversi G,Pfundt R,Moroni RF,Magnani I,van Reijmersdal S,Pollo B,Straatman H,Larizza L,Schoenmakers EF
Category | C2
Sub-category | CGP
Brief description | Genes in the most frequently heterozygous deleted loci of a panel of glioma cell lines.
Full description | Identification of genetic copy number changes in glial tumors is of importance in the context of improved/refined diagnostic, prognostic procedures and therapeutic decision-making. In order to detect recurrent genomic copy number changes that might play a role in glioma pathogenesis and/or progression, we characterized 25 primary glioma cell lines including 15 non glioblastoma (non GBM) (I-III WHO grade) and 10 GBM (IV WHO grade), by array comparative genomic hybridization, using a DNA microarray comprising approx. 3500 BACs covering the entire genome with a 1 Mb resolution and additional 800 BACs covering chromosome 19 at tiling path resolution. Combined evaluation by single clone and whole chromosome analysis plus 'moving average (MA) approach' enabled us to confirm most of the genetic abnormalities previously identified to be associated with glioma progression, including +1q32, +7, -10, -22q, PTEN and p16 loss, and to disclose new small genomic regions, some correlating with grade malignancy. Grade I-III gliomas exclusively showed losses at 3p26 (53%), 4q13-21 (33%) and 7p15-p21 (26%), whereas only GBMs exhibited 4p16.1 losses (40%). Other recurrent imbalances, such as losses at 4p15, 5q22-q23, 6p23-25, 12p13 and gains at 11p11-q13, were shared by different glioma grades. Three intervals with peak of loss could be further refined for chromosome 10 by our MA approach. Data analysis of full-coverage chromosome 19 highlighted two main regions of copy number gain, never described before in gliomas, at 19p13.11 and 19q13.13-13.2. The well-known 19q13.3 loss of heterozygosity area in gliomas was not frequently affected in our cell lines. Genomic hotspot detection facilitated the identification of small intervals resulting in positional candidate genes such as PRDM2 (1p36.21), LRP1B (2q22.3), ADARB2 (10p15.3), BCCIP (10q26.2) and ING1 (13q34) for losses and ECT2 (3q26.3), MDK, DDB2, IG20 (11p11.2) for gains. These data increase our current knowledge about cryptic genetic changes in gliomas and may facilitate the further identification of novel genetic elements, which may provide us with molecular tools for the improved diagnostics and therapeutic decision-making in these tumors.

Standard name | ROVERSI_GLIOMA_COPY_NUMBER_UP
Systematic name | M11028
Organism | Homo sapiens
PMID | 16247447
Authors | Roversi G,Pfundt R,Moroni RF,Magnani I,van Reijmersdal S,Pollo B,Straatman H,Larizza L,Schoenmakers EF
Category | C2
Sub-category | CGP
Brief description | Genes in the most frequently gained loci in a panel of glioma cell lines.
Full description | Identification of genetic copy number changes in glial tumors is of importance in the context of improved/refined diagnostic, prognostic procedures and therapeutic decision-making. In order to detect recurrent genomic copy number changes that might play a role in glioma pathogenesis and/or progression, we characterized 25 primary glioma cell lines including 15 non glioblastoma (non GBM) (I-III WHO grade) and 10 GBM (IV WHO grade), by array comparative genomic hybridization, using a DNA microarray comprising approx. 3500 BACs covering the entire genome with a 1 Mb resolution and additional 800 BACs covering chromosome 19 at tiling path resolution. Combined evaluation by single clone and whole chromosome analysis plus 'moving average (MA) approach' enabled us to confirm most of the genetic abnormalities previously identified to be associated with glioma progression, including +1q32, +7, -10, -22q, PTEN and p16 loss, and to disclose new small genomic regions, some correlating with grade malignancy. Grade I-III gliomas exclusively showed losses at 3p26 (53%), 4q13-21 (33%) and 7p15-p21 (26%), whereas only GBMs exhibited 4p16.1 losses (40%). Other recurrent imbalances, such as losses at 4p15, 5q22-q23, 6p23-25, 12p13 and gains at 11p11-q13, were shared by different glioma grades. Three intervals with peak of loss could be further refined for chromosome 10 by our MA approach. Data analysis of full-coverage chromosome 19 highlighted two main regions of copy number gain, never described before in gliomas, at 19p13.11 and 19q13.13-13.2. The well-known 19q13.3 loss of heterozygosity area in gliomas was not frequently affected in our cell lines. Genomic hotspot detection facilitated the identification of small intervals resulting in positional candidate genes such as PRDM2 (1p36.21), LRP1B (2q22.3), ADARB2 (10p15.3), BCCIP (10q26.2) and ING1 (13q34) for losses and ECT2 (3q26.3), MDK, DDB2, IG20 (11p11.2) for gains. These data increase our current knowledge about cryptic genetic changes in gliomas and may facilitate the further identification of novel genetic elements, which may provide us with molecular tools for the improved diagnostics and therapeutic decision-making in these tumors.

Standard name | RASHI_RESPONSE_TO_IONIZING_RADIATION_1
Systematic name | M1897
Organism | Mus musculus
PMID | 16314843
Authors | Rashi-Elkeles S,Elkon R,Weizman N,Linhart C,Amariglio N,Sternberg G,Rechavi G,Barzilai A,Shamir R,Shiloh Y
Category | C2
Sub-category | CGP
Brief description | Cluster 1: ATM [GeneID=472] dependent genes induced at 30 min after ionizing radiation treatment.
Full description | The ATM protein kinase, functionally missing in patients with the human genetic disorder ataxia-telangiectasia, is a master regulator of the cellular network induced by DNA double-strand breaks. The ATM gene is also frequently mutated in sporadic cancers of lymphoid origin. Here, we applied a functional genomics approach that combined gene expression profiling and computational promoter analysis to obtain global dissection of the transcriptional response to ionizing radiation in murine lymphoid tissue. Cluster analysis revealed a prominent pattern characterizing dozens of genes whose response to irradiation was Atm-dependent. Computational analysis identified significant enrichment of the binding site signatures of NF-kappaB and p53 among promoters of these genes, pointing to the major role of these two transcription factors in mediating the Atm-dependent transcriptional response in the irradiated lymphoid tissue. Examination of the response showed that pro- and antiapoptotic signals were simultaneously induced, with the proapoptotic pathway mediated by p53 targets, and the prosurvival pathway by NF-kappaB targets. These findings further elucidate the molecular network induced by IR, point to novel putative NF-kappaB targets, and suggest a mechanistic model for cellular balancing between pro- and antiapoptotic signals induced by IR in lymphoid tissues, which has implications for cancer management. The emerging model suggests that restoring the p53-mediated apoptotic arm while blocking the NF-kappaB-mediated prosurvival arm could effectively increase the radiosensitivity of lymphoid tumors.

Standard name | RASHI_RESPONSE_TO_IONIZING_RADIATION_2
Systematic name | M5888
Organism | Mus musculus
PMID | 16314843
Authors | Rashi-Elkeles S,Elkon R,Weizman N,Linhart C,Amariglio N,Sternberg G,Rechavi G,Barzilai A,Shamir R,Shiloh Y
Category | C2
Sub-category | CGP
Brief description | Cluster 2: late ATM [GeneID=472] dependent genes induced by ionizing radiation treatment.
Full description | The ATM protein kinase, functionally missing in patients with the human genetic disorder ataxia-telangiectasia, is a master regulator of the cellular network induced by DNA double-strand breaks. The ATM gene is also frequently mutated in sporadic cancers of lymphoid origin. Here, we applied a functional genomics approach that combined gene expression profiling and computational promoter analysis to obtain global dissection of the transcriptional response to ionizing radiation in murine lymphoid tissue. Cluster analysis revealed a prominent pattern characterizing dozens of genes whose response to irradiation was Atm-dependent. Computational analysis identified significant enrichment of the binding site signatures of NF-kappaB and p53 among promoters of these genes, pointing to the major role of these two transcription factors in mediating the Atm-dependent transcriptional response in the irradiated lymphoid tissue. Examination of the response showed that pro- and antiapoptotic signals were simultaneously induced, with the proapoptotic pathway mediated by p53 targets, and the prosurvival pathway by NF-kappaB targets. These findings further elucidate the molecular network induced by IR, point to novel putative NF-kappaB targets, and suggest a mechanistic model for cellular balancing between pro- and antiapoptotic signals induced by IR in lymphoid tissues, which has implications for cancer management. The emerging model suggests that restoring the p53-mediated apoptotic arm while blocking the NF-kappaB-mediated prosurvival arm could effectively increase the radiosensitivity of lymphoid tumors.

Standard name | RASHI_RESPONSE_TO_IONIZING_RADIATION_3
Systematic name | M7248
Organism | Mus musculus
PMID | 16314843
Authors | Rashi-Elkeles S,Elkon R,Weizman N,Linhart C,Amariglio N,Sternberg G,Rechavi G,Barzilai A,Shamir R,Shiloh Y
Category | C2
Sub-category | CGP
Brief description | Cluster 3: genes activated by ionizing radiation regardless of ATM [GeneID=472] status.
Full description | The ATM protein kinase, functionally missing in patients with the human genetic disorder ataxia-telangiectasia, is a master regulator of the cellular network induced by DNA double-strand breaks. The ATM gene is also frequently mutated in sporadic cancers of lymphoid origin. Here, we applied a functional genomics approach that combined gene expression profiling and computational promoter analysis to obtain global dissection of the transcriptional response to ionizing radiation in murine lymphoid tissue. Cluster analysis revealed a prominent pattern characterizing dozens of genes whose response to irradiation was Atm-dependent. Computational analysis identified significant enrichment of the binding site signatures of NF-kappaB and p53 among promoters of these genes, pointing to the major role of these two transcription factors in mediating the Atm-dependent transcriptional response in the irradiated lymphoid tissue. Examination of the response showed that pro- and antiapoptotic signals were simultaneously induced, with the proapoptotic pathway mediated by p53 targets, and the prosurvival pathway by NF-kappaB targets. These findings further elucidate the molecular network induced by IR, point to novel putative NF-kappaB targets, and suggest a mechanistic model for cellular balancing between pro- and antiapoptotic signals induced by IR in lymphoid tissues, which has implications for cancer management. The emerging model suggests that restoring the p53-mediated apoptotic arm while blocking the NF-kappaB-mediated prosurvival arm could effectively increase the radiosensitivity of lymphoid tumors.

Standard name | RASHI_RESPONSE_TO_IONIZING_RADIATION_4
Systematic name | M3141
Organism | Mus musculus
PMID | 16314843
Authors | Rashi-Elkeles S,Elkon R,Weizman N,Linhart C,Amariglio N,Sternberg G,Rechavi G,Barzilai A,Shamir R,Shiloh Y
Category | C2
Sub-category | CGP
Brief description | Cluster 4: genes repressed by ionizing radiation regardless of ATM [GeneID=472] status.
Full description | The ATM protein kinase, functionally missing in patients with the human genetic disorder ataxia-telangiectasia, is a master regulator of the cellular network induced by DNA double-strand breaks. The ATM gene is also frequently mutated in sporadic cancers of lymphoid origin. Here, we applied a functional genomics approach that combined gene expression profiling and computational promoter analysis to obtain global dissection of the transcriptional response to ionizing radiation in murine lymphoid tissue. Cluster analysis revealed a prominent pattern characterizing dozens of genes whose response to irradiation was Atm-dependent. Computational analysis identified significant enrichment of the binding site signatures of NF-kappaB and p53 among promoters of these genes, pointing to the major role of these two transcription factors in mediating the Atm-dependent transcriptional response in the irradiated lymphoid tissue. Examination of the response showed that pro- and antiapoptotic signals were simultaneously induced, with the proapoptotic pathway mediated by p53 targets, and the prosurvival pathway by NF-kappaB targets. These findings further elucidate the molecular network induced by IR, point to novel putative NF-kappaB targets, and suggest a mechanistic model for cellular balancing between pro- and antiapoptotic signals induced by IR in lymphoid tissues, which has implications for cancer management. The emerging model suggests that restoring the p53-mediated apoptotic arm while blocking the NF-kappaB-mediated prosurvival arm could effectively increase the radiosensitivity of lymphoid tumors.

Standard name | RASHI_RESPONSE_TO_IONIZING_RADIATION_5
Systematic name | M15659
Organism | Mus musculus
PMID | 16314843
Authors | Rashi-Elkeles S,Elkon R,Weizman N,Linhart C,Amariglio N,Sternberg G,Rechavi G,Barzilai A,Shamir R,Shiloh Y
Category | C2
Sub-category | CGP
Brief description | Cluster 5: early responding genes activated in ATM [GeneID=472] deficient but not in the wild type tissues.
Full description | The ATM protein kinase, functionally missing in patients with the human genetic disorder ataxia-telangiectasia, is a master regulator of the cellular network induced by DNA double-strand breaks. The ATM gene is also frequently mutated in sporadic cancers of lymphoid origin. Here, we applied a functional genomics approach that combined gene expression profiling and computational promoter analysis to obtain global dissection of the transcriptional response to ionizing radiation in murine lymphoid tissue. Cluster analysis revealed a prominent pattern characterizing dozens of genes whose response to irradiation was Atm-dependent. Computational analysis identified significant enrichment of the binding site signatures of NF-kappaB and p53 among promoters of these genes, pointing to the major role of these two transcription factors in mediating the Atm-dependent transcriptional response in the irradiated lymphoid tissue. Examination of the response showed that pro- and antiapoptotic signals were simultaneously induced, with the proapoptotic pathway mediated by p53 targets, and the prosurvival pathway by NF-kappaB targets. These findings further elucidate the molecular network induced by IR, point to novel putative NF-kappaB targets, and suggest a mechanistic model for cellular balancing between pro- and antiapoptotic signals induced by IR in lymphoid tissues, which has implications for cancer management. The emerging model suggests that restoring the p53-mediated apoptotic arm while blocking the NF-kappaB-mediated prosurvival arm could effectively increase the radiosensitivity of lymphoid tumors.

Standard name | RASHI_RESPONSE_TO_IONIZING_RADIATION_6
Systematic name | M1560
Organism | Mus musculus
PMID | 16314843
Authors | Rashi-Elkeles S,Elkon R,Weizman N,Linhart C,Amariglio N,Sternberg G,Rechavi G,Barzilai A,Shamir R,Shiloh Y
Category | C2
Sub-category | CGP
Brief description | Cluster 6: late responding genes activated in ATM [GeneID=472] deficient but not in the wild type tissues.
Full description | The ATM protein kinase, functionally missing in patients with the human genetic disorder ataxia-telangiectasia, is a master regulator of the cellular network induced by DNA double-strand breaks. The ATM gene is also frequently mutated in sporadic cancers of lymphoid origin. Here, we applied a functional genomics approach that combined gene expression profiling and computational promoter analysis to obtain global dissection of the transcriptional response to ionizing radiation in murine lymphoid tissue. Cluster analysis revealed a prominent pattern characterizing dozens of genes whose response to irradiation was Atm-dependent. Computational analysis identified significant enrichment of the binding site signatures of NF-kappaB and p53 among promoters of these genes, pointing to the major role of these two transcription factors in mediating the Atm-dependent transcriptional response in the irradiated lymphoid tissue. Examination of the response showed that pro- and antiapoptotic signals were simultaneously induced, with the proapoptotic pathway mediated by p53 targets, and the prosurvival pathway by NF-kappaB targets. These findings further elucidate the molecular network induced by IR, point to novel putative NF-kappaB targets, and suggest a mechanistic model for cellular balancing between pro- and antiapoptotic signals induced by IR in lymphoid tissues, which has implications for cancer management. The emerging model suggests that restoring the p53-mediated apoptotic arm while blocking the NF-kappaB-mediated prosurvival arm could effectively increase the radiosensitivity of lymphoid tumors.

Standard name | RASHI_NFKB1_TARGETS
Systematic name | M1171
Organism | Mus musculus
PMID | 16314843
Authors | Rashi-Elkeles S,Elkon R,Weizman N,Linhart C,Amariglio N,Sternberg G,Rechavi G,Barzilai A,Shamir R,Shiloh Y
Category | C2
Sub-category | CGP
Brief description | Known and putative targets of NFKB1 [GeneID=4790] identified among the ATM [GeneID=472] dependent, late responders to ionizing radiation.
Full description | The ATM protein kinase, functionally missing in patients with the human genetic disorder ataxia-telangiectasia, is a master regulator of the cellular network induced by DNA double-strand breaks. The ATM gene is also frequently mutated in sporadic cancers of lymphoid origin. Here, we applied a functional genomics approach that combined gene expression profiling and computational promoter analysis to obtain global dissection of the transcriptional response to ionizing radiation in murine lymphoid tissue. Cluster analysis revealed a prominent pattern characterizing dozens of genes whose response to irradiation was Atm-dependent. Computational analysis identified significant enrichment of the binding site signatures of NF-kappaB and p53 among promoters of these genes, pointing to the major role of these two transcription factors in mediating the Atm-dependent transcriptional response in the irradiated lymphoid tissue. Examination of the response showed that pro- and antiapoptotic signals were simultaneously induced, with the proapoptotic pathway mediated by p53 targets, and the prosurvival pathway by NF-kappaB targets. These findings further elucidate the molecular network induced by IR, point to novel putative NF-kappaB targets, and suggest a mechanistic model for cellular balancing between pro- and antiapoptotic signals induced by IR in lymphoid tissues, which has implications for cancer management. The emerging model suggests that restoring the p53-mediated apoptotic arm while blocking the NF-kappaB-mediated prosurvival arm could effectively increase the radiosensitivity of lymphoid tumors.

Standard name | IWANAGA_E2F1_TARGETS_INDUCED_BY_SERUM
Systematic name | M1172
Organism | Rattus norvegicus
PMID | 16288221
Authors | Iwanaga R,Komori H,Ishida S,Okamura N,Nakayama K,Nakayama KI,Ohtani K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in REF52 cells (embryonic fibroblast) by expression of E2F1 [GeneID=1869] that were also induced at 16 hr after serum stimulation.
Full description | The transcription factor E2F mediates cell cycle-dependent expression of genes important for cell proliferation in response to growth stimulation. To further understand the role of E2F, we utilized a sensitive subtraction method to explore new E2F1 targets, which are expressed at low levels and might have been unrecognized in previous studies. We identified 33 new E2F1-inducible genes, including checkpoint genes Claspin and Rad51ap1, and four genes with unknown function required for cell cycle progression. Moreover, we found three groups of E2F1-inducible genes that were not induced by growth stimulation. At least, two groups of genes were directly induced by E2F1, indicating that E2F1 can regulate expression of genes not induced during the cell cycle. One included Neogenin, WASF1 and SGEF genes, which may have a role in differentiation or development. The other was the cyclin-dependent kinase inhibitor p27(Kip1), which was involved in suppression of inappropriate cell cycle progression induced by deregulated E2F. E2F1-responsive regions of these genes were located more upstream than those of typical E2F targets and did not have typical E2F sites. These results indicate that there are groups of E2F1 targets, which are regulated in a distinct manner from that of typical E2F targets.

Standard name | AIGNER_ZEB1_TARGETS
Systematic name | M14590
Organism | Homo sapiens
PMID | 17486063
Authors | Aigner K,Dampier B,Descovich L,Mikula M,Sultan A,Schreiber M,Mikulits W,Brabletz T,Strand D,Obrist P,Sommergruber W,Schweifer N,Wernitznig A,Beug H,Foisner R,Eger A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MDA-MB-231 cells (breast cancer) after knockdown of ZEB1 [GeneID=6935] by RNAi.
Full description | Epithelial to mesenchymal transition (EMT) is implicated in the progression of primary tumours towards metastasis and is likely caused by a pathological activation of transcription factors regulating EMT in embryonic development. To analyse EMT-causing pathways in tumourigenesis, we identified transcriptional targets of the E-cadherin repressor ZEB1 in invasive human cancer cells. We show that ZEB1 repressed multiple key determinants of epithelial differentiation and cell-cell adhesion, including the cell polarity genes Crumbs3, HUGL2 and Pals1-associated tight junction protein. ZEB1 associated with their endogenous promoters in vivo, and strongly repressed promotor activities in reporter assays. ZEB1 downregulation in undifferentiated cancer cells by RNA interference was sufficient to upregulate expression of these cell polarity genes on the RNA and protein level, to re-establish epithelial features and to impair cell motility in vitro. In human colorectal cancer, ZEB1 expression was limited to the tumour-host interface and was accompanied by loss of intercellular adhesion and tumour cell invasion. In invasive ductal and lobular breast cancer, upregulation of ZEB1 was stringently coupled to cancer cell dedifferentiation. Our data show that ZEB1 represents a key player in pathologic EMTs associated with tumour progression.

Standard name | SUZUKI_AMPLIFIED_IN_ORAL_CANCER
Systematic name | M15351
Organism | Homo sapiens
PMID | 17599052
Authors | Suzuki E,Imoto I,Pimkhaokham A,Nakagawa T,Kamata N,Kozaki KI,Amagasa T,Inazawa J
Category | C2
Sub-category | CGP
Brief description | High-level amplifications detected in oral squamous cell carcinoma (OSCC) lines by array-CGH analysis.
Full description | Array-based comparative genomic hybridization (array-CGH) has good potential for the high-throughput identification of genetic aberrations in cell genomes. In the course of a program to screen a panel of oral squamous-cell carcinoma (OSCC), cell lines for genomic copy-number aberrations by array-CGH using our in-house arrays, we identified a 3-Mb homozygous deletion at 10p12 in 1 of 18 cell lines (5.6%). Among seven genes located within this region, expression of PRTFDC1 mRNA was not detected in 50% (9/18) or decreased in 5.6% (1/18) of OSCC cell lines, but detected in normal oral epithelia and restored in gene-silenced OSCC cells without its homozygous loss after treatment with 5-aza-2'-deoxycytidine. Among 17 cell lines without a homozygous deletion, the hypermethylation of the PRTFDC1 CpG island, which showed promoter activity, was observed in all nine cell lines with no or reduced PRTFDC1 expression (52.9%). Methylation of this CpG island was also observed in primary OSCC tissues (8/47, 17.0%). In addition, restoration of PRTFDC1 in OSCC cells lacking its expression inhibited cell growth in colony-formation assays, whereas knockdown of PRTFDC1 expression in OSCC cells expressing the gene promoted cell growth. These results suggest that epigenetic silencing of PRTFDC1 by hypermethylation of the CpG island leads to a loss of PRTFDC1 function, which might be involved in squamous cell oral carcinogenesis.

Standard name | HESSON_TUMOR_SUPPRESSOR_CLUSTER_3P21_3
Systematic name | M1173
Organism | Homo sapiens
PMID | 17533367
Authors | Hesson LB,Cooper WN,Latif F
Category | C2
Sub-category | CGP
Brief description | Genes in the tumor suppressor cluster of the 3p21.3 region.
Full description | Deletions of the 3p21.3 region are a frequent and early event in the formation of lung, breast, kidney and other cancers. Intense investigation of allelic losses and the discovery of overlapping homozygous deletions in lung and breast tumour-cell lines have defined a minimal critical 120 kb deletion region containing eight genes and likely to harbor one or more tumour-suppressor genes (TSGs). The candidate genes are HYAL2, FUS1, Ras-associated factor 1 (RASSF1), BLU/ZMYND10, NPR2L, 101F6, PL6 and CACNA2D2. Recent research indicates that several of these genes can suppress the growth of lung and other tumour cells. Furthermore, some genes (RASSF1A and BLU/ZMYND10) are very frequently inactivated by non-classical mechanisms such as promoter hypermethylation resulting in loss of expression. These data indicate that the 120 kb critical deletion region at 3p21.3 may represent a TSG cluster with preferential inactivation of particular genes depending on tumour type. The eight genes within this region and their potential role in cancer will be the focus of this review.

Standard name | MARTIN_INTERACT_WITH_HDAC
Systematic name | M15154
Organism | Homo sapiens
PMID | 17694086
Authors | Martin M,Kettmann R,Dequiedt F
Category | C2
Sub-category | CGP
Brief description | Interaction partners of class IIa histone deacetylases (HDAC).
Full description | In the last decade, the identification of enzymes that regulate acetylation of histones and nonhistone proteins has revealed the key role of dynamic acetylation and deacetylation in various cellular processes. Mammalian histone deacetylases (HDACs), which catalyse the removal of acetyl groups from lysine residues, are grouped into three classes, on the basis of similarity to yeast counterparts. An abundance of experimental evidence has established class IIa HDACs as crucial transcriptional regulators of various developmental and differentiation processes. In the past 5 years, a tremendous effort has been dedicated to characterizing the regulation of these enzymes. In this review, we summarize the latest discoveries in the field and discuss the molecular and structural determinants of class IIa HDACs regulation. Finally, we emphasize that comprehension of the mechanisms underlying class IIa HDAC functions is essential for potential therapeutic applications.

Standard name | LASTOWSKA_COAMPLIFIED_WITH_MYCN
Systematic name | M1375
Organism | Homo sapiens
PMID | 17533364
Authors | Łastowska M,Viprey V,Santibanez-Koref M,Wappler I,Peters H,Cullinane C,Roberts P,Hall AG,Tweddle DA,Pearson AD,Lewis I,Burchill SA,Jackson MS
Category | C2
Sub-category | CGP
Brief description | Genes co-amplified within MYCN [GeneID=4613] in primary neuroblastoma tumors.
Full description | Identifying genes, whose expression is consistently altered by chromosomal gains or losses, is an important step in defining genes of biological relevance in a wide variety of tumour types. However, additional criteria are needed to discriminate further among the large number of candidate genes identified. This is particularly true for neuroblastoma, where multiple genomic copy number changes of proven prognostic value exist. We have used Affymetrix microarrays and a combination of fluorescent in situ hybridization and single nucleotide polymorphism (SNP) microarrays to establish expression profiles and delineate copy number alterations in 30 primary neuroblastomas. Correlation of microarray data with patient survival and analysis of expression within rodent neuroblastoma cell lines were then used to define further genes likely to be involved in the disease process. Using this approach, we identify >1000 genes within eight recurrent genomic alterations (loss of 1p, 3p, 4p, 10q and 11q, 2p gain, 17q gain, and the MYCN amplicon) whose expression is consistently altered by copy number change. Of these, 84 correlate with patient survival, with the minimal regions of 17q gain and 4p loss being enriched significantly for such genes. These include genes involved in RNA and DNA metabolism, and apoptosis. Orthologues of all but one of these genes on 17q are overexpressed in rodent neuroblastoma cell lines. A significant excess of SNPs whose copy number correlates with survival is also observed on proximal 4p in stage 4 tumours, and we find that deletion of 4p is associated with improved outcome in an extended cohort of tumours. These results define the major impact of genomic copy number alterations upon transcription within neuroblastoma, and highlight genes on distal 17q and proximal 4p for downstream analyses. They also suggest that integration of discriminators, such as survival and comparative gene expression, with microarray data may be useful in the identification of critical genes within regions of loss or gain in many human cancers.

Standard name | IWANAGA_E2F1_TARGETS_NOT_INDUCED_BY_SERUM
Systematic name | M1175
Organism | Rattus norvegicus
PMID | 16288221
Authors | Iwanaga R,Komori H,Ishida S,Okamura N,Nakayama K,Nakayama KI,Ohtani K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in REF52 cells (embryonic fibroblast) by expression of E2F1 [GeneID=1869] that were not induced at all at 16 hr after serum stimulation.
Full description | The transcription factor E2F mediates cell cycle-dependent expression of genes important for cell proliferation in response to growth stimulation. To further understand the role of E2F, we utilized a sensitive subtraction method to explore new E2F1 targets, which are expressed at low levels and might have been unrecognized in previous studies. We identified 33 new E2F1-inducible genes, including checkpoint genes Claspin and Rad51ap1, and four genes with unknown function required for cell cycle progression. Moreover, we found three groups of E2F1-inducible genes that were not induced by growth stimulation. At least, two groups of genes were directly induced by E2F1, indicating that E2F1 can regulate expression of genes not induced during the cell cycle. One included Neogenin, WASF1 and SGEF genes, which may have a role in differentiation or development. The other was the cyclin-dependent kinase inhibitor p27(Kip1), which was involved in suppression of inappropriate cell cycle progression induced by deregulated E2F. E2F1-responsive regions of these genes were located more upstream than those of typical E2F targets and did not have typical E2F sites. These results indicate that there are groups of E2F1 targets, which are regulated in a distinct manner from that of typical E2F targets.

Standard name | LI_LUNG_CANCER
Systematic name | M8779
Organism | Homo sapiens
PMID | 16369491
Authors | Li R,Wang H,Bekele BN,Yin Z,Caraway NP,Katz RL,Stass SA,Jiang F
Category | C2
Sub-category | CGP
Brief description | Proteins showing significant overexpression in lung cancer cell lines relative to normal bronchial epithelial cell lines.
Full description | Amplification and overexpression of putative oncogenes confer growth advantages for tumor development. We used a functional genomic approach that integrated simultaneous genomic and transcript microarray, proteomics, and tissue microarray analyses to directly identify putative oncogenes in lung adenocarcinoma. We first identified 183 genes with increases in both genomic copy number and transcript in six lung adenocarcinoma cell lines. Next, we used two-dimensional polyacrylamide gel electrophoresis and mass spectrometry to identify 42 proteins that were overexpressed in the cancer cells relative to normal cells. Comparing the 183 genes with the 42 proteins, we identified four genes - PRDX1, EEF1A2, CALR, and KCIP-1 - in which elevated protein expression correlated with both increased DNA copy number and increased transcript levels (all r > 0.84, two-sided P < 0.05). These findings were validated by Southern, Northern, and Western blotting. Specific inhibition of EEF1A2 and KCIP-1 expression with siRNA in the four cell lines tested suppressed proliferation and induced apoptosis. Parallel fluorescence in situ hybridization and immunohistochemical analyses of EEF1A2 and KCIP-1 in tissue microarrays from patients with lung adenocarcinoma showed that gene amplification was associated with high protein expression for both genes and that protein overexpression was related to tumor grade, disease stage, Ki-67 expression, and a shorter survival of patients. The amplification of EEF1A2 and KCIP-1 and the presence of overexpressed protein in tumor samples strongly suggest that these genes could be oncogenes and hence potential targets for diagnosis and therapy in lung adenocarcinoma.

Standard name | LI_AMPLIFIED_IN_LUNG_CANCER
Systematic name | M5792
Organism | Homo sapiens
PMID | 16369491
Authors | Li R,Wang H,Bekele BN,Yin Z,Caraway NP,Katz RL,Stass SA,Jiang F
Category | C2
Sub-category | CGP
Brief description | Genes with increased copy number that correlates with increased expression across six different lung adenocarcinoma cell lines.
Full description | Amplification and overexpression of putative oncogenes confer growth advantages for tumor development. We used a functional genomic approach that integrated simultaneous genomic and transcript microarray, proteomics, and tissue microarray analyses to directly identify putative oncogenes in lung adenocarcinoma. We first identified 183 genes with increases in both genomic copy number and transcript in six lung adenocarcinoma cell lines. Next, we used two-dimensional polyacrylamide gel electrophoresis and mass spectrometry to identify 42 proteins that were overexpressed in the cancer cells relative to normal cells. Comparing the 183 genes with the 42 proteins, we identified four genes - PRDX1, EEF1A2, CALR, and KCIP-1 - in which elevated protein expression correlated with both increased DNA copy number and increased transcript levels (all r > 0.84, two-sided P < 0.05). These findings were validated by Southern, Northern, and Western blotting. Specific inhibition of EEF1A2 and KCIP-1 expression with siRNA in the four cell lines tested suppressed proliferation and induced apoptosis. Parallel fluorescence in situ hybridization and immunohistochemical analyses of EEF1A2 and KCIP-1 in tissue microarrays from patients with lung adenocarcinoma showed that gene amplification was associated with high protein expression for both genes and that protein overexpression was related to tumor grade, disease stage, Ki-67 expression, and a shorter survival of patients. The amplification of EEF1A2 and KCIP-1 and the presence of overexpressed protein in tumor samples strongly suggest that these genes could be oncogenes and hence potential targets for diagnosis and therapy in lung adenocarcinoma.

Standard name | LINDGREN_BLADDER_CANCER_CLUSTER_2B
Systematic name | M4995
Organism | Homo sapiens
PMID | 16532037
Authors | Lindgren D,Liedberg F,Andersson A,Chebil G,Gudjonsson S,Borg A,Månsson W,Fioretos T,Höglund M
Category | C2
Sub-category | CGP
Brief description | Genes specifically up-regulated in Cluster IIb of urothelial cell carcinom (UCC) tumors.
Full description | We used gene expression profiling, mutation analyses of FGFR3 and TP53, and LOH analyses of chromosome 9 and the TP53 region on chromosome arm 17p, to molecularly characterize 75 Ta and T1 bladder carcinomas. We identified four major cellular processes related to cell cycle, protein synthesis, immune response, and extra cellular components that contribute to the expressional heterogeneity of early-stage urothelial cell carcinoma (UCC). Activating FGFR3 mutations were found at the highest frequency in G1 tumors (80%), and showed a strong correlation with FGFR3 expression. In contrast, G3 tumors displayed mutations in less than 10% of the cases and a low level of FGFR3 expression. Even though LOH on chromosome 9 was not associated with any specific expression pattern, our data indicate that loss of chromosome 9 is associated with tumor development rather than initiation. The combined analyses suggest the existence of two types of UCC tumors, one which is characterized by FGFR3 mutation or expression, high expression of protein synthesis genes, and low expression of cell cycle genes. Furthermore, the presented data underscore FGFR3 receptor involvement in urothelial cell transformation as the presence of FGFR3 mutations has a major impact on the global gene expression profile of bladder carcinomas.

Standard name | LINDGREN_BLADDER_CANCER_HIGH_RECURRENCE
Systematic name | M2899
Organism | Homo sapiens
PMID | 16532037
Authors | Lindgren D,Liedberg F,Andersson A,Chebil G,Gudjonsson S,Borg A,Månsson W,Fioretos T,Höglund M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated among the high recurrence rate urothelial cell carcinoma (UCC) tumors.
Full description | We used gene expression profiling, mutation analyses of FGFR3 and TP53, and LOH analyses of chromosome 9 and the TP53 region on chromosome arm 17p, to molecularly characterize 75 Ta and T1 bladder carcinomas. We identified four major cellular processes related to cell cycle, protein synthesis, immune response, and extra cellular components that contribute to the expressional heterogeneity of early-stage urothelial cell carcinoma (UCC). Activating FGFR3 mutations were found at the highest frequency in G1 tumors (80%), and showed a strong correlation with FGFR3 expression. In contrast, G3 tumors displayed mutations in less than 10% of the cases and a low level of FGFR3 expression. Even though LOH on chromosome 9 was not associated with any specific expression pattern, our data indicate that loss of chromosome 9 is associated with tumor development rather than initiation. The combined analyses suggest the existence of two types of UCC tumors, one which is characterized by FGFR3 mutation or expression, high expression of protein synthesis genes, and low expression of cell cycle genes. Furthermore, the presented data underscore FGFR3 receptor involvement in urothelial cell transformation as the presence of FGFR3 mutations has a major impact on the global gene expression profile of bladder carcinomas.

Standard name | LINDGREN_BLADDER_CANCER_WITH_LOH_IN_CHR9Q
Systematic name | M8411
Organism | Homo sapiens
PMID | 16532037
Authors | Lindgren D,Liedberg F,Andersson A,Chebil G,Gudjonsson S,Borg A,Månsson W,Fioretos T,Höglund M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in urothelial cell carcinoma (UCC) tumors with LOH on 9q as compared to the tumors showing retention.
Full description | We used gene expression profiling, mutation analyses of FGFR3 and TP53, and LOH analyses of chromosome 9 and the TP53 region on chromosome arm 17p, to molecularly characterize 75 Ta and T1 bladder carcinomas. We identified four major cellular processes related to cell cycle, protein synthesis, immune response, and extra cellular components that contribute to the expressional heterogeneity of early-stage urothelial cell carcinoma (UCC). Activating FGFR3 mutations were found at the highest frequency in G1 tumors (80%), and showed a strong correlation with FGFR3 expression. In contrast, G3 tumors displayed mutations in less than 10% of the cases and a low level of FGFR3 expression. Even though LOH on chromosome 9 was not associated with any specific expression pattern, our data indicate that loss of chromosome 9 is associated with tumor development rather than initiation. The combined analyses suggest the existence of two types of UCC tumors, one which is characterized by FGFR3 mutation or expression, high expression of protein synthesis genes, and low expression of cell cycle genes. Furthermore, the presented data underscore FGFR3 receptor involvement in urothelial cell transformation as the presence of FGFR3 mutations has a major impact on the global gene expression profile of bladder carcinomas.

Standard name | NAKAMURA_ALVEOLAR_EPITHELIUM
Systematic name | M17424
Organism | Homo sapiens
PMID | 16491115
Authors | Nakamura N,Kobayashi K,Nakamoto M,Kohno T,Sasaki H,Matsuno Y,Yokota J
Category | C2
Sub-category | CGP
Brief description | Differentiation markers for normal alveolar epithelium cells.
Full description | To identify tumor markers and differentiation markers for lung adenocarcinoma (AdC), we analysed expression profiles of 14,500 genes against three cases of type II alveolar epithelial cells, bronchiolar epithelial cells, and bronchial epithelial cells, respectively, and 10 cases of AdC cells isolated by laser capture microdissection. Hierarchical clustering analysis indicated that AdC cells and noncancerous lung epithelial cells are significantly different in their expression profiles, and that different sets of differentiation markers are expressed among alveolar, bronchiolar and bronchial epithelial cells. Nine genes were identified as being highly expressed in AdC cells, but not expressed in noncancerous lung epithelial cells. Sixteen genes were identified as differentiation markers for lung epithelial cells. Real-time RT-PCR analysis of 45 lung AdC cases further revealed that expression of four tumor markers in AdC cells was significantly higher than that in noncancerous lung cells and that expression of ten differentiation markers was retained in a considerable fraction of lung AdC cases. Five tumor markers and seven differentiation markers were not expressed in peripheral blood cells. Similarities and differences in expression profiles between normal epithelial cells from different lung respiratory compartments and AdC cells demonstrated in this study will be informative for the molecular diagnosis of lung AdC.

Standard name | NAKAMURA_BRONCHIAL_AND_BRONCHIOLAR_EPITHELIA
Systematic name | M14511
Organism | Homo sapiens
PMID | 16491115
Authors | Nakamura N,Kobayashi K,Nakamoto M,Kohno T,Sasaki H,Matsuno Y,Yokota J
Category | C2
Sub-category | CGP
Brief description | Differentiation markers for normal bronchiolar and bronchial epithelial cells.
Full description | To identify tumor markers and differentiation markers for lung adenocarcinoma (AdC), we analysed expression profiles of 14,500 genes against three cases of type II alveolar epithelial cells, bronchiolar epithelial cells, and bronchial epithelial cells, respectively, and 10 cases of AdC cells isolated by laser capture microdissection. Hierarchical clustering analysis indicated that AdC cells and noncancerous lung epithelial cells are significantly different in their expression profiles, and that different sets of differentiation markers are expressed among alveolar, bronchiolar and bronchial epithelial cells. Nine genes were identified as being highly expressed in AdC cells, but not expressed in noncancerous lung epithelial cells. Sixteen genes were identified as differentiation markers for lung epithelial cells. Real-time RT-PCR analysis of 45 lung AdC cases further revealed that expression of four tumor markers in AdC cells was significantly higher than that in noncancerous lung cells and that expression of ten differentiation markers was retained in a considerable fraction of lung AdC cases. Five tumor markers and seven differentiation markers were not expressed in peripheral blood cells. Similarities and differences in expression profiles between normal epithelial cells from different lung respiratory compartments and AdC cells demonstrated in this study will be informative for the molecular diagnosis of lung AdC.

Standard name | NAKAMURA_LUNG_CANCER_DIFFERENTIATION_MARKERS
Systematic name | M13656
Organism | Homo sapiens
PMID | 16491115
Authors | Nakamura N,Kobayashi K,Nakamoto M,Kohno T,Sasaki H,Matsuno Y,Yokota J
Category | C2
Sub-category | CGP
Brief description | 14 candidate differentiation markers in lung adenocarcinoma cells, noncancerous lung cells and peripheral blood cells.
Full description | To identify tumor markers and differentiation markers for lung adenocarcinoma (AdC), we analysed expression profiles of 14,500 genes against three cases of type II alveolar epithelial cells, bronchiolar epithelial cells, and bronchial epithelial cells, respectively, and 10 cases of AdC cells isolated by laser capture microdissection. Hierarchical clustering analysis indicated that AdC cells and noncancerous lung epithelial cells are significantly different in their expression profiles, and that different sets of differentiation markers are expressed among alveolar, bronchiolar and bronchial epithelial cells. Nine genes were identified as being highly expressed in AdC cells, but not expressed in noncancerous lung epithelial cells. Sixteen genes were identified as differentiation markers for lung epithelial cells. Real-time RT-PCR analysis of 45 lung AdC cases further revealed that expression of four tumor markers in AdC cells was significantly higher than that in noncancerous lung cells and that expression of ten differentiation markers was retained in a considerable fraction of lung AdC cases. Five tumor markers and seven differentiation markers were not expressed in peripheral blood cells. Similarities and differences in expression profiles between normal epithelial cells from different lung respiratory compartments and AdC cells demonstrated in this study will be informative for the molecular diagnosis of lung AdC.

Standard name | GALLUZZI_PREVENT_MITOCHONDIAL_PERMEABILIZATION
Systematic name | M7952
Organism | Homo sapiens
PMID | 16892093
Authors | Galluzzi L,Larochette N,Zamzami N,Kroemer G
Category | C2
Sub-category | CGP
Brief description | Proteins acting on mitochondria to prevent membrane permeabilization.
Full description | Mitochondria are vital for cellular bioenergetics and play a central role in determining the point-of-no-return of the apoptotic process. As a consequence, mitochondria exert a dual function in carcinogenesis. Cancer-associated changes in cellular metabolism (the Warburg effect) influence mitochondrial function, and the invalidation of apoptosis is linked to an inhibition of mitochondrial outer membrane permeabilization (MOMP). On theoretical grounds, it is tempting to develop specific therapeutic interventions that target the mitochondrial Achilles' heel, rendering cancer cells metabolically unviable or subverting endogenous MOMP inhibitors. A variety of experimental therapeutic agents can directly target mitochondria, causing apoptosis induction. This applies to a heterogeneous collection of chemically unrelated compounds including positively charged alpha-helical peptides, agents designed to mimic the Bcl-2 homology domain 3 of Bcl-2-like proteins, ampholytic cations, metals and steroid-like compounds. Such MOMP inducers or facilitators can induce apoptosis by themselves (monotherapy) or facilitate apoptosis induction in combination therapies, bypassing chemoresistance against DNA-damaging agents. In addition, it is possible to design molecules that neutralize inhibitor of apoptosis proteins (IAPs) or heat shock protein 70 (HSP70). Such IAP or HSP70 inhibitors can mimic the action of mitochondrion-derived mediators (Smac/DIABLO, that is, second mitochondria-derived activator of caspases/direct inhibitor of apoptosis-binding protein with a low isoelectric point, in the case of IAPs; AIF, that is apoptosis-inducing factor, in the case of HSP70) and exert potent chemosensitizing effects.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_17
Systematic name | M14183
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 17: colocalized fragile sites and cancer genes in the 1q11-q44 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_24
Systematic name | M16402
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 24: colocalized fragile sites and cancer genes in the 1q21-q24 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_25
Systematic name | M16082
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 25: colocalized fragile sites and cancer genes in the 2q13-q36 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_7
Systematic name | M8754
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 7: colocalized fragile sites and cancer genes in the 3q26.3-q29 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_27
Systematic name | M3815
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 27: colocalized fragile sites and cancer genes in the 5p15.3-p15.1; 5p12-q35 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_15
Systematic name | M7559
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 15: colocalized fragile sites and cancer genes in the 6p25-p11.1 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_29
Systematic name | M762
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 29: colocolized fragile sites and cancer genes in the 7p22-p13 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_9
Systematic name | M9239
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 9: colocolized fragile sites and cancer genes in the 8p23-q12; 8q23 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_16
Systematic name | M9291
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 16: colocolized fragile sites and cancer genes in the 8q11.1-q24.3 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | EBAUER_TARGETS_OF_PAX3_FOXO1_FUSION_DN
Systematic name | M7778
Organism | Homo sapiens
PMID | 17525748
Authors | Ebauer M,Wachtel M,Niggli FK,Schäfer BW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Rh4 cells (alveolar rhabdomyosarcoma, ARMS) after knockdown of the PAX3-FOXO1 [GeneiD=5077;2308] fusion protein by RNAi for 72 hr.
Full description | The chromosomal translocation t(2;13), characteristic for the aggressive childhood cancer alveolar rhabdomyosarcoma (aRMS), generates the chimeric transcription factor PAX3/FKHR with a well known oncogenic role. However, the molecular mechanisms mediating essential pathophysiological functions remain poorly defined. Here, we used comparative expression profiling of PAX3/FKHR silencing in vitro and PAX3/FKHR-specific gene signatures in vivo to identify physiologically important target genes. Hereby, 51 activated genes, both novel and known, were identified. We also found repression of skeletal muscle-specific genes suggesting that PAX3/FKHR blocks further differentiation of aRMS cells. Importantly, TFAP2B was validated as direct target gene mediating the anti-apoptotic function of PAX3/FKHR. Hence, we developed a pathophysiologically relevant transcriptional profile of PAX3/FKHR and identified a critical target gene for aRMS development.

Standard name | EBAUER_MYOGENIC_TARGETS_OF_PAX3_FOXO1_FUSION
Systematic name | M16123
Organism | Homo sapiens
PMID | 17525748
Authors | Ebauer M,Wachtel M,Niggli FK,Schäfer BW
Category | C2
Sub-category | CGP
Brief description | Muscle development genes up-regulated in Rh4 cells (alveolar rhabdomyosarcoma, ARMS) but not in the RD cells (embryonal rhabdomyosarcoma, ERMS) after knockdown of PAX3-FOXO1 [GeneID=5077;2308] fusion by RNAi for 72 hr.
Full description | The chromosomal translocation t(2;13), characteristic for the aggressive childhood cancer alveolar rhabdomyosarcoma (aRMS), generates the chimeric transcription factor PAX3/FKHR with a well known oncogenic role. However, the molecular mechanisms mediating essential pathophysiological functions remain poorly defined. Here, we used comparative expression profiling of PAX3/FKHR silencing in vitro and PAX3/FKHR-specific gene signatures in vivo to identify physiologically important target genes. Hereby, 51 activated genes, both novel and known, were identified. We also found repression of skeletal muscle-specific genes suggesting that PAX3/FKHR blocks further differentiation of aRMS cells. Importantly, TFAP2B was validated as direct target gene mediating the anti-apoptotic function of PAX3/FKHR. Hence, we developed a pathophysiologically relevant transcriptional profile of PAX3/FKHR and identified a critical target gene for aRMS development.

Standard name | SCHAVOLT_TARGETS_OF_TP53_AND_TP63
Systematic name | M154
Organism | Homo sapiens
PMID | 17404570
Authors | Schavolt KL,Pietenpol JA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by TP53 [GeneID=7157] and down-regulated by an isoform of TP63 [GeneID=8626] in primary HEK cells (epidermal keratinocytes).
Full description | The mechanism by which the p53 family of proteins coordinately regulates select target genes after various types of cell stress is not well understood. To further define factors that dictate regulation of target genes, we examined the binding of p53, DeltaNp63alpha and RNA polymerase II (pol II) to the regulatory regions of select target genes in primary human epidermal keratinocytes (HEKs) using chromatin immunoprecipitation. In rapidly proliferating cells, we observed constitutive binding of DeltaNp63alpha and varying levels of p53 binding, to consensus sites in target genes involved in cell cycle arrest, DNA repair and apoptosis. Following genotoxic stress, p53 occupancy increased whereas DeltaNp63alpha occupancy decreased at the majority of binding sites examined. Microarray analysis of transcripts isolated from HEKs ectopically expressing p53 and DeltaNp63alpha revealed an inverse regulation of select target genes by the two family members. Collectively, our results suggest that DeltaNp63alpha can function as a repressor of select p53 target genes involved in growth arrest, DNA repair and apoptosis, and that the location of the p53 consensus binding site(s) in a target gene may dictate whether pol II is constitutively bound in proliferating cells.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_8
Systematic name | M5304
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 8: colocolized fragile sites and cancer genes in the 9q11-34 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_23
Systematic name | M13194
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 23: colocolized fragile sites and cancer genes in the 11q12-q25 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_2
Systematic name | M1176
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 2: colocolized fragile sites and cancer genes in the 12p13-p11.1 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_21
Systematic name | M8406
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 21: colocolized fragile sites and cancer genes in the 12q13-q21 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_30
Systematic name | M14194
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 30: colocolized fragile sites and cancer genes in the 12q21-q24.3 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_6
Systematic name | M1179
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 6: colocolized fragile sites and cancer genes in the 17p13-p11.1 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_12
Systematic name | M16845
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 12: colocolized fragile sites and cancer genes in the 17q11.1-q21; 17q25 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MATTIOLI_MGUS_VS_PCL
Systematic name | M10973
Organism | Homo sapiens
PMID | 15735737
Authors | Mattioli M,Agnelli L,Fabris S,Baldini L,Morabito F,Bicciato S,Verdelli D,Intini D,Nobili L,Cro L,Pruneri G,Callea V,Stelitano C,Maiolo AT,Lombardi L,Neri A
Category | C2
Sub-category | CGP
Brief description | Genes changed in MGUS (monoclonal gammopathy of undetermined significance) compared to PCL (plasma cell leukemia) samples.
Full description | Multiple myeloma (MM) is the most common form of plasma cell dyscrasia, characterized by a marked heterogeneity of genetic lesions and clinical course. It may develop from a premalignant condition (monoclonal gammopathy of undetermined significance, MGUS) or progress from intramedullary to extramedullary forms (plasma cell leukemia, PCL). To provide insights into the molecular characterization of plasma cell dyscrasias and to investigate the contribution of specific genetic lesions to the biological and clinical heterogeneity of MM, we analysed the gene expression profiles of plasma cells isolated from seven MGUS, 39 MM and six PCL patients by means of DNA microarrays. MMs resulted highly heterogeneous at transcriptional level, whereas the differential expression of genes mainly involved in DNA metabolism and proliferation distinguished MGUS from PCLs and the majority of MM cases. The clustering of MM patients was mainly driven by the presence of the most recurrent translocations involving the immunoglobulin heavy-chain locus. Distinct gene expression patterns have been found to be associated with different lesions: the overexpression of CCND2 and genes involved in cell adhesion pathways was observed in cases with deregulated MAF and MAFB, whereas genes upregulated in cases with the t(4;14) showed apoptosis-related functions. The peculiar finding in patients with the t(11;14) was the downregulation of the alpha-subunit of the IL-6 receptor. In addition, we identified a set of cancer germline antigens specifically expressed in a subgroup of MM patients characterized by an aggressive clinical evolution, a finding that could have implications for patient classification and immunotherapy.

Standard name | MATTIOLI_MGUS_VS_MULTIPLE_MYELOMA
Systematic name | M2555
Organism | Homo sapiens
PMID | 15735737
Authors | Mattioli M,Agnelli L,Fabris S,Baldini L,Morabito F,Bicciato S,Verdelli D,Intini D,Nobili L,Cro L,Pruneri G,Callea V,Stelitano C,Maiolo AT,Lombardi L,Neri A
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing between MGUS (monoclonal gammopathy of undetermined significance) and multiple myeloma (MM) samples.
Full description | Multiple myeloma (MM) is the most common form of plasma cell dyscrasia, characterized by a marked heterogeneity of genetic lesions and clinical course. It may develop from a premalignant condition (monoclonal gammopathy of undetermined significance, MGUS) or progress from intramedullary to extramedullary forms (plasma cell leukemia, PCL). To provide insights into the molecular characterization of plasma cell dyscrasias and to investigate the contribution of specific genetic lesions to the biological and clinical heterogeneity of MM, we analysed the gene expression profiles of plasma cells isolated from seven MGUS, 39 MM and six PCL patients by means of DNA microarrays. MMs resulted highly heterogeneous at transcriptional level, whereas the differential expression of genes mainly involved in DNA metabolism and proliferation distinguished MGUS from PCLs and the majority of MM cases. The clustering of MM patients was mainly driven by the presence of the most recurrent translocations involving the immunoglobulin heavy-chain locus. Distinct gene expression patterns have been found to be associated with different lesions: the overexpression of CCND2 and genes involved in cell adhesion pathways was observed in cases with deregulated MAF and MAFB, whereas genes upregulated in cases with the t(4;14) showed apoptosis-related functions. The peculiar finding in patients with the t(11;14) was the downregulation of the alpha-subunit of the IL-6 receptor. In addition, we identified a set of cancer germline antigens specifically expressed in a subgroup of MM patients characterized by an aggressive clinical evolution, a finding that could have implications for patient classification and immunotherapy.

Standard name | FARMER_BREAST_CANCER_APOCRINE_VS_LUMINAL
Systematic name | M4008
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Genes which best discriminate between two groups of breast cancer according to the status of ESR1 and AR [GeneID=2099;367]: apocrine (ESR1- AR+) and luminal (ESR1+ AR+).
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | FARMER_BREAST_CANCER_APOCRINE_VS_BASAL
Systematic name | M2631
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Genes which best discriminate between two groups of breast cancer according the status of ESR1 and AR [GeneID=2099;367]: apocrine (ESR1- AR+) vs basal (ESR1- AR-).
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | FARMER_BREAST_CANCER_BASAL_VS_LULMINAL
Systematic name | M5652
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Genes which best discriminated between two groups of breast cancer according to the status of ESR1 and AR [GeneID=2099;367]: basal (ESR1- AR-) and luminal (ESR1+ AR+).
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_5
Systematic name | M12227
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 5: colocolized fragile sites and cancer genes in the 17q22-q25 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_18
Systematic name | M12820
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 18: colocolized fragile sites and cancer genes in the 18q11.2-q23 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | LUI_THYROID_CANCER_CLUSTER_1
Systematic name | M2135
Organism | Homo sapiens
PMID | 15608688
Authors | Lui WO,Foukakis T,Lidén J,Thoppe SR,Dwight T,Höög A,Zedenius J,Wallin G,Reimers M,Larsson C
Category | C2
Sub-category | CGP
Brief description | Cluster 1: genes with similar expression profiles across follicular thyrorid carcinoma (FTC) samples.
Full description | The demonstration of the PAX8-PPAR(gamma) fusion oncogene in a subset of follicular thyroid tumors provides a new and promising starting point to dissect the molecular genetic events involved in the development of this tumor form. In the present study, we compared the gene expression profiles of follicular thyroid carcinomas (FTCs) bearing a PAX8-PPAR(gamma) fusion against FTCs that lack this fusion. Using unsupervised clustering and multidimensional scaling analyses, we show that FTCs possessing a PAX8-PPAR(gamma) fusion have a highly uniform and distinct gene expression signature that clearly distinguishes them from FTCs without the fusion. The PAX8-PPAR(gamma)(+) FTCs grouped in a defined cluster, where highly ranked genes were mostly associated with signal transduction, cell growth and translation control. Notably, a large number of ribosomal protein and translation-associated genes were concurrently underexpressed in the FTCs with the fusion. Taken together, our findings further support that follicular carcinomas with a PAX8-PPAR(gamma) rearrangement constitute a distinct biological entity. The current data represent one step to elucidate the molecular pathways in the development of FTCs with the specific PAX8-PPAR(gamma) fusion.

Standard name | LUI_THYROID_CANCER_CLUSTER_2
Systematic name | M7343
Organism | Homo sapiens
PMID | 15608688
Authors | Lui WO,Foukakis T,Lidén J,Thoppe SR,Dwight T,Höög A,Zedenius J,Wallin G,Reimers M,Larsson C
Category | C2
Sub-category | CGP
Brief description | Cluster 2: genes with similar expression profiles across follicular thyroid carcinoma (FTC) samples.
Full description | The demonstration of the PAX8-PPAR(gamma) fusion oncogene in a subset of follicular thyroid tumors provides a new and promising starting point to dissect the molecular genetic events involved in the development of this tumor form. In the present study, we compared the gene expression profiles of follicular thyroid carcinomas (FTCs) bearing a PAX8-PPAR(gamma) fusion against FTCs that lack this fusion. Using unsupervised clustering and multidimensional scaling analyses, we show that FTCs possessing a PAX8-PPAR(gamma) fusion have a highly uniform and distinct gene expression signature that clearly distinguishes them from FTCs without the fusion. The PAX8-PPAR(gamma)(+) FTCs grouped in a defined cluster, where highly ranked genes were mostly associated with signal transduction, cell growth and translation control. Notably, a large number of ribosomal protein and translation-associated genes were concurrently underexpressed in the FTCs with the fusion. Taken together, our findings further support that follicular carcinomas with a PAX8-PPAR(gamma) rearrangement constitute a distinct biological entity. The current data represent one step to elucidate the molecular pathways in the development of FTCs with the specific PAX8-PPAR(gamma) fusion.

Standard name | LUI_THYROID_CANCER_CLUSTER_3
Systematic name | M4290
Organism | Homo sapiens
PMID | 15608688
Authors | Lui WO,Foukakis T,Lidén J,Thoppe SR,Dwight T,Höög A,Zedenius J,Wallin G,Reimers M,Larsson C
Category | C2
Sub-category | CGP
Brief description | Cluster 3: genes with similar expression profiles across follicular thyrorid carcinoma (FTC) samples; genes in this cluster correlated well with the presence of PAX8-PPARG [GeneID=7849;5468] fusion protein.
Full description | The demonstration of the PAX8-PPAR(gamma) fusion oncogene in a subset of follicular thyroid tumors provides a new and promising starting point to dissect the molecular genetic events involved in the development of this tumor form. In the present study, we compared the gene expression profiles of follicular thyroid carcinomas (FTCs) bearing a PAX8-PPAR(gamma) fusion against FTCs that lack this fusion. Using unsupervised clustering and multidimensional scaling analyses, we show that FTCs possessing a PAX8-PPAR(gamma) fusion have a highly uniform and distinct gene expression signature that clearly distinguishes them from FTCs without the fusion. The PAX8-PPAR(gamma)(+) FTCs grouped in a defined cluster, where highly ranked genes were mostly associated with signal transduction, cell growth and translation control. Notably, a large number of ribosomal protein and translation-associated genes were concurrently underexpressed in the FTCs with the fusion. Taken together, our findings further support that follicular carcinomas with a PAX8-PPAR(gamma) rearrangement constitute a distinct biological entity. The current data represent one step to elucidate the molecular pathways in the development of FTCs with the specific PAX8-PPAR(gamma) fusion.

Standard name | LUI_THYROID_CANCER_CLUSTER_4
Systematic name | M4333
Organism | Homo sapiens
PMID | 15608688
Authors | Lui WO,Foukakis T,Lidén J,Thoppe SR,Dwight T,Höög A,Zedenius J,Wallin G,Reimers M,Larsson C
Category | C2
Sub-category | CGP
Brief description | Cluster 4: genes with similar expression profiles across follicular thyroid carcinoma (FTC) samples.
Full description | The demonstration of the PAX8-PPAR(gamma) fusion oncogene in a subset of follicular thyroid tumors provides a new and promising starting point to dissect the molecular genetic events involved in the development of this tumor form. In the present study, we compared the gene expression profiles of follicular thyroid carcinomas (FTCs) bearing a PAX8-PPAR(gamma) fusion against FTCs that lack this fusion. Using unsupervised clustering and multidimensional scaling analyses, we show that FTCs possessing a PAX8-PPAR(gamma) fusion have a highly uniform and distinct gene expression signature that clearly distinguishes them from FTCs without the fusion. The PAX8-PPAR(gamma)(+) FTCs grouped in a defined cluster, where highly ranked genes were mostly associated with signal transduction, cell growth and translation control. Notably, a large number of ribosomal protein and translation-associated genes were concurrently underexpressed in the FTCs with the fusion. Taken together, our findings further support that follicular carcinomas with a PAX8-PPAR(gamma) rearrangement constitute a distinct biological entity. The current data represent one step to elucidate the molecular pathways in the development of FTCs with the specific PAX8-PPAR(gamma) fusion.

Standard name | LUI_THYROID_CANCER_CLUSTER_5
Systematic name | M13462
Organism | Homo sapiens
PMID | 15608688
Authors | Lui WO,Foukakis T,Lidén J,Thoppe SR,Dwight T,Höög A,Zedenius J,Wallin G,Reimers M,Larsson C
Category | C2
Sub-category | CGP
Brief description | Cluster 5: genes with similar expression profiles across follicular thyroid carcinoma (FTC) samples.
Full description | The demonstration of the PAX8-PPAR(gamma) fusion oncogene in a subset of follicular thyroid tumors provides a new and promising starting point to dissect the molecular genetic events involved in the development of this tumor form. In the present study, we compared the gene expression profiles of follicular thyroid carcinomas (FTCs) bearing a PAX8-PPAR(gamma) fusion against FTCs that lack this fusion. Using unsupervised clustering and multidimensional scaling analyses, we show that FTCs possessing a PAX8-PPAR(gamma) fusion have a highly uniform and distinct gene expression signature that clearly distinguishes them from FTCs without the fusion. The PAX8-PPAR(gamma)(+) FTCs grouped in a defined cluster, where highly ranked genes were mostly associated with signal transduction, cell growth and translation control. Notably, a large number of ribosomal protein and translation-associated genes were concurrently underexpressed in the FTCs with the fusion. Taken together, our findings further support that follicular carcinomas with a PAX8-PPAR(gamma) rearrangement constitute a distinct biological entity. The current data represent one step to elucidate the molecular pathways in the development of FTCs with the specific PAX8-PPAR(gamma) fusion.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_22
Systematic name | M11594
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 22: colocolized fragile sites and cancer genes in the 22q11.1-q13s region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_1
Systematic name | M5931
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 1: colocolized fragile sites and cancer genes in the Xp22.3-p11.1 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | MYLLYKANGAS_AMPLIFICATION_HOT_SPOT_13
Systematic name | M2750
Organism | Homo sapiens
PMID | 16751803
Authors | Myllykangas S,Himberg J,Böhling T,Nagy B,Hollmén J,Knuutila S
Category | C2
Sub-category | CGP
Brief description | Amplification hot spot 13: colocolized fragile sites and cancer genes in the Xq12-q28 region.
Full description | DNA copy number amplifications activate oncogenes and are hallmarks of nearly all advanced tumors. Amplified genes represent attractive targets for therapy, diagnostics and prognostics. To investigate DNA amplifications in different neoplasms, we performed a bibliomics survey using 838 published chromosomal comparative genomic hybridization studies and collected amplification data at chromosome band resolution from more than 4500 cases. Amplification profiles were determined for 73 distinct neoplasms. Neoplasms were clustered according to the amplification profiles, and frequently amplified chromosomal loci (amplification hot spots) were identified using computational modeling. To investigate the site specificity and mechanisms of gene amplifications, colocalization of amplification hot spots, cancer genes, fragile sites, virus integration sites and gene size cohorts were tested in a statistical framework. Amplification-based clustering demonstrated that cancers with similar etiology, cell-of-origin or topographical location have a tendency to obtain convergent amplification profiles. The identified amplification hot spots were colocalized with the known fragile sites, cancer genes and virus integration sites, but global statistical significance could not be ascertained. Large genes were significantly overrepresented on the fragile sites and the reported amplification hot spots. These findings indicate that amplifications are selected in the cancer tissue environment according to the qualitative traits and localization of cancer genes.

Standard name | GRASEMANN_RETINOBLASTOMA_WITH_6P_AMPLIFICATION
Systematic name | M14308
Organism | Homo sapiens
PMID | 16007192
Authors | Grasemann C,Gratias S,Stephan H,Schüler A,Schramm A,Klein-Hitpass L,Rieder H,Schneider S,Kappes F,Eggert A,Lohmann DR
Category | C2
Sub-category | CGP
Brief description | Genes changed in retinoblastoma tumors with respect to chromosome 6p amplifications.
Full description | The paediatric eye tumour retinoblastoma is initiated by inactivation of RB1, a tumour suppressor on chromosome 13q. In addition to RB1 loss, many retinoblastomas show other genetic alterations including gains on chromosomes 6p21-pter and 1q31-q32. Recently, the minimal region of gains on chromosome 6 was narrowed to band p22. We examined genomic gains and expression changes in primary retinoblastomas to identify potential target genes in 6p22. Quantitative multiplex PCR detected copy numbers > or = 3 in 25 (33%) tumours and no gains in 31 of 76 (40%) tumours. The remaining 20 (26%) samples showed gains only at some loci, most often including E2F3 and DEK in 6p22.3. Analysis of RNA from 21 primary retinoblastomas showed that expression levels of these and some other genes in 6p22 correspond to DNA gains. However, KIF 13A, a reported candidate oncogene on 6p, was expressed at low levels or absent. Clinical manifestation of tumours with gains at all 6p22 loci was distinct in that distribution of age at diagnosis was markedly shifted to older age compared to tumours with no or partial gains. In summary, our results suggest that DEK and E2F3 are potential targets of 6p gains in retinoblastoma.

Standard name | LUI_TARGETS_OF_PAX8_PPARG_FUSION
Systematic name | M13314
Organism | Homo sapiens
PMID | 15608688
Authors | Lui WO,Foukakis T,Lidén J,Thoppe SR,Dwight T,Höög A,Zedenius J,Wallin G,Reimers M,Larsson C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in follicular thyroid carcinoma (FTC) samples that bear PAX8-PPARG [GeneID=7849;5468] fusion protein.
Full description | The demonstration of the PAX8-PPAR(gamma) fusion oncogene in a subset of follicular thyroid tumors provides a new and promising starting point to dissect the molecular genetic events involved in the development of this tumor form. In the present study, we compared the gene expression profiles of follicular thyroid carcinomas (FTCs) bearing a PAX8-PPAR(gamma) fusion against FTCs that lack this fusion. Using unsupervised clustering and multidimensional scaling analyses, we show that FTCs possessing a PAX8-PPAR(gamma) fusion have a highly uniform and distinct gene expression signature that clearly distinguishes them from FTCs without the fusion. The PAX8-PPAR(gamma)(+) FTCs grouped in a defined cluster, where highly ranked genes were mostly associated with signal transduction, cell growth and translation control. Notably, a large number of ribosomal protein and translation-associated genes were concurrently underexpressed in the FTCs with the fusion. Taken together, our findings further support that follicular carcinomas with a PAX8-PPAR(gamma) rearrangement constitute a distinct biological entity. The current data represent one step to elucidate the molecular pathways in the development of FTCs with the specific PAX8-PPAR(gamma) fusion.

Standard name | SCHLOSSER_SERUM_RESPONSE_UP
Systematic name | M16381
Organism | Homo sapiens
PMID | 15516975
Authors | Schlosser I,Hölzel M,Hoffmann R,Burtscher H,Kohlhuber F,Schuhmacher M,Chapman R,Weidle UH,Eick D
Category | C2
Sub-category | CGP
Brief description | Cluster 1: genes up-regulated in B493-6 cells (B lymphocytes) upon serum stimulation but not by affected by MYC [GeneID=4609].
Full description | Proliferation of higher eukaryotic cells is triggered by the proto-oncogene c-myc (myc), which is induced downstream of a large number of growth factor receptors. Myc, a basic helix-loop-helix leucine zipper transcription factor, transmits growth signals by up- and downregulation of target genes. The importance of Myc in growth control is well established. However, the number of growth control genes requiring Myc as an essential factor for regulation after mitogenic stimulation of cells is not yet clear. Here, we have studied the transcriptional programme of a human B-cell line, P493-6, in response to Myc and serum. P493-6 cells do not express the endogenous myc, nor is it induced by serum stimulation. Proliferation of the cells is dependent upon both the expression of a tetracycline-regulated myc gene and serum stimulation. Using DNA microarrays, expression profiling was performed following stimulation of cells with serum, with Myc, or with both. We observed serum regulation of >1000 genes. A number of these genes were synergistically or antagonistically regulated by Myc. Moreover, we identified >300 Myc-regulated genes that were almost unresponsive to serum. Gene ontology analysis revealed that a high proportion of Myc target genes are involved in ribosome biogenesis and tRNA metabolism. The data support our current notion that Myc is essential for the regulation of a large number of growth-related genes in B cells, and cannot be replaced by other serum-induced factors.

Standard name | SCHLOSSER_SERUM_RESPONSE_AUGMENTED_BY_MYC
Systematic name | M15801
Organism | Homo sapiens
PMID | 15516975
Authors | Schlosser I,Hölzel M,Hoffmann R,Burtscher H,Kohlhuber F,Schuhmacher M,Chapman R,Weidle UH,Eick D
Category | C2
Sub-category | CGP
Brief description | Cluster 2: genes up-regulated in B493-6 cells (B lymphocytes) by serum alone or in combination with MYC [GeneID=4609] but not by MYC alone.
Full description | Proliferation of higher eukaryotic cells is triggered by the proto-oncogene c-myc (myc), which is induced downstream of a large number of growth factor receptors. Myc, a basic helix-loop-helix leucine zipper transcription factor, transmits growth signals by up- and downregulation of target genes. The importance of Myc in growth control is well established. However, the number of growth control genes requiring Myc as an essential factor for regulation after mitogenic stimulation of cells is not yet clear. Here, we have studied the transcriptional programme of a human B-cell line, P493-6, in response to Myc and serum. P493-6 cells do not express the endogenous myc, nor is it induced by serum stimulation. Proliferation of the cells is dependent upon both the expression of a tetracycline-regulated myc gene and serum stimulation. Using DNA microarrays, expression profiling was performed following stimulation of cells with serum, with Myc, or with both. We observed serum regulation of >1000 genes. A number of these genes were synergistically or antagonistically regulated by Myc. Moreover, we identified >300 Myc-regulated genes that were almost unresponsive to serum. Gene ontology analysis revealed that a high proportion of Myc target genes are involved in ribosome biogenesis and tRNA metabolism. The data support our current notion that Myc is essential for the regulation of a large number of growth-related genes in B cells, and cannot be replaced by other serum-induced factors.

Standard name | SCHLOSSER_MYC_AND_SERUM_RESPONSE_SYNERGY
Systematic name | M16789
Organism | Homo sapiens
PMID | 15516975
Authors | Schlosser I,Hölzel M,Hoffmann R,Burtscher H,Kohlhuber F,Schuhmacher M,Chapman R,Weidle UH,Eick D
Category | C2
Sub-category | CGP
Brief description | Cluster 3: genes strongly up-regulated in B493-6 cells (B lymphocytes) by a combination of MYC [GeneID=4609] and serum but not by each of them alone.
Full description | Proliferation of higher eukaryotic cells is triggered by the proto-oncogene c-myc (myc), which is induced downstream of a large number of growth factor receptors. Myc, a basic helix-loop-helix leucine zipper transcription factor, transmits growth signals by up- and downregulation of target genes. The importance of Myc in growth control is well established. However, the number of growth control genes requiring Myc as an essential factor for regulation after mitogenic stimulation of cells is not yet clear. Here, we have studied the transcriptional programme of a human B-cell line, P493-6, in response to Myc and serum. P493-6 cells do not express the endogenous myc, nor is it induced by serum stimulation. Proliferation of the cells is dependent upon both the expression of a tetracycline-regulated myc gene and serum stimulation. Using DNA microarrays, expression profiling was performed following stimulation of cells with serum, with Myc, or with both. We observed serum regulation of >1000 genes. A number of these genes were synergistically or antagonistically regulated by Myc. Moreover, we identified >300 Myc-regulated genes that were almost unresponsive to serum. Gene ontology analysis revealed that a high proportion of Myc target genes are involved in ribosome biogenesis and tRNA metabolism. The data support our current notion that Myc is essential for the regulation of a large number of growth-related genes in B cells, and cannot be replaced by other serum-induced factors.

Standard name | SCHLOSSER_MYC_TARGETS_REPRESSED_BY_SERUM
Systematic name | M5075
Organism | Homo sapiens
PMID | 15516975
Authors | Schlosser I,Hölzel M,Hoffmann R,Burtscher H,Kohlhuber F,Schuhmacher M,Chapman R,Weidle UH,Eick D
Category | C2
Sub-category | CGP
Brief description | Cluster 7: genes up-regulated in B493-6 cells (B lymphocytes) by MYC [GeneID=4609] and down-regulated by the combination of MYC and serum.
Full description | Proliferation of higher eukaryotic cells is triggered by the proto-oncogene c-myc (myc), which is induced downstream of a large number of growth factor receptors. Myc, a basic helix-loop-helix leucine zipper transcription factor, transmits growth signals by up- and downregulation of target genes. The importance of Myc in growth control is well established. However, the number of growth control genes requiring Myc as an essential factor for regulation after mitogenic stimulation of cells is not yet clear. Here, we have studied the transcriptional programme of a human B-cell line, P493-6, in response to Myc and serum. P493-6 cells do not express the endogenous myc, nor is it induced by serum stimulation. Proliferation of the cells is dependent upon both the expression of a tetracycline-regulated myc gene and serum stimulation. Using DNA microarrays, expression profiling was performed following stimulation of cells with serum, with Myc, or with both. We observed serum regulation of >1000 genes. A number of these genes were synergistically or antagonistically regulated by Myc. Moreover, we identified >300 Myc-regulated genes that were almost unresponsive to serum. Gene ontology analysis revealed that a high proportion of Myc target genes are involved in ribosome biogenesis and tRNA metabolism. The data support our current notion that Myc is essential for the regulation of a large number of growth-related genes in B cells, and cannot be replaced by other serum-induced factors.

Standard name | SCHLOSSER_MYC_TARGETS_AND_SERUM_RESPONSE_DN
Systematic name | M2138
Organism | Homo sapiens
PMID | 15516975
Authors | Schlosser I,Hölzel M,Hoffmann R,Burtscher H,Kohlhuber F,Schuhmacher M,Chapman R,Weidle UH,Eick D
Category | C2
Sub-category | CGP
Brief description | Cluster 6: genes down-regulated in B493-6 cells (B lymphocytes) by MYC [GeneID=4609] in combination with serum but not affected by serum alone; they are also up-regulated by MYC alone.
Full description | Proliferation of higher eukaryotic cells is triggered by the proto-oncogene c-myc (myc), which is induced downstream of a large number of growth factor receptors. Myc, a basic helix-loop-helix leucine zipper transcription factor, transmits growth signals by up- and downregulation of target genes. The importance of Myc in growth control is well established. However, the number of growth control genes requiring Myc as an essential factor for regulation after mitogenic stimulation of cells is not yet clear. Here, we have studied the transcriptional programme of a human B-cell line, P493-6, in response to Myc and serum. P493-6 cells do not express the endogenous myc, nor is it induced by serum stimulation. Proliferation of the cells is dependent upon both the expression of a tetracycline-regulated myc gene and serum stimulation. Using DNA microarrays, expression profiling was performed following stimulation of cells with serum, with Myc, or with both. We observed serum regulation of >1000 genes. A number of these genes were synergistically or antagonistically regulated by Myc. Moreover, we identified >300 Myc-regulated genes that were almost unresponsive to serum. Gene ontology analysis revealed that a high proportion of Myc target genes are involved in ribosome biogenesis and tRNA metabolism. The data support our current notion that Myc is essential for the regulation of a large number of growth-related genes in B cells, and cannot be replaced by other serum-induced factors.

Standard name | SCHLOSSER_MYC_TARGETS_AND_SERUM_RESPONSE_UP
Systematic name | M14278
Organism | Homo sapiens
PMID | 15516975
Authors | Schlosser I,Hölzel M,Hoffmann R,Burtscher H,Kohlhuber F,Schuhmacher M,Chapman R,Weidle UH,Eick D
Category | C2
Sub-category | CGP
Brief description | Cluster 5: genes up-regulated in B493-6 cells (B lymphocytes) by MYC [GeneID=4609] alone or in combination with serum but not by serum alone.
Full description | Proliferation of higher eukaryotic cells is triggered by the proto-oncogene c-myc (myc), which is induced downstream of a large number of growth factor receptors. Myc, a basic helix-loop-helix leucine zipper transcription factor, transmits growth signals by up- and downregulation of target genes. The importance of Myc in growth control is well established. However, the number of growth control genes requiring Myc as an essential factor for regulation after mitogenic stimulation of cells is not yet clear. Here, we have studied the transcriptional programme of a human B-cell line, P493-6, in response to Myc and serum. P493-6 cells do not express the endogenous myc, nor is it induced by serum stimulation. Proliferation of the cells is dependent upon both the expression of a tetracycline-regulated myc gene and serum stimulation. Using DNA microarrays, expression profiling was performed following stimulation of cells with serum, with Myc, or with both. We observed serum regulation of >1000 genes. A number of these genes were synergistically or antagonistically regulated by Myc. Moreover, we identified >300 Myc-regulated genes that were almost unresponsive to serum. Gene ontology analysis revealed that a high proportion of Myc target genes are involved in ribosome biogenesis and tRNA metabolism. The data support our current notion that Myc is essential for the regulation of a large number of growth-related genes in B cells, and cannot be replaced by other serum-induced factors.

Standard name | SCHLOSSER_SERUM_RESPONSE_DN
Systematic name | M1410
Organism | Homo sapiens
PMID | 15516975
Authors | Schlosser I,Hölzel M,Hoffmann R,Burtscher H,Kohlhuber F,Schuhmacher M,Chapman R,Weidle UH,Eick D
Category | C2
Sub-category | CGP
Brief description | Cluster 4: genes down-regulated in B493-6 cells (B lymphocytes) upon serum stimulation but not affected by MYC [GeneID=4609].
Full description | Proliferation of higher eukaryotic cells is triggered by the proto-oncogene c-myc (myc), which is induced downstream of a large number of growth factor receptors. Myc, a basic helix-loop-helix leucine zipper transcription factor, transmits growth signals by up- and downregulation of target genes. The importance of Myc in growth control is well established. However, the number of growth control genes requiring Myc as an essential factor for regulation after mitogenic stimulation of cells is not yet clear. Here, we have studied the transcriptional programme of a human B-cell line, P493-6, in response to Myc and serum. P493-6 cells do not express the endogenous myc, nor is it induced by serum stimulation. Proliferation of the cells is dependent upon both the expression of a tetracycline-regulated myc gene and serum stimulation. Using DNA microarrays, expression profiling was performed following stimulation of cells with serum, with Myc, or with both. We observed serum regulation of >1000 genes. A number of these genes were synergistically or antagonistically regulated by Myc. Moreover, we identified >300 Myc-regulated genes that were almost unresponsive to serum. Gene ontology analysis revealed that a high proportion of Myc target genes are involved in ribosome biogenesis and tRNA metabolism. The data support our current notion that Myc is essential for the regulation of a large number of growth-related genes in B cells, and cannot be replaced by other serum-induced factors.

Standard name | MATTIOLI_MULTIPLE_MYELOMA_SUBGROUPS
Systematic name | M15055
Organism | Homo sapiens
PMID | 15735737
Authors | Mattioli M,Agnelli L,Fabris S,Baldini L,Morabito F,Bicciato S,Verdelli D,Intini D,Nobili L,Cro L,Pruneri G,Callea V,Stelitano C,Maiolo AT,Lombardi L,Neri A
Category | C2
Sub-category | CGP
Brief description | Genes differentially expressed in multiple myeloma (MM) patients: comparison of MGUS-like vs PCL-like samples; MGUS=monoclonal gammopathy of undetermined significance, PCL=plasma cell leukemia.
Full description | Multiple myeloma (MM) is the most common form of plasma cell dyscrasia, characterized by a marked heterogeneity of genetic lesions and clinical course. It may develop from a premalignant condition (monoclonal gammopathy of undetermined significance, MGUS) or progress from intramedullary to extramedullary forms (plasma cell leukemia, PCL). To provide insights into the molecular characterization of plasma cell dyscrasias and to investigate the contribution of specific genetic lesions to the biological and clinical heterogeneity of MM, we analysed the gene expression profiles of plasma cells isolated from seven MGUS, 39 MM and six PCL patients by means of DNA microarrays. MMs resulted highly heterogeneous at transcriptional level, whereas the differential expression of genes mainly involved in DNA metabolism and proliferation distinguished MGUS from PCLs and the majority of MM cases. The clustering of MM patients was mainly driven by the presence of the most recurrent translocations involving the immunoglobulin heavy-chain locus. Distinct gene expression patterns have been found to be associated with different lesions: the overexpression of CCND2 and genes involved in cell adhesion pathways was observed in cases with deregulated MAF and MAFB, whereas genes upregulated in cases with the t(4;14) showed apoptosis-related functions. The peculiar finding in patients with the t(11;14) was the downregulation of the alpha-subunit of the IL-6 receptor. In addition, we identified a set of cancer germline antigens specifically expressed in a subgroup of MM patients characterized by an aggressive clinical evolution, a finding that could have implications for patient classification and immunotherapy.

Standard name | MATTIOLI_MULTIPLE_MYELOMA_WITH_14Q32_TRANSLOCATIONS
Systematic name | M18467
Organism | Homo sapiens
PMID | 15735737
Authors | Mattioli M,Agnelli L,Fabris S,Baldini L,Morabito F,Bicciato S,Verdelli D,Intini D,Nobili L,Cro L,Pruneri G,Callea V,Stelitano C,Maiolo AT,Lombardi L,Neri A
Category | C2
Sub-category | CGP
Brief description | Genes expressed in multiple myeloma (MM) patients carrying specific translocations involving the immunoglobulin heavy chain (IGH) locus at 14q32.
Full description | Multiple myeloma (MM) is the most common form of plasma cell dyscrasia, characterized by a marked heterogeneity of genetic lesions and clinical course. It may develop from a premalignant condition (monoclonal gammopathy of undetermined significance, MGUS) or progress from intramedullary to extramedullary forms (plasma cell leukemia, PCL). To provide insights into the molecular characterization of plasma cell dyscrasias and to investigate the contribution of specific genetic lesions to the biological and clinical heterogeneity of MM, we analysed the gene expression profiles of plasma cells isolated from seven MGUS, 39 MM and six PCL patients by means of DNA microarrays. MMs resulted highly heterogeneous at transcriptional level, whereas the differential expression of genes mainly involved in DNA metabolism and proliferation distinguished MGUS from PCLs and the majority of MM cases. The clustering of MM patients was mainly driven by the presence of the most recurrent translocations involving the immunoglobulin heavy-chain locus. Distinct gene expression patterns have been found to be associated with different lesions: the overexpression of CCND2 and genes involved in cell adhesion pathways was observed in cases with deregulated MAF and MAFB, whereas genes upregulated in cases with the t(4;14) showed apoptosis-related functions. The peculiar finding in patients with the t(11;14) was the downregulation of the alpha-subunit of the IL-6 receptor. In addition, we identified a set of cancer germline antigens specifically expressed in a subgroup of MM patients characterized by an aggressive clinical evolution, a finding that could have implications for patient classification and immunotherapy.

Standard name | FARMER_BREAST_CANCER_CLUSTER_1
Systematic name | M15015
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Cluster 1: interferon, T and B lymphocyte genes clustered together across breast cancer samples.
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | FARMER_BREAST_CANCER_CLUSTER_8
Systematic name | M7081
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Cluster 8: selected ERBB2 [GeneID=2064] amplicon genes clustered together across breast cancer samples.
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | FARMER_BREAST_CANCER_CLUSTER_7
Systematic name | M10394
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Cluster 7: selected apocrine and luminal genes clustered together across breast cancer samples.
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | FARMER_BREAST_CANCER_CLUSTER_2
Systematic name | M17333
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Cluster 2: selected proliferation and 8q amplicon genes clustered together across breast cancer samples.
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | ROSTY_CERVICAL_CANCER_PROLIFERATION_CLUSTER
Systematic name | M15664
Organism | Homo sapiens
PMID | 16007141
Authors | Rosty C,Sheffer M,Tsafrir D,Stransky N,Tsafrir I,Peter M,Crémoux de P,Rochefordière La de A,Salmon R,Dorval T,Thiery JP,Couturier J,Radvanyi F,Domany E,Sastre-Garau X
Category | C2
Sub-category | CGP
Brief description | The 'Cervical Cancer Proliferation Cluster' (CCPC): genes whose expression in cervical carcinoma positively correlates with that of the HPV E6 and E7 oncogenes; they are also differentially expressed according to disease outcome.
Full description | Specific HPV DNA sequences are associated with more than 90% of invasive carcinomas of the uterine cervix. Viral E6 and E7 oncogenes are key mediators in cell transformation by disrupting TP53 and RB pathways. To investigate molecular mechanisms involved in the progression of invasive cervical carcinoma, we performed a gene expression study on cases selected according to viral and clinical parameters. Using Coupled Two-Way Clustering and Sorting Points Into Neighbourhoods methods, we identified a 'cervical cancer proliferation cluster' composed of 163 highly correlated transcripts. Most of these transcripts corresponded to E2F pathway genes controlling cell division or proliferation, whereas none was known as TP53 primary target. The average expression level of the genes of this cluster was higher in tumours with an early relapse than in tumours with a favourable course (P = 0.026). Moreover, we found that E6/E7 mRNA expression level was positively correlated with the expression level of the cluster genes and with viral DNA load. These findings suggest that HPV E6/E7 expression level plays a key role in the progression of invasive carcinoma of the uterine cervix via the deregulation of cellular genes controlling tumour cell proliferation. HPV expression level may thus provide a biological marker useful for prognosis assessment and specific therapy of the disease.

Standard name | SCHEIDEREIT_IKK_INTERACTING_PROTEINS
Systematic name | M6303
Organism | Homo sapiens
PMID | 17072322
Authors | Scheidereit C
Category | C2
Sub-category | CGP
Brief description | Genes encoding IkappaB kinase (IKK) interacting proteins.
Full description | Transcription factors of the NF-kappaB family regulate hundreds of genes in the context of multiple important physiological and pathological processes. NF-kappaB activation depends on phosphorylation-induced proteolysis of inhibitory IkappaB molecules and NF-kappaB precursors by the ubiquitin-proteasome system. Most of the diverse signaling pathways that activate NF-kappaB converge on IkappaB kinases (IKK), which are essential for signal transmission. Many important details of the composition, regulation and biological function of IKK have been revealed in the last years. This review summarizes current aspects of structure and function of the regular stoichiometric components, the regulatory transient protein interactions of IKK and the mechanisms that contribute to its activation, deactivation and homeostasis. Both phosphorylation and ubiquitinatin (destructive as well as non-destructive) are crucial post-translational events in these processes. In addition to controlling induced IkappaB degradation in the cytoplasm and processing of the NF-kappaB precursor p100, nuclear IKK components have been found to act directly at the chromatin level of induced genes and to mediate responses to DNA damage. Finally, IKK is engaged in cross talk with other pathways and confers functions independently of NF-kappaB.

Standard name | JAERVINEN_AMPLIFIED_IN_LARYNGEAL_CANCER
Systematic name | M4988
Organism | Homo sapiens
PMID | 16715129
Authors | Järvinen AK,Autio R,Haapa-Paananen S,Wolf M,Saarela M,Grénman R,Leivo I,Kallioniemi O,Mäkitie AA,Monni O
Category | C2
Sub-category | CGP
Brief description | Genes whose expression was increased due to copy number gain in laryngeal cancer tumors (both in primary cultures and cell lines).
Full description | Molecular mechanisms contributing to initiation and progression of head and neck squamous cell carcinoma are still poorly known. Numerous genetic alterations have been described, but molecular consequences of such alterations in most cases remain unclear. Here, we performed an integrated high-resolution microarray analysis of gene copy number and expression in 20 laryngeal cancer cell lines and primary tumors. Our aim was to identify genetic alterations that play a key role in disease pathogenesis and pinpoint genes whose expression is directly impacted by these events. Integration of DNA level data from array-based comparative genomic hybridization with RNA level information from oligonucleotide microarrays was achieved with custom-developed bioinformatic methods. High-level amplifications had a clear impact on gene expression. Across the genome, overexpression of 739 genes could be attributed to gene amplification events in cell lines, with 325 genes showing the same phenomenon in primary tumors including FADD and PPFIA1 at 11q13. The analysis of gene ontology and pathway distributions further pinpointed genes that may identify potential targets of therapeutic intervention. Our data highlight genes that may be critically important to laryngeal cancer progression and offer potential therapeutic targets.

Standard name | HEIDENBLAD_AMPLIFIED_IN_SOFT_TISSUE_CANCER
Systematic name | M6364
Organism | Homo sapiens
PMID | 16732325
Authors | Heidenblad M,Hallor KH,Staaf J,Jönsson G,Borg A,Höglund M,Mertens F,Mandahl N
Category | C2
Sub-category | CGP
Brief description | Genes from selected recurrently amplified regions in soft tissue tumors with supernumerary ring chromosomes.
Full description | Ring chromosomes and/or giant marker chromosomes have been observed in a variety of human tumor types, but they are particularly common in a subgroup of mesenchymal tumors of low-grade or borderline malignancy. These rings and markers have been shown to contain amplified material predominantly from 12q13-15, but also sequences from other chromosomes. Such amplified sequences were mapped in detail by genome-wide array comparative genomic hybridization in ring-containing tumor samples from soft tissue (n = 15) and bone (n = 6), using tiling resolution microarrays, encompassing 32 433 bacterial artificial chromosome clones. The DNA copy number profiles revealed multiple amplification targets, in many cases highly discontinuous, leading to delineation of large numbers of very small amplicons. A total number of 356 (median size: 0.64 Mb) amplicons were seen in the soft tissue tumors and 90 (median size: 1.19 Mb) in the bone tumors. Notably, more than 40% of all amplicons in both soft tissue and bone tumors were mapped to chromosome 12, and at least one of the previously reported recurrent amplifications in 12q13.3-14.1 and 12q15.1, including SAS and CDK4, and MDM2, respectively, were present in 85% of the soft tissue tumors and in all of the bone tumors. Although chromosome 12 was the only chromosome displaying recurrent amplification in the bone tumors, the soft tissue tumors frequently showed recurrent amplicons mapping to other chromosomes, that is, 1p32, 1q23-24, 3p11-12, 6q24-25 and 20q11-12. Of particular interest, amplicons containing genes involved in the c-jun NH2-terminal kinase/mitogen-activated protein kinase pathway, that is, JUN in 1p32 and MAP3K7IP2 (TAB2) in 6q24-25, were found to be independently amplified in eight of 11 cases with 12q amplification, providing strong support for the notion that aberrant expression of this pathway is an important step in the dedifferentiation of liposarcomas.

Standard name | HEIDENBLAD_AMPLIFIED_IN_BONE_CANCER
Systematic name | M7870
Organism | Homo sapiens
PMID | 16732325
Authors | Heidenblad M,Hallor KH,Staaf J,Jönsson G,Borg A,Höglund M,Mertens F,Mandahl N
Category | C2
Sub-category | CGP
Brief description | Genes from selected recurrently amplified regions in bone tissue tumors with supernumerary ring chromosomes.
Full description | Ring chromosomes and/or giant marker chromosomes have been observed in a variety of human tumor types, but they are particularly common in a subgroup of mesenchymal tumors of low-grade or borderline malignancy. These rings and markers have been shown to contain amplified material predominantly from 12q13-15, but also sequences from other chromosomes. Such amplified sequences were mapped in detail by genome-wide array comparative genomic hybridization in ring-containing tumor samples from soft tissue (n = 15) and bone (n = 6), using tiling resolution microarrays, encompassing 32 433 bacterial artificial chromosome clones. The DNA copy number profiles revealed multiple amplification targets, in many cases highly discontinuous, leading to delineation of large numbers of very small amplicons. A total number of 356 (median size: 0.64 Mb) amplicons were seen in the soft tissue tumors and 90 (median size: 1.19 Mb) in the bone tumors. Notably, more than 40% of all amplicons in both soft tissue and bone tumors were mapped to chromosome 12, and at least one of the previously reported recurrent amplifications in 12q13.3-14.1 and 12q15.1, including SAS and CDK4, and MDM2, respectively, were present in 85% of the soft tissue tumors and in all of the bone tumors. Although chromosome 12 was the only chromosome displaying recurrent amplification in the bone tumors, the soft tissue tumors frequently showed recurrent amplicons mapping to other chromosomes, that is, 1p32, 1q23-24, 3p11-12, 6q24-25 and 20q11-12. Of particular interest, amplicons containing genes involved in the c-jun NH2-terminal kinase/mitogen-activated protein kinase pathway, that is, JUN in 1p32 and MAP3K7IP2 (TAB2) in 6q24-25, were found to be independently amplified in eight of 11 cases with 12q amplification, providing strong support for the notion that aberrant expression of this pathway is an important step in the dedifferentiation of liposarcomas.

Standard name | OHASHI_AURKA_TARGETS
Systematic name | M1180
Organism | Homo sapiens
PMID | 16785988
Authors | Ohashi S,Sakashita G,Ban R,Nagasawa M,Matsuzaki H,Murata Y,Taniguchi H,Shima H,Furukawa K,Urano T
Category | C2
Sub-category | CGP
Brief description | Candidate substrate proteins of AURKA [GeneID=6790].
Full description | Mammalian Aurora-A is related to a serine/threonine protein kinase that was originally identified by its close homology with Saccharomyces cerevisiae Ipl1p and Drosophila melanogaster aurora that are key regulators in the orchestration of mitotic events. The protein level of Aurora-A, its peak kinase activity during mitosis, and its activation have been attributed to phosphorylation. Here we show that this enzyme is an arginine-directed kinase and define its substrate specificity. We also found that Thr288 within the activation loop is a critical residue for activating phosphorylation events in vitro and that it is spatiotemporally restricted to a brief window at mitosis on duplicated centrosomes and on spindle microtubules proximal to the poles in vivo. Immunodepletion assays indicated that an upstream kinase(s) of Aurora-A might exist in mammalian cells in addition to autophosphorylation. Furthermore, human activated Aurora-A forms complexes with the negative regulator protein serine/threonine phosphatase type 1 (PP1) that was negatively phosphorylated on Thr320. Interestingly, phospho-specific Aurora-A monoclonal antibodies restrain Aurora-A kinase activity in vitro, providing further therapeutic avenues to explore.

Standard name | OHASHI_AURKB_TARGETS
Systematic name | M10867
Organism | Homo sapiens
PMID | 16785988
Authors | Ohashi S,Sakashita G,Ban R,Nagasawa M,Matsuzaki H,Murata Y,Taniguchi H,Shima H,Furukawa K,Urano T
Category | C2
Sub-category | CGP
Brief description | Candidate substrate proteins of AURKB [GeneID=9212].
Full description | Mammalian Aurora-A is related to a serine/threonine protein kinase that was originally identified by its close homology with Saccharomyces cerevisiae Ipl1p and Drosophila melanogaster aurora that are key regulators in the orchestration of mitotic events. The protein level of Aurora-A, its peak kinase activity during mitosis, and its activation have been attributed to phosphorylation. Here we show that this enzyme is an arginine-directed kinase and define its substrate specificity. We also found that Thr288 within the activation loop is a critical residue for activating phosphorylation events in vitro and that it is spatiotemporally restricted to a brief window at mitosis on duplicated centrosomes and on spindle microtubules proximal to the poles in vivo. Immunodepletion assays indicated that an upstream kinase(s) of Aurora-A might exist in mammalian cells in addition to autophosphorylation. Furthermore, human activated Aurora-A forms complexes with the negative regulator protein serine/threonine phosphatase type 1 (PP1) that was negatively phosphorylated on Thr320. Interestingly, phospho-specific Aurora-A monoclonal antibodies restrain Aurora-A kinase activity in vitro, providing further therapeutic avenues to explore.

Standard name | KOBAYASHI_RESPONSE_TO_ROMIDEPSIN
Systematic name | M3021
Organism | Homo sapiens
PMID | 16186804
Authors | Kobayashi Y,Ohtsuki M,Murakami T,Kobayashi T,Sutheesophon K,Kitayama H,Kano Y,Kusano E,Nakagawa H,Furukawa Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MM-LH cells (malignant melanoma) after treatment with the HDAC inhibitor romidepsin (FK228) [PubChem=5352062].
Full description | Histone deacetylase (HDAC) inhibitors are expected to be effective for refractory cancer because their mechanism of action differs from that of conventional antineoplastic agents. In this study, we examined the effect of the HDAC inhibitor FK228 on malignant melanoma, as well as its molecular mechanisms. FK228 was highly effective against melanoma compared with other commonly used drugs. By comparing the gene expression profiles of melanoma cells and normal melanocytes, we defined a subset of genes specifically upregulated in melanoma cells by FK228, which included Rap1, a small GTP-binding protein of the Ras family. The expression of Rap1 mRNA and protein increased in FK228-treated melanoma cells in both a dose- and a time-dependent manner. A decrease in the phosphorylation of c-Raf, MEK1/2, and ERK1/2 was accompanied by an increase in Rap1 expression in both FK228-treated and Rap1-overexpressing cells. Inhibition of Rap1 upregulation by small interfering RNA (siRNA) abrogated the induction of apoptosis and suppression of ERK1/2 phosphorylation in FK228-treated melanoma cells. These results indicate that the cytotoxic effects of FK228 are mediated via the upregulation of Rap1. Furthermore, we found that Rap1 was overexpressed and formed a complex with B-Raf in melanoma cell lines with a V599E mutation of B-Raf. The siRNA-mediated abrogation of Rap1 overexpression increased the viability of these cells, suggesting that Rap1 is also an endogenous regulator of Ras-MAP kinase signaling in melanomas.

Standard name | LA_MEN1_TARGETS
Systematic name | M1182
Organism | Mus musculus
PMID | 16449969
Authors | La P,Desmond A,Hou Z,Silva AC,Schnepp RW,Hua X
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in cells expressing MEN1 [GeneID=4221].
Full description | Menin is encoded by the tumor suppressor gene MEN1 that is mutated in patients with an inherited tumor syndrome, multiple endocrine neoplasia type 1 (MEN1). Although menin is a nuclear protein and directly binds to DNA through its nuclear localization signals (NLSs), the precise role for each of the NLSs in nuclear translocation and gene expression remains to be elucidated. Here, we show that point mutations in three individual NLSs, NLS1, NLS2, and a novel accessory NLS, NLSa, do not block nuclear translocation, but compromise the ability of menin to repress expression of the endogenous insulin-like growth factor binding protein-2 (IGFBP-2) gene. This repression is not released by an inhibitor of histone deacetylases. Although subtle mutations in menin NLSs do not affect menin association with chromatin, they abolish menin binding to the IGFBP-2 promoter in vivo. Furthermore, each of the NLSs is also crucial for menin-mediated induction of caspase 8 expression. Together, these results suggest that menin may act as a scaffold protein in coordinating activation and repression of gene transcription and that its NLSs play a more important role in controlling gene transcription than merely targeting menin into the nucleus.

Standard name | KOMMAGANI_TP63_GAMMA_TARGETS
Systematic name | M9630
Organism | Homo sapiens
PMID | 16462763
Authors | Kommagani R,Caserta TM,Kadakia MP
Category | C2
Sub-category | CGP
Brief description | Genes changed in H1299 cells (non-small cell lung cancer, NSCLC) transiently transfected to express the TP63 [GeneID=8626] gamma splice variant.
Full description | p63, a p53 homolog has been shown to play a role in development and cancer. p63 is essential for both commitment of ectoderm to stratified epithelia and for the proliferative potential of epithelial stem cells. p63 knockout mice are born with severe development defects and lack organs of epithelial origin. In addition, p63 has also been shown to play a role in cancer development through the differential regulation of genes with tumor suppressor function and genes involved in metastasis. In order to understand the role of p63 in cancer and development, genes that are specifically regulated by p63 but not p53 were identified. In this study, we provide evidence that p63gamma specifically upregulates vitamin D Receptor (VDR). In contrast, p53 does not appear to be involved in upregulation of VDR expression. Additionally, we demonstrate that a naturally occurring p63 missense mutant, p63gamma (R279H) and p14(ARF), both act in a dominant negative manner to inhibit p63gamma-mediated upregulation of VDR. Furthermore, using chromatin immunoprecipitation assays, we demonstrated that p63 directly binds to the VDR promoter in vivo. Our findings clearly demonstrate that VDR is a direct target of p63 and suggests that p63 may play a role in cancer and differentiation through modulation of the VDR pathway.

Standard name | LUND_SILENCED_BY_METHYLATION
Systematic name | M12026
Organism | Rattus norvegicus
PMID | 16568090
Authors | Lund P,Weisshaupt K,Mikeska T,Jammas D,Chen X,Kuban RJ,Ungethüm U,Krapfenbauer U,Herzel HP,Schäfer R,Walter J,Sers C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in FE-8 cells (fibroblasts) upon treatment with azacitidine [PubChem=9444].
Full description | Silencing of gene expression by methylation of CpG islands in regulatory elements is frequently observed in cancer. However, an influence of the most common oncogenic signalling pathways onto DNA methylation has not yet been investigated thoroughly. To address this issue, we identified genes suppressed in HRAS-transformed rat fibroblasts but upregulated after treatment with the demethylating agent 5-Aza-2-deoxycytidine and with the MEK1,2 inhibitor U0126. Analysis of gene expression by microarray and Northern blot analysis revealed the MEK/ERK target genes clusterin, matrix metalloproteinase 2 (Mmp2), peptidylpropyl isomerase C-associated protein, syndecan 4, Timp2 and Thbs1 to be repressed in the HRAS-transformed FE-8 cells in a MEK/ERK- and methylation-dependent manner. Hypermethylation of putative regulatory elements in HRAS-transformed cells as compared to immortalized fibroblasts was detected within a CpG island 14.5 kb upstream of clusterin, within the clusterin promoter and within a CpG island of the Mmp2 promoter by bisulphite sequencing. Furthermore, hypermethylation of the clusterin promoter was observed 10 days after induction of HRAS in immortalized rat fibroblasts and a clear correlation between reduced clusterin expression and hypermethlyation could also be observed in distinct rat tissues. These results suggest that silencing of individual genes by DNA methylation is controlled by oncogenic signalling pathways, yet the mechanisms responsible for initial target gene suppression are variable.

Standard name | HONRADO_BREAST_CANCER_BRCA1_VS_BRCA2
Systematic name | M9940
Organism | Homo sapiens
PMID | 16998498
Authors | Honrado E,Osorio A,Palacios J,Benitez J
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing between breast cancer tumors bearing mutations in BRCA1 [GeneID=672] and those with mutated BRCA2 [GeneID=675].
Full description | Tumors arising in BRCA1 and BRCA2 mutation carriers appear to have specific pathological and gene expression profiles, which show a high level of concordance. BRCA1 tumors are high-grade, negative for hormone receptors, have a high proliferation rate, and are positive for some cell cycle promoter genes. BRCA2 tumors present a phenotype opposite to BRCA1 tumors but very similar to sporadic tumors, except that BRCA2 overexpress some DNA repair markers such as CHEK2, show high cytoplasmic expression of RAD51, and are negative for HER-2 amplification and expression. Some of these characteristics have also been found in cDNA expression studies, although more analysis are necessary in order to obtain new markers that can be associated with a germ line mutation in BRCA1 or BRCA2. In this way, some studies in normal tissues of BRCA1/2 carriers suggest that differences exist in the level of expression of some genes when compared with noncarriers. Finally, IHC studies in tumors carrying a mutation in CHEK2 are rare and show contradictory results, probably due to the low number of these cases. However, they represent an example showing how different mutations of the same gene may be associated with specific histological subtypes of cancer.

Standard name | BOWIE_RESPONSE_TO_EXTRACELLULAR_MATRIX
Systematic name | M6162
Organism | Homo sapiens
PMID | 17016442
Authors | Bowie ML,Troch MM,Delrow J,Dietze EC,Bean GR,Ibarra C,Pandiyan G,Seewaldt VL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by growing HMEC-E6 cells (mammary epithelial cells damaged by expression of HPV-16 E6 [GeneID=1489078]) in extracellular matrix (ECM).
Full description | Interactions between extracellular matrix (ECM) and mammary epithelial cells are critical for mammary gland homeostasis and apoptotic signaling. Interferon regulatory factor-1 (IRF-1) is a transcriptional regulator that promotes apoptosis during mammary gland involution and p53-independent apoptosis. We have recently shown that rapid cell surface tamoxifen (Tam) signaling promotes apoptosis in normal human mammary epithelial cells that were acutely damaged by expression of human papillomavirus type-16 E6 protein (*HMEC-E6). Apoptosis was mediated by recruitment of CREB-binding protein (CBP) to the gamma-activating sequence (GAS) element of the IRF-1 promoter, induction of IRF-1 and caspase-1/-3 activation. Here, we show that growth factor-depleted, reconstituted ECM (rECM), similar to Tam, promotes apoptosis in *HMEC-E6 cells through induction of IRF-1. Apoptosis was temporally associated with recruitment of CBP to the GAS element of the IRF-1 promoter, induction of IRF-1 expression and caspase-1/-3 activation. Small interfering RNA-mediated suppression of IRF-1 protein expression in *HMEC-E6 cells blocked (1) induction of IRF-1, (2) caspase-1/-3 activation and (3) apoptosis. These observations demonstrate that IRF-1 promotes rECM-mediated apoptosis and provide evidence that both rECM and rapid Tam signaling transcriptionally activate IRF-1 through recruitment of CBP to the IRF-1 GAS promoter complex.

Standard name | BOWIE_RESPONSE_TO_TAMOXIFEN
Systematic name | M3283
Organism | Homo sapiens
PMID | 17016442
Authors | Bowie ML,Troch MM,Delrow J,Dietze EC,Bean GR,Ibarra C,Pandiyan G,Seewaldt VL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by tamoxifen [PubChem=5376] in HMEC-E6 cells (mammary epithelial cells damaged by expression of HPV-16 E6 [GeneID=1489078]).
Full description | Interactions between extracellular matrix (ECM) and mammary epithelial cells are critical for mammary gland homeostasis and apoptotic signaling. Interferon regulatory factor-1 (IRF-1) is a transcriptional regulator that promotes apoptosis during mammary gland involution and p53-independent apoptosis. We have recently shown that rapid cell surface tamoxifen (Tam) signaling promotes apoptosis in normal human mammary epithelial cells that were acutely damaged by expression of human papillomavirus type-16 E6 protein (*HMEC-E6). Apoptosis was mediated by recruitment of CREB-binding protein (CBP) to the gamma-activating sequence (GAS) element of the IRF-1 promoter, induction of IRF-1 and caspase-1/-3 activation. Here, we show that growth factor-depleted, reconstituted ECM (rECM), similar to Tam, promotes apoptosis in *HMEC-E6 cells through induction of IRF-1. Apoptosis was temporally associated with recruitment of CBP to the GAS element of the IRF-1 promoter, induction of IRF-1 expression and caspase-1/-3 activation. Small interfering RNA-mediated suppression of IRF-1 protein expression in *HMEC-E6 cells blocked (1) induction of IRF-1, (2) caspase-1/-3 activation and (3) apoptosis. These observations demonstrate that IRF-1 promotes rECM-mediated apoptosis and provide evidence that both rECM and rapid Tam signaling transcriptionally activate IRF-1 through recruitment of CBP to the IRF-1 GAS promoter complex.

Standard name | AIYAR_COBRA1_TARGETS_UP
Systematic name | M17074
Organism | Homo sapiens
PMID | 17043641
Authors | Aiyar SE,Blair AL,Hopkinson DA,Bekiranov S,Li R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T47D cells (breast cancer) after COBRA1 [GeneID=25920] knockdown by RNAi.
Full description | Eucaryotic genes that are coordinately expressed tend to be clustered. Furthermore, gene clusters across chromosomal regions are often upregulated in various tumors. However, relatively little is known about how gene clusters are coordinately expressed in physiological or pathological conditions. Cofactor of BRCA1 (COBRA1), a subunit of the human negative elongation factor, has been shown to repress estrogen-stimulated transcription of trefoil factor 1 (TFF1 or pS2) by stalling RNA polymerase II. Here, we carried out a genome-wide study to identify additional physiological target genes of COBRA1 in breast cancer cells. The study identified a total of 134 genes that were either activated or repressed upon small hairpin RNA-mediated reduction of COBRA1. Interestingly, many COBRA1-regulated genes reside as clusters on the chromosomes and have been previously implicated in cancer development. Detailed examination of two such clusters on chromosome 21 (21q22) and chromosome X (Xp11) reveals that COBRA1 is physically associated with a subset of its regulated genes in each cluster. In addition, COBRA1 was shown to regulate both estrogen-dependent and -independent transcription of the gene cluster at 21q22, which encompasses the previously identified COBRA1-regulated TFF1 (pS2) locus. Thus, COBRA1 plays a critical role in the regulation of clustered gene expression at preferred chromosomal domains in breast cancer cells.

Standard name | AIYAR_COBRA1_TARGETS_DN
Systematic name | M13606
Organism | Homo sapiens
PMID | 17043641
Authors | Aiyar SE,Blair AL,Hopkinson DA,Bekiranov S,Li R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T47D cells (breast cancer) after COBRA1 [GeneID=25920] knockdown by RNAi.
Full description | Eucaryotic genes that are coordinately expressed tend to be clustered. Furthermore, gene clusters across chromosomal regions are often upregulated in various tumors. However, relatively little is known about how gene clusters are coordinately expressed in physiological or pathological conditions. Cofactor of BRCA1 (COBRA1), a subunit of the human negative elongation factor, has been shown to repress estrogen-stimulated transcription of trefoil factor 1 (TFF1 or pS2) by stalling RNA polymerase II. Here, we carried out a genome-wide study to identify additional physiological target genes of COBRA1 in breast cancer cells. The study identified a total of 134 genes that were either activated or repressed upon small hairpin RNA-mediated reduction of COBRA1. Interestingly, many COBRA1-regulated genes reside as clusters on the chromosomes and have been previously implicated in cancer development. Detailed examination of two such clusters on chromosome 21 (21q22) and chromosome X (Xp11) reveals that COBRA1 is physically associated with a subset of its regulated genes in each cluster. In addition, COBRA1 was shown to regulate both estrogen-dependent and -independent transcription of the gene cluster at 21q22, which encompasses the previously identified COBRA1-regulated TFF1 (pS2) locus. Thus, COBRA1 plays a critical role in the regulation of clustered gene expression at preferred chromosomal domains in breast cancer cells.

Standard name | LI_CISPLATIN_RESISTANCE_DN
Systematic name | M10150
Organism | Homo sapiens
PMID | 17072341
Authors | Li J,Wood WH 3rd,Becker KG,Weeraratna AT,Morin PJ
Category | C2
Sub-category | CGP
Brief description | Genes consistently down-regulated in ACRP cells (ovarian cancer, resistant to cisplatin [PubChem=2767]) compared to the parental sensitive A2780 cells, regardless of cisplatin exposure.
Full description | The molecular pathways activated in response to acute cisplatin exposure, as well as the mechanisms involved in the long-term development of cisplatin-resistant cancer cells remain unclear. Using whole genome oligonucleotide microarrays, we have examined the kinetics of gene expression changes in a cisplatin-sensitive cell line, A2780, and its cisplatin-resistant derivative, ACRP. Both sensitive and resistant cell lines exhibited a very similar response of p53-inducible genes as early as 16 h after treatment. This p53 response was further increased at the 24-h time point. These experiments identify p53 as the main pathway producing a large-scale transcriptional response after cisplatin treatment in these cells containing wild-type p53. Consistent with a role for the p53 response in cisplatin sensitivity, knockdown of the p53 protein with small interfering RNA led to a twofold decrease in cell survival in the resistant cells. In addition, our analysis also allowed the identification of several genes that are differentially expressed between sensitive and resistant cells. These genes include GJA1 (encoding connexin 43 (Cx43)) and TWIST1, which are highly upregulated in cisplatin-resistant cells. The importance of Cx43 in drug resistance was demonstrated through functional analyses, although paradoxically, inhibition of Cx43 function in high expressing cells led to an increase in drug resistance. The pathways important in cisplatin response, as well as the genes found differentially expressed between cisplatin-resistant and -sensitive cells, may represent targets for therapy aimed at reversing drug resistance.

Standard name | LI_CISPLATIN_RESISTANCE_UP
Systematic name | M4717
Organism | Homo sapiens
PMID | 17072341
Authors | Li J,Wood WH 3rd,Becker KG,Weeraratna AT,Morin PJ
Category | C2
Sub-category | CGP
Brief description | Genes consistently up-regulated in ACRP cells (ovarian cancer, resistant to cisplatin [PubChem=2767]) compared to the parental sensitive A2780 cells, regardless of cisplatin exposure.
Full description | The molecular pathways activated in response to acute cisplatin exposure, as well as the mechanisms involved in the long-term development of cisplatin-resistant cancer cells remain unclear. Using whole genome oligonucleotide microarrays, we have examined the kinetics of gene expression changes in a cisplatin-sensitive cell line, A2780, and its cisplatin-resistant derivative, ACRP. Both sensitive and resistant cell lines exhibited a very similar response of p53-inducible genes as early as 16 h after treatment. This p53 response was further increased at the 24-h time point. These experiments identify p53 as the main pathway producing a large-scale transcriptional response after cisplatin treatment in these cells containing wild-type p53. Consistent with a role for the p53 response in cisplatin sensitivity, knockdown of the p53 protein with small interfering RNA led to a twofold decrease in cell survival in the resistant cells. In addition, our analysis also allowed the identification of several genes that are differentially expressed between sensitive and resistant cells. These genes include GJA1 (encoding connexin 43 (Cx43)) and TWIST1, which are highly upregulated in cisplatin-resistant cells. The importance of Cx43 in drug resistance was demonstrated through functional analyses, although paradoxically, inhibition of Cx43 function in high expressing cells led to an increase in drug resistance. The pathways important in cisplatin response, as well as the genes found differentially expressed between cisplatin-resistant and -sensitive cells, may represent targets for therapy aimed at reversing drug resistance.

Standard name | HERNANDEZ_ABERRANT_MITOSIS_BY_DOCETACEL_4NM_UP
Systematic name | M1184
Organism | Homo sapiens
PMID | 17099726
Authors | Hernández-Vargas H,Palacios J,Moreno-Bueno G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer, normal TP53 [GeneID=7157]) undergoing aberrant mitosis and necrosis after treatment wiht 4 nM docetaxel [PubChem=148124].
Full description | Among microtubule-targeting agents, docetaxel has received recent interest owing to its good therapeutic index. Clinical trials have underlined its potential for the treatment of advanced breast cancer, although little is known about its molecular mode of action in this context. We characterized the molecular changes induced by docetaxel in two well-known human breast carcinoma cell lines. Two mechanisms of action according to drug concentration were suggested by a biphasic sensitivity curve, and were further validated by cell morphology, cell cycle and cell death changes. Two to four nanomolar docetaxel induced aberrant mitosis followed by late necrosis, and 100 nM docetaxel induced mitotic arrest followed by apoptosis. Passing through mitosis phase was a requirement for hypodiploidy to occur, as shown by functional studies in synchronized cells and by combining docetaxel with the proteasome inhibitor MG132. Transcriptional profiling showed differences according to cell line and docetaxel concentration, with cell cycle, cell death and structural genes commonly regulated in both cell lines. Although p53 targets were mainly induced with low concentration of drug in MCF7 cells, its relevance in the dual mechanism of docetaxel cytotoxicity was ruled out by using an isogenic shp53 cell line. Many of the genes shown in this study may contribute to the dual mechanism by which docetaxel inhibits the growth of breast cancer cells at different concentrations. These findings provide a basis for rationally enhancing docetaxel therapy, considering lower concentrations, and better drug combinations.

Standard name | HERNANDEZ_ABERRANT_MITOSIS_BY_DOCETACEL_4NM_DN
Systematic name | M1185
Organism | Homo sapiens
PMID | 17099726
Authors | Hernández-Vargas H,Palacios J,Moreno-Bueno G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer, normal TP53 [GeneID=7157]) undergoing aberrant mitosis and necrosis after treatment wiht 4 nM docetaxel [PubChem=148124].
Full description | Among microtubule-targeting agents, docetaxel has received recent interest owing to its good therapeutic index. Clinical trials have underlined its potential for the treatment of advanced breast cancer, although little is known about its molecular mode of action in this context. We characterized the molecular changes induced by docetaxel in two well-known human breast carcinoma cell lines. Two mechanisms of action according to drug concentration were suggested by a biphasic sensitivity curve, and were further validated by cell morphology, cell cycle and cell death changes. Two to four nanomolar docetaxel induced aberrant mitosis followed by late necrosis, and 100 nM docetaxel induced mitotic arrest followed by apoptosis. Passing through mitosis phase was a requirement for hypodiploidy to occur, as shown by functional studies in synchronized cells and by combining docetaxel with the proteasome inhibitor MG132. Transcriptional profiling showed differences according to cell line and docetaxel concentration, with cell cycle, cell death and structural genes commonly regulated in both cell lines. Although p53 targets were mainly induced with low concentration of drug in MCF7 cells, its relevance in the dual mechanism of docetaxel cytotoxicity was ruled out by using an isogenic shp53 cell line. Many of the genes shown in this study may contribute to the dual mechanism by which docetaxel inhibits the growth of breast cancer cells at different concentrations. These findings provide a basis for rationally enhancing docetaxel therapy, considering lower concentrations, and better drug combinations.

Standard name | HERNANDEZ_MITOTIC_ARREST_BY_DOCETAXEL_1_UP
Systematic name | M1186
Organism | Homo sapiens
PMID | 17099726
Authors | Hernández-Vargas H,Palacios J,Moreno-Bueno G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer, normal TP53 [GeneID=7157]) undergoing mitotic arrest and apoptosis after treatment with 100 nM docetaxel [PubChem=148124].
Full description | Among microtubule-targeting agents, docetaxel has received recent interest owing to its good therapeutic index. Clinical trials have underlined its potential for the treatment of advanced breast cancer, although little is known about its molecular mode of action in this context. We characterized the molecular changes induced by docetaxel in two well-known human breast carcinoma cell lines. Two mechanisms of action according to drug concentration were suggested by a biphasic sensitivity curve, and were further validated by cell morphology, cell cycle and cell death changes. Two to four nanomolar docetaxel induced aberrant mitosis followed by late necrosis, and 100 nM docetaxel induced mitotic arrest followed by apoptosis. Passing through mitosis phase was a requirement for hypodiploidy to occur, as shown by functional studies in synchronized cells and by combining docetaxel with the proteasome inhibitor MG132. Transcriptional profiling showed differences according to cell line and docetaxel concentration, with cell cycle, cell death and structural genes commonly regulated in both cell lines. Although p53 targets were mainly induced with low concentration of drug in MCF7 cells, its relevance in the dual mechanism of docetaxel cytotoxicity was ruled out by using an isogenic shp53 cell line. Many of the genes shown in this study may contribute to the dual mechanism by which docetaxel inhibits the growth of breast cancer cells at different concentrations. These findings provide a basis for rationally enhancing docetaxel therapy, considering lower concentrations, and better drug combinations.

Standard name | HERNANDEZ_MITOTIC_ARREST_BY_DOCETAXEL_1_DN
Systematic name | M1187
Organism | Homo sapiens
PMID | 17099726
Authors | Hernández-Vargas H,Palacios J,Moreno-Bueno G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer, normal TP53 [GeneID=7157]) undergoing mitotic arrest and apoptosis after treatment with 100 nM docetaxel [PubChem=148124].
Full description | Among microtubule-targeting agents, docetaxel has received recent interest owing to its good therapeutic index. Clinical trials have underlined its potential for the treatment of advanced breast cancer, although little is known about its molecular mode of action in this context. We characterized the molecular changes induced by docetaxel in two well-known human breast carcinoma cell lines. Two mechanisms of action according to drug concentration were suggested by a biphasic sensitivity curve, and were further validated by cell morphology, cell cycle and cell death changes. Two to four nanomolar docetaxel induced aberrant mitosis followed by late necrosis, and 100 nM docetaxel induced mitotic arrest followed by apoptosis. Passing through mitosis phase was a requirement for hypodiploidy to occur, as shown by functional studies in synchronized cells and by combining docetaxel with the proteasome inhibitor MG132. Transcriptional profiling showed differences according to cell line and docetaxel concentration, with cell cycle, cell death and structural genes commonly regulated in both cell lines. Although p53 targets were mainly induced with low concentration of drug in MCF7 cells, its relevance in the dual mechanism of docetaxel cytotoxicity was ruled out by using an isogenic shp53 cell line. Many of the genes shown in this study may contribute to the dual mechanism by which docetaxel inhibits the growth of breast cancer cells at different concentrations. These findings provide a basis for rationally enhancing docetaxel therapy, considering lower concentrations, and better drug combinations.

Standard name | HERNANDEZ_ABERRANT_MITOSIS_BY_DOCETACEL_2NM_UP
Systematic name | M1188
Organism | Homo sapiens
PMID | 17099726
Authors | Hernández-Vargas H,Palacios J,Moreno-Bueno G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MDA-MB-231 cells (breast cancer, mutated TP53 [GeneID=7157]) undergoing aberrant mitosis and necrosis after treatment with 2 nM docetaxel [PubChem=148124].
Full description | Among microtubule-targeting agents, docetaxel has received recent interest owing to its good therapeutic index. Clinical trials have underlined its potential for the treatment of advanced breast cancer, although little is known about its molecular mode of action in this context. We characterized the molecular changes induced by docetaxel in two well-known human breast carcinoma cell lines. Two mechanisms of action according to drug concentration were suggested by a biphasic sensitivity curve, and were further validated by cell morphology, cell cycle and cell death changes. Two to four nanomolar docetaxel induced aberrant mitosis followed by late necrosis, and 100 nM docetaxel induced mitotic arrest followed by apoptosis. Passing through mitosis phase was a requirement for hypodiploidy to occur, as shown by functional studies in synchronized cells and by combining docetaxel with the proteasome inhibitor MG132. Transcriptional profiling showed differences according to cell line and docetaxel concentration, with cell cycle, cell death and structural genes commonly regulated in both cell lines. Although p53 targets were mainly induced with low concentration of drug in MCF7 cells, its relevance in the dual mechanism of docetaxel cytotoxicity was ruled out by using an isogenic shp53 cell line. Many of the genes shown in this study may contribute to the dual mechanism by which docetaxel inhibits the growth of breast cancer cells at different concentrations. These findings provide a basis for rationally enhancing docetaxel therapy, considering lower concentrations, and better drug combinations.

Standard name | HERNANDEZ_ABERRANT_MITOSIS_BY_DOCETACEL_2NM_DN
Systematic name | M1191
Organism | Homo sapiens
PMID | 17099726
Authors | Hernández-Vargas H,Palacios J,Moreno-Bueno G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MDA-MB-231 cells (breast cancer, mutated TP53 [GeneID=7157]) undergoing aberrant mitosis and necrosis after treatment with 2 nM docetaxel [PubChem=148124].
Full description | Among microtubule-targeting agents, docetaxel has received recent interest owing to its good therapeutic index. Clinical trials have underlined its potential for the treatment of advanced breast cancer, although little is known about its molecular mode of action in this context. We characterized the molecular changes induced by docetaxel in two well-known human breast carcinoma cell lines. Two mechanisms of action according to drug concentration were suggested by a biphasic sensitivity curve, and were further validated by cell morphology, cell cycle and cell death changes. Two to four nanomolar docetaxel induced aberrant mitosis followed by late necrosis, and 100 nM docetaxel induced mitotic arrest followed by apoptosis. Passing through mitosis phase was a requirement for hypodiploidy to occur, as shown by functional studies in synchronized cells and by combining docetaxel with the proteasome inhibitor MG132. Transcriptional profiling showed differences according to cell line and docetaxel concentration, with cell cycle, cell death and structural genes commonly regulated in both cell lines. Although p53 targets were mainly induced with low concentration of drug in MCF7 cells, its relevance in the dual mechanism of docetaxel cytotoxicity was ruled out by using an isogenic shp53 cell line. Many of the genes shown in this study may contribute to the dual mechanism by which docetaxel inhibits the growth of breast cancer cells at different concentrations. These findings provide a basis for rationally enhancing docetaxel therapy, considering lower concentrations, and better drug combinations.

Standard name | HERNANDEZ_MITOTIC_ARREST_BY_DOCETAXEL_2_UP
Systematic name | M1192
Organism | Homo sapiens
PMID | 17099726
Authors | Hernández-Vargas H,Palacios J,Moreno-Bueno G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MDA-MB-231 cells (breast cancer, mutated TP53 [GeneID=7157]) undergoing mitotic arrest and apoptosis after treatment with 100 nM docetaxel [PubChem=148124].
Full description | Among microtubule-targeting agents, docetaxel has received recent interest owing to its good therapeutic index. Clinical trials have underlined its potential for the treatment of advanced breast cancer, although little is known about its molecular mode of action in this context. We characterized the molecular changes induced by docetaxel in two well-known human breast carcinoma cell lines. Two mechanisms of action according to drug concentration were suggested by a biphasic sensitivity curve, and were further validated by cell morphology, cell cycle and cell death changes. Two to four nanomolar docetaxel induced aberrant mitosis followed by late necrosis, and 100 nM docetaxel induced mitotic arrest followed by apoptosis. Passing through mitosis phase was a requirement for hypodiploidy to occur, as shown by functional studies in synchronized cells and by combining docetaxel with the proteasome inhibitor MG132. Transcriptional profiling showed differences according to cell line and docetaxel concentration, with cell cycle, cell death and structural genes commonly regulated in both cell lines. Although p53 targets were mainly induced with low concentration of drug in MCF7 cells, its relevance in the dual mechanism of docetaxel cytotoxicity was ruled out by using an isogenic shp53 cell line. Many of the genes shown in this study may contribute to the dual mechanism by which docetaxel inhibits the growth of breast cancer cells at different concentrations. These findings provide a basis for rationally enhancing docetaxel therapy, considering lower concentrations, and better drug combinations.

Standard name | HERNANDEZ_MITOTIC_ARREST_BY_DOCETAXEL_2_DN
Systematic name | M1193
Organism | Homo sapiens
PMID | 17099726
Authors | Hernández-Vargas H,Palacios J,Moreno-Bueno G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MDA-MB-231 cells (breast cancer, mutated TP53 [GeneID=7157]) undergoing mitotic arrest and apoptosis after treatment with 100 nM docetaxel [PubChem=148124].
Full description | Among microtubule-targeting agents, docetaxel has received recent interest owing to its good therapeutic index. Clinical trials have underlined its potential for the treatment of advanced breast cancer, although little is known about its molecular mode of action in this context. We characterized the molecular changes induced by docetaxel in two well-known human breast carcinoma cell lines. Two mechanisms of action according to drug concentration were suggested by a biphasic sensitivity curve, and were further validated by cell morphology, cell cycle and cell death changes. Two to four nanomolar docetaxel induced aberrant mitosis followed by late necrosis, and 100 nM docetaxel induced mitotic arrest followed by apoptosis. Passing through mitosis phase was a requirement for hypodiploidy to occur, as shown by functional studies in synchronized cells and by combining docetaxel with the proteasome inhibitor MG132. Transcriptional profiling showed differences according to cell line and docetaxel concentration, with cell cycle, cell death and structural genes commonly regulated in both cell lines. Although p53 targets were mainly induced with low concentration of drug in MCF7 cells, its relevance in the dual mechanism of docetaxel cytotoxicity was ruled out by using an isogenic shp53 cell line. Many of the genes shown in this study may contribute to the dual mechanism by which docetaxel inhibits the growth of breast cancer cells at different concentrations. These findings provide a basis for rationally enhancing docetaxel therapy, considering lower concentrations, and better drug combinations.

Standard name | XU_HGF_SIGNALING_NOT_VIA_AKT1_6HR
Systematic name | M6840
Organism | Homo sapiens
PMID | 17099727
Authors | Xu J,Gao M,Fan S,Meng Q,Goldberg ID,Abounader R,Ressom H,Laterra JJ,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes changed similarly in DU-145 cells (prostate cancer) in the absence and presence of a dominant negative form of AKT1 [GeneID=207] upon exposure to HGF [GeneID=3082] for 6 h.
Full description | The cytokine scatter factor (SF) (hepatocyte growth factor) transduces various biologic actions, including cell motility, invasion, angiogenesis and apoptosis inhibition. The latter is relevant to understanding the role of SF in promoting tumor cell survival in different contexts, for example, detachment from basement membrane, growth in metastatic sites and responses to chemo- and radiotherapy. Previously, we showed that SF protects cells against apoptosis owing to DNA damage, by a mechanism involving phosphoinositol-3-kinase/c-Akt signaling. Here, we used DNA microarray assays to identify c-Akt-regulated genes that might contribute to cell protection. DU-145 human prostate cancer cells were transfected+/-a dominant-negative mutant Akt, treated+/-SF and analysed for gene expression using Affymetrix arrays. These studies identified SF-regulated genes for which induction was c-Akt-dependent vs -independent. Selected microarray findings were confirmed by semiquantitative and quantitative reverse transcription-polymerase chain reaction. We tested the contribution of four SF-inducible/c-Akt-dependent genes (AMPD3, EPHB2, MX1 and WNT4) to protection against adriamycin (a DNA topoisomerase IIalpha inhibitor) using RNA interference. Knockdown of each gene except EPHB2 caused a small but significant reduction in the SF cell protection. The lack of effect of EPHB2 knockdown may be due to the fact that DU-145 cells contain a single-mutant EPHB2 allele. A combination of three small interfering RNAs blocked most of the protection by SF in both DU-145 and T47D cells. These findings identify novel c-Akt-regulated genes, some of which contribute to SF-mediated cytoprotection.

Standard name | XU_HGF_TARGETS_INDUCED_BY_AKT1_6HR
Systematic name | M18356
Organism | Homo sapiens
PMID | 17099727
Authors | Xu J,Gao M,Fan S,Meng Q,Goldberg ID,Abounader R,Ressom H,Laterra JJ,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes changed in DU-145 cells (prostate cancer) in the absence but not presence of a dominant negative form of AKT1 [GeneID=207] upon exposure to HGF [GeneID=3082] for 6 h.
Full description | The cytokine scatter factor (SF) (hepatocyte growth factor) transduces various biologic actions, including cell motility, invasion, angiogenesis and apoptosis inhibition. The latter is relevant to understanding the role of SF in promoting tumor cell survival in different contexts, for example, detachment from basement membrane, growth in metastatic sites and responses to chemo- and radiotherapy. Previously, we showed that SF protects cells against apoptosis owing to DNA damage, by a mechanism involving phosphoinositol-3-kinase/c-Akt signaling. Here, we used DNA microarray assays to identify c-Akt-regulated genes that might contribute to cell protection. DU-145 human prostate cancer cells were transfected+/-a dominant-negative mutant Akt, treated+/-SF and analysed for gene expression using Affymetrix arrays. These studies identified SF-regulated genes for which induction was c-Akt-dependent vs -independent. Selected microarray findings were confirmed by semiquantitative and quantitative reverse transcription-polymerase chain reaction. We tested the contribution of four SF-inducible/c-Akt-dependent genes (AMPD3, EPHB2, MX1 and WNT4) to protection against adriamycin (a DNA topoisomerase IIalpha inhibitor) using RNA interference. Knockdown of each gene except EPHB2 caused a small but significant reduction in the SF cell protection. The lack of effect of EPHB2 knockdown may be due to the fact that DU-145 cells contain a single-mutant EPHB2 allele. A combination of three small interfering RNAs blocked most of the protection by SF in both DU-145 and T47D cells. These findings identify novel c-Akt-regulated genes, some of which contribute to SF-mediated cytoprotection.

Standard name | XU_HGF_SIGNALING_NOT_VIA_AKT1_48HR_UP
Systematic name | M11954
Organism | Homo sapiens
PMID | 17099727
Authors | Xu J,Gao M,Fan S,Meng Q,Goldberg ID,Abounader R,Ressom H,Laterra JJ,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DU-145 cells (prostate cancer) in the absence and presence of a dominant negative form of AKT1 [GeneID=207] upon exposure to HGF [GeneID=3082] for 48 h.
Full description | The cytokine scatter factor (SF) (hepatocyte growth factor) transduces various biologic actions, including cell motility, invasion, angiogenesis and apoptosis inhibition. The latter is relevant to understanding the role of SF in promoting tumor cell survival in different contexts, for example, detachment from basement membrane, growth in metastatic sites and responses to chemo- and radiotherapy. Previously, we showed that SF protects cells against apoptosis owing to DNA damage, by a mechanism involving phosphoinositol-3-kinase/c-Akt signaling. Here, we used DNA microarray assays to identify c-Akt-regulated genes that might contribute to cell protection. DU-145 human prostate cancer cells were transfected+/-a dominant-negative mutant Akt, treated+/-SF and analysed for gene expression using Affymetrix arrays. These studies identified SF-regulated genes for which induction was c-Akt-dependent vs -independent. Selected microarray findings were confirmed by semiquantitative and quantitative reverse transcription-polymerase chain reaction. We tested the contribution of four SF-inducible/c-Akt-dependent genes (AMPD3, EPHB2, MX1 and WNT4) to protection against adriamycin (a DNA topoisomerase IIalpha inhibitor) using RNA interference. Knockdown of each gene except EPHB2 caused a small but significant reduction in the SF cell protection. The lack of effect of EPHB2 knockdown may be due to the fact that DU-145 cells contain a single-mutant EPHB2 allele. A combination of three small interfering RNAs blocked most of the protection by SF in both DU-145 and T47D cells. These findings identify novel c-Akt-regulated genes, some of which contribute to SF-mediated cytoprotection.

Standard name | XU_HGF_SIGNALING_NOT_VIA_AKT1_48HR_DN
Systematic name | M11536
Organism | Homo sapiens
PMID | 17099727
Authors | Xu J,Gao M,Fan S,Meng Q,Goldberg ID,Abounader R,Ressom H,Laterra JJ,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in DU-145 cells (prostate cancer) in the absence and presence of a dominant negative form of AKT1 [GeneID=207] upon exposure to HGF [GeneID=3082] for 48 h.
Full description | The cytokine scatter factor (SF) (hepatocyte growth factor) transduces various biologic actions, including cell motility, invasion, angiogenesis and apoptosis inhibition. The latter is relevant to understanding the role of SF in promoting tumor cell survival in different contexts, for example, detachment from basement membrane, growth in metastatic sites and responses to chemo- and radiotherapy. Previously, we showed that SF protects cells against apoptosis owing to DNA damage, by a mechanism involving phosphoinositol-3-kinase/c-Akt signaling. Here, we used DNA microarray assays to identify c-Akt-regulated genes that might contribute to cell protection. DU-145 human prostate cancer cells were transfected+/-a dominant-negative mutant Akt, treated+/-SF and analysed for gene expression using Affymetrix arrays. These studies identified SF-regulated genes for which induction was c-Akt-dependent vs -independent. Selected microarray findings were confirmed by semiquantitative and quantitative reverse transcription-polymerase chain reaction. We tested the contribution of four SF-inducible/c-Akt-dependent genes (AMPD3, EPHB2, MX1 and WNT4) to protection against adriamycin (a DNA topoisomerase IIalpha inhibitor) using RNA interference. Knockdown of each gene except EPHB2 caused a small but significant reduction in the SF cell protection. The lack of effect of EPHB2 knockdown may be due to the fact that DU-145 cells contain a single-mutant EPHB2 allele. A combination of three small interfering RNAs blocked most of the protection by SF in both DU-145 and T47D cells. These findings identify novel c-Akt-regulated genes, some of which contribute to SF-mediated cytoprotection.

Standard name | XU_HGF_TARGETS_INDUCED_BY_AKT1_48HR_UP
Systematic name | M17359
Organism | Homo sapiens
PMID | 17099727
Authors | Xu J,Gao M,Fan S,Meng Q,Goldberg ID,Abounader R,Ressom H,Laterra JJ,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DU-145 cells (prostate cancer) in the absence but not in the presence of a dominant negative form of AKT1 [GeneID=207] upon exposure to HGF [GeneID=3082] for 48 h.
Full description | The cytokine scatter factor (SF) (hepatocyte growth factor) transduces various biologic actions, including cell motility, invasion, angiogenesis and apoptosis inhibition. The latter is relevant to understanding the role of SF in promoting tumor cell survival in different contexts, for example, detachment from basement membrane, growth in metastatic sites and responses to chemo- and radiotherapy. Previously, we showed that SF protects cells against apoptosis owing to DNA damage, by a mechanism involving phosphoinositol-3-kinase/c-Akt signaling. Here, we used DNA microarray assays to identify c-Akt-regulated genes that might contribute to cell protection. DU-145 human prostate cancer cells were transfected+/-a dominant-negative mutant Akt, treated+/-SF and analysed for gene expression using Affymetrix arrays. These studies identified SF-regulated genes for which induction was c-Akt-dependent vs -independent. Selected microarray findings were confirmed by semiquantitative and quantitative reverse transcription-polymerase chain reaction. We tested the contribution of four SF-inducible/c-Akt-dependent genes (AMPD3, EPHB2, MX1 and WNT4) to protection against adriamycin (a DNA topoisomerase IIalpha inhibitor) using RNA interference. Knockdown of each gene except EPHB2 caused a small but significant reduction in the SF cell protection. The lack of effect of EPHB2 knockdown may be due to the fact that DU-145 cells contain a single-mutant EPHB2 allele. A combination of three small interfering RNAs blocked most of the protection by SF in both DU-145 and T47D cells. These findings identify novel c-Akt-regulated genes, some of which contribute to SF-mediated cytoprotection.

Standard name | XU_HGF_TARGETS_INDUCED_BY_AKT1_48HR_DN
Systematic name | M18912
Organism | Homo sapiens
PMID | 17099727
Authors | Xu J,Gao M,Fan S,Meng Q,Goldberg ID,Abounader R,Ressom H,Laterra JJ,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in DU-145 cells (prostate cancer) in the absence but not in the presence of a dominant negative form of AKT1 [GeneID=207] upon exposure to HGF [GeneID=3082] for 48 h.
Full description | The cytokine scatter factor (SF) (hepatocyte growth factor) transduces various biologic actions, including cell motility, invasion, angiogenesis and apoptosis inhibition. The latter is relevant to understanding the role of SF in promoting tumor cell survival in different contexts, for example, detachment from basement membrane, growth in metastatic sites and responses to chemo- and radiotherapy. Previously, we showed that SF protects cells against apoptosis owing to DNA damage, by a mechanism involving phosphoinositol-3-kinase/c-Akt signaling. Here, we used DNA microarray assays to identify c-Akt-regulated genes that might contribute to cell protection. DU-145 human prostate cancer cells were transfected+/-a dominant-negative mutant Akt, treated+/-SF and analysed for gene expression using Affymetrix arrays. These studies identified SF-regulated genes for which induction was c-Akt-dependent vs -independent. Selected microarray findings were confirmed by semiquantitative and quantitative reverse transcription-polymerase chain reaction. We tested the contribution of four SF-inducible/c-Akt-dependent genes (AMPD3, EPHB2, MX1 and WNT4) to protection against adriamycin (a DNA topoisomerase IIalpha inhibitor) using RNA interference. Knockdown of each gene except EPHB2 caused a small but significant reduction in the SF cell protection. The lack of effect of EPHB2 knockdown may be due to the fact that DU-145 cells contain a single-mutant EPHB2 allele. A combination of three small interfering RNAs blocked most of the protection by SF in both DU-145 and T47D cells. These findings identify novel c-Akt-regulated genes, some of which contribute to SF-mediated cytoprotection.

Standard name | XU_HGF_TARGETS_REPRESSED_BY_AKT1_UP
Systematic name | M10500
Organism | Homo sapiens
PMID | 17099727
Authors | Xu J,Gao M,Fan S,Meng Q,Goldberg ID,Abounader R,Ressom H,Laterra JJ,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DU-145 cells (prostate cancer) in the presence but not in the absence of a dominant negative form of AKT1 [GeneID=207] upon exposure to HGF [GeneID=3082] for 48 h.
Full description | The cytokine scatter factor (SF) (hepatocyte growth factor) transduces various biologic actions, including cell motility, invasion, angiogenesis and apoptosis inhibition. The latter is relevant to understanding the role of SF in promoting tumor cell survival in different contexts, for example, detachment from basement membrane, growth in metastatic sites and responses to chemo- and radiotherapy. Previously, we showed that SF protects cells against apoptosis owing to DNA damage, by a mechanism involving phosphoinositol-3-kinase/c-Akt signaling. Here, we used DNA microarray assays to identify c-Akt-regulated genes that might contribute to cell protection. DU-145 human prostate cancer cells were transfected+/-a dominant-negative mutant Akt, treated+/-SF and analysed for gene expression using Affymetrix arrays. These studies identified SF-regulated genes for which induction was c-Akt-dependent vs -independent. Selected microarray findings were confirmed by semiquantitative and quantitative reverse transcription-polymerase chain reaction. We tested the contribution of four SF-inducible/c-Akt-dependent genes (AMPD3, EPHB2, MX1 and WNT4) to protection against adriamycin (a DNA topoisomerase IIalpha inhibitor) using RNA interference. Knockdown of each gene except EPHB2 caused a small but significant reduction in the SF cell protection. The lack of effect of EPHB2 knockdown may be due to the fact that DU-145 cells contain a single-mutant EPHB2 allele. A combination of three small interfering RNAs blocked most of the protection by SF in both DU-145 and T47D cells. These findings identify novel c-Akt-regulated genes, some of which contribute to SF-mediated cytoprotection.

Standard name | XU_HGF_TARGETS_REPRESSED_BY_AKT1_DN
Systematic name | M10855
Organism | Homo sapiens
PMID | 17099727
Authors | Xu J,Gao M,Fan S,Meng Q,Goldberg ID,Abounader R,Ressom H,Laterra JJ,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in DU-145 cells (prostate cancer) in the presence but not in the absence of a dominant negative form of AKT1 [GeneID=207] upon exposure to HGF [GeneID=3082] for 48 h.
Full description | The cytokine scatter factor (SF) (hepatocyte growth factor) transduces various biologic actions, including cell motility, invasion, angiogenesis and apoptosis inhibition. The latter is relevant to understanding the role of SF in promoting tumor cell survival in different contexts, for example, detachment from basement membrane, growth in metastatic sites and responses to chemo- and radiotherapy. Previously, we showed that SF protects cells against apoptosis owing to DNA damage, by a mechanism involving phosphoinositol-3-kinase/c-Akt signaling. Here, we used DNA microarray assays to identify c-Akt-regulated genes that might contribute to cell protection. DU-145 human prostate cancer cells were transfected+/-a dominant-negative mutant Akt, treated+/-SF and analysed for gene expression using Affymetrix arrays. These studies identified SF-regulated genes for which induction was c-Akt-dependent vs -independent. Selected microarray findings were confirmed by semiquantitative and quantitative reverse transcription-polymerase chain reaction. We tested the contribution of four SF-inducible/c-Akt-dependent genes (AMPD3, EPHB2, MX1 and WNT4) to protection against adriamycin (a DNA topoisomerase IIalpha inhibitor) using RNA interference. Knockdown of each gene except EPHB2 caused a small but significant reduction in the SF cell protection. The lack of effect of EPHB2 knockdown may be due to the fact that DU-145 cells contain a single-mutant EPHB2 allele. A combination of three small interfering RNAs blocked most of the protection by SF in both DU-145 and T47D cells. These findings identify novel c-Akt-regulated genes, some of which contribute to SF-mediated cytoprotection.

Standard name | XU_AKT1_TARGETS_6HR
Systematic name | M18724
Organism | Homo sapiens
PMID | 17099727
Authors | Xu J,Gao M,Fan S,Meng Q,Goldberg ID,Abounader R,Ressom H,Laterra JJ,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DU-145 cells (prostate cancer) expressing a dominant negative form of AKT1 [GeneID=207] upon sham-treatment for 6 h (as a control for the HGF [GeneID=3082] experiments).
Full description | The cytokine scatter factor (SF) (hepatocyte growth factor) transduces various biologic actions, including cell motility, invasion, angiogenesis and apoptosis inhibition. The latter is relevant to understanding the role of SF in promoting tumor cell survival in different contexts, for example, detachment from basement membrane, growth in metastatic sites and responses to chemo- and radiotherapy. Previously, we showed that SF protects cells against apoptosis owing to DNA damage, by a mechanism involving phosphoinositol-3-kinase/c-Akt signaling. Here, we used DNA microarray assays to identify c-Akt-regulated genes that might contribute to cell protection. DU-145 human prostate cancer cells were transfected+/-a dominant-negative mutant Akt, treated+/-SF and analysed for gene expression using Affymetrix arrays. These studies identified SF-regulated genes for which induction was c-Akt-dependent vs -independent. Selected microarray findings were confirmed by semiquantitative and quantitative reverse transcription-polymerase chain reaction. We tested the contribution of four SF-inducible/c-Akt-dependent genes (AMPD3, EPHB2, MX1 and WNT4) to protection against adriamycin (a DNA topoisomerase IIalpha inhibitor) using RNA interference. Knockdown of each gene except EPHB2 caused a small but significant reduction in the SF cell protection. The lack of effect of EPHB2 knockdown may be due to the fact that DU-145 cells contain a single-mutant EPHB2 allele. A combination of three small interfering RNAs blocked most of the protection by SF in both DU-145 and T47D cells. These findings identify novel c-Akt-regulated genes, some of which contribute to SF-mediated cytoprotection.

Standard name | XU_AKT1_TARGETS_48HR
Systematic name | M18117
Organism | Homo sapiens
PMID | 17099727
Authors | Xu J,Gao M,Fan S,Meng Q,Goldberg ID,Abounader R,Ressom H,Laterra JJ,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DU-145 cells (prostate cancer) expressing a dominant negative form of AKT1 [GeneID=207] upon sham-treatment for 48 h (as a control for the HGF [GeneID=3082] experiments).
Full description | The cytokine scatter factor (SF) (hepatocyte growth factor) transduces various biologic actions, including cell motility, invasion, angiogenesis and apoptosis inhibition. The latter is relevant to understanding the role of SF in promoting tumor cell survival in different contexts, for example, detachment from basement membrane, growth in metastatic sites and responses to chemo- and radiotherapy. Previously, we showed that SF protects cells against apoptosis owing to DNA damage, by a mechanism involving phosphoinositol-3-kinase/c-Akt signaling. Here, we used DNA microarray assays to identify c-Akt-regulated genes that might contribute to cell protection. DU-145 human prostate cancer cells were transfected+/-a dominant-negative mutant Akt, treated+/-SF and analysed for gene expression using Affymetrix arrays. These studies identified SF-regulated genes for which induction was c-Akt-dependent vs -independent. Selected microarray findings were confirmed by semiquantitative and quantitative reverse transcription-polymerase chain reaction. We tested the contribution of four SF-inducible/c-Akt-dependent genes (AMPD3, EPHB2, MX1 and WNT4) to protection against adriamycin (a DNA topoisomerase IIalpha inhibitor) using RNA interference. Knockdown of each gene except EPHB2 caused a small but significant reduction in the SF cell protection. The lack of effect of EPHB2 knockdown may be due to the fact that DU-145 cells contain a single-mutant EPHB2 allele. A combination of three small interfering RNAs blocked most of the protection by SF in both DU-145 and T47D cells. These findings identify novel c-Akt-regulated genes, some of which contribute to SF-mediated cytoprotection.

Standard name | SHI_SPARC_TARGETS_UP
Systematic name | M4095
Organism | Homo sapiens
PMID | 17213807
Authors | Shi Q,Bao S,Song L,Wu Q,Bigner DD,Hjelmeland AB,Rich JN
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in glioma cell lines after knockdown of SPARC [GeneID=6678] by RNAi.
Full description | Secreted protein acidic and rich in cysteine (SPARC) is an extracellular glycoprotein expressed in several solid cancers, including malignant gliomas, upon adoption of metastatic or invasive behaviors. SPARC expression in glioma cells promotes invasion and survival under stress, the latter process dependent on SPARC activation of AKT. Here we demonstrate that downregulation of SPARC expression with short interfering RNA (siRNA) in glioma cells decreased tumor cell survival and invasion. SPARC siRNA reduced the activating phosphorylation of AKT and two cytoplasmic kinases, focal adhesion kinase (FAK) and integrin-linked kinase (ILK). We determined the contributions of FAK and ILK to SPARC effects using SPARC protein and cell lines engineered to overexpress SPARC. SPARC activated FAK and ILK in glioma cells previously characterized as responsive to SPARC. Downregulation of either FAK or ILK expression inhibited SPARC-mediated AKT phosphorylation, and targeting both FAK and ILK attenuated AKT activation more potently than targeting either FAK or ILK alone. Decreased SPARC-mediated AKT activation correlated with a reduction in SPARC-dependent invasion and survival upon the downregulation of FAK and/or ILK expression. These data further demonstrate the role of SPARC in glioma tumor progression through the activation of intracellular kinases that may provide novel therapeutic targets for advanced cancers.

Standard name | SHI_SPARC_TARGETS_DN
Systematic name | M6946
Organism | Homo sapiens
PMID | 17213807
Authors | Shi Q,Bao S,Song L,Wu Q,Bigner DD,Hjelmeland AB,Rich JN
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in glioma cell lines after knockdown of SPARC [GeneID=6678] by RNAi.
Full description | Secreted protein acidic and rich in cysteine (SPARC) is an extracellular glycoprotein expressed in several solid cancers, including malignant gliomas, upon adoption of metastatic or invasive behaviors. SPARC expression in glioma cells promotes invasion and survival under stress, the latter process dependent on SPARC activation of AKT. Here we demonstrate that downregulation of SPARC expression with short interfering RNA (siRNA) in glioma cells decreased tumor cell survival and invasion. SPARC siRNA reduced the activating phosphorylation of AKT and two cytoplasmic kinases, focal adhesion kinase (FAK) and integrin-linked kinase (ILK). We determined the contributions of FAK and ILK to SPARC effects using SPARC protein and cell lines engineered to overexpress SPARC. SPARC activated FAK and ILK in glioma cells previously characterized as responsive to SPARC. Downregulation of either FAK or ILK expression inhibited SPARC-mediated AKT phosphorylation, and targeting both FAK and ILK attenuated AKT activation more potently than targeting either FAK or ILK alone. Decreased SPARC-mediated AKT activation correlated with a reduction in SPARC-dependent invasion and survival upon the downregulation of FAK and/or ILK expression. These data further demonstrate the role of SPARC in glioma tumor progression through the activation of intracellular kinases that may provide novel therapeutic targets for advanced cancers.

Standard name | WAESCH_ANAPHASE_PROMOTING_COMPLEX
Systematic name | M7890
Organism | Homo sapiens
PMID | 15637585
Authors | Wäsch R,Engelbert D
Category | C2
Sub-category | CGP
Brief description | Subunits of the anaphase promoting complex (APC).
Full description | Genomic instability can be found in most cancer cells. Cell proliferation is under tight control to ensure accurate DNA replication and chromosome segregation. Cyclin-dependent kinases (Cdks) and their activating subunits, the cyclins, are the driving forces of the cell division cycle. Regulation of cyclin oscillation by ubiquitin-dependent proteolysis thereby has a central role in cell cycle regulation. The anaphase-promoting complex (APC) is a specific ubiquitin ligase and is essential for chromosome segregation, exit from mitosis and a stable subsequent G1 phase allowing cell differentiation or accurate DNA replication in the following S phase. The APC is activated by the regulatory subunits Cdc20 (APC(Cdc20)) and Cdh1 (APC(Cdh1)) to target securin, mitotic cyclins and other cell cycle regulatory proteins for proteasomal degradation. This review is focused on the role of APC-dependent proteolysis in cell cycle regulation and how its deregulation may lead to genomic instability of cancer cells.

Standard name | AGARWAL_AKT_PATHWAY_TARGETS
Systematic name | M3495
Organism | Homo sapiens
PMID | 15592509
Authors | Agarwal A,Das K,Lerner N,Sathe S,Cicek M,Casey G,Sizemore N
Category | C2
Sub-category | CGP
Brief description | Angiogenic and metastatic genes changed in RKO cells (colorectal cancer) upon perturbation of key components of AKT pathway.
Full description | Our laboratory has delineated that the phosphatidylinositol 3' kinase (PI3K)/AKT/I kappa B kinase (IKK) pathway positively regulates NF kappa B and beta-catenin, both important transcriptional regulators in colorectal cancer (CRC). Therefore, we investigated the effect of inhibiting the PI3K/AKT/IKK alpha pathway in regulating the inappropriate constitutive activation of NF kappa B and beta-catenin in CRC cell lines. SW480 and RKO CRC cell lines demonstrate constitutive activation of AKT as well as both NF kappa B- and beta-catenin-dependent transcription. The constitutive activation of NF kappa B- and beta-catenin-dependent transcription is inhibited by transiently transfecting either kinase dead (KD) IKK alpha, which blocks IKK alpha kinase activity, KD AKT, which blocks AKT activity, or wildtype (WT) PTEN, which inhibits PI3K and AKT activity. The ability of KD IKK alpha, KD AKT or WT PTEN to decrease beta-catenin-dependent transcription is independent of their effects on NF kappa B. Inducible expression of either KD IKK alpha or WT PTEN strongly inhibits both the constitutive NF kappa B- and beta-catenin-dependent promoter and endogenous gene activation. Targeted array-based gene expression analysis of this inducible system reveals that many of the genes downregulated upon inhibition of this pathway are involved in tumor angiogenesis and metastasis. The activation of this pathway and the expression of the three most repressed genes was further analysed in samples of CRC. These results indicate a role of this pathway in controlling gene expression important in tumor progression and metastasis.

Standard name | NEBEN_AML_WITH_FLT3_OR_NRAS_UP
Systematic name | M16304
Organism | Homo sapiens
PMID | 15674343
Authors | Neben K,Schnittger S,Brors B,Tews B,Kokocinski F,Haferlach T,Müller J,Hahn M,Hiddemann W,Eils R,Lichter P,Schoch C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in acute myeloid leukemia (AML) samples with constitutively activated FLT3 [GeneID=2322] or with activating point mutations within NRAS [GeneID=4893].
Full description | In acute myeloid leukemia (AML), constitutive activation of the FLT3 receptor tyrosine kinase, either by internal tandem duplications (FLT3-ITD) of the juxtamembrane region or by point mutations in the second tyrosine kinase domain (FLT3-TKD), as well as point mutations of the NRAS gene (NRAS-PM) are among the most frequent somatic gene mutations. To elucidate whether these mutations cause aberrant signal transduction in AML, we used gene expression profiling in a series of 110 newly diagnosed AML patients with normal karyotype. The different algorithms used for data analysis revealed highly concordant sets of genes, indicating that the identified gene signatures are specific for each analysed subgroup. Whereas samples with FLT3-ITD and FLT3-TKD could be separated with up to 100% accuracy, this did not apply for NRAS-PM and wild-type samples, suggesting that only FLT3-ITD and FLT3-TKD are associated with an apparent signature in AML. The set of discriminating genes included several known genes, which are involved in cell cycle control (CDC14A, WEE1), gene transcription (HOXB5, FOXA1), and signal transduction (SMG1). In conclusion, we showed that unique gene expression patterns can be correlated with FLT3-ITD and FLT3-TKD. This might lead to the identification of further pathogenetic relevant candidate genes particularly in AML with normal karyotype.

Standard name | NEBEN_AML_WITH_FLT3_OR_NRAS_DN
Systematic name | M12530
Organism | Homo sapiens
PMID | 15674343
Authors | Neben K,Schnittger S,Brors B,Tews B,Kokocinski F,Haferlach T,Müller J,Hahn M,Hiddemann W,Eils R,Lichter P,Schoch C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in acute myeloid leukemia (AML) samples with constitutively activated FLT3 [GeneID=2322] or with activating point mutations within NRAS [GeneID=4893].
Full description | In acute myeloid leukemia (AML), constitutive activation of the FLT3 receptor tyrosine kinase, either by internal tandem duplications (FLT3-ITD) of the juxtamembrane region or by point mutations in the second tyrosine kinase domain (FLT3-TKD), as well as point mutations of the NRAS gene (NRAS-PM) are among the most frequent somatic gene mutations. To elucidate whether these mutations cause aberrant signal transduction in AML, we used gene expression profiling in a series of 110 newly diagnosed AML patients with normal karyotype. The different algorithms used for data analysis revealed highly concordant sets of genes, indicating that the identified gene signatures are specific for each analysed subgroup. Whereas samples with FLT3-ITD and FLT3-TKD could be separated with up to 100% accuracy, this did not apply for NRAS-PM and wild-type samples, suggesting that only FLT3-ITD and FLT3-TKD are associated with an apparent signature in AML. The set of discriminating genes included several known genes, which are involved in cell cycle control (CDC14A, WEE1), gene transcription (HOXB5, FOXA1), and signal transduction (SMG1). In conclusion, we showed that unique gene expression patterns can be correlated with FLT3-ITD and FLT3-TKD. This might lead to the identification of further pathogenetic relevant candidate genes particularly in AML with normal karyotype.

Standard name | DIRMEIER_LMP1_RESPONSE_EARLY
Systematic name | M13941
Organism | Homo sapiens
PMID | 15674340
Authors | Dirmeier U,Hoffmann R,Kilger E,Schultheiss U,Briseño C,Gires O,Kieser A,Eick D,Sugden B,Hammerschmidt W
Category | C2
Sub-category | CGP
Brief description | Clusters 1 and 2: genes up-regulated in B2264-19/3 cells (primary B lymphocytes) within 30-60 min after activation of LMP1 (an oncogene encoded by Epstein-Barr virus, EBV).
Full description | Latent membrane protein 1 (LMP1), an oncoprotein encoded by Epstein-Barr virus (EBV), is an integral membrane protein, which acts like a constitutively active receptor. LMP1 is critical for some facet of EBV's induction and maintenance of proliferation of infected B cells. It, in part, mimics signaling by the CD40 receptor and has been implicated in regulating proliferation, survival, or both properties of EBV-infected cells. We established a conditional LMP1 allele in the context of the intact EBV genome to define the immediate-early cellular target genes regulated by LMP1 in order to assess its contributions to infected human B cells. The functional analysis of this conditional system indicated that LMP1 specifically induces mitogenic B-cell activation through c-myc and Jun/AP1 family members and confirms its direct role in upregulating expression of multiple genes with opposing activities involved in cell survival. LMP1's signals were found to be essential for the G1/S transition in human B cells; cells lacking LMP1's signals are cell cycle arrested and survive quiescently. LMP1's activities are therefore not required to maintain survival in nonproliferating cells. LMP1 does induce both pro- and antiapoptotic genes whose balance seems to permit survival during LMP1's induction and maintenance of proliferation.

Standard name | EINAV_INTERFERON_SIGNATURE_IN_CANCER
Systematic name | M5091
Organism | Homo sapiens
PMID | 16007187
Authors | Einav U,Tabach Y,Getz G,Yitzhaky A,Ozbek U,Amariglio N,Izraeli S,Rechavi G,Domany E
Category | C2
Sub-category | CGP
Brief description | A gene expression signature found in a subset of cancer patients suggestive of a deregulated immune or inflammatory response.
Full description | On the basis of epidemiological studies, infection was suggested to play a role in the etiology of human cancer. While for some cancers such a role was indeed demonstrated, there is no direct biological support for the role of viral pathogens in the pathogenesis of childhood leukemia. Using a novel bioinformatic tool that alternates between clustering and standard statistical methods of analysis, we performed a 'double-blind' search of published gene expression data of subjects with different childhood acute lymphoblastic leukemia (ALL) subtypes, looking for unanticipated partitions of patients, induced by unexpected groups of genes with correlated expression. We discovered a group of about 30 genes, related to the interferon response pathway, whose expression levels divide the ALL samples into two subgroups; high in 50, low in 285 patients. Leukemic subclasses prevalent in early childhood (the age most susceptible to infection) are over-represented in the high-expression subgroup. Similar partitions, induced by the same genes, were found also in breast and ovarian cancer but not in lung cancer, prostate cancer and lymphoma. About 40% of breast cancer samples expressed the 'interferon-related' signature. It is of interest that several studies demonstrated mouse mammary tumor virus-like sequences in about 40% of breast cancer samples. Our discovery of an unanticipated strong signature of an interferon-induced pathway provides molecular support for a role for either inflammation or viral infection in the pathogenesis of childhood leukemia as well as breast and ovarian cancer.

Standard name | AMUNDSON_DNA_DAMAGE_RESPONSE_TP53
Systematic name | M17836
Organism | Homo sapiens
PMID | 15824734
Authors | Amundson SA,Do KT,Vinikoor L,Koch-Paiz CA,Bittner ML,Trent JM,Meltzer P,Fornace AJ Jr
Category | C2
Sub-category | CGP
Brief description | Genes discriminating TP53 [GeneID=7157] status across various genotoxic stress agents.
Full description | Gene expression responses of human cell lines exposed to a diverse set of stress agents were compared by cDNA microarray hybridization. The B-lymphoblastoid cell line TK6 (p53 wild-type) and its p53-null derivative, NH32, were treated in parallel to facilitate investigation of p53-dependent responses. RNA was extracted 4 h after the beginning of treatment when no notable decrease in cell viability was evident in the cultures. Gene expression signatures were defined that discriminated between four broad general mechanisms of stress agents: Non-DNA-damaging stresses (heat shock, osmotic shock, and 12-O-tetradecanoylphorbol 13-acetate), agents causing mainly oxidative stress (arsenite and hydrogen peroxide), ionizing radiations (neutron and gamma-ray exposures), and other DNA-damaging agents (ultraviolet radiation, methyl methanesulfonate, adriamycin, camptothecin, and cis-Platinum(II)diammine dichloride (cisplatin)). Within this data set, non-DNA-damaging stresses could be discriminated from all DNA-damaging stresses, and profiles for individual agents were also defined. While DNA-damaging stresses showed a strong p53-dependent element in their responses, no discernible p53-dependent responses were triggered by the non-DNA-damaging stresses. A set of 16 genes did exhibit a robust p53-dependent pattern of induction in response to all nine DNA-damaging agents, however.

Standard name | SNIJDERS_AMPLIFIED_IN_HEAD_AND_NECK_TUMORS
Systematic name | M12802
Organism | Homo sapiens
PMID | 15824737
Authors | Snijders AM,Schmidt BL,Fridlyand J,Dekker N,Pinkel D,Jordan RC,Albertson DG
Category | C2
Sub-category | CGP
Brief description | Genes from the recurrent amplicons in 89 samples of oral squamous cell carcinoma (SCC).
Full description | Genomes of solid tumors are characterized by gains and losses of regions, which may contribute to tumorigenesis by altering gene expression. Often the aberrations are extensive, encompassing whole chromosome arms, which makes identification of candidate genes in these regions difficult. Here, we focused on narrow regions of gene amplification to facilitate identification of genetic pathways important in oral squamous cell carcinoma (SCC) development. We used array comparative genomic hybridization (array CGH) to define minimum common amplified regions and then used expression analysis to identify candidate driver genes in amplicons that spanned <3 Mb. We found genes involved in integrin signaling (TLN1), survival (YAP1, BIRC2), and adhesion and migration (TLN1, LAMA3, MMP7), as well as members of the hedgehog (GLI2) and notch (JAG1, RBPSUH, FJX1) pathways to be amplified and overexpressed. Deregulation of these and other members of the hedgehog and notch pathways (HHIP, SMO, DLL1, NOTCH4) implicates deregulation of developmental and differentiation pathways, cell fate misspecification, in oral SCC development.

Standard name | NAISHIRO_CTNNB1_TARGETS_WITH_LEF1_MOTIF
Systematic name | M1194
Organism | Homo sapiens
PMID | 15735679
Authors | Naishiro Y,Yamada T,Idogawa M,Honda K,Takada M,Kondo T,Imai K,Hirohashi S
Category | C2
Sub-category | CGP
Brief description | Genes regulated by CTNNB1 [GeneID=1499] and whose promoters contain binding sites for LEF1 [GeneID=51176].
Full description | Aberrant transactivation of a certain set of target genes by the beta-catenin and T-cell factor/lymphoid enhancer factor (TCF/LEF) transcription factor complexes has been implicated in the process of intestinal epithelial cells entering early colorectal carcinogenesis. A rat intestinal epithelial cell line IEC6 became elongated, extended protrusions at cell periphery, and increased stress fibers and focal contacts upon the induction of beta-catenin protein stabilized by deletion of the N-terminal glycogen synthase kinase-3beta (GSKbeta) phosphorylation sites (beta-catenin DeltaN89). We used the GeneChiptrade mark oligonucleotide microarray system to examine approximately 24 000 genes and identified 13 genes whose expression was altered during the course of this morphological transformation. Those genes included known negative regulators of the Wnt signaling pathway, Sfrp4 and Axin2; extracellular matrix and related molecule, Hxb and Crtl1; cell adhesion and cytoskeletal proteins, Podxl, Igaf4, and Itab6; and molecules involved in the insulin and insulin-like growth factor (IGF) signaling pathways, Enpp1, Igfbp2, and Sgk. We report the finding that insulin-like growth factor-binding protein-2 (IGFBP2) is a direct target gene of the beta-catenin and TCF/LEF complexes. The IGFBP2 protein interacts with integrins. Disruption of the multigene network system regulating cell adhesion and cytoskeleton may be crucial in the initiation of colorectal carcinogenesis.

Standard name | WHITE_NEUROBLASTOMA_WITH_1P36.3_DELETION
Systematic name | M11268
Organism | Homo sapiens
PMID | 15829979
Authors | White PS,Thompson PM,Gotoh T,Okawa ER,Igarashi J,Kok M,Winter C,Gregory SG,Hogarty MD,Maris JM,Brodeur GM
Category | C2
Sub-category | CGP
Brief description | Genes within the smallest region of consistend deletion (SRD) within 1p36.3 area across a large collection of neuroblastoma cell lines and biopsy samples.
Full description | Substantial genomic and functional evidence from primary tumors and cell lines indicates that a consistent region of distal chromosome 1p is deleted in a sizable proportion of human neuroblastomas, suggesting that this region contains one or more tumor suppressor genes. To determine systematically and precisely the location and extent of 1p deletion in neuroblastomas, we performed allelic loss studies of 737 primary neuroblastomas and genotype analysis of 46 neuroblastoma cell lines. Together, the results defined a single region within 1p36.3 that was consistently deleted in 25% of tumors and 87% of cell lines. Two neuroblastoma patients had constitutional deletions of distal 1p36 that overlapped the tumor-defined region. The tumor- and constitutionally-derived deletions together defined a smallest region of consistent deletion (SRD) between D1S2795 and D1S253. The 1p36.3 SRD was deleted in all but one of the 184 tumors with 1p deletion. Physical mapping and DNA sequencing determined that the SRD minimally spans an estimated 729 kb. Genomic content and sequence analysis of the SRD identified 15 characterized, nine uncharacterized, and six predicted genes in the region. The RNA expression profiles of 21 of the genes were investigated in a variety of normal tissues. The SHREW1 and KCNAB2 genes both had tissue-restricted expression patterns, including expression in the nervous system. In addition, a novel gene (CHD5) with strong homology to proteins involved in chromatin remodeling was expressed mainly in neural tissues. Together, these results suggest that one or more genes involved in neuroblastoma tumorigenesis or tumor progression are likely contained within this region.

Standard name | BEGUM_TARGETS_OF_PAX3_FOXO1_FUSION_AND_PAX3
Systematic name | M18597
Organism | Homo sapiens
PMID | 15688035
Authors | Begum S,Emami N,Cheung A,Wilkins O,Der S,Hamel PA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SaOS-2 cells (osteosarcoma) upon expression of PAX3-FOXO1 [GeneID=5077;2308] but down-regulated by PAX3 expression off adenoviral vectors.
Full description | The oncogenic fusion protein, Pax3/FKHR, is a more potent transcription factor relative to its normal counterpart, Pax3. Since Pax3 induced a mesenchymal to epithelial transition (MET) in human SaOS-2 osteosarcomas, we hypothesized that Pax3/FKHR would also induce a morphological change in SaOS-2 cells. We demonstrate here that Pax3/FKHR more potently induces a MET in SaOS-2 cells than Pax3. This greater potency was further evident where Pax3/FKHR, but not Pax3, induced a morphological alteration in U2-OS osteosarcoma cells. By microarray analysis, we determined that Pax3/FKHR altered the expression of gene targets in a manner quantitatively and qualitatively distinct from Pax3. Three classes of genes were identified: (i) genes induced or repressed by Pax3 and Pax3/FKHR, (ii) genes induced or repressed by Pax3/FKHR but not Pax3 and (iii) genes induced by Pax3/FKHR but repressed by Pax3. Chromatin immunoprecipitations confirmed the direct binding of Pax3/FKHR to the promoter region of several factors including cannabinoid receptor-1, EPHA2 and EPHA4. Verification of the microarray data also revealed coordinate alteration in the expression of factors involved in BMP4 signalling. Regulation of gene expression by Pax3 and Pax3/FKHR is, however, cell-type specific. BMP4 expression, for example, was repressed by both Pax3 and Pax3/FKHR in SaOS-2 cells, while in the rhabdomyosarcoma, RD, Pax3/FKHR, but not Pax3, induced BMP4 expression. Thus, our data reveal that Pax3/FKHR regulates a distinct but overlapping set of genes relative to Pax3 and that the global set of Pax3 and Pax3/FKHR gene targets is cell-type specific.

Standard name | SILIGAN_BOUND_BY_EWS_FLT1_FUSION
Systematic name | M5218
Organism | Homo sapiens
PMID | 15735734
Authors | Siligan C,Ban J,Bachmaier R,Spahn L,Kreppel M,Schaefer KL,Poremba C,Aryee DN,Kovar H
Category | C2
Sub-category | CGP
Brief description | Genes bound by EWSR1-FLT1 [GeneID=2130;2321] fusion but whose expression did not change in STA-ET-7.2 cells (Ewing's sarcoma) after knockdown of EWSR1-FLT1 by RNAi.
Full description | In all, 85% of Ewing's sarcoma family tumors (ESFT), a neoplasm of unknown histogenesis, express EWS-FLI1 transcription factor gene fusions. To characterize direct target genes avoiding artificial model systems, we cloned genomic DNA from ESFT chromatin precipitating with EWS-FLI1. We now present a comprehensive list of 99 putative transcription factor targets identified, for the first time, by a hypothesis-free approach based on physical interaction. Gene-derived chromatin fragments co-precipitating with EWS-FLI1 were nonrandomly distributed over the human genome and localized predominantly to the upstream region and the first two introns of the genes. At least 20% of putative direct EWS-FLI1 targets were neural genes. One-third of genes recovered showed a significant ESFT-specific expression pattern and were found to be altered upon RNAi-mediated knockdown of EWS-FLI1. Among them, MK-STYX, encoding a MAP kinase phosphatase-like protein, was consistently expressed in ESFT. EWS-FLI1 was found to drive MK-STYX expression by binding to a single ETS binding motif within the first gene intron. MK-STYX serves as precedence for successful recovery of direct EWS-FLI1 targets from the authentic ESFT cellular context, the most relevant system to study oncogenic mechanisms for the discovery of new therapeutic targets in this disease.

Standard name | DAUER_STAT3_TARGETS_UP
Systematic name | M12391
Organism | Homo sapiens
PMID | 15735721
Authors | Dauer DJ,Ferraro B,Song L,Yu B,Mora L,Buettner R,Enkemann S,Jove R,Haura EB
Category | C2
Sub-category | CGP
Brief description | Top 50 genes up-regulated in A549 cells (lung cancer) expressing STAT3 [GeneID=6774] off an adenovirus vector.
Full description | Wound healing and cancer are both characterized by cell proliferation, remodeling of extracellular matrix, cell invasion and migration, new blood vessel formation, and modulation of blood coagulation. The mechanisms that link wound healing and cancer are poorly understood. We report here that Stat3, a common signaling mechanism involved in oncogenesis and tissue injury, regulates a common set of genes involved in wound healing and cancer. Using oligonucleotide gene arrays and quantitative real-time PCR, we evaluated changes in global gene expression resulting from expression of Stat3 in lung epithelial cells. We report here previously uncharacterized genes induced by Stat3 implicated in signaling pathways common to both wound healing and cancer including cell invasion and migration, angiogenesis, modulation of coagulation, and repression of interferon-inducible genes. Consistent with these results, we found increased Stat3 activity associated with wound healing in chronically inflamed mouse lungs and increased Stat3 activity was identified at the leading edge of lung tumors invading adjacent nontumor stroma. These findings provide a molecular basis for understanding cancer as a deregulation of normal wound healing processes.

Standard name | DAUER_STAT3_TARGETS_DN
Systematic name | M13696
Organism | Homo sapiens
PMID | 15735721
Authors | Dauer DJ,Ferraro B,Song L,Yu B,Mora L,Buettner R,Enkemann S,Jove R,Haura EB
Category | C2
Sub-category | CGP
Brief description | Top 50 genes down-regulated in A549 cells (lung cancer) expressing STAT3 [GeneID=6774] off an adenovirus vector.
Full description | Wound healing and cancer are both characterized by cell proliferation, remodeling of extracellular matrix, cell invasion and migration, new blood vessel formation, and modulation of blood coagulation. The mechanisms that link wound healing and cancer are poorly understood. We report here that Stat3, a common signaling mechanism involved in oncogenesis and tissue injury, regulates a common set of genes involved in wound healing and cancer. Using oligonucleotide gene arrays and quantitative real-time PCR, we evaluated changes in global gene expression resulting from expression of Stat3 in lung epithelial cells. We report here previously uncharacterized genes induced by Stat3 implicated in signaling pathways common to both wound healing and cancer including cell invasion and migration, angiogenesis, modulation of coagulation, and repression of interferon-inducible genes. Consistent with these results, we found increased Stat3 activity associated with wound healing in chronically inflamed mouse lungs and increased Stat3 activity was identified at the leading edge of lung tumors invading adjacent nontumor stroma. These findings provide a molecular basis for understanding cancer as a deregulation of normal wound healing processes.

Standard name | PATIL_LIVER_CANCER
Systematic name | M1195
Organism | Homo sapiens
PMID | 15735714
Authors | Patil MA,Chua MS,Pan KH,Lin R,Lih CJ,Cheung ST,Ho C,Li R,Fan ST,Cohen SN,Chen X,So S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) compared to normal liver samples.
Full description | Hepatocellular carcinoma (HCC) is one of the major causes of cancer deaths worldwide. New diagnostic and therapeutic options are needed for more effective and early detection and treatment of this malignancy. We identified 703 genes that are highly expressed in HCC using DNA microarrays, and further characterized them in order to uncover novel tumor markers, oncogenes, and therapeutic targets for HCC. Using Gene Ontology annotations, genes with functions related to cell proliferation and cell cycle, chromatin, repair, and transcription were found to be significantly enriched in this list of highly expressed genes. We also identified a set of genes that encode secreted (e.g. GPC3, LCN2, and DKK1) or membrane-bound proteins (e.g. GPC3, IGSF1, and PSK-1), which may be attractive candidates for the diagnosis of HCC. A significant enrichment of genes highly expressed in HCC was found on chromosomes 1q, 6p, 8q, and 20q, and we also identified chromosomal clusters of genes highly expressed in HCC. The microarray analyses were validated by RT-PCR and PCR. This approach of integrating other biological information with gene expression in the analysis helps select aberrantly expressed genes in HCC that may be further studied for their diagnostic or therapeutic utility.

Standard name | KORKOLA_EMBRYONAL_CARCINOMA
Systematic name | M18941
Organism | Homo sapiens
PMID | 15870693
Authors | Korkola JE,Houldsworth J,Dobrzynski D,Olshen AB,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes predicting the embryonic carcinoma (EC) subtype of nonseminomatous male germ cell tumors (NSGCT).
Full description | Male adult germ cell tumors (GCTs) comprise two major histologic groups: seminomas and nonseminomas. Nonseminomatous GCTs (NSGCTs) can be further divided into embryonal carcinoma (EC), teratoma (T), yolk sac tumor (YS), and choriocarcinoma (CC) on the basis of the lineage differentiation that they exhibit. NSGCTs frequently present as mixed tumors consisting of two or more histological subtypes, often limiting correlative studies of clinical and molecular features to histology. We sought to develop a molecular classifier that could predict the predominant histologic subtype within mixed NSGCT tumor samples. The expression profiles of 84 NSGCTs (42 pure and 42 mixed) and normal age-matched testes were obtained using Affymetrix microarrays. Using prediction analysis for microarrays, we identified 146 transcripts that classified the histology of pure NSGCTs samples with 93% accuracy. When applied to mixed NSGCTs, the classifier predicted a histology that was consistent with one of the reported components in 93% of cases. Among the predictive transcripts were CGB (high in CC), LCN2 (high in T), BMP2 (high in YS), and POU5F1 (high in EC). Thus, the expression-based classifier accurately assigned a single predominant histology to mixed NSGCTs, and identified transcripts differentially expressed between histologic components with relevance to NSGCT differentiation.

Standard name | KORKOLA_TERATOMA
Systematic name | M4623
Organism | Homo sapiens
PMID | 15870693
Authors | Korkola JE,Houldsworth J,Dobrzynski D,Olshen AB,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes predicting the teratoma (T) subtype of nonseminomatous male germ cell tumors (NSGCT).
Full description | Male adult germ cell tumors (GCTs) comprise two major histologic groups: seminomas and nonseminomas. Nonseminomatous GCTs (NSGCTs) can be further divided into embryonal carcinoma (EC), teratoma (T), yolk sac tumor (YS), and choriocarcinoma (CC) on the basis of the lineage differentiation that they exhibit. NSGCTs frequently present as mixed tumors consisting of two or more histological subtypes, often limiting correlative studies of clinical and molecular features to histology. We sought to develop a molecular classifier that could predict the predominant histologic subtype within mixed NSGCT tumor samples. The expression profiles of 84 NSGCTs (42 pure and 42 mixed) and normal age-matched testes were obtained using Affymetrix microarrays. Using prediction analysis for microarrays, we identified 146 transcripts that classified the histology of pure NSGCTs samples with 93% accuracy. When applied to mixed NSGCTs, the classifier predicted a histology that was consistent with one of the reported components in 93% of cases. Among the predictive transcripts were CGB (high in CC), LCN2 (high in T), BMP2 (high in YS), and POU5F1 (high in EC). Thus, the expression-based classifier accurately assigned a single predominant histology to mixed NSGCTs, and identified transcripts differentially expressed between histologic components with relevance to NSGCT differentiation.

Standard name | KORKOLA_YOLK_SAC_TUMOR
Systematic name | M6250
Organism | Homo sapiens
PMID | 15870693
Authors | Korkola JE,Houldsworth J,Dobrzynski D,Olshen AB,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes predicting the yolk sac tumor (YS) subtype of nonseminomatous male germ cell tumors (NSGCT).
Full description | Male adult germ cell tumors (GCTs) comprise two major histologic groups: seminomas and nonseminomas. Nonseminomatous GCTs (NSGCTs) can be further divided into embryonal carcinoma (EC), teratoma (T), yolk sac tumor (YS), and choriocarcinoma (CC) on the basis of the lineage differentiation that they exhibit. NSGCTs frequently present as mixed tumors consisting of two or more histological subtypes, often limiting correlative studies of clinical and molecular features to histology. We sought to develop a molecular classifier that could predict the predominant histologic subtype within mixed NSGCT tumor samples. The expression profiles of 84 NSGCTs (42 pure and 42 mixed) and normal age-matched testes were obtained using Affymetrix microarrays. Using prediction analysis for microarrays, we identified 146 transcripts that classified the histology of pure NSGCTs samples with 93% accuracy. When applied to mixed NSGCTs, the classifier predicted a histology that was consistent with one of the reported components in 93% of cases. Among the predictive transcripts were CGB (high in CC), LCN2 (high in T), BMP2 (high in YS), and POU5F1 (high in EC). Thus, the expression-based classifier accurately assigned a single predominant histology to mixed NSGCTs, and identified transcripts differentially expressed between histologic components with relevance to NSGCT differentiation.

Standard name | KORKOLA_CHORIOCARCINOMA
Systematic name | M11690
Organism | Homo sapiens
PMID | 15870693
Authors | Korkola JE,Houldsworth J,Dobrzynski D,Olshen AB,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes predicting the choriocarcinoma (CC) of nonseminomatous male germ cell tumors (NSGCT).
Full description | Male adult germ cell tumors (GCTs) comprise two major histologic groups: seminomas and nonseminomas. Nonseminomatous GCTs (NSGCTs) can be further divided into embryonal carcinoma (EC), teratoma (T), yolk sac tumor (YS), and choriocarcinoma (CC) on the basis of the lineage differentiation that they exhibit. NSGCTs frequently present as mixed tumors consisting of two or more histological subtypes, often limiting correlative studies of clinical and molecular features to histology. We sought to develop a molecular classifier that could predict the predominant histologic subtype within mixed NSGCT tumor samples. The expression profiles of 84 NSGCTs (42 pure and 42 mixed) and normal age-matched testes were obtained using Affymetrix microarrays. Using prediction analysis for microarrays, we identified 146 transcripts that classified the histology of pure NSGCTs samples with 93% accuracy. When applied to mixed NSGCTs, the classifier predicted a histology that was consistent with one of the reported components in 93% of cases. Among the predictive transcripts were CGB (high in CC), LCN2 (high in T), BMP2 (high in YS), and POU5F1 (high in EC). Thus, the expression-based classifier accurately assigned a single predominant histology to mixed NSGCTs, and identified transcripts differentially expressed between histologic components with relevance to NSGCT differentiation.

Standard name | WANG_METHYLATED_IN_BREAST_CANCER
Systematic name | M9951
Organism | Homo sapiens
PMID | 15735726
Authors | Wang W,Huper G,Guo Y,Murphy SK,Olson JA Jr,Marks JR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MDA468 cells (breast cancer) vs DU99 cells (normal breast) after treatment with azacytidine [PubChem=9444].
Full description | Treatment of the breast cancer cell line, MDAMB468 with the DNA methylation inhibitor, 5-azacytidine (5-AzaC) results in growth arrest, whereas the growth of the normal breast epithelial line DU99 (telomerase immortalized) is relatively unaffected. Comparing gene expression profiles of these two lines after 5-AzaC treatment, we identified 36 genes that had relatively low basal levels in MDAMB468 cells compared to the DU99 line and were induced in the cancer cell line but not in the normal breast epithelial line. Of these genes, 33 have associated CpG islands greater than 300 bp in length but only three have been previously described as targets for aberrant methylation in human cancer. Northern blotting for five of these genes (alpha-Catenin, DTR, FYN, GADD45a, and Zyxin) verified the array results. Further analysis of one of these genes, GADD45a, showed that 5-AzaC induced expression in five additional breast cancer cell lines with little or no induction in three additional lines derived from normal breast epithelial cells. The CpG island associated with GADD45a was analysed by bisulfite sequencing, sampling over 100 CpG dinucleotides. We found that four CpG's, located approximately 700 bp upstream of the transcriptional start site are methylated in the majority of breast cancer cell lines and primary tumors but not in DNA from normal breast epithelia or matched lymphocytes from cancer patients. Therefore, this simple method of dynamic transcriptional profiling yielded a series of novel methylation-sensitive genes in breast cancer including the BRCA1 and p53 responsive gene, GADD45a.

Standard name | HEIDENBLAD_AMPLIFIED_IN_PANCREATIC_CANCER
Systematic name | M9044
Organism | Homo sapiens
PMID | 15688027
Authors | Heidenblad M,Lindgren D,Veltman JA,Jonson T,Mahlamäki EH,Gorunova L,Kessel van AG,Schoenmakers EF,Höglund M
Category | C2
Sub-category | CGP
Brief description | Genes amplified and up-regulated more than twofold in at least two out of 10 pancreatic cancer cell lines studied.
Full description | DNA copy number alterations are believed to play a major role in the development and progression of human neoplasms. Although most of these genomic imbalances have been associated with dysregulation of individual genes, their large-scale transcriptional consequences remain unclear. Pancreatic carcinomas frequently display gene copy number variation of entire chromosomes as well as of chromosomal subregions. These changes range from homozygous deletions to high-level amplifications and are believed to constitute key genetic alterations in the cellular transformation of this tumor type. To investigate the transcriptional consequences of the most drastic genomic changes, that is, genomic amplifications, and to analyse the genome-wide transcriptional effects of DNA copy number changes, we performed expression profiling of 29 pancreatic carcinoma cell lines and compared the results with matching genomic profiling data. We show that a strong association between DNA copy numbers and mRNA expression levels is present in pancreatic cancer, and demonstrate that as much as 60% of the genes within highly amplified genomic regions display associated overexpression. Consequently, we identified 67 recurrently overexpressed genes located in seven precisely mapped commonly amplified regions. The presented findings indicate that more than one putative target gene may be of importance in most pancreatic cancer amplicons.

Standard name | TERAMOTO_OPN_TARGETS_CLUSTER_1
Systematic name | M1197
Organism | Mus musculus
PMID | 15516973
Authors | Teramoto H,Castellone MD,Malek RL,Letwin N,Frank B,Gutkind JS,Lee NH
Category | C2
Sub-category | CGP
Brief description | Cluster 1: genes whose up-regulation peaked one day after knockdown of OPN [GeneID=6696] by RNAi in the NIH3T3 cells (fibroblasts) transformed by activated HRAS [GeneID=3265].
Full description | Activated forms of Ras family members are prevalent in many cancers where Ras mutants transduce signals essential for transformation, angiogenesis, invasion and metastasis. As a cancer progression model, we used NIH3T3 cells to explore the mechanism of Ras-induced tumorigenesis. Ras family mutants H-RasV12 and Rit79L strongly induced foci formation, while Rho family mutants RhoA-QL, Rac1-QL and Cdc42-QL were less effective. A comparison of downstream transcriptional targets of Ras and Rho family members using a 26 383 element cDNA microarray revealed that the osteopontin (OPN) gene exhibited the best correlation between magnitude of gene expression change and level of foci formation (r=0.96, P<0.001). In association with H-RasV12- and Rit79L-mediated transformation, foci secreted OPN protein and upregulated the OPN receptor CD44, suggesting the novel initiation of an aberrant OPN-CD44-Rac autocrine pathway. In support of this were the following observations. First, RGD-deficient OPN protein-binding activity was present in H-RasV12-transformed cells but not in control cells, and binding activity was inhibited by the CD44 blocking antibody. Second, foci formation, cell invasion and Rac activity were induced by H-RasV12 and inhibited by the CD44 blocking antibody. Third, foci formation by H-RasV12 was substantially reduced by a short interfering RNA (siRNA) specifically targeting OPN expression for knockdown. Fourth, H-RasV12-mediated transformation was not blocked by the GRGDS peptide, suggesting that OPN effects were not mediated by the integrins. Lastly, OPN knockdown affected the downstream expression of 160 '2nd tier' genes, and at least a subset of these genes appears to be involved in transformation. Indeed, four genes were selected for knockdown, each resulting in a disruption of foci formation and/or invasion. These results underscore the role of aberrant autocrine signaling and transcriptional networking during tumorigenesis.

Standard name | TERAMOTO_OPN_TARGETS_CLUSTER_3
Systematic name | M1198
Organism | Mus musculus
PMID | 15516973
Authors | Teramoto H,Castellone MD,Malek RL,Letwin N,Frank B,Gutkind JS,Lee NH
Category | C2
Sub-category | CGP
Brief description | Cluster 3: genes whose up-regulation peaked 3 days after knockdown of OPN [GeneID=6696] by RNAi in the NIH3T3 cells (fibroblasts) transformed by activated HRAS [GeneID=3265].
Full description | Activated forms of Ras family members are prevalent in many cancers where Ras mutants transduce signals essential for transformation, angiogenesis, invasion and metastasis. As a cancer progression model, we used NIH3T3 cells to explore the mechanism of Ras-induced tumorigenesis. Ras family mutants H-RasV12 and Rit79L strongly induced foci formation, while Rho family mutants RhoA-QL, Rac1-QL and Cdc42-QL were less effective. A comparison of downstream transcriptional targets of Ras and Rho family members using a 26 383 element cDNA microarray revealed that the osteopontin (OPN) gene exhibited the best correlation between magnitude of gene expression change and level of foci formation (r=0.96, P<0.001). In association with H-RasV12- and Rit79L-mediated transformation, foci secreted OPN protein and upregulated the OPN receptor CD44, suggesting the novel initiation of an aberrant OPN-CD44-Rac autocrine pathway. In support of this were the following observations. First, RGD-deficient OPN protein-binding activity was present in H-RasV12-transformed cells but not in control cells, and binding activity was inhibited by the CD44 blocking antibody. Second, foci formation, cell invasion and Rac activity were induced by H-RasV12 and inhibited by the CD44 blocking antibody. Third, foci formation by H-RasV12 was substantially reduced by a short interfering RNA (siRNA) specifically targeting OPN expression for knockdown. Fourth, H-RasV12-mediated transformation was not blocked by the GRGDS peptide, suggesting that OPN effects were not mediated by the integrins. Lastly, OPN knockdown affected the downstream expression of 160 '2nd tier' genes, and at least a subset of these genes appears to be involved in transformation. Indeed, four genes were selected for knockdown, each resulting in a disruption of foci formation and/or invasion. These results underscore the role of aberrant autocrine signaling and transcriptional networking during tumorigenesis.

Standard name | TERAMOTO_OPN_TARGETS_CLUSTER_4
Systematic name | M1199
Organism | Mus musculus
PMID | 15516973
Authors | Teramoto H,Castellone MD,Malek RL,Letwin N,Frank B,Gutkind JS,Lee NH
Category | C2
Sub-category | CGP
Brief description | Cluster 4: genes whose up-regulation peaked 4 days after knockdown of OPN [GeneID=6696] by RNAi in the NIH3T3 cells (fibroblasts) transformed by activated HRAS [GeneID=3265].
Full description | Activated forms of Ras family members are prevalent in many cancers where Ras mutants transduce signals essential for transformation, angiogenesis, invasion and metastasis. As a cancer progression model, we used NIH3T3 cells to explore the mechanism of Ras-induced tumorigenesis. Ras family mutants H-RasV12 and Rit79L strongly induced foci formation, while Rho family mutants RhoA-QL, Rac1-QL and Cdc42-QL were less effective. A comparison of downstream transcriptional targets of Ras and Rho family members using a 26 383 element cDNA microarray revealed that the osteopontin (OPN) gene exhibited the best correlation between magnitude of gene expression change and level of foci formation (r=0.96, P<0.001). In association with H-RasV12- and Rit79L-mediated transformation, foci secreted OPN protein and upregulated the OPN receptor CD44, suggesting the novel initiation of an aberrant OPN-CD44-Rac autocrine pathway. In support of this were the following observations. First, RGD-deficient OPN protein-binding activity was present in H-RasV12-transformed cells but not in control cells, and binding activity was inhibited by the CD44 blocking antibody. Second, foci formation, cell invasion and Rac activity were induced by H-RasV12 and inhibited by the CD44 blocking antibody. Third, foci formation by H-RasV12 was substantially reduced by a short interfering RNA (siRNA) specifically targeting OPN expression for knockdown. Fourth, H-RasV12-mediated transformation was not blocked by the GRGDS peptide, suggesting that OPN effects were not mediated by the integrins. Lastly, OPN knockdown affected the downstream expression of 160 '2nd tier' genes, and at least a subset of these genes appears to be involved in transformation. Indeed, four genes were selected for knockdown, each resulting in a disruption of foci formation and/or invasion. These results underscore the role of aberrant autocrine signaling and transcriptional networking during tumorigenesis.

Standard name | TERAMOTO_OPN_TARGETS_CLUSTER_5
Systematic name | M1201
Organism | Mus musculus
PMID | 15516973
Authors | Teramoto H,Castellone MD,Malek RL,Letwin N,Frank B,Gutkind JS,Lee NH
Category | C2
Sub-category | CGP
Brief description | Cluster 5: genes whose up-regulation peaked 5 days after knockdown of OPN [GeneID=6696] by RNAi in the NIH3T3 cells (fibroblasts) transformed by activated HRAS [GeneID=3265].
Full description | Activated forms of Ras family members are prevalent in many cancers where Ras mutants transduce signals essential for transformation, angiogenesis, invasion and metastasis. As a cancer progression model, we used NIH3T3 cells to explore the mechanism of Ras-induced tumorigenesis. Ras family mutants H-RasV12 and Rit79L strongly induced foci formation, while Rho family mutants RhoA-QL, Rac1-QL and Cdc42-QL were less effective. A comparison of downstream transcriptional targets of Ras and Rho family members using a 26 383 element cDNA microarray revealed that the osteopontin (OPN) gene exhibited the best correlation between magnitude of gene expression change and level of foci formation (r=0.96, P<0.001). In association with H-RasV12- and Rit79L-mediated transformation, foci secreted OPN protein and upregulated the OPN receptor CD44, suggesting the novel initiation of an aberrant OPN-CD44-Rac autocrine pathway. In support of this were the following observations. First, RGD-deficient OPN protein-binding activity was present in H-RasV12-transformed cells but not in control cells, and binding activity was inhibited by the CD44 blocking antibody. Second, foci formation, cell invasion and Rac activity were induced by H-RasV12 and inhibited by the CD44 blocking antibody. Third, foci formation by H-RasV12 was substantially reduced by a short interfering RNA (siRNA) specifically targeting OPN expression for knockdown. Fourth, H-RasV12-mediated transformation was not blocked by the GRGDS peptide, suggesting that OPN effects were not mediated by the integrins. Lastly, OPN knockdown affected the downstream expression of 160 '2nd tier' genes, and at least a subset of these genes appears to be involved in transformation. Indeed, four genes were selected for knockdown, each resulting in a disruption of foci formation and/or invasion. These results underscore the role of aberrant autocrine signaling and transcriptional networking during tumorigenesis.

Standard name | TERAMOTO_OPN_TARGETS_CLUSTER_6
Systematic name | M1202
Organism | Mus musculus
PMID | 15516973
Authors | Teramoto H,Castellone MD,Malek RL,Letwin N,Frank B,Gutkind JS,Lee NH
Category | C2
Sub-category | CGP
Brief description | Cluster 6: genes exhibiting prolonged up-regulation (>72 h) after knockdown of OPN [GeneID=6696] by RNAi in the NIH3T3 cells (fibroblasts) transformed by activated HRAS [GeneID=3265].
Full description | Activated forms of Ras family members are prevalent in many cancers where Ras mutants transduce signals essential for transformation, angiogenesis, invasion and metastasis. As a cancer progression model, we used NIH3T3 cells to explore the mechanism of Ras-induced tumorigenesis. Ras family mutants H-RasV12 and Rit79L strongly induced foci formation, while Rho family mutants RhoA-QL, Rac1-QL and Cdc42-QL were less effective. A comparison of downstream transcriptional targets of Ras and Rho family members using a 26 383 element cDNA microarray revealed that the osteopontin (OPN) gene exhibited the best correlation between magnitude of gene expression change and level of foci formation (r=0.96, P<0.001). In association with H-RasV12- and Rit79L-mediated transformation, foci secreted OPN protein and upregulated the OPN receptor CD44, suggesting the novel initiation of an aberrant OPN-CD44-Rac autocrine pathway. In support of this were the following observations. First, RGD-deficient OPN protein-binding activity was present in H-RasV12-transformed cells but not in control cells, and binding activity was inhibited by the CD44 blocking antibody. Second, foci formation, cell invasion and Rac activity were induced by H-RasV12 and inhibited by the CD44 blocking antibody. Third, foci formation by H-RasV12 was substantially reduced by a short interfering RNA (siRNA) specifically targeting OPN expression for knockdown. Fourth, H-RasV12-mediated transformation was not blocked by the GRGDS peptide, suggesting that OPN effects were not mediated by the integrins. Lastly, OPN knockdown affected the downstream expression of 160 '2nd tier' genes, and at least a subset of these genes appears to be involved in transformation. Indeed, four genes were selected for knockdown, each resulting in a disruption of foci formation and/or invasion. These results underscore the role of aberrant autocrine signaling and transcriptional networking during tumorigenesis.

Standard name | TERAMOTO_OPN_TARGETS_CLUSTER_7
Systematic name | M1203
Organism | Mus musculus
PMID | 15516973
Authors | Teramoto H,Castellone MD,Malek RL,Letwin N,Frank B,Gutkind JS,Lee NH
Category | C2
Sub-category | CGP
Brief description | Cluster 7: genes down-regulated early (within 24 h) after knockdown of OPN [GeneID=6696] by RNAi in the NIH3T3 cells (fibroblasts) transformed by activated HRAS [GeneID=3265].
Full description | Activated forms of Ras family members are prevalent in many cancers where Ras mutants transduce signals essential for transformation, angiogenesis, invasion and metastasis. As a cancer progression model, we used NIH3T3 cells to explore the mechanism of Ras-induced tumorigenesis. Ras family mutants H-RasV12 and Rit79L strongly induced foci formation, while Rho family mutants RhoA-QL, Rac1-QL and Cdc42-QL were less effective. A comparison of downstream transcriptional targets of Ras and Rho family members using a 26 383 element cDNA microarray revealed that the osteopontin (OPN) gene exhibited the best correlation between magnitude of gene expression change and level of foci formation (r=0.96, P<0.001). In association with H-RasV12- and Rit79L-mediated transformation, foci secreted OPN protein and upregulated the OPN receptor CD44, suggesting the novel initiation of an aberrant OPN-CD44-Rac autocrine pathway. In support of this were the following observations. First, RGD-deficient OPN protein-binding activity was present in H-RasV12-transformed cells but not in control cells, and binding activity was inhibited by the CD44 blocking antibody. Second, foci formation, cell invasion and Rac activity were induced by H-RasV12 and inhibited by the CD44 blocking antibody. Third, foci formation by H-RasV12 was substantially reduced by a short interfering RNA (siRNA) specifically targeting OPN expression for knockdown. Fourth, H-RasV12-mediated transformation was not blocked by the GRGDS peptide, suggesting that OPN effects were not mediated by the integrins. Lastly, OPN knockdown affected the downstream expression of 160 '2nd tier' genes, and at least a subset of these genes appears to be involved in transformation. Indeed, four genes were selected for knockdown, each resulting in a disruption of foci formation and/or invasion. These results underscore the role of aberrant autocrine signaling and transcriptional networking during tumorigenesis.

Standard name | TERAMOTO_OPN_TARGETS_CLUSTER_8
Systematic name | M1204
Organism | Mus musculus
PMID | 15516973
Authors | Teramoto H,Castellone MD,Malek RL,Letwin N,Frank B,Gutkind JS,Lee NH
Category | C2
Sub-category | CGP
Brief description | Cluster 8: genes showing sustained pattern of down-regulation after knockdown of OPN [GeneID=6696] by RNAi in the NIH3T3 cells (fibroblasts) transformed by activated HRAS [GeneID=3265].
Full description | Activated forms of Ras family members are prevalent in many cancers where Ras mutants transduce signals essential for transformation, angiogenesis, invasion and metastasis. As a cancer progression model, we used NIH3T3 cells to explore the mechanism of Ras-induced tumorigenesis. Ras family mutants H-RasV12 and Rit79L strongly induced foci formation, while Rho family mutants RhoA-QL, Rac1-QL and Cdc42-QL were less effective. A comparison of downstream transcriptional targets of Ras and Rho family members using a 26 383 element cDNA microarray revealed that the osteopontin (OPN) gene exhibited the best correlation between magnitude of gene expression change and level of foci formation (r=0.96, P<0.001). In association with H-RasV12- and Rit79L-mediated transformation, foci secreted OPN protein and upregulated the OPN receptor CD44, suggesting the novel initiation of an aberrant OPN-CD44-Rac autocrine pathway. In support of this were the following observations. First, RGD-deficient OPN protein-binding activity was present in H-RasV12-transformed cells but not in control cells, and binding activity was inhibited by the CD44 blocking antibody. Second, foci formation, cell invasion and Rac activity were induced by H-RasV12 and inhibited by the CD44 blocking antibody. Third, foci formation by H-RasV12 was substantially reduced by a short interfering RNA (siRNA) specifically targeting OPN expression for knockdown. Fourth, H-RasV12-mediated transformation was not blocked by the GRGDS peptide, suggesting that OPN effects were not mediated by the integrins. Lastly, OPN knockdown affected the downstream expression of 160 '2nd tier' genes, and at least a subset of these genes appears to be involved in transformation. Indeed, four genes were selected for knockdown, each resulting in a disruption of foci formation and/or invasion. These results underscore the role of aberrant autocrine signaling and transcriptional networking during tumorigenesis.

Standard name | SEITZ_NEOPLASTIC_TRANSFORMATION_BY_8P_DELETION_UP
Systematic name | M7284
Organism | Homo sapiens
PMID | 15580292
Authors | Seitz S,Frege R,Jacobsen A,Weimer J,Arnold W,von Haefen C,Niederacher D,Schmutzler R,Arnold N,Scherneck S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CT60/4 cells (breast cancer reverted to normal by transfer of chromosome 8p region) vs parental MDA-MB-231 cells (deleted chromosome 8p).
Full description | Several investigations have supposed that tumor suppressor genes might be located on human chromosome 8. We used microcell-mediated transfer of chromosome 8 into MDA-MB-231 breast cancer cells and generated independent hybrids with strongly reduced tumorigenic potential. Loss of the transferred chromosome results in reappearance of the malignant phenotype. Expression analysis identified a set of 109 genes (CT8-ps) differentially expressed in microcell hybrids as compared to the tumorigenic MDA-MB-231 and rerevertant cells. Of these, 44.9% are differentially expressed in human breast tumors. The expression pattern of CT8-ps was associated with prognostic factors such as tumor size and grading as well as loss of heterozygosity at the short arm of chromosome 8. We identified CT8-ps networks suggesting that these genes act cooperatively to cause reversion of tumorigenicity in MDA-MB-231 cells. Our findings provide a conceptual basis and experimental system to identify and evaluate genes and gene networks involved in the development and/or progression of breast cancer.

Standard name | SEITZ_NEOPLASTIC_TRANSFORMATION_BY_8P_DELETION_DN
Systematic name | M740
Organism | Homo sapiens
PMID | 15580292
Authors | Seitz S,Frege R,Jacobsen A,Weimer J,Arnold W,von Haefen C,Niederacher D,Schmutzler R,Arnold N,Scherneck S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CT60/4 cells (breast cancer reverted to normal by transfer of chromosome 8p region) vs parental MDA-MB-231 cells (deleted chromosome 8p).
Full description | Several investigations have supposed that tumor suppressor genes might be located on human chromosome 8. We used microcell-mediated transfer of chromosome 8 into MDA-MB-231 breast cancer cells and generated independent hybrids with strongly reduced tumorigenic potential. Loss of the transferred chromosome results in reappearance of the malignant phenotype. Expression analysis identified a set of 109 genes (CT8-ps) differentially expressed in microcell hybrids as compared to the tumorigenic MDA-MB-231 and rerevertant cells. Of these, 44.9% are differentially expressed in human breast tumors. The expression pattern of CT8-ps was associated with prognostic factors such as tumor size and grading as well as loss of heterozygosity at the short arm of chromosome 8. We identified CT8-ps networks suggesting that these genes act cooperatively to cause reversion of tumorigenicity in MDA-MB-231 cells. Our findings provide a conceptual basis and experimental system to identify and evaluate genes and gene networks involved in the development and/or progression of breast cancer.

Standard name | YORDY_RECIPROCAL_REGULATION_BY_ETS1_AND_SP100_DN
Systematic name | M1208
Organism | Homo sapiens
PMID | 15592518
Authors | Yordy JS,Moussa O,Pei H,Chaussabel D,Li R,Watson DK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HUVEC cells (endothelium) by ETS1 [GeneID=2113] which were up-regulated by SP100 [GeneID=6672].
Full description | SP100 was first identified as a nuclear autoimmune antigen and is a constituent of the nuclear body. SP100 interacts with the ETS1 transcription factor, and we have previously shown that SP100 reduces ETS1-DNA binding and inhibits ETS1 transcriptional activity on the MMP1 and uPA promoters. We now demonstrate that SP100 expression is upregulated by interferons, which have been shown to be antiangiogenic, in primary endothelial cells. As ETS1 is functionally important in promoting angiogenesis, we tested the hypothesis that ETS1 activity is negatively modulated by SP100 in endothelial cells. SP100 directly antagonizes ETS1-mediated morphological changes in human umbilical vein endothelial cell (HUVEC) network formation and reduces HUVEC migration and invasion. To further understand the functional relationship between ETS1 and SP100, cDNA microarray analysis was utilized to assess reprogramming of gene expression by ETS1 and SP100. A subset of the differentially regulated genes, including heat-shock proteins (HSPs) H11, HSPA1L, HSPA6, HSPA8, HSPE1 and AXIN1, BRCA1, CD14, CTGF (connective tissue growth factor), GABRE (gamma-aminobutyric acid A receptor epsilon), ICAM1, SNAI1, SRD5A1 (steroid-5-alpha-reductase 1) and THY1, were validated by real-time PCR and a majority showed reciprocal expression in response to ETS1 and SP100. Interestingly, genes that are negatively regulated by ETS1 and upregulated by SP100 have antimigratory or antiangiogenic properties. Collectively, these data indicate that SP100 negatively modulates ETS1-dependent downstream biological processes.

Standard name | YORDY_RECIPROCAL_REGULATION_BY_ETS1_AND_SP100_UP
Systematic name | M1211
Organism | Homo sapiens
PMID | 15592518
Authors | Yordy JS,Moussa O,Pei H,Chaussabel D,Li R,Watson DK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HUVEC cells (endothelium) by ETS1 [GeneID=2113] which were down-regulated by SP100 [GeneID=6672].
Full description | SP100 was first identified as a nuclear autoimmune antigen and is a constituent of the nuclear body. SP100 interacts with the ETS1 transcription factor, and we have previously shown that SP100 reduces ETS1-DNA binding and inhibits ETS1 transcriptional activity on the MMP1 and uPA promoters. We now demonstrate that SP100 expression is upregulated by interferons, which have been shown to be antiangiogenic, in primary endothelial cells. As ETS1 is functionally important in promoting angiogenesis, we tested the hypothesis that ETS1 activity is negatively modulated by SP100 in endothelial cells. SP100 directly antagonizes ETS1-mediated morphological changes in human umbilical vein endothelial cell (HUVEC) network formation and reduces HUVEC migration and invasion. To further understand the functional relationship between ETS1 and SP100, cDNA microarray analysis was utilized to assess reprogramming of gene expression by ETS1 and SP100. A subset of the differentially regulated genes, including heat-shock proteins (HSPs) H11, HSPA1L, HSPA6, HSPA8, HSPE1 and AXIN1, BRCA1, CD14, CTGF (connective tissue growth factor), GABRE (gamma-aminobutyric acid A receptor epsilon), ICAM1, SNAI1, SRD5A1 (steroid-5-alpha-reductase 1) and THY1, were validated by real-time PCR and a majority showed reciprocal expression in response to ETS1 and SP100. Interestingly, genes that are negatively regulated by ETS1 and upregulated by SP100 have antimigratory or antiangiogenic properties. Collectively, these data indicate that SP100 negatively modulates ETS1-dependent downstream biological processes.

Standard name | MEINHOLD_OVARIAN_CANCER_LOW_GRADE_UP
Systematic name | M3003
Organism | Homo sapiens
PMID | 15558012
Authors | Meinhold-Heerlein I,Bauerschlag D,Hilpert F,Dimitrov P,Sapinoso LM,Orlowska-Volk M,Bauknecht T,Park TW,Jonat W,Jacobsen A,Sehouli J,Luttges J,Krajewski M,Krajewski S,Reed JC,Arnold N,Hampton GM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in low grade (LMP and G1) serous ovarian carcinomas vs the higher grade invasive tumors (G2 and G3).
Full description | Profiles of gene transcription have begun to delineate the molecular basis of ovarian cancer, including distinctions between carcinomas of differing histology, tumor progression and patient outcome. However, the similarities and differences among the most commonly diagnosed noninvasive borderline (low malignant potential, LMP) lesions and invasive serous carcinomas of varying grade (G1, G2 and G3) have not yet been explored. Here, we used oligonucleotide arrays to profile the expression of 12,500 genes in a series of 57 predominantly stage III serous ovarian adenocarcinomas from 52 patients, eight with borderline tumors and 44 with adenocarcinomas of varying grade. Unsupervised and supervised analyses showed that LMP lesions were distinct from high-grade serous adenocarcinomas, as might be expected; however, well-differentiated (G1) invasive adenocarcinomas showed a strikingly similar profile to LMP tumors as compared to cancers with moderate (G2) or poor (G3) cellular differentiation, which were also highly similar. Comparative genomic hybridization of an independent cohort of five LMP and 63 invasive carcinomas of varying grade demonstrated LMP and G1 were again similar, exhibiting significantly less chromosomal aberration than G2/G3 carcinomas. A majority of LMP and G1 tumors were characterized by high levels of p21/WAF1, with concomitant expression of cell growth suppressors, gadd34 and BTG-2. In contrast, G2/G3 cancers were characterized by the expression of genes associated with the cell cycle and by STAT-1-, STAT-3/JAK-1/2-induced gene expression. The distinction between the LMP-G1 and G2-G3 groups of tumors was highly correlated to patient outcome (chi(2) for equivalence of death rates=7.681189; P=0.0056, log-rank test). Our results are consistent with the recent demonstration of a poor differentiation molecular 'meta-signature' in human cancer, and underscore a number of cell-cycle- and STAT-associated targets that may prove useful as points of therapeutic intervention for those patients with aggressive disease.

Standard name | MEINHOLD_OVARIAN_CANCER_LOW_GRADE_DN
Systematic name | M867
Organism | Homo sapiens
PMID | 15558012
Authors | Meinhold-Heerlein I,Bauerschlag D,Hilpert F,Dimitrov P,Sapinoso LM,Orlowska-Volk M,Bauknecht T,Park TW,Jonat W,Jacobsen A,Sehouli J,Luttges J,Krajewski M,Krajewski S,Reed JC,Arnold N,Hampton GM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in low grade (LMP and G1) serous ovarian carcinomas vs the higher grade invasive tumors (G2 and G3).
Full description | Profiles of gene transcription have begun to delineate the molecular basis of ovarian cancer, including distinctions between carcinomas of differing histology, tumor progression and patient outcome. However, the similarities and differences among the most commonly diagnosed noninvasive borderline (low malignant potential, LMP) lesions and invasive serous carcinomas of varying grade (G1, G2 and G3) have not yet been explored. Here, we used oligonucleotide arrays to profile the expression of 12,500 genes in a series of 57 predominantly stage III serous ovarian adenocarcinomas from 52 patients, eight with borderline tumors and 44 with adenocarcinomas of varying grade. Unsupervised and supervised analyses showed that LMP lesions were distinct from high-grade serous adenocarcinomas, as might be expected; however, well-differentiated (G1) invasive adenocarcinomas showed a strikingly similar profile to LMP tumors as compared to cancers with moderate (G2) or poor (G3) cellular differentiation, which were also highly similar. Comparative genomic hybridization of an independent cohort of five LMP and 63 invasive carcinomas of varying grade demonstrated LMP and G1 were again similar, exhibiting significantly less chromosomal aberration than G2/G3 carcinomas. A majority of LMP and G1 tumors were characterized by high levels of p21/WAF1, with concomitant expression of cell growth suppressors, gadd34 and BTG-2. In contrast, G2/G3 cancers were characterized by the expression of genes associated with the cell cycle and by STAT-1-, STAT-3/JAK-1/2-induced gene expression. The distinction between the LMP-G1 and G2-G3 groups of tumors was highly correlated to patient outcome (chi(2) for equivalence of death rates=7.681189; P=0.0056, log-rank test). Our results are consistent with the recent demonstration of a poor differentiation molecular 'meta-signature' in human cancer, and underscore a number of cell-cycle- and STAT-associated targets that may prove useful as points of therapeutic intervention for those patients with aggressive disease.

Standard name | DACOSTA_ERCC3_ALLELE_XPCS_VS_TTD_UP
Systematic name | M16941
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in fibroblasts expressing different mutant forms of ERCC3 [GeneID=2071]: XP/CS (xeroderma pigmentosum (XP) and Cockraine's syndrome (CS)) vs TTD (trichothiodystrophy).
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | DACOSTA_ERCC3_ALLELE_XPCS_VS_TTD_DN
Systematic name | M7439
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in fibroblasts expressing different mutant forms of ERCC3 [GeneID=2071]: XP/CS (xeroderma pigmentosum (XP) and Cockraine's syndrome (CS)) vs TTD (trichothiodystrophy).
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | DACOSTA_LOW_DOSE_UV_RESPONSE_VIA_ERCC3_XPCS_UP
Systematic name | M17421
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in fibroblasts expressing the XP/CS mutant form of ERCC3 [GeneID=2071], after low dose UVC irradiation.
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | DACOSTA_LOW_DOSE_UV_RESPONSE_VIA_ERCC3_XPCS_DN
Systematic name | M14105
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in fibroblasts expressing the XP/CS mutant form of ERCC3 [GeneID=2071], after low dose UVC irradiation.
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | DACOSTA_UV_RESPONSE_VIA_ERCC3_UP
Systematic name | M11171
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in fibroblasts expressing mutant forms of ERCC3 [GeneID=2071] after UV irradiation.
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | DACOSTA_UV_RESPONSE_VIA_ERCC3_DN
Systematic name | M4500
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in fibroblasts expressing mutant forms of ERCC3 [GeneID=2071] after UV irradiation.
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | DACOSTA_UV_RESPONSE_VIA_ERCC3_COMMON_DN
Systematic name | M13522
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Common down-regulated transcripts in fibroblasts expressing either XP/CS or TDD mutant forms of ERCC3 [GeneID=2071], after UVC irradiation.
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | DIRMEIER_LMP1_RESPONSE_LATE_UP
Systematic name | M4976
Organism | Homo sapiens
PMID | 15674340
Authors | Dirmeier U,Hoffmann R,Kilger E,Schultheiss U,Briseño C,Gires O,Kieser A,Eick D,Sugden B,Hammerschmidt W
Category | C2
Sub-category | CGP
Brief description | Cluster 3: genes up-regulated in B2264-19/3 cells (primary B lymphocytes) within 60-180 min after activation of LMP1 (an oncogene encoded by Epstein-Barr virus, EBV).
Full description | Latent membrane protein 1 (LMP1), an oncoprotein encoded by Epstein-Barr virus (EBV), is an integral membrane protein, which acts like a constitutively active receptor. LMP1 is critical for some facet of EBV's induction and maintenance of proliferation of infected B cells. It, in part, mimics signaling by the CD40 receptor and has been implicated in regulating proliferation, survival, or both properties of EBV-infected cells. We established a conditional LMP1 allele in the context of the intact EBV genome to define the immediate-early cellular target genes regulated by LMP1 in order to assess its contributions to infected human B cells. The functional analysis of this conditional system indicated that LMP1 specifically induces mitogenic B-cell activation through c-myc and Jun/AP1 family members and confirms its direct role in upregulating expression of multiple genes with opposing activities involved in cell survival. LMP1's signals were found to be essential for the G1/S transition in human B cells; cells lacking LMP1's signals are cell cycle arrested and survive quiescently. LMP1's activities are therefore not required to maintain survival in nonproliferating cells. LMP1 does induce both pro- and antiapoptotic genes whose balance seems to permit survival during LMP1's induction and maintenance of proliferation.

Standard name | DIRMEIER_LMP1_RESPONSE_LATE_DN
Systematic name | M16713
Organism | Homo sapiens
PMID | 15674340
Authors | Dirmeier U,Hoffmann R,Kilger E,Schultheiss U,Briseño C,Gires O,Kieser A,Eick D,Sugden B,Hammerschmidt W
Category | C2
Sub-category | CGP
Brief description | Cluster 4: genes down-regulated in B2264-19/3 cells (primary B lymphocytes) within 60-180 min after activation of LMP1 (an oncogene encoded by Epstein-Barr virus, EBV).
Full description | Latent membrane protein 1 (LMP1), an oncoprotein encoded by Epstein-Barr virus (EBV), is an integral membrane protein, which acts like a constitutively active receptor. LMP1 is critical for some facet of EBV's induction and maintenance of proliferation of infected B cells. It, in part, mimics signaling by the CD40 receptor and has been implicated in regulating proliferation, survival, or both properties of EBV-infected cells. We established a conditional LMP1 allele in the context of the intact EBV genome to define the immediate-early cellular target genes regulated by LMP1 in order to assess its contributions to infected human B cells. The functional analysis of this conditional system indicated that LMP1 specifically induces mitogenic B-cell activation through c-myc and Jun/AP1 family members and confirms its direct role in upregulating expression of multiple genes with opposing activities involved in cell survival. LMP1's signals were found to be essential for the G1/S transition in human B cells; cells lacking LMP1's signals are cell cycle arrested and survive quiescently. LMP1's activities are therefore not required to maintain survival in nonproliferating cells. LMP1 does induce both pro- and antiapoptotic genes whose balance seems to permit survival during LMP1's induction and maintenance of proliferation.

Standard name | HEIDENBLAD_AMPLICON_8Q24_UP
Systematic name | M18260
Organism | Homo sapiens
PMID | 15688027
Authors | Heidenblad M,Lindgren D,Veltman JA,Jonson T,Mahlamäki EH,Gorunova L,Kessel van AG,Schoenmakers EF,Höglund M
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes whose expression is associated with amplification of the 8q24 chromosome region in pancreatic cancer cell lines.
Full description | DNA copy number alterations are believed to play a major role in the development and progression of human neoplasms. Although most of these genomic imbalances have been associated with dysregulation of individual genes, their large-scale transcriptional consequences remain unclear. Pancreatic carcinomas frequently display gene copy number variation of entire chromosomes as well as of chromosomal subregions. These changes range from homozygous deletions to high-level amplifications and are believed to constitute key genetic alterations in the cellular transformation of this tumor type. To investigate the transcriptional consequences of the most drastic genomic changes, that is, genomic amplifications, and to analyse the genome-wide transcriptional effects of DNA copy number changes, we performed expression profiling of 29 pancreatic carcinoma cell lines and compared the results with matching genomic profiling data. We show that a strong association between DNA copy numbers and mRNA expression levels is present in pancreatic cancer, and demonstrate that as much as 60% of the genes within highly amplified genomic regions display associated overexpression. Consequently, we identified 67 recurrently overexpressed genes located in seven precisely mapped commonly amplified regions. The presented findings indicate that more than one putative target gene may be of importance in most pancreatic cancer amplicons.

Standard name | HEIDENBLAD_AMPLICON_8Q24_DN
Systematic name | M11584
Organism | Homo sapiens
PMID | 15688027
Authors | Heidenblad M,Lindgren D,Veltman JA,Jonson T,Mahlamäki EH,Gorunova L,Kessel van AG,Schoenmakers EF,Höglund M
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes whose expression is associated with amplification of the 8q24 chromosome region in pancreatic cancer cell lines.
Full description | DNA copy number alterations are believed to play a major role in the development and progression of human neoplasms. Although most of these genomic imbalances have been associated with dysregulation of individual genes, their large-scale transcriptional consequences remain unclear. Pancreatic carcinomas frequently display gene copy number variation of entire chromosomes as well as of chromosomal subregions. These changes range from homozygous deletions to high-level amplifications and are believed to constitute key genetic alterations in the cellular transformation of this tumor type. To investigate the transcriptional consequences of the most drastic genomic changes, that is, genomic amplifications, and to analyse the genome-wide transcriptional effects of DNA copy number changes, we performed expression profiling of 29 pancreatic carcinoma cell lines and compared the results with matching genomic profiling data. We show that a strong association between DNA copy numbers and mRNA expression levels is present in pancreatic cancer, and demonstrate that as much as 60% of the genes within highly amplified genomic regions display associated overexpression. Consequently, we identified 67 recurrently overexpressed genes located in seven precisely mapped commonly amplified regions. The presented findings indicate that more than one putative target gene may be of importance in most pancreatic cancer amplicons.

Standard name | HEIDENBLAD_AMPLICON_12P11_12_UP
Systematic name | M8231
Organism | Homo sapiens
PMID | 15688027
Authors | Heidenblad M,Lindgren D,Veltman JA,Jonson T,Mahlamäki EH,Gorunova L,Kessel van AG,Schoenmakers EF,Höglund M
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes whose expression is associated with amplification of the 12p11-12 chromosome in pancreatic cancer cell lines.
Full description | DNA copy number alterations are believed to play a major role in the development and progression of human neoplasms. Although most of these genomic imbalances have been associated with dysregulation of individual genes, their large-scale transcriptional consequences remain unclear. Pancreatic carcinomas frequently display gene copy number variation of entire chromosomes as well as of chromosomal subregions. These changes range from homozygous deletions to high-level amplifications and are believed to constitute key genetic alterations in the cellular transformation of this tumor type. To investigate the transcriptional consequences of the most drastic genomic changes, that is, genomic amplifications, and to analyse the genome-wide transcriptional effects of DNA copy number changes, we performed expression profiling of 29 pancreatic carcinoma cell lines and compared the results with matching genomic profiling data. We show that a strong association between DNA copy numbers and mRNA expression levels is present in pancreatic cancer, and demonstrate that as much as 60% of the genes within highly amplified genomic regions display associated overexpression. Consequently, we identified 67 recurrently overexpressed genes located in seven precisely mapped commonly amplified regions. The presented findings indicate that more than one putative target gene may be of importance in most pancreatic cancer amplicons.

Standard name | HEIDENBLAD_AMPLICON_12P11_12_DN
Systematic name | M1602
Organism | Homo sapiens
PMID | 15688027
Authors | Heidenblad M,Lindgren D,Veltman JA,Jonson T,Mahlamäki EH,Gorunova L,Kessel van AG,Schoenmakers EF,Höglund M
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes whose expression is associated with amplification of the 12p11-12 chromosome in pancreatic cancer cell lines.
Full description | DNA copy number alterations are believed to play a major role in the development and progression of human neoplasms. Although most of these genomic imbalances have been associated with dysregulation of individual genes, their large-scale transcriptional consequences remain unclear. Pancreatic carcinomas frequently display gene copy number variation of entire chromosomes as well as of chromosomal subregions. These changes range from homozygous deletions to high-level amplifications and are believed to constitute key genetic alterations in the cellular transformation of this tumor type. To investigate the transcriptional consequences of the most drastic genomic changes, that is, genomic amplifications, and to analyse the genome-wide transcriptional effects of DNA copy number changes, we performed expression profiling of 29 pancreatic carcinoma cell lines and compared the results with matching genomic profiling data. We show that a strong association between DNA copy numbers and mRNA expression levels is present in pancreatic cancer, and demonstrate that as much as 60% of the genes within highly amplified genomic regions display associated overexpression. Consequently, we identified 67 recurrently overexpressed genes located in seven precisely mapped commonly amplified regions. The presented findings indicate that more than one putative target gene may be of importance in most pancreatic cancer amplicons.

Standard name | AMUNDSON_RESPONSE_TO_ARSENITE
Systematic name | M262
Organism | Homo sapiens
PMID | 15824734
Authors | Amundson SA,Do KT,Vinikoor L,Koch-Paiz CA,Bittner ML,Trent JM,Meltzer P,Fornace AJ Jr
Category | C2
Sub-category | CGP
Brief description | Genes discriminating responses to sodium arsenite [PubChem=26435] from other stresses.
Full description | Gene expression responses of human cell lines exposed to a diverse set of stress agents were compared by cDNA microarray hybridization. The B-lymphoblastoid cell line TK6 (p53 wild-type) and its p53-null derivative, NH32, were treated in parallel to facilitate investigation of p53-dependent responses. RNA was extracted 4 h after the beginning of treatment when no notable decrease in cell viability was evident in the cultures. Gene expression signatures were defined that discriminated between four broad general mechanisms of stress agents: Non-DNA-damaging stresses (heat shock, osmotic shock, and 12-O-tetradecanoylphorbol 13-acetate), agents causing mainly oxidative stress (arsenite and hydrogen peroxide), ionizing radiations (neutron and gamma-ray exposures), and other DNA-damaging agents (ultraviolet radiation, methyl methanesulfonate, adriamycin, camptothecin, and cis-Platinum(II)diammine dichloride (cisplatin)). Within this data set, non-DNA-damaging stresses could be discriminated from all DNA-damaging stresses, and profiles for individual agents were also defined. While DNA-damaging stresses showed a strong p53-dependent element in their responses, no discernible p53-dependent responses were triggered by the non-DNA-damaging stresses. A set of 16 genes did exhibit a robust p53-dependent pattern of induction in response to all nine DNA-damaging agents, however.

Standard name | FUNG_IL2_SIGNALING_2
Systematic name | M10198
Organism | Homo sapiens
PMID | 15735688
Authors | Fung MM,Chu YL,Fink JL,Wallace A,McGuire KL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by IL2 [GeneID=3558] in T1 cells (primary thymocytes immortalized by Tax, an HTLV-1 encoded gene).
Full description | Interleukin-2 (IL-2) mediates cell cycle progression and antiapoptosis in human T cells via several signal transduction pathways. The Tax protein of the human T-cell leukemia virus type I (HTLV-1) deregulates cell growth and alters the role of IL-2 in infected cells. However, Tax-immortalized cells stay dependent on IL-2, suggesting that events besides HTLV-1 gene expression are required for leukemia to develop. Here, IL-2-dependent and -independent events were analysed in a human T cell line immortalized by Tax. These studies show that, of the signaling pathways evaluated, only STAT5 remains dependent. Microarray analyses revealed several genes, including il-5, il-9 and il-13, are uniquely upregulated by IL-2 in the presence of Tax. Bioinformatics and supporting molecular biology show that some of these genes are STAT5 targets, explaining their IL-2 upregulation. These results suggest that IL-2 and viral proteins work together to induce gene expression, promoting the hypothesis that deregulation via the constitutive activation of STAT5 may lead to the IL-2-independent phenotype of HTLV-1-transformed cells.

Standard name | FUNG_IL2_SIGNALING_1
Systematic name | M14139
Organism | Homo sapiens
PMID | 15735688
Authors | Fung MM,Chu YL,Fink JL,Wallace A,McGuire KL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by IL2 [GeneID=3558] in both primary thymocytes and T1 cells (primary thymocytes immortalized by Tax, an HTLV-1 encoded gene).
Full description | Interleukin-2 (IL-2) mediates cell cycle progression and antiapoptosis in human T cells via several signal transduction pathways. The Tax protein of the human T-cell leukemia virus type I (HTLV-1) deregulates cell growth and alters the role of IL-2 in infected cells. However, Tax-immortalized cells stay dependent on IL-2, suggesting that events besides HTLV-1 gene expression are required for leukemia to develop. Here, IL-2-dependent and -independent events were analysed in a human T cell line immortalized by Tax. These studies show that, of the signaling pathways evaluated, only STAT5 remains dependent. Microarray analyses revealed several genes, including il-5, il-9 and il-13, are uniquely upregulated by IL-2 in the presence of Tax. Bioinformatics and supporting molecular biology show that some of these genes are STAT5 targets, explaining their IL-2 upregulation. These results suggest that IL-2 and viral proteins work together to induce gene expression, promoting the hypothesis that deregulation via the constitutive activation of STAT5 may lead to the IL-2-independent phenotype of HTLV-1-transformed cells.

Standard name | FUNG_IL2_TARGETS_WITH_STAT5_BINDING_SITES_T1
Systematic name | M5058
Organism | Homo sapiens
PMID | 15735688
Authors | Fung MM,Chu YL,Fink JL,Wallace A,McGuire KL
Category | C2
Sub-category | CGP
Brief description | Genes with putative STAT5 [GeneID=6777] binding sites; up-regulated by IL2 [GeneID=3558] only in T1 cells (primary thymocytes immortalized by Tax, an HTLV-1 encoded gene).
Full description | Interleukin-2 (IL-2) mediates cell cycle progression and antiapoptosis in human T cells via several signal transduction pathways. The Tax protein of the human T-cell leukemia virus type I (HTLV-1) deregulates cell growth and alters the role of IL-2 in infected cells. However, Tax-immortalized cells stay dependent on IL-2, suggesting that events besides HTLV-1 gene expression are required for leukemia to develop. Here, IL-2-dependent and -independent events were analysed in a human T cell line immortalized by Tax. These studies show that, of the signaling pathways evaluated, only STAT5 remains dependent. Microarray analyses revealed several genes, including il-5, il-9 and il-13, are uniquely upregulated by IL-2 in the presence of Tax. Bioinformatics and supporting molecular biology show that some of these genes are STAT5 targets, explaining their IL-2 upregulation. These results suggest that IL-2 and viral proteins work together to induce gene expression, promoting the hypothesis that deregulation via the constitutive activation of STAT5 may lead to the IL-2-independent phenotype of HTLV-1-transformed cells.

Standard name | FUNG_IL2_TARGETS_WITH_STAT5_BINDING_SITES
Systematic name | M19436
Organism | Homo sapiens
PMID | 15735688
Authors | Fung MM,Chu YL,Fink JL,Wallace A,McGuire KL
Category | C2
Sub-category | CGP
Brief description | Genes with putative STAT5 [GeneID=6777] binding sites; up-regulated by IL2 [Gene D=3558] in both primary thymocytes and T1 cells (primary thymocytes immortalized by Tax, an HTLV-1 encoded gene).
Full description | Interleukin-2 (IL-2) mediates cell cycle progression and antiapoptosis in human T cells via several signal transduction pathways. The Tax protein of the human T-cell leukemia virus type I (HTLV-1) deregulates cell growth and alters the role of IL-2 in infected cells. However, Tax-immortalized cells stay dependent on IL-2, suggesting that events besides HTLV-1 gene expression are required for leukemia to develop. Here, IL-2-dependent and -independent events were analysed in a human T cell line immortalized by Tax. These studies show that, of the signaling pathways evaluated, only STAT5 remains dependent. Microarray analyses revealed several genes, including il-5, il-9 and il-13, are uniquely upregulated by IL-2 in the presence of Tax. Bioinformatics and supporting molecular biology show that some of these genes are STAT5 targets, explaining their IL-2 upregulation. These results suggest that IL-2 and viral proteins work together to induce gene expression, promoting the hypothesis that deregulation via the constitutive activation of STAT5 may lead to the IL-2-independent phenotype of HTLV-1-transformed cells.

Standard name | SASAKI_TARGETS_OF_TP73_AND_TP63
Systematic name | M17374
Organism | Homo sapiens
PMID | 15856012
Authors | Sasaki Y,Naishiro Y,Oshima Y,Imai K,Nakamura Y,Tokino T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DLD1 cells (colon cancer) by p73 beta [GeneID=7161] or by and p63 gamma [GeneID=8626] but not by p53 [GeneID=7157].
Full description | p63 and p73 show a high degree of structural homology to p53 and are members of a family of transcriptional factors that can activate transcription of p53-responsive genes. p53 is mutated in more than 50% of human cancers, whereas p63 and p73 are rarely mutated. Studies of knockout mice also revealed an unexpected functional diversity among the p53 family. To determine how p63 and p73 are involved in tumorigenesis and normal development, we used cDNA microarray to examine 9216 genes in human colorectal cancer cells. We discovered that the expression of pigment epithelium-derived factor (PEDF) was specifically induced by either p63 or p73, but not by p53. We also report here that the PEDF gene contains a response element specific for p63 and p73 in its promoter region and is a direct target of p63 and p73. Collectively, p63 and p73 may be involved in cell fate by inducing PEDF expression.

Standard name | YANAGIHARA_ESX1_TARGETS
Systematic name | M1538
Organism | Homo sapiens
PMID | 15897875
Authors | Yanagihara M,Ishikawa S,Naito M,Nakajima J,Aburatani H,Hatakeyama M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in U2-OS Tet-On cells (osteosarcoma) after induction of ESX1 [GeneID=80712] expression.
Full description | Gain-of-function mutation of the K-ras gene is one of the most common genetic changes in human tumors. In tumors carrying K-ras mutation, the presence of oncogenic K-Ras is necessary for maintenance of the transformed phenotype. ESXR1 is a human paired-like homeodomain-containing protein expressed primarily in the testis. In cells, the 65-kDa full-length ESXR1 protein is proteolytically processed into an N-terminal 45-kDa fragment containing the homeodomain, which localizes exclusively within the nucleus, and a C-terminal 20-kDa fragment consisting of a proline-rich repeat region, which is located in the cytoplasm. In this work, we demonstrated that the N-terminal ESXR1 fragment specifically recognizes the TAATNNNATTA P3 consensus sequence for the paired-like homeodomain and functions as a sequence-specific transcriptional repressor. We also showed that the N-terminal ESXR1 fragment binds to the TAATGTTATTA sequence present within the first intron of the human K-ras gene and inhibits its expression at both mRNA and protein levels. Ectopic expression of the N-terminal ESXR1 fragment in human carcinoma cells that carry mutated K-ras reduces the level of K-Ras and thereby inhibits the tumor cell proliferation. Identification of ESXR1 as a transcriptional repressor of K-ras has an important implication for the development of cancer therapy that inhibits oncogenic K-Ras expression.

Standard name | WEINMANN_ADAPTATION_TO_HYPOXIA_UP
Systematic name | M11948
Organism | Homo sapiens
PMID | 15897868
Authors | Weinmann M,Belka C,Güner D,Goecke B,Müller I,Bamberg M,Jendrossek V
Category | C2
Sub-category | CGP
Brief description | Genes most up-regulated in hypoxia tolerant NCI H460 cells (lung cancer).
Full description | Tumor hypoxia is an adverse prognostic factor. In a recent study, we could demonstrate that cyclic hypoxia selects for hypoxia-tolerant tumor cells, which are cross-resistant to other stimuli of mitochondrial death pathways. In contrast, sensitivity of the cells to death-receptor ligands was mainly not affected. The aim of the present study was to further elucidate cellular changes induced by cyclic hypoxia and to identify alterations in gene expression pattern upon hypoxic selection by means of DNA-microarray analysis. Our data reveal that cyclic hypoxia resulted in the selection of cells with resistance to doxorubicine and radiation. Furthermore, hypoxic selection was accompanied by constitutive changes of the gene expression pattern with downregulation of 156 and upregulation of 82 genes. Most of the differentially regulated genes were involved in cellular responses to hypoxia and reoxygenation. While many of the genes that were downregulated upon hypoxic selection represent genes that are usually upregulated by acute hypoxia, the genes that were upregulated represent genes that are involved in stress resistance and anti-apoptotic signalling. Most importantly, hypoxic selection was not associated with changes of single apoptosis relevant genes, but with alterations in gene expression levels of a wide variety of genes indicating a more complex adaptation process.

Standard name | WEINMANN_ADAPTATION_TO_HYPOXIA_DN
Systematic name | M7137
Organism | Homo sapiens
PMID | 15897868
Authors | Weinmann M,Belka C,Güner D,Goecke B,Müller I,Bamberg M,Jendrossek V
Category | C2
Sub-category | CGP
Brief description | Genes most down-regulated in hypoxia tolerant NCI H460 cells (lung cancer).
Full description | Tumor hypoxia is an adverse prognostic factor. In a recent study, we could demonstrate that cyclic hypoxia selects for hypoxia-tolerant tumor cells, which are cross-resistant to other stimuli of mitochondrial death pathways. In contrast, sensitivity of the cells to death-receptor ligands was mainly not affected. The aim of the present study was to further elucidate cellular changes induced by cyclic hypoxia and to identify alterations in gene expression pattern upon hypoxic selection by means of DNA-microarray analysis. Our data reveal that cyclic hypoxia resulted in the selection of cells with resistance to doxorubicine and radiation. Furthermore, hypoxic selection was accompanied by constitutive changes of the gene expression pattern with downregulation of 156 and upregulation of 82 genes. Most of the differentially regulated genes were involved in cellular responses to hypoxia and reoxygenation. While many of the genes that were downregulated upon hypoxic selection represent genes that are usually upregulated by acute hypoxia, the genes that were upregulated represent genes that are involved in stress resistance and anti-apoptotic signalling. Most importantly, hypoxic selection was not associated with changes of single apoptosis relevant genes, but with alterations in gene expression levels of a wide variety of genes indicating a more complex adaptation process.

Standard name | TSUNODA_CISPLATIN_RESISTANCE_UP
Systematic name | M10202
Organism | Homo sapiens
PMID | 15608674
Authors | Tsunoda T,Koga H,Yokomizo A,Tatsugami K,Eto M,Inokuchi J,Hirata A,Masuda K,Okumura K,Naito S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in bladder cancer cells resistant to cisplatin [PubChem=2767] compared to the parental cells sensitive to the drug.
Full description | To investigate the molecules that regulate the acquisition of cis-diamminedichloroplatinum (II) (cisplatin) resistance, we performed cDNA microarrays using two pairs of parental and cisplatin-resistant bladder cancer cell lines. We found a markedly reduced expression of inositol 1,4,5-trisphosphate (IP3) receptor type1 (IP3R1), endoplasmic reticulum membrane protein, in cisplatin-resistant cells. The suppression of IP3R1 expression using small interfering RNA in parental cells prevented apoptosis and resulted in decreased sensitivity to cisplatin. Contrarily, overexpression of IP3R1 in resistant cells induced apoptosis and increased sensitivity to cisplatin. These results suggest that cisplatin-induced downregulation of IP3R1 expression was closely associated with the acquisition of cisplatin resistance in bladder cancer cells.

Standard name | TSUNODA_CISPLATIN_RESISTANCE_DN
Systematic name | M5014
Organism | Homo sapiens
PMID | 15608674
Authors | Tsunoda T,Koga H,Yokomizo A,Tatsugami K,Eto M,Inokuchi J,Hirata A,Masuda K,Okumura K,Naito S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in bladder cancer cells resistant to cisplatin [PubChem=2767] compared to the parental cells sensitive to the drug.
Full description | To investigate the molecules that regulate the acquisition of cis-diamminedichloroplatinum (II) (cisplatin) resistance, we performed cDNA microarrays using two pairs of parental and cisplatin-resistant bladder cancer cell lines. We found a markedly reduced expression of inositol 1,4,5-trisphosphate (IP3) receptor type1 (IP3R1), endoplasmic reticulum membrane protein, in cisplatin-resistant cells. The suppression of IP3R1 expression using small interfering RNA in parental cells prevented apoptosis and resulted in decreased sensitivity to cisplatin. Contrarily, overexpression of IP3R1 in resistant cells induced apoptosis and increased sensitivity to cisplatin. These results suggest that cisplatin-induced downregulation of IP3R1 expression was closely associated with the acquisition of cisplatin resistance in bladder cancer cells.

Standard name | MAINA_HYPOXIA_VHL_TARGETS_UP
Systematic name | M12398
Organism | Homo sapiens
PMID | 15824735
Authors | Maina EN,Morris MR,Zatyka M,Raval RR,Banks RE,Richards FM,Johnson CM,Maher ER
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by hypoxia in RCC4 cells (renal cell carcinoma) engineered to stably express VHL [GeneID=7428] off a plasmid vector.
Full description | Upregulation of hypoxia-inducible factors HIF-1 and HIF-2 is frequent in human cancers and may result from tissue hypoxia or genetic mechanisms, in particular the inactivation of the von Hippel-Lindau (VHL) tumour suppressor gene (TSG). Tumours with VHL inactivation are highly vascular, but it is unclear to what extent HIF-dependent and HIF-independent mechanisms account for pVHL tumour suppressor activity. As the identification of novel pVHL targets might provide insights into pVHL tumour suppressor activity, we performed gene expression microarray analysis in VHL-wild-type and VHL-null renal cell carcinoma (RCC) cell lines. We identified 30 differentially regulated pVHL targets (26 of which were 'novel') and the results of microarray analysis were confirmed in all 11 novel targets further analysed by real-time RT-PCR or Western blotting. Furthermore, nine of 11 targets were dysregulated in the majority of a series of primary clear cell RCC with VHL inactivation. Three of the nine targets had been identified previously as candidate TSGs (DOC-2/DAB2, CDKN1C and SPARC) and all were upregulated by wild-type pVHL. The significance for pVHL function of two further genes upregulated by wild-type pVHL was initially unclear, but re-expression of GNG4 (G protein gamma-4 subunit/guanine nucleotide-binding protein-4) and MLC2 (myosin light chain) in a RCC cell line suppressed tumour cell growth. pVHL regulation of CDKN1C, SPARC and GNG4 was not mimicked by hypoxia, whereas for six of 11 novel targets analysed (including DOC-2/DAB2 and MLC2) the effects of pVHL inactivation and hypoxia were similar. For GPR56 there was evidence of a tissue-specific hypoxia response. Such a phenomenon might, in part, explain organ-specific tumorigenesis in VHL disease. These provide insights into mechanisms of pVHL tumour suppressor function and identify novel hypoxia-responsive targets that might be implicated in tumorigenesis in both VHL disease and in other cancers with HIF upregulation.

Standard name | MARTORIATI_MDM4_TARGETS_NEUROEPITHELIUM_UP
Systematic name | M5681
Organism | Mus musculus
PMID | 15608685
Authors | Martoriati A,Doumont G,Alcalay M,Bellefroid E,Pelicci PG,Marine JC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in apoptotic tissues (neuroepithelium) after MDM4 [GeneID=4194] knockout.
Full description | The p53 tumour suppressor functions as a transcriptional activator, and several p53-inducible genes that play a critical proapoptotic role have been described. Moreover, p53 regulates the expression of various proteins participating in autoregulatory feedback loops, including proteins that negatively control p53 stability (Mdm2 and Pirh2) or modulate stress-induced phosphorylation of p53 on Ser-46 (p53DINP1 or Wip1), a key event for p53-induced apoptosis. Here, we describe a new systematic analysis of p53 targets using oligonucleotide chips, and report the identification of dapk1 as a novel p53 target. We demonstrate that dapk1 mRNA levels increase in a p53-dependent manner in various cellular settings. Both human and mouse dapk1 genomic loci contain DNA sequences that bind p53 in vitro and in vivo. Since dapk1 encodes a serine/threonine kinase previously shown to suppress oncogene-induced transformation by activating a p19ARF/p53-dependent apoptotic checkpoint, our results suggest that Dapk1 participates in a new positive feedback loop controlling p53 activation and apoptosis.

Standard name | MARTORIATI_MDM4_TARGETS_NEUROEPITHELIUM_DN
Systematic name | M12135
Organism | Mus musculus
PMID | 15608685
Authors | Martoriati A,Doumont G,Alcalay M,Bellefroid E,Pelicci PG,Marine JC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in apoptotic tissues (neuroepithelium) after MDM4 [GeneID=4194] knockout.
Full description | The p53 tumour suppressor functions as a transcriptional activator, and several p53-inducible genes that play a critical proapoptotic role have been described. Moreover, p53 regulates the expression of various proteins participating in autoregulatory feedback loops, including proteins that negatively control p53 stability (Mdm2 and Pirh2) or modulate stress-induced phosphorylation of p53 on Ser-46 (p53DINP1 or Wip1), a key event for p53-induced apoptosis. Here, we describe a new systematic analysis of p53 targets using oligonucleotide chips, and report the identification of dapk1 as a novel p53 target. We demonstrate that dapk1 mRNA levels increase in a p53-dependent manner in various cellular settings. Both human and mouse dapk1 genomic loci contain DNA sequences that bind p53 in vitro and in vivo. Since dapk1 encodes a serine/threonine kinase previously shown to suppress oncogene-induced transformation by activating a p19ARF/p53-dependent apoptotic checkpoint, our results suggest that Dapk1 participates in a new positive feedback loop controlling p53 activation and apoptosis.

Standard name | MARTORIATI_MDM4_TARGETS_FETAL_LIVER_UP
Systematic name | M1570
Organism | Mus musculus
PMID | 15608685
Authors | Martoriati A,Doumont G,Alcalay M,Bellefroid E,Pelicci PG,Marine JC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in non-apoptotic tissues (fetal liver) after MDM4 [GeneID=4194] knockout.
Full description | The p53 tumour suppressor functions as a transcriptional activator, and several p53-inducible genes that play a critical proapoptotic role have been described. Moreover, p53 regulates the expression of various proteins participating in autoregulatory feedback loops, including proteins that negatively control p53 stability (Mdm2 and Pirh2) or modulate stress-induced phosphorylation of p53 on Ser-46 (p53DINP1 or Wip1), a key event for p53-induced apoptosis. Here, we describe a new systematic analysis of p53 targets using oligonucleotide chips, and report the identification of dapk1 as a novel p53 target. We demonstrate that dapk1 mRNA levels increase in a p53-dependent manner in various cellular settings. Both human and mouse dapk1 genomic loci contain DNA sequences that bind p53 in vitro and in vivo. Since dapk1 encodes a serine/threonine kinase previously shown to suppress oncogene-induced transformation by activating a p19ARF/p53-dependent apoptotic checkpoint, our results suggest that Dapk1 participates in a new positive feedback loop controlling p53 activation and apoptosis.

Standard name | MARTORIATI_MDM4_TARGETS_FETAL_LIVER_DN
Systematic name | M3395
Organism | Mus musculus
PMID | 15608685
Authors | Martoriati A,Doumont G,Alcalay M,Bellefroid E,Pelicci PG,Marine JC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in non-apoptotic tissues (fetal liver) after MDM4 [GeneID=4194] knockout.
Full description | The p53 tumour suppressor functions as a transcriptional activator, and several p53-inducible genes that play a critical proapoptotic role have been described. Moreover, p53 regulates the expression of various proteins participating in autoregulatory feedback loops, including proteins that negatively control p53 stability (Mdm2 and Pirh2) or modulate stress-induced phosphorylation of p53 on Ser-46 (p53DINP1 or Wip1), a key event for p53-induced apoptosis. Here, we describe a new systematic analysis of p53 targets using oligonucleotide chips, and report the identification of dapk1 as a novel p53 target. We demonstrate that dapk1 mRNA levels increase in a p53-dependent manner in various cellular settings. Both human and mouse dapk1 genomic loci contain DNA sequences that bind p53 in vitro and in vivo. Since dapk1 encodes a serine/threonine kinase previously shown to suppress oncogene-induced transformation by activating a p19ARF/p53-dependent apoptotic checkpoint, our results suggest that Dapk1 participates in a new positive feedback loop controlling p53 activation and apoptosis.

Standard name | LI_WILMS_TUMOR_ANAPLASTIC_UP
Systematic name | M1215
Organism | Homo sapiens
PMID | 15531917
Authors | Li W,Kessler P,Williams BR
Category | C2
Sub-category | CGP
Brief description | Selected up-regulated genes distinguishing between Wilms tumors of different histological types: anaplastic vs favorable histology.
Full description | Anaplasia (unfavorable histology) is associated with therapy resistance and poor prognosis of Wilms tumor, but the molecular basis for this phenotype is unclear. Here, we used a cDNA array with 9240 clones relevant to cancer biology and/or kidney development to examine the expression profiles of 54 Wilms tumors, five normal kidneys and fetal kidney. By linking genes differentially expressed between fetal kidney and Wilms tumors to kidney morphogenesis, we found that genes expressed at a higher level in Wilms tumors tend to be expressed more in uninduced metanephrogenic mesenchyme or blastema than in their differentiated structures. Conversely, genes expressed at a lower level in Wilms tumors tend to be expressed less in uninduced metanephrogenic mesenchyme or blastema. We also identified 97 clones representing 76 Unigenes or unclustered ESTs that clearly separate anaplastic Wilms tumors from tumors with favorable histology. Genes in this set provide insight into the nature of the abnormal nuclear morphology of anaplastic tumors and may facilitate identification of molecular targets to improve their responsiveness to treatment.

Standard name | LI_WILMS_TUMOR_ANAPLASTIC_DN
Systematic name | M1216
Organism | Homo sapiens
PMID | 15531917
Authors | Li W,Kessler P,Williams BR
Category | C2
Sub-category | CGP
Brief description | Selected down-regulated genes distinguishing between Wilms tumors of different histological types: anaplastic vs favorable histology.
Full description | Anaplasia (unfavorable histology) is associated with therapy resistance and poor prognosis of Wilms tumor, but the molecular basis for this phenotype is unclear. Here, we used a cDNA array with 9240 clones relevant to cancer biology and/or kidney development to examine the expression profiles of 54 Wilms tumors, five normal kidneys and fetal kidney. By linking genes differentially expressed between fetal kidney and Wilms tumors to kidney morphogenesis, we found that genes expressed at a higher level in Wilms tumors tend to be expressed more in uninduced metanephrogenic mesenchyme or blastema than in their differentiated structures. Conversely, genes expressed at a lower level in Wilms tumors tend to be expressed less in uninduced metanephrogenic mesenchyme or blastema. We also identified 97 clones representing 76 Unigenes or unclustered ESTs that clearly separate anaplastic Wilms tumors from tumors with favorable histology. Genes in this set provide insight into the nature of the abnormal nuclear morphology of anaplastic tumors and may facilitate identification of molecular targets to improve their responsiveness to treatment.

Standard name | BORLAK_LIVER_CANCER_EGF_UP
Systematic name | M1218
Organism | Mus musculus
PMID | 15674348
Authors | Borlak J,Meier T,Halter R,Spanel R,Spanel-Borowski K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) developed by transgenic mice overexpressing a secretable form of EGF [GeneID=1950] in liver.
Full description | Epidermal growth factor is an important mitogen for hepatocytes. Its overexpression promotes hepatocellular carcinogenesis. To identify the network of genes regulated through EGF, we investigated the liver transcriptome during various stages of hepatocarcinogenesis in EGF2B transgenic mice. Targeted overexpression of IgEGF induced distinct hepatocellular lesions and eventually solid tumours at the age of 6-8 months, as evidenced by histopathology. We used the murine MG U74Av2 oligonucleotide microarrays to identify transcript signatures in 12 tumours of small (n=5, pooled), medium (n=4) and large sizes (n=3), and compared the findings with three nontumorous transgenic livers and four control livers. Global gene expression analysis at successive stages of carcinogenesis revealed hallmarks linked to tumour size. A comparison of gene expression profiles of nontumorous transgenic liver versus control liver provided insight into the initial events predisposing liver cells to malignant transformation, and we found overexpression of c-fos, eps-15, TGIF, IGFBP1, Alcam, ets-2 and repression of Gas-1 as distinct events. Further, when gene expression profiles of small manifested tumours were compared with nontumorous transgenic liver, additional changes were obvious and included overexpression of junB, Id-1, minopontin, villin, claudin-7, RR M2, p34cdc2, cyclinD1 and cyclinB1 among others. These genes are therefore strongly associated with tumour formation. Our study provided new information on the tumour stage-dependent network of EGF-regulated genes, and we identified candidate genes linked to tumorigenes and progression of disease.

Standard name | MANN_RESPONSE_TO_AMIFOSTINE_UP
Systematic name | M18954
Organism | Homo sapiens
PMID | 15750621
Authors | Mann K,Hainaut P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HCT116 cells (colon cancer) after treatment with amifostine [PubChem=2141] depending on the presence of TP53 [GeneID=7157]: TP53-positive vs TP53-null cells.
Full description | The aminothiol WR1065 exerts selective cytoprotective effects in normal cells compared to cancer cells and has clinical applications for the protection of normal cells in cancer patients undergoing radio- or chemotherapy. There is evidence that p53 is activated in response to WR1065. To examine the effects of WR1065 on the signalling pathways controlled by p53, isogeneic human colon carcinoma cell lines (HCT116) differing only in the presence or absence of wild-type p53 were used. Treatment with WR1065 resulted in G1 cell cycle arrest in the p53-positive cell line but not in the p53-negative cell line. Long-term exposure resulted in minimal apoptosis of either cell line. Changes in gene expression in p53-positive or -negative cells treated with WR1065 were examined using commercial human stress and cancer gene arrays (Clontech Atlas arrays). Genes found to be specifically upregulated in a p53-dependent manner included coproporphyrinogen oxidase, ICErel-II cysteine protease, macrophage inhibitory cytokine-1 (also known as placental transforming growth factor beta), S100A4, and Waf1/p21. However, most proapoptotic genes typically upregulated by p53 in response to DNA damage were not activated. These studies show that WR1065 specifically modulates a subset of p53 target genes in a colon carcinoma cell line, consistent with the observation that this agent elicits essentially p53-dependent, cell cycle arrest responses.

Standard name | MANN_RESPONSE_TO_AMIFOSTINE_DN
Systematic name | M16463
Organism | Homo sapiens
PMID | 15750621
Authors | Mann K,Hainaut P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HCT116 cells (colon cancer) after treatment with amifostine [PubChem=2141] depending on the presence of TP53 [GeneID=7157]: TP53-positive vs TP53-null cells.
Full description | The aminothiol WR1065 exerts selective cytoprotective effects in normal cells compared to cancer cells and has clinical applications for the protection of normal cells in cancer patients undergoing radio- or chemotherapy. There is evidence that p53 is activated in response to WR1065. To examine the effects of WR1065 on the signalling pathways controlled by p53, isogeneic human colon carcinoma cell lines (HCT116) differing only in the presence or absence of wild-type p53 were used. Treatment with WR1065 resulted in G1 cell cycle arrest in the p53-positive cell line but not in the p53-negative cell line. Long-term exposure resulted in minimal apoptosis of either cell line. Changes in gene expression in p53-positive or -negative cells treated with WR1065 were examined using commercial human stress and cancer gene arrays (Clontech Atlas arrays). Genes found to be specifically upregulated in a p53-dependent manner included coproporphyrinogen oxidase, ICErel-II cysteine protease, macrophage inhibitory cytokine-1 (also known as placental transforming growth factor beta), S100A4, and Waf1/p21. However, most proapoptotic genes typically upregulated by p53 in response to DNA damage were not activated. These studies show that WR1065 specifically modulates a subset of p53 target genes in a colon carcinoma cell line, consistent with the observation that this agent elicits essentially p53-dependent, cell cycle arrest responses.

Standard name | YAN_ESCAPE_FROM_ANOIKIS
Systematic name | M1221
Organism | Rattus norvegicus
PMID | 16007176
Authors | Yan SR,Joseph RR,Rosen K,Reginato MJ,Jackson A,Allaire N,Brugge JS,Jobin C,Stadnyk AW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in IEC-18 cells (intestinal epithelial cells) which avoided anoikis (a form of apoptosis) after detachment.
Full description | We reported earlier that IL-1beta, an NF-kappaB-regulated cytokine, was made by intestinal epithelial cells during detachment-induced apoptosis (anoikis) and that IL-1 was antiapoptotic for detached cells. Since surviving anoikis is a prerequisite for cancer progression and metastases, we are further exploring the link between anoikis and cytokines. Here we determined that multiple genes are expressed following detachment including a number of NF-kappaB-regulated products and therefore aimed to determine whether NF-kappaB signalling plays any role in regulating apoptosis. Using Western blotting, we detected that IkappaBalpha becomes phosphorylated immediately following detachment and that levels of phospho-IkappaBalpha peaked within 20 min. Phosphorylation of IkappaBalpha was followed by Rel A (p65) nuclear translocation. Increased NF-kappaB activity following detachment was confirmed using the detection of NF-kappaB-promoted luciferase gene expression delivered by adenovirus infection. Infection of cells with adenovirus expressing a super-repressor IkappaBalpha protein and pharmacological inhibitors of NF-kappaB resulted in the failure to phosphorylate IkappaBalpha, a more rapid activation of caspases and earlier apoptosis. We also detected that IkappaB kinase alpha (IKKalpha) and not IKKbeta became phosphorylated following detachment. Since IKKalpha is activated by NF-kappaB-inducing kinase (NIK), we overexpressed native NIK using an adenovirus vector that resulted in enhanced phospho-IkappaBalpha and nuclear p65 in detached cells compared to control detached cells but did not result in a significantly greater number of cells surviving to 24 h. We conclude that detachment directly activates NF-kappaB, which, in addition to launching an inflammatory cytokine wave, contributes to a delay in apoptosis in intestinal epithelial cells.

Standard name | LIEN_BREAST_CARCINOMA_METAPLASTIC_VS_DUCTAL_UP
Systematic name | M15975
Organism | Homo sapiens
PMID | 17603561
Authors | Lien HC,Hsiao YH,Lin YS,Yao YT,Juan HF,Kuo WH,Hung MC,Chang KJ,Hsieh FJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated between two breast carcinoma subtypes: metaplastic (MCB) and ductal (DCB).
Full description | Metaplastic carcinoma of the breast (MCB) is a poorly understood subtype of breast cancer. It is generally characterized by the coexistence of ductal carcinomatous and transdifferentiated sarcomatous components, but the underlying molecular alterations, possibly related to epithelial-mesenchymal transition (EMT), remain elusive. We performed transcriptional profiling using half-a-genome oligonucleotide microarrays to elucidate genetic profiles of MCBs and their differences to those of ductal carcinoma of breasts (DCBs) using discarded specimens of four MCBs and 34 DCBs. Unsupervised clustering disclosed distinctive expression profiles between MCBs and DCBs. Supervised analysis identified gene signatures discriminating MCBs from DCBs and between MCB subclasses. Notably, many of the discriminator genes were associated with downregulation of epithelial phenotypes and with synthesis, remodeling and adhesion of extracellular matrix, with some of them have known or inferred roles related to EMT. Importantly, several of the discriminator genes were upregulated in a mutant Snail-transfected MCF7 cell known to exhibit features of EMT, thereby indicating a crucial role for EMT in the pathogenesis of MCBs. Finally, the identification of SPARC and vimentin as poor prognostic factors reinforced the role of EMT in cancer progression. These data advance our understanding of MCB and offer clues to the molecular alterations underlying EMT.

Standard name | LIEN_BREAST_CARCINOMA_METAPLASTIC_VS_DUCTAL_DN
Systematic name | M737
Organism | Homo sapiens
PMID | 17603561
Authors | Lien HC,Hsiao YH,Lin YS,Yao YT,Juan HF,Kuo WH,Hung MC,Chang KJ,Hsieh FJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated between two breast carcinoma subtypes: metaplastic (MCB) and ductal (DCB).
Full description | Metaplastic carcinoma of the breast (MCB) is a poorly understood subtype of breast cancer. It is generally characterized by the coexistence of ductal carcinomatous and transdifferentiated sarcomatous components, but the underlying molecular alterations, possibly related to epithelial-mesenchymal transition (EMT), remain elusive. We performed transcriptional profiling using half-a-genome oligonucleotide microarrays to elucidate genetic profiles of MCBs and their differences to those of ductal carcinoma of breasts (DCBs) using discarded specimens of four MCBs and 34 DCBs. Unsupervised clustering disclosed distinctive expression profiles between MCBs and DCBs. Supervised analysis identified gene signatures discriminating MCBs from DCBs and between MCB subclasses. Notably, many of the discriminator genes were associated with downregulation of epithelial phenotypes and with synthesis, remodeling and adhesion of extracellular matrix, with some of them have known or inferred roles related to EMT. Importantly, several of the discriminator genes were upregulated in a mutant Snail-transfected MCF7 cell known to exhibit features of EMT, thereby indicating a crucial role for EMT in the pathogenesis of MCBs. Finally, the identification of SPARC and vimentin as poor prognostic factors reinforced the role of EMT in cancer progression. These data advance our understanding of MCB and offer clues to the molecular alterations underlying EMT.

Standard name | WOOD_EBV_EBNA1_TARGETS_UP
Systematic name | M1696
Organism | Homo sapiens
PMID | 17486072
Authors | Wood VH,O'Neil JD,Wei W,Stewart SE,Dawson CW,Young LS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the Ad/AH cells (adenocarcinoma) engineered to stably express the Epstein-Barr virus (EBV) gene EBNA1.
Full description | The Epstein-Barr virus (EBV)-encoded EBNA1 protein is expressed in all virus-associated tumors where it plays an essential role in the maintenance, replication and transcription of the EBV genome. Transcriptional profiling of EBNA1-expressing carcinoma cells demonstrated that EBNA1 also influences the expression of a range of cellular genes including those involved in translation, transcription and cell signaling. Of particular interest was the ability of EBNA1 to enhance expression of STAT1 and sensitize cells to interferon-induced STAT1 activation with resultant enhancement of major histocompatibility complex expression. A negative effect of EBNA1 on the expression of TGFbeta1-responsive betaig-h3 and PAI-1 genes was confirmed at the protein level in EBV-infected carcinoma cells. This effect resulted from the ability of EBNA1 to repress TGFbeta1-induced transcription via a reduction in the interaction of SMAD2 with SMAD4. More detailed analysis revealed that EBNA1 induces a lower steady-state level of SMAD2 protein as a consequence of increased protein turnover. These data show that EBNA1 can influence cellular gene transcription resulting in effects that may contribute to the development of EBV-associated tumors.

Standard name | WOOD_EBV_EBNA1_TARGETS_DN
Systematic name | M19460
Organism | Homo sapiens
PMID | 17486072
Authors | Wood VH,O'Neil JD,Wei W,Stewart SE,Dawson CW,Young LS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the Ad/AH cells (adenocarcinoma) engineered to stably express the Epstein-Barr virus (EBV) gene EBNA1.
Full description | The Epstein-Barr virus (EBV)-encoded EBNA1 protein is expressed in all virus-associated tumors where it plays an essential role in the maintenance, replication and transcription of the EBV genome. Transcriptional profiling of EBNA1-expressing carcinoma cells demonstrated that EBNA1 also influences the expression of a range of cellular genes including those involved in translation, transcription and cell signaling. Of particular interest was the ability of EBNA1 to enhance expression of STAT1 and sensitize cells to interferon-induced STAT1 activation with resultant enhancement of major histocompatibility complex expression. A negative effect of EBNA1 on the expression of TGFbeta1-responsive betaig-h3 and PAI-1 genes was confirmed at the protein level in EBV-infected carcinoma cells. This effect resulted from the ability of EBNA1 to repress TGFbeta1-induced transcription via a reduction in the interaction of SMAD2 with SMAD4. More detailed analysis revealed that EBNA1 induces a lower steady-state level of SMAD2 protein as a consequence of increased protein turnover. These data show that EBNA1 can influence cellular gene transcription resulting in effects that may contribute to the development of EBV-associated tumors.

Standard name | MOHANKUMAR_HOXA1_TARGETS_UP
Systematic name | M4399
Organism | Homo sapiens
PMID | 17213808
Authors | Mohankumar KM,Xu XQ,Zhu T,Kannan N,Miller LD,Liu ET,Gluckman PD,Sukumar S,Emerald BS,Lobie PE
Category | C2
Sub-category | CGP
Brief description | Up-regulated in MCF7 cells (breast cancer) by HOXA1 [GeneID=3198].
Full description | Expression of homeobox A1 (HOXA1) results in oncogenic transformation of immortalized human mammary epithelial cells with aggressive tumor formation in vivo. However, the mechanisms by which HOXA1 mediates oncogenic transformation is not well defined. To identify molecules that could potentially be involved in HOXA1-mediated oncogenic transformation, microarray analysis was utilized to characterize and compare the gene expression pattern in response to forced expression or depletion of HOXA1 in human mammary carcinoma cells. Gene expression profiling identified that genes involved in the p44/42 mitogen-activated protein (MAP) kinase activation pathway (GRB2, MAP kinase kinase (MEK1) and SDFR1) or p44/42 MAP kinase-regulated genes (IER3, EPAS1, PCNA and catalase) are downstream expression targets of HOXA1. Forced expression of HOXA1 increased GRB2 and MEK1 mRNA and protein expression and increased p44/42 MAP kinase phosphorylation, activity and Elk-1-mediated transcription. Use of a MEK1 inhibitor demonstrated that increased p44/42 MAP kinase activity is required for the HOXA1-mediated increase in cell proliferation, survival, oncogenicity and oncogenic transformation. Thus, modulation of the p44/42 MAP kinase pathway is one mechanism by which HOXA1 mediates oncogenic transformation of the human mammary epithelial cell.

Standard name | MOHANKUMAR_HOXA1_TARGETS_DN
Systematic name | M9032
Organism | Homo sapiens
PMID | 17213808
Authors | Mohankumar KM,Xu XQ,Zhu T,Kannan N,Miller LD,Liu ET,Gluckman PD,Sukumar S,Emerald BS,Lobie PE
Category | C2
Sub-category | CGP
Brief description | Down-regulated in MCF7 cells (breast cancer) by HOXA1 [GeneID=3198].
Full description | Expression of homeobox A1 (HOXA1) results in oncogenic transformation of immortalized human mammary epithelial cells with aggressive tumor formation in vivo. However, the mechanisms by which HOXA1 mediates oncogenic transformation is not well defined. To identify molecules that could potentially be involved in HOXA1-mediated oncogenic transformation, microarray analysis was utilized to characterize and compare the gene expression pattern in response to forced expression or depletion of HOXA1 in human mammary carcinoma cells. Gene expression profiling identified that genes involved in the p44/42 mitogen-activated protein (MAP) kinase activation pathway (GRB2, MAP kinase kinase (MEK1) and SDFR1) or p44/42 MAP kinase-regulated genes (IER3, EPAS1, PCNA and catalase) are downstream expression targets of HOXA1. Forced expression of HOXA1 increased GRB2 and MEK1 mRNA and protein expression and increased p44/42 MAP kinase phosphorylation, activity and Elk-1-mediated transcription. Use of a MEK1 inhibitor demonstrated that increased p44/42 MAP kinase activity is required for the HOXA1-mediated increase in cell proliferation, survival, oncogenicity and oncogenic transformation. Thus, modulation of the p44/42 MAP kinase pathway is one mechanism by which HOXA1 mediates oncogenic transformation of the human mammary epithelial cell.

Standard name | DAWSON_METHYLATED_IN_LYMPHOMA_TCL1
Systematic name | M1238
Organism | Mus musculus
PMID | 17260020
Authors | Dawson DW,Hong JS,Shen RR,French SW,Troke JJ,Wu YZ,Chen SS,Gui D,Regelson M,Marahrens Y,Morse HC 3rd,Said J,Plass C,Teitell MA
Category | C2
Sub-category | CGP
Brief description | Genes hypermethylated in at least one of the lymphoma tumors of transgenic mice overexpressing TCL1 [GeneID=8115] in germinal center B lymphocytes.
Full description | Most human lymphomas originate from transformed germinal center (GC) B lymphocytes. While activating mutations and translocations of MYC, BCL2 and BCL6 promote specific GC lymphoma subtypes, other genetic and epigenetic modifications that contribute to malignant progression in the GC remain poorly defined. Recently, aberrant expression of the TCL1 proto-oncogene was identified in major GC lymphoma subtypes. TCL1 transgenic mice offer unique models of both aggressive GC and marginal zone B-cell lymphomas, further supporting a role for TCL1 in B-cell transformation. Here, restriction landmark genomic scanning was employed to discover tumor-associated epigenetic alterations in malignant GC and marginal zone B-cells in TCL1 transgenic mice. Multiple genes were identified that underwent DNA hypermethylation and decreased expression in TCL1 transgenic tumors. Further, we identified a secreted isoform of EPHA7, a member of the Eph family of receptor tyrosine kinases that are able to influence tumor invasiveness, metastasis and neovascularization. EPHA7 was hypermethylated and repressed in both mouse and human GC B-cell non-Hodgkin lymphomas, with the potential to influence tumor progression and spread. These data provide the first set of hypermethylated genes with the potential to complement TCL1-mediated GC B-cell transformation and spread.

Standard name | MURATA_VIRULENCE_OF_H_PILORI
Systematic name | M18608
Organism | Homo sapiens
PMID | 17237808
Authors | Murata-Kamiya N,Kurashima Y,Teishikata Y,Yamahashi Y,Saito Y,Higashi H,Aburatani H,Akiyama T,Peek RM Jr,Azuma T,Hatakeyama M
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated in WT-A10 cells (gastric epithelium) expressing the H. pilori virulence gene CagA.
Full description | Infection with Helicobacter pylori cagA-positive strains is associated with gastric adenocarcinoma. Intestinal metaplasia is a precancerous lesion of the stomach characterized by transdifferentiation of the gastric mucosa to an intestinal phenotype. The H. pylori cagA gene product, CagA, is delivered into gastric epithelial cells, where it undergoes tyrosine phosphorylation by Src family kinases. Tyrosine-phosphorylated CagA specifically binds to and activates SHP-2 phosphatase, thereby inducing cell-morphological transformation. We report here that CagA physically interacts with E-cadherin independently of CagA tyrosine phosphorylation. The CagA/E-cadherin interaction impairs the complex formation between E-cadherin and beta-catenin, causing cytoplasmic and nuclear accumulation of beta-catenin. CagA-deregulated beta-catenin then transactivates beta-catenin-dependent genes such as cdx1, which encodes intestinal specific CDX1 transcription factor. In addition to beta-catenin signal, CagA also transactivates p21(WAF1/Cip1), again, in a phosphorylation-independent manner. Consequently, CagA induces aberrant expression of an intestinal-differentiation marker, goblet-cell mucin MUC2, in gastric epithelial cells that have been arrested in G1 by p21(WAF1/Cip1). These results indicate that perturbation of the E-cadherin/beta-catenin complex by H. pylori CagA plays an important role in the development of intestinal metaplasia, a premalignant transdifferentiation of gastric epithelial cells from which intestinal-type gastric adenocarcinoma arises.

Standard name | WANG_HCP_PROSTATE_CANCER
Systematic name | M17044
Organism | Homo sapiens
PMID | 17486081
Authors | Wang Q,Williamson M,Bott S,Brookman-Amissah N,Freeman A,Nariculam J,Hubank MJ,Ahmed A,Masters JR
Category | C2
Sub-category | CGP
Brief description | Genes with the high-CpG-density promoters (HCP) that were up-regulated in 1542-CP3TX cells (prostate cancer) compared to 1542-NPTX (normal prostate).
Full description | Oligoarray analysis of a matched pair of prostate cancer and normal cell lines derived from the same radical prostatectomy specimen identified 113 candidate hypomethylated genes that were overexpressed in the cancer cells and contained CpG islands. Hypomethylation of wingless-related MMTV integration site 5A (WNT5A), S100 calcium-binding protein P (S100P) and cysteine-rich protein 1(CRIP1) was confirmed in the cancer cells by bisulfite sequencing. Treatment of the corresponding normal prostate epithelial cells 1542-NPTX with the DNA methyltransferase inhibitor 5-Aza-2'-deoxycytidine (5-aza-CdR) induced higher levels of mRNA expression and partial loss of methylation on these genes. Primary prostate cancers were tested using methylation-specific polymerase chain reaction. WNT5A was hypomethylated in 11/17 (65%) tumors, S100P in 8/16 (50%) and CRIP1 in 13/20 (65%). Bisulfite sequencing of a section of the 5' untranslated region (UTR) of WNT5A revealed that three CpG sites (15, 24 and 35) were consistently methylated (93%) in the normal cell line and normal tissues, but not in the prostate cancer cell line and eight primary prostate cancers. Multiple putative binding sites for the transcription factors SP1 and AP-2 were found adjacent to CpG sites 15 and 24. A putative c-Myb binding site was located within the CpG site 35. Anti-c-Myb antibody co-precipitation with WNT5A was methylation-sensitive in 1542-NPTX cells. It is likely that an epigenetic mechanism regulates WNT5A expression in prostate cancer.

Standard name | JOHANSSON_BRAIN_CANCER_EARLY_VS_LATE_UP
Systematic name | M1239
Organism | Mus musculus
PMID | 15750623
Authors | Johansson FK,Göransson H,Westermark B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in early vs late brain tumors induced by retroviral delivery of PDGFB [GeneID=5155].
Full description | Retroviral tagging previously identified putative cancer-causing genes in a mouse brain tumor model where a recombinant Moloney murine leukemia virus encoding the platelet-derived growth factor B-chain (MMLV/PDGFB) was intracerebrally injected in newborn mice. In the present study, expression analysis using cDNA arrays revealed several similarities of virus-induced mouse gliomas with human brain tumors. Brain tumors with short latency contained on average 8.0 retroviral insertions and resembled human glioblastoma multiforme (GBM) whereas long-latency gliomas were of lower grade, similar to human oligodendroglioma (OD) and had 2.3 insertions per tumor. Several known and novel genes of tumor progression or cell markers were differentially expressed between OD- and GBM-like tumors. Array and quantitative real-time PCR analysis demonstrated elevated expression similar to Pdgfralpha of retrovirally tagged genes Abhd2, Ddr1, Fos, Ng2, Ppfibp1, Rad51b and Sulf2 in both glioma types compared to neonatal and adult normal brain. The retrovirally tagged genes Plekhb1, Prex1, Prkg2, Sox10 and 1200004M23Rik were upregulated in the tumors but had a different expression profile than Pdgfralpha whereas Rap1gap, Gli1, Neurl and Camk2b were downregulated in the tumors. The present study accentuates the proposed role of the retrovirally tagged genes in PDGF-driven gliomagenesis and indicates that insertional mutagenesis can promote glioma progression.

Standard name | JOHANSSON_BRAIN_CANCER_EARLY_VS_LATE_DN
Systematic name | M1240
Organism | Mus musculus
PMID | 15750623
Authors | Johansson FK,Göransson H,Westermark B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in early vs late brain tumors induced by retroviral delivery of PDGFB [GeneID=5155].
Full description | Retroviral tagging previously identified putative cancer-causing genes in a mouse brain tumor model where a recombinant Moloney murine leukemia virus encoding the platelet-derived growth factor B-chain (MMLV/PDGFB) was intracerebrally injected in newborn mice. In the present study, expression analysis using cDNA arrays revealed several similarities of virus-induced mouse gliomas with human brain tumors. Brain tumors with short latency contained on average 8.0 retroviral insertions and resembled human glioblastoma multiforme (GBM) whereas long-latency gliomas were of lower grade, similar to human oligodendroglioma (OD) and had 2.3 insertions per tumor. Several known and novel genes of tumor progression or cell markers were differentially expressed between OD- and GBM-like tumors. Array and quantitative real-time PCR analysis demonstrated elevated expression similar to Pdgfralpha of retrovirally tagged genes Abhd2, Ddr1, Fos, Ng2, Ppfibp1, Rad51b and Sulf2 in both glioma types compared to neonatal and adult normal brain. The retrovirally tagged genes Plekhb1, Prex1, Prkg2, Sox10 and 1200004M23Rik were upregulated in the tumors but had a different expression profile than Pdgfralpha whereas Rap1gap, Gli1, Neurl and Camk2b were downregulated in the tumors. The present study accentuates the proposed role of the retrovirally tagged genes in PDGF-driven gliomagenesis and indicates that insertional mutagenesis can promote glioma progression.

Standard name | WIEMANN_TELOMERE_SHORTENING_AND_CHRONIC_LIVER_DAMAGE_UP
Systematic name | M1243
Organism | Mus musculus
PMID | 15608677
Authors | Wiemann SU,Satyanarayana A,Buer J,Kamino K,Manns MP,Rudolph KL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by telomere shortening due to the knockout of TERC [GeneID=7012] in the presence of chronic liver damage.
Full description | Telomere shortening limits the regenerative capacity of cells during aging and chronic disease but at the same time inhibits tumor progression, and it has yet to be determined which of these mechanisms is dominantly affecting organismal survival. Here we show that telomere shortening in telomerase knockout (mTERC-/-) mice in combination with chronic liver damage significantly reduced organismal survival even though telomere shortening strongly inhibited liver tumor formation. Decreased survival induced by telomere shortening correlated with an imbalance between liver cell proliferation and liver cell apoptosis. Specific changes in gene expression were associated with telomere shortening and chronic liver damage and these gene expression changes were partially reversed by adenovirus mediated telomerase gene delivery. This study gives experimental evidence that the negative impact of telomere shortening on organ homeostasis and organismal survival can surpass the beneficial effects of telomere shortening on suppression of tumor growth in the setting of chronic organ damage.

Standard name | MAINA_VHL_TARGETS_UP
Systematic name | M12942
Organism | Homo sapiens
PMID | 15824735
Authors | Maina EN,Morris MR,Zatyka M,Raval RR,Banks RE,Richards FM,Johnson CM,Maher ER
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RCC4 cells (renal cell carcinoma) engineered to stably express VHL [GeneID=7428] off a plasmid vector.
Full description | Upregulation of hypoxia-inducible factors HIF-1 and HIF-2 is frequent in human cancers and may result from tissue hypoxia or genetic mechanisms, in particular the inactivation of the von Hippel-Lindau (VHL) tumour suppressor gene (TSG). Tumours with VHL inactivation are highly vascular, but it is unclear to what extent HIF-dependent and HIF-independent mechanisms account for pVHL tumour suppressor activity. As the identification of novel pVHL targets might provide insights into pVHL tumour suppressor activity, we performed gene expression microarray analysis in VHL-wild-type and VHL-null renal cell carcinoma (RCC) cell lines. We identified 30 differentially regulated pVHL targets (26 of which were 'novel') and the results of microarray analysis were confirmed in all 11 novel targets further analysed by real-time RT-PCR or Western blotting. Furthermore, nine of 11 targets were dysregulated in the majority of a series of primary clear cell RCC with VHL inactivation. Three of the nine targets had been identified previously as candidate TSGs (DOC-2/DAB2, CDKN1C and SPARC) and all were upregulated by wild-type pVHL. The significance for pVHL function of two further genes upregulated by wild-type pVHL was initially unclear, but re-expression of GNG4 (G protein gamma-4 subunit/guanine nucleotide-binding protein-4) and MLC2 (myosin light chain) in a RCC cell line suppressed tumour cell growth. pVHL regulation of CDKN1C, SPARC and GNG4 was not mimicked by hypoxia, whereas for six of 11 novel targets analysed (including DOC-2/DAB2 and MLC2) the effects of pVHL inactivation and hypoxia were similar. For GPR56 there was evidence of a tissue-specific hypoxia response. Such a phenomenon might, in part, explain organ-specific tumorigenesis in VHL disease. These provide insights into mechanisms of pVHL tumour suppressor function and identify novel hypoxia-responsive targets that might be implicated in tumorigenesis in both VHL disease and in other cancers with HIF upregulation.

Standard name | MAINA_VHL_TARGETS_DN
Systematic name | M17552
Organism | Homo sapiens
PMID | 15824735
Authors | Maina EN,Morris MR,Zatyka M,Raval RR,Banks RE,Richards FM,Johnson CM,Maher ER
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in RCC4 cells (renal cell carcinoma) engineered to stably express VHL [GeneID=7428] off a plasmid vector.
Full description | Upregulation of hypoxia-inducible factors HIF-1 and HIF-2 is frequent in human cancers and may result from tissue hypoxia or genetic mechanisms, in particular the inactivation of the von Hippel-Lindau (VHL) tumour suppressor gene (TSG). Tumours with VHL inactivation are highly vascular, but it is unclear to what extent HIF-dependent and HIF-independent mechanisms account for pVHL tumour suppressor activity. As the identification of novel pVHL targets might provide insights into pVHL tumour suppressor activity, we performed gene expression microarray analysis in VHL-wild-type and VHL-null renal cell carcinoma (RCC) cell lines. We identified 30 differentially regulated pVHL targets (26 of which were 'novel') and the results of microarray analysis were confirmed in all 11 novel targets further analysed by real-time RT-PCR or Western blotting. Furthermore, nine of 11 targets were dysregulated in the majority of a series of primary clear cell RCC with VHL inactivation. Three of the nine targets had been identified previously as candidate TSGs (DOC-2/DAB2, CDKN1C and SPARC) and all were upregulated by wild-type pVHL. The significance for pVHL function of two further genes upregulated by wild-type pVHL was initially unclear, but re-expression of GNG4 (G protein gamma-4 subunit/guanine nucleotide-binding protein-4) and MLC2 (myosin light chain) in a RCC cell line suppressed tumour cell growth. pVHL regulation of CDKN1C, SPARC and GNG4 was not mimicked by hypoxia, whereas for six of 11 novel targets analysed (including DOC-2/DAB2 and MLC2) the effects of pVHL inactivation and hypoxia were similar. For GPR56 there was evidence of a tissue-specific hypoxia response. Such a phenomenon might, in part, explain organ-specific tumorigenesis in VHL disease. These provide insights into mechanisms of pVHL tumour suppressor function and identify novel hypoxia-responsive targets that might be implicated in tumorigenesis in both VHL disease and in other cancers with HIF upregulation.

Standard name | GRUETZMANN_PANCREATIC_CANCER_UP
Systematic name | M15193
Organism | Homo sapiens
PMID | 15897887
Authors | Grützmann R,Boriss H,Ammerpohl O,Lüttges J,Kalthoff H,Schackert HK,Klöppel G,Saeger HD,Pilarsky C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pancreatic ductal adenocarcinoma (PDAC) identified in a meta analysis across four independent studies.
Full description | Pancreatic ductal adenocarcinoma is the eighth most common cancer with the lowest overall 5-year relative survival rate of any tumor type today. Expression profiling using microarrays has been widely used to identify genes associated with pancreatic cancer development. To extract maximum value from the available gene expression data, we applied a meta-analysis to search for commonly differentially expressed genes in pancreatic ductal adenocarcinoma. We obtained data sets from four different gene expression studies on pancreatic cancer. We selected a consensus set of 2984 genes measured in all four studies and applied a meta-analysis approach to evaluate the combined data. Of the genes identified as differentially expressed, several were validated using RT-PCR and immunohistochemistry. Additionally, we used a class discovery algorithm to identify a gene expression signature. Our meta-analysis revealed that the pancreatic cancer gene expression data sets shared a significant number of up- and downregulated genes, independent of the technology used. This interstudy crossvalidation approach generated a set of 568 genes that were consistently and significantly dysregulated in pancreatic cancer. Of these, 364 (64.1%) were upregulated and 204 (35.9%) were downregulated in pancreatic cancer. Only 127 (22%) were described in the published individual analyses. Functional annotation of the genes revealed that genes presumably associated with the cell adhesion-mediated drug resistance pathway are frequently overexpressed in pancreatic cancer. Meta-analysis is an important tool for the identification and validation of differentially expressed genes. These could represent good candidates for novel diagnostic and therapeutic approaches to pancreatic cancer.

Standard name | GRUETZMANN_PANCREATIC_CANCER_DN
Systematic name | M10431
Organism | Homo sapiens
PMID | 15897887
Authors | Grützmann R,Boriss H,Ammerpohl O,Lüttges J,Kalthoff H,Schackert HK,Klöppel G,Saeger HD,Pilarsky C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pancreatic ductal adenocarcinoma (PDAC) identified in a meta analysis across four independent studies.
Full description | Pancreatic ductal adenocarcinoma is the eighth most common cancer with the lowest overall 5-year relative survival rate of any tumor type today. Expression profiling using microarrays has been widely used to identify genes associated with pancreatic cancer development. To extract maximum value from the available gene expression data, we applied a meta-analysis to search for commonly differentially expressed genes in pancreatic ductal adenocarcinoma. We obtained data sets from four different gene expression studies on pancreatic cancer. We selected a consensus set of 2984 genes measured in all four studies and applied a meta-analysis approach to evaluate the combined data. Of the genes identified as differentially expressed, several were validated using RT-PCR and immunohistochemistry. Additionally, we used a class discovery algorithm to identify a gene expression signature. Our meta-analysis revealed that the pancreatic cancer gene expression data sets shared a significant number of up- and downregulated genes, independent of the technology used. This interstudy crossvalidation approach generated a set of 568 genes that were consistently and significantly dysregulated in pancreatic cancer. Of these, 364 (64.1%) were upregulated and 204 (35.9%) were downregulated in pancreatic cancer. Only 127 (22%) were described in the published individual analyses. Functional annotation of the genes revealed that genes presumably associated with the cell adhesion-mediated drug resistance pathway are frequently overexpressed in pancreatic cancer. Meta-analysis is an important tool for the identification and validation of differentially expressed genes. These could represent good candidates for novel diagnostic and therapeutic approaches to pancreatic cancer.

Standard name | JAZAG_TGFB1_SIGNALING_UP
Systematic name | M7160
Organism | Homo sapiens
PMID | 15592526
Authors | Jazag A,Ijichi H,Kanai F,Imamura T,Guleng B,Ohta M,Imamura J,Tanaka Y,Tateishi K,Ikenoue T,Kawakami T,Arakawa Y,Miyagishi M,Taira K,Kawabe T,Omata M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in PANC-1-puro cells (pancreatic cancer) stimulated by TGF1B [GeneID=7040] for 2 h.
Full description | The transforming growth factor-beta (TGF-beta)-Smad signaling pathway inhibits the growth of human epithelial cells and plays a role in tumor suppression. The Smad4 gene is mutated or deleted in 50% of pancreatic cancers. In this study, we succeeded in establishing Smad4 knockdown (S4KD) pancreatic cancer cell lines using the stable RNA interference (RNAi) method. Smad4 protein expression was reduced dramatically and TGF-beta-Smad signaling was markedly inhibited in the S4KD cell lines. The S4KD and control cells were stimulated with TGF-beta and analysed using a cDNA microarray that contained 3756 genes, in order to screen for target molecules downstream of TGF-beta. The microarray analysis revealed that 187 S4KD genes and 155 genes in the control cells were regulated immediately upon TGF-beta stimulation. Quantitative RT-PCR analysis on several of these genes produced results that corroborated the outcome of the microarray analysis. Most of the genes in the S4KD and control cells identified by the array differed, which suggests signaling pathways that differ according to Smad4 status. Of the identified genes, 246 have not been reported previously as genes that lie downstream of TGF-beta. Genes that are involved in cell proliferation, adhesion, and motility were found to be regulated differentially with respect to S4KD and control cells. Cell migration induced by TGF-beta was inhibited in the S4KD cells, which might be associated with a different regulation of integrin beta7. The knock down of a specific gene using stable RNAi appears to be a promising tool for analysing endogenous gene function.

Standard name | JAZAG_TGFB1_SIGNALING_DN
Systematic name | M12455
Organism | Homo sapiens
PMID | 15592526
Authors | Jazag A,Ijichi H,Kanai F,Imamura T,Guleng B,Ohta M,Imamura J,Tanaka Y,Tateishi K,Ikenoue T,Kawakami T,Arakawa Y,Miyagishi M,Taira K,Kawabe T,Omata M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in PANC-1-puro cells (pancreatic cancer) stimulated by TGF1B [GeneID=7040] for 2 h.
Full description | The transforming growth factor-beta (TGF-beta)-Smad signaling pathway inhibits the growth of human epithelial cells and plays a role in tumor suppression. The Smad4 gene is mutated or deleted in 50% of pancreatic cancers. In this study, we succeeded in establishing Smad4 knockdown (S4KD) pancreatic cancer cell lines using the stable RNA interference (RNAi) method. Smad4 protein expression was reduced dramatically and TGF-beta-Smad signaling was markedly inhibited in the S4KD cell lines. The S4KD and control cells were stimulated with TGF-beta and analysed using a cDNA microarray that contained 3756 genes, in order to screen for target molecules downstream of TGF-beta. The microarray analysis revealed that 187 S4KD genes and 155 genes in the control cells were regulated immediately upon TGF-beta stimulation. Quantitative RT-PCR analysis on several of these genes produced results that corroborated the outcome of the microarray analysis. Most of the genes in the S4KD and control cells identified by the array differed, which suggests signaling pathways that differ according to Smad4 status. Of the identified genes, 246 have not been reported previously as genes that lie downstream of TGF-beta. Genes that are involved in cell proliferation, adhesion, and motility were found to be regulated differentially with respect to S4KD and control cells. Cell migration induced by TGF-beta was inhibited in the S4KD cells, which might be associated with a different regulation of integrin beta7. The knock down of a specific gene using stable RNAi appears to be a promising tool for analysing endogenous gene function.

Standard name | JAZAG_TGFB1_SIGNALING_VIA_SMAD4_UP
Systematic name | M13424
Organism | Homo sapiens
PMID | 15592526
Authors | Jazag A,Ijichi H,Kanai F,Imamura T,Guleng B,Ohta M,Imamura J,Tanaka Y,Tateishi K,Ikenoue T,Kawakami T,Arakawa Y,Miyagishi M,Taira K,Kawabe T,Omata M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in PANC-1-S4KD cells (pancreatic cancer; SMAD4 [GeneID=4089] knocked down by RNAi) after stimulation by TGF1B [GeneID=7040] for 2 h.
Full description | The transforming growth factor-beta (TGF-beta)-Smad signaling pathway inhibits the growth of human epithelial cells and plays a role in tumor suppression. The Smad4 gene is mutated or deleted in 50% of pancreatic cancers. In this study, we succeeded in establishing Smad4 knockdown (S4KD) pancreatic cancer cell lines using the stable RNA interference (RNAi) method. Smad4 protein expression was reduced dramatically and TGF-beta-Smad signaling was markedly inhibited in the S4KD cell lines. The S4KD and control cells were stimulated with TGF-beta and analysed using a cDNA microarray that contained 3756 genes, in order to screen for target molecules downstream of TGF-beta. The microarray analysis revealed that 187 S4KD genes and 155 genes in the control cells were regulated immediately upon TGF-beta stimulation. Quantitative RT-PCR analysis on several of these genes produced results that corroborated the outcome of the microarray analysis. Most of the genes in the S4KD and control cells identified by the array differed, which suggests signaling pathways that differ according to Smad4 status. Of the identified genes, 246 have not been reported previously as genes that lie downstream of TGF-beta. Genes that are involved in cell proliferation, adhesion, and motility were found to be regulated differentially with respect to S4KD and control cells. Cell migration induced by TGF-beta was inhibited in the S4KD cells, which might be associated with a different regulation of integrin beta7. The knock down of a specific gene using stable RNAi appears to be a promising tool for analysing endogenous gene function.

Standard name | JAZAG_TGFB1_SIGNALING_VIA_SMAD4_DN
Systematic name | M18705
Organism | Homo sapiens
PMID | 15592526
Authors | Jazag A,Ijichi H,Kanai F,Imamura T,Guleng B,Ohta M,Imamura J,Tanaka Y,Tateishi K,Ikenoue T,Kawakami T,Arakawa Y,Miyagishi M,Taira K,Kawabe T,Omata M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in PANC-1-S4KD cells (pancreatic cancer; SMAD4 [GeneID=4089] knocked down by RNAi) after stimulation by TGF1B [GeneID=7040] for 2 h.
Full description | The transforming growth factor-beta (TGF-beta)-Smad signaling pathway inhibits the growth of human epithelial cells and plays a role in tumor suppression. The Smad4 gene is mutated or deleted in 50% of pancreatic cancers. In this study, we succeeded in establishing Smad4 knockdown (S4KD) pancreatic cancer cell lines using the stable RNA interference (RNAi) method. Smad4 protein expression was reduced dramatically and TGF-beta-Smad signaling was markedly inhibited in the S4KD cell lines. The S4KD and control cells were stimulated with TGF-beta and analysed using a cDNA microarray that contained 3756 genes, in order to screen for target molecules downstream of TGF-beta. The microarray analysis revealed that 187 S4KD genes and 155 genes in the control cells were regulated immediately upon TGF-beta stimulation. Quantitative RT-PCR analysis on several of these genes produced results that corroborated the outcome of the microarray analysis. Most of the genes in the S4KD and control cells identified by the array differed, which suggests signaling pathways that differ according to Smad4 status. Of the identified genes, 246 have not been reported previously as genes that lie downstream of TGF-beta. Genes that are involved in cell proliferation, adhesion, and motility were found to be regulated differentially with respect to S4KD and control cells. Cell migration induced by TGF-beta was inhibited in the S4KD cells, which might be associated with a different regulation of integrin beta7. The knock down of a specific gene using stable RNAi appears to be a promising tool for analysing endogenous gene function.

Standard name | LI_WILMS_TUMOR_VS_FETAL_KIDNEY_2_UP
Systematic name | M1245
Organism | Homo sapiens
PMID | 15531917
Authors | Li W,Kessler P,Williams BR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Wilm's tumor vs fetal kidney.
Full description | Anaplasia (unfavorable histology) is associated with therapy resistance and poor prognosis of Wilms tumor, but the molecular basis for this phenotype is unclear. Here, we used a cDNA array with 9240 clones relevant to cancer biology and/or kidney development to examine the expression profiles of 54 Wilms tumors, five normal kidneys and fetal kidney. By linking genes differentially expressed between fetal kidney and Wilms tumors to kidney morphogenesis, we found that genes expressed at a higher level in Wilms tumors tend to be expressed more in uninduced metanephrogenic mesenchyme or blastema than in their differentiated structures. Conversely, genes expressed at a lower level in Wilms tumors tend to be expressed less in uninduced metanephrogenic mesenchyme or blastema. We also identified 97 clones representing 76 Unigenes or unclustered ESTs that clearly separate anaplastic Wilms tumors from tumors with favorable histology. Genes in this set provide insight into the nature of the abnormal nuclear morphology of anaplastic tumors and may facilitate identification of molecular targets to improve their responsiveness to treatment.

Standard name | LI_WILMS_TUMOR_VS_FETAL_KIDNEY_2_DN
Systematic name | M1246
Organism | Homo sapiens
PMID | 15531917
Authors | Li W,Kessler P,Williams BR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Wilm's tumor vs fetal kidney.
Full description | Anaplasia (unfavorable histology) is associated with therapy resistance and poor prognosis of Wilms tumor, but the molecular basis for this phenotype is unclear. Here, we used a cDNA array with 9240 clones relevant to cancer biology and/or kidney development to examine the expression profiles of 54 Wilms tumors, five normal kidneys and fetal kidney. By linking genes differentially expressed between fetal kidney and Wilms tumors to kidney morphogenesis, we found that genes expressed at a higher level in Wilms tumors tend to be expressed more in uninduced metanephrogenic mesenchyme or blastema than in their differentiated structures. Conversely, genes expressed at a lower level in Wilms tumors tend to be expressed less in uninduced metanephrogenic mesenchyme or blastema. We also identified 97 clones representing 76 Unigenes or unclustered ESTs that clearly separate anaplastic Wilms tumors from tumors with favorable histology. Genes in this set provide insight into the nature of the abnormal nuclear morphology of anaplastic tumors and may facilitate identification of molecular targets to improve their responsiveness to treatment.

Standard name | SIMBULAN_UV_RESPONSE_NORMAL_UP
Systematic name | M16664
Organism | Homo sapiens
PMID | 16007217
Authors | Simbulan-Rosenthal CM,Trabosh V,Velarde A,Chou FP,Daher A,Tenzin F,Tokino T,Rosenthal DS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HFK cells (primary keratinocytes) in response to UVB irradiation.
Full description | Solar ultraviolet B (UVB) acts as both an initiator and promoter in models of multistage skin carcinogenesis. We found that, whereas UVB induces apoptosis in human papillomavirus-16 E6/7-immortalized keratinocytes, it inhibits markers of differentiation in human foreskin keratinocytes (HFK). Potential mechanisms for this differential response were examined by DNA microarray, which revealed that UVB alters the expression of three of the four human inhibitor of differentiation/DNA binding (Id) proteins that comprise a class of helix-loop-helix family of transcription factors involved in proliferation, differentiation, apoptosis, and carcinogenesis. These results were verified by RT-PCR and immunoblot analysis of control and UVB-irradiated primary and immortalized keratinocytes. Whereas Id1 was downregulated in both cell types, Id2 expression was upregulated in primary HFK, but not immortalized cells. In contrast, Id3 expression was significantly increased only in immortalized cells. The differential expression pattern of Id2 in response to UVB was recapitulated in reporter constructs containing the 5' regulatory regions of this gene. Id2 promoter activity increased in response to UVB in HFK, but not in immortalized cells. To identify the regulatory elements in the Id2 promoter that mediate transcriptional activation by UVB in HFK, promoter deletion/mutation analysis was performed. Deletion analysis revealed that transactivation involves a 166 bp region immediately upstream to the Id2 transcriptional start site and is independent of c-Myc. The consensus E twenty-six (ETS) binding site at -120 appears to mediate UVB transcriptional activation of Id2 because point mutations at this site completely abrogated this response. Chromatin immunoprecipitation and electrophoretic mobility-shift assays verified that the Id2 promoter interacts with known Id2 promoter (ETS) binding factors Erg1/2 and Fli1, but not with c-Myc; and this interaction is enhanced after UVB exposure. Similar to the effects of UVB exposure, ectopic expression of Id2 protein in primary HFK resulted in inhibition of differentiation, as shown by decreased levels of the terminal differentiation marker keratin K1 and inhibition of involucrin crosslinking. Reduction of Id2 expression by small interfering RNAs attenuated the UVB-induced inhibition of differentiation in these cells. These results suggest that UVB-induced inhibition of differentiation of primary HFK is at least, in part, due to the upregulation of Id2, and that upregulation of Id2 by UVB might predispose keratinocytes to carcinogenesis by preventing their normal differentiation program.

Standard name | SIMBULAN_UV_RESPONSE_NORMAL_DN
Systematic name | M16114
Organism | Homo sapiens
PMID | 16007217
Authors | Simbulan-Rosenthal CM,Trabosh V,Velarde A,Chou FP,Daher A,Tenzin F,Tokino T,Rosenthal DS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HFK cells (primary keratinocytes) in response to UVB irradiation.
Full description | Solar ultraviolet B (UVB) acts as both an initiator and promoter in models of multistage skin carcinogenesis. We found that, whereas UVB induces apoptosis in human papillomavirus-16 E6/7-immortalized keratinocytes, it inhibits markers of differentiation in human foreskin keratinocytes (HFK). Potential mechanisms for this differential response were examined by DNA microarray, which revealed that UVB alters the expression of three of the four human inhibitor of differentiation/DNA binding (Id) proteins that comprise a class of helix-loop-helix family of transcription factors involved in proliferation, differentiation, apoptosis, and carcinogenesis. These results were verified by RT-PCR and immunoblot analysis of control and UVB-irradiated primary and immortalized keratinocytes. Whereas Id1 was downregulated in both cell types, Id2 expression was upregulated in primary HFK, but not immortalized cells. In contrast, Id3 expression was significantly increased only in immortalized cells. The differential expression pattern of Id2 in response to UVB was recapitulated in reporter constructs containing the 5' regulatory regions of this gene. Id2 promoter activity increased in response to UVB in HFK, but not in immortalized cells. To identify the regulatory elements in the Id2 promoter that mediate transcriptional activation by UVB in HFK, promoter deletion/mutation analysis was performed. Deletion analysis revealed that transactivation involves a 166 bp region immediately upstream to the Id2 transcriptional start site and is independent of c-Myc. The consensus E twenty-six (ETS) binding site at -120 appears to mediate UVB transcriptional activation of Id2 because point mutations at this site completely abrogated this response. Chromatin immunoprecipitation and electrophoretic mobility-shift assays verified that the Id2 promoter interacts with known Id2 promoter (ETS) binding factors Erg1/2 and Fli1, but not with c-Myc; and this interaction is enhanced after UVB exposure. Similar to the effects of UVB exposure, ectopic expression of Id2 protein in primary HFK resulted in inhibition of differentiation, as shown by decreased levels of the terminal differentiation marker keratin K1 and inhibition of involucrin crosslinking. Reduction of Id2 expression by small interfering RNAs attenuated the UVB-induced inhibition of differentiation in these cells. These results suggest that UVB-induced inhibition of differentiation of primary HFK is at least, in part, due to the upregulation of Id2, and that upregulation of Id2 by UVB might predispose keratinocytes to carcinogenesis by preventing their normal differentiation program.

Standard name | SIMBULAN_UV_RESPONSE_IMMORTALIZED_DN
Systematic name | M3732
Organism | Homo sapiens
PMID | 16007217
Authors | Simbulan-Rosenthal CM,Trabosh V,Velarde A,Chou FP,Daher A,Tenzin F,Tokino T,Rosenthal DS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in response to UVB radiation in HFK cells (keratinocytes) immortalized by overexpression of HPV E6 and E7 viral oncogenes.
Full description | Solar ultraviolet B (UVB) acts as both an initiator and promoter in models of multistage skin carcinogenesis. We found that, whereas UVB induces apoptosis in human papillomavirus-16 E6/7-immortalized keratinocytes, it inhibits markers of differentiation in human foreskin keratinocytes (HFK). Potential mechanisms for this differential response were examined by DNA microarray, which revealed that UVB alters the expression of three of the four human inhibitor of differentiation/DNA binding (Id) proteins that comprise a class of helix-loop-helix family of transcription factors involved in proliferation, differentiation, apoptosis, and carcinogenesis. These results were verified by RT-PCR and immunoblot analysis of control and UVB-irradiated primary and immortalized keratinocytes. Whereas Id1 was downregulated in both cell types, Id2 expression was upregulated in primary HFK, but not immortalized cells. In contrast, Id3 expression was significantly increased only in immortalized cells. The differential expression pattern of Id2 in response to UVB was recapitulated in reporter constructs containing the 5' regulatory regions of this gene. Id2 promoter activity increased in response to UVB in HFK, but not in immortalized cells. To identify the regulatory elements in the Id2 promoter that mediate transcriptional activation by UVB in HFK, promoter deletion/mutation analysis was performed. Deletion analysis revealed that transactivation involves a 166 bp region immediately upstream to the Id2 transcriptional start site and is independent of c-Myc. The consensus E twenty-six (ETS) binding site at -120 appears to mediate UVB transcriptional activation of Id2 because point mutations at this site completely abrogated this response. Chromatin immunoprecipitation and electrophoretic mobility-shift assays verified that the Id2 promoter interacts with known Id2 promoter (ETS) binding factors Erg1/2 and Fli1, but not with c-Myc; and this interaction is enhanced after UVB exposure. Similar to the effects of UVB exposure, ectopic expression of Id2 protein in primary HFK resulted in inhibition of differentiation, as shown by decreased levels of the terminal differentiation marker keratin K1 and inhibition of involucrin crosslinking. Reduction of Id2 expression by small interfering RNAs attenuated the UVB-induced inhibition of differentiation in these cells. These results suggest that UVB-induced inhibition of differentiation of primary HFK is at least, in part, due to the upregulation of Id2, and that upregulation of Id2 by UVB might predispose keratinocytes to carcinogenesis by preventing their normal differentiation program.

Standard name | CEBALLOS_TARGETS_OF_TP53_AND_MYC_UP
Systematic name | M1247
Organism | Homo sapiens
PMID | 15856024
Authors | Ceballos E,Muñoz-Alonso MJ,Berwanger B,Acosta JC,Hernández R,Krause M,Hartmann O,Eilers M,León J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in K562 cells (chronic myelogenous leukemia, CML) expressing TP53 and MYC [GeneID=7157;4609].
Full description | We have previously demonstrated that c-Myc impairs p53-mediated apoptosis in K562 human leukemia cells, which lack ARF. To investigate the mechanisms by which c-Myc protects from p53-mediated apoptosis, we used K562 cells that conditionally express c-Myc and harbor a temperature-sensitive allele of p53. Gene expression profiles of cells expressing wild-type conformation p53 in the presence of either uninduced or induced c-Myc were analysed by cDNA microarrays. The results show that multiple p53 target genes are downregulated when c-Myc is present, including p21WAF1, MDM2, PERP, NOXA, GADD45, DDB2, PIR121 and p53R2. Also, a number of genes that are upregulated by c-Myc in cells expressing wild-type conformation p53 encode chaperones related to cell death protection as HSP105, HSP90 and HSP27. Both downregulation of p53 target genes and upregulation of chaperones could explain the inhibition of apoptosis observed in K562 cells with ectopic c-Myc. Myc-mediated impairment of p53 transactivation was not restricted to K562 cells, but it was reproduced in a panel of human cancer cell lines derived from different tissues. Our data suggest that elevated levels of Myc counteract p53 activity in human tumor cells that lack ARF. This mechanism could contribute to explain the c-Myc deregulation frequently found in cancer.

Standard name | CEBALLOS_TARGETS_OF_TP53_AND_MYC_DN
Systematic name | M1252
Organism | Homo sapiens
PMID | 15856024
Authors | Ceballos E,Muñoz-Alonso MJ,Berwanger B,Acosta JC,Hernández R,Krause M,Hartmann O,Eilers M,León J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in K562 cells (chronic myelogenous leukemia, CML) expressing TP53 and MYC [GeneID=7157;4609].
Full description | We have previously demonstrated that c-Myc impairs p53-mediated apoptosis in K562 human leukemia cells, which lack ARF. To investigate the mechanisms by which c-Myc protects from p53-mediated apoptosis, we used K562 cells that conditionally express c-Myc and harbor a temperature-sensitive allele of p53. Gene expression profiles of cells expressing wild-type conformation p53 in the presence of either uninduced or induced c-Myc were analysed by cDNA microarrays. The results show that multiple p53 target genes are downregulated when c-Myc is present, including p21WAF1, MDM2, PERP, NOXA, GADD45, DDB2, PIR121 and p53R2. Also, a number of genes that are upregulated by c-Myc in cells expressing wild-type conformation p53 encode chaperones related to cell death protection as HSP105, HSP90 and HSP27. Both downregulation of p53 target genes and upregulation of chaperones could explain the inhibition of apoptosis observed in K562 cells with ectopic c-Myc. Myc-mediated impairment of p53 transactivation was not restricted to K562 cells, but it was reproduced in a panel of human cancer cell lines derived from different tissues. Our data suggest that elevated levels of Myc counteract p53 activity in human tumor cells that lack ARF. This mechanism could contribute to explain the c-Myc deregulation frequently found in cancer.

Standard name | INAMURA_LUNG_CANCER_SCC_UP
Systematic name | M1253
Organism | Homo sapiens
PMID | 16007138
Authors | Inamura K,Fujiwara T,Hoshida Y,Isagawa T,Jones MH,Virtanen C,Shimane M,Satoh Y,Okumura S,Nakagawa K,Tsuchiya E,Ishikawa S,Aburatani H,Nomura H,Ishikawa Y
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes characteristic to the squamous cell carcinoma (SCC) type of non-small cell lung cancer (NSCLC).
Full description | Current clinical and histopathological criteria used to define lung squamous cell carcinomas (SCCs) are insufficient to predict clinical outcome. To make a clinically useful classification by gene expression profiling, we used a 40 386 element cDNA microarray to analyse 48 SCC, nine adenocarcinoma, and 30 normal lung samples. Initial analysis by hierarchical clustering (HC) allowed division of SCCs into two distinct subclasses. An additional independent round of HC induced a similar partition and consensus clustering with the non-negative matrix factorization approach indicated the robustness of this classification. Kaplan-Meier analysis with the log-rank test pointed to a nonsignificant difference in survival (P = 0.071), but the likelihood of survival to 6 years was significantly different between the two groups (40.5 vs 81.8%, P = 0.014, Z-test). Biological process categories characteristic for each subclass were identified statistically and upregulation of cell-proliferation-related genes was evident in the subclass with poor prognosis. In the subclass with better survival, genes involved in differentiated intracellular functions, such as the MAPKKK cascade, ceramide metabolism, or regulation of transcription, were upregulated. This work represents an important step toward the identification of clinically useful classification for lung SCC.

Standard name | INAMURA_LUNG_CANCER_SCC_DN
Systematic name | M1255
Organism | Homo sapiens
PMID | 16007138
Authors | Inamura K,Fujiwara T,Hoshida Y,Isagawa T,Jones MH,Virtanen C,Shimane M,Satoh Y,Okumura S,Nakagawa K,Tsuchiya E,Ishikawa S,Aburatani H,Nomura H,Ishikawa Y
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes characteristic to the squamous cell carcinoma (SCC) type of non-small cell lung cancer (NSCLC).
Full description | Current clinical and histopathological criteria used to define lung squamous cell carcinomas (SCCs) are insufficient to predict clinical outcome. To make a clinically useful classification by gene expression profiling, we used a 40 386 element cDNA microarray to analyse 48 SCC, nine adenocarcinoma, and 30 normal lung samples. Initial analysis by hierarchical clustering (HC) allowed division of SCCs into two distinct subclasses. An additional independent round of HC induced a similar partition and consensus clustering with the non-negative matrix factorization approach indicated the robustness of this classification. Kaplan-Meier analysis with the log-rank test pointed to a nonsignificant difference in survival (P = 0.071), but the likelihood of survival to 6 years was significantly different between the two groups (40.5 vs 81.8%, P = 0.014, Z-test). Biological process categories characteristic for each subclass were identified statistically and upregulation of cell-proliferation-related genes was evident in the subclass with poor prognosis. In the subclass with better survival, genes involved in differentiated intracellular functions, such as the MAPKKK cascade, ceramide metabolism, or regulation of transcription, were upregulated. This work represents an important step toward the identification of clinically useful classification for lung SCC.

Standard name | INAMURA_LUNG_CANCER_SCC_SUBTYPES_UP
Systematic name | M1256
Organism | Homo sapiens
PMID | 16007138
Authors | Inamura K,Fujiwara T,Hoshida Y,Isagawa T,Jones MH,Virtanen C,Shimane M,Satoh Y,Okumura S,Nakagawa K,Tsuchiya E,Ishikawa S,Aburatani H,Nomura H,Ishikawa Y
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes discriminating between two subtypes of squamous cell carcinoma (SCC) type of non-small cell lung cancer: SSC-A vs SSC-B.
Full description | Current clinical and histopathological criteria used to define lung squamous cell carcinomas (SCCs) are insufficient to predict clinical outcome. To make a clinically useful classification by gene expression profiling, we used a 40 386 element cDNA microarray to analyse 48 SCC, nine adenocarcinoma, and 30 normal lung samples. Initial analysis by hierarchical clustering (HC) allowed division of SCCs into two distinct subclasses. An additional independent round of HC induced a similar partition and consensus clustering with the non-negative matrix factorization approach indicated the robustness of this classification. Kaplan-Meier analysis with the log-rank test pointed to a nonsignificant difference in survival (P = 0.071), but the likelihood of survival to 6 years was significantly different between the two groups (40.5 vs 81.8%, P = 0.014, Z-test). Biological process categories characteristic for each subclass were identified statistically and upregulation of cell-proliferation-related genes was evident in the subclass with poor prognosis. In the subclass with better survival, genes involved in differentiated intracellular functions, such as the MAPKKK cascade, ceramide metabolism, or regulation of transcription, were upregulated. This work represents an important step toward the identification of clinically useful classification for lung SCC.

Standard name | SASAI_RESISTANCE_TO_NEOPLASTIC_TRANSFROMATION
Systematic name | M1259
Organism | Mus musculus
PMID | 16832346
Authors | Sasai K,Kakumoto K,Hanafusa H,Akagi T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF and REF cells (mouse and rat fibroblasts) but not in TIG3/T cells (human lung fibroblasts expressing TERT [GeneID=7015]) by co-expression of the SV40 early region and the activated HRAS (H-RasV12) [GeneID=3265].
Full description | Normal human diploid fibroblasts (HDFs) are refractory to oncogene-mediated transformations in vitro, compared with rodent fibroblasts. As successful oncogene-mediated transformations of normal HDFs have been reported using the human telomerase catalytic subunit, it has been considered that telomerase activity contributes to the species-specific transformability. However, these transformed HDFs are much less malignant compared with those of rodent cells, suggesting the existence of undefined mechanisms that render HDFs resistant to malignant transformation. Here, cDNA microarray analysis identified caveolin-1 as one of the possible cellular factors involved in such mechanisms. The mitogen-activated protein kinases (MAPK) pathway downregulates Caveolin-1 in rodent fibroblasts, transformed by coexpression of the SV40 early region and activated H-Ras. In contrast, the coexpression of these two oncogenes in HDFs failed to reduce the expression level of Caveolin-1. These results strongly suggest the presence of critical differences in events following the phosphorylation of ERK during the activation process of the MAPK signaling pathway between human and rodent cells, as the ERK protein was similarly phosphorylated in both systems. Furthermore, the small interfering RNA-mediated suppression of Caveolin-1 facilitated the oncogene-mediated transformation of normal HDFs, clearly indicating that the differences in the transformability between human and rodent cells are due, at least in part, to the mechanism responsible for the resistance to Ras-induced Caveolin-1 downregulation in HDFs.

Standard name | KIM_MYC_AMPLIFICATION_TARGETS_UP
Systematic name | M8445
Organism | Homo sapiens
PMID | 16116477
Authors | Kim YH,Girard L,Giacomini CP,Wang P,Hernandez-Boussard T,Tibshirani R,Minna JD,Pollack JR
Category | C2
Sub-category | CGP
Brief description | Genes positively correlated with amplifications of MYC [GeneID=4609] in SCLC (small cell lung cancer) cell lines.
Full description | DNA amplifications and deletions frequently contribute to the development and progression of lung cancer. To identify such novel alterations in small cell lung cancer (SCLC), we performed comparative genomic hybridization on a set of 24 SCLC cell lines, using cDNA microarrays representing approximately 22,000 human genes (providing an average mapping resolution of <70 kb). We identified localized DNA amplifications corresponding to oncogenes known to be amplified in SCLC, including MYC (8q24), MYCN (2p24) and MYCL1 (1p34). Additional highly localized DNA amplifications suggested candidate oncogenes not previously identified as amplified in SCLC, including the antiapoptotic genes TNFRSF4 (1p36), DAD1 (14q11), BCL2L1 (20q11) and BCL2L2 (14q11). Likewise, newly discovered PCR-validated homozygous deletions suggested candidate tumor-suppressor genes, including the proapoptotic genes MAPK10 (4q21) and TNFRSF6 (10q23). To characterize the effect of DNA amplification on gene expression patterns, we performed expression profiling using the same microarray platform. Among our findings, we identified sets of genes whose expression correlated with MYC, MYCN or MYCL1 amplification, with surprisingly little overlap among gene sets. While both MYC and MYCN amplification were associated with increased and decreased expression of known MYC upregulated and downregulated targets, respectively, MYCL1 amplification was associated only with the latter. Our findings support a role of altered apoptotic balance in the pathogenesis of SCLC, and suggest that MYC family genes might affect oncogenesis through distinct sets of targets, in particular implicating the importance of transcriptional repression.

Standard name | KIM_MYC_AMPLIFICATION_TARGETS_DN
Systematic name | M6319
Organism | Homo sapiens
PMID | 16116477
Authors | Kim YH,Girard L,Giacomini CP,Wang P,Hernandez-Boussard T,Tibshirani R,Minna JD,Pollack JR
Category | C2
Sub-category | CGP
Brief description | Genes negatively correlated with amplifications of MYC [GeneID=4609] in SCLC (small cell lung cancer) cell lines.
Full description | DNA amplifications and deletions frequently contribute to the development and progression of lung cancer. To identify such novel alterations in small cell lung cancer (SCLC), we performed comparative genomic hybridization on a set of 24 SCLC cell lines, using cDNA microarrays representing approximately 22,000 human genes (providing an average mapping resolution of <70 kb). We identified localized DNA amplifications corresponding to oncogenes known to be amplified in SCLC, including MYC (8q24), MYCN (2p24) and MYCL1 (1p34). Additional highly localized DNA amplifications suggested candidate oncogenes not previously identified as amplified in SCLC, including the antiapoptotic genes TNFRSF4 (1p36), DAD1 (14q11), BCL2L1 (20q11) and BCL2L2 (14q11). Likewise, newly discovered PCR-validated homozygous deletions suggested candidate tumor-suppressor genes, including the proapoptotic genes MAPK10 (4q21) and TNFRSF6 (10q23). To characterize the effect of DNA amplification on gene expression patterns, we performed expression profiling using the same microarray platform. Among our findings, we identified sets of genes whose expression correlated with MYC, MYCN or MYCL1 amplification, with surprisingly little overlap among gene sets. While both MYC and MYCN amplification were associated with increased and decreased expression of known MYC upregulated and downregulated targets, respectively, MYCL1 amplification was associated only with the latter. Our findings support a role of altered apoptotic balance in the pathogenesis of SCLC, and suggest that MYC family genes might affect oncogenesis through distinct sets of targets, in particular implicating the importance of transcriptional repression.

Standard name | KIM_MYCN_AMPLIFICATION_TARGETS_UP
Systematic name | M18532
Organism | Homo sapiens
PMID | 16116477
Authors | Kim YH,Girard L,Giacomini CP,Wang P,Hernandez-Boussard T,Tibshirani R,Minna JD,Pollack JR
Category | C2
Sub-category | CGP
Brief description | Genes positively correlated with amplifications of MYCN [GeneID=4613] in the SCLC (small cell lung cancer) cell lines.
Full description | DNA amplifications and deletions frequently contribute to the development and progression of lung cancer. To identify such novel alterations in small cell lung cancer (SCLC), we performed comparative genomic hybridization on a set of 24 SCLC cell lines, using cDNA microarrays representing approximately 22,000 human genes (providing an average mapping resolution of <70 kb). We identified localized DNA amplifications corresponding to oncogenes known to be amplified in SCLC, including MYC (8q24), MYCN (2p24) and MYCL1 (1p34). Additional highly localized DNA amplifications suggested candidate oncogenes not previously identified as amplified in SCLC, including the antiapoptotic genes TNFRSF4 (1p36), DAD1 (14q11), BCL2L1 (20q11) and BCL2L2 (14q11). Likewise, newly discovered PCR-validated homozygous deletions suggested candidate tumor-suppressor genes, including the proapoptotic genes MAPK10 (4q21) and TNFRSF6 (10q23). To characterize the effect of DNA amplification on gene expression patterns, we performed expression profiling using the same microarray platform. Among our findings, we identified sets of genes whose expression correlated with MYC, MYCN or MYCL1 amplification, with surprisingly little overlap among gene sets. While both MYC and MYCN amplification were associated with increased and decreased expression of known MYC upregulated and downregulated targets, respectively, MYCL1 amplification was associated only with the latter. Our findings support a role of altered apoptotic balance in the pathogenesis of SCLC, and suggest that MYC family genes might affect oncogenesis through distinct sets of targets, in particular implicating the importance of transcriptional repression.

Standard name | KIM_MYCN_AMPLIFICATION_TARGETS_DN
Systematic name | M2919
Organism | Homo sapiens
PMID | 16116477
Authors | Kim YH,Girard L,Giacomini CP,Wang P,Hernandez-Boussard T,Tibshirani R,Minna JD,Pollack JR
Category | C2
Sub-category | CGP
Brief description | Genes negatively correlated with amplifications of MYCN [GeneID=4613] in the SCLC (small cell lung cancer) cell lines.
Full description | DNA amplifications and deletions frequently contribute to the development and progression of lung cancer. To identify such novel alterations in small cell lung cancer (SCLC), we performed comparative genomic hybridization on a set of 24 SCLC cell lines, using cDNA microarrays representing approximately 22,000 human genes (providing an average mapping resolution of <70 kb). We identified localized DNA amplifications corresponding to oncogenes known to be amplified in SCLC, including MYC (8q24), MYCN (2p24) and MYCL1 (1p34). Additional highly localized DNA amplifications suggested candidate oncogenes not previously identified as amplified in SCLC, including the antiapoptotic genes TNFRSF4 (1p36), DAD1 (14q11), BCL2L1 (20q11) and BCL2L2 (14q11). Likewise, newly discovered PCR-validated homozygous deletions suggested candidate tumor-suppressor genes, including the proapoptotic genes MAPK10 (4q21) and TNFRSF6 (10q23). To characterize the effect of DNA amplification on gene expression patterns, we performed expression profiling using the same microarray platform. Among our findings, we identified sets of genes whose expression correlated with MYC, MYCN or MYCL1 amplification, with surprisingly little overlap among gene sets. While both MYC and MYCN amplification were associated with increased and decreased expression of known MYC upregulated and downregulated targets, respectively, MYCL1 amplification was associated only with the latter. Our findings support a role of altered apoptotic balance in the pathogenesis of SCLC, and suggest that MYC family genes might affect oncogenesis through distinct sets of targets, in particular implicating the importance of transcriptional repression.

Standard name | KIM_MYCL1_AMPLIFICATION_TARGETS_UP
Systematic name | M5329
Organism | Homo sapiens
PMID | 16116477
Authors | Kim YH,Girard L,Giacomini CP,Wang P,Hernandez-Boussard T,Tibshirani R,Minna JD,Pollack JR
Category | C2
Sub-category | CGP
Brief description | Genes positively correlated with amplifications of MYCL1 [GeneID=4610] in SCLC (small cell lung cancer) cell lines.
Full description | DNA amplifications and deletions frequently contribute to the development and progression of lung cancer. To identify such novel alterations in small cell lung cancer (SCLC), we performed comparative genomic hybridization on a set of 24 SCLC cell lines, using cDNA microarrays representing approximately 22,000 human genes (providing an average mapping resolution of <70 kb). We identified localized DNA amplifications corresponding to oncogenes known to be amplified in SCLC, including MYC (8q24), MYCN (2p24) and MYCL1 (1p34). Additional highly localized DNA amplifications suggested candidate oncogenes not previously identified as amplified in SCLC, including the antiapoptotic genes TNFRSF4 (1p36), DAD1 (14q11), BCL2L1 (20q11) and BCL2L2 (14q11). Likewise, newly discovered PCR-validated homozygous deletions suggested candidate tumor-suppressor genes, including the proapoptotic genes MAPK10 (4q21) and TNFRSF6 (10q23). To characterize the effect of DNA amplification on gene expression patterns, we performed expression profiling using the same microarray platform. Among our findings, we identified sets of genes whose expression correlated with MYC, MYCN or MYCL1 amplification, with surprisingly little overlap among gene sets. While both MYC and MYCN amplification were associated with increased and decreased expression of known MYC upregulated and downregulated targets, respectively, MYCL1 amplification was associated only with the latter. Our findings support a role of altered apoptotic balance in the pathogenesis of SCLC, and suggest that MYC family genes might affect oncogenesis through distinct sets of targets, in particular implicating the importance of transcriptional repression.

Standard name | KIM_MYCL1_AMPLIFICATION_TARGETS_DN
Systematic name | M5624
Organism | Homo sapiens
PMID | 16116477
Authors | Kim YH,Girard L,Giacomini CP,Wang P,Hernandez-Boussard T,Tibshirani R,Minna JD,Pollack JR
Category | C2
Sub-category | CGP
Brief description | Genes negatively correlated with amplifications of MYCL1 [GeneID=4610] in SCLC (small cell lung cancer) cell lines.
Full description | DNA amplifications and deletions frequently contribute to the development and progression of lung cancer. To identify such novel alterations in small cell lung cancer (SCLC), we performed comparative genomic hybridization on a set of 24 SCLC cell lines, using cDNA microarrays representing approximately 22,000 human genes (providing an average mapping resolution of <70 kb). We identified localized DNA amplifications corresponding to oncogenes known to be amplified in SCLC, including MYC (8q24), MYCN (2p24) and MYCL1 (1p34). Additional highly localized DNA amplifications suggested candidate oncogenes not previously identified as amplified in SCLC, including the antiapoptotic genes TNFRSF4 (1p36), DAD1 (14q11), BCL2L1 (20q11) and BCL2L2 (14q11). Likewise, newly discovered PCR-validated homozygous deletions suggested candidate tumor-suppressor genes, including the proapoptotic genes MAPK10 (4q21) and TNFRSF6 (10q23). To characterize the effect of DNA amplification on gene expression patterns, we performed expression profiling using the same microarray platform. Among our findings, we identified sets of genes whose expression correlated with MYC, MYCN or MYCL1 amplification, with surprisingly little overlap among gene sets. While both MYC and MYCN amplification were associated with increased and decreased expression of known MYC upregulated and downregulated targets, respectively, MYCL1 amplification was associated only with the latter. Our findings support a role of altered apoptotic balance in the pathogenesis of SCLC, and suggest that MYC family genes might affect oncogenesis through distinct sets of targets, in particular implicating the importance of transcriptional repression.

Standard name | TSAI_RESPONSE_TO_IONIZING_RADIATION
Systematic name | M8512
Organism | Homo sapiens
PMID | 16247478
Authors | Tsai MH,Chen X,Chandramouli GV,Chen Y,Yan H,Zhao S,Keng P,Liber HL,Coleman CN,Mitchell JB,Chuang EY
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in TK6, WTK1, and NH32 cell lines (lymphoblast) in response to ionizing radiation.
Full description | The p53 protein has been implicated in multiple cellular responses related to DNA damage. Alterations in any of these cellular responses could be related to increased genomic instability. Our previous study has shown that mutations in p53 lead to hypermutability to ionizing radiation. To investigate further how p53 is involved in regulating mutational processes, we used 8K cDNA microarrays to compare the patterns of gene expression among three closely related human cell lines with different p53 status including TK6 (wild-type p53), NH32 (p53-null), and WTK1 (mutant p53). Total RNA samples were collected at 1, 3, 6, 9, and 24 h after 10 Gy gamma-irradiation. Template-based clustering analysis of the gene expression over the time course showed that 464 genes are either up or downregulated by at least twofold following radiation treatment. In addition, cluster analyses of gene expression profiles among these three cell lines revealed distinct patterns. In TK6, 165 genes were upregulated, while 36 genes were downregulated. In contrast, in WTK1 75 genes were upregulated and 12 genes were downregulated. In NH32, only 54 genes were upregulated. Furthermore, we found several genes associated with DNA repair namely p53R2, DDB2, XPC, PCNA, BTG2, and MSH2 that were highly induced in TK6 compared to WTK1 and NH32. p53R2, which is regulated by the tumor suppressor p53, is a small subunit of ribonucleotide reductase. To determine whether it is involved in radiation-induced mutagenesis, p53R2 protein was inhibited by siRNA in TK6 cells and followed by 2 Gy radiation. The background mutation frequencies at the TK locus of siRNA-transfected TK6 cells were about three times higher than those seen in TK6 cells. The mutation frequencies of siRNA-transfected TK6 cells after 2 Gy radiation were significantly higher than the irradiated TK6 cells without p53R2 knock down. These results indicate that p53R2 was induced by p53 protein and is involved in protecting against radiation-induced mutagenesis.

Standard name | YANG_BREAST_CANCER_ESR1_UP
Systematic name | M18299
Organism | Homo sapiens
PMID | 16261164
Authors | Yang F,Foekens JA,Yu J,Sieuwerts AM,Timmermans M,Klijn JG,Atkins D,Wang Y,Jiang Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in early primary breast tumors expressing ESR1 [GeneID=2099] vs the ESR1 negative ones.
Full description | About 70-80% of breast cancers express estrogen receptor alpha (ER-alpha), and estrogens play important roles in the development and growth of hormone-dependent tumors. Together with lymph node metastasis, tumor size, and histological grade, ER status is considered as one of the prognostic factors in breast cancer, and an indicator for hormonal treatment. To investigate genes and pathways that are associated with ER status and epithelial cells in breast tumor, we applied laser capture microdissection (LCM) technology to capture epithelial tumor cells from 28 lymph node-negative breast tumor samples, in which 17 patients had ER-alpha+ tumors, and 11 patients have ER-alpha- tumors. Gene expression profiles were analysed on Affymetrix Hu133A GeneChip. Meanwhile, gene profiles using total RNA isolated from bulk tumors of the same 28 patients were also generated. In total, 146 genes and 112 genes with significant P-value and having significant differential expression between ER-alpha+ and ER-alpha- tumors were identified from the LCM data set and bulk tissue data set, respectively. A total of 61 genes were found to be common in both data sets, while 85 genes were unique to the LCM data set and 51 genes were present only in the bulk tumor data set. Pathway analysis with the 85 genes using Gene Ontology suggested that genes involved in endocytosis, ceramide generation, Ras/ERK/Ark cascade, and JAT-STAT pathways may play roles related to ER. The gene profiling with LCM-captured tumor cells provides a unique approach to study epithelial tumor cells and to gain an insight into signaling pathways associated with ER.

Standard name | YANG_BREAST_CANCER_ESR1_DN
Systematic name | M1293
Organism | Homo sapiens
PMID | 16261164
Authors | Yang F,Foekens JA,Yu J,Sieuwerts AM,Timmermans M,Klijn JG,Atkins D,Wang Y,Jiang Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in early primary breast tumors expressing ESR1 [GeneID=2099] vs the ESR1 negative ones.
Full description | About 70-80% of breast cancers express estrogen receptor alpha (ER-alpha), and estrogens play important roles in the development and growth of hormone-dependent tumors. Together with lymph node metastasis, tumor size, and histological grade, ER status is considered as one of the prognostic factors in breast cancer, and an indicator for hormonal treatment. To investigate genes and pathways that are associated with ER status and epithelial cells in breast tumor, we applied laser capture microdissection (LCM) technology to capture epithelial tumor cells from 28 lymph node-negative breast tumor samples, in which 17 patients had ER-alpha+ tumors, and 11 patients have ER-alpha- tumors. Gene expression profiles were analysed on Affymetrix Hu133A GeneChip. Meanwhile, gene profiles using total RNA isolated from bulk tumors of the same 28 patients were also generated. In total, 146 genes and 112 genes with significant P-value and having significant differential expression between ER-alpha+ and ER-alpha- tumors were identified from the LCM data set and bulk tissue data set, respectively. A total of 61 genes were found to be common in both data sets, while 85 genes were unique to the LCM data set and 51 genes were present only in the bulk tumor data set. Pathway analysis with the 85 genes using Gene Ontology suggested that genes involved in endocytosis, ceramide generation, Ras/ERK/Ark cascade, and JAT-STAT pathways may play roles related to ER. The gene profiling with LCM-captured tumor cells provides a unique approach to study epithelial tumor cells and to gain an insight into signaling pathways associated with ER.

Standard name | YANG_BREAST_CANCER_ESR1_LASER_UP
Systematic name | M10541
Organism | Homo sapiens
PMID | 16261164
Authors | Yang F,Foekens JA,Yu J,Sieuwerts AM,Timmermans M,Klijn JG,Atkins D,Wang Y,Jiang Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in laser microdissected (LCM) samples of early primary breast tumors expressing ESR1 [GeneID=2099] vs the ESR1 negative ones.
Full description | About 70-80% of breast cancers express estrogen receptor alpha (ER-alpha), and estrogens play important roles in the development and growth of hormone-dependent tumors. Together with lymph node metastasis, tumor size, and histological grade, ER status is considered as one of the prognostic factors in breast cancer, and an indicator for hormonal treatment. To investigate genes and pathways that are associated with ER status and epithelial cells in breast tumor, we applied laser capture microdissection (LCM) technology to capture epithelial tumor cells from 28 lymph node-negative breast tumor samples, in which 17 patients had ER-alpha+ tumors, and 11 patients have ER-alpha- tumors. Gene expression profiles were analysed on Affymetrix Hu133A GeneChip. Meanwhile, gene profiles using total RNA isolated from bulk tumors of the same 28 patients were also generated. In total, 146 genes and 112 genes with significant P-value and having significant differential expression between ER-alpha+ and ER-alpha- tumors were identified from the LCM data set and bulk tissue data set, respectively. A total of 61 genes were found to be common in both data sets, while 85 genes were unique to the LCM data set and 51 genes were present only in the bulk tumor data set. Pathway analysis with the 85 genes using Gene Ontology suggested that genes involved in endocytosis, ceramide generation, Ras/ERK/Ark cascade, and JAT-STAT pathways may play roles related to ER. The gene profiling with LCM-captured tumor cells provides a unique approach to study epithelial tumor cells and to gain an insight into signaling pathways associated with ER.

Standard name | YANG_BREAST_CANCER_ESR1_LASER_DN
Systematic name | M11078
Organism | Homo sapiens
PMID | 16261164
Authors | Yang F,Foekens JA,Yu J,Sieuwerts AM,Timmermans M,Klijn JG,Atkins D,Wang Y,Jiang Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in laser microdissected (LCM) samples of early primary breast tumors expressing ESR1 [GeneID=2099] vs the ESR1 negative ones.
Full description | About 70-80% of breast cancers express estrogen receptor alpha (ER-alpha), and estrogens play important roles in the development and growth of hormone-dependent tumors. Together with lymph node metastasis, tumor size, and histological grade, ER status is considered as one of the prognostic factors in breast cancer, and an indicator for hormonal treatment. To investigate genes and pathways that are associated with ER status and epithelial cells in breast tumor, we applied laser capture microdissection (LCM) technology to capture epithelial tumor cells from 28 lymph node-negative breast tumor samples, in which 17 patients had ER-alpha+ tumors, and 11 patients have ER-alpha- tumors. Gene expression profiles were analysed on Affymetrix Hu133A GeneChip. Meanwhile, gene profiles using total RNA isolated from bulk tumors of the same 28 patients were also generated. In total, 146 genes and 112 genes with significant P-value and having significant differential expression between ER-alpha+ and ER-alpha- tumors were identified from the LCM data set and bulk tissue data set, respectively. A total of 61 genes were found to be common in both data sets, while 85 genes were unique to the LCM data set and 51 genes were present only in the bulk tumor data set. Pathway analysis with the 85 genes using Gene Ontology suggested that genes involved in endocytosis, ceramide generation, Ras/ERK/Ark cascade, and JAT-STAT pathways may play roles related to ER. The gene profiling with LCM-captured tumor cells provides a unique approach to study epithelial tumor cells and to gain an insight into signaling pathways associated with ER.

Standard name | YANG_BREAST_CANCER_ESR1_BULK_UP
Systematic name | M10748
Organism | Homo sapiens
PMID | 16261164
Authors | Yang F,Foekens JA,Yu J,Sieuwerts AM,Timmermans M,Klijn JG,Atkins D,Wang Y,Jiang Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in bulk samples from early primary breast tumors expressing ESR1 [GeneID=2099] vs the ESR1 negative samples.
Full description | About 70-80% of breast cancers express estrogen receptor alpha (ER-alpha), and estrogens play important roles in the development and growth of hormone-dependent tumors. Together with lymph node metastasis, tumor size, and histological grade, ER status is considered as one of the prognostic factors in breast cancer, and an indicator for hormonal treatment. To investigate genes and pathways that are associated with ER status and epithelial cells in breast tumor, we applied laser capture microdissection (LCM) technology to capture epithelial tumor cells from 28 lymph node-negative breast tumor samples, in which 17 patients had ER-alpha+ tumors, and 11 patients have ER-alpha- tumors. Gene expression profiles were analysed on Affymetrix Hu133A GeneChip. Meanwhile, gene profiles using total RNA isolated from bulk tumors of the same 28 patients were also generated. In total, 146 genes and 112 genes with significant P-value and having significant differential expression between ER-alpha+ and ER-alpha- tumors were identified from the LCM data set and bulk tissue data set, respectively. A total of 61 genes were found to be common in both data sets, while 85 genes were unique to the LCM data set and 51 genes were present only in the bulk tumor data set. Pathway analysis with the 85 genes using Gene Ontology suggested that genes involved in endocytosis, ceramide generation, Ras/ERK/Ark cascade, and JAT-STAT pathways may play roles related to ER. The gene profiling with LCM-captured tumor cells provides a unique approach to study epithelial tumor cells and to gain an insight into signaling pathways associated with ER.

Standard name | YANG_BREAST_CANCER_ESR1_BULK_DN
Systematic name | M5483
Organism | Homo sapiens
PMID | 16261164
Authors | Yang F,Foekens JA,Yu J,Sieuwerts AM,Timmermans M,Klijn JG,Atkins D,Wang Y,Jiang Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in bulk samples from early primary breast tumors expressing ESR1 [GeneID=2099] vs the ESR1 negative samples.
Full description | About 70-80% of breast cancers express estrogen receptor alpha (ER-alpha), and estrogens play important roles in the development and growth of hormone-dependent tumors. Together with lymph node metastasis, tumor size, and histological grade, ER status is considered as one of the prognostic factors in breast cancer, and an indicator for hormonal treatment. To investigate genes and pathways that are associated with ER status and epithelial cells in breast tumor, we applied laser capture microdissection (LCM) technology to capture epithelial tumor cells from 28 lymph node-negative breast tumor samples, in which 17 patients had ER-alpha+ tumors, and 11 patients have ER-alpha- tumors. Gene expression profiles were analysed on Affymetrix Hu133A GeneChip. Meanwhile, gene profiles using total RNA isolated from bulk tumors of the same 28 patients were also generated. In total, 146 genes and 112 genes with significant P-value and having significant differential expression between ER-alpha+ and ER-alpha- tumors were identified from the LCM data set and bulk tissue data set, respectively. A total of 61 genes were found to be common in both data sets, while 85 genes were unique to the LCM data set and 51 genes were present only in the bulk tumor data set. Pathway analysis with the 85 genes using Gene Ontology suggested that genes involved in endocytosis, ceramide generation, Ras/ERK/Ark cascade, and JAT-STAT pathways may play roles related to ER. The gene profiling with LCM-captured tumor cells provides a unique approach to study epithelial tumor cells and to gain an insight into signaling pathways associated with ER.

Standard name | WANG_RESPONSE_TO_BEXAROTENE_UP
Systematic name | M1263
Organism | Mus musculus
PMID | 16247446
Authors | Wang Y,Zhang Z,Yao R,Jia D,Wang D,Lubet RA,You M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the mouse lung cancer model and which reverted to normal levels upon treatment with bexarotene [PubChem=82146].
Full description | Bexarotene (Targretin), is a synthetic high-affinity RXR receptor agonist with limited affinity for RAR receptors. Bexarotene has shown efficacy in a phase I/II trial of non-small-cell lung cancers. However, the chemopreventive efficacy of bexarotene has not been determined in mouse lung cancer models. In this study, we have investigated the ability of bexarotene to inhibit lung tumor progression in the mutant A/J mouse models with genetic alterations in p53 or K-ras, two of the most commonly altered genes in human lung tumorigenesis. Mice were administered vinyl carbamate (VC), a carcinogen, by a single intraperitoneal injection (i.p.) at 6 weeks of age. Bexarotene was given by gavage starting at 16 weeks after VC and was continued for 12 weeks. Although all mice developed lung tumors, only 7% of lung tumors were adenocarcinomas in wild-type mice, whereas 22 and 26% of lung tumors were adenocarcinomas in p53 transgenic or K-ras heterozygous deficient mice. Bexarotene inhibited both tumor multiplicity and tumor volume in mice of all three genotypes. Furthermore, bexarotene reduced the progression of adenoma to adenocarcinoma by approximately 50% in both p53(wt/wt)K-ras(ko/wt) and p53(wt/wt)K-ras(wt/wt) mice. Thus, bexarotene appears to be an effective preventive agent against lung tumor growth and progression.

Standard name | WANG_RESPONSE_TO_BEXAROTENE_DN
Systematic name | M1264
Organism | Mus musculus
PMID | 16247446
Authors | Wang Y,Zhang Z,Yao R,Jia D,Wang D,Lubet RA,You M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the mouse lung cancer model and which reverted to normal levels upon treatment with bexarotene [PubChem=82146].
Full description | Bexarotene (Targretin), is a synthetic high-affinity RXR receptor agonist with limited affinity for RAR receptors. Bexarotene has shown efficacy in a phase I/II trial of non-small-cell lung cancers. However, the chemopreventive efficacy of bexarotene has not been determined in mouse lung cancer models. In this study, we have investigated the ability of bexarotene to inhibit lung tumor progression in the mutant A/J mouse models with genetic alterations in p53 or K-ras, two of the most commonly altered genes in human lung tumorigenesis. Mice were administered vinyl carbamate (VC), a carcinogen, by a single intraperitoneal injection (i.p.) at 6 weeks of age. Bexarotene was given by gavage starting at 16 weeks after VC and was continued for 12 weeks. Although all mice developed lung tumors, only 7% of lung tumors were adenocarcinomas in wild-type mice, whereas 22 and 26% of lung tumors were adenocarcinomas in p53 transgenic or K-ras heterozygous deficient mice. Bexarotene inhibited both tumor multiplicity and tumor volume in mice of all three genotypes. Furthermore, bexarotene reduced the progression of adenoma to adenocarcinoma by approximately 50% in both p53(wt/wt)K-ras(ko/wt) and p53(wt/wt)K-ras(wt/wt) mice. Thus, bexarotene appears to be an effective preventive agent against lung tumor growth and progression.

Standard name | STANHILL_HRAS_TRANSFROMATION_UP
Systematic name | M1265
Organism | Rattus norvegicus
PMID | 16278678
Authors | Stanhill A,Levin V,Hendel A,Shachar I,Kazanov D,Arber N,Kaminski N,Engelberg D
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated in Rat1Ras cells (fibroblasts) which were transformed by expression of an oncogenic activated form of HRAS [GeneID=3265] compared to the parental Rat1 cells.
Full description | Heat shock proteins (Hsps) are overexpressed in many tumors, but are downregulated in some tumors. To check for a direct effect of Ha-Ras(val12) on HSP70 transcription, we transiently expressed the oncoprotein in Rat1 fibroblasts and monitored its effect on HSP70b promoter-driven reporter gene. We show that expression of Ha-Ras(val12) induced this promoter. Promoter analysis via systematic deletions and point mutations revealed that Ha-Ras(val12) induces HSP70b transcription via heat shock elements (HSEs). Also, Ha-Ras(val12) induction of HSE-mediated transcription was dramatically reduced in HSF1-/- cells. Yet, residual effect of Ha-Ras(val12) that was still measured in HSF1-/- cells suggests that some of the Ha-Ras(val12) effect is Hsf1-independent. When HSF1-/- cells, stably expressing Ha-Ras(val12), were grown on soft agar only small colonies were formed suggesting a role for heat shock factor 1 (Hsf1) in Ha-Ras(val12)-mediated transformation. Although Ha-ras(Val12) seems to be an inducer of HSP70's expression, we found that in Ha-ras(Val12-)transformed fibroblasts expression of this gene is suppressed. This suppression is correlated with higher sensitivity of Ha-ras(val12)-transformed cells to heat shock. We suggest that Ha-ras(Val12) is involved in Hsf1 activation, thereby inducing the cellular protective response. Cells that repress this response are perhaps those that acquire the capability to further proliferate and become transformed clones.

Standard name | REN_MIF_TARGETS_DN
Systematic name | M9823
Organism | Homo sapiens
PMID | 16449971
Authors | Ren Y,Chan HM,Fan J,Xie Y,Chen YX,Li W,Jiang GP,Liu Q,Meinhardt A,Tam PK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SK-N-DZ cells (neuroblastoma) after knockdown of MIF [GeneID=4282] by antisense RNA.
Full description | Macrophage migration inhibitory factor (MIF) has been defined as a novel oncogene. Our previous results have shown that MIF may contribute to the progression of neuroblastoma by (a) inducing N-Myc expression and (b) upregulating the expression of angiogenic factors. The aim of this study was to test whether tumor growth could be inhibited by reduction of endogenous MIF expression in neuroblastoma and clarify the molecular mechanisms underlying MIF reduction on the control of neuroblastoma growth. We established human neuroblastoma cell lines stably expressing antisense MIF (AS-MIF) cDNA. These stable transfectants were characterized by cell proliferation, gene expression profile, tumorigenicity and metastasis in vitro and in vivo. Decreased MIF expression was observed after transfection with AS-MIF in neuroblastoma cells and downregulation of MIF expression significantly correlated with decreased expression of N-Myc, Ras, c-Met and TrkB at protein level. Affymetrix microarray analysis revealed that expression of IL-8 and c-met was inhibited and neuroblastoma-favorable genes such as EPHB6 and BLU were upregulated in MIF reduced cells. Neuroblastoma cell growth exhibited a nearly 80% reduction in AS-MIF transfectants in vitro. Furthermore, mice in which tumors formed after subcutaneous injection of AS-MIF transfectants showed a 90% reduction in tumor growth compared to control. Metastasis in mice was also suppressed dramatically. Our data demonstrate that targeting MIF expression is a promising therapeutic strategy in human neuroblastoma therapy, and also identifies the MIF target genes for further study.

Standard name | SEMBA_FHIT_TARGETS_UP
Systematic name | M14812
Organism | Homo sapiens
PMID | 16407838
Authors | Semba S,Trapasso F,Fabbri M,McCorkell KA,Volinia S,Druck T,Iliopoulos D,Pekarsky Y,Ishii H,Garrison PN,Barnes LD,Croce CM,Huebner K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in H1299 cells (non-small cell lung cancer, NSCLC) expressing the Y144F mutant form of FHIT [GeneID=2272].
Full description | The Fhit tumor suppressor binds and hydrolyses diadenosine polyphosphates and the Fhit-substrate complex has been proposed as a proapoptotic effector, as determined by infection of susceptible cancer cells with adenoviruses carrying wild-type fragile histidine triad (FHIT) or catalytic site mutants. The highly conserved Fhit tyrosine 114 (Y114), within the unstructured loop C-terminal of the catalytic site, can be phosphorylated by Src family tyrosine kinases, although endogenous phospho-Fhit is rarely detected. To explore the importance of Y114 and identify Fhit-mediated signaling events, wild-type and Y114 mutant FHIT-expressing adenoviruses were introduced into two human lung cancer cell lines. Caspase-dependent apoptosis was effectively induced only by wild-type but not Y114 mutant Fhit proteins. By expression profiling of FHIT versus mutant FHIT-infected cells, we found that survivin, an Inhibitor of Apoptosis Protein (IAP) family member, was significantly decreased by wild-type Fhit. In addition, Fhit inhibited activity of Akt, a key effector in the phosphatidylinositol 3-OH kinase (PI3K) pathway; loss of endogenous Fhit expression caused increased Akt activity in vitro and in vivo, and overexpression of constitutively active Akt inhibited Fhit-induced apoptosis. The results indicate that the Fhit Y114 residue plays a critical role in Fhit-induced apoptosis, occurring through inactivation of the PI3K-Akt-survivin signal pathway.

Standard name | SEMBA_FHIT_TARGETS_DN
Systematic name | M10504
Organism | Homo sapiens
PMID | 16407838
Authors | Semba S,Trapasso F,Fabbri M,McCorkell KA,Volinia S,Druck T,Iliopoulos D,Pekarsky Y,Ishii H,Garrison PN,Barnes LD,Croce CM,Huebner K
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in H1299 cells (non-small cell lung cancer, NSCLC) expressing the Y144F mutant form of FHIT [GeneID=2272].
Full description | The Fhit tumor suppressor binds and hydrolyses diadenosine polyphosphates and the Fhit-substrate complex has been proposed as a proapoptotic effector, as determined by infection of susceptible cancer cells with adenoviruses carrying wild-type fragile histidine triad (FHIT) or catalytic site mutants. The highly conserved Fhit tyrosine 114 (Y114), within the unstructured loop C-terminal of the catalytic site, can be phosphorylated by Src family tyrosine kinases, although endogenous phospho-Fhit is rarely detected. To explore the importance of Y114 and identify Fhit-mediated signaling events, wild-type and Y114 mutant FHIT-expressing adenoviruses were introduced into two human lung cancer cell lines. Caspase-dependent apoptosis was effectively induced only by wild-type but not Y114 mutant Fhit proteins. By expression profiling of FHIT versus mutant FHIT-infected cells, we found that survivin, an Inhibitor of Apoptosis Protein (IAP) family member, was significantly decreased by wild-type Fhit. In addition, Fhit inhibited activity of Akt, a key effector in the phosphatidylinositol 3-OH kinase (PI3K) pathway; loss of endogenous Fhit expression caused increased Akt activity in vitro and in vivo, and overexpression of constitutively active Akt inhibited Fhit-induced apoptosis. The results indicate that the Fhit Y114 residue plays a critical role in Fhit-induced apoptosis, occurring through inactivation of the PI3K-Akt-survivin signal pathway.

Standard name | SHANK_TAL1_TARGETS_DN
Systematic name | M1266
Organism | Mus musculus
PMID | 16407836
Authors | Shank-Calvo JA,Draheim K,Bhasin M,Kelliher MA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in preleukemic thymocytes from transgenic mice which overexpress TAL1 [GeneID=6886] in thymus.
Full description | Analysis of the INK4A/ARF locus in human T-ALL patients revealed frequent deletions in exon 2, the exon common to both p16(INK4A) and p14(ARF). Other studies have described selective deletion of exon 1beta of p14(ARF) or methylation of the p16(INK4A) promoter. Therefore, it is unclear from these studies whether loss of p16(INK4A) and/or p14(ARF) contributes to the development of T-ALL. To elucidate the relative contribution of the ink4a/arf locus to T-cell leukemogenesis, we mated our tal1 transgenic mice to ink4a/arf-/-, p16(ink4a)-/-, and p19(arf)-/- mice and generated tal1/ink4a/arf+/-, tal1/p16(ink4a)+/-, and tal1/p19(arf)+/- mice. Each of these mice developed T-cell leukemia rapidly, indicating that loss of either p16(ink4a) or p19(arf) cooperates with Tal1 to induce leukemia in mice. Preleukemic studies reveal that Tal1 expression stimulates entry into the cell cycle and thymocyte apoptosis in vivo. Interestingly, mice expressing a DNA-binding mutant of Tal1 do not exhibit increases in S phase cells. The S phase induction is accompanied by an increase in thymocyte apoptosis in tal1 transgenic mice. Whereas apoptosis is reduced to wild-type levels in tal1/ink4a/arf-/- mice, S phase induction remains unaffected. Thus, Tal1 stimulates cell cycle entry independent of the ink4a/arf locus, but its ability to induce apoptosis is Ink4a/Arf-dependent.

Standard name | HASINA_NOL7_TARGETS_UP
Systematic name | M6656
Organism | Homo sapiens
PMID | 16205646
Authors | Hasina R,Pontier AL,Fekete MJ,Martin LE,Qi XM,Brigaudeau C,Pramanik R,Cline EI,Coignet LJ,Lingen MW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SiHa cells (cervical carcinoma) by stable expression of NOL7 [GeneID=51406] off a plasmid vector.
Full description | Cervical cancer is associated with human papilloma virus infection. However, this infection is insufficient to induce transformation and progression. Loss of heterozygosity analyses suggest the presence of a tumor suppressor gene (TSG) on chromosome 6p21.3-p25. Here we report the cloning NOL7, its mapping to chromosome band 6p23, and localization of the protein to the nucleolus. Fluorescence in situ hybridization analysis demonstrated an allelic loss of an NOL7 in cultured tumor cells and human tumor samples. Transfection of NOL7 into cervical carcinoma cells inhibited their growth in mouse xenografts, confirming its in vivo tumor suppressor activity. The induction of tumor dormancy correlated with an angiogenic switch caused by a decreased production of vascular endothelial growth factor and an increase in the production of the angiogenesis inhibitor thrombospondin-1. These data suggest that NOL7 may function as a TSG in part by modulating the expression of the angiogenic phenotype.

Standard name | HASINA_NOL7_TARGETS_DN
Systematic name | M596
Organism | Homo sapiens
PMID | 16205646
Authors | Hasina R,Pontier AL,Fekete MJ,Martin LE,Qi XM,Brigaudeau C,Pramanik R,Cline EI,Coignet LJ,Lingen MW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SiHa cells (cervical carcinoma) by stable expression of NOL7 [GeneID=51406] off a plasmid vector.
Full description | Cervical cancer is associated with human papilloma virus infection. However, this infection is insufficient to induce transformation and progression. Loss of heterozygosity analyses suggest the presence of a tumor suppressor gene (TSG) on chromosome 6p21.3-p25. Here we report the cloning NOL7, its mapping to chromosome band 6p23, and localization of the protein to the nucleolus. Fluorescence in situ hybridization analysis demonstrated an allelic loss of an NOL7 in cultured tumor cells and human tumor samples. Transfection of NOL7 into cervical carcinoma cells inhibited their growth in mouse xenografts, confirming its in vivo tumor suppressor activity. The induction of tumor dormancy correlated with an angiogenic switch caused by a decreased production of vascular endothelial growth factor and an increase in the production of the angiogenesis inhibitor thrombospondin-1. These data suggest that NOL7 may function as a TSG in part by modulating the expression of the angiogenic phenotype.

Standard name | KONDO_HYPOXIA
Systematic name | M7407
Organism | Homo sapiens
PMID | 16247469
Authors | Kondo S,Kubota S,Mukudai Y,Moritani N,Nishida T,Matsushita H,Matsumoto S,Sugahara T,Takigawa M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HSC-2/8 cells (chondrosarcoma) under hypoxic conditions.
Full description | Connective tissue growth factor (CTGF/CCN2) can be induced by various forms of stress such as exposure to high glucose, mechanical load, or hypoxia. Here, we investigated the molecular mechanism involved in the induction of ctgf/ccn2 by hypoxia in a human chondrosarcoma cell line, HCS-2/8. Hypoxia increased the ctgf/ccn2 mRNA level by altering the 3'-untranslated region (UTR)-mediated mRNA stability without requiring de novo protein synthesis. After a series of extensive analyses, we eventually found that the cis-repressive element of 84 bases within the 3'-UTR specifically bound to a cytoplasmic/nuclear protein. By conducting a UV crosslinking assay, we found the cytoplasmic/nuclear protein to be a 35 kDa molecule that bound to the cis-element in a hypoxia-inducible manner. These results suggest that a cis-element in the 3'-UTR of ctgf/ccn2 mRNA and trans-factor counterpart(s) play an important role in the post-transcriptional regulation by determining the stability of ctgf/ccn2 mRNA.

Standard name | HOWLIN_PUBERTAL_MAMMARY_GLAND
Systematic name | M1267
Organism | Mus musculus
PMID | 16278680
Authors | Howlin J,McBryan J,Napoletano S,Lambe T,McArdle E,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pubertal mammary glands compared to mammary glands from other developmental stages.
Full description | Expression microarray analysis identified CITED1 among a group of genes specifically upregulated in the pubertal mouse mammary gland. At puberty, CITED1 localizes to the luminal epithelial cell population of the mammary ducts and the body cells of the terminal end buds. Generation of CITED1 gene knockout mice showed that homozygous null mutants exhibit retarded mammary ductal growth at puberty and, in addition, dilated ductal structures with a lack of spatial restriction of the subtending branches. Analysis of CITED1 homozygous null and heterozygous null mammary gland gene expression using microarrays suggested that the mammary-specific phenotype seen in the homozygous null females is due to a disturbance in the transcription of a number of key mediators of pubertal ductal morphogenesis. These include estrogen and TGFbeta responsive genes, such as the EGFR/ErbB2 ligand, amphiregulin, whose transcription we suggest is directly or indirectly regulated by CITED1.

Standard name | KREPPEL_CD99_TARGETS_DN
Systematic name | M1269
Organism | Homo sapiens
PMID | 16314831
Authors | Kreppel M,Aryee DN,Schaefer KL,Amann G,Kofler R,Poremba C,Kovar H
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ESFT cells (Ewing's sarcoma family of tumors) after knockdown of CD99 [GeneID=4267] by RNAi.
Full description | High CD99 expression levels and rearrangements of the EWS gene with ETS transcription factor genes characterize the Ewing's sarcoma family of tumors (ESFT). CD99 is a cell surface glycoprotein whose engagement has been implicated in cell proliferation as well as upregulation and transport of several transmembrane proteins in hematopoietic cells. In ESFT, antibody ligation of CD99 induces fast homotypic cell aggregation and cell death although its functional role in these processes remains largely unknown. Here, using an RNAi approach, we studied for the first time the consequences of modulated CD99 expression in six different ESFT cell lines, representing the most frequent variant forms of EWS gene rearrangement. CD99 suppression resulted in growth inhibition and reduced migration of ESFT cells. Among genes whose expression changes in response to CD99 modulation, the potassium-channel modulatory factor KCMF1 was consistently upregulated. In a series of 22 primary ESFT, KCMF1 expression levels inversely correlated with CD99 abundancy. Cells forced to express ectopic KCMF1 showed a similar reduction in migratory ability as CD99 silenced ESFT cells. Our results suggest that in ESFT, high CD99 expression levels contribute to the malignant properties of ESFT by promoting growth and migration of tumor cells and identify KCMF1 as a potential metastasis suppressor gene downregulated by high constitutive CD99 expression in ESFT.

Standard name | HATADA_METHYLATED_IN_LUNG_CANCER_UP
Systematic name | M19508
Organism | Homo sapiens
PMID | 16407832
Authors | Hatada I,Fukasawa M,Kimura M,Morita S,Yamada K,Yoshikawa T,Yamanaka S,Endo C,Sakurada A,Sato M,Kondo T,Horii A,Ushijima T,Sasaki H
Category | C2
Sub-category | CGP
Brief description | Genes with hypermethylated DNA in lung cancer samples.
Full description | DNA methylation in the promoter region of a gene is associated with a loss of that gene's expression and plays an important role in gene silencing. The inactivation of tumor-suppressor genes by aberrant methylation in the promoter region is well recognized in carcinogenesis. However, there has been little study in this area when it comes to genome-wide profiling of the promoter methylation. Here, we developed a genome-wide profiling method called Microarray-based Integrated Analysis of Methylation by Isoschizomers to analyse the DNA methylation of promoter regions of 8091 human genes. With this method, resistance to both the methylation-sensitive restriction enzyme HpaII and the methylation-insensitive isoschizomer MspI was compared between samples by using a microarray with promoter regions of the 8091 genes. The reliability of the difference in HpaII resistance was judged using the difference in MspI resistance. We demonstrated the utility of this method by finding epigenetic mutations in cancer. Aberrant hypermethylation is known to inactivate tumour suppressor genes. Using this method, we found that frequency of the aberrant promoter hypermethylation in cancer is higher than previously hypothesized. Aberrant hypomethylation is known to induce activation of oncogenes in cancer. Genome-wide analysis of hypomethylated promoter sequences in cancer demonstrated low CG/GC ratio of these sequences, suggesting that CpG-poor genes are sensitive to demethylation activity in cancer.

Standard name | HATADA_METHYLATED_IN_LUNG_CANCER_DN
Systematic name | M11680
Organism | Homo sapiens
PMID | 16407832
Authors | Hatada I,Fukasawa M,Kimura M,Morita S,Yamada K,Yoshikawa T,Yamanaka S,Endo C,Sakurada A,Sato M,Kondo T,Horii A,Ushijima T,Sasaki H
Category | C2
Sub-category | CGP
Brief description | Genes with unmethylated DNA in lung cancer samples.
Full description | DNA methylation in the promoter region of a gene is associated with a loss of that gene's expression and plays an important role in gene silencing. The inactivation of tumor-suppressor genes by aberrant methylation in the promoter region is well recognized in carcinogenesis. However, there has been little study in this area when it comes to genome-wide profiling of the promoter methylation. Here, we developed a genome-wide profiling method called Microarray-based Integrated Analysis of Methylation by Isoschizomers to analyse the DNA methylation of promoter regions of 8091 human genes. With this method, resistance to both the methylation-sensitive restriction enzyme HpaII and the methylation-insensitive isoschizomer MspI was compared between samples by using a microarray with promoter regions of the 8091 genes. The reliability of the difference in HpaII resistance was judged using the difference in MspI resistance. We demonstrated the utility of this method by finding epigenetic mutations in cancer. Aberrant hypermethylation is known to inactivate tumour suppressor genes. Using this method, we found that frequency of the aberrant promoter hypermethylation in cancer is higher than previously hypothesized. Aberrant hypomethylation is known to induce activation of oncogenes in cancer. Genome-wide analysis of hypomethylated promoter sequences in cancer demonstrated low CG/GC ratio of these sequences, suggesting that CpG-poor genes are sensitive to demethylation activity in cancer.

Standard name | CALVET_IRINOTECAN_SENSITIVE_VS_RESISTANT_UP
Systematic name | M17456
Organism | Homo sapiens
PMID | 16501609
Authors | Calvet L,Geoerger B,Regairaz M,Opolon P,Machet L,Morizet J,Joseph JM,Elie N,Vassal G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in neuroblastoma xenografts: sensitive vs resistant to the topoisomerase inhibitor irinotecan [GeneID=3750].
Full description | In vivo neuroblastoma (NB) xenograft model, resistant to the DNA-topoisomerase I inhibitor irinotecan (CPT-11), has been established to study resistance mechanisms acquired in a therapeutic setting. Common mechanisms of resistance were not involved in this resistance. Thus, we compared the gene expression profiles of sensitive, resistant, and reverted tumors using cDNA expression arrays. Expression of selected transcripts was confirmed by quantitative real-time PCR. We found that pleiotrophin (PTN), a heparin-binding growth factor, was the only gene significantly affected: PTN gene expression was downregulated in all resistant tumors (8-14-fold) as compared to sensitive tumors, and was increased (2-4-fold) in all reverted tumors as compared to resistant tumors. PTN thus appeared to be a likely candidate gene associated with resistance to CPT-11 in this in vivo model. To investigate the direct implication of PTN in NB, we transfected two NB cell lines with RNA interferences in order to silence PTN. PTN failed to demonstrate implication in resistance to CPT-11 in vitro but could influence sensitivity to CPT-11 exclusively through an in vivo mechanism. Indeed, vasculature was significantly enhanced in resistant NB xenografts compared to sensitive and reverted xenografts, and we suggest that PTN is acting in our resistant in vivo NB model as an angiostatic factor.

Standard name | CALVET_IRINOTECAN_SENSITIVE_VS_REVERTED_UP
Systematic name | M1750
Organism | Homo sapiens
PMID | 16501609
Authors | Calvet L,Geoerger B,Regairaz M,Opolon P,Machet L,Morizet J,Joseph JM,Elie N,Vassal G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in neuroblastoma xenografts: resistant vs those that reverted to be sensitive to the topoisomerase inhibitor irinotecan [PubChem=3750].
Full description | In vivo neuroblastoma (NB) xenograft model, resistant to the DNA-topoisomerase I inhibitor irinotecan (CPT-11), has been established to study resistance mechanisms acquired in a therapeutic setting. Common mechanisms of resistance were not involved in this resistance. Thus, we compared the gene expression profiles of sensitive, resistant, and reverted tumors using cDNA expression arrays. Expression of selected transcripts was confirmed by quantitative real-time PCR. We found that pleiotrophin (PTN), a heparin-binding growth factor, was the only gene significantly affected: PTN gene expression was downregulated in all resistant tumors (8-14-fold) as compared to sensitive tumors, and was increased (2-4-fold) in all reverted tumors as compared to resistant tumors. PTN thus appeared to be a likely candidate gene associated with resistance to CPT-11 in this in vivo model. To investigate the direct implication of PTN in NB, we transfected two NB cell lines with RNA interferences in order to silence PTN. PTN failed to demonstrate implication in resistance to CPT-11 in vitro but could influence sensitivity to CPT-11 exclusively through an in vivo mechanism. Indeed, vasculature was significantly enhanced in resistant NB xenografts compared to sensitive and reverted xenografts, and we suggest that PTN is acting in our resistant in vivo NB model as an angiostatic factor.

Standard name | CALVET_IRINOTECAN_SENSITIVE_VS_REVERTED_DN
Systematic name | M1271
Organism | Homo sapiens
PMID | 16501609
Authors | Calvet L,Geoerger B,Regairaz M,Opolon P,Machet L,Morizet J,Joseph JM,Elie N,Vassal G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in neuroblastoma xenografts: resistant vs those that reverted to be sensitive to the topoisomerase inhibitor irinotecan [PubChem=3750].
Full description | In vivo neuroblastoma (NB) xenograft model, resistant to the DNA-topoisomerase I inhibitor irinotecan (CPT-11), has been established to study resistance mechanisms acquired in a therapeutic setting. Common mechanisms of resistance were not involved in this resistance. Thus, we compared the gene expression profiles of sensitive, resistant, and reverted tumors using cDNA expression arrays. Expression of selected transcripts was confirmed by quantitative real-time PCR. We found that pleiotrophin (PTN), a heparin-binding growth factor, was the only gene significantly affected: PTN gene expression was downregulated in all resistant tumors (8-14-fold) as compared to sensitive tumors, and was increased (2-4-fold) in all reverted tumors as compared to resistant tumors. PTN thus appeared to be a likely candidate gene associated with resistance to CPT-11 in this in vivo model. To investigate the direct implication of PTN in NB, we transfected two NB cell lines with RNA interferences in order to silence PTN. PTN failed to demonstrate implication in resistance to CPT-11 in vitro but could influence sensitivity to CPT-11 exclusively through an in vivo mechanism. Indeed, vasculature was significantly enhanced in resistant NB xenografts compared to sensitive and reverted xenografts, and we suggest that PTN is acting in our resistant in vivo NB model as an angiostatic factor.

Standard name | FURUKAWA_DUSP6_TARGETS_PCI35_UP
Systematic name | M6998
Organism | Homo sapiens
PMID | 16532023
Authors | Furukawa T,Kanai N,Shiwaku HO,Soga N,Uehara A,Horii A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in PCI-35 cells (pancreatic cancer, lack endogenous DUSP6 [GeneID=1848]) upon expression of DUSP6 off an adenoviral vector.
Full description | DUSP6/MKP-3, a specific inhibitor of MAPK1/ERK2, frequently loses its expression in primary pancreatic cancer tissues. This evidence suggests that constitutive activation of MAPK1 synergistically induced by frequent mutation of KRAS2 and the loss of function of DUSP6 plays key roles in pancreatic carcinogenesis and progression. By profiling of gene expressions associated with downregulation of MAPK1 induced by exogenous overexpression of DUSP6 in pancreatic cancer cells, we found that AURKA/STK15, the gene encoding Aurora-A kinase, which plays key roles in cellular mitosis, was among the downregulated genes along with its related genes, which included AURKB, TPX2 and CENPA. An association of expression and promoter activity of AURKA with MAPK activity was verified. Knockdown of ETS2 resulted in a reduction of AURKA expression. These results indicate that AURKA is a direct target of the MAPK pathway and that its overexpression in pancreatic cancer is induced by hyperactivation of the pathway, at least via ETS2.

Standard name | FURUKAWA_DUSP6_TARGETS_PCI35_DN
Systematic name | M7339
Organism | Homo sapiens
PMID | 16532023
Authors | Furukawa T,Kanai N,Shiwaku HO,Soga N,Uehara A,Horii A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in PCI-35 cells (pancreatic cancer, lack endogenous DUSP6 [GeneID=1848]) upon expression of DUSP6 off an adenoviral vector.
Full description | DUSP6/MKP-3, a specific inhibitor of MAPK1/ERK2, frequently loses its expression in primary pancreatic cancer tissues. This evidence suggests that constitutive activation of MAPK1 synergistically induced by frequent mutation of KRAS2 and the loss of function of DUSP6 plays key roles in pancreatic carcinogenesis and progression. By profiling of gene expressions associated with downregulation of MAPK1 induced by exogenous overexpression of DUSP6 in pancreatic cancer cells, we found that AURKA/STK15, the gene encoding Aurora-A kinase, which plays key roles in cellular mitosis, was among the downregulated genes along with its related genes, which included AURKB, TPX2 and CENPA. An association of expression and promoter activity of AURKA with MAPK activity was verified. Knockdown of ETS2 resulted in a reduction of AURKA expression. These results indicate that AURKA is a direct target of the MAPK pathway and that its overexpression in pancreatic cancer is induced by hyperactivation of the pathway, at least via ETS2.

Standard name | KARAKAS_TGFB1_SIGNALING
Systematic name | M17300
Organism | Homo sapiens
PMID | 16619041
Authors | Karakas B,Weeraratna A,Abukhdeir A,Blair BG,Konishi H,Arena S,Becker K,Wood W 3rd,Argani P,De Marzo AM,Bachman KE,Park BH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by TGFB1 [GeneID=7040] in MCF10A cells (breast cancer): both wild-type and those lacking p21 [GeneID=1026].
Full description | Transforming growth factor-beta type 1 (TGF-beta) has been implicated as both a tumor suppressor and a tumor promoter in many solid epithelial cancers. We have previously demonstrated that the cyclin dependent kinase (CDK) inhibitor p21 acts as a molecular switch in determining a growth inhibitory versus growth proliferative response to TGF-beta in the spontaneously immortalized human mammary epithelial cell line MCF-10A. We now demonstrate that this proliferative effect of TGF-beta is mediated through the proinflammatory cytokine, interleukin-1alpha (IL-1alpha). Using gene expression array analysis, we identified IL-1alpha as a cytokine specifically upregulated only in cells lacking p21 and only upon TGF-beta stimulation. Cell proliferation assays verified that recombinant IL-1alpha was capable of inducing a growth proliferative response in p21 null MCF-10A cells, while neutralizing antibodies against IL-1alpha prevented the growth proliferative effects of TGF-beta. Mechanistically, both the CDK and proliferating cell nuclear antigen (PCNA) inhibitory functions of p21 were responsible for preventing TGF-beta induced cell proliferation, but only PCNA inhibition by p21 regulated IL-1alpha gene expression. These studies demonstrate a novel role for IL-1alpha in mediating a proliferative response to TGF-beta signaling, and suggest that therapies directed against IL-1alpha could abate the growth proliferative effects of TGF-beta without compromising its tumor suppressive function.

Standard name | SHETH_LIVER_CANCER_VS_TXNIP_LOSS_PAM1
Systematic name | M1273
Organism | Mus musculus
PMID | 16607285
Authors | Sheth SS,Bodnar JS,Ghazalpour A,Thipphavong CK,Tsutsumi S,Tward AD,Demant P,Kodama T,Aburatani H,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Cluster PAM1: genes up-regulated in hepatocellular carcinoma (HCC) vs normal liver tissue from mice deficient for TXNIP [GeneID=10628].
Full description | The molecular pathogenesis and the genetic aberrations that lead to the progression of hepatocellular carcinoma (HCC) are largely unknown. Here, we demonstrate that the thioredoxin interacting protein (Txnip) gene is a candidate tumor suppressor gene in vivo. We previously showed that the recombinant inbred congenic strain HcB-19 has a spontaneous mutation of the Txnip gene, and we now show that the strain has dramatically increased incidence of HCC, and that the HCC cosegregates with the Txnip mutation. Approximately 40% of the Txnip-deficient mice developed hepatic tumors with an increased prevalence in male mice. Visible tumors develop as early as 8 months of age. Histological analysis confirmed the morphology of HCC in the Txnip-deficient mice. Molecular markers of HCC, alpha-fetoprotein and p53, were increased in tumors of Txnip-deficient mice. The upregulation of p53 preceded tumor development; however, bromodeoxyuridine (BrdU) labeling of normal hepatic tissue of Txnip-deficient mice did not reveal increased cell proliferation. Finally, microarray analyses of tumor, non-tumor adjacent, and normal tissue of Txnip-deficient mice highlighted the genetic differences leading to the predisposition and onset of HCC. Our findings suggest that Txnip deficiency is sufficient to initiate HCC and suggest novel mechanisms in hepatocarcinogenesis.

Standard name | SHETH_LIVER_CANCER_VS_TXNIP_LOSS_PAM2
Systematic name | M1275
Organism | Mus musculus
PMID | 16607285
Authors | Sheth SS,Bodnar JS,Ghazalpour A,Thipphavong CK,Tsutsumi S,Tward AD,Demant P,Kodama T,Aburatani H,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Cluster PAM2: genes up-regulated in hepatocellular carcinoma (HCC) vs normal liver tissue from mice deficient for TXNIP [GeneID=10628].
Full description | The molecular pathogenesis and the genetic aberrations that lead to the progression of hepatocellular carcinoma (HCC) are largely unknown. Here, we demonstrate that the thioredoxin interacting protein (Txnip) gene is a candidate tumor suppressor gene in vivo. We previously showed that the recombinant inbred congenic strain HcB-19 has a spontaneous mutation of the Txnip gene, and we now show that the strain has dramatically increased incidence of HCC, and that the HCC cosegregates with the Txnip mutation. Approximately 40% of the Txnip-deficient mice developed hepatic tumors with an increased prevalence in male mice. Visible tumors develop as early as 8 months of age. Histological analysis confirmed the morphology of HCC in the Txnip-deficient mice. Molecular markers of HCC, alpha-fetoprotein and p53, were increased in tumors of Txnip-deficient mice. The upregulation of p53 preceded tumor development; however, bromodeoxyuridine (BrdU) labeling of normal hepatic tissue of Txnip-deficient mice did not reveal increased cell proliferation. Finally, microarray analyses of tumor, non-tumor adjacent, and normal tissue of Txnip-deficient mice highlighted the genetic differences leading to the predisposition and onset of HCC. Our findings suggest that Txnip deficiency is sufficient to initiate HCC and suggest novel mechanisms in hepatocarcinogenesis.

Standard name | SHETH_LIVER_CANCER_VS_TXNIP_LOSS_PAM3
Systematic name | M1277
Organism | Mus musculus
PMID | 16607285
Authors | Sheth SS,Bodnar JS,Ghazalpour A,Thipphavong CK,Tsutsumi S,Tward AD,Demant P,Kodama T,Aburatani H,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Cluster PAM3: genes most highly up-regulated in hepatocellular carcinoma (HCC) vs normal liver tissue from mice deficient for TXNIP [GeneID=10628].
Full description | The molecular pathogenesis and the genetic aberrations that lead to the progression of hepatocellular carcinoma (HCC) are largely unknown. Here, we demonstrate that the thioredoxin interacting protein (Txnip) gene is a candidate tumor suppressor gene in vivo. We previously showed that the recombinant inbred congenic strain HcB-19 has a spontaneous mutation of the Txnip gene, and we now show that the strain has dramatically increased incidence of HCC, and that the HCC cosegregates with the Txnip mutation. Approximately 40% of the Txnip-deficient mice developed hepatic tumors with an increased prevalence in male mice. Visible tumors develop as early as 8 months of age. Histological analysis confirmed the morphology of HCC in the Txnip-deficient mice. Molecular markers of HCC, alpha-fetoprotein and p53, were increased in tumors of Txnip-deficient mice. The upregulation of p53 preceded tumor development; however, bromodeoxyuridine (BrdU) labeling of normal hepatic tissue of Txnip-deficient mice did not reveal increased cell proliferation. Finally, microarray analyses of tumor, non-tumor adjacent, and normal tissue of Txnip-deficient mice highlighted the genetic differences leading to the predisposition and onset of HCC. Our findings suggest that Txnip deficiency is sufficient to initiate HCC and suggest novel mechanisms in hepatocarcinogenesis.

Standard name | SHETH_LIVER_CANCER_VS_TXNIP_LOSS_PAM4
Systematic name | M1280
Organism | Mus musculus
PMID | 16607285
Authors | Sheth SS,Bodnar JS,Ghazalpour A,Thipphavong CK,Tsutsumi S,Tward AD,Demant P,Kodama T,Aburatani H,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Cluster PAM4: genes down-regulated in hepatocellular carcinoma (HCC) vs normal liver tissue from mice deficient for TXNIP [GeneID=10628].
Full description | The molecular pathogenesis and the genetic aberrations that lead to the progression of hepatocellular carcinoma (HCC) are largely unknown. Here, we demonstrate that the thioredoxin interacting protein (Txnip) gene is a candidate tumor suppressor gene in vivo. We previously showed that the recombinant inbred congenic strain HcB-19 has a spontaneous mutation of the Txnip gene, and we now show that the strain has dramatically increased incidence of HCC, and that the HCC cosegregates with the Txnip mutation. Approximately 40% of the Txnip-deficient mice developed hepatic tumors with an increased prevalence in male mice. Visible tumors develop as early as 8 months of age. Histological analysis confirmed the morphology of HCC in the Txnip-deficient mice. Molecular markers of HCC, alpha-fetoprotein and p53, were increased in tumors of Txnip-deficient mice. The upregulation of p53 preceded tumor development; however, bromodeoxyuridine (BrdU) labeling of normal hepatic tissue of Txnip-deficient mice did not reveal increased cell proliferation. Finally, microarray analyses of tumor, non-tumor adjacent, and normal tissue of Txnip-deficient mice highlighted the genetic differences leading to the predisposition and onset of HCC. Our findings suggest that Txnip deficiency is sufficient to initiate HCC and suggest novel mechanisms in hepatocarcinogenesis.

Standard name | SHETH_LIVER_CANCER_VS_TXNIP_LOSS_PAM5
Systematic name | M1281
Organism | Mus musculus
PMID | 16607285
Authors | Sheth SS,Bodnar JS,Ghazalpour A,Thipphavong CK,Tsutsumi S,Tward AD,Demant P,Kodama T,Aburatani H,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Cluster PAM5: genes changed exclusively in hepatocellular carcinoma (HCC) samples from 27 month old mice deficient for TXNIP [GeneID=10628].
Full description | The molecular pathogenesis and the genetic aberrations that lead to the progression of hepatocellular carcinoma (HCC) are largely unknown. Here, we demonstrate that the thioredoxin interacting protein (Txnip) gene is a candidate tumor suppressor gene in vivo. We previously showed that the recombinant inbred congenic strain HcB-19 has a spontaneous mutation of the Txnip gene, and we now show that the strain has dramatically increased incidence of HCC, and that the HCC cosegregates with the Txnip mutation. Approximately 40% of the Txnip-deficient mice developed hepatic tumors with an increased prevalence in male mice. Visible tumors develop as early as 8 months of age. Histological analysis confirmed the morphology of HCC in the Txnip-deficient mice. Molecular markers of HCC, alpha-fetoprotein and p53, were increased in tumors of Txnip-deficient mice. The upregulation of p53 preceded tumor development; however, bromodeoxyuridine (BrdU) labeling of normal hepatic tissue of Txnip-deficient mice did not reveal increased cell proliferation. Finally, microarray analyses of tumor, non-tumor adjacent, and normal tissue of Txnip-deficient mice highlighted the genetic differences leading to the predisposition and onset of HCC. Our findings suggest that Txnip deficiency is sufficient to initiate HCC and suggest novel mechanisms in hepatocarcinogenesis.

Standard name | SHETH_LIVER_CANCER_VS_TXNIP_LOSS_PAM6
Systematic name | M1284
Organism | Mus musculus
PMID | 16607285
Authors | Sheth SS,Bodnar JS,Ghazalpour A,Thipphavong CK,Tsutsumi S,Tward AD,Demant P,Kodama T,Aburatani H,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Cluster PAM6: genes changed exclusively in normal liver tissue adjacent to hepatocellular carcinoma (HCC) from mice deficient for TXNIP [GeneID=10628].
Full description | The molecular pathogenesis and the genetic aberrations that lead to the progression of hepatocellular carcinoma (HCC) are largely unknown. Here, we demonstrate that the thioredoxin interacting protein (Txnip) gene is a candidate tumor suppressor gene in vivo. We previously showed that the recombinant inbred congenic strain HcB-19 has a spontaneous mutation of the Txnip gene, and we now show that the strain has dramatically increased incidence of HCC, and that the HCC cosegregates with the Txnip mutation. Approximately 40% of the Txnip-deficient mice developed hepatic tumors with an increased prevalence in male mice. Visible tumors develop as early as 8 months of age. Histological analysis confirmed the morphology of HCC in the Txnip-deficient mice. Molecular markers of HCC, alpha-fetoprotein and p53, were increased in tumors of Txnip-deficient mice. The upregulation of p53 preceded tumor development; however, bromodeoxyuridine (BrdU) labeling of normal hepatic tissue of Txnip-deficient mice did not reveal increased cell proliferation. Finally, microarray analyses of tumor, non-tumor adjacent, and normal tissue of Txnip-deficient mice highlighted the genetic differences leading to the predisposition and onset of HCC. Our findings suggest that Txnip deficiency is sufficient to initiate HCC and suggest novel mechanisms in hepatocarcinogenesis.

Standard name | LIEN_BREAST_CARCINOMA_METAPLASTIC
Systematic name | M11654
Organism | Homo sapiens
PMID | 17603561
Authors | Lien HC,Hsiao YH,Lin YS,Yao YT,Juan HF,Kuo WH,Hung MC,Chang KJ,Hsieh FJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in metaplastic carcinoma of the breast (MCB) subclass 2 compared to the MCB subclass 1.
Full description | Metaplastic carcinoma of the breast (MCB) is a poorly understood subtype of breast cancer. It is generally characterized by the coexistence of ductal carcinomatous and transdifferentiated sarcomatous components, but the underlying molecular alterations, possibly related to epithelial-mesenchymal transition (EMT), remain elusive. We performed transcriptional profiling using half-a-genome oligonucleotide microarrays to elucidate genetic profiles of MCBs and their differences to those of ductal carcinoma of breasts (DCBs) using discarded specimens of four MCBs and 34 DCBs. Unsupervised clustering disclosed distinctive expression profiles between MCBs and DCBs. Supervised analysis identified gene signatures discriminating MCBs from DCBs and between MCB subclasses. Notably, many of the discriminator genes were associated with downregulation of epithelial phenotypes and with synthesis, remodeling and adhesion of extracellular matrix, with some of them have known or inferred roles related to EMT. Importantly, several of the discriminator genes were upregulated in a mutant Snail-transfected MCF7 cell known to exhibit features of EMT, thereby indicating a crucial role for EMT in the pathogenesis of MCBs. Finally, the identification of SPARC and vimentin as poor prognostic factors reinforced the role of EMT in cancer progression. These data advance our understanding of MCB and offer clues to the molecular alterations underlying EMT.

Standard name | SCHMAHL_PDGF_SIGNALING
Systematic name | M1285
Organism | Mus musculus
PMID | 17143286
Authors | Schmahl J,Raymond CS,Soriano P
Category | C2
Sub-category | CGP
Brief description | These genes form a a network that controls specific processes downstream of PDGF signaling.
Full description | Growth factor signaling leads to the induction or repression of immediate early genes, but how these genes act collectively as effectors of downstream processes remains unresolved. We have used gene trap-coupled microarray analysis to identify and mutate multiple platelet-derived growth factor (PDGF) intermediate early genes in mice. Mutations in these genes lead to a high frequency of phenotypes that affect the same cell types and processes as those controlled by the PDGF pathway. We conclude that these genes form a network that controls specific processes downstream of PDGF signaling.

Standard name | TOMLINS_PROSTATE_CANCER_UP
Systematic name | M19148
Organism | Homo sapiens
PMID | 17173048
Authors | Tomlins SA,Mehra R,Rhodes DR,Cao X,Wang L,Dhanasekaran SM,Kalyana-Sundaram S,Wei JT,Rubin MA,Pienta KJ,Shah RB,Chinnaiyan AM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in prostate cancer vs benign prostate tissue, based on a meta-analysis of five gene expression profiling studies.
Full description | Despite efforts to profile prostate cancer, the genetic alterations and biological processes that correlate with the observed histological progression are unclear. Using laser-capture microdissection to isolate 101 cell populations, we have profiled prostate cancer progression from benign epithelium to metastatic disease. By analyzing expression signatures in the context of over 14,000 'molecular concepts', or sets of biologically connected genes, we generated an integrative model of progression. Molecular concepts that demarcate critical transitions in progression include protein biosynthesis, E26 transformation-specific (ETS) family transcriptional targets, androgen signaling and cell proliferation. Of note, relative to low-grade prostate cancer (Gleason pattern 3), high-grade cancer (Gleason pattern 4) shows an attenuated androgen signaling signature, similar to metastatic prostate cancer, which may reflect dedifferentiation and explain the clinical association of grade with prognosis. Taken together, these data show that analyzing gene expression signatures in the context of a compendium of molecular concepts is useful in understanding cancer biology.

Standard name | TOMLINS_PROSTATE_CANCER_DN
Systematic name | M11504
Organism | Homo sapiens
PMID | 17173048
Authors | Tomlins SA,Mehra R,Rhodes DR,Cao X,Wang L,Dhanasekaran SM,Kalyana-Sundaram S,Wei JT,Rubin MA,Pienta KJ,Shah RB,Chinnaiyan AM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in prostate cancer vs benign prostate tissue, based on a meta-analysis of five gene expression profiling studies.
Full description | Despite efforts to profile prostate cancer, the genetic alterations and biological processes that correlate with the observed histological progression are unclear. Using laser-capture microdissection to isolate 101 cell populations, we have profiled prostate cancer progression from benign epithelium to metastatic disease. By analyzing expression signatures in the context of over 14,000 'molecular concepts', or sets of biologically connected genes, we generated an integrative model of progression. Molecular concepts that demarcate critical transitions in progression include protein biosynthesis, E26 transformation-specific (ETS) family transcriptional targets, androgen signaling and cell proliferation. Of note, relative to low-grade prostate cancer (Gleason pattern 3), high-grade cancer (Gleason pattern 4) shows an attenuated androgen signaling signature, similar to metastatic prostate cancer, which may reflect dedifferentiation and explain the clinical association of grade with prognosis. Taken together, these data show that analyzing gene expression signatures in the context of a compendium of molecular concepts is useful in understanding cancer biology.

Standard name | TOMLINS_METASTASIS_UP
Systematic name | M9054
Organism | Homo sapiens
PMID | 17173048
Authors | Tomlins SA,Mehra R,Rhodes DR,Cao X,Wang L,Dhanasekaran SM,Kalyana-Sundaram S,Wei JT,Rubin MA,Pienta KJ,Shah RB,Chinnaiyan AM
Category | C2
Sub-category | CGP
Brief description | Top genes up-regulated in hormone refractory metastatic prostate cancer compared to localized prostate cancer.
Full description | Despite efforts to profile prostate cancer, the genetic alterations and biological processes that correlate with the observed histological progression are unclear. Using laser-capture microdissection to isolate 101 cell populations, we have profiled prostate cancer progression from benign epithelium to metastatic disease. By analyzing expression signatures in the context of over 14,000 'molecular concepts', or sets of biologically connected genes, we generated an integrative model of progression. Molecular concepts that demarcate critical transitions in progression include protein biosynthesis, E26 transformation-specific (ETS) family transcriptional targets, androgen signaling and cell proliferation. Of note, relative to low-grade prostate cancer (Gleason pattern 3), high-grade cancer (Gleason pattern 4) shows an attenuated androgen signaling signature, similar to metastatic prostate cancer, which may reflect dedifferentiation and explain the clinical association of grade with prognosis. Taken together, these data show that analyzing gene expression signatures in the context of a compendium of molecular concepts is useful in understanding cancer biology.

Standard name | TOMLINS_METASTASIS_DN
Systematic name | M7090
Organism | Homo sapiens
PMID | 17173048
Authors | Tomlins SA,Mehra R,Rhodes DR,Cao X,Wang L,Dhanasekaran SM,Kalyana-Sundaram S,Wei JT,Rubin MA,Pienta KJ,Shah RB,Chinnaiyan AM
Category | C2
Sub-category | CGP
Brief description | Top genes down-regulated in hormone refractory metastatic prostate cancer compared to localized prostate cancer.
Full description | Despite efforts to profile prostate cancer, the genetic alterations and biological processes that correlate with the observed histological progression are unclear. Using laser-capture microdissection to isolate 101 cell populations, we have profiled prostate cancer progression from benign epithelium to metastatic disease. By analyzing expression signatures in the context of over 14,000 'molecular concepts', or sets of biologically connected genes, we generated an integrative model of progression. Molecular concepts that demarcate critical transitions in progression include protein biosynthesis, E26 transformation-specific (ETS) family transcriptional targets, androgen signaling and cell proliferation. Of note, relative to low-grade prostate cancer (Gleason pattern 3), high-grade cancer (Gleason pattern 4) shows an attenuated androgen signaling signature, similar to metastatic prostate cancer, which may reflect dedifferentiation and explain the clinical association of grade with prognosis. Taken together, these data show that analyzing gene expression signatures in the context of a compendium of molecular concepts is useful in understanding cancer biology.

Standard name | LIANG_HEMATOPOIESIS_STEM_CELL_NUMBER_LARGE_VS_TINY_UP
Systematic name | M7084
Organism | Mus musculus
PMID | 17220891
Authors | Liang Y,Jansen M,Aronow B,Geiger H,Van Zant G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in LSK cells (bone marrow) as a function of a QTL for the size of hematopoietic stem cell (HSC) population: comparison of congenic B.D. chr3 (BD, large HSC size) vs parental B6 strain (tiny HSC size).
Full description | We mapped quantitative trait loci that accounted for the variation in hematopoietic stem cell (HSC) numbers between young adult C57BL/6 (B6) and DBA/2 (D2) mice. In reciprocal chromosome 3 congenic mice, introgressed D2 alleles increased HSC numbers owing to enhanced proliferation and self-renewal and reduced apoptosis, whereas B6 alleles had the opposite effects. Using oligonucleotide arrays, real-time PCR and protein blots, we identified latexin (Lxn), a gene whose differential transcription and expression was associated with the allelic differences. Expression was inversely correlated with the number of HSCs; therefore, ectopic expression of Lxn using a retroviral vector decreased stem cell population size. We identified clusters of SNPs upstream of the Lxn transcriptional start site, at least two of which are associated with potential binding sites for transcription factors regulating stem cells. Thus, promoter polymorphisms between the B6 and D2 alleles may affect Lxn gene expression and consequently influence the population size of hematopoietic stem cells.

Standard name | LIANG_HEMATOPOIESIS_STEM_CELL_NUMBER_LARGE_VS_TINY_DN
Systematic name | M870
Organism | Mus musculus
PMID | 17220891
Authors | Liang Y,Jansen M,Aronow B,Geiger H,Van Zant G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in LSK cells (bone marrow) as a function of a QTL for the size of hematopoietic stem cell (HSC) population: comparison of congenic B.D. chr3 (BD, large HSC size) vs parental B6 strain (tiny HSC size).
Full description | We mapped quantitative trait loci that accounted for the variation in hematopoietic stem cell (HSC) numbers between young adult C57BL/6 (B6) and DBA/2 (D2) mice. In reciprocal chromosome 3 congenic mice, introgressed D2 alleles increased HSC numbers owing to enhanced proliferation and self-renewal and reduced apoptosis, whereas B6 alleles had the opposite effects. Using oligonucleotide arrays, real-time PCR and protein blots, we identified latexin (Lxn), a gene whose differential transcription and expression was associated with the allelic differences. Expression was inversely correlated with the number of HSCs; therefore, ectopic expression of Lxn using a retroviral vector decreased stem cell population size. We identified clusters of SNPs upstream of the Lxn transcriptional start site, at least two of which are associated with potential binding sites for transcription factors regulating stem cells. Thus, promoter polymorphisms between the B6 and D2 alleles may affect Lxn gene expression and consequently influence the population size of hematopoietic stem cells.

Standard name | LIANG_HEMATOPOIESIS_STEM_CELL_NUMBER_SMALL_VS_HUGE_UP
Systematic name | M10245
Organism | Mus musculus
PMID | 17220891
Authors | Liang Y,Jansen M,Aronow B,Geiger H,Van Zant G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in LSK cells (bone marrow) as a function of a QTL for the size of hematopoietic stem cell (HSC) population: comparison of congenic D.B. Chr 3 (DB, small HSC population) vs parental D2 strain (huge HSC population).
Full description | We mapped quantitative trait loci that accounted for the variation in hematopoietic stem cell (HSC) numbers between young adult C57BL/6 (B6) and DBA/2 (D2) mice. In reciprocal chromosome 3 congenic mice, introgressed D2 alleles increased HSC numbers owing to enhanced proliferation and self-renewal and reduced apoptosis, whereas B6 alleles had the opposite effects. Using oligonucleotide arrays, real-time PCR and protein blots, we identified latexin (Lxn), a gene whose differential transcription and expression was associated with the allelic differences. Expression was inversely correlated with the number of HSCs; therefore, ectopic expression of Lxn using a retroviral vector decreased stem cell population size. We identified clusters of SNPs upstream of the Lxn transcriptional start site, at least two of which are associated with potential binding sites for transcription factors regulating stem cells. Thus, promoter polymorphisms between the B6 and D2 alleles may affect Lxn gene expression and consequently influence the population size of hematopoietic stem cells.

Standard name | LIANG_HEMATOPOIESIS_STEM_CELL_NUMBER_SMALL_VS_HUGE_DN
Systematic name | M19655
Organism | Mus musculus
PMID | 17220891
Authors | Liang Y,Jansen M,Aronow B,Geiger H,Van Zant G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in LSK cells (bone marrow) as a function of a QTL for the size of hematopoietic stem cell (HSC) population: comparison of congenic D.B. Chr 3 (DB, small HSC population) vs parental D2 strain (huge HSC population).
Full description | We mapped quantitative trait loci that accounted for the variation in hematopoietic stem cell (HSC) numbers between young adult C57BL/6 (B6) and DBA/2 (D2) mice. In reciprocal chromosome 3 congenic mice, introgressed D2 alleles increased HSC numbers owing to enhanced proliferation and self-renewal and reduced apoptosis, whereas B6 alleles had the opposite effects. Using oligonucleotide arrays, real-time PCR and protein blots, we identified latexin (Lxn), a gene whose differential transcription and expression was associated with the allelic differences. Expression was inversely correlated with the number of HSCs; therefore, ectopic expression of Lxn using a retroviral vector decreased stem cell population size. We identified clusters of SNPs upstream of the Lxn transcriptional start site, at least two of which are associated with potential binding sites for transcription factors regulating stem cells. Thus, promoter polymorphisms between the B6 and D2 alleles may affect Lxn gene expression and consequently influence the population size of hematopoietic stem cells.

Standard name | SPIELMAN_LYMPHOBLAST_EUROPEAN_VS_ASIAN_2FC_UP
Systematic name | M2267
Organism | Homo sapiens
PMID | 17206142
Authors | Spielman RS,Bastone LA,Burdick JT,Morley M,Ewens WJ,Cheung VG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated more than two-fold in lymphoblastoid cell lines from European population compared to those from Asian population.
Full description | Variation in DNA sequence contributes to individual differences in quantitative traits, but in humans the specific sequence variants are known for very few traits. We characterized variation in gene expression in cells from individuals belonging to three major population groups. This quantitative phenotype differs significantly between European-derived and Asian-derived populations for 1,097 of 4,197 genes tested. For the phenotypes with the strongest evidence of cis determinants, most of the variation is due to allele frequency differences at cis-linked regulators. The results show that specific genetic variation among populations contributes appreciably to differences in gene expression phenotypes. Populations differ in prevalence of many complex genetic diseases, such as diabetes and cardiovascular disease. As some of these are probably influenced by the level of gene expression, our results suggest that allele frequency differences at regulatory polymorphisms also account for some population differences in prevalence of complex diseases.

Standard name | SPIELMAN_LYMPHOBLAST_EUROPEAN_VS_ASIAN_2FC_DN
Systematic name | M5754
Organism | Homo sapiens
PMID | 17206142
Authors | Spielman RS,Bastone LA,Burdick JT,Morley M,Ewens WJ,Cheung VG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated more than two-fold in lymphoblastoid cell lines from European population compared to those from Asian population.
Full description | Variation in DNA sequence contributes to individual differences in quantitative traits, but in humans the specific sequence variants are known for very few traits. We characterized variation in gene expression in cells from individuals belonging to three major population groups. This quantitative phenotype differs significantly between European-derived and Asian-derived populations for 1,097 of 4,197 genes tested. For the phenotypes with the strongest evidence of cis determinants, most of the variation is due to allele frequency differences at cis-linked regulators. The results show that specific genetic variation among populations contributes appreciably to differences in gene expression phenotypes. Populations differ in prevalence of many complex genetic diseases, such as diabetes and cardiovascular disease. As some of these are probably influenced by the level of gene expression, our results suggest that allele frequency differences at regulatory polymorphisms also account for some population differences in prevalence of complex diseases.

Standard name | SPIELMAN_LYMPHOBLAST_EUROPEAN_VS_ASIAN_UP
Systematic name | M14665
Organism | Homo sapiens
PMID | 17206142
Authors | Spielman RS,Bastone LA,Burdick JT,Morley M,Ewens WJ,Cheung VG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in lymphoblastoid cells from the European population compared to those from the Asian population.
Full description | Variation in DNA sequence contributes to individual differences in quantitative traits, but in humans the specific sequence variants are known for very few traits. We characterized variation in gene expression in cells from individuals belonging to three major population groups. This quantitative phenotype differs significantly between European-derived and Asian-derived populations for 1,097 of 4,197 genes tested. For the phenotypes with the strongest evidence of cis determinants, most of the variation is due to allele frequency differences at cis-linked regulators. The results show that specific genetic variation among populations contributes appreciably to differences in gene expression phenotypes. Populations differ in prevalence of many complex genetic diseases, such as diabetes and cardiovascular disease. As some of these are probably influenced by the level of gene expression, our results suggest that allele frequency differences at regulatory polymorphisms also account for some population differences in prevalence of complex diseases.

Standard name | SPIELMAN_LYMPHOBLAST_EUROPEAN_VS_ASIAN_DN
Systematic name | M16066
Organism | Homo sapiens
PMID | 17206142
Authors | Spielman RS,Bastone LA,Burdick JT,Morley M,Ewens WJ,Cheung VG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in lymphoblastoid cells from the European population compared to those from the Asian population.
Full description | Variation in DNA sequence contributes to individual differences in quantitative traits, but in humans the specific sequence variants are known for very few traits. We characterized variation in gene expression in cells from individuals belonging to three major population groups. This quantitative phenotype differs significantly between European-derived and Asian-derived populations for 1,097 of 4,197 genes tested. For the phenotypes with the strongest evidence of cis determinants, most of the variation is due to allele frequency differences at cis-linked regulators. The results show that specific genetic variation among populations contributes appreciably to differences in gene expression phenotypes. Populations differ in prevalence of many complex genetic diseases, such as diabetes and cardiovascular disease. As some of these are probably influenced by the level of gene expression, our results suggest that allele frequency differences at regulatory polymorphisms also account for some population differences in prevalence of complex diseases.

Standard name | HUI_MAPK14_TARGETS_UP
Systematic name | M1289
Organism | Mus musculus
PMID | 17468757
Authors | Hui L,Bakiri L,Mairhorfer A,Schweifer N,Haslinger C,Kenner L,Komnenovic V,Scheuch H,Beug H,Wagner EF
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in fetal liver (days E13.5 and E15.5) samples from embryo-specific Cre-lox knockout of MAPK14 [GeneID=1432].
Full description | The mitogen-activated protein kinase (MAPK) p38alpha controls inflammatory responses and cell proliferation. Using mice carrying conditional Mapk14 (also known as p38alpha) alleles, we investigated its function in postnatal development and tumorigenesis. When we specifically deleted Mapk14 in the mouse embryo, fetuses developed to term but died shortly after birth, probably owing to lung dysfunction. Fetal hematopoietic cells and embryonic fibroblasts deficient in p38alpha showed increased proliferation resulting from sustained activation of the c-Jun N-terminal kinase (JNK)-c-Jun pathway. Notably, in chemical-induced liver cancer development, mice with liver-specific deletion of Mapk14 showed enhanced hepatocyte proliferation and tumor development that correlated with upregulation of the JNK-c-Jun pathway. Furthermore, inactivation of JNK or c-Jun suppressed the increased proliferation of Mapk14-deficient hepatocytes and tumor cells. These results demonstrate a new mechanism whereby p38alpha negatively regulates cell proliferation by antagonizing the JNK-c-Jun pathway in multiple cell types and in liver cancer development.

Standard name | DIERICK_SEROTONIN_FUNCTION_GENES
Systematic name | M1290
Organism | Homo sapiens
PMID | 17450142
Authors | Dierick HA,Greenspan RJ
Category | C2
Sub-category | CGP
Brief description | Genes involved in serotonin [PubChem=5202] function, orthologs computed from D. melanogaster genes using InsParanoid resource.
Full description | Both serotonin (5-HT) and neuropeptide Y have been shown to affect a variety of mammalian behaviors, including aggression. Here we show in Drosophila melanogaster that both 5-HT and neuropeptide F, the invertebrate homolog of neuropeptide Y, modulate aggression. We show that drug-induced increases of 5-HT in the fly brain increase aggression. Elevating 5-HT genetically in the serotonergic circuits recapitulates these pharmacological effects, whereas genetic silencing of these circuits makes the flies behaviorally unresponsive to the drug-induced increase of 5-HT but leaves them capable of aggression. Genetic silencing of the neuropeptide F (npf) circuit also increases fly aggression, demonstrating an opposite modulation to 5-HT. Moreover, this neuropeptide F effect seems to be independent of 5-HT. The implication of these two modulatory systems in fly and mouse aggression suggest a marked degree of conservation and a deep molecular root for this behavior.

Standard name | THEODOROU_MAMMARY_TUMORIGENESIS
Systematic name | M1291
Organism | Mus musculus
PMID | 17468756
Authors | Theodorou V,Kimm MA,Boer M,Wessels L,Theelen W,Jonkers J,Hilkens J
Category | C2
Sub-category | CGP
Brief description | Candidate mammary tumorigenesis genes from the common insertion sites (CIS) of MMTV virus that induced breast tumors in mice.
Full description | We performed a high-throughput retroviral insertional mutagenesis screen in mouse mammary tumor virus (MMTV)-induced mammary tumors and identified 33 common insertion sites, of which 17 genes were previously not known to be associated with mammary cancer and 13 had not previously been linked to cancer in general. Although members of the Wnt and fibroblast growth factors (Fgf) families were frequently tagged, our exhaustive screening for MMTV insertion sites uncovered a new repertoire of candidate breast cancer oncogenes. We validated one of these genes, Rspo3, as an oncogene by overexpression in a p53-deficient mammary epithelial cell line. The human orthologs of the candidate oncogenes were frequently deregulated in human breast cancers and associated with several tumor parameters. Computational analysis of all MMTV-tagged genes uncovered specific gene families not previously associated with cancer and showed a significant overrepresentation of protein domains and signaling pathways mainly associated with development and growth factor signaling. Comparison of all tagged genes in MMTV and Moloney murine leukemia virus-induced malignancies showed that both viruses target mostly different genes that act predominantly in distinct pathways.

Standard name | BALLIF_DEVELOPMENTAL_DISABILITY_P16_P12_DELETION
Systematic name | M14238
Organism | Homo sapiens
PMID | 17704777
Authors | Ballif BC,Hornor SA,Jenkins E,Madan-Khetarpal S,Surti U,Jackson KE,Asamoah A,Brock PL,Gowans GC,Conway RL,Graham JM Jr,Medne L,Zackai EH,Shaikh TH,Geoghegan J,Selzer RR,Eis PS,Bejjani BA,Shaffer LG
Category | C2
Sub-category | CGP
Brief description | Candidate genes in the pericentromeric microdeletion in 16p11.2-p12.2 associated with developmental disabilities.
Full description | We have identified a recurrent de novo pericentromeric deletion in 16p11.2-p12.2 in four individuals with developmental disabilities by microarray-based comparative genomic hybridization analysis. The identification of common clinical features in these four individuals along with the characterization of complex segmental duplications flanking the deletion regions suggests that nonallelic homologous recombination mediated these rearrangements and that deletions in 16p11.2-p12.2 constitute a previously undescribed syndrome.

Standard name | SCHLESINGER_METHYLATED_IN_COLON_CANCER
Systematic name | M821
Organism | Homo sapiens
PMID | 17200670
Authors | Schlesinger Y,Straussman R,Keshet I,Farkash S,Hecht M,Zimmerman J,Eden E,Yakhini Z,Ben-Shushan E,Reubinoff BE,Bergman Y,Simon I,Cedar H
Category | C2
Sub-category | CGP
Brief description | Genes expressed in normal colon; they undergo down-regulation in tumors through DNA methylation.
Full description | Many genes associated with CpG islands undergo de novo methylation in cancer. Studies have suggested that the pattern of this modification may be partially determined by an instructive mechanism that recognizes specifically marked regions of the genome. Using chromatin immunoprecipitation analysis, here we show that genes methylated in cancer cells are specifically packaged with nucleosomes containing histone H3 trimethylated on Lys27. This chromatin mark is established on these unmethylated CpG island genes early in development and then maintained in differentiated cell types by the presence of an EZH2-containing Polycomb complex. In cancer cells, as opposed to normal cells, the presence of this complex brings about the recruitment of DNA methyl transferases, leading to de novo methylation. These results suggest that tumor-specific targeting of de novo methylation is pre-programmed by an established epigenetic system that normally has a role in marking embryonic genes for repression.

Standard name | JIANG_CORE_DUPLICON_GENES
Systematic name | M9416
Organism | Homo sapiens
PMID | 17922013
Authors | Jiang Z,Tang H,Ventura M,Cardone MF,Marques-Bonet T,She X,Pevzner PA,Eichler EE
Category | C2
Sub-category | CGP
Brief description | Genes mapped to core duplicons - elements shared by a majority of segmental duplication blocks.
Full description | Human segmental duplications are hotspots for nonallelic homologous recombination leading to genomic disorders, copy-number polymorphisms and gene and transcript innovations. The complex structure and history of these regions have precluded a global evolutionary analysis. Combining a modified A-Bruijn graph algorithm with comparative genome sequence data, we identify the origin of 4,692 ancestral duplication loci and use these to cluster 437 complex duplication blocks into 24 distinct groups. The sequence-divergence data between ancestral-derivative pairs and a comparison with the chimpanzee and macaque genome support a 'punctuated' model of evolution. Our analysis reveals that human segmental duplications are frequently organized around 'core' duplicons, which are enriched for transcripts and, in some cases, encode primate-specific genes undergoing positive selection. We hypothesize that the rapid expansion and fixation of some intrachromosomal segmental duplications during great-ape evolution has been due to the selective advantage conferred by these genes and transcripts embedded within these core duplications.

Standard name | PUJANA_BREAST_CANCER_LIT_INT_NETWORK
Systematic name | M15356
Organism | Homo sapiens
PMID | 17922014
Authors | Pujana MA,Han JD,Starita LM,Stevens KN,Tewari M,Ahn JS,Rennert G,Moreno V,Kirchhoff T,Gold B,Assmann V,Elshamy WM,Rual JF,Levine D,Rozek LS,Gelman RS,Gunsalus KC,Greenberg RA,Sobhian B,Bertin N,Venkatesan K,Ayivi-Guedehoussou N,Solé X,Hernández P,Lázaro C,Nathanson KL,Weber BL,Cusick ME,Hill DE,Offit K,Livingston DM,Gruber SB,Parvin JD,Vidal M
Category | C2
Sub-category | CGP
Brief description | Genes constituting the LIT-Int network of proteins interacting with breast cancer reference proteins BRCA1, BRCA2, ATM, and CHEK2 [GeneID=672;675;472;11200]; the interactions were manually curated from the literature.
Full description | Many cancer-associated genes remain to be identified to clarify the underlying molecular mechanisms of cancer susceptibility and progression. Better understanding is also required of how mutations in cancer genes affect their products in the context of complex cellular networks. Here we have used a network modeling strategy to identify genes potentially associated with higher risk of breast cancer. Starting with four known genes encoding tumor suppressors of breast cancer, we combined gene expression profiling with functional genomic and proteomic (or 'omic') data from various species to generate a network containing 118 genes linked by 866 potential functional associations. This network shows higher connectivity than expected by chance, suggesting that its components function in biologically related pathways. One of the components of the network is HMMR, encoding a centrosome subunit, for which we demonstrate previously unknown functional associations with the breast cancer-associated gene BRCA1. Two case-control studies of incident breast cancer indicate that the HMMR locus is associated with higher risk of breast cancer in humans. Our network modeling strategy should be useful for the discovery of additional cancer-associated genes.

Standard name | PUJANA_XPRSS_INT_NETWORK
Systematic name | M18811
Organism | Homo sapiens
PMID | 17922014
Authors | Pujana MA,Han JD,Starita LM,Stevens KN,Tewari M,Ahn JS,Rennert G,Moreno V,Kirchhoff T,Gold B,Assmann V,Elshamy WM,Rual JF,Levine D,Rozek LS,Gelman RS,Gunsalus KC,Greenberg RA,Sobhian B,Bertin N,Venkatesan K,Ayivi-Guedehoussou N,Solé X,Hernández P,Lázaro C,Nathanson KL,Weber BL,Cusick ME,Hill DE,Offit K,Livingston DM,Gruber SB,Parvin JD,Vidal M
Category | C2
Sub-category | CGP
Brief description | Genes constituting the XPRSS-Int network: intersection of genes whose expression correlates with BRCA1, BRCA2, ATM, and CHEK2 [GeneID=672;675;472;11200] in a compendium of normal tissues.
Full description | Many cancer-associated genes remain to be identified to clarify the underlying molecular mechanisms of cancer susceptibility and progression. Better understanding is also required of how mutations in cancer genes affect their products in the context of complex cellular networks. Here we have used a network modeling strategy to identify genes potentially associated with higher risk of breast cancer. Starting with four known genes encoding tumor suppressors of breast cancer, we combined gene expression profiling with functional genomic and proteomic (or 'omic') data from various species to generate a network containing 118 genes linked by 866 potential functional associations. This network shows higher connectivity than expected by chance, suggesting that its components function in biologically related pathways. One of the components of the network is HMMR, encoding a centrosome subunit, for which we demonstrate previously unknown functional associations with the breast cancer-associated gene BRCA1. Two case-control studies of incident breast cancer indicate that the HMMR locus is associated with higher risk of breast cancer in humans. Our network modeling strategy should be useful for the discovery of additional cancer-associated genes.

Standard name | PUJANA_BRCA1_PCC_NETWORK
Systematic name | M5611
Organism | Homo sapiens
PMID | 17922014
Authors | Pujana MA,Han JD,Starita LM,Stevens KN,Tewari M,Ahn JS,Rennert G,Moreno V,Kirchhoff T,Gold B,Assmann V,Elshamy WM,Rual JF,Levine D,Rozek LS,Gelman RS,Gunsalus KC,Greenberg RA,Sobhian B,Bertin N,Venkatesan K,Ayivi-Guedehoussou N,Solé X,Hernández P,Lázaro C,Nathanson KL,Weber BL,Cusick ME,Hill DE,Offit K,Livingston DM,Gruber SB,Parvin JD,Vidal M
Category | C2
Sub-category | CGP
Brief description | Genes constituting the BRCA1-PCC network of transcripts whose expression positively correlated (Pearson correlation coefficient, PCC >= 0.4) with that of BRCA1 [GeneID=672] across a compendium of normal tissues.
Full description | Many cancer-associated genes remain to be identified to clarify the underlying molecular mechanisms of cancer susceptibility and progression. Better understanding is also required of how mutations in cancer genes affect their products in the context of complex cellular networks. Here we have used a network modeling strategy to identify genes potentially associated with higher risk of breast cancer. Starting with four known genes encoding tumor suppressors of breast cancer, we combined gene expression profiling with functional genomic and proteomic (or 'omic') data from various species to generate a network containing 118 genes linked by 866 potential functional associations. This network shows higher connectivity than expected by chance, suggesting that its components function in biologically related pathways. One of the components of the network is HMMR, encoding a centrosome subunit, for which we demonstrate previously unknown functional associations with the breast cancer-associated gene BRCA1. Two case-control studies of incident breast cancer indicate that the HMMR locus is associated with higher risk of breast cancer in humans. Our network modeling strategy should be useful for the discovery of additional cancer-associated genes.

Standard name | PUJANA_BRCA2_PCC_NETWORK
Systematic name | M9516
Organism | Homo sapiens
PMID | 17922014
Authors | Pujana MA,Han JD,Starita LM,Stevens KN,Tewari M,Ahn JS,Rennert G,Moreno V,Kirchhoff T,Gold B,Assmann V,Elshamy WM,Rual JF,Levine D,Rozek LS,Gelman RS,Gunsalus KC,Greenberg RA,Sobhian B,Bertin N,Venkatesan K,Ayivi-Guedehoussou N,Solé X,Hernández P,Lázaro C,Nathanson KL,Weber BL,Cusick ME,Hill DE,Offit K,Livingston DM,Gruber SB,Parvin JD,Vidal M
Category | C2
Sub-category | CGP
Brief description | Genes constituting the BRCA2-PCC network of transcripts whose expression positively correlated (Pearson correlation coefficient, PCC >= 0.4) with that of BRCA2 [GeneID=675] across a compendium of normal tissues.
Full description | Many cancer-associated genes remain to be identified to clarify the underlying molecular mechanisms of cancer susceptibility and progression. Better understanding is also required of how mutations in cancer genes affect their products in the context of complex cellular networks. Here we have used a network modeling strategy to identify genes potentially associated with higher risk of breast cancer. Starting with four known genes encoding tumor suppressors of breast cancer, we combined gene expression profiling with functional genomic and proteomic (or 'omic') data from various species to generate a network containing 118 genes linked by 866 potential functional associations. This network shows higher connectivity than expected by chance, suggesting that its components function in biologically related pathways. One of the components of the network is HMMR, encoding a centrosome subunit, for which we demonstrate previously unknown functional associations with the breast cancer-associated gene BRCA1. Two case-control studies of incident breast cancer indicate that the HMMR locus is associated with higher risk of breast cancer in humans. Our network modeling strategy should be useful for the discovery of additional cancer-associated genes.

Standard name | PUJANA_ATM_PCC_NETWORK
Systematic name | M9585
Organism | Homo sapiens
PMID | 17922014
Authors | Pujana MA,Han JD,Starita LM,Stevens KN,Tewari M,Ahn JS,Rennert G,Moreno V,Kirchhoff T,Gold B,Assmann V,Elshamy WM,Rual JF,Levine D,Rozek LS,Gelman RS,Gunsalus KC,Greenberg RA,Sobhian B,Bertin N,Venkatesan K,Ayivi-Guedehoussou N,Solé X,Hernández P,Lázaro C,Nathanson KL,Weber BL,Cusick ME,Hill DE,Offit K,Livingston DM,Gruber SB,Parvin JD,Vidal M
Category | C2
Sub-category | CGP
Brief description | Genes constituting the ATM-PCC network of transcripts whose expression positively correlated (Pearson correlation coefficient, PCC >= 0.4) with that of ATM [GeneID=472] across a compendium of normal tissues.
Full description | Many cancer-associated genes remain to be identified to clarify the underlying molecular mechanisms of cancer susceptibility and progression. Better understanding is also required of how mutations in cancer genes affect their products in the context of complex cellular networks. Here we have used a network modeling strategy to identify genes potentially associated with higher risk of breast cancer. Starting with four known genes encoding tumor suppressors of breast cancer, we combined gene expression profiling with functional genomic and proteomic (or 'omic') data from various species to generate a network containing 118 genes linked by 866 potential functional associations. This network shows higher connectivity than expected by chance, suggesting that its components function in biologically related pathways. One of the components of the network is HMMR, encoding a centrosome subunit, for which we demonstrate previously unknown functional associations with the breast cancer-associated gene BRCA1. Two case-control studies of incident breast cancer indicate that the HMMR locus is associated with higher risk of breast cancer in humans. Our network modeling strategy should be useful for the discovery of additional cancer-associated genes.

Standard name | PUJANA_CHEK2_PCC_NETWORK
Systematic name | M11961
Organism | Homo sapiens
PMID | 17922014
Authors | Pujana MA,Han JD,Starita LM,Stevens KN,Tewari M,Ahn JS,Rennert G,Moreno V,Kirchhoff T,Gold B,Assmann V,Elshamy WM,Rual JF,Levine D,Rozek LS,Gelman RS,Gunsalus KC,Greenberg RA,Sobhian B,Bertin N,Venkatesan K,Ayivi-Guedehoussou N,Solé X,Hernández P,Lázaro C,Nathanson KL,Weber BL,Cusick ME,Hill DE,Offit K,Livingston DM,Gruber SB,Parvin JD,Vidal M
Category | C2
Sub-category | CGP
Brief description | Genes constituting the CHEK2-PCC network of transcripts whose expression positively correlates (Pearson correlation coefficient, PCC >= 0.4) with that of CHEK2 [GeneID=11200].
Full description | Many cancer-associated genes remain to be identified to clarify the underlying molecular mechanisms of cancer susceptibility and progression. Better understanding is also required of how mutations in cancer genes affect their products in the context of complex cellular networks. Here we have used a network modeling strategy to identify genes potentially associated with higher risk of breast cancer. Starting with four known genes encoding tumor suppressors of breast cancer, we combined gene expression profiling with functional genomic and proteomic (or 'omic') data from various species to generate a network containing 118 genes linked by 866 potential functional associations. This network shows higher connectivity than expected by chance, suggesting that its components function in biologically related pathways. One of the components of the network is HMMR, encoding a centrosome subunit, for which we demonstrate previously unknown functional associations with the breast cancer-associated gene BRCA1. Two case-control studies of incident breast cancer indicate that the HMMR locus is associated with higher risk of breast cancer in humans. Our network modeling strategy should be useful for the discovery of additional cancer-associated genes.

Standard name | PUJANA_BRCA_CENTERED_NETWORK
Systematic name | M15305
Organism | Homo sapiens
PMID | 17922014
Authors | Pujana MA,Han JD,Starita LM,Stevens KN,Tewari M,Ahn JS,Rennert G,Moreno V,Kirchhoff T,Gold B,Assmann V,Elshamy WM,Rual JF,Levine D,Rozek LS,Gelman RS,Gunsalus KC,Greenberg RA,Sobhian B,Bertin N,Venkatesan K,Ayivi-Guedehoussou N,Solé X,Hernández P,Lázaro C,Nathanson KL,Weber BL,Cusick ME,Hill DE,Offit K,Livingston DM,Gruber SB,Parvin JD,Vidal M
Category | C2
Sub-category | CGP
Brief description | Genes constituting the BRCA-centered network (BCN).
Full description | Many cancer-associated genes remain to be identified to clarify the underlying molecular mechanisms of cancer susceptibility and progression. Better understanding is also required of how mutations in cancer genes affect their products in the context of complex cellular networks. Here we have used a network modeling strategy to identify genes potentially associated with higher risk of breast cancer. Starting with four known genes encoding tumor suppressors of breast cancer, we combined gene expression profiling with functional genomic and proteomic (or 'omic') data from various species to generate a network containing 118 genes linked by 866 potential functional associations. This network shows higher connectivity than expected by chance, suggesting that its components function in biologically related pathways. One of the components of the network is HMMR, encoding a centrosome subunit, for which we demonstrate previously unknown functional associations with the breast cancer-associated gene BRCA1. Two case-control studies of incident breast cancer indicate that the HMMR locus is associated with higher risk of breast cancer in humans. Our network modeling strategy should be useful for the discovery of additional cancer-associated genes.

Standard name | SCHLESINGER_H3K27ME3_IN_NORMAL_AND_METHYLATED_IN_CANCER
Systematic name | M16297
Organism | Homo sapiens
PMID | 17200670
Authors | Schlesinger Y,Straussman R,Keshet I,Farkash S,Hecht M,Zimmerman J,Eden E,Yakhini Z,Ben-Shushan E,Reubinoff BE,Bergman Y,Simon I,Cedar H
Category | C2
Sub-category | CGP
Brief description | Genes bearing the H3K27me3 mark in normal cells; their DNA is methylated in cancer cells.
Full description | Many genes associated with CpG islands undergo de novo methylation in cancer. Studies have suggested that the pattern of this modification may be partially determined by an instructive mechanism that recognizes specifically marked regions of the genome. Using chromatin immunoprecipitation analysis, here we show that genes methylated in cancer cells are specifically packaged with nucleosomes containing histone H3 trimethylated on Lys27. This chromatin mark is established on these unmethylated CpG island genes early in development and then maintained in differentiated cell types by the presence of an EZH2-containing Polycomb complex. In cancer cells, as opposed to normal cells, the presence of this complex brings about the recruitment of DNA methyl transferases, leading to de novo methylation. These results suggest that tumor-specific targeting of de novo methylation is pre-programmed by an established epigenetic system that normally has a role in marking embryonic genes for repression.

Standard name | SCHLESINGER_METHYLATED_DE_NOVO_IN_CANCER
Systematic name | M11288
Organism | Homo sapiens
PMID | 17200670
Authors | Schlesinger Y,Straussman R,Keshet I,Farkash S,Hecht M,Zimmerman J,Eden E,Yakhini Z,Ben-Shushan E,Reubinoff BE,Bergman Y,Simon I,Cedar H
Category | C2
Sub-category | CGP
Brief description | Genes bearing H3K27me3 mark or whose promoters are bound by the polycomb proteins SUZ12 or EED [GeneID=23512;8726]; their DNA is methylated de novo in cancer.
Full description | Many genes associated with CpG islands undergo de novo methylation in cancer. Studies have suggested that the pattern of this modification may be partially determined by an instructive mechanism that recognizes specifically marked regions of the genome. Using chromatin immunoprecipitation analysis, here we show that genes methylated in cancer cells are specifically packaged with nucleosomes containing histone H3 trimethylated on Lys27. This chromatin mark is established on these unmethylated CpG island genes early in development and then maintained in differentiated cell types by the presence of an EZH2-containing Polycomb complex. In cancer cells, as opposed to normal cells, the presence of this complex brings about the recruitment of DNA methyl transferases, leading to de novo methylation. These results suggest that tumor-specific targeting of de novo methylation is pre-programmed by an established epigenetic system that normally has a role in marking embryonic genes for repression.

Standard name | GOERING_BLOOD_HDL_CHOLESTEROL_QTL_CIS
Systematic name | M16720
Organism | Homo sapiens
PMID | 17873875
Authors | Göring HH,Curran JE,Johnson MP,Dyer TD,Charlesworth J,Cole SA,Jowett JB,Abraham LJ,Rainwater DL,Comuzzie AG,Mahaney MC,Almasy L,MacCluer JW,Kissebah AH,Collier GR,Moses EK,Blangero J
Category | C2
Sub-category | CGP
Brief description | Top scoring cis-regulated QTL (quantitative trait loci) influencing blood levels of high-density lipoprotein (HDL) cholesterol.
Full description | Quantitative differences in gene expression are thought to contribute to phenotypic differences between individuals. We generated genome-wide transcriptional profiles of lymphocyte samples from 1,240 participants in the San Antonio Family Heart Study. The expression levels of 85% of the 19,648 detected autosomal transcripts were significantly heritable. Linkage analysis uncovered >1,000 cis-regulated transcripts at a false discovery rate of 5% and showed that the expression quantitative trait loci with the most significant linkage evidence are often located at the structural locus of a given transcript. To highlight the usefulness of this much-enlarged map of cis-regulated transcripts for the discovery of genes that influence complex traits in humans, as an example we selected high-density lipoprotein cholesterol concentration as a phenotype of clinical importance, and identified the cis-regulated vanin 1 (VNN1) gene as harboring sequence variants that influence high-density lipoprotein cholesterol concentrations.

Standard name | GOERING_BLOOD_HDL_CHOLESTEROL_QTL_TRANS
Systematic name | M18000
Organism | Homo sapiens
PMID | 17873875
Authors | Göring HH,Curran JE,Johnson MP,Dyer TD,Charlesworth J,Cole SA,Jowett JB,Abraham LJ,Rainwater DL,Comuzzie AG,Mahaney MC,Almasy L,MacCluer JW,Kissebah AH,Collier GR,Moses EK,Blangero J
Category | C2
Sub-category | CGP
Brief description | Top scoring trans-regulated expression quantitative trait loci (eQTL) influencing blood levels of high-density lipoprotein (HDL) cholesterol.
Full description | Quantitative differences in gene expression are thought to contribute to phenotypic differences between individuals. We generated genome-wide transcriptional profiles of lymphocyte samples from 1,240 participants in the San Antonio Family Heart Study. The expression levels of 85% of the 19,648 detected autosomal transcripts were significantly heritable. Linkage analysis uncovered >1,000 cis-regulated transcripts at a false discovery rate of 5% and showed that the expression quantitative trait loci with the most significant linkage evidence are often located at the structural locus of a given transcript. To highlight the usefulness of this much-enlarged map of cis-regulated transcripts for the discovery of genes that influence complex traits in humans, as an example we selected high-density lipoprotein cholesterol concentration as a phenotype of clinical importance, and identified the cis-regulated vanin 1 (VNN1) gene as harboring sequence variants that influence high-density lipoprotein cholesterol concentrations.

Standard name | KHETCHOUMIAN_TRIM24_TARGETS_UP
Systematic name | M1399
Organism | Mus musculus
PMID | 18026104
Authors | Khetchoumian K,Teletin M,Tisserand J,Mark M,Herquel B,Ignat M,Zucman-Rossi J,Cammas F,Lerouge T,Thibault C,Metzger D,Chambon P,Losson R
Category | C2
Sub-category | CGP
Brief description | Retinoic acid-responsive genes up-regulated in hepatocellular carcinoma (HCC) samples of TRIM24 [GeneID=8805] knockout mice.
Full description | Hepatocellular carcinoma (HCC) is a major cause of death worldwide. Here, we provide evidence that the ligand-dependent nuclear receptor co-regulator Trim24 (also known as Tif1alpha) functions in mice as a liver-specific tumor suppressor. In Trim24-null mice, hepatocytes fail to execute proper cell cycle withdrawal during the neonatal-to-adult transition and continue to cycle in adult livers, becoming prone to a continuum of cellular alterations that progress toward metastatic HCC. Using pharmacological approaches, we show that inhibition of retinoic acid signaling markedly reduces hepatocyte proliferation in Trim24-/- mice. We further show that deletion of a single retinoic acid receptor alpha (Rara) allele in a Trim24-null background suppresses HCC development and restores wild-type expression of retinoic acid-responsive genes in the liver, thus demonstrating that in this genetic background Rara expresses an oncogenic activity correlating with a dysregulation of the retinoic acid signaling pathway. Our results not only provide genetic evidence that Trim24 and Rara co-regulate hepatocarcinogenesis in an antagonistic manner but also suggest that aberrant activation of Rara is deleterious to liver homeostasis.

Standard name | KHETCHOUMIAN_TRIM24_TARGETS_DN
Systematic name | M5125
Organism | Mus musculus
PMID | 18026104
Authors | Khetchoumian K,Teletin M,Tisserand J,Mark M,Herquel B,Ignat M,Zucman-Rossi J,Cammas F,Lerouge T,Thibault C,Metzger D,Chambon P,Losson R
Category | C2
Sub-category | CGP
Brief description | Retinoic acid-responsive genes down-regulated in hepatocellular carcinoma (HCC) samples of TRIM24 [GeneID=8805] knockout mice.
Full description | Hepatocellular carcinoma (HCC) is a major cause of death worldwide. Here, we provide evidence that the ligand-dependent nuclear receptor co-regulator Trim24 (also known as Tif1alpha) functions in mice as a liver-specific tumor suppressor. In Trim24-null mice, hepatocytes fail to execute proper cell cycle withdrawal during the neonatal-to-adult transition and continue to cycle in adult livers, becoming prone to a continuum of cellular alterations that progress toward metastatic HCC. Using pharmacological approaches, we show that inhibition of retinoic acid signaling markedly reduces hepatocyte proliferation in Trim24-/- mice. We further show that deletion of a single retinoic acid receptor alpha (Rara) allele in a Trim24-null background suppresses HCC development and restores wild-type expression of retinoic acid-responsive genes in the liver, thus demonstrating that in this genetic background Rara expresses an oncogenic activity correlating with a dysregulation of the retinoic acid signaling pathway. Our results not only provide genetic evidence that Trim24 and Rara co-regulate hepatocarcinogenesis in an antagonistic manner but also suggest that aberrant activation of Rara is deleterious to liver homeostasis.

Standard name | OHM_METHYLATED_IN_ADULT_CANCERS
Systematic name | M1233
Organism | Homo sapiens
PMID | 17211412
Authors | Ohm JE,McGarvey KM,Yu X,Cheng L,Schuebel KE,Cope L,Mohammad HP,Chen W,Daniel VC,Yu W,Berman DM,Jenuwein T,Pruitt K,Sharkis SJ,Watkins DN,Herman JG,Baylin SB
Category | C2
Sub-category | CGP
Brief description | Genes showing frequent DNA methylation and which are silenced in adult cancers but remain unmethylated in embryonic carcinoma and embryonic stem (ES) cells.
Full description | Adult cancers may derive from stem or early progenitor cells. Epigenetic modulation of gene expression is essential for normal function of these early cells but is highly abnormal in cancers, which often show aberrant promoter CpG island hypermethylation and transcriptional silencing of tumor suppressor genes and pro-differentiation factors. We find that for such genes, both normal and malignant embryonic cells generally lack the hypermethylation of DNA found in adult cancers. In embryonic stem cells, these genes are held in a 'transcription-ready' state mediated by a 'bivalent' promoter chromatin pattern consisting of the repressive mark, histone H3 methylated at Lys27 (H3K27) by Polycomb group proteins, plus the active mark, methylated H3K4. However, embryonic carcinoma cells add two key repressive marks, dimethylated H3K9 and trimethylated H3K9, both associated with DNA hypermethylation in adult cancers. We hypothesize that cell chromatin patterns and transient silencing of these important regulatory genes in stem or progenitor cells may leave these genes vulnerable to aberrant DNA hypermethylation and heritable gene silencing during tumor initiation and progression.

Standard name | OHM_EMBRYONIC_CARCINOMA_UP
Systematic name | M6244
Organism | Homo sapiens
PMID | 17211412
Authors | Ohm JE,McGarvey KM,Yu X,Cheng L,Schuebel KE,Cope L,Mohammad HP,Chen W,Daniel VC,Yu W,Berman DM,Jenuwein T,Pruitt K,Sharkis SJ,Watkins DN,Herman JG,Baylin SB
Category | C2
Sub-category | CGP
Brief description | Genes with a high basal transcription state in undifferentiated embryonic carcinoma cells.
Full description | Adult cancers may derive from stem or early progenitor cells. Epigenetic modulation of gene expression is essential for normal function of these early cells but is highly abnormal in cancers, which often show aberrant promoter CpG island hypermethylation and transcriptional silencing of tumor suppressor genes and pro-differentiation factors. We find that for such genes, both normal and malignant embryonic cells generally lack the hypermethylation of DNA found in adult cancers. In embryonic stem cells, these genes are held in a 'transcription-ready' state mediated by a 'bivalent' promoter chromatin pattern consisting of the repressive mark, histone H3 methylated at Lys27 (H3K27) by Polycomb group proteins, plus the active mark, methylated H3K4. However, embryonic carcinoma cells add two key repressive marks, dimethylated H3K9 and trimethylated H3K9, both associated with DNA hypermethylation in adult cancers. We hypothesize that cell chromatin patterns and transient silencing of these important regulatory genes in stem or progenitor cells may leave these genes vulnerable to aberrant DNA hypermethylation and heritable gene silencing during tumor initiation and progression.

Standard name | OHM_EMBRYONIC_CARCINOMA_DN
Systematic name | M13398
Organism | Homo sapiens
PMID | 17211412
Authors | Ohm JE,McGarvey KM,Yu X,Cheng L,Schuebel KE,Cope L,Mohammad HP,Chen W,Daniel VC,Yu W,Berman DM,Jenuwein T,Pruitt K,Sharkis SJ,Watkins DN,Herman JG,Baylin SB
Category | C2
Sub-category | CGP
Brief description | Genes with low to medium basal transcription state in undifferentiated embryonic carcinoma cells.
Full description | Adult cancers may derive from stem or early progenitor cells. Epigenetic modulation of gene expression is essential for normal function of these early cells but is highly abnormal in cancers, which often show aberrant promoter CpG island hypermethylation and transcriptional silencing of tumor suppressor genes and pro-differentiation factors. We find that for such genes, both normal and malignant embryonic cells generally lack the hypermethylation of DNA found in adult cancers. In embryonic stem cells, these genes are held in a 'transcription-ready' state mediated by a 'bivalent' promoter chromatin pattern consisting of the repressive mark, histone H3 methylated at Lys27 (H3K27) by Polycomb group proteins, plus the active mark, methylated H3K4. However, embryonic carcinoma cells add two key repressive marks, dimethylated H3K9 and trimethylated H3K9, both associated with DNA hypermethylation in adult cancers. We hypothesize that cell chromatin patterns and transient silencing of these important regulatory genes in stem or progenitor cells may leave these genes vulnerable to aberrant DNA hypermethylation and heritable gene silencing during tumor initiation and progression.

Standard name | ALCALA_APOPTOSIS
Systematic name | M16169
Organism | Homo sapiens
PMID | 17621274
Authors | Alcalá S,Klee M,Fernández J,Fleischer A,Pimentel-Muiños FX
Category | C2
Sub-category | CGP
Brief description | Genes able to induce cell death in an expression cDNA library screen.
Full description | Functional annotation of complex genomes requires the development of novel experimental platforms with increased capacity. Here, we describe a high-throughput system designed to identify cDNAs whose overexpression induces morphologically distinct cell death modalities. The methodology incorporates two robotized steps, and relies on coexpression of library clones with GFP to reveal the morphological features presented by the dying cells. By using this system we screened 135 000 cDNA clones and obtained 90 independent molecules. Interestingly, three death categories were identified, namely; apoptotic, vacuolated and autophagic. Among the pro-apoptotic clones, we found four members of the mitochondrial carrier family: the phosphate and adenine nucleotide (type 3) transporters, and the mitochondrial carrier homologs (MTCHs) 1 and 2. Expression of these molecules induced cytochrome c release and caspase-9-dependent death. One of them, the phosphate carrier, was able to interact with members of the permeability transition pore complex ANT1 and VDAC1, and its binding to ANT1 was stabilized in the presence of apoptotic activators. Depletion of this carrier by siRNA delayed cytochrome c mobilization and apoptosis. These results attribute a previously undescribed apoptotic function to the phosphate carrier and, more generally, suggest that a common property of various mitochondrial transporters was exploited during evolution to regulate apoptosis.

Standard name | OKAWA_NEUROBLASTOMA_1P36_31_DELETION
Systematic name | M4786
Organism | Homo sapiens
PMID | 17667943
Authors | Okawa ER,Gotoh T,Manne J,Igarashi J,Fujita T,Silverman KA,Xhao H,Mosse YP,White PS,Brodeur GM
Category | C2
Sub-category | CGP
Brief description | Genes in the smallest region of deletion (SRD) in 1p36.3 area in neuroblastoma samples.
Full description | Neuroblastomas are characterized by 1p deletions, suggesting that a tumor suppressor gene (TSG) resides in this region. We have mapped the smallest region of deletion (SRD) to a 2 Mb region of 1p36.31 using microsatellite and single nucleotide polymorphisms. We have identified 23 genes in this region, and we have analysed these genes for mutations and RNA expression patterns to identify candidate TSGs. We sequenced the coding exons of these genes in 30 neuroblastoma cell lines. Although rare mutations were found in 10 of the 23 genes, none showed a pattern of genetic change consistent with homozygous inactivation. We examined the expression of these 23 genes in 20 neuroblastoma cell lines, and most showed readily detectable expression, and no correlation with 1p deletion. However, 7 genes showed uniformly low expression in the lines, and 2 genes (CHD5, RNF207) had virtually absent expression, consistent with the expected pattern for a TSG. Our mutation and expression analysis in neuroblastoma cell lines, combined with expression analysis in normal tissues, putative function and prior implication in neuroblastoma pathogenesis, suggests that the most promising TSG deleted from the 1p36 SRD is CHD5, but TNFRSF25, CAMTA1 and AJAP1 are also viable candidates.

Standard name | COWLING_MYCN_TARGETS
Systematic name | M16692
Organism | Homo sapiens
PMID | 17704800
Authors | Cowling VH,Cole MD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by MYCN [GeneID=4613] but not by its transactivation-defficient, trunkated form N-Myc-delta-73.
Full description | Myc promotes both normal cell proliferation and oncogenic transformation through the activation and repression of target genes. The c-Myc-S protein is a truncated form of c-Myc that is produced in some cells from translation initiation at an internal AUG codon. We report that c-Myc-S and a similar truncated form of N-MycWT can fully rescue the proliferation defect in myc-null fibroblasts, but rescue is dependent on the highly conserved Myc homology box II (MBII). Global gene expression studies show that the N-Myc equivalent of c-Myc-S is defective for virtually all transcriptional activation of Myc target genes but remains active for the majority of transcriptional repression. Repression by Myc-S is dependent on MBII, but it does not bind to several known nuclear cofactors. These data suggest that repression by Myc involves recruitment of a novel MBII-dependent cofactor.

Standard name | GROSS_HYPOXIA_VIA_HIF1A_ONLY
Systematic name | M1292
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes uniquely up-regulated in SEND cells (skin endothelium) at hypoxia after knockdown of HIF1A [GeneID=3091] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | FALVELLA_SMOKERS_WITH_LUNG_CANCER
Systematic name | M18536
Organism | Homo sapiens
PMID | 17724461
Authors | Falvella FS,Spinola M,Pignatiello C,Noci S,Conti B,Pastorino U,Carbone A,Dragani TA
Category | C2
Sub-category | CGP
Brief description | Genes that distinguish normal from cancer (lung adenocarcinoma) samples and smokers from non-smoking subjects.
Full description | Evidence in animal models has suggested an association between susceptibility to lung tumorigenesis and gene-expression profiles in normal lung. Here, we compared RNA pools from normal lung tissue of lung adenocarcinoma patients (cases) or non-lung cancer patients (controls) by hybridization of whole-human genome expression arrays. Principal component analysis identified a gene-expression signature of 85 genes that distinguishes cases from controls as well as smokers from nonsmokers. Elevated mRNA levels of one of these genes, AZGP1, were significantly associated with disease status. These results support the hypothesis that differences in the gene-expression levels of the normal tissue may be predictive of genetic predisposition to lung cancer in humans.

Standard name | OZEN_MIR125B1_TARGETS
Systematic name | M15122
Organism | Homo sapiens
PMID | 17891175
Authors | Ozen M,Creighton CJ,Ozdemir M,Ittmann M
Category | C2
Sub-category | CGP
Brief description | Potential targets of MIR125B1 [GeneID=406911] microRNA which are up-regulated in prostate cancer.
Full description | MicroRNAs (miRNAs) are small regulatory RNAs that can regulate gene expression by binding to mRNA sequences and repressing target-gene expression post-transcriptionally, either by inhibiting translation or promoting RNA degradation. We have analysed expression of 328 known and 152 novel human miRNAs in 10 benign peripheral zone tissues and 16 prostate cancer tissues using microarrays and found widespread, but not universal, downregulation of miRNAs in clinically localized prostate cancer relative to benign peripheral zone tissue. These findings have been verified by real-time RT-PCR assays on select miRNAs, including miR-125b, miR-145 and let-7c. The downregulated miRNAs include several with proven target mRNAs whose proteins have been previously shown to be increased in prostate cancer by immunohistochemistry, including RAS, E2F3, BCL-2 and MCL-1. Using a bioinformatics approach, we have identified additional potential mRNA targets of one of the miRNAs, (miR-125b) that are upregulated in prostate cancer and confirmed increased expression of one of these targets, EIF4EBP1, in prostate cancer tissues. Our findings indicate that changes in miRNA expression may have an important role in the biology of human prostate cancer.

Standard name | GALIE_TUMOR_ANGIOGENESIS
Systematic name | M1294
Organism | Mus musculus
PMID | 17998939
Authors | Galiè M,Konstantinidou G,Peroni D,Scambi I,Marchini C,Lisi V,Krampera M,Magnani P,Merigo F,Montani M,Boschi F,Marzola P,Orrù R,Farace P,Sbarbati A,Amici A
Category | C2
Sub-category | CGP
Brief description | Angiogenic genes up-regulated in A17 carcinomas (high vascularization) compared to the syngeneic BB1 and spontaneous tumors (little vascularization).
Full description | Tumor microenvironment in carcinomas recruits mesenchymal cells with an abnormal proangiogenic and invasive phenotype. It is not clear whether mesenchymal tumor cells (MTCs) derive from the activation of mature fibroblasts or from their stem cell precursors. However, stromal cell activation in tumors resembles in several aspects the mesenchymal rearrangement which normally occurs during reparative processes such as wound healing. Mesenchymal stem cells (MSCs) play a crucial role in developmental and reparative processes and have extraordinary proangiogenic potential, on the basis of which they are thought to show great promise for the treatment of ischemic disorders. Here, we show that MTCs have proangiogenic potential and that they share the transcriptional expression of the best-known proangiogenic factors with MSCs. We also found that MTCs and MSCs have the same molecular signature for stemness-related genes, and that when co-implanted with cancer cells in syngeneic animals MSCs determine early tumor appearance, probably by favoring the angiogenic switch. Our data (1) reveal crucial aspects of the proangiogenic phenotype of MTCs, (2) strongly suggest their stem origin and (3) signal the risk of therapeutic use of MSCs in tumor-promoting conditions.

Standard name | GALIE_TUMOR_STEMNESS_GENES
Systematic name | M1295
Organism | Mus musculus
PMID | 17998939
Authors | Galiè M,Konstantinidou G,Peroni D,Scambi I,Marchini C,Lisi V,Krampera M,Magnani P,Merigo F,Montani M,Boschi F,Marzola P,Orrù R,Farace P,Sbarbati A,Amici A
Category | C2
Sub-category | CGP
Brief description | Stemness-related genes changed in A17 carcinomas (MTC, mesenchymal tumor cells) compared with the mesenchymal stem cells (MSC).
Full description | Tumor microenvironment in carcinomas recruits mesenchymal cells with an abnormal proangiogenic and invasive phenotype. It is not clear whether mesenchymal tumor cells (MTCs) derive from the activation of mature fibroblasts or from their stem cell precursors. However, stromal cell activation in tumors resembles in several aspects the mesenchymal rearrangement which normally occurs during reparative processes such as wound healing. Mesenchymal stem cells (MSCs) play a crucial role in developmental and reparative processes and have extraordinary proangiogenic potential, on the basis of which they are thought to show great promise for the treatment of ischemic disorders. Here, we show that MTCs have proangiogenic potential and that they share the transcriptional expression of the best-known proangiogenic factors with MSCs. We also found that MTCs and MSCs have the same molecular signature for stemness-related genes, and that when co-implanted with cancer cells in syngeneic animals MSCs determine early tumor appearance, probably by favoring the angiogenic switch. Our data (1) reveal crucial aspects of the proangiogenic phenotype of MTCs, (2) strongly suggest their stem origin and (3) signal the risk of therapeutic use of MSCs in tumor-promoting conditions.

Standard name | KAUFFMANN_MELANOMA_RELAPSE_UP
Systematic name | M2431
Organism | Homo sapiens
PMID | 17891185
Authors | Kauffmann A,Rosselli F,Lazar V,Winnepenninckx V,Mansuet-Lupo A,Dessen P,van den Oord JJ,Spatz A,Sarasin A
Category | C2
Sub-category | CGP
Brief description | DNA repair and replication genes up-regulated in melanoma patients who will relapse vs patients who will not.
Full description | We have identified a gene-profile signature for human primary malignant melanoma associated with metastasis to distant sites and poor prognosis. We analyse the differential gene expression by looking at whole biological pathways rather than individual genes. Among the most significant pathways associated with progression to metastasis, we found the DNA replication (P=10(-14)) and the DNA repair pathways (P=10(-16)). We concentrated our analysis on DNA repair and found that 48 genes of this category, among a list of 234 genes, are associated with metastatic progression. These genes belong essentially to the pathways allowing recovery of stalled replication forks due to spontaneous blockage or induced DNA lesions. Because almost all these differentially expressed repair genes were overexpressed in primary tumors with bad prognosis, we speculate that primary melanoma cells that will metastasize try to replicate in a fast and error-free mode. In contrast to the progression from melanocytes to primary melanoma, genetic stability appears to be necessary for a melanoma cell to give rise to distant metastasis. This overexpression of repair genes explains nicely the extraordinary resistance of metastatic melanoma to chemo- and radio-therapy. Our results may open a new avenue for the discovery of drugs active on human metastatic melanoma.

Standard name | KAUFFMANN_MELANOMA_RELAPSE_DN
Systematic name | M6452
Organism | Homo sapiens
PMID | 17891185
Authors | Kauffmann A,Rosselli F,Lazar V,Winnepenninckx V,Mansuet-Lupo A,Dessen P,van den Oord JJ,Spatz A,Sarasin A
Category | C2
Sub-category | CGP
Brief description | DNA repair and replication genes down-regulated in melanoma patients who will relapse vs patients who will not.
Full description | We have identified a gene-profile signature for human primary malignant melanoma associated with metastasis to distant sites and poor prognosis. We analyse the differential gene expression by looking at whole biological pathways rather than individual genes. Among the most significant pathways associated with progression to metastasis, we found the DNA replication (P=10(-14)) and the DNA repair pathways (P=10(-16)). We concentrated our analysis on DNA repair and found that 48 genes of this category, among a list of 234 genes, are associated with metastatic progression. These genes belong essentially to the pathways allowing recovery of stalled replication forks due to spontaneous blockage or induced DNA lesions. Because almost all these differentially expressed repair genes were overexpressed in primary tumors with bad prognosis, we speculate that primary melanoma cells that will metastasize try to replicate in a fast and error-free mode. In contrast to the progression from melanocytes to primary melanoma, genetic stability appears to be necessary for a melanoma cell to give rise to distant metastasis. This overexpression of repair genes explains nicely the extraordinary resistance of metastatic melanoma to chemo- and radio-therapy. Our results may open a new avenue for the discovery of drugs active on human metastatic melanoma.

Standard name | WILLIAMS_ESR1_TARGETS_UP
Systematic name | M2970
Organism | Homo sapiens
PMID | 17700529
Authors | Williams C,Edvardsson K,Lewandowski SA,Ström A,Gustafsson JA
Category | C2
Sub-category | CGP
Brief description | The 'ER-alpha profile': genes up-regulated in T47D cells (breast cancer, ESR2 [GeneID=2100] Tet-Off) upon activation of ESR1 [GeneID=2099] by estradiol (E2) [PubChem=5757].
Full description | Transcriptional effects of estrogen result from its activation of two estrogen receptor (ER) isoforms; ERalpha that drives proliferation and ERbeta that is antiproliferative. Expression of ERbeta in xenograft tumors from the T47D breast cancer cell line reduces tumor growth and angiogenesis. If ERbeta can halt tumor growth, its introduction into cancers may be a novel therapeutic approach to the treatment of estrogen-responsive cancers. To assess the complete impact of ERbeta on transcription, we have made a full transcriptome analysis of ERalpha- and ERbeta-mediated gene regulation in T47D cell line with Tet-Off regulated ERbeta expression. Of the 35 000 genes and transcripts analysed, 4.1% (1434) were altered by ERalpha activation. Tet withdrawal and subsequent ERbeta expression inhibited the ERalpha regulation of 998 genes and, in addition, altered expression of 152 non-ERalpha-regulated genes. ERalpha-induced and ERbeta-repressed genes were involved in proliferation, steroid/xenobiotic metabolism and ion transport. The ERbeta repressive effect was further confirmed by proliferation assays, where ERbeta was shown to completely oppose the ERalpha-E2 induced proliferation. Additional analysis of ERbeta with a mutated DNA-binding domain revealed that this mutant, at least for a quantity of genes, antagonizes ERalpha even more strongly than ERbeta wt. From an examination of the genes regulated by ERalpha and ERbeta, we suggest that introduction of ERbeta may be an alternative therapeutic approach to the treatment of certain cancers.

Standard name | WILLIAMS_ESR1_TARGETS_DN
Systematic name | M10196
Organism | Homo sapiens
PMID | 17700529
Authors | Williams C,Edvardsson K,Lewandowski SA,Ström A,Gustafsson JA
Category | C2
Sub-category | CGP
Brief description | The 'ER-alpha profile': genes down-regulated in T47D cells (breast cancer, ESR2 [GeneID=2100] Tet-Off) upon activation of ESR1 [GeneID=2099] by estradiol (E2) [PubChem=5757].
Full description | Transcriptional effects of estrogen result from its activation of two estrogen receptor (ER) isoforms; ERalpha that drives proliferation and ERbeta that is antiproliferative. Expression of ERbeta in xenograft tumors from the T47D breast cancer cell line reduces tumor growth and angiogenesis. If ERbeta can halt tumor growth, its introduction into cancers may be a novel therapeutic approach to the treatment of estrogen-responsive cancers. To assess the complete impact of ERbeta on transcription, we have made a full transcriptome analysis of ERalpha- and ERbeta-mediated gene regulation in T47D cell line with Tet-Off regulated ERbeta expression. Of the 35 000 genes and transcripts analysed, 4.1% (1434) were altered by ERalpha activation. Tet withdrawal and subsequent ERbeta expression inhibited the ERalpha regulation of 998 genes and, in addition, altered expression of 152 non-ERalpha-regulated genes. ERalpha-induced and ERbeta-repressed genes were involved in proliferation, steroid/xenobiotic metabolism and ion transport. The ERbeta repressive effect was further confirmed by proliferation assays, where ERbeta was shown to completely oppose the ERalpha-E2 induced proliferation. Additional analysis of ERbeta with a mutated DNA-binding domain revealed that this mutant, at least for a quantity of genes, antagonizes ERalpha even more strongly than ERbeta wt. From an examination of the genes regulated by ERalpha and ERbeta, we suggest that introduction of ERbeta may be an alternative therapeutic approach to the treatment of certain cancers.

Standard name | WILLIAMS_ESR2_TARGETS_UP
Systematic name | M18326
Organism | Homo sapiens
PMID | 17700529
Authors | Williams C,Edvardsson K,Lewandowski SA,Ström A,Gustafsson JA
Category | C2
Sub-category | CGP
Brief description | Genes uniquely up-regulated in T47D cells (breast cancer) by induction of ESR2 [GeneID=2100] expression in the Tet-Off system.
Full description | Transcriptional effects of estrogen result from its activation of two estrogen receptor (ER) isoforms; ERalpha that drives proliferation and ERbeta that is antiproliferative. Expression of ERbeta in xenograft tumors from the T47D breast cancer cell line reduces tumor growth and angiogenesis. If ERbeta can halt tumor growth, its introduction into cancers may be a novel therapeutic approach to the treatment of estrogen-responsive cancers. To assess the complete impact of ERbeta on transcription, we have made a full transcriptome analysis of ERalpha- and ERbeta-mediated gene regulation in T47D cell line with Tet-Off regulated ERbeta expression. Of the 35 000 genes and transcripts analysed, 4.1% (1434) were altered by ERalpha activation. Tet withdrawal and subsequent ERbeta expression inhibited the ERalpha regulation of 998 genes and, in addition, altered expression of 152 non-ERalpha-regulated genes. ERalpha-induced and ERbeta-repressed genes were involved in proliferation, steroid/xenobiotic metabolism and ion transport. The ERbeta repressive effect was further confirmed by proliferation assays, where ERbeta was shown to completely oppose the ERalpha-E2 induced proliferation. Additional analysis of ERbeta with a mutated DNA-binding domain revealed that this mutant, at least for a quantity of genes, antagonizes ERalpha even more strongly than ERbeta wt. From an examination of the genes regulated by ERalpha and ERbeta, we suggest that introduction of ERbeta may be an alternative therapeutic approach to the treatment of certain cancers.

Standard name | WILLIAMS_ESR2_TARGETS_DN
Systematic name | M5714
Organism | Homo sapiens
PMID | 17700529
Authors | Williams C,Edvardsson K,Lewandowski SA,Ström A,Gustafsson JA
Category | C2
Sub-category | CGP
Brief description | Genes uniquely down-regulated in T47D cells (breast cancer) by induction of ESR2 [GeneID=2100] expression in the Tet-Off system.
Full description | Transcriptional effects of estrogen result from its activation of two estrogen receptor (ER) isoforms; ERalpha that drives proliferation and ERbeta that is antiproliferative. Expression of ERbeta in xenograft tumors from the T47D breast cancer cell line reduces tumor growth and angiogenesis. If ERbeta can halt tumor growth, its introduction into cancers may be a novel therapeutic approach to the treatment of estrogen-responsive cancers. To assess the complete impact of ERbeta on transcription, we have made a full transcriptome analysis of ERalpha- and ERbeta-mediated gene regulation in T47D cell line with Tet-Off regulated ERbeta expression. Of the 35 000 genes and transcripts analysed, 4.1% (1434) were altered by ERalpha activation. Tet withdrawal and subsequent ERbeta expression inhibited the ERalpha regulation of 998 genes and, in addition, altered expression of 152 non-ERalpha-regulated genes. ERalpha-induced and ERbeta-repressed genes were involved in proliferation, steroid/xenobiotic metabolism and ion transport. The ERbeta repressive effect was further confirmed by proliferation assays, where ERbeta was shown to completely oppose the ERalpha-E2 induced proliferation. Additional analysis of ERbeta with a mutated DNA-binding domain revealed that this mutant, at least for a quantity of genes, antagonizes ERalpha even more strongly than ERbeta wt. From an examination of the genes regulated by ERalpha and ERbeta, we suggest that introduction of ERbeta may be an alternative therapeutic approach to the treatment of certain cancers.

Standard name | GROSS_ELK3_TARGETS_UP
Systematic name | M1298
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SEND cells (skin endothelium) at normal oxygen (normoxia) conditions after knockdown of ELK3 [GeneID=2004] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_ELK3_TARGETS_DN
Systematic name | M1299
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SEND cells (skin endothelium) at normal oxygen (normoxia) conditions after knockdown of ELK3 [GeneID=2004] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_HYPOXIA_VIA_ELK3_UP
Systematic name | M1303
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SEND cells (skin endothelium) at hypoxia with ELK3 [GeneID=2004] knockdown by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_HYPOXIA_VIA_ELK3_DN
Systematic name | M1304
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SEND cells (skin endothelium) at hypoxia with ELK3 [GeneID=2004] knockdown by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_HIF1A_TARGETS_UP
Systematic name | M1306
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SEND cells (skin endothelium) at normal oxygen (normoxia) conditions after knockdown of HIF1A [GeneID=3091] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_HIF1A_TARGETS_DN
Systematic name | M1307
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SEND cells (skin endothelium) at normal oxygen (normoxia) conditions after knockdown of HIF1A [GeneID=3091] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_HYPOXIA_VIA_HIF1A_UP
Systematic name | M1308
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SEND cells (skin endothelium) at hypoxia after knockdown of HIF1A [GeneID=3091] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_HYPOXIA_VIA_HIF1A_DN
Systematic name | M1309
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SEND cells (skin endothelium) at hypoxia after knockdown of HIF1A [GeneID=3091] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_HYPOXIA_VIA_ELK3_ONLY_UP
Systematic name | M1313
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes specifically up-regulated in SEND cells (skin endothelium) at hypoxia after knockdown of ELK3 [GeneID=2004] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_HYPOXIA_VIA_ELK3_ONLY_DN
Systematic name | M1316
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes specifically down-regulated in SEND cells (skin endothelium) at hypoxia after knockdown of ELK3 [GeneID=2004] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_HYPOXIA_VIA_ELK3_AND_HIF1A_UP
Systematic name | M1317
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SEND cells (skin endothelium) at hypoxia after knockdown of ELK3 [GeneID=2004] and HIF1A [GeneID=3091] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | GROSS_HYPOXIA_VIA_ELK3_AND_HIF1A_DN
Systematic name | M1318
Organism | Mus musculus
PMID | 17704799
Authors | Gross C,Dubois-Pot H,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SEND cells (skin endothelium) at hypoxia after knockdown of ELK3 [GeneID=2004] and HIF1A [GeneID=3091] by RNAi.
Full description | The ternary complex factor Net/Elk3 is downregulated in hypoxia and participates in the induction by hypoxia of several genes, including c-fos, vascular endothelial growth factor and egr-1. However, the global role of Net in hypoxia remains to be elucidated. We have identified, in a large-scale analysis of RNA expression using microarrays, more than 370 genes that are regulated by Net in hypoxia. In order to gain insights into the role of Net in hypoxia, we have analysed in parallel the genes regulated by HIF-1alpha, the classical factor involved in the response to hypoxia. We identified about 190 genes that are regulated by HIF-1alpha in hypoxia. Surprisingly, when we compare the genes induced by hypoxia that require either Net or HIF-1alpha, the majority are the same (75%), suggesting that the functions of both factors are closely linked. Interestingly, in hypoxia, Net regulates the expression of several genes known to control HIF-1alpha stability, including PHD2, PHD3 and Siah2, suggesting that Net regulates the stability of HIF-1alpha. We found that inhibition of Net by RNAi leads to decreased HIF-1alpha expression at the protein level in hypoxia. These results indicate that Net participates in the transcriptional response to hypoxia by regulation of HIF-1alpha protein stability.

Standard name | NUYTTEN_NIPP1_TARGETS_UP
Systematic name | M6444
Organism | Homo sapiens
PMID | 17724462
Authors | Nuytten M,Beke L,Van Eynde A,Ceulemans H,Beullens M,Van Hummelen P,Fuks F,Bollen M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in PC3 cells (prostate cancer) after knockdown of NIPP1 [GeneID=5511] by RNAi.
Full description | EZH2 is a Polycomb group (PcG) protein that promotes the late-stage development of cancer by silencing a specific set of genes, at least in part through trimethylation of associated histone H3 on Lys 27 (H3K27). Nuclear inhibitor of protein phosphatase-1 (NIPP1) is a ubiquitously expressed transcriptional repressor that has binding sites for the EZH2 interactor EED. Here, we examine the contribution of NIPP1 to EZH2-mediated gene silencing. Studies on NIPP1-deficient cells disclose a widespread and essential role of NIPP1 in the trimethylation of H3K27 by EZH2, not only in the onset of this trimethylation during embryonic development, but also in the maintenance of this repressive mark in proliferating cells. Consistent with this notion, EZH2 and NIPP1 silence a common set of genes, as revealed by gene-expression profiling, and NIPP1 is associated with established Polycomb target genes and with genomic regions that are enriched in Polycomb targets. Furthermore, most NIPP1 target genes are trimethylated on H3K27 and the knockdown of either NIPP1 or EZH2 is often associated with a loss of this modification. Our data reveal that NIPP1 is required for the global trimethylation of H3K27 and is implicated in gene silencing by EZH2.

Standard name | NUYTTEN_NIPP1_TARGETS_DN
Systematic name | M18090
Organism | Homo sapiens
PMID | 17724462
Authors | Nuytten M,Beke L,Van Eynde A,Ceulemans H,Beullens M,Van Hummelen P,Fuks F,Bollen M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in PC3 cells (prostate cancer) after knockdown of NIPP1 [GeneID=5511] by RNAi.
Full description | EZH2 is a Polycomb group (PcG) protein that promotes the late-stage development of cancer by silencing a specific set of genes, at least in part through trimethylation of associated histone H3 on Lys 27 (H3K27). Nuclear inhibitor of protein phosphatase-1 (NIPP1) is a ubiquitously expressed transcriptional repressor that has binding sites for the EZH2 interactor EED. Here, we examine the contribution of NIPP1 to EZH2-mediated gene silencing. Studies on NIPP1-deficient cells disclose a widespread and essential role of NIPP1 in the trimethylation of H3K27 by EZH2, not only in the onset of this trimethylation during embryonic development, but also in the maintenance of this repressive mark in proliferating cells. Consistent with this notion, EZH2 and NIPP1 silence a common set of genes, as revealed by gene-expression profiling, and NIPP1 is associated with established Polycomb target genes and with genomic regions that are enriched in Polycomb targets. Furthermore, most NIPP1 target genes are trimethylated on H3K27 and the knockdown of either NIPP1 or EZH2 is often associated with a loss of this modification. Our data reveal that NIPP1 is required for the global trimethylation of H3K27 and is implicated in gene silencing by EZH2.

Standard name | NUYTTEN_EZH2_TARGETS_UP
Systematic name | M4196
Organism | Homo sapiens
PMID | 17724462
Authors | Nuytten M,Beke L,Van Eynde A,Ceulemans H,Beullens M,Van Hummelen P,Fuks F,Bollen M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in PC3 cells (prostate cancer) after knockdown of EZH2 [GeneID=2146] by RNAi.
Full description | EZH2 is a Polycomb group (PcG) protein that promotes the late-stage development of cancer by silencing a specific set of genes, at least in part through trimethylation of associated histone H3 on Lys 27 (H3K27). Nuclear inhibitor of protein phosphatase-1 (NIPP1) is a ubiquitously expressed transcriptional repressor that has binding sites for the EZH2 interactor EED. Here, we examine the contribution of NIPP1 to EZH2-mediated gene silencing. Studies on NIPP1-deficient cells disclose a widespread and essential role of NIPP1 in the trimethylation of H3K27 by EZH2, not only in the onset of this trimethylation during embryonic development, but also in the maintenance of this repressive mark in proliferating cells. Consistent with this notion, EZH2 and NIPP1 silence a common set of genes, as revealed by gene-expression profiling, and NIPP1 is associated with established Polycomb target genes and with genomic regions that are enriched in Polycomb targets. Furthermore, most NIPP1 target genes are trimethylated on H3K27 and the knockdown of either NIPP1 or EZH2 is often associated with a loss of this modification. Our data reveal that NIPP1 is required for the global trimethylation of H3K27 and is implicated in gene silencing by EZH2.

Standard name | NUYTTEN_EZH2_TARGETS_DN
Systematic name | M17122
Organism | Homo sapiens
PMID | 17724462
Authors | Nuytten M,Beke L,Van Eynde A,Ceulemans H,Beullens M,Van Hummelen P,Fuks F,Bollen M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in PC3 cells (prostate cancer) after knockdown of EZH2 [GeneID=2146] by RNAi.
Full description | EZH2 is a Polycomb group (PcG) protein that promotes the late-stage development of cancer by silencing a specific set of genes, at least in part through trimethylation of associated histone H3 on Lys 27 (H3K27). Nuclear inhibitor of protein phosphatase-1 (NIPP1) is a ubiquitously expressed transcriptional repressor that has binding sites for the EZH2 interactor EED. Here, we examine the contribution of NIPP1 to EZH2-mediated gene silencing. Studies on NIPP1-deficient cells disclose a widespread and essential role of NIPP1 in the trimethylation of H3K27 by EZH2, not only in the onset of this trimethylation during embryonic development, but also in the maintenance of this repressive mark in proliferating cells. Consistent with this notion, EZH2 and NIPP1 silence a common set of genes, as revealed by gene-expression profiling, and NIPP1 is associated with established Polycomb target genes and with genomic regions that are enriched in Polycomb targets. Furthermore, most NIPP1 target genes are trimethylated on H3K27 and the knockdown of either NIPP1 or EZH2 is often associated with a loss of this modification. Our data reveal that NIPP1 is required for the global trimethylation of H3K27 and is implicated in gene silencing by EZH2.

Standard name | INGRAM_SHH_TARGETS_UP
Systematic name | M1320
Organism | Mus musculus
PMID | 17873912
Authors | Ingram WJ,McCue KI,Tran TH,Hallahan AR,Wainwright BJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 10T1/2 cells (multipotent mesoderma) by expression of SHH [GeneID=6469].
Full description | Aberrant regulation of signalling mechanisms that normally orchestrate embryonic development, such as the Hedgehog, Wnt and Notch pathways, is a common feature of tumorigenesis. In order to better understand the neoplastic events mediated by Hedgehog signalling, we identified over 200 genes regulated by Sonic Hedgehog in multipotent mesodermal cells. Widespread crosstalk with other developmental signalling pathways is evident, suggesting a complex network of interactions that challenges the often over-simplistic representation of these pathways as simple linear entities. Hes1, a principal effector of the Notch pathway, was found to be a target of Sonic Hedgehog in both C3H/10T1/2 mesodermal and MNS70 neural cells. Desert Hedgehog also elicited a strong Hes1 response. While Smoothened function was found necessary for upregulation of Hes1 in response to Sonic Hedgehog, the mechanism does not require gamma-secretase-mediated cleavage of Notch receptors, and appears to involve transcription factors other than RBP-Jkappa. Thus, we have defined a novel mechanism for Hes1 regulation in stem-like cells that is independent of canonical Notch signalling.

Standard name | INGRAM_SHH_TARGETS_DN
Systematic name | M1322
Organism | Mus musculus
PMID | 17873912
Authors | Ingram WJ,McCue KI,Tran TH,Hallahan AR,Wainwright BJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 10T1/2 cells (multipotent mesoderma) by expression of SHH [GeneID=6469].
Full description | Aberrant regulation of signalling mechanisms that normally orchestrate embryonic development, such as the Hedgehog, Wnt and Notch pathways, is a common feature of tumorigenesis. In order to better understand the neoplastic events mediated by Hedgehog signalling, we identified over 200 genes regulated by Sonic Hedgehog in multipotent mesodermal cells. Widespread crosstalk with other developmental signalling pathways is evident, suggesting a complex network of interactions that challenges the often over-simplistic representation of these pathways as simple linear entities. Hes1, a principal effector of the Notch pathway, was found to be a target of Sonic Hedgehog in both C3H/10T1/2 mesodermal and MNS70 neural cells. Desert Hedgehog also elicited a strong Hes1 response. While Smoothened function was found necessary for upregulation of Hes1 in response to Sonic Hedgehog, the mechanism does not require gamma-secretase-mediated cleavage of Notch receptors, and appears to involve transcription factors other than RBP-Jkappa. Thus, we have defined a novel mechanism for Hes1 regulation in stem-like cells that is independent of canonical Notch signalling.

Standard name | MARTIN_NFKB_TARGETS_UP
Systematic name | M1325
Organism | Mus musculus
PMID | 17934524
Authors | Martin D,Galisteo R,Ji Y,Montaner S,Gutkind JS
Category | C2
Sub-category | CGP
Brief description | NF-kB-controlled genes up-regulated in endothelial cells in response to viral GPCR protein.
Full description | Kaposi's sarcoma (KS) is the most frequent AIDS-associated malignancy, etiologically linked to the infection with the human herpesvirus 8 (HHV-8/KSHV). This member of the gamma-herpesviridae family encodes 81 open reading frames, several bearing oncogenic potential. A constitutively active virally encoded G protein-coupled receptor (vGPCR) readily induces KS-like lesions when expressed in endothelial cells in vivo, and unmasks the oncogenic potential of other HHV-8 genes in a paracrine fashion. How vGPCR causes endothelial cell transformation is still not fully understood. Using full-genome microarray analysis we show here that the expression of nuclear factor-kappaB (NF-kappaB)-regulated genes is a prominent feature triggered by vGPCR in cells expressing this viral oncogene and in cells exposed to vGPCR-induced secretions, thus mimicking its paracrine effect. Indeed, vGPCR activates the NF-kappaB pathway potently, and NF-kappaB activation is a hallmark of both human and experimental KS. Of interest, whereas constitutive NF-kappaB signaling is not sufficient to promote endothelial cells transformation, NF-kappaB function is strictly required for vGPCR-induced direct and paracrine neoplasia. Taken together, these results strongly support the role of NF-kappaB regulated genes in KS pathogenesis, thus providing the rationale for the development of novel mechanism-based therapies for this angioproliferative disease.

Standard name | MARTIN_NFKB_TARGETS_DN
Systematic name | M1326
Organism | Mus musculus
PMID | 17934524
Authors | Martin D,Galisteo R,Ji Y,Montaner S,Gutkind JS
Category | C2
Sub-category | CGP
Brief description | NF-kB-controlled genes down-regulated in endothelial cells in response to viral GPCR protein.
Full description | Kaposi's sarcoma (KS) is the most frequent AIDS-associated malignancy, etiologically linked to the infection with the human herpesvirus 8 (HHV-8/KSHV). This member of the gamma-herpesviridae family encodes 81 open reading frames, several bearing oncogenic potential. A constitutively active virally encoded G protein-coupled receptor (vGPCR) readily induces KS-like lesions when expressed in endothelial cells in vivo, and unmasks the oncogenic potential of other HHV-8 genes in a paracrine fashion. How vGPCR causes endothelial cell transformation is still not fully understood. Using full-genome microarray analysis we show here that the expression of nuclear factor-kappaB (NF-kappaB)-regulated genes is a prominent feature triggered by vGPCR in cells expressing this viral oncogene and in cells exposed to vGPCR-induced secretions, thus mimicking its paracrine effect. Indeed, vGPCR activates the NF-kappaB pathway potently, and NF-kappaB activation is a hallmark of both human and experimental KS. Of interest, whereas constitutive NF-kappaB signaling is not sufficient to promote endothelial cells transformation, NF-kappaB function is strictly required for vGPCR-induced direct and paracrine neoplasia. Taken together, these results strongly support the role of NF-kappaB regulated genes in KS pathogenesis, thus providing the rationale for the development of novel mechanism-based therapies for this angioproliferative disease.

Standard name | MARTIN_VIRAL_GPCR_SIGNALING_UP
Systematic name | M1327
Organism | Mus musculus
PMID | 17934524
Authors | Martin D,Galisteo R,Ji Y,Montaner S,Gutkind JS
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the expression signature of direct and paracrine viral GPCR signaling in endothelial cells.
Full description | Kaposi's sarcoma (KS) is the most frequent AIDS-associated malignancy, etiologically linked to the infection with the human herpesvirus 8 (HHV-8/KSHV). This member of the gamma-herpesviridae family encodes 81 open reading frames, several bearing oncogenic potential. A constitutively active virally encoded G protein-coupled receptor (vGPCR) readily induces KS-like lesions when expressed in endothelial cells in vivo, and unmasks the oncogenic potential of other HHV-8 genes in a paracrine fashion. How vGPCR causes endothelial cell transformation is still not fully understood. Using full-genome microarray analysis we show here that the expression of nuclear factor-kappaB (NF-kappaB)-regulated genes is a prominent feature triggered by vGPCR in cells expressing this viral oncogene and in cells exposed to vGPCR-induced secretions, thus mimicking its paracrine effect. Indeed, vGPCR activates the NF-kappaB pathway potently, and NF-kappaB activation is a hallmark of both human and experimental KS. Of interest, whereas constitutive NF-kappaB signaling is not sufficient to promote endothelial cells transformation, NF-kappaB function is strictly required for vGPCR-induced direct and paracrine neoplasia. Taken together, these results strongly support the role of NF-kappaB regulated genes in KS pathogenesis, thus providing the rationale for the development of novel mechanism-based therapies for this angioproliferative disease.

Standard name | MARTIN_VIRAL_GPCR_SIGNALING_DN
Systematic name | M1330
Organism | Mus musculus
PMID | 17934524
Authors | Martin D,Galisteo R,Ji Y,Montaner S,Gutkind JS
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the expression signature of direct and paracrine viral GPCR signaling in endothelial cells.
Full description | Kaposi's sarcoma (KS) is the most frequent AIDS-associated malignancy, etiologically linked to the infection with the human herpesvirus 8 (HHV-8/KSHV). This member of the gamma-herpesviridae family encodes 81 open reading frames, several bearing oncogenic potential. A constitutively active virally encoded G protein-coupled receptor (vGPCR) readily induces KS-like lesions when expressed in endothelial cells in vivo, and unmasks the oncogenic potential of other HHV-8 genes in a paracrine fashion. How vGPCR causes endothelial cell transformation is still not fully understood. Using full-genome microarray analysis we show here that the expression of nuclear factor-kappaB (NF-kappaB)-regulated genes is a prominent feature triggered by vGPCR in cells expressing this viral oncogene and in cells exposed to vGPCR-induced secretions, thus mimicking its paracrine effect. Indeed, vGPCR activates the NF-kappaB pathway potently, and NF-kappaB activation is a hallmark of both human and experimental KS. Of interest, whereas constitutive NF-kappaB signaling is not sufficient to promote endothelial cells transformation, NF-kappaB function is strictly required for vGPCR-induced direct and paracrine neoplasia. Taken together, these results strongly support the role of NF-kappaB regulated genes in KS pathogenesis, thus providing the rationale for the development of novel mechanism-based therapies for this angioproliferative disease.

Standard name | BUYTAERT_PHOTODYNAMIC_THERAPY_STRESS_UP
Systematic name | M6782
Organism | Homo sapiens
PMID | 17952126
Authors | Buytaert E,Matroule JY,Durinck S,Close P,Kocanova S,Vandenheede JR,de Witte PA,Piette J,Agostinis P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T24 (bladder cancer) cells in response to the photodynamic therapy (PDT) stress.
Full description | Photodynamic therapy (PDT) is an anticancer approach utilizing a light-absorbing molecule and visible light irradiation to generate, in the presence of O(2), cytotoxic reactive oxygen species, which cause tumor ablation. Given that the photosensitizer hypericin is under consideration for PDT treatment of bladder cancer we used oligonucleotide microarrays in the T24 bladder cancer cell line to identify differentially expressed genes with therapeutic potential. This study reveals that the expression of several genes involved in various metabolic processes, stress-induced cell death, autophagy, proliferation, inflammation and carcinogenesis is strongly affected by PDT and pinpoints the coordinated induction of a cluster of genes involved in the unfolded protein response pathway after endoplasmic reticulum stress and in antioxidant response. Analysis of PDT-treated cells after p38(MAPK) inhibition or silencing unraveled that the induction of an important subset of differentially expressed genes regulating growth and invasion, as well as adaptive mechanisms against oxidative stress, is governed by this stress-activated kinase. Moreover, p38(MAPK) inhibition blocked autonomous regrowth and migration of cancer cells escaping PDT-induced cell death. This analysis identifies new molecular effectors of the cancer cell response to PDT opening attractive avenues to improve the therapeutic efficacy of hypericin-based PDT of bladder cancer.

Standard name | BUYTAERT_PHOTODYNAMIC_THERAPY_STRESS_DN
Systematic name | M10351
Organism | Homo sapiens
PMID | 17952126
Authors | Buytaert E,Matroule JY,Durinck S,Close P,Kocanova S,Vandenheede JR,de Witte PA,Piette J,Agostinis P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T24 (bladder cancer) cells in response to the photodynamic therapy (PDT) stress.
Full description | Photodynamic therapy (PDT) is an anticancer approach utilizing a light-absorbing molecule and visible light irradiation to generate, in the presence of O(2), cytotoxic reactive oxygen species, which cause tumor ablation. Given that the photosensitizer hypericin is under consideration for PDT treatment of bladder cancer we used oligonucleotide microarrays in the T24 bladder cancer cell line to identify differentially expressed genes with therapeutic potential. This study reveals that the expression of several genes involved in various metabolic processes, stress-induced cell death, autophagy, proliferation, inflammation and carcinogenesis is strongly affected by PDT and pinpoints the coordinated induction of a cluster of genes involved in the unfolded protein response pathway after endoplasmic reticulum stress and in antioxidant response. Analysis of PDT-treated cells after p38(MAPK) inhibition or silencing unraveled that the induction of an important subset of differentially expressed genes regulating growth and invasion, as well as adaptive mechanisms against oxidative stress, is governed by this stress-activated kinase. Moreover, p38(MAPK) inhibition blocked autonomous regrowth and migration of cancer cells escaping PDT-induced cell death. This analysis identifies new molecular effectors of the cancer cell response to PDT opening attractive avenues to improve the therapeutic efficacy of hypericin-based PDT of bladder cancer.

Standard name | FERREIRA_EWINGS_SARCOMA_UNSTABLE_VS_STABLE_UP
Systematic name | M19957
Organism | Homo sapiens
PMID | 17952124
Authors | Ferreira BI,Alonso J,Carrillo J,Acquadro F,Largo C,Suela J,Teixeira MR,Cerveira N,Molares A,Goméz-López G,Pestaña A,Sastre A,Garcia-Miguel P,Cigudosa JC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in genomically unstable Ewing's sarcoma tumors compared to the stable ones.
Full description | Ewing's sarcoma (ES) is characterized by specific chromosome translocations, the most common being t(11;22)(q24;q12). Additionally, other type of genetic abnormalities may occur and be relevant for explaining the variable tumour biology and clinical outcome. We have carried out a high-resolution array CGH and expression profiling on 25 ES tumour samples to characterize the DNA copy number aberrations (CNA) occurring in these tumours and determine their association with gene-expression profiles and clinical outcome. CNA were observed in 84% of the cases. We observed a median number of three aberrations per case. Besides numerical chromosome changes, smaller aberrations were found and defined at chromosomes 5p, 7q and 9p. All CNA were compiled to define the smallest overlapping regions of imbalance (SORI). A total of 35 SORI were delimited. Bioinformatics analyses were conducted to identify subgroups according to the pattern of genomic instability. Unsupervised and supervised clustering analysis (using SORI as variables) segregated the tumours in two distinct groups: one genomically stable (< or =3 CNA) and other genomically unstable (>3 CNA). The genomic unstable group showed a statistically significant shorter overall survival and was more refractory to chemotherapy. Expression profile analysis revealed significant differences between both groups. Genes related with chromosome segregation, DNA repair pathways and cell-cycle control were upregulated in the genomically unstable group. This report elucidates, for the first time, data about genomic instability in ES, based on CNA and expression profiling, and shows that a genomically unstable group of Ewing's tumours is correlated with a significant poor prognosis.

Standard name | FERREIRA_EWINGS_SARCOMA_UNSTABLE_VS_STABLE_DN
Systematic name | M11984
Organism | Homo sapiens
PMID | 17952124
Authors | Ferreira BI,Alonso J,Carrillo J,Acquadro F,Largo C,Suela J,Teixeira MR,Cerveira N,Molares A,Goméz-López G,Pestaña A,Sastre A,Garcia-Miguel P,Cigudosa JC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in genomically unstable Ewing's sarcoma tumors compared to the stable ones.
Full description | Ewing's sarcoma (ES) is characterized by specific chromosome translocations, the most common being t(11;22)(q24;q12). Additionally, other type of genetic abnormalities may occur and be relevant for explaining the variable tumour biology and clinical outcome. We have carried out a high-resolution array CGH and expression profiling on 25 ES tumour samples to characterize the DNA copy number aberrations (CNA) occurring in these tumours and determine their association with gene-expression profiles and clinical outcome. CNA were observed in 84% of the cases. We observed a median number of three aberrations per case. Besides numerical chromosome changes, smaller aberrations were found and defined at chromosomes 5p, 7q and 9p. All CNA were compiled to define the smallest overlapping regions of imbalance (SORI). A total of 35 SORI were delimited. Bioinformatics analyses were conducted to identify subgroups according to the pattern of genomic instability. Unsupervised and supervised clustering analysis (using SORI as variables) segregated the tumours in two distinct groups: one genomically stable (< or =3 CNA) and other genomically unstable (>3 CNA). The genomic unstable group showed a statistically significant shorter overall survival and was more refractory to chemotherapy. Expression profile analysis revealed significant differences between both groups. Genes related with chromosome segregation, DNA repair pathways and cell-cycle control were upregulated in the genomically unstable group. This report elucidates, for the first time, data about genomic instability in ES, based on CNA and expression profiling, and shows that a genomically unstable group of Ewing's tumours is correlated with a significant poor prognosis.

Standard name | NAKAYAMA_FRA2_TARGETS
Systematic name | M3782
Organism | Homo sapiens
PMID | 18071306
Authors | Nakayama T,Hieshima K,Arao T,Jin Z,Nagakubo D,Shirakawa AK,Yamada Y,Fujii M,Oiso N,Kawada A,Nishio K,Yoshie O
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ST1 cells (adult T-cell leukemia, ATL) after knockdown of FRA2 [GeneID=2355] by RNAi.
Full description | Adult T-cell leukemia (ATL) is a mature CD4+ T-cell malignancy etiologically associated with human T-cell leukemia virus type 1 (HTLV-1). Primary ATL cells frequently express CCR4 at high levels. Since HTLV-1 Tax does not induce CCR4 expression, transcription factor(s) constitutively active in ATL may be responsible for its strong expression. We identified an activator protein-1 (AP-1) site in the CCR4 promoter as the major positive regulatory element in ATL cells. Among the AP-1 family members, Fra-2, JunB and JunD are highly expressed in fresh primary ATL cells. Consistently, the Fra-2/JunB and Fra-2/JunD heterodimers strongly activated the CCR4 promoter in Jurkat cells. Furthermore, Fra-2 small interfering RNA (siRNA) or JunD siRNA, but not JunB siRNA, effectively reduced CCR4 expression and cell growth in ATL cells. Conversely, Fra-2 or JunD overexpression promoted cell growth in Jurkat cells. We identified 49 genes, including c-Myb, BCL-6 and MDM2, which were downregulated by Fra-2 siRNA in ATL cells. c-Myb, BCL-6 and MDM2 were also downregulated by JunD siRNA. As Fra-2, these proto-oncogenes were highly expressed in primary ATL cells but not in normal CD4+ T cells. Collectively, aberrantly expressed Fra-2 in association with JunD may play a major role in CCR4 expression and oncogenesis in ATL.

Standard name | LOPEZ_MBD_TARGETS
Systematic name | M4120
Organism | Homo sapiens
PMID | 18223687
Authors | Lopez-Serra L,Ballestar E,Ropero S,Setien F,Billard LM,Fraga MF,Lopez-Nieva P,Alaminos M,Guerrero D,Dante R,Esteller M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HeLa cells (cervical cancer) after simultaneus knockdown of all three MBD (methyl-CpG binding domain) proteins MeCP2, MBD1 and MBD2 [GeneID=4204;4152;8932] by RNAi.
Full description | Methyl-cytosine-phosphate-guanine (CpG)-binding domain (MBD) proteins are bound to hypermethylated promoter CpG islands of tumor suppressor genes in human cancer cells, although a direct causal relationship at the genome-wide level between MBD presence and gene silencing remains to be demonstrated. To this end, we have inhibited the expression of MBD proteins in HeLa cells by short hairpin RNAs; and studied the functional consequences of MBD depletion using microarray-based expression analysis in conjunction with extensive bisulfite genomic sequencing and chromatin immunoprecipitation. The removal of MBDs results in a release of gene silencing associated with a loss of MBD occupancy in 5'-CpG islands without any change in the DNA methylation pattern. Our results unveil new targets for epigenetic inactivation mediated by MBDs in transformed cells, such as the cell adhesion protein gamma-parvin and the fibroblast growth factor 19, where we also demonstrate their bona fide tumor suppressor features. Our data support a fundamental role for MBD proteins in the direct maintenance of transcriptional repression of tumor suppressors and identify new candidate genes for epigenetic disruption in cancer cells.

Standard name | LOPEZ_MBD_TARGETS_IMPRINTED_AND_X_LINKED
Systematic name | M4324
Organism | Homo sapiens
PMID | 18223687
Authors | Lopez-Serra L,Ballestar E,Ropero S,Setien F,Billard LM,Fraga MF,Lopez-Nieva P,Alaminos M,Guerrero D,Dante R,Esteller M
Category | C2
Sub-category | CGP
Brief description | X chromosome and imprinted genes up-regulated in HeLa cells (cervical cancer) after knockdown of the MBD (methyl-CpG binding domain) proteins by RNAi.
Full description | Methyl-cytosine-phosphate-guanine (CpG)-binding domain (MBD) proteins are bound to hypermethylated promoter CpG islands of tumor suppressor genes in human cancer cells, although a direct causal relationship at the genome-wide level between MBD presence and gene silencing remains to be demonstrated. To this end, we have inhibited the expression of MBD proteins in HeLa cells by short hairpin RNAs; and studied the functional consequences of MBD depletion using microarray-based expression analysis in conjunction with extensive bisulfite genomic sequencing and chromatin immunoprecipitation. The removal of MBDs results in a release of gene silencing associated with a loss of MBD occupancy in 5'-CpG islands without any change in the DNA methylation pattern. Our results unveil new targets for epigenetic inactivation mediated by MBDs in transformed cells, such as the cell adhesion protein gamma-parvin and the fibroblast growth factor 19, where we also demonstrate their bona fide tumor suppressor features. Our data support a fundamental role for MBD proteins in the direct maintenance of transcriptional repression of tumor suppressors and identify new candidate genes for epigenetic disruption in cancer cells.

Standard name | ROPERO_HDAC2_TARGETS
Systematic name | M8759
Organism | Homo sapiens
PMID | 18264134
Authors | Ropero S,Ballestar E,Alaminos M,Arango D,Schwartz S Jr,Esteller M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated genes in cell lines with HDAC2 [GeneID=3066] loss of function (LOS).
Full description | Although disruption of histone modification patterns is a common hallmark of human cancer, our knowledge of the mechanistic role of histone-modifying enzymes in its generation is very limited. We have recently identified an inactivating mutation in the histone deacetylase-2 (HDAC2) in sporadic carcinomas with microsatellite instability and in tumors arising in individuals with hereditary nonpolyposis colorectal cancer syndrome. Since HDAC2 seems to be a central player in epigenetic gene repression, we wondered whether HDAC2-truncating mutations conferred a particular expression signature on these cancer cells. Using unsupervised clustering analysis in microsatellite-unstable colorectal cancer cell lines, we have found that HDAC2 mutant cells (RKO and Co115) show a characteristically different expression microarray signature from HDAC2 wild-type cells (HCT-116, SW48, HCT-15 and LoVo). HDAC2 mutant cells exhibit upregulation of tumor-promoting genes, such as those of tyrosine kinases, mediators of cell cycle progression and angiogenic factors. The overexpression of these genes is associated with a loss of HDAC2 recruitment and a gain of histone H4 hyperacetylation in their particular 5'-end promoters, as observed by chromatin immunoprecipitation. Transfection of wild-type HDAC2 in mutant cells reverted this epigenetic pattern by repressing the transforming genes in association with HDAC2 promoter occupancy. These results suggest a role for HDAC2 mutations in human tumorigenesis through the derepression of key genes from multiple cellular transformation pathways.

Standard name | GOUYER_TUMOR_INVASIVENESS
Systematic name | M13965
Organism | Homo sapiens
PMID | 18317448
Authors | Gouyer V,Fontaine D,Dumont P,de Wever O,Fontayne-Devaud H,Leteurtre E,Truant S,Delacour D,Drobecq H,Kerckaert JP,de Launoit Y,Bracke M,Gespach C,Desseyn JL,Huet G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in constitutively invasive HT-29 5M21 cells (colon cancer) vs the parental non-invasive cells.
Full description | From the conditioned medium of the human colon carcinoma cells, HT-29 5M21 (CM-5M21), expressing a spontaneous invasive phenotype, tumor-associated trypsin inhibitor (TATI) was identified and characterized by proteomics, cDNA microarray approaches and functional analyses. Both CM-5M21 and recombinant TATI, but not the K18Y-TATI mutant at the protease inhibitor site, trigger collagen type I invasion by several human adenoma and carcinoma cells of the colon and breast, through phosphoinositide-3-kinase, protein kinase C and Rho-GTPases/Rho kinase-dependent pathways. Conversely, the proinvasive action of TATI in parental HT29 cells was alleviated by the TATI antibody PSKAN2 and the K18Y-TATI mutant. Stable expression of K18Y-TATI in HT-29 5M21 cells downregulated tumor growth, angiogenesis and the expression of several metastasis-related genes, including CSPG4 (13.8-fold), BMP-7 (9.7-fold), the BMP antagonist CHORDIN (5.2-fold), IGFBP-2 and IGF2 (9.6- and 4.6-fold). Accordingly, ectopic expression of KY-TATI inhibited the development of lung metastases from HT-29 5M21 tumor xenografts in immunodeficient mice. These findings identify TATI as an autocrine transforming factor potentially involved in early and late events of colon cancer progression, including local invasion of the primary tumor and its metastatic spread. Targeting TATI, its molecular partners and effectors may bring novel therapeutic applications for high-grade human solid tumors in the digestive and urogenital systems.

Standard name | LIU_LIVER_CANCER
Systematic name | M18919
Organism | Homo sapiens
PMID | 18332864
Authors | Liu BH,Goh CH,Ooi LL,Hui KM
Category | C2
Sub-category | CGP
Brief description | Low abundance transcripts specific to hepatocellular carcinoma (HCC).
Full description | Most human cancers are characterized by genetic aberrations accompanied by altered expression and function of numerous genes. Applying genome-wide, microarray gene expression analysis to identify deregulated genes in different tumour types can provide potential gene candidates as diagnostic and prognostic tools and promising targets for drug development. However, the detection of deregulated genes with low levels of expression remains a major challenge. In this study, we have designed a strategy, termed modified suppression subtractive hybridization (mSSH), to identify genes encoding rare transcripts. The strategy entails incorporating the T(7)-promoter sequence at the 5' end of the noncoding cDNA strand during first strand cDNA synthesis to generate unidirectional antisense RNA from the resultant cDNA following conventional SSH. These transcripts are subsequently analysed by Affymetrix oligonucleotide gene arrays. Here, we have used five hepatocellular carcinoma (HCC), five breast carcinoma and four nasopharyngeal carcinoma (NPC) biopsies separately as testers and their corresponding normal biopsies as drivers to enrich for low abundance tumour type-specific transcripts. The total detectable number of probe sets following mSSH was reduced almost 10-fold in comparison to those detected for the same resected tumour tissues without undergoing subtraction, thus yielding a subtraction efficacy of over 90%. Using this experimental approach, we have identified 48 HCC-specific, 45 breast carcinoma-specific, and 83 NPC-specific genes. In addition, 115 genes were upregulated in all the three cancer types. When compared to gene-profiling data obtained without mSSH, the majority of these identified transcripts were of low abundance in the original cancer tissues. mSSH can therefore serve as a comprehensive molecular strategy for pursuing functional genomic studies of human cancers.

Standard name | LIU_BREAST_CANCER
Systematic name | M16584
Organism | Homo sapiens
PMID | 18332864
Authors | Liu BH,Goh CH,Ooi LL,Hui KM
Category | C2
Sub-category | CGP
Brief description | Low abundance transcripts specific for breast cancer.
Full description | Most human cancers are characterized by genetic aberrations accompanied by altered expression and function of numerous genes. Applying genome-wide, microarray gene expression analysis to identify deregulated genes in different tumour types can provide potential gene candidates as diagnostic and prognostic tools and promising targets for drug development. However, the detection of deregulated genes with low levels of expression remains a major challenge. In this study, we have designed a strategy, termed modified suppression subtractive hybridization (mSSH), to identify genes encoding rare transcripts. The strategy entails incorporating the T(7)-promoter sequence at the 5' end of the noncoding cDNA strand during first strand cDNA synthesis to generate unidirectional antisense RNA from the resultant cDNA following conventional SSH. These transcripts are subsequently analysed by Affymetrix oligonucleotide gene arrays. Here, we have used five hepatocellular carcinoma (HCC), five breast carcinoma and four nasopharyngeal carcinoma (NPC) biopsies separately as testers and their corresponding normal biopsies as drivers to enrich for low abundance tumour type-specific transcripts. The total detectable number of probe sets following mSSH was reduced almost 10-fold in comparison to those detected for the same resected tumour tissues without undergoing subtraction, thus yielding a subtraction efficacy of over 90%. Using this experimental approach, we have identified 48 HCC-specific, 45 breast carcinoma-specific, and 83 NPC-specific genes. In addition, 115 genes were upregulated in all the three cancer types. When compared to gene-profiling data obtained without mSSH, the majority of these identified transcripts were of low abundance in the original cancer tissues. mSSH can therefore serve as a comprehensive molecular strategy for pursuing functional genomic studies of human cancers.

Standard name | LIU_NASOPHARYNGEAL_CARCINOMA
Systematic name | M18988
Organism | Homo sapiens
PMID | 18332864
Authors | Liu BH,Goh CH,Ooi LL,Hui KM
Category | C2
Sub-category | CGP
Brief description | Low abundance transcripts specific to nasopharyngeal carcinoma (NPC).
Full description | Most human cancers are characterized by genetic aberrations accompanied by altered expression and function of numerous genes. Applying genome-wide, microarray gene expression analysis to identify deregulated genes in different tumour types can provide potential gene candidates as diagnostic and prognostic tools and promising targets for drug development. However, the detection of deregulated genes with low levels of expression remains a major challenge. In this study, we have designed a strategy, termed modified suppression subtractive hybridization (mSSH), to identify genes encoding rare transcripts. The strategy entails incorporating the T(7)-promoter sequence at the 5' end of the noncoding cDNA strand during first strand cDNA synthesis to generate unidirectional antisense RNA from the resultant cDNA following conventional SSH. These transcripts are subsequently analysed by Affymetrix oligonucleotide gene arrays. Here, we have used five hepatocellular carcinoma (HCC), five breast carcinoma and four nasopharyngeal carcinoma (NPC) biopsies separately as testers and their corresponding normal biopsies as drivers to enrich for low abundance tumour type-specific transcripts. The total detectable number of probe sets following mSSH was reduced almost 10-fold in comparison to those detected for the same resected tumour tissues without undergoing subtraction, thus yielding a subtraction efficacy of over 90%. Using this experimental approach, we have identified 48 HCC-specific, 45 breast carcinoma-specific, and 83 NPC-specific genes. In addition, 115 genes were upregulated in all the three cancer types. When compared to gene-profiling data obtained without mSSH, the majority of these identified transcripts were of low abundance in the original cancer tissues. mSSH can therefore serve as a comprehensive molecular strategy for pursuing functional genomic studies of human cancers.

Standard name | LIU_COMMON_CANCER_GENES
Systematic name | M18694
Organism | Homo sapiens
PMID | 18332864
Authors | Liu BH,Goh CH,Ooi LL,Hui KM
Category | C2
Sub-category | CGP
Brief description | Low abundance transcripts common to nasopharyngeal carcinoma (NPC), breast and liver tumors.
Full description | Most human cancers are characterized by genetic aberrations accompanied by altered expression and function of numerous genes. Applying genome-wide, microarray gene expression analysis to identify deregulated genes in different tumour types can provide potential gene candidates as diagnostic and prognostic tools and promising targets for drug development. However, the detection of deregulated genes with low levels of expression remains a major challenge. In this study, we have designed a strategy, termed modified suppression subtractive hybridization (mSSH), to identify genes encoding rare transcripts. The strategy entails incorporating the T(7)-promoter sequence at the 5' end of the noncoding cDNA strand during first strand cDNA synthesis to generate unidirectional antisense RNA from the resultant cDNA following conventional SSH. These transcripts are subsequently analysed by Affymetrix oligonucleotide gene arrays. Here, we have used five hepatocellular carcinoma (HCC), five breast carcinoma and four nasopharyngeal carcinoma (NPC) biopsies separately as testers and their corresponding normal biopsies as drivers to enrich for low abundance tumour type-specific transcripts. The total detectable number of probe sets following mSSH was reduced almost 10-fold in comparison to those detected for the same resected tumour tissues without undergoing subtraction, thus yielding a subtraction efficacy of over 90%. Using this experimental approach, we have identified 48 HCC-specific, 45 breast carcinoma-specific, and 83 NPC-specific genes. In addition, 115 genes were upregulated in all the three cancer types. When compared to gene-profiling data obtained without mSSH, the majority of these identified transcripts were of low abundance in the original cancer tissues. mSSH can therefore serve as a comprehensive molecular strategy for pursuing functional genomic studies of human cancers.

Standard name | LOCKWOOD_AMPLIFIED_IN_LUNG_CANCER
Systematic name | M4572
Organism | Homo sapiens
PMID | 18391978
Authors | Lockwood WW,Chari R,Coe BP,Girard L,Macaulay C,Lam S,Gazdar AF,Minna JD,Lam WL
Category | C2
Sub-category | CGP
Brief description | Overexpressed genes with amplified copy number across 27 non-small cell lung cancer (NSCLC) cell lines.
Full description | Chromosomal translocation is the best-characterized genetic mechanism for oncogene activation. However, there are documented examples of activation by alternate mechanisms, for example gene dosage increase, though its prevalence is unclear. Here, we answered the fundamental question of the contribution of DNA amplification as a molecular mechanism driving oncogenesis. Comparing 104 cancer lines representing diverse tissue origins identified genes residing in amplification 'hotspots' and discovered an unexpected frequency of genes activated by this mechanism. The 3431 amplicons identified represent approximately 10 per hematological and approximately 36 per epithelial cancer genome. Many recurrently amplified oncogenes were previously known to be activated only by disease-specific translocations. The 135 hotspots identified contain 538 unique genes and are enriched for proliferation, apoptosis and linage-dependency genes, reflecting functions advantageous to tumor growth. Integrating gene dosage with expression data validated the downstream impact of the novel amplification events in both cell lines and clinical samples. For example, multiple downstream components of the EGFR-family-signaling pathway, including CDK5, AKT1 and SHC1, are overexpressed as a direct result of gene amplification in lung cancer. Our findings suggest that amplification is far more common a mechanism of oncogene activation than previously believed and that specific regions of the genome are hotspots of amplification.

Standard name | FREDERICK_PRKCI_TARGETS
Systematic name | M13167
Organism | Homo sapiens
PMID | 18427549
Authors | Frederick LA,Matthews JA,Jamieson L,Justilien V,Thompson EA,Radisky DC,Fields AP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in H1703 cells (non-small cell lung cancer, NSCLC) after knockdown of PRKCI [GeneID=5584] by RNAi.
Full description | Protein kinase Ciota (PKCiota) drives transformed growth of non-small cell lung cancer (NSCLC) cells through the Rho family GTPase Rac1. We show here that PKCiota activates Rac1 in NSCLC cells by formation of a PKCiota-Par6alpha complex that drives anchorage-independent growth and invasion through activation of matrix metalloproteinase-10 (MMP-10) expression. RNAi-mediated knockdown of PKCiota, Par6alpha or Rac1 expression inhibits NSCLC transformation and MMP-10 expression in vitro. Expression of wild-type Par6alpha in Par6alpha-deficient cells restores transformation and MMP-10 expression, whereas expression of Par6alpha mutants that either cannot bind PKCiota (Par6alpha-K19A) or couple to Rac1 (Par6alpha-DeltaCRIB) do not. Knockdown of MMP-10 expression blocks anchorage-independent growth and invasion of NSCLC cells and addition of catalytically active MMP-10 to PKCiota- or Par6alpha-deficient cells restores anchorage-independent growth and invasion. Dominant-negative PKCiota inhibits tumorigenicity and MMP-10 expression in subcutaneous NSCLC tumors. MMP-10 and PKCiota are coordinately overexpressed in primary NSCLC tumors, and tumor MMP-10 expression predicts poor survival in NSCLC patients. Our data define a PKCiota-Par6alpha-Rac1 signaling axis that drives anchorage-independent growth and invasion of NSCLC cells through induction of MMP-10 expression.

Standard name | RAHMAN_TP53_TARGETS_PHOSPHORYLATED
Systematic name | M1333
Organism | Homo sapiens
PMID | 18438429
Authors | Rahman-Roblick R,Hellman U,Becker S,Bader FG,Auer G,Wiman KG,Roblick UJ
Category | C2
Sub-category | CGP
Brief description | Proteins phosporylated in HCT116 cells (colon cancer) upon p53 [GeneID=7157] activation.
Full description | The p53 tumor suppressor regulates transcription of target genes. We have previously analysed the p53-dependent proteome and identified novel protein targets. Here we have examined p53-dependent phosphorylation using two-dimensional gel electrophoresis and staining with the fluorescent phosphoprotein dye Pro-Q Diamond. We report that p53 induces phosphorylation of a subset of proteins including Nm23, DJ-1, ANXA1 and PrxII. Our identification of p53-dependent phosphorylation of specific target proteins reveals new aspects of the p53-dependent cellular response and suggests that such posttranslational modifications may contribute to p53-mediated tumor suppression.

Standard name | WEI_MIR34A_TARGETS
Systematic name | M8617
Organism | Homo sapiens
PMID | 18504438
Authors | Wei JS,Song YK,Durinck S,Chen QR,Cheuk AT,Tsang P,Zhang Q,Thiele CJ,Slack A,Shohet J,Khan J
Category | C2
Sub-category | CGP
Brief description | Potential direct target genes for MIR34A [GeneID=407040] microRNA in IMR32 cells (neuroblastoma).
Full description | Loss of 1p36 heterozygosity commonly occurs with MYCN amplification in neuroblastoma tumors, and both are associated with an aggressive phenotype. Database searches identified five microRNAs that map to the commonly deleted region of 1p36 and we hypothesized that the loss of one or more of these microRNAs contributes to the malignant phenotype of MYCN-amplified tumors. By bioinformatic analysis, we identified that three out of the five microRNAs target MYCN and of these miR-34a caused the most significant suppression of cell growth through increased apoptosis and decreased DNA synthesis in neuroblastoma cell lines with MYCN amplification. Quantitative RT-PCR showed that neuroblastoma tumors with 1p36 loss expressed lower level of miR-34a than those with normal copies of 1p36. Furthermore, we demonstrated that MYCN is a direct target of miR-34a. Finally, using a series of mRNA expression profiling experiments, we identified other potential direct targets of miR-34a, and pathway analysis demonstrated that miR-34a suppresses cell-cycle genes and induces several neural-related genes. This study demonstrates one important regulatory role of miR-34a in cell growth and MYCN suppression in neuroblastoma.

Standard name | WEI_MYCN_TARGETS_WITH_E_BOX
Systematic name | M12113
Organism | Homo sapiens
PMID | 18504438
Authors | Wei JS,Song YK,Durinck S,Chen QR,Cheuk AT,Tsang P,Zhang Q,Thiele CJ,Slack A,Shohet J,Khan J
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters contain E-box motifs and whose expression changed in MYCN-3 cells (neuroblastoma) upon induction of MYCN [GeneID=4613].
Full description | Loss of 1p36 heterozygosity commonly occurs with MYCN amplification in neuroblastoma tumors, and both are associated with an aggressive phenotype. Database searches identified five microRNAs that map to the commonly deleted region of 1p36 and we hypothesized that the loss of one or more of these microRNAs contributes to the malignant phenotype of MYCN-amplified tumors. By bioinformatic analysis, we identified that three out of the five microRNAs target MYCN and of these miR-34a caused the most significant suppression of cell growth through increased apoptosis and decreased DNA synthesis in neuroblastoma cell lines with MYCN amplification. Quantitative RT-PCR showed that neuroblastoma tumors with 1p36 loss expressed lower level of miR-34a than those with normal copies of 1p36. Furthermore, we demonstrated that MYCN is a direct target of miR-34a. Finally, using a series of mRNA expression profiling experiments, we identified other potential direct targets of miR-34a, and pathway analysis demonstrated that miR-34a suppresses cell-cycle genes and induces several neural-related genes. This study demonstrates one important regulatory role of miR-34a in cell growth and MYCN suppression in neuroblastoma.

Standard name | LIAO_HAVE_SOX4_BINDING_SITES
Systematic name | M15025
Organism | Homo sapiens
PMID | 18504433
Authors | Liao YL,Sun YM,Chau GY,Chau YP,Lai TC,Wang JL,Horng JT,Hsiao M,Tsou AP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the samples with intrahepatic metastatic hepatocellular carcinoma (HCC) vs primary HCC that also have putative binding sites for SOX4 [GeneID=6659].
Full description | A comprehensive microarray analysis of hepatocellular carcinoma (HCC) revealed distinct synexpression patterns during intrahepatic metastasis. Recent evidence has demonstrated that synexpression group member genes are likely to be regulated by master control gene(s). Here we investigate the functions and gene regulation of the transcription factor SOX4 in intrahepatic metastatic HCC. SOX4 is important in tumor metastasis as RNAi knockdown reduces tumor cell migration, invasion, in vivo tumorigenesis and metastasis. A multifaceted approach integrating gene profiling, binding site computation and empirical verification by chromatin immunoprecipitation and gene ablation refined the consensus SOX4 binding motif and identified 32 binding loci in 31 genes with high confidence. RNAi knockdown of two SOX4 target genes, neuropilin 1 and semaphorin 3C, drastically reduced cell migration activity in HCC cell lines suggesting that SOX4 exerts some of its action via regulation of these two downstream targets. The discovery of 31 previously unidentified targets expands our knowledge of how SOX4 modulates HCC progression and implies a range of novel SOX4 functions. This integrated approach sets a paradigm whereby a subset of member genes from a synexpression group can be regulated by one master control gene and this is exemplified by SOX4 and advanced HCC.Oncogene advance online publication, 26 May 2008; doi:10.1038/onc.2008.168.

Standard name | LIAO_METASTASIS
Systematic name | M13809
Organism | Homo sapiens
PMID | 18504433
Authors | Liao YL,Sun YM,Chau GY,Chau YP,Lai TC,Wang JL,Horng JT,Hsiao M,Tsou AP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the samples with intrahepatic metastatic hepatocellular carcinoma (HCC) vs primary HCC.
Full description | A comprehensive microarray analysis of hepatocellular carcinoma (HCC) revealed distinct synexpression patterns during intrahepatic metastasis. Recent evidence has demonstrated that synexpression group member genes are likely to be regulated by master control gene(s). Here we investigate the functions and gene regulation of the transcription factor SOX4 in intrahepatic metastatic HCC. SOX4 is important in tumor metastasis as RNAi knockdown reduces tumor cell migration, invasion, in vivo tumorigenesis and metastasis. A multifaceted approach integrating gene profiling, binding site computation and empirical verification by chromatin immunoprecipitation and gene ablation refined the consensus SOX4 binding motif and identified 32 binding loci in 31 genes with high confidence. RNAi knockdown of two SOX4 target genes, neuropilin 1 and semaphorin 3C, drastically reduced cell migration activity in HCC cell lines suggesting that SOX4 exerts some of its action via regulation of these two downstream targets. The discovery of 31 previously unidentified targets expands our knowledge of how SOX4 modulates HCC progression and implies a range of novel SOX4 functions. This integrated approach sets a paradigm whereby a subset of member genes from a synexpression group can be regulated by one master control gene and this is exemplified by SOX4 and advanced HCC.Oncogene advance online publication, 26 May 2008; doi:10.1038/onc.2008.168.

Standard name | HASEGAWA_TUMORIGENESIS_BY_RET_C634R
Systematic name | M1334
Organism | Mus musculus
PMID | 18542059
Authors | Hasegawa T,Enomoto A,Kato T,Kawai K,Miyamoto R,Jijiwa M,Ichihara M,Ishida M,Asai N,Murakumo Y,Ohara K,Niwa Y,Goto H,Takahashi M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in salivary, thyroid and mammary gland carcinomas developed in transgenic mice carrying RET [GeneID=5979] allele with the MEN2A mutation (C634R).
Full description | Germline mutations in the RET tyrosine kinase gene are responsible for the development of multiple endocrine neoplasia 2A and 2B (MEN2A and MEN2B). However, knowledge of the fundamental principles that determine the mutant RET-mediated signaling remains elusive. Here, we report increased expression of mitogen-activated protein kinase phosphatase-2 (MKP-2) in carcinomas developed in transgenic mice carrying RET with the MEN2A mutation (RET-MEN2A). The expression of MKP-2 was not only induced by RET-MEN2A or RET-MEN2B mutant proteins but also by the activation of endogenous RET by its ligand, glial cell line-derived neurotrophic factor (GDNF). MKP-2 expression was also evident in the MKK-f cell line, which was established from a mammary tumor developed in a RET-MEN2A transgenic mouse. Inhibition of MKP-2 attenuated the in vitro and in vivo proliferation of MKK-f cells, which was mediated by the suppression of cyclin B1 expression. Furthermore, we found that MKP-2 is highly expressed in medullary thyroid carcinomas derived from MEN2A patients. These findings suggest that the increased expression of MKP-2 may play a crucial role in oncogenic signaling downstream of mutant RET, leading to deregulation of cell cycle.

Standard name | TONG_INTERACT_WITH_PTTG1
Systematic name | M3844
Organism | Homo sapiens
PMID | 18663361
Authors | Tong Y,Ben-Shlomo A,Zhou C,Wawrowsky K,Melmed S
Category | C2
Sub-category | CGP
Brief description | Proteins that interact with PTTG1 [GeneID=9232], based on protein array.
Full description | Pituitary tumor transforming gene 1 (PTTG1), a transforming gene highly expressed in several cancers, is a mammalian securin protein regulating both G1/S and G2/M phases. Using protein array screening, we showed PTTG1 interacting with Aurora kinase A (Aurora-A), and confirmed the interaction using co-immunoprecipitation, His-tagged pull-down assays and intracellular immunofluorescence colocalization. PTTG1 transfection into HCT116 cells prevented Aurora-A T288 autophosphorylation, inhibited phosphorylation of the histone H3 Aurora-A substrate and resulted in abnormally condensed chromatin. PTTG1-null cell proliferation was more sensitive to Aurora-A knock down and to Aurora kinase Inhibitor III treatment. The results indicate that PTTG1 and Aurora-A interact to regulate cellular responses to anti-neoplastic drugs. PTTG1 knockdown is therefore a potential approach to improve the efficacy of tumor Aurora kinase inhibitors.

Standard name | SCIAN_CELL_CYCLE_TARGETS_OF_TP53_AND_TP73_UP
Systematic name | M18679
Organism | Homo sapiens
PMID | 17982488
Authors | Scian MJ,Carchman EH,Mohanraj L,Stagliano KE,Anderson MA,Deb D,Crane BM,Kiyono T,Windle B,Deb SP,Deb S
Category | C2
Sub-category | CGP
Brief description | Cell cycle genes up-regulated in H1299 cells (lung cancer) after overexpression of either P53 or P73 [GeneID=7157;7161].
Full description | When normal cells come under stress, the wild-type (WT) p53 level increases resulting in the regulation of gene expression responsible for growth arrest or apoptosis. Here we show that elevated levels of WT p53 or its homologue, p73, inhibit expression of a number of cell cycle regulatory and growth promoting genes. Our analysis also identified a group of genes whose expression is differentially regulated by WT p53 and p73. We have infected p53-null H1299 human lung carcinoma cells with recombinant adenoviruses expressing WT p53, p73 or beta-galactosidase, and have undertaken microarray hybridization analyses to identify genes whose expression profile is altered by p53 or p73. Quantitative real-time PCR verified the repression of E2F-5, centromere protein A and E, minichromosome maintenance proteins (MCM)-2, -3, -5, -6 and -7 and human CDC25B after p53 expression. 5-Fluorouracil treatment of colon carcinoma HCT116 cells expressing WT p53 results in a reduction of the cyclin B2 protein level suggesting that DNA damage may indeed cause repression of these genes. Transient transcriptional assays verified that WT p53 repressed promoters of a number of these genes. Interestingly, a gain-of-function p53 mutant instead upregulated a number of these promoters in transient transfection. Using promoter deletion mutants of MCM-7 we have found that WT p53-mediated repression needs a minimal promoter that contains a single E2F site and surrounding sequences. However, a single E2F site cannot be significantly repressed by WT p53. Many of the genes identified are also repressed by p21. Thus, our work shows that WT p53 and p73 repress a number of growth-related genes and that in many instances this repression may be through the induction of p21.

Standard name | SCIAN_CELL_CYCLE_TARGETS_OF_TP53_AND_TP73_DN
Systematic name | M9402
Organism | Homo sapiens
PMID | 17982488
Authors | Scian MJ,Carchman EH,Mohanraj L,Stagliano KE,Anderson MA,Deb D,Crane BM,Kiyono T,Windle B,Deb SP,Deb S
Category | C2
Sub-category | CGP
Brief description | Cell cycle genes down-regulated in H1299 cells (lung cancer) after overexpression of either P53 or P73 [GeneID=7157;7161].
Full description | When normal cells come under stress, the wild-type (WT) p53 level increases resulting in the regulation of gene expression responsible for growth arrest or apoptosis. Here we show that elevated levels of WT p53 or its homologue, p73, inhibit expression of a number of cell cycle regulatory and growth promoting genes. Our analysis also identified a group of genes whose expression is differentially regulated by WT p53 and p73. We have infected p53-null H1299 human lung carcinoma cells with recombinant adenoviruses expressing WT p53, p73 or beta-galactosidase, and have undertaken microarray hybridization analyses to identify genes whose expression profile is altered by p53 or p73. Quantitative real-time PCR verified the repression of E2F-5, centromere protein A and E, minichromosome maintenance proteins (MCM)-2, -3, -5, -6 and -7 and human CDC25B after p53 expression. 5-Fluorouracil treatment of colon carcinoma HCT116 cells expressing WT p53 results in a reduction of the cyclin B2 protein level suggesting that DNA damage may indeed cause repression of these genes. Transient transcriptional assays verified that WT p53 repressed promoters of a number of these genes. Interestingly, a gain-of-function p53 mutant instead upregulated a number of these promoters in transient transfection. Using promoter deletion mutants of MCM-7 we have found that WT p53-mediated repression needs a minimal promoter that contains a single E2F site and surrounding sequences. However, a single E2F site cannot be significantly repressed by WT p53. Many of the genes identified are also repressed by p21. Thus, our work shows that WT p53 and p73 repress a number of growth-related genes and that in many instances this repression may be through the induction of p21.

Standard name | SCIAN_INVERSED_TARGETS_OF_TP53_AND_TP73_UP
Systematic name | M7918
Organism | Homo sapiens
PMID | 17982488
Authors | Scian MJ,Carchman EH,Mohanraj L,Stagliano KE,Anderson MA,Deb D,Crane BM,Kiyono T,Windle B,Deb SP,Deb S
Category | C2
Sub-category | CGP
Brief description | Genes that were inversely correlated in H1299 cells (lung cancer): up-regulated by P53 [GeneID=7157] and down-regulated by P73 [GeneID=7161].
Full description | When normal cells come under stress, the wild-type (WT) p53 level increases resulting in the regulation of gene expression responsible for growth arrest or apoptosis. Here we show that elevated levels of WT p53 or its homologue, p73, inhibit expression of a number of cell cycle regulatory and growth promoting genes. Our analysis also identified a group of genes whose expression is differentially regulated by WT p53 and p73. We have infected p53-null H1299 human lung carcinoma cells with recombinant adenoviruses expressing WT p53, p73 or beta-galactosidase, and have undertaken microarray hybridization analyses to identify genes whose expression profile is altered by p53 or p73. Quantitative real-time PCR verified the repression of E2F-5, centromere protein A and E, minichromosome maintenance proteins (MCM)-2, -3, -5, -6 and -7 and human CDC25B after p53 expression. 5-Fluorouracil treatment of colon carcinoma HCT116 cells expressing WT p53 results in a reduction of the cyclin B2 protein level suggesting that DNA damage may indeed cause repression of these genes. Transient transcriptional assays verified that WT p53 repressed promoters of a number of these genes. Interestingly, a gain-of-function p53 mutant instead upregulated a number of these promoters in transient transfection. Using promoter deletion mutants of MCM-7 we have found that WT p53-mediated repression needs a minimal promoter that contains a single E2F site and surrounding sequences. However, a single E2F site cannot be significantly repressed by WT p53. Many of the genes identified are also repressed by p21. Thus, our work shows that WT p53 and p73 repress a number of growth-related genes and that in many instances this repression may be through the induction of p21.

Standard name | SCIAN_INVERSED_TARGETS_OF_TP53_AND_TP73_DN
Systematic name | M8511
Organism | Homo sapiens
PMID | 17982488
Authors | Scian MJ,Carchman EH,Mohanraj L,Stagliano KE,Anderson MA,Deb D,Crane BM,Kiyono T,Windle B,Deb SP,Deb S
Category | C2
Sub-category | CGP
Brief description | Genes that were inversely correlated in H1299 cells (lung cancer): down-regulated by P53 [GeneID=7157] and up-regulated by P73 [GeneID=7161].
Full description | When normal cells come under stress, the wild-type (WT) p53 level increases resulting in the regulation of gene expression responsible for growth arrest or apoptosis. Here we show that elevated levels of WT p53 or its homologue, p73, inhibit expression of a number of cell cycle regulatory and growth promoting genes. Our analysis also identified a group of genes whose expression is differentially regulated by WT p53 and p73. We have infected p53-null H1299 human lung carcinoma cells with recombinant adenoviruses expressing WT p53, p73 or beta-galactosidase, and have undertaken microarray hybridization analyses to identify genes whose expression profile is altered by p53 or p73. Quantitative real-time PCR verified the repression of E2F-5, centromere protein A and E, minichromosome maintenance proteins (MCM)-2, -3, -5, -6 and -7 and human CDC25B after p53 expression. 5-Fluorouracil treatment of colon carcinoma HCT116 cells expressing WT p53 results in a reduction of the cyclin B2 protein level suggesting that DNA damage may indeed cause repression of these genes. Transient transcriptional assays verified that WT p53 repressed promoters of a number of these genes. Interestingly, a gain-of-function p53 mutant instead upregulated a number of these promoters in transient transfection. Using promoter deletion mutants of MCM-7 we have found that WT p53-mediated repression needs a minimal promoter that contains a single E2F site and surrounding sequences. However, a single E2F site cannot be significantly repressed by WT p53. Many of the genes identified are also repressed by p21. Thus, our work shows that WT p53 and p73 repress a number of growth-related genes and that in many instances this repression may be through the induction of p21.

Standard name | GUENTHER_GROWTH_SPHERICAL_VS_ADHERENT_UP
Systematic name | M7184
Organism | Homo sapiens
PMID | 18037961
Authors | Günther HS,Schmidt NO,Phillips HS,Kemming D,Kharbanda S,Soriano R,Modrusan Z,Meissner H,Westphal M,Lamszus K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in glioblastoma cell lines displaying spherical growth (cluster-1) compared to those displaying semiadherent or adherent growth phenotype (cluster-2).
Full description | Tumor cells with stem cell-like properties can be cultured from human glioblastomas by using conditions that select for the expansion of neural stem cells. We generated cell lines from glioblastoma specimens with the goal to obtain model systems for glioma stem cell biology. Unsupervised analysis of the expression profiles of nine cell lines established under neural stem cell conditions yielded two distinct clusters. Four cell lines were characterized by the expression of neurodevelopmental genes. They showed a multipotent differentiation profile along neuronal, astroglial and oligodendroglial lineages, grew spherically in vitro, expressed CD133 and formed highly invasive tumors in vivo. The other five cell lines shared expression signatures enriched for extracellular matrix-related genes, had a more restricted differentiation capacity, contained no or fewer CD133+ cells, grew semiadherent or adherent in vitro and displayed reduced tumorigenicity and invasion in vivo. Our findings show that stable, multipotent glioblastoma cell lines with a full stem-like phenotype express neurodevelopmental genes as a distinctive feature, which may offer therapeutic targeting opportunities. The generation of another distinct cluster of cell lines showing similarly homogeneous profiling but restricted stem cell properties suggests that different phenotypes exist, each of which may lead to the typical appearance of glioblastoma.

Standard name | GUENTHER_GROWTH_SPHERICAL_VS_ADHERENT_DN
Systematic name | M1511
Organism | Homo sapiens
PMID | 18037961
Authors | Günther HS,Schmidt NO,Phillips HS,Kemming D,Kharbanda S,Soriano R,Modrusan Z,Meissner H,Westphal M,Lamszus K
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in glioblastoma cell lines displaying spherical growth (cluster-1) compared to those displaying semiadherent or adherent growth phenotype (cluster-2).
Full description | Tumor cells with stem cell-like properties can be cultured from human glioblastomas by using conditions that select for the expansion of neural stem cells. We generated cell lines from glioblastoma specimens with the goal to obtain model systems for glioma stem cell biology. Unsupervised analysis of the expression profiles of nine cell lines established under neural stem cell conditions yielded two distinct clusters. Four cell lines were characterized by the expression of neurodevelopmental genes. They showed a multipotent differentiation profile along neuronal, astroglial and oligodendroglial lineages, grew spherically in vitro, expressed CD133 and formed highly invasive tumors in vivo. The other five cell lines shared expression signatures enriched for extracellular matrix-related genes, had a more restricted differentiation capacity, contained no or fewer CD133+ cells, grew semiadherent or adherent in vitro and displayed reduced tumorigenicity and invasion in vivo. Our findings show that stable, multipotent glioblastoma cell lines with a full stem-like phenotype express neurodevelopmental genes as a distinctive feature, which may offer therapeutic targeting opportunities. The generation of another distinct cluster of cell lines showing similarly homogeneous profiling but restricted stem cell properties suggests that different phenotypes exist, each of which may lead to the typical appearance of glioblastoma.

Standard name | SCHWAB_TARGETS_OF_BMYB_POLYMORPHIC_VARIANTS_UP
Systematic name | M9811
Organism | Homo sapiens
PMID | 18026132
Authors | Schwab R,Bussolari R,Corvetta D,Chayka O,Santilli G,Kwok JM,Ferrari-Amorotti G,Tonini GP,Iacoviello L,Bertorelle R,Menin C,Hubank M,Calabretta B,Sala A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 293 cells (embryonic kidney) expressing polymorphic variants S427G (SNP ID=rs2070235) or I624M (SNP ID=rs11556379) of BMYB [GeneID=4605].
Full description | The B-MYB proto-oncogene is a transcription factor belonging to the MYB family that is frequently overexpressed or amplified in different types of human malignancies. While it is suspected that B-MYB plays a role in human cancer, there is still no direct evidence of its causative role. Looking for mutations of the B-MYB gene in human cell lines and primary cancer samples, we frequently isolated two nonsynonymous B-MYB polymorphic variants (rs2070235 and rs11556379). Compared to the wild-type protein, the B-MYB isoforms display altered conformation, impaired regulation of target genes and decreased antiapoptotic activity, suggesting that they are hypomorphic variants of the major allele. Importantly, the B-MYB polymorphisms are common; rs2070235 and rs11556379 are found, depending on the ethnic background, in 10-50% of human subjects. We postulated that, if B-MYB activity is important for transformation, the presence of common, hypomorphic variants might modify cancer risk. Indeed, the B-MYB polymorphisms are underrepresented in 419 cancer patients compared to 230 controls (odds ratio 0.53; (95%) confidence interval 0.385-0.755; P=0.001). This data imply that a large fraction of the human population is carrier of B-MYB alleles that might be associated with a reduced risk of developing neoplastic disease.

Standard name | SCHWAB_TARGETS_OF_BMYB_POLYMORPHIC_VARIANTS_DN
Systematic name | M10651
Organism | Homo sapiens
PMID | 18026132
Authors | Schwab R,Bussolari R,Corvetta D,Chayka O,Santilli G,Kwok JM,Ferrari-Amorotti G,Tonini GP,Iacoviello L,Bertorelle R,Menin C,Hubank M,Calabretta B,Sala A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 293 cells (embryonic kidney) expressing polymorphic variants S427G (SNP ID=rs2070235) or I624M (SNP ID=rs11556379) of BMYB [GeneID=4605].
Full description | The B-MYB proto-oncogene is a transcription factor belonging to the MYB family that is frequently overexpressed or amplified in different types of human malignancies. While it is suspected that B-MYB plays a role in human cancer, there is still no direct evidence of its causative role. Looking for mutations of the B-MYB gene in human cell lines and primary cancer samples, we frequently isolated two nonsynonymous B-MYB polymorphic variants (rs2070235 and rs11556379). Compared to the wild-type protein, the B-MYB isoforms display altered conformation, impaired regulation of target genes and decreased antiapoptotic activity, suggesting that they are hypomorphic variants of the major allele. Importantly, the B-MYB polymorphisms are common; rs2070235 and rs11556379 are found, depending on the ethnic background, in 10-50% of human subjects. We postulated that, if B-MYB activity is important for transformation, the presence of common, hypomorphic variants might modify cancer risk. Indeed, the B-MYB polymorphisms are underrepresented in 419 cancer patients compared to 230 controls (odds ratio 0.53; (95%) confidence interval 0.385-0.755; P=0.001). This data imply that a large fraction of the human population is carrier of B-MYB alleles that might be associated with a reduced risk of developing neoplastic disease.

Standard name | GOUYER_TATI_TARGETS_UP
Systematic name | M589
Organism | Homo sapiens
PMID | 18317448
Authors | Gouyer V,Fontaine D,Dumont P,de Wever O,Fontayne-Devaud H,Leteurtre E,Truant S,Delacour D,Drobecq H,Kerckaert JP,de Launoit Y,Bracke M,Gespach C,Desseyn JL,Huet G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in constitutively invasive HT-29 5M21 cells (colon cancer) vs those expressing functionally inactive TATI [GeneID=6690].
Full description | From the conditioned medium of the human colon carcinoma cells, HT-29 5M21 (CM-5M21), expressing a spontaneous invasive phenotype, tumor-associated trypsin inhibitor (TATI) was identified and characterized by proteomics, cDNA microarray approaches and functional analyses. Both CM-5M21 and recombinant TATI, but not the K18Y-TATI mutant at the protease inhibitor site, trigger collagen type I invasion by several human adenoma and carcinoma cells of the colon and breast, through phosphoinositide-3-kinase, protein kinase C and Rho-GTPases/Rho kinase-dependent pathways. Conversely, the proinvasive action of TATI in parental HT29 cells was alleviated by the TATI antibody PSKAN2 and the K18Y-TATI mutant. Stable expression of K18Y-TATI in HT-29 5M21 cells downregulated tumor growth, angiogenesis and the expression of several metastasis-related genes, including CSPG4 (13.8-fold), BMP-7 (9.7-fold), the BMP antagonist CHORDIN (5.2-fold), IGFBP-2 and IGF2 (9.6- and 4.6-fold). Accordingly, ectopic expression of KY-TATI inhibited the development of lung metastases from HT-29 5M21 tumor xenografts in immunodeficient mice. These findings identify TATI as an autocrine transforming factor potentially involved in early and late events of colon cancer progression, including local invasion of the primary tumor and its metastatic spread. Targeting TATI, its molecular partners and effectors may bring novel therapeutic applications for high-grade human solid tumors in the digestive and urogenital systems.

Standard name | GOUYER_TATI_TARGETS_DN
Systematic name | M3697
Organism | Homo sapiens
PMID | 18317448
Authors | Gouyer V,Fontaine D,Dumont P,de Wever O,Fontayne-Devaud H,Leteurtre E,Truant S,Delacour D,Drobecq H,Kerckaert JP,de Launoit Y,Bracke M,Gespach C,Desseyn JL,Huet G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in constitutively invasive HT-29 5M21 cells (colon cancer) vs those expressing functionally inactive TATI [GeneID=6690].
Full description | From the conditioned medium of the human colon carcinoma cells, HT-29 5M21 (CM-5M21), expressing a spontaneous invasive phenotype, tumor-associated trypsin inhibitor (TATI) was identified and characterized by proteomics, cDNA microarray approaches and functional analyses. Both CM-5M21 and recombinant TATI, but not the K18Y-TATI mutant at the protease inhibitor site, trigger collagen type I invasion by several human adenoma and carcinoma cells of the colon and breast, through phosphoinositide-3-kinase, protein kinase C and Rho-GTPases/Rho kinase-dependent pathways. Conversely, the proinvasive action of TATI in parental HT29 cells was alleviated by the TATI antibody PSKAN2 and the K18Y-TATI mutant. Stable expression of K18Y-TATI in HT-29 5M21 cells downregulated tumor growth, angiogenesis and the expression of several metastasis-related genes, including CSPG4 (13.8-fold), BMP-7 (9.7-fold), the BMP antagonist CHORDIN (5.2-fold), IGFBP-2 and IGF2 (9.6- and 4.6-fold). Accordingly, ectopic expression of KY-TATI inhibited the development of lung metastases from HT-29 5M21 tumor xenografts in immunodeficient mice. These findings identify TATI as an autocrine transforming factor potentially involved in early and late events of colon cancer progression, including local invasion of the primary tumor and its metastatic spread. Targeting TATI, its molecular partners and effectors may bring novel therapeutic applications for high-grade human solid tumors in the digestive and urogenital systems.

Standard name | CAFFAREL_RESPONSE_TO_THC_UP
Systematic name | M11298
Organism | Homo sapiens
PMID | 18454173
Authors | Caffarel MM,Moreno-Bueno G,Cerutti C,Palacios J,Guzman M,Mechta-Grigoriou F,Sanchez C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in EVSA-T cells (breast cancer) treated THC (delta-9-tetrahydrocannabinol) [PubChem=6610319].
Full description | It has been recently shown that cannabinoids, the active components of marijuana and their derivatives, inhibit cell cycle progression of human breast cancer cells. Here we studied the mechanism of Delta(9)-tetrahydrocannabinol (THC) antiproliferative action in these cells, and show that it involves the modulation of JunD, a member of the AP-1 transcription factor family. THC activates JunD both by upregulating gene expression and by translocating the protein to the nuclear compartment, and these events are accompanied by a decrease in cell proliferation. Of interest, neither JunD activation nor proliferation inhibition was observed in human non-tumour mammary epithelial cells exposed to THC. We confirmed the importance of JunD in THC action by RNA interference and genetic ablation. Thus, in both JunD-silenced human breast cancer cells and JunD knockout mice-derived immortalized fibroblasts, the antiproliferative effect exerted by THC was significantly diminished. Gene array and siRNA experiments support that the cyclin-dependent kinase inhibitor p27 and the tumour suppressor gene testin are candidate JunD targets in cannabinoid action. In addition, our data suggest that the stress-regulated protein p8 participates in THC antiproliferative action in a JunD-independent manner. In summary, this is the first report showing not only that cannabinoids regulate JunD but, more generally, that JunD activation reduces the proliferation of cancer cells, which points to a new target to inhibit breast cancer progression.

Standard name | CAFFAREL_RESPONSE_TO_THC_DN
Systematic name | M17998
Organism | Homo sapiens
PMID | 18454173
Authors | Caffarel MM,Moreno-Bueno G,Cerutti C,Palacios J,Guzman M,Mechta-Grigoriou F,Sanchez C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in EVSA-T cells (breast cancer) treated THC (delta-9-tetrahydrocannabinol) [PubChem=6610319].
Full description | It has been recently shown that cannabinoids, the active components of marijuana and their derivatives, inhibit cell cycle progression of human breast cancer cells. Here we studied the mechanism of Delta(9)-tetrahydrocannabinol (THC) antiproliferative action in these cells, and show that it involves the modulation of JunD, a member of the AP-1 transcription factor family. THC activates JunD both by upregulating gene expression and by translocating the protein to the nuclear compartment, and these events are accompanied by a decrease in cell proliferation. Of interest, neither JunD activation nor proliferation inhibition was observed in human non-tumour mammary epithelial cells exposed to THC. We confirmed the importance of JunD in THC action by RNA interference and genetic ablation. Thus, in both JunD-silenced human breast cancer cells and JunD knockout mice-derived immortalized fibroblasts, the antiproliferative effect exerted by THC was significantly diminished. Gene array and siRNA experiments support that the cyclin-dependent kinase inhibitor p27 and the tumour suppressor gene testin are candidate JunD targets in cannabinoid action. In addition, our data suggest that the stress-regulated protein p8 participates in THC antiproliferative action in a JunD-independent manner. In summary, this is the first report showing not only that cannabinoids regulate JunD but, more generally, that JunD activation reduces the proliferation of cancer cells, which points to a new target to inhibit breast cancer progression.

Standard name | CAFFAREL_RESPONSE_TO_THC_8HR_5_UP
Systematic name | M17987
Organism | Homo sapiens
PMID | 18454173
Authors | Caffarel MM,Moreno-Bueno G,Cerutti C,Palacios J,Guzman M,Mechta-Grigoriou F,Sanchez C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in EVSA-T cells (breast cancer) treated with 5 micromolar THC (delta-9-tetrahydrocannabinol) [PubChem=6610319] for 8 h.
Full description | It has been recently shown that cannabinoids, the active components of marijuana and their derivatives, inhibit cell cycle progression of human breast cancer cells. Here we studied the mechanism of Delta(9)-tetrahydrocannabinol (THC) antiproliferative action in these cells, and show that it involves the modulation of JunD, a member of the AP-1 transcription factor family. THC activates JunD both by upregulating gene expression and by translocating the protein to the nuclear compartment, and these events are accompanied by a decrease in cell proliferation. Of interest, neither JunD activation nor proliferation inhibition was observed in human non-tumour mammary epithelial cells exposed to THC. We confirmed the importance of JunD in THC action by RNA interference and genetic ablation. Thus, in both JunD-silenced human breast cancer cells and JunD knockout mice-derived immortalized fibroblasts, the antiproliferative effect exerted by THC was significantly diminished. Gene array and siRNA experiments support that the cyclin-dependent kinase inhibitor p27 and the tumour suppressor gene testin are candidate JunD targets in cannabinoid action. In addition, our data suggest that the stress-regulated protein p8 participates in THC antiproliferative action in a JunD-independent manner. In summary, this is the first report showing not only that cannabinoids regulate JunD but, more generally, that JunD activation reduces the proliferation of cancer cells, which points to a new target to inhibit breast cancer progression.

Standard name | CAFFAREL_RESPONSE_TO_THC_8HR_5_DN
Systematic name | M2260
Organism | Homo sapiens
PMID | 18454173
Authors | Caffarel MM,Moreno-Bueno G,Cerutti C,Palacios J,Guzman M,Mechta-Grigoriou F,Sanchez C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in EVSA-T cells (breast cancer) treated with 5 micromolar THC (delta-9-tetrahydrocannabinol) [PubChem=6610319] for 8 h.
Full description | It has been recently shown that cannabinoids, the active components of marijuana and their derivatives, inhibit cell cycle progression of human breast cancer cells. Here we studied the mechanism of Delta(9)-tetrahydrocannabinol (THC) antiproliferative action in these cells, and show that it involves the modulation of JunD, a member of the AP-1 transcription factor family. THC activates JunD both by upregulating gene expression and by translocating the protein to the nuclear compartment, and these events are accompanied by a decrease in cell proliferation. Of interest, neither JunD activation nor proliferation inhibition was observed in human non-tumour mammary epithelial cells exposed to THC. We confirmed the importance of JunD in THC action by RNA interference and genetic ablation. Thus, in both JunD-silenced human breast cancer cells and JunD knockout mice-derived immortalized fibroblasts, the antiproliferative effect exerted by THC was significantly diminished. Gene array and siRNA experiments support that the cyclin-dependent kinase inhibitor p27 and the tumour suppressor gene testin are candidate JunD targets in cannabinoid action. In addition, our data suggest that the stress-regulated protein p8 participates in THC antiproliferative action in a JunD-independent manner. In summary, this is the first report showing not only that cannabinoids regulate JunD but, more generally, that JunD activation reduces the proliferation of cancer cells, which points to a new target to inhibit breast cancer progression.

Standard name | CAFFAREL_RESPONSE_TO_THC_8HR_3_UP
Systematic name | M1335
Organism | Homo sapiens
PMID | 18454173
Authors | Caffarel MM,Moreno-Bueno G,Cerutti C,Palacios J,Guzman M,Mechta-Grigoriou F,Sanchez C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in EVSA-T cells (breast cancer) treated with 3 micromolar THC (delta-9-tetrahydrocannabinol) [PubChem=6610319] for 8 h.
Full description | It has been recently shown that cannabinoids, the active components of marijuana and their derivatives, inhibit cell cycle progression of human breast cancer cells. Here we studied the mechanism of Delta(9)-tetrahydrocannabinol (THC) antiproliferative action in these cells, and show that it involves the modulation of JunD, a member of the AP-1 transcription factor family. THC activates JunD both by upregulating gene expression and by translocating the protein to the nuclear compartment, and these events are accompanied by a decrease in cell proliferation. Of interest, neither JunD activation nor proliferation inhibition was observed in human non-tumour mammary epithelial cells exposed to THC. We confirmed the importance of JunD in THC action by RNA interference and genetic ablation. Thus, in both JunD-silenced human breast cancer cells and JunD knockout mice-derived immortalized fibroblasts, the antiproliferative effect exerted by THC was significantly diminished. Gene array and siRNA experiments support that the cyclin-dependent kinase inhibitor p27 and the tumour suppressor gene testin are candidate JunD targets in cannabinoid action. In addition, our data suggest that the stress-regulated protein p8 participates in THC antiproliferative action in a JunD-independent manner. In summary, this is the first report showing not only that cannabinoids regulate JunD but, more generally, that JunD activation reduces the proliferation of cancer cells, which points to a new target to inhibit breast cancer progression.

Standard name | CAFFAREL_RESPONSE_TO_THC_8HR_3_DN
Systematic name | M14648
Organism | Homo sapiens
PMID | 18454173
Authors | Caffarel MM,Moreno-Bueno G,Cerutti C,Palacios J,Guzman M,Mechta-Grigoriou F,Sanchez C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in EVSA-T cells (breast cancer) treated with 3 micromolar THC (delta-9-tetrahydrocannabinol) [PubChem=6610319] for 8 h.
Full description | It has been recently shown that cannabinoids, the active components of marijuana and their derivatives, inhibit cell cycle progression of human breast cancer cells. Here we studied the mechanism of Delta(9)-tetrahydrocannabinol (THC) antiproliferative action in these cells, and show that it involves the modulation of JunD, a member of the AP-1 transcription factor family. THC activates JunD both by upregulating gene expression and by translocating the protein to the nuclear compartment, and these events are accompanied by a decrease in cell proliferation. Of interest, neither JunD activation nor proliferation inhibition was observed in human non-tumour mammary epithelial cells exposed to THC. We confirmed the importance of JunD in THC action by RNA interference and genetic ablation. Thus, in both JunD-silenced human breast cancer cells and JunD knockout mice-derived immortalized fibroblasts, the antiproliferative effect exerted by THC was significantly diminished. Gene array and siRNA experiments support that the cyclin-dependent kinase inhibitor p27 and the tumour suppressor gene testin are candidate JunD targets in cannabinoid action. In addition, our data suggest that the stress-regulated protein p8 participates in THC antiproliferative action in a JunD-independent manner. In summary, this is the first report showing not only that cannabinoids regulate JunD but, more generally, that JunD activation reduces the proliferation of cancer cells, which points to a new target to inhibit breast cancer progression.

Standard name | CAFFAREL_RESPONSE_TO_THC_24HR_3_UP
Systematic name | M7465
Organism | Homo sapiens
PMID | 18454173
Authors | Caffarel MM,Moreno-Bueno G,Cerutti C,Palacios J,Guzman M,Mechta-Grigoriou F,Sanchez C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in EVSA-T cells (breast cancer) after treatment with 3 micromolar THC (delta-9-tetrahydrocannabinol) [PubChem=6610319] for 24 h.
Full description | It has been recently shown that cannabinoids, the active components of marijuana and their derivatives, inhibit cell cycle progression of human breast cancer cells. Here we studied the mechanism of Delta(9)-tetrahydrocannabinol (THC) antiproliferative action in these cells, and show that it involves the modulation of JunD, a member of the AP-1 transcription factor family. THC activates JunD both by upregulating gene expression and by translocating the protein to the nuclear compartment, and these events are accompanied by a decrease in cell proliferation. Of interest, neither JunD activation nor proliferation inhibition was observed in human non-tumour mammary epithelial cells exposed to THC. We confirmed the importance of JunD in THC action by RNA interference and genetic ablation. Thus, in both JunD-silenced human breast cancer cells and JunD knockout mice-derived immortalized fibroblasts, the antiproliferative effect exerted by THC was significantly diminished. Gene array and siRNA experiments support that the cyclin-dependent kinase inhibitor p27 and the tumour suppressor gene testin are candidate JunD targets in cannabinoid action. In addition, our data suggest that the stress-regulated protein p8 participates in THC antiproliferative action in a JunD-independent manner. In summary, this is the first report showing not only that cannabinoids regulate JunD but, more generally, that JunD activation reduces the proliferation of cancer cells, which points to a new target to inhibit breast cancer progression.

Standard name | CAFFAREL_RESPONSE_TO_THC_24HR_3_DN
Systematic name | M5574
Organism | Homo sapiens
PMID | 18454173
Authors | Caffarel MM,Moreno-Bueno G,Cerutti C,Palacios J,Guzman M,Mechta-Grigoriou F,Sanchez C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in EVSA-T cells (breast cancer) after treatment with 3 micromolar THC (delta-9-tetrahydrocannabinol) [PubChem=6610319] for 24 h.
Full description | It has been recently shown that cannabinoids, the active components of marijuana and their derivatives, inhibit cell cycle progression of human breast cancer cells. Here we studied the mechanism of Delta(9)-tetrahydrocannabinol (THC) antiproliferative action in these cells, and show that it involves the modulation of JunD, a member of the AP-1 transcription factor family. THC activates JunD both by upregulating gene expression and by translocating the protein to the nuclear compartment, and these events are accompanied by a decrease in cell proliferation. Of interest, neither JunD activation nor proliferation inhibition was observed in human non-tumour mammary epithelial cells exposed to THC. We confirmed the importance of JunD in THC action by RNA interference and genetic ablation. Thus, in both JunD-silenced human breast cancer cells and JunD knockout mice-derived immortalized fibroblasts, the antiproliferative effect exerted by THC was significantly diminished. Gene array and siRNA experiments support that the cyclin-dependent kinase inhibitor p27 and the tumour suppressor gene testin are candidate JunD targets in cannabinoid action. In addition, our data suggest that the stress-regulated protein p8 participates in THC antiproliferative action in a JunD-independent manner. In summary, this is the first report showing not only that cannabinoids regulate JunD but, more generally, that JunD activation reduces the proliferation of cancer cells, which points to a new target to inhibit breast cancer progression.

Standard name | CAFFAREL_RESPONSE_TO_THC_24HR_5_UP
Systematic name | M13585
Organism | Homo sapiens
PMID | 18454173
Authors | Caffarel MM,Moreno-Bueno G,Cerutti C,Palacios J,Guzman M,Mechta-Grigoriou F,Sanchez C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in EVSA-T cells (breast cancer) treated with 5 micromolar THC (delta-9-tetrahydrocannabinol) [PubChem=6610319] for 24 h.
Full description | It has been recently shown that cannabinoids, the active components of marijuana and their derivatives, inhibit cell cycle progression of human breast cancer cells. Here we studied the mechanism of Delta(9)-tetrahydrocannabinol (THC) antiproliferative action in these cells, and show that it involves the modulation of JunD, a member of the AP-1 transcription factor family. THC activates JunD both by upregulating gene expression and by translocating the protein to the nuclear compartment, and these events are accompanied by a decrease in cell proliferation. Of interest, neither JunD activation nor proliferation inhibition was observed in human non-tumour mammary epithelial cells exposed to THC. We confirmed the importance of JunD in THC action by RNA interference and genetic ablation. Thus, in both JunD-silenced human breast cancer cells and JunD knockout mice-derived immortalized fibroblasts, the antiproliferative effect exerted by THC was significantly diminished. Gene array and siRNA experiments support that the cyclin-dependent kinase inhibitor p27 and the tumour suppressor gene testin are candidate JunD targets in cannabinoid action. In addition, our data suggest that the stress-regulated protein p8 participates in THC antiproliferative action in a JunD-independent manner. In summary, this is the first report showing not only that cannabinoids regulate JunD but, more generally, that JunD activation reduces the proliferation of cancer cells, which points to a new target to inhibit breast cancer progression.

Standard name | CAFFAREL_RESPONSE_TO_THC_24HR_5_DN
Systematic name | M17042
Organism | Homo sapiens
PMID | 18454173
Authors | Caffarel MM,Moreno-Bueno G,Cerutti C,Palacios J,Guzman M,Mechta-Grigoriou F,Sanchez C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in EVSA-T cells (breast cancer) treated with 5 micromolar THC (delta-9-tetrahydrocannabinol) [PubChem=6610319] for 24 h.
Full description | It has been recently shown that cannabinoids, the active components of marijuana and their derivatives, inhibit cell cycle progression of human breast cancer cells. Here we studied the mechanism of Delta(9)-tetrahydrocannabinol (THC) antiproliferative action in these cells, and show that it involves the modulation of JunD, a member of the AP-1 transcription factor family. THC activates JunD both by upregulating gene expression and by translocating the protein to the nuclear compartment, and these events are accompanied by a decrease in cell proliferation. Of interest, neither JunD activation nor proliferation inhibition was observed in human non-tumour mammary epithelial cells exposed to THC. We confirmed the importance of JunD in THC action by RNA interference and genetic ablation. Thus, in both JunD-silenced human breast cancer cells and JunD knockout mice-derived immortalized fibroblasts, the antiproliferative effect exerted by THC was significantly diminished. Gene array and siRNA experiments support that the cyclin-dependent kinase inhibitor p27 and the tumour suppressor gene testin are candidate JunD targets in cannabinoid action. In addition, our data suggest that the stress-regulated protein p8 participates in THC antiproliferative action in a JunD-independent manner. In summary, this is the first report showing not only that cannabinoids regulate JunD but, more generally, that JunD activation reduces the proliferation of cancer cells, which points to a new target to inhibit breast cancer progression.

Standard name | RANKIN_ANGIOGENIC_TARGETS_OF_VHL_HIF2A_UP
Systematic name | M1336
Organism | Mus musculus
PMID | 18490920
Authors | Rankin EB,Rha J,Unger TL,Wu CH,Shutt HP,Johnson RS,Simon MC,Keith B,Haase VH
Category | C2
Sub-category | CGP
Brief description | Angiogenic genes up-regulated in hepatocytes after knockout of VHL and HIF2A [GeneID=7428;2034].
Full description | The von Hippel-Lindau tumor suppressor pVHL regulates the stability of hypoxia-inducible factors (HIF)-1 and -2, oxygen-sensitive basic helix-loop-helix transcription factors, which mediate the hypoxic induction of angiogenic growth factors such as vascular endothelial growth factor. Loss of pVHL function results in constitutive activation of HIF-1 and HIF-2 and is associated with the development of highly vascularized tumors in multiple organs. We have used a conditional gene-targeting approach to investigate the relative contributions of HIF-1 and HIF-2 to VHL-associated vascular tumorigenesis in a mouse model of liver hemangiomas. Here we demonstrate genetically that conditional inactivation of HIF-2alpha suppressed the development of VHL-associated liver hemangiomas and that angiogenic gene expression in hepatocytes is predominantly regulated by HIF-2 and not by HIF-1. These findings suggest that HIF-2 is the dominant HIF in the pathogenesis of VHL-associated vascular tumors and that pharmacologic targeting of HIF-2 may be an effective strategy for their treatment.

Standard name | RANKIN_ANGIOGENIC_TARGETS_OF_VHL_HIF2A_DN
Systematic name | M1337
Organism | Mus musculus
PMID | 18490920
Authors | Rankin EB,Rha J,Unger TL,Wu CH,Shutt HP,Johnson RS,Simon MC,Keith B,Haase VH
Category | C2
Sub-category | CGP
Brief description | Angiogenic genes down-regulated in hepatocytes after knockout of VHL and HIF2A [GeneID=7428;2034].
Full description | The von Hippel-Lindau tumor suppressor pVHL regulates the stability of hypoxia-inducible factors (HIF)-1 and -2, oxygen-sensitive basic helix-loop-helix transcription factors, which mediate the hypoxic induction of angiogenic growth factors such as vascular endothelial growth factor. Loss of pVHL function results in constitutive activation of HIF-1 and HIF-2 and is associated with the development of highly vascularized tumors in multiple organs. We have used a conditional gene-targeting approach to investigate the relative contributions of HIF-1 and HIF-2 to VHL-associated vascular tumorigenesis in a mouse model of liver hemangiomas. Here we demonstrate genetically that conditional inactivation of HIF-2alpha suppressed the development of VHL-associated liver hemangiomas and that angiogenic gene expression in hepatocytes is predominantly regulated by HIF-2 and not by HIF-1. These findings suggest that HIF-2 is the dominant HIF in the pathogenesis of VHL-associated vascular tumors and that pharmacologic targeting of HIF-2 may be an effective strategy for their treatment.

Standard name | BERTUCCI_INVASIVE_CARCINOMA_DUCTAL_VS_LOBULAR_UP
Systematic name | M16424
Organism | Homo sapiens
PMID | 18490921
Authors | Bertucci F,Orsetti B,Nègre V,Finetti P,Rougé C,Ahomadegbe JC,Bibeau F,Mathieu MC,Treilleux I,Jacquemier J,Ursule L,Martinec A,Wang Q,Bénard J,Puisieux A,Birnbaum D,Theillet C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the invasive ductal carcinoma (IDC) compared to the invasive lobular carcinoma (ILC), the two major pathological types of breast cancer.
Full description | Invasive ductal carcinomas (IDCs) and invasive lobular carcinomas (ILCs) are the two major pathological types of breast cancer. Epidemiological and histoclinical data suggest biological differences, but little is known about the molecular alterations involved in ILCs. We undertook a comparative large-scale study by both array-compared genomic hybridization and cDNA microarray of a set of 50 breast tumors (21 classic ILCs and 29 IDCs) selected on homogeneous histoclinical criteria. Results were validated on independent tumor sets, as well as by quantitative RT-PCR. ILCs and IDCs presented differences at both the genomic and expression levels with ILCs being less rearranged and heterogeneous than IDCs. Supervised analysis defined a 75-BACs signature discriminating accurately ILCs from IDCs. Expression profiles identified two subgroups of ILCs: typical ILCs ( approximately 50%), which were homogeneous and displayed a normal-like molecular pattern, and atypical ILCs, more heterogeneous with features intermediate between ILCs and IDCs. Supervised analysis identified a 75-gene expression signature that discriminated ILCs from IDCs, with many genes involved in cell adhesion, motility, apoptosis, protein folding, extracellular matrix and protein phosphorylation. Although ILCs and IDCs share common alterations, our data show that ILCs and IDCs could be distinguished on the basis of their genomic and expression profiles suggesting that they evolve along distinct genetic pathways.

Standard name | BERTUCCI_INVASIVE_CARCINOMA_DUCTAL_VS_LOBULAR_DN
Systematic name | M14142
Organism | Homo sapiens
PMID | 18490921
Authors | Bertucci F,Orsetti B,Nègre V,Finetti P,Rougé C,Ahomadegbe JC,Bibeau F,Mathieu MC,Treilleux I,Jacquemier J,Ursule L,Martinec A,Wang Q,Bénard J,Puisieux A,Birnbaum D,Theillet C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the invasive ductal carcinoma (IDC) compared to the invasive lobular carcinoma (ILC), the two major pathological types of breast cancer.
Full description | Invasive ductal carcinomas (IDCs) and invasive lobular carcinomas (ILCs) are the two major pathological types of breast cancer. Epidemiological and histoclinical data suggest biological differences, but little is known about the molecular alterations involved in ILCs. We undertook a comparative large-scale study by both array-compared genomic hybridization and cDNA microarray of a set of 50 breast tumors (21 classic ILCs and 29 IDCs) selected on homogeneous histoclinical criteria. Results were validated on independent tumor sets, as well as by quantitative RT-PCR. ILCs and IDCs presented differences at both the genomic and expression levels with ILCs being less rearranged and heterogeneous than IDCs. Supervised analysis defined a 75-BACs signature discriminating accurately ILCs from IDCs. Expression profiles identified two subgroups of ILCs: typical ILCs ( approximately 50%), which were homogeneous and displayed a normal-like molecular pattern, and atypical ILCs, more heterogeneous with features intermediate between ILCs and IDCs. Supervised analysis identified a 75-gene expression signature that discriminated ILCs from IDCs, with many genes involved in cell adhesion, motility, apoptosis, protein folding, extracellular matrix and protein phosphorylation. Although ILCs and IDCs share common alterations, our data show that ILCs and IDCs could be distinguished on the basis of their genomic and expression profiles suggesting that they evolve along distinct genetic pathways.

Standard name | SUH_COEXPRESSED_WITH_ID1_AND_ID2_UP
Systematic name | M13616
Organism | Homo sapiens
PMID | 18542061
Authors | Suh HC,Leeanansaksiri W,Ji M,Klarmann KD,Renn K,Gooya J,Smith D,McNiece I,Lugthart S,Valk PJ,Delwel R,Keller JR
Category | C2
Sub-category | CGP
Brief description | Genes whose expression positively correlates with that of both ID1 and ID2 [GeneID=3397;3398] genes in a cohort of 285 patients with primaly AML (acule myelogenous leukemia) [PMID=15084694].
Full description | Id1 is frequently overexpressed in many cancer cells, but the functional significance of these findings is not known. To determine if Id1 could contribute to the development of hematopoietic malignancy, we reconstituted mice with hematopoietic cells overexpressing Id1. We showed for the first time that deregulated expression of Id1 leads to a myeloproliferative disease in mice, and immortalizes myeloid progenitors in vitro. In human cells, we demonstrate that Id genes are expressed in human acute myelogenous leukemia cells, and that knock down of Id1 expression inhibits leukemic cell line growth, suggesting that Id1 is required for leukemic cell proliferation. These findings established a causal relationship between Id1 overexpression and hematologic malignancy. Thus, deregulated expression of Id1 may contribute to the initiation of myeloid malignancy, and Id1 may represent a potential therapeutic target for early stage intervention in the treatment of hematopoietic malignancy.Oncogene advance online publication, 9 June 2008; doi:10.1038/onc.2008.175.

Standard name | WOTTON_RUNX_TARGETS_UP
Systematic name | M11756
Organism | Mus musculus
PMID | 18560354
Authors | Wotton S,Terry A,Kilbey A,Jenkins A,Herzyk P,Cameron E,Neil JC
Category | C2
Sub-category | CGP
Brief description | Common target genes up-regulated by all three Runx family members (RUNX1, RUNX2, and RUNX3 [GeneID=861;860;864]) in MEF cells (embryonic fibroblasts).
Full description | The Runx genes are important in development and cancer, where they can act either as oncogenes or tumour suppressors. We compared the effects of ectopic Runx expression in established fibroblasts, where all three genes produce an indistinguishable phenotype entailing epithelioid morphology and increased cell survival under stress conditions. Gene array analysis revealed a strongly overlapping transcriptional signature, with no examples of opposing regulation of the same target gene. A common set of 50 highly regulated genes was identified after further filtering on regulation by inducible RUNX1-ER. This set revealed a strong bias toward genes with annotated roles in cancer and development, and a preponderance of targets encoding extracellular or surface proteins, reflecting the marked effects of Runx on cell adhesion. Furthermore, in silico prediction of resistance to glucocorticoid growth inhibition was confirmed in fibroblasts and lymphoid cells expressing ectopic Runx. The effects of fibroblast expression of common RUNX1 fusion oncoproteins (RUNX1-ETO, TEL-RUNX1 and CBFB-MYH11) were also tested. Although two direct Runx activation target genes were repressed (Ncam1 and Rgc32), the fusion proteins appeared to disrupt the regulation of downregulated targets (Cebpd, Id2 and Rgs2) rather than impose constitutive repression. These results elucidate the oncogenic potential of the Runx family and reveal novel targets for therapeutic inhibition.

Standard name | WOTTON_RUNX_TARGETS_DN
Systematic name | M4303
Organism | Mus musculus
PMID | 18560354
Authors | Wotton S,Terry A,Kilbey A,Jenkins A,Herzyk P,Cameron E,Neil JC
Category | C2
Sub-category | CGP
Brief description | Common target genes down-regulated by all three Runx family members (RUNX1, RUNX2, and RUNX3 [GeneID=861;860;864]) in MEF cells (embryonic fibroblasts).
Full description | The Runx genes are important in development and cancer, where they can act either as oncogenes or tumour suppressors. We compared the effects of ectopic Runx expression in established fibroblasts, where all three genes produce an indistinguishable phenotype entailing epithelioid morphology and increased cell survival under stress conditions. Gene array analysis revealed a strongly overlapping transcriptional signature, with no examples of opposing regulation of the same target gene. A common set of 50 highly regulated genes was identified after further filtering on regulation by inducible RUNX1-ER. This set revealed a strong bias toward genes with annotated roles in cancer and development, and a preponderance of targets encoding extracellular or surface proteins, reflecting the marked effects of Runx on cell adhesion. Furthermore, in silico prediction of resistance to glucocorticoid growth inhibition was confirmed in fibroblasts and lymphoid cells expressing ectopic Runx. The effects of fibroblast expression of common RUNX1 fusion oncoproteins (RUNX1-ETO, TEL-RUNX1 and CBFB-MYH11) were also tested. Although two direct Runx activation target genes were repressed (Ncam1 and Rgc32), the fusion proteins appeared to disrupt the regulation of downregulated targets (Cebpd, Id2 and Rgs2) rather than impose constitutive repression. These results elucidate the oncogenic potential of the Runx family and reveal novel targets for therapeutic inhibition.

Standard name | FUJIWARA_PARK2_HEPATOCYTE_PROLIFERATION_UP
Systematic name | M1338
Organism | Mus musculus
PMID | 18574468
Authors | Fujiwara M,Marusawa H,Wang HQ,Iwai A,Ikeuchi K,Imai Y,Kataoka A,Nukina N,Takahashi R,Chiba T
Category | C2
Sub-category | CGP
Brief description | Genes commonly up-regulated in both non-tumorous and tumorous liver tissues of PARK2 [GeneID=5071] knockout mice.
Full description | The parkin was first identified as a gene implicated in autosomal recessive juvenile Parkinsonism. Deregulation of the parkin gene, however, has been observed in various human cancers, suggesting that the parkin gene may be important in tumorigenesis. To gain insight into the physiologic role of parkin, we generated parkin-/- mice lacking exon 3 of the parkin gene. We demonstrated here that parkin-/- mice had enhanced hepatocyte proliferation and developed macroscopic hepatic tumors with the characteristics of hepatocellular carcinoma. Microarray analyses revealed that parkin deficiency caused the alteration of gene expression profiles in the liver. Among them, endogenous follistatin is commonly upregulated in both nontumorous and tumorous liver tissues of parkin-deficient mice. Parkin deficiency resulted in suppression of caspase activation and rendered hepatocytes resistant to apoptosis in a follistatin-dependent manner. These results suggested that parkin deficiency caused enhanced hepatocyte proliferation and resistance to apoptosis, resulting in hepatic tumor development, partially through the upregulation of endogenous follistatin. The finding that parkin-deficient mice are susceptible to hepatocarcinogenesis provided the first evidence showing that parkin is indeed a tumor suppressor gene.

Standard name | FUJIWARA_PARK2_HEPATOCYTE_PROLIFERATION_DN
Systematic name | M1342
Organism | Mus musculus
PMID | 18574468
Authors | Fujiwara M,Marusawa H,Wang HQ,Iwai A,Ikeuchi K,Imai Y,Kataoka A,Nukina N,Takahashi R,Chiba T
Category | C2
Sub-category | CGP
Brief description | Genes commonly down-regulated in both non-tumorous and tumorous liver tissues of PARK2 [GeneID=5071] knockout mice.
Full description | The parkin was first identified as a gene implicated in autosomal recessive juvenile Parkinsonism. Deregulation of the parkin gene, however, has been observed in various human cancers, suggesting that the parkin gene may be important in tumorigenesis. To gain insight into the physiologic role of parkin, we generated parkin-/- mice lacking exon 3 of the parkin gene. We demonstrated here that parkin-/- mice had enhanced hepatocyte proliferation and developed macroscopic hepatic tumors with the characteristics of hepatocellular carcinoma. Microarray analyses revealed that parkin deficiency caused the alteration of gene expression profiles in the liver. Among them, endogenous follistatin is commonly upregulated in both nontumorous and tumorous liver tissues of parkin-deficient mice. Parkin deficiency resulted in suppression of caspase activation and rendered hepatocytes resistant to apoptosis in a follistatin-dependent manner. These results suggested that parkin deficiency caused enhanced hepatocyte proliferation and resistance to apoptosis, resulting in hepatic tumor development, partially through the upregulation of endogenous follistatin. The finding that parkin-deficient mice are susceptible to hepatocarcinogenesis provided the first evidence showing that parkin is indeed a tumor suppressor gene.

Standard name | FUJIWARA_PARK2_IN_LIVER_CANCER_UP
Systematic name | M1343
Organism | Mus musculus
PMID | 18574468
Authors | Fujiwara M,Marusawa H,Wang HQ,Iwai A,Ikeuchi K,Imai Y,Kataoka A,Nukina N,Takahashi R,Chiba T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in tumorous liver tissues from PARK2 [GeneID=5071] knockout mice compared to the normal, non-tumorous tissue from wild type mice.
Full description | The parkin was first identified as a gene implicated in autosomal recessive juvenile Parkinsonism. Deregulation of the parkin gene, however, has been observed in various human cancers, suggesting that the parkin gene may be important in tumorigenesis. To gain insight into the physiologic role of parkin, we generated parkin-/- mice lacking exon 3 of the parkin gene. We demonstrated here that parkin-/- mice had enhanced hepatocyte proliferation and developed macroscopic hepatic tumors with the characteristics of hepatocellular carcinoma. Microarray analyses revealed that parkin deficiency caused the alteration of gene expression profiles in the liver. Among them, endogenous follistatin is commonly upregulated in both nontumorous and tumorous liver tissues of parkin-deficient mice. Parkin deficiency resulted in suppression of caspase activation and rendered hepatocytes resistant to apoptosis in a follistatin-dependent manner. These results suggested that parkin deficiency caused enhanced hepatocyte proliferation and resistance to apoptosis, resulting in hepatic tumor development, partially through the upregulation of endogenous follistatin. The finding that parkin-deficient mice are susceptible to hepatocarcinogenesis provided the first evidence showing that parkin is indeed a tumor suppressor gene.

Standard name | FUJIWARA_PARK2_IN_LIVER_CANCER_DN
Systematic name | M1344
Organism | Mus musculus
PMID | 18574468
Authors | Fujiwara M,Marusawa H,Wang HQ,Iwai A,Ikeuchi K,Imai Y,Kataoka A,Nukina N,Takahashi R,Chiba T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in tumorous liver tissues from PARK2 [GeneID=5071] knockout mice compared to the normal, non-tumorous tissue from wild type mice.
Full description | The parkin was first identified as a gene implicated in autosomal recessive juvenile Parkinsonism. Deregulation of the parkin gene, however, has been observed in various human cancers, suggesting that the parkin gene may be important in tumorigenesis. To gain insight into the physiologic role of parkin, we generated parkin-/- mice lacking exon 3 of the parkin gene. We demonstrated here that parkin-/- mice had enhanced hepatocyte proliferation and developed macroscopic hepatic tumors with the characteristics of hepatocellular carcinoma. Microarray analyses revealed that parkin deficiency caused the alteration of gene expression profiles in the liver. Among them, endogenous follistatin is commonly upregulated in both nontumorous and tumorous liver tissues of parkin-deficient mice. Parkin deficiency resulted in suppression of caspase activation and rendered hepatocytes resistant to apoptosis in a follistatin-dependent manner. These results suggested that parkin deficiency caused enhanced hepatocyte proliferation and resistance to apoptosis, resulting in hepatic tumor development, partially through the upregulation of endogenous follistatin. The finding that parkin-deficient mice are susceptible to hepatocarcinogenesis provided the first evidence showing that parkin is indeed a tumor suppressor gene.

Standard name | GARCIA_TARGETS_OF_FLI1_AND_DAX1_UP
Systematic name | M6117
Organism | Homo sapiens
PMID | 18591936
Authors | García-Aragoncillo E,Carrillo J,Lalli E,Agra N,Gómez-López G,Pestaña A,Alonso J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the A673 cells (Ewing sarcoma) after double knockdown of both FLI1 and DAX1 [GeneID=2313;190] by RNAi.
Full description | The molecular hallmark of the Ewing's family of tumors is the presence of balanced chromosomal translocations, leading to the formation of chimerical transcription factors (that is, EWS/FLI1) that play a pivotal role in the pathogenesis of Ewing's tumors by deregulating gene expression. We have recently demonstrated that DAX1 (NR0B1), an orphan nuclear receptor that was not previously implicated in cancer, is induced by the EWS/FLI1 oncoprotein and is highly expressed in Ewing's tumors, suggesting that DAX1 is a biologically relevant target of EWS/FLI1-mediated oncogenesis. In this study we demonstrate that DAX1 is a direct transcriptional target of the EWS/FLI1 oncoprotein through its binding to a GGAA-rich region in the DAX1 promoter and show that DAX1 is a key player of EWS/FLI1-mediated oncogenesis. DAX1 silencing using an inducible model of RNA interference induces growth arrest in the A673 Ewing's cell line and severely impairs its capability to grow in semisolid medium and form tumors in immunodeficient mice. Gene expression profile analysis demonstrated that about 10% of the genes regulated by EWS/FLI1 in Ewing's cells are DAX1 targets, confirming the importance of DAX1 in Ewing's oncogenesis. Functional genomic analysis, validated by quantitative RT-PCR, showed that genes implicated in cell-cycle progression, such as CDK2, CDC6, MCM10 or SKP2 were similarly regulated by EWS/FLI1 and DAX1. These findings indicate that DAX1 is important in the pathogenesis of the Ewing's family of tumors, identify new functions for DAX1 as a cell-cycle progression regulator and open the possibility to new therapeutic approaches based on DAX1 function interference.

Standard name | GARCIA_TARGETS_OF_FLI1_AND_DAX1_DN
Systematic name | M13844
Organism | Homo sapiens
PMID | 18591936
Authors | García-Aragoncillo E,Carrillo J,Lalli E,Agra N,Gómez-López G,Pestaña A,Alonso J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the A673 cells (Ewing sarcoma) after double knockdown of both FLI1 and DAX1 [GeneID=2313;190] by RNAi.
Full description | The molecular hallmark of the Ewing's family of tumors is the presence of balanced chromosomal translocations, leading to the formation of chimerical transcription factors (that is, EWS/FLI1) that play a pivotal role in the pathogenesis of Ewing's tumors by deregulating gene expression. We have recently demonstrated that DAX1 (NR0B1), an orphan nuclear receptor that was not previously implicated in cancer, is induced by the EWS/FLI1 oncoprotein and is highly expressed in Ewing's tumors, suggesting that DAX1 is a biologically relevant target of EWS/FLI1-mediated oncogenesis. In this study we demonstrate that DAX1 is a direct transcriptional target of the EWS/FLI1 oncoprotein through its binding to a GGAA-rich region in the DAX1 promoter and show that DAX1 is a key player of EWS/FLI1-mediated oncogenesis. DAX1 silencing using an inducible model of RNA interference induces growth arrest in the A673 Ewing's cell line and severely impairs its capability to grow in semisolid medium and form tumors in immunodeficient mice. Gene expression profile analysis demonstrated that about 10% of the genes regulated by EWS/FLI1 in Ewing's cells are DAX1 targets, confirming the importance of DAX1 in Ewing's oncogenesis. Functional genomic analysis, validated by quantitative RT-PCR, showed that genes implicated in cell-cycle progression, such as CDK2, CDC6, MCM10 or SKP2 were similarly regulated by EWS/FLI1 and DAX1. These findings indicate that DAX1 is important in the pathogenesis of the Ewing's family of tumors, identify new functions for DAX1 as a cell-cycle progression regulator and open the possibility to new therapeutic approaches based on DAX1 function interference.

Standard name | RICKMAN_TUMOR_DIFFERENTIATED_WELL_VS_POORLY_UP
Systematic name | M904
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes that vary between HNSCC (head and neck squamous cell carcinoma) groups formed on the basis of their level of pathological differentiation: well vs poorly differentiated tumors.
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_TUMOR_DIFFERENTIATED_WELL_VS_POORLY_DN
Systematic name | M12527
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes that vary between HNSCC (head and neck squamous cell carcinoma) groups formed on the basis of their level of pathological differentiation: well vs poorly differentiated tumors.
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_TUMOR_DIFFERENTIATED_WELL_VS_MODERATELY_UP
Systematic name | M7141
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes that vary between HNSCC (head and neck squamous cell carcinoma) groups formed on the basis of their level of pathological differentiation: well vs moderately differentiated tumors.
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_TUMOR_DIFFERENTIATED_WELL_VS_MODERATELY_DN
Systematic name | M9524
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes that vary between HNSCC (head and neck squamous cell carcinoma) groups formed on the basis of their level of pathological differentiation: well vs moderately differentiated tumors.
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_TUMOR_DIFFERENTIATED_MODERATELY_VS_POORLY_UP
Systematic name | M15672
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes that vary between HNSCC (head and neck squamous cell carcinoma) groups formed on the basis of their level of pathological differentiation: moderately vs poorly differentiated tumors.
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_TUMOR_DIFFERENTIATED_MODERATELY_VS_POORLY_DN
Systematic name | M17006
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes that vary between HNSCC (head and neck squamous cell carcinoma) groups formed on the basis of their level of pathological differentiation: moderately vs poorly differentiated tumors.
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_METASTASIS_UP
Systematic name | M9752
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in metastatic vs non-metastatic HNSCC (head and neck squamous cell carcinoma) samples.
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_METASTASIS_DN
Systematic name | M12369
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in metastatic vs non-metastatic HNSCC (head and neck squamous cell carcinoma) samples.
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | FRIDMAN_SENESCENCE_UP
Systematic name | M9143
Organism | Homo sapiens
PMID | 18711403
Authors | Fridman AL,Tainsky MA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in senescent cells.
Full description | Bypassing cellular senescence and becoming immortal is a prerequisite step in the tumorigenic transformation of a cell. It has long been known that loss of a key tumor suppressor gene, such as p53, is necessary, but not sufficient, for spontaneous cellular immortalization. Therefore, there must be additional mutations and/or epigenetic alterations required for immortalization to occur. Early work on these processes included somatic cell genetic studies to estimate the number of senescence genes, and microcell-mediated transfer of chromosomes into immortalized cells to identify putative senescence-inducing genetic loci. These principal studies laid the foundation for the field of senescence/immortalization, but were labor intensive and the results were somewhat limited. The advent of gene expression profiling and bioinformatics analysis greatly facilitated the identification of genes and pathways that regulate cellular senescence/immortalization. In this review, we present the findings of several gene expression profiling studies and supporting functional data, where available. We identified universal genes regulating senescence/immortalization and found that the key regulator genes represented six pathways: the cell cycle pRB/p53, cytoskeletal, interferon-related, insulin growth factor-related, MAP kinase and oxidative stress pathway. The identification of the genes and pathways regulating senescence/immortalization could provide novel molecular targets for the treatment and/or prevention of cancer.

Standard name | FRIDMAN_SENESCENCE_DN
Systematic name | M9487
Organism | Homo sapiens
PMID | 18711403
Authors | Fridman AL,Tainsky MA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in senescent cells.
Full description | Bypassing cellular senescence and becoming immortal is a prerequisite step in the tumorigenic transformation of a cell. It has long been known that loss of a key tumor suppressor gene, such as p53, is necessary, but not sufficient, for spontaneous cellular immortalization. Therefore, there must be additional mutations and/or epigenetic alterations required for immortalization to occur. Early work on these processes included somatic cell genetic studies to estimate the number of senescence genes, and microcell-mediated transfer of chromosomes into immortalized cells to identify putative senescence-inducing genetic loci. These principal studies laid the foundation for the field of senescence/immortalization, but were labor intensive and the results were somewhat limited. The advent of gene expression profiling and bioinformatics analysis greatly facilitated the identification of genes and pathways that regulate cellular senescence/immortalization. In this review, we present the findings of several gene expression profiling studies and supporting functional data, where available. We identified universal genes regulating senescence/immortalization and found that the key regulator genes represented six pathways: the cell cycle pRB/p53, cytoskeletal, interferon-related, insulin growth factor-related, MAP kinase and oxidative stress pathway. The identification of the genes and pathways regulating senescence/immortalization could provide novel molecular targets for the treatment and/or prevention of cancer.

Standard name | FRIDMAN_IMMORTALIZATION_DN
Systematic name | M7404
Organism | Homo sapiens
PMID | 18711403
Authors | Fridman AL,Tainsky MA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in immortalized cell lines.
Full description | Bypassing cellular senescence and becoming immortal is a prerequisite step in the tumorigenic transformation of a cell. It has long been known that loss of a key tumor suppressor gene, such as p53, is necessary, but not sufficient, for spontaneous cellular immortalization. Therefore, there must be additional mutations and/or epigenetic alterations required for immortalization to occur. Early work on these processes included somatic cell genetic studies to estimate the number of senescence genes, and microcell-mediated transfer of chromosomes into immortalized cells to identify putative senescence-inducing genetic loci. These principal studies laid the foundation for the field of senescence/immortalization, but were labor intensive and the results were somewhat limited. The advent of gene expression profiling and bioinformatics analysis greatly facilitated the identification of genes and pathways that regulate cellular senescence/immortalization. In this review, we present the findings of several gene expression profiling studies and supporting functional data, where available. We identified universal genes regulating senescence/immortalization and found that the key regulator genes represented six pathways: the cell cycle pRB/p53, cytoskeletal, interferon-related, insulin growth factor-related, MAP kinase and oxidative stress pathway. The identification of the genes and pathways regulating senescence/immortalization could provide novel molecular targets for the treatment and/or prevention of cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_6HR_UP
Systematic name | M1346
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the urogenital sinus (UGS) of day E16 females exposed to the androgen dihydrotestosterone [PubChem=10635] for 6 h.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_6HR_DN
Systematic name | M1347
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the urogenital sinus (UGS) of day E16 females exposed to the androgen dihydrotestosterone [PubChem=10635] for 6 h.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_12HR_UP
Systematic name | M1348
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the urogenital sinus (UGS) of day E16 females exposed to the androgen dihydrotestosterone [PubChem=10635] for 12 h.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_12HR_DN
Systematic name | M1349
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the urogenital sinus (UGS) of day E16 females exposed to the androgen dihydrotestosterone [PubChem=10635] for 12 h.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_48HR_UP
Systematic name | M1350
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the urogenital sinus (UGS) of day E16 females exposed to the androgen dihydrotestosterone [PubChem=10635] for 48 h.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_48HR_DN
Systematic name | M1351
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the urogenital sinus (UGS) of day E16 females exposed to the androgen dihydrotestosterone [PubChem=10635] for 48 h.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX1_UP
Systematic name | M1353
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (up-regulated at 6 h dihydrotestosterone [PubChem=10635]) which are also up-regulated in normal epithelium vs high grade prostatic intraepithelial neoplasia (PIN).
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX1_DN
Systematic name | M1355
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (down-regulated at 6 h dihydrotestosterone [PubChem=10635]) which are also down-regulated in normal epithelium vs high grade prostatic intraepithelial neoplasia (PIN).
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX2_UP
Systematic name | M1356
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (up-regulated at 6 hr dihydrotestosterone [PubChem=10635]) which are also up-regulated in high grade prostatic intraepithelial neoplasia (PIN) vs invasive cancer.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX2_DN
Systematic name | M1357
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (down-regulated at 6 hr dihydrotestosterone [PubChem=10635]) which are also down-regulated in high grade prostatic intraepithelial neoplasia (PIN) vs invasive cancer.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX4_UP
Systematic name | M1358
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (up-regulated at 6 hr dihydrotestosterone [PubChem=10635]) which are also up-regulated in localized vs metastatic prostate cancers.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX4_DN
Systematic name | M1359
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (down-regulated at 6 hr dihydrotestosterone [PubChem=10635]) which are also down-regulated in localized vs metastatic prostate cancers.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX5_UP
Systematic name | M1362
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (up-regulated at 12 hr dihydrotestosterone [PubChem=10635]) which are also up-regulated in high grade prostatic intraepithelial neoplasia (PIN) vs invasive cancer.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX5_DN
Systematic name | M1363
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (down-regulated at 12 hr dihydrotestosterone [PubChem=10635]) which are also down-regulated in high grade prostatic intraepithelial neoplasia (PIN) vs invasive cancer.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX6_UP
Systematic name | M1364
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (up-regulated at 48 hr dihydrotestosterone [PubChem=10635]) which are also up-regulated in high grade prostatic intraepithelial neoplasia (PIN) vs invasive cancer.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX6_DN
Systematic name | M1366
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (down-regulated at 48 hr dihydrotestosterone [PubChem=10635]) which are also down-regulated in high grade prostatic intraepithelial neoplasia (PIN) vs invasive cancer.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_SOX9_TARGETS_IN_PROSTATE_DEVELOPMENT_UP
Systematic name | M1368
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Predicted targets of SOX9 [GeneID=6662] that are up-regulated during early prostate development.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | SCHAEFFER_SOX9_TARGETS_IN_PROSTATE_DEVELOPMENT_DN
Systematic name | M1369
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Predicted targets of SOX9 [GeneID=6662] that are down-regulated during early prostate development.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | KOYAMA_SEMA3B_TARGETS_UP
Systematic name | M12746
Organism | Homo sapiens
PMID | 18985860
Authors | Koyama N,Zhang J,Huqun,Miyazawa H,Tanaka T,Su X,Hagiwara K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NCI-H1299 cells (large cell neuroendocrine carcinoma) stably expressing SEMA3B [GeneID=7869].
Full description | SEMA3B, a member of class 3 semaphorins, is a tumor suppressor. Competition with vascular endothelial growth factor (VEGF)165 explains a portion of the activity, whereas the VEGF-independent mechanism was not elucidated. We employed a microarray and screened for the genes whose expression was increased by SEMA3B in NCI-H1299 cells. Insulin-like growth factor-binding protein-6 (IGFBP-6), a tumor suppressor, showed greatest difference in the expression level. Introduction of IGFBP-6 cDNA reduced colony formation both on the dish surface and in soft agar. Insulin-like growth factor II, which antagonizes IGFBP-6, partly abrogated the effect. Inhibition of IGFBP-6 by small interfering RNA diminished the sub-G0/G1 population that was induced by SEMA3B and abrogated the growth suppressive effect of SEMA3B. We concluded that IGFBP-6 is the effector of tumor suppressor activity of SEMA3B in NCI-H1299 cells. It has been reported that beta-catenin suppresses the expression of IGFBP-6. Introduction of beta-catenin into the cells partly abrogated the growth suppressive effect of SEMA3B. Our result indicates that semaphorin signaling and beta-catenin signaling converge on IGFBP-6 and antithetically affect their functions.

Standard name | KOYAMA_SEMA3B_TARGETS_DN
Systematic name | M2029
Organism | Homo sapiens
PMID | 18985860
Authors | Koyama N,Zhang J,Huqun,Miyazawa H,Tanaka T,Su X,Hagiwara K
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NCI-H1299 cells (large cell neuroendocrine carcinoma) stably expressing SEMA3B [GeneID=7869].
Full description | SEMA3B, a member of class 3 semaphorins, is a tumor suppressor. Competition with vascular endothelial growth factor (VEGF)165 explains a portion of the activity, whereas the VEGF-independent mechanism was not elucidated. We employed a microarray and screened for the genes whose expression was increased by SEMA3B in NCI-H1299 cells. Insulin-like growth factor-binding protein-6 (IGFBP-6), a tumor suppressor, showed greatest difference in the expression level. Introduction of IGFBP-6 cDNA reduced colony formation both on the dish surface and in soft agar. Insulin-like growth factor II, which antagonizes IGFBP-6, partly abrogated the effect. Inhibition of IGFBP-6 by small interfering RNA diminished the sub-G0/G1 population that was induced by SEMA3B and abrogated the growth suppressive effect of SEMA3B. We concluded that IGFBP-6 is the effector of tumor suppressor activity of SEMA3B in NCI-H1299 cells. It has been reported that beta-catenin suppresses the expression of IGFBP-6. Introduction of beta-catenin into the cells partly abrogated the growth suppressive effect of SEMA3B. Our result indicates that semaphorin signaling and beta-catenin signaling converge on IGFBP-6 and antithetically affect their functions.

Standard name | RICKMAN_HEAD_AND_NECK_CANCER_A
Systematic name | M14228
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Cluster a: genes identifying an intrinsic group in head and neck squamous cell carcinoma (HNSCC).
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | SCHAEFFER_PROSTATE_DEVELOPMENT_AND_CANCER_BOX3
Systematic name | M1371
Organism | Mus musculus
PMID | 18794802
Authors | Schaeffer EM,Marchionni L,Huang Z,Simons B,Blackman A,Yu W,Parmigiani G,Berman DM
Category | C2
Sub-category | CGP
Brief description | Early prostate development genes (up-regulated at 6 hr dihydrotestosterone [PubChem=10635]) which are also up-regulated in lower grade vs higher grade locally invasive prostate cancers.
Full description | Cancer cells differentiate along specific lineages that largely determine their clinical and biologic behavior. Distinct cancer phenotypes from different cells and organs likely result from unique gene expression repertoires established in the embryo and maintained after malignant transformation. We used comprehensive gene expression analysis to examine this concept in the prostate, an organ with a tractable developmental program and a high propensity for cancer. We focused on gene expression in the murine prostate rudiment at three time points during the first 48 h of exposure to androgen, which initiates proliferation and invasion of prostate epithelial buds into surrounding urogenital sinus mesenchyme. Here, we show that androgen exposure regulates genes previously implicated in prostate carcinogenesis comprising pathways for the phosphatase and tensin homolog (PTEN), fibroblast growth factor (FGF)/mitogen-activated protein kinase (MAPK), and Wnt signaling along with cellular programs regulating such 'hallmarks' of cancer as angiogenesis, apoptosis, migration and proliferation. We found statistically significant evidence for novel androgen-induced gene regulation events that establish and/or maintain prostate cell fate. These include modulation of gene expression through microRNAs, expression of specific transcription factors, and regulation of their predicted targets. By querying public gene expression databases from other tissues, we found that rather than generally characterizing androgen exposure or epithelial budding, the early prostate development program more closely resembles the program for human prostate cancer. Most importantly, early androgen-regulated genes and functional themes associated with prostate development were highly enriched in contrasts between increasingly lethal forms of prostate cancer, confirming a 'reactivation' of embryonic pathways for proliferation and invasion in prostate cancer progression. Among the genes with the most significant links to the development and cancer, we highlight coordinate induction of the transcription factor Sox9 and suppression of the proapoptotic phospholipid-binding protein Annexin A1 that link early prostate development to early prostate carcinogenesis. These results credential early prostate development as a reliable and valid model system for the investigation of genes and pathways that drive prostate cancer.

Standard name | RICKMAN_HEAD_AND_NECK_CANCER_B
Systematic name | M7727
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Cluster b: genes identifying an intrinsic group in head and neck squamous cell carcinoma (HNSCC).
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_HEAD_AND_NECK_CANCER_C
Systematic name | M16130
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Cluster c: genes identifying an intrinsic group in head and neck squamous cell carcinoma (HNSCC).
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_HEAD_AND_NECK_CANCER_D
Systematic name | M19164
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Cluster d: genes identifying an intrinsic group in head and neck squamous cell carcinoma (HNSCC).
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_HEAD_AND_NECK_CANCER_E
Systematic name | M19837
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Cluster e: genes identifying an intrinsic group in head and neck squamous cell carcinoma (HNSCC).
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | RICKMAN_HEAD_AND_NECK_CANCER_F
Systematic name | M2043
Organism | Homo sapiens
PMID | 18679425
Authors | Rickman DS,Millon R,De Reynies A,Thomas E,Wasylyk C,Muller D,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Cluster f: genes identifying an intrinsic group in head and neck squamous cell carcinoma (HNSCC).
Full description | Propensity for subsequent distant metastasis in head and neck squamous-cell carcinoma (HNSCC) was analysed using 186 primary tumours from patients initially treated by surgery that developed (M) or did not develop (NM) metastases as the first recurrent event. Transcriptome (Affymetrix HGU133_Plus2, QRT-PCR) and array-comparative genomic hybridization data were collected. Non-supervised hierarchical clustering based on Affymetrix data distinguished tumours differing in pathological differentiation, and identified associated functional changes. Propensity for metastasis was not associated with these subgroups. Using QRT-PCR data we identified a four-gene model (PSMD10, HSD17B12, FLOT2 and KRT17) that predicts M/NM status with 77% success in a separate 79-sample validation group of HNSCC samples. This prediction is independent of clinical criteria (age, lymph node status, stage, differentiation and localization). The most significantly altered transcripts in M versus NM were significantly associated to metastasis-related functions, including adhesion, mobility and cell survival. Several genomic modifications were significantly associated with M/NM status (most notably gains at 4q11-22 and Xq12-28; losses at 11q14-24 and 17q11 losses) and partly linked to transcription modifications. This work yields a basis for the development of prognostic molecular signatures, markers and therapeutic targets for HNSCC metastasis.

Standard name | WU_CELL_MIGRATION
Systematic name | M2001
Organism | Homo sapiens
PMID | 18724390
Authors | Wu Y,Siadaty MS,Berens ME,Hampton GM,Theodorescu D
Category | C2
Sub-category | CGP
Brief description | Genes associated with migration rate of 40 human bladder cancer cells.
Full description | Cell migration is essential to cancer invasion and metastasis and is spatially and temporally integrated through transcriptionally dependent and independent mechanisms. As cell migration is studied in vitro, it is important to identify genes that both drive cell migration and are biologically relevant in promoting invasion and metastasis in patients with cancer. Here, gene expression profiling and a high-throughput cell migration system answers this question in human bladder cancer. In vitro migration rates of 40 microarray-profiled human bladder cancer cell lines were measured by radial migration assay. Genes whose expression was either directly or inversely associated with cell migration rate were identified and subsequently evaluated for their association with cancer stage in 61 patients. This analysis identified genes known to be associated with cell invasion such as versican, and novel ones, including metallothionein 1E (MT1E) and nicotinamide N-methyltransferase (NNMT), whose expression correlated positively with cancer cell migration and tumor stage. Using loss of function analysis, we show that MT1E and NNMT are necessary for cancer cell migration. These studies provide a general approach to identify the clinically relevant genes in cancer cell migration and mechanistically implicate two novel genes in this process in human bladder cancer.

Standard name | TAGHAVI_NEOPLASTIC_TRANSFORMATION
Systematic name | M9267
Organism | Mus musculus
PMID | 18762810
Authors | Taghavi P,Verhoeven E,Jacobs JJ,Lambooij JP,Stortelers C,Tanger E,Moolenaar WH,van Lohuizen M
Category | C2
Sub-category | CGP
Brief description | Genes that cooperate with MYC and TBX2 [GeneID=4609;6909] to transform MEF cells (embryo fibroblasts).
Full description | c-Myc drives uncontrolled cell proliferation in various human cancers. However, in mouse embryo fibroblasts (MEFs), c-Myc also induces apoptosis by activating the p19Arf tumor suppressor pathway. Tbx2, a transcriptional repressor of p19Arf, can collaborate with c-Myc by suppressing apoptosis. MEFs overexpressing c-Myc and Tbx2 are immortal but not transformed. We have performed an unbiased genetic screen, which identified 12 oncogenes that collaborate with c-Myc and Tbx2 to transform MEFs in vitro. One of them encodes the LPA2 receptor for the lipid growth factor lysophosphatidic acid (LPA). We find that LPA1 and LPA4, but not LPA3, can reproduce the transforming effect of LPA2. Using pharmacological inhibitors, we show that the in vitro cell transformation induced by LPA receptors is dependent on the Gi-linked ERK and PI3K signaling pathways. The transforming ability of LPA1, LPA2 and LPA4 was confirmed by tumor formation assays in vivo and correlated with prolonged ERK1/2 activation in response to LPA. Our results reveal a direct role for LPA receptor signaling in cell transformation and tumorigenesis in conjunction with c-Myc and reduced p19Arf expression.

Standard name | COLIN_PILOCYTIC_ASTROCYTOMA_VS_GLIOBLASTOMA_UP
Systematic name | M11581
Organism | Homo sapiens
PMID | 16314830
Authors | Colin C,Baeza N,Bartoli C,Fina F,Eudes N,Nanni I,Martin PM,Ouafik L,Figarella-Branger D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pilocytic astrocytoma compared to glioblastoma samples.
Full description | Glioblastoma (GBM) is a highly malignant glioma, which has the propensity to infiltrate throughout the brain in contrast to pilocytic astrocytoma (PA) of the posterior fossa, which does not spread and can be cured by surgery. We have used Suppression Subtractive Hybridization to define markers that better delineate the molecular basis of brain invasion and distinguish these tumor groups. We have identified 106 genes expressed in PA versus GBM and 80 genes expressed in GBM versus PA. Subsequent analysis identified a subset of 20 transcripts showing a common differential expression pattern for the two groups. GBM differs from PA by the expression of five genes involved in invasion and angiogenesis: fibronectin, osteopontin, chitinase-3-like-1 (YKL-40), keratoepithelin and fibromodulin. PA differs from GBM by the expression of genes related to metabolism (apolipoprotein D), proteolysis (protease-serine-11), receptor and signal transduction (PLEKHB1 for Pleckstrin-Homology-domain-containing-protein-family-B-member-1), transcription/translation (eukaryotic-translation-elongation-factor-1-alpha1) processes and cell adhesion (SPOCK1 for SPARC/Osteonectin-CWCV-kazal-like-domains-proteoglycan). The expression of these genes was confirmed by real-time quantitative RT-PCR and immunohistochemistry. This study highlights the crucial role of brain invasion in GBM and identifies specific molecules involved in this process. In addition, it offers a restricted list of markers that accurately distinguish PA from GBM.

Standard name | COLIN_PILOCYTIC_ASTROCYTOMA_VS_GLIOBLASTOMA_DN
Systematic name | M14859
Organism | Homo sapiens
PMID | 16314830
Authors | Colin C,Baeza N,Bartoli C,Fina F,Eudes N,Nanni I,Martin PM,Ouafik L,Figarella-Branger D
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pilocytic astrocytoma compared to glioblastoma samples.
Full description | Glioblastoma (GBM) is a highly malignant glioma, which has the propensity to infiltrate throughout the brain in contrast to pilocytic astrocytoma (PA) of the posterior fossa, which does not spread and can be cured by surgery. We have used Suppression Subtractive Hybridization to define markers that better delineate the molecular basis of brain invasion and distinguish these tumor groups. We have identified 106 genes expressed in PA versus GBM and 80 genes expressed in GBM versus PA. Subsequent analysis identified a subset of 20 transcripts showing a common differential expression pattern for the two groups. GBM differs from PA by the expression of five genes involved in invasion and angiogenesis: fibronectin, osteopontin, chitinase-3-like-1 (YKL-40), keratoepithelin and fibromodulin. PA differs from GBM by the expression of genes related to metabolism (apolipoprotein D), proteolysis (protease-serine-11), receptor and signal transduction (PLEKHB1 for Pleckstrin-Homology-domain-containing-protein-family-B-member-1), transcription/translation (eukaryotic-translation-elongation-factor-1-alpha1) processes and cell adhesion (SPOCK1 for SPARC/Osteonectin-CWCV-kazal-like-domains-proteoglycan). The expression of these genes was confirmed by real-time quantitative RT-PCR and immunohistochemistry. This study highlights the crucial role of brain invasion in GBM and identifies specific molecules involved in this process. In addition, it offers a restricted list of markers that accurately distinguish PA from GBM.

Standard name | BALDWIN_PRKCI_TARGETS_UP
Systematic name | M16912
Organism | Homo sapiens
PMID | 16331246
Authors | Baldwin RM,Garratt-Lalonde M,Parolin DA,Krzyzanowski PM,Andrade MA,Lorimer IA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in U87MG cells (glioblastoma multiforme) after knockdown of PRKCI [GeneID=5584] by RNAi.
Full description | Glioblastoma multiforme is an aggressive form of brain cancer that responds poorly to chemotherapy and is generally incurable. The basis for the poor response of this cancer to chemotherapy is not well understood. The atypical protein kinases C (PKCiota and PKCzeta) have previously been implicated in leukaemia cell chemoresistance. To assess the role of atypical PKC in glioblastoma cell chemoresistance, RNA interference was used to deplete human glioblastoma cells of PKCiota. Transfection of cells with either of two different RNA duplexes specific for PKCiota caused a partial sensitisation to cell death induced by the chemotherapy agent cisplatin. To screen for possible mechanisms for PKCiota-mediated chemoresistance, microarray analysis of gene expression was performed on RNA from glioblastoma cells that were either untreated or depleted of PKCiota. This identified sets of genes that were regulated either positively or negatively by PKCiota. Within the set of genes that were negatively regulated by PKCiota, the function of the gene coding for GMFbeta, an enhancer of p38 mitogen-activated protein kinase (MAP kinase) signaling, was investigated further, as the p38 MAP kinase pathway has been previously identified as a key mediator of cisplatin cytotoxicity. The expression of both GMFbeta mRNA and protein increased upon PKCiota depletion, and this was accompanied by an increase in cisplatin-activated p38 MAP kinase signaling. Transient overexpression of GMFbeta increased cisplatin-activated p38 MAP kinase signaling and also sensitised cells to cisplatin cytotoxicity. The increase in cisplatin cytotoxicity seen with PKCiota depletion was blocked by the p38 MAP kinase inhibitor SKF86002. These data show that PKCiota can confer partial resistance to cisplatin in glioblastoma cells by suppressing GMFbeta-mediated enhancement of p38 MAP kinase signaling.

Standard name | GOTZMANN_EPITHELIAL_TO_MESENCHYMAL_TRANSITION_UP
Systematic name | M1373
Organism | Mus musculus
PMID | 16607286
Authors | Gotzmann J,Fischer AN,Zojer M,Mikula M,Proell V,Huber H,Jechlinger M,Waerner T,Weith A,Beug H,Mikulits W
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MMH-RT cells (hepatocytes displaying an invasive, metastatic phenotype) during epithelial to mesenchymal transition (EMT).
Full description | Polarized hepatocytes expressing hyperactive Ha-Ras adopt an invasive and metastatic phenotype in cooperation with transforming growth factor (TGF)-beta. This dramatic increase in malignancy is displayed by an epithelial to mesenchymal transition (EMT), which mimics the TGF-beta-mediated progression of human hepatocellular carcinomas. In culture, hepatocellular EMT occurs highly synchronously, facilitating the analysis of molecular events underlying the various stages of this process. Here, we show that in response to TGF-beta, phosphorylated Smads rapidly translocated into the nucleus and activated transcription of target genes such as E-cadherin repressors of the Snail superfamily, causing loss of cell adhesion. Within the TGF-beta superfamily of cytokines, TGF-beta1, -beta2 and -beta3 were specific for the induction of hepatocellular EMT. Expression profiling of EMT kinetics revealed 78 up- and 235 downregulated genes, which preferentially modulate metabolic activities, extracellular matrix composition, transcriptional activities and cell survival. Independent of the genetic background, platelet-derived growth factor (PDGF)-A ligand and both PDGF receptor subunits were highly elevated, together with autocrine secretion of bioactive PDGF. Interference with PDGF signalling by employing hepatocytes expressing the dominant-negative PDGF-alpha receptor revealed decreased TGF-beta-induced migration in vitro and efficient suppression of tumour growth in vivo. In conclusion, these results provide evidence for a crucial role of PDGF in TGF-beta-mediated tumour progression of hepatocytes and suggest PDGF as a target for therapeutic intervention in liver cancer.

Standard name | GOTZMANN_EPITHELIAL_TO_MESENCHYMAL_TRANSITION_DN
Systematic name | M1376
Organism | Mus musculus
PMID | 16607286
Authors | Gotzmann J,Fischer AN,Zojer M,Mikula M,Proell V,Huber H,Jechlinger M,Waerner T,Weith A,Beug H,Mikulits W
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MMH-RT cells (hepatocytes displaying an invasive, metastatic phenotype) during epithelial to mesenchymal transition (EMT).
Full description | Polarized hepatocytes expressing hyperactive Ha-Ras adopt an invasive and metastatic phenotype in cooperation with transforming growth factor (TGF)-beta. This dramatic increase in malignancy is displayed by an epithelial to mesenchymal transition (EMT), which mimics the TGF-beta-mediated progression of human hepatocellular carcinomas. In culture, hepatocellular EMT occurs highly synchronously, facilitating the analysis of molecular events underlying the various stages of this process. Here, we show that in response to TGF-beta, phosphorylated Smads rapidly translocated into the nucleus and activated transcription of target genes such as E-cadherin repressors of the Snail superfamily, causing loss of cell adhesion. Within the TGF-beta superfamily of cytokines, TGF-beta1, -beta2 and -beta3 were specific for the induction of hepatocellular EMT. Expression profiling of EMT kinetics revealed 78 up- and 235 downregulated genes, which preferentially modulate metabolic activities, extracellular matrix composition, transcriptional activities and cell survival. Independent of the genetic background, platelet-derived growth factor (PDGF)-A ligand and both PDGF receptor subunits were highly elevated, together with autocrine secretion of bioactive PDGF. Interference with PDGF signalling by employing hepatocytes expressing the dominant-negative PDGF-alpha receptor revealed decreased TGF-beta-induced migration in vitro and efficient suppression of tumour growth in vivo. In conclusion, these results provide evidence for a crucial role of PDGF in TGF-beta-mediated tumour progression of hepatocytes and suggest PDGF as a target for therapeutic intervention in liver cancer.

Standard name | HE_PTEN_TARGETS_UP
Systematic name | M1377
Organism | Mus musculus
PMID | 17237784
Authors | He XC,Yin T,Grindley JC,Tian Q,Sato T,Tao WA,Dirisina R,Porter-Westpfahl KS,Hembree M,Johnson T,Wiedemann LM,Barrett TA,Hood L,Wu H,Li L
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the intestine after the tissue specific knockout of PTEN [GeneID=5728] by Cre-lox.
Full description | Intestinal polyposis, a precancerous neoplasia, results primarily from an abnormal increase in the number of crypts, which contain intestinal stem cells (ISCs). In mice, widespread deletion of the tumor suppressor Phosphatase and tensin homolog (PTEN) generates hamartomatous intestinal polyps with epithelial and stromal involvement. Using this model, we have established the relationship between stem cells and polyp and tumor formation. PTEN helps govern the proliferation rate and number of ISCs and loss of PTEN results in an excess of ISCs. In PTEN-deficient mice, excess ISCs initiate de novo crypt formation and crypt fission, recapitulating crypt production in fetal and neonatal intestine. The PTEN-Akt pathway probably governs stem cell activation by helping control nuclear localization of the Wnt pathway effector beta-catenin. Akt phosphorylates beta-catenin at Ser552, resulting in a nuclear-localized form in ISCs. Our observations show that intestinal polyposis is initiated by PTEN-deficient ISCs that undergo excessive proliferation driven by Akt activation and nuclear localization of beta-catenin.

Standard name | HE_PTEN_TARGETS_DN
Systematic name | M1379
Organism | Mus musculus
PMID | 17237784
Authors | He XC,Yin T,Grindley JC,Tian Q,Sato T,Tao WA,Dirisina R,Porter-Westpfahl KS,Hembree M,Johnson T,Wiedemann LM,Barrett TA,Hood L,Wu H,Li L
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the intestine after the tissue specific knockout of PTEN [GeneID=5728] by Cre-lox.
Full description | Intestinal polyposis, a precancerous neoplasia, results primarily from an abnormal increase in the number of crypts, which contain intestinal stem cells (ISCs). In mice, widespread deletion of the tumor suppressor Phosphatase and tensin homolog (PTEN) generates hamartomatous intestinal polyps with epithelial and stromal involvement. Using this model, we have established the relationship between stem cells and polyp and tumor formation. PTEN helps govern the proliferation rate and number of ISCs and loss of PTEN results in an excess of ISCs. In PTEN-deficient mice, excess ISCs initiate de novo crypt formation and crypt fission, recapitulating crypt production in fetal and neonatal intestine. The PTEN-Akt pathway probably governs stem cell activation by helping control nuclear localization of the Wnt pathway effector beta-catenin. Akt phosphorylates beta-catenin at Ser552, resulting in a nuclear-localized form in ISCs. Our observations show that intestinal polyposis is initiated by PTEN-deficient ISCs that undergo excessive proliferation driven by Akt activation and nuclear localization of beta-catenin.

Standard name | AMIT_DELAYED_EARLY_GENES
Systematic name | M10550
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Delayed early genes (DEG) which are coordinately down-regulated in multiple epithelial tumor types.
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | DEN_INTERACT_WITH_LCA5
Systematic name | M1380
Organism | Homo sapiens
PMID | 17546029
Authors | den Hollander AI,Koenekoop RK,Mohamed MD,Arts HH,Boldt K,Towns KV,Sedmak T,Beer M,Nagel-Wolfrum K,McKibbin M,Dharmaraj S,Lopez I,Ivings L,Williams GA,Springell K,Woods CG,Jafri H,Rashid Y,Strom TM,van der Zwaag B,Gosens I,Kersten FF,van Wijk E,Veltman JA,Zonneveld MN,van Beersum SE,Maumenee IH,Wolfrum U,Cheetham ME,Ueffing M,Cremers FP,Inglehearn CF,Roepman R
Category | C2
Sub-category | CGP
Brief description | Proteins shown to interact with LCA5 [GeneID=167691] in vivo.
Full description | Leber congenital amaurosis (LCA) causes blindness or severe visual impairment at or within a few months of birth. Here we show, using homozygosity mapping, that the LCA5 gene on chromosome 6q14, which encodes the previously unknown ciliary protein lebercilin, is associated with this disease. We detected homozygous nonsense and frameshift mutations in LCA5 in five families affected with LCA. In a sixth family, the LCA5 transcript was completely absent. LCA5 is expressed widely throughout development, although the phenotype in affected individuals is limited to the eye. Lebercilin localizes to the connecting cilia of photoreceptors and to the microtubules, centrioles and primary cilia of cultured mammalian cells. Using tandem affinity purification, we identified 24 proteins that link lebercilin to centrosomal and ciliary functions. Members of this interactome represent candidate genes for LCA and other ciliopathies. Our findings emphasize the emerging role of disrupted ciliary processes in the molecular pathogenesis of LCA.

Standard name | PASQUALUCCI_LYMPHOMA_BY_GC_STAGE_UP
Systematic name | M6510
Organism | Mus musculus
PMID | 18066064
Authors | Pasqualucci L,Bhagat G,Jankovic M,Compagno M,Smith P,Muramatsu M,Honjo T,Morse HC 3rd,Nussenzweig MC,Dalla-Favera R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in post-GC, BCL6 [GeneID=604] dependent B cell non-Hodgkin's lymphoma (B-NHL) vs MYC [GeneID=4609] driven pre-GC lymphoma.
Full description | Most human B cell non-Hodgkin's lymphomas (B-NHLs) derive from germinal centers (GCs), the structure in which B cells undergo somatic hypermutation (SHM) and class switch recombination (CSR) before being selected for high-affinity antibody production. The pathogenesis of B-NHL is associated with distinct genetic lesions, including chromosomal translocations and aberrant SHM, which arise from mistakes occurring during CSR and SHM. A direct link between these DNA remodeling events and GC lymphoma development, however, has not been demonstrated. Here we have crossed three mouse models of B cell lymphoma driven by oncogenes (Myc, Bcl6 and Myc/Bcl6; refs. 5,6) with mice lacking activation-induced cytidine deaminase (AID), the enzyme required for both CSR and SHM. We show that AID deficiency prevents Bcl6-dependent, GC-derived B-NHL, but has no impact on Myc-driven, pre-GC lymphomas. Accordingly, abrogation of AID is associated with the disappearance of CSR- and SHM-mediated structural alterations. These results show that AID is required for GC-derived lymphomagenesis, supporting the notion that errors in AID-mediated antigen-receptor gene modification processes are principal contributors to the pathogenesis of human B-NHL.

Standard name | PASQUALUCCI_LYMPHOMA_BY_GC_STAGE_DN
Systematic name | M17811
Organism | Mus musculus
PMID | 18066064
Authors | Pasqualucci L,Bhagat G,Jankovic M,Compagno M,Smith P,Muramatsu M,Honjo T,Morse HC 3rd,Nussenzweig MC,Dalla-Favera R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in post-GC, BCL6 [GeneID=604] dependent B cell non-Hodgkin's lymphoma (B-NHL) vs MYC [GeneID=4609] driven pre-GC lymphoma.
Full description | Most human B cell non-Hodgkin's lymphomas (B-NHLs) derive from germinal centers (GCs), the structure in which B cells undergo somatic hypermutation (SHM) and class switch recombination (CSR) before being selected for high-affinity antibody production. The pathogenesis of B-NHL is associated with distinct genetic lesions, including chromosomal translocations and aberrant SHM, which arise from mistakes occurring during CSR and SHM. A direct link between these DNA remodeling events and GC lymphoma development, however, has not been demonstrated. Here we have crossed three mouse models of B cell lymphoma driven by oncogenes (Myc, Bcl6 and Myc/Bcl6; refs. 5,6) with mice lacking activation-induced cytidine deaminase (AID), the enzyme required for both CSR and SHM. We show that AID deficiency prevents Bcl6-dependent, GC-derived B-NHL, but has no impact on Myc-driven, pre-GC lymphomas. Accordingly, abrogation of AID is associated with the disappearance of CSR- and SHM-mediated structural alterations. These results show that AID is required for GC-derived lymphomagenesis, supporting the notion that errors in AID-mediated antigen-receptor gene modification processes are principal contributors to the pathogenesis of human B-NHL.

Standard name | BENPORATH_ES_1
Systematic name | M1871
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'ES exp1': genes overexpressed in human embryonic stem cells according to 5 or more out of 20 profiling studies.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_ES_2
Systematic name | M4241
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'Set 'ES exp2': genes overexpressed in human embryonic stem cells according to a meta-analysis of 8 profiling studies.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_NANOG_TARGETS
Systematic name | M6616
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'Nanog targets': genes upregulated and identified by ChIP on chip as Nanog [GeneID=79923] transcription factor targets in human embryonic stem cells.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_OCT4_TARGETS
Systematic name | M17183
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'Oct4 targets': genes upregulated and identified by ChIP on chip as OCT4 [GeneID=5460] transcription factor targets in human embryonic stem cells.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_SOX2_TARGETS
Systematic name | M3835
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'Sox2 targets': genes upregulated and identified by ChIP on chip as SOX2 [GeneID=6657] transcription factor targets in human embryonic stem cells.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_NOS_TARGETS
Systematic name | M14573
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'NOS targets': genes upregulated and identified by ChIP on chip as targets of the transcription factors NANOG , OCT4, and Sox2 [GeneID=79923;5460;6657] (NOS) in human embryonic stem cells.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_SUZ12_TARGETS
Systematic name | M9898
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'Suz12 targets': genes identified by ChIP on chip as targets of the Polycomb protein SUZ12 [GeneID=23512] in human embryonic stem cells.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_EED_TARGETS
Systematic name | M7617
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'Eed targets': genes identified by ChIP on chip as targets of the Polycomb protein EED [GeneID=8726] in human embryonic stem cells.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_ES_WITH_H3K27ME3
Systematic name | M10371
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'H3K27 bound': genes posessing the trimethylated H3K27 (H3K27me3) mark in their promoters in human embryonic stem cells, as identified by ChIP on chip.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_PRC2_TARGETS
Systematic name | M8448
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'PRC2 targets': Polycomb Repression Complex 2 (PRC) targets; identified by ChIP on chip on human embryonic stem cells as genes that: posess the trimethylated H3K27 mark in their promoters and are bound by SUZ12 [GeneID=23512] and EED [GeneID=8726] Polycomb proteins.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_MYC_TARGETS_WITH_EBOX
Systematic name | M27
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'Myc targets1': targets of c-Myc [GeneID=4609] identified by ChIP on chip in cultured cell lines, focusing on E-box-containing genes; high affinity bound subset
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_MYC_MAX_TARGETS
Systematic name | M17753
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'Myc targets2': targets of c-Myc [GeneID=4609] and Max [GeneID=4149] identified by ChIP on chip in a Burkitt's lymphoma cell line; overlap set.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_CYCLING_GENES
Systematic name | M8156
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Genes showing cell-cycle stage-specific expression [PMID=12058064].
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_PROLIFERATION
Systematic name | M2114
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'Proliferation Cluster': genes defined in human breast tumor expression data.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | PETRETTO_CARDIAC_HYPERTROPHY
Systematic name | M14043
Organism | Homo sapiens
PMID | 18443592
Authors | Petretto E,Sarwar R,Grieve I,Lu H,Kumaran MK,Muckett PJ,Mangion J,Schroen B,Benson M,Punjabi PP,Prasad SK,Pennell DJ,Kiesewetter C,Tasheva ES,Corpuz LM,Webb MD,Conrad GW,Kurtz TW,Kren V,Fischer J,Hubner N,Pinto YM,Pravenec M,Aitman TJ,Cook SA
Category | C2
Sub-category | CGP
Brief description | Genes that correlated most highly with left ventricular mass (LVM) index.
Full description | Left ventricular mass (LVM) and cardiac gene expression are complex traits regulated by factors both intrinsic and extrinsic to the heart. To dissect the major determinants of LVM, we combined expression quantitative trait locus1 and quantitative trait transcript (QTT) analyses of the cardiac transcriptome in the rat. Using these methods and in vitro functional assays, we identified osteoglycin (Ogn) as a major candidate regulator of rat LVM, with increased Ogn protein expression associated with elevated LVM. We also applied genome-wide QTT analysis to the human heart and observed that, out of 22,000 transcripts, OGN transcript abundance had the highest correlation with LVM. We further confirmed a role for Ogn in the in vivo regulation of LVM in Ogn knockout mice. Taken together, these data implicate Ogn as a key regulator of LVM in rats, mice and humans, and suggest that Ogn modifies the hypertrophic response to extrinsic factors such as hypertension and aortic stenosis.

Standard name | STARK_PREFRONTAL_CORTEX_22Q11_DELETION_UP
Systematic name | M2817
Organism | Mus musculus
PMID | 18469815
Authors | Stark KL,Xu B,Bagchi A,Lai WS,Liu H,Hsu R,Wan X,Pavlidis P,Mills AA,Karayiorgou M,Gogos JA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in prefrontal cortex (PFC) of mice carrying a hemizygotic microdeletion in the 22q11.2 region.
Full description | Individuals with 22q11.2 microdeletions show behavioral and cognitive deficits and are at high risk of developing schizophrenia. We analyzed an engineered mouse strain carrying a chromosomal deficiency spanning a segment syntenic to the human 22q11.2 locus. We uncovered a previously unknown alteration in the biogenesis of microRNAs (miRNAs) and identified a subset of brain miRNAs affected by the microdeletion. We provide evidence that the abnormal miRNA biogenesis emerges because of haploinsufficiency of the Dgcr8 gene, which encodes an RNA-binding moiety of the 'microprocessor' complex and contributes to the behavioral and neuronal deficits associated with the 22q11.2 microdeletion.

Standard name | STARK_PREFRONTAL_CORTEX_22Q11_DELETION_DN
Systematic name | M10914
Organism | Mus musculus
PMID | 18469815
Authors | Stark KL,Xu B,Bagchi A,Lai WS,Liu H,Hsu R,Wan X,Pavlidis P,Mills AA,Karayiorgou M,Gogos JA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in prefrontal cortex (PFC) of mice carrying a hemizygotic microdeletion in the 22q11.2 region.
Full description | Individuals with 22q11.2 microdeletions show behavioral and cognitive deficits and are at high risk of developing schizophrenia. We analyzed an engineered mouse strain carrying a chromosomal deficiency spanning a segment syntenic to the human 22q11.2 locus. We uncovered a previously unknown alteration in the biogenesis of microRNAs (miRNAs) and identified a subset of brain miRNAs affected by the microdeletion. We provide evidence that the abnormal miRNA biogenesis emerges because of haploinsufficiency of the Dgcr8 gene, which encodes an RNA-binding moiety of the 'microprocessor' complex and contributes to the behavioral and neuronal deficits associated with the 22q11.2 microdeletion.

Standard name | STARK_HYPPOCAMPUS_22Q11_DELETION_UP
Systematic name | M12050
Organism | Mus musculus
PMID | 18469815
Authors | Stark KL,Xu B,Bagchi A,Lai WS,Liu H,Hsu R,Wan X,Pavlidis P,Mills AA,Karayiorgou M,Gogos JA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hyppocampus of mice carrying a hemizygotic microdeletion in the 22q11.2 region.
Full description | Individuals with 22q11.2 microdeletions show behavioral and cognitive deficits and are at high risk of developing schizophrenia. We analyzed an engineered mouse strain carrying a chromosomal deficiency spanning a segment syntenic to the human 22q11.2 locus. We uncovered a previously unknown alteration in the biogenesis of microRNAs (miRNAs) and identified a subset of brain miRNAs affected by the microdeletion. We provide evidence that the abnormal miRNA biogenesis emerges because of haploinsufficiency of the Dgcr8 gene, which encodes an RNA-binding moiety of the 'microprocessor' complex and contributes to the behavioral and neuronal deficits associated with the 22q11.2 microdeletion.

Standard name | STARK_HYPPOCAMPUS_22Q11_DELETION_DN
Systematic name | M17954
Organism | Mus musculus
PMID | 18469815
Authors | Stark KL,Xu B,Bagchi A,Lai WS,Liu H,Hsu R,Wan X,Pavlidis P,Mills AA,Karayiorgou M,Gogos JA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hyppocampus of mice carrying a hemizygotic microdeletion in the 22q11.2 region.
Full description | Individuals with 22q11.2 microdeletions show behavioral and cognitive deficits and are at high risk of developing schizophrenia. We analyzed an engineered mouse strain carrying a chromosomal deficiency spanning a segment syntenic to the human 22q11.2 locus. We uncovered a previously unknown alteration in the biogenesis of microRNAs (miRNAs) and identified a subset of brain miRNAs affected by the microdeletion. We provide evidence that the abnormal miRNA biogenesis emerges because of haploinsufficiency of the Dgcr8 gene, which encodes an RNA-binding moiety of the 'microprocessor' complex and contributes to the behavioral and neuronal deficits associated with the 22q11.2 microdeletion.

Standard name | STARK_BRAIN_22Q11_DELETION
Systematic name | M6139
Organism | Mus musculus
PMID | 18469815
Authors | Stark KL,Xu B,Bagchi A,Lai WS,Liu H,Hsu R,Wan X,Pavlidis P,Mills AA,Karayiorgou M,Gogos JA
Category | C2
Sub-category | CGP
Brief description | Genes located outside the microdeletion region in 22q11 which were differentially expressed in the same manner both in hyppocampus and prefrontal cortex.
Full description | Individuals with 22q11.2 microdeletions show behavioral and cognitive deficits and are at high risk of developing schizophrenia. We analyzed an engineered mouse strain carrying a chromosomal deficiency spanning a segment syntenic to the human 22q11.2 locus. We uncovered a previously unknown alteration in the biogenesis of microRNAs (miRNAs) and identified a subset of brain miRNAs affected by the microdeletion. We provide evidence that the abnormal miRNA biogenesis emerges because of haploinsufficiency of the Dgcr8 gene, which encodes an RNA-binding moiety of the 'microprocessor' complex and contributes to the behavioral and neuronal deficits associated with the 22q11.2 microdeletion.

Standard name | BENPORATH_ES_CORE_NINE
Systematic name | M4740
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Set 'Core 9': 'embryonic stem cell' transcription regulators that are preferentially and coordinately overexpressed in the high-grade, ER-negative breast cancer tumors.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | BENPORATH_ES_CORE_NINE_CORRELATED
Systematic name | M14079
Organism | Homo sapiens
PMID | 18443585
Authors | Ben-Porath I,Thomson MW,Carey VJ,Ge R,Bell GW,Regev A,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Breast cancer compendium: 100 transcription regulators showing most correlated expression with the 9 'embryonic stem cell' transcription factors that are preferentially and coordinately overexpressed in the high-grade, ER-negative breast cancer tumors.
Full description | Cancer cells possess traits reminiscent of those ascribed to normal stem cells. It is unclear, however, whether these phenotypic similarities reflect the activity of common molecular pathways. Here, we analyze the enrichment patterns of gene sets associated with embryonic stem (ES) cell identity in the expression profiles of various human tumor types. We find that histologically poorly differentiated tumors show preferential overexpression of genes normally enriched in ES cells, combined with preferential repression of Polycomb-regulated genes. Moreover, activation targets of Nanog, Oct4, Sox2 and c-Myc are more frequently overexpressed in poorly differentiated tumors than in well-differentiated tumors. In breast cancers, this ES-like signature is associated with high-grade estrogen receptor (ER)-negative tumors, often of the basal-like subtype, and with poor clinical outcome. The ES signature is also present in poorly differentiated glioblastomas and bladder carcinomas. We identify a subset of ES cell-associated transcription regulators that are highly expressed in poorly differentiated tumors. Our results reveal a previously unknown link between genes associated with ES cell identity and the histopathological traits of tumors and support the possibility that these genes contribute to stem cell-like phenotypes shown by many tumors.

Standard name | PETRETTO_BLOOD_PRESSURE_UP
Systematic name | M14298
Organism | Rattus norvegicus
PMID | 18443592
Authors | Petretto E,Sarwar R,Grieve I,Lu H,Kumaran MK,Muckett PJ,Mangion J,Schroen B,Benson M,Punjabi PP,Prasad SK,Pennell DJ,Kiesewetter C,Tasheva ES,Corpuz LM,Webb MD,Conrad GW,Kurtz TW,Kren V,Fischer J,Hubner N,Pinto YM,Pravenec M,Aitman TJ,Cook SA
Category | C2
Sub-category | CGP
Brief description | Genes that are most strongly positively correlated with systolic blood pressure (SBP).
Full description | Left ventricular mass (LVM) and cardiac gene expression are complex traits regulated by factors both intrinsic and extrinsic to the heart. To dissect the major determinants of LVM, we combined expression quantitative trait locus1 and quantitative trait transcript (QTT) analyses of the cardiac transcriptome in the rat. Using these methods and in vitro functional assays, we identified osteoglycin (Ogn) as a major candidate regulator of rat LVM, with increased Ogn protein expression associated with elevated LVM. We also applied genome-wide QTT analysis to the human heart and observed that, out of 22,000 transcripts, OGN transcript abundance had the highest correlation with LVM. We further confirmed a role for Ogn in the in vivo regulation of LVM in Ogn knockout mice. Taken together, these data implicate Ogn as a key regulator of LVM in rats, mice and humans, and suggest that Ogn modifies the hypertrophic response to extrinsic factors such as hypertension and aortic stenosis.

Standard name | PETRETTO_BLOOD_PRESSURE_DN
Systematic name | M7813
Organism | Rattus norvegicus
PMID | 18443592
Authors | Petretto E,Sarwar R,Grieve I,Lu H,Kumaran MK,Muckett PJ,Mangion J,Schroen B,Benson M,Punjabi PP,Prasad SK,Pennell DJ,Kiesewetter C,Tasheva ES,Corpuz LM,Webb MD,Conrad GW,Kurtz TW,Kren V,Fischer J,Hubner N,Pinto YM,Pravenec M,Aitman TJ,Cook SA
Category | C2
Sub-category | CGP
Brief description | Genes that are most strongly negatively correlated with systolic blood pressure (SBP).
Full description | Left ventricular mass (LVM) and cardiac gene expression are complex traits regulated by factors both intrinsic and extrinsic to the heart. To dissect the major determinants of LVM, we combined expression quantitative trait locus1 and quantitative trait transcript (QTT) analyses of the cardiac transcriptome in the rat. Using these methods and in vitro functional assays, we identified osteoglycin (Ogn) as a major candidate regulator of rat LVM, with increased Ogn protein expression associated with elevated LVM. We also applied genome-wide QTT analysis to the human heart and observed that, out of 22,000 transcripts, OGN transcript abundance had the highest correlation with LVM. We further confirmed a role for Ogn in the in vivo regulation of LVM in Ogn knockout mice. Taken together, these data implicate Ogn as a key regulator of LVM in rats, mice and humans, and suggest that Ogn modifies the hypertrophic response to extrinsic factors such as hypertension and aortic stenosis.

Standard name | PETRETTO_HEART_MASS_QTL_CIS_UP
Systematic name | M17037
Organism | Rattus norvegicus
PMID | 18443592
Authors | Petretto E,Sarwar R,Grieve I,Lu H,Kumaran MK,Muckett PJ,Mangion J,Schroen B,Benson M,Punjabi PP,Prasad SK,Pennell DJ,Kiesewetter C,Tasheva ES,Corpuz LM,Webb MD,Conrad GW,Kurtz TW,Kren V,Fischer J,Hubner N,Pinto YM,Pravenec M,Aitman TJ,Cook SA
Category | C2
Sub-category | CGP
Brief description | Up-regulated cis-regulated expression quantitative loci (cis-eQTL) in the heart that colocalize with previously mapped cardiac mass QTLs.
Full description | Left ventricular mass (LVM) and cardiac gene expression are complex traits regulated by factors both intrinsic and extrinsic to the heart. To dissect the major determinants of LVM, we combined expression quantitative trait locus1 and quantitative trait transcript (QTT) analyses of the cardiac transcriptome in the rat. Using these methods and in vitro functional assays, we identified osteoglycin (Ogn) as a major candidate regulator of rat LVM, with increased Ogn protein expression associated with elevated LVM. We also applied genome-wide QTT analysis to the human heart and observed that, out of 22,000 transcripts, OGN transcript abundance had the highest correlation with LVM. We further confirmed a role for Ogn in the in vivo regulation of LVM in Ogn knockout mice. Taken together, these data implicate Ogn as a key regulator of LVM in rats, mice and humans, and suggest that Ogn modifies the hypertrophic response to extrinsic factors such as hypertension and aortic stenosis.

Standard name | PETRETTO_HEART_MASS_QTL_CIS_DN
Systematic name | M13336
Organism | Rattus norvegicus
PMID | 18443592
Authors | Petretto E,Sarwar R,Grieve I,Lu H,Kumaran MK,Muckett PJ,Mangion J,Schroen B,Benson M,Punjabi PP,Prasad SK,Pennell DJ,Kiesewetter C,Tasheva ES,Corpuz LM,Webb MD,Conrad GW,Kurtz TW,Kren V,Fischer J,Hubner N,Pinto YM,Pravenec M,Aitman TJ,Cook SA
Category | C2
Sub-category | CGP
Brief description | Down-regulated cis-regulated expression quantitative loci (cis-eQTL) in the heart that colocalize with previously mapped cardiac mass QTLs.
Full description | Left ventricular mass (LVM) and cardiac gene expression are complex traits regulated by factors both intrinsic and extrinsic to the heart. To dissect the major determinants of LVM, we combined expression quantitative trait locus1 and quantitative trait transcript (QTT) analyses of the cardiac transcriptome in the rat. Using these methods and in vitro functional assays, we identified osteoglycin (Ogn) as a major candidate regulator of rat LVM, with increased Ogn protein expression associated with elevated LVM. We also applied genome-wide QTT analysis to the human heart and observed that, out of 22,000 transcripts, OGN transcript abundance had the highest correlation with LVM. We further confirmed a role for Ogn in the in vivo regulation of LVM in Ogn knockout mice. Taken together, these data implicate Ogn as a key regulator of LVM in rats, mice and humans, and suggest that Ogn modifies the hypertrophic response to extrinsic factors such as hypertension and aortic stenosis.

Standard name | PETRETTO_LEFT_VENTRICLE_MASS_QTL_CIS_UP
Systematic name | M1381
Organism | Rattus norvegicus
PMID | 18443592
Authors | Petretto E,Sarwar R,Grieve I,Lu H,Kumaran MK,Muckett PJ,Mangion J,Schroen B,Benson M,Punjabi PP,Prasad SK,Pennell DJ,Kiesewetter C,Tasheva ES,Corpuz LM,Webb MD,Conrad GW,Kurtz TW,Kren V,Fischer J,Hubner N,Pinto YM,Pravenec M,Aitman TJ,Cook SA
Category | C2
Sub-category | CGP
Brief description | Up-regulated cis-regulated expression quantitative loci (cis-eQTL) in the heart that were identified as candidate genes for the regulation of left ventricle mass (LVM).
Full description | Left ventricular mass (LVM) and cardiac gene expression are complex traits regulated by factors both intrinsic and extrinsic to the heart. To dissect the major determinants of LVM, we combined expression quantitative trait locus1 and quantitative trait transcript (QTT) analyses of the cardiac transcriptome in the rat. Using these methods and in vitro functional assays, we identified osteoglycin (Ogn) as a major candidate regulator of rat LVM, with increased Ogn protein expression associated with elevated LVM. We also applied genome-wide QTT analysis to the human heart and observed that, out of 22,000 transcripts, OGN transcript abundance had the highest correlation with LVM. We further confirmed a role for Ogn in the in vivo regulation of LVM in Ogn knockout mice. Taken together, these data implicate Ogn as a key regulator of LVM in rats, mice and humans, and suggest that Ogn modifies the hypertrophic response to extrinsic factors such as hypertension and aortic stenosis.

Standard name | PETRETTO_LEFT_VENTRICLE_MASS_QTL_CIS_DN
Systematic name | M1382
Organism | Rattus norvegicus
PMID | 18443592
Authors | Petretto E,Sarwar R,Grieve I,Lu H,Kumaran MK,Muckett PJ,Mangion J,Schroen B,Benson M,Punjabi PP,Prasad SK,Pennell DJ,Kiesewetter C,Tasheva ES,Corpuz LM,Webb MD,Conrad GW,Kurtz TW,Kren V,Fischer J,Hubner N,Pinto YM,Pravenec M,Aitman TJ,Cook SA
Category | C2
Sub-category | CGP
Brief description | Down-regulated cis-regulated expression quantitative loci (cis-eQTL) in the heart that were identified as candidate genes for the regulation of left ventricle mass (LVM).
Full description | Left ventricular mass (LVM) and cardiac gene expression are complex traits regulated by factors both intrinsic and extrinsic to the heart. To dissect the major determinants of LVM, we combined expression quantitative trait locus1 and quantitative trait transcript (QTT) analyses of the cardiac transcriptome in the rat. Using these methods and in vitro functional assays, we identified osteoglycin (Ogn) as a major candidate regulator of rat LVM, with increased Ogn protein expression associated with elevated LVM. We also applied genome-wide QTT analysis to the human heart and observed that, out of 22,000 transcripts, OGN transcript abundance had the highest correlation with LVM. We further confirmed a role for Ogn in the in vivo regulation of LVM in Ogn knockout mice. Taken together, these data implicate Ogn as a key regulator of LVM in rats, mice and humans, and suggest that Ogn modifies the hypertrophic response to extrinsic factors such as hypertension and aortic stenosis.

Standard name | AMIT_EGF_RESPONSE_20_HELA
Systematic name | M13526
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 20 min after stimulation of HeLa cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_40_HELA
Systematic name | M4204
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 40 min after stimulation of HeLa cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_60_HELA
Systematic name | M10797
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 60 min after stimulation of HeLa cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_120_HELA
Systematic name | M12710
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 120 min after stimulation of HeLa cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_240_HELA
Systematic name | M7714
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 240 min after stimulation of HeLa cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_480_HELA
Systematic name | M8729
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 480 min after stimulation of HeLa cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_20_MCF10A
Systematic name | M4625
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 20 min after stimulation of MCF10A cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_40_MCF10A
Systematic name | M19909
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 40 min after stimulation of MCF10A cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_60_MCF10A
Systematic name | M6815
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 60 min after stimulation of MCF10A cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_120_MCF10A
Systematic name | M3471
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 120 min after stimulation of MCF10A cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_240_MCF10A
Systematic name | M2894
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 240 min after stimulation of MCF10A cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_EGF_RESPONSE_480_MCF10A
Systematic name | M12170
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 480 min after stimulation of MCF10A cells with EGF [GeneID=1950].
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_SERUM_RESPONSE_20_MCF10A
Systematic name | M11193
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 20 min after stimulation of MCF10A cells with serum.
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_SERUM_RESPONSE_40_MCF10A
Systematic name | M11519
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 40 min after stimulation of MCF10A cells with serum.
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_SERUM_RESPONSE_60_MCF10A
Systematic name | M3447
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 60 min after stimulation of MCF10A cells with serum.
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_SERUM_RESPONSE_120_MCF10A
Systematic name | M15821
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 120 min after stimulation of MCF10A cells with serum.
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_SERUM_RESPONSE_240_MCF10A
Systematic name | M2777
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 240 min after stimulation of MCF10A cells with serum.
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | AMIT_SERUM_RESPONSE_480_MCF10A
Systematic name | M8202
Organism | Homo sapiens
PMID | 17322878
Authors | Amit I,Citri A,Shay T,Lu Y,Katz M,Zhang F,Tarcic G,Siwak D,Lahad J,Jacob-Hirsch J,Amariglio N,Vaisman N,Segal E,Rechavi G,Alon U,Mills GB,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes whose expression peaked at 480 min after stimulation of MCF10A cells with serum.
Full description | Signaling pathways invoke interplays between forward signaling and feedback to drive robust cellular response. In this study, we address the dynamics of growth factor signaling through profiling of protein phosphorylation and gene expression, demonstrating the presence of a kinetically defined cluster of delayed early genes that function to attenuate the early events of growth factor signaling. Using epidermal growth factor receptor signaling as the major model system and concentrating on regulation of transcription and mRNA stability, we demonstrate that a number of genes within the delayed early gene cluster function as feedback regulators of immediate early genes. Consistent with their role in negative regulation of cell signaling, genes within this cluster are downregulated in diverse tumor types, in correlation with clinical outcome. More generally, our study proposes a mechanistic description of the cellular response to growth factors by defining architectural motifs that underlie the function of signaling networks.

Standard name | GEORGES_CELL_CYCLE_MIR192_TARGETS
Systematic name | M11038
Organism | Homo sapiens
PMID | 19074876
Authors | Georges SA,Biery MC,Kim SY,Schelter JM,Guo J,Chang AN,Jackson AL,Carleton MO,Linsley PS,Cleary MA,Chau BN
Category | C2
Sub-category | CGP
Brief description | Experimentally validated direct targets of MIR192 [GeneID=406967] microRNA; MIR192 caused cell cycle arrest in HCT116 cells (colon cancer).
Full description | Cell cycle arrest in response to DNA damage is an important antitumorigenic mechanism. MicroRNAs (miRNAs) were recently shown to play key regulatory roles in cell cycle progression. For example, miR-34a is induced in response to p53 activation and mediates G(1) arrest by down-regulating multiple cell cycle-related transcripts. Here we show that genotoxic stress promotes the p53-dependent up-regulation of the homologous miRNAs miR-192 and miR-215. Like miR-34a, activation of miR-192/215 induces cell cycle arrest, suggesting that multiple miRNA families operate in the p53 network. Furthermore, we define a downstream gene expression signature for miR-192/215 expression, which includes a number of transcripts that regulate G(1) and G(2) checkpoints. Of these transcripts, 18 transcripts are direct targets of miR-192/215, and the observed cell cycle arrest likely results from a cooperative effect among the modulations of these genes by the miRNAs. Our results showing a role for miR-192/215 in cell proliferation combined with recent observations that these miRNAs are underexpressed in primary cancers support the idea that miR-192 and miR-215 function as tumor suppressors.

Standard name | GEORGES_TARGETS_OF_MIR192_AND_MIR215
Systematic name | M18120
Organism | Homo sapiens
PMID | 19074876
Authors | Georges SA,Biery MC,Kim SY,Schelter JM,Guo J,Chang AN,Jackson AL,Carleton MO,Linsley PS,Cleary MA,Chau BN
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HCT116 cells (colon cancer) by expression of MIR192 or MIR215 [GeneID=406967;406997] at 24 h.
Full description | Cell cycle arrest in response to DNA damage is an important antitumorigenic mechanism. MicroRNAs (miRNAs) were recently shown to play key regulatory roles in cell cycle progression. For example, miR-34a is induced in response to p53 activation and mediates G(1) arrest by down-regulating multiple cell cycle-related transcripts. Here we show that genotoxic stress promotes the p53-dependent up-regulation of the homologous miRNAs miR-192 and miR-215. Like miR-34a, activation of miR-192/215 induces cell cycle arrest, suggesting that multiple miRNA families operate in the p53 network. Furthermore, we define a downstream gene expression signature for miR-192/215 expression, which includes a number of transcripts that regulate G(1) and G(2) checkpoints. Of these transcripts, 18 transcripts are direct targets of miR-192/215, and the observed cell cycle arrest likely results from a cooperative effect among the modulations of these genes by the miRNAs. Our results showing a role for miR-192/215 in cell proliferation combined with recent observations that these miRNAs are underexpressed in primary cancers support the idea that miR-192 and miR-215 function as tumor suppressors.

Standard name | SHEN_SMARCA2_TARGETS_UP
Systematic name | M29
Organism | Homo sapiens
PMID | 19074882
Authors | Shen H,Powers N,Saini N,Comstock CE,Sharma A,Weaver K,Revelo MP,Gerald W,Williams E,Jessen WJ,Aronow BJ,Rosson G,Weissman B,Muchardt C,Yaniv M,Knudsen KE
Category | C2
Sub-category | CGP
Brief description | Genes whose expression positively correlated with that of SMARCA2 [GeneID=6595] in prostate cancer samples.
Full description | Factors that drive prostate cancer progression remain poorly defined, thus hindering the development of new therapeutic strategies. Disseminated tumors are treated through regimens that ablate androgen signaling, as prostate cancer cells require androgen for growth and survival. However, recurrent, incurable tumors that have bypassed the androgen requirement ultimately arise. This study reveals that the Brm ATPase, a component of selected SWI/SNF complexes, has significant antiproliferative functions in the prostate that protect against these transitions. First, we show that targeted ablation of Brm is causative for the development of prostatic hyperplasia in mice. Second, in vivo challenge revealed that Brm-/- epithelia acquire the capacity for lobe-specific, castration-resistant cellular proliferation. Third, investigation of human specimens revealed that Brm mRNA and protein levels are attenuated in prostate cancer. Fourth, Brm down-regulation was associated with an increased proliferative index, consistent with the mouse model. Lastly, gene expression profiling showed that Brm loss alters factors upstream of E2F1; this was confirmed in murine models, wherein Brm loss induced E2F1 deregulation in a tissue-specific manner. Combined, these data identify Brm as a major effector of serum androgen-induced proliferation in the prostate that is disrupted in human disease, and indicate that loss of Brm confers a proliferative advantage in prostate cancer.

Standard name | SHEN_SMARCA2_TARGETS_DN
Systematic name | M1676
Organism | Homo sapiens
PMID | 19074882
Authors | Shen H,Powers N,Saini N,Comstock CE,Sharma A,Weaver K,Revelo MP,Gerald W,Williams E,Jessen WJ,Aronow BJ,Rosson G,Weissman B,Muchardt C,Yaniv M,Knudsen KE
Category | C2
Sub-category | CGP
Brief description | Genes whose expression negatively correlated with that of SMARCA2 [GeneID=6595] in prostate cancer samples.
Full description | Factors that drive prostate cancer progression remain poorly defined, thus hindering the development of new therapeutic strategies. Disseminated tumors are treated through regimens that ablate androgen signaling, as prostate cancer cells require androgen for growth and survival. However, recurrent, incurable tumors that have bypassed the androgen requirement ultimately arise. This study reveals that the Brm ATPase, a component of selected SWI/SNF complexes, has significant antiproliferative functions in the prostate that protect against these transitions. First, we show that targeted ablation of Brm is causative for the development of prostatic hyperplasia in mice. Second, in vivo challenge revealed that Brm-/- epithelia acquire the capacity for lobe-specific, castration-resistant cellular proliferation. Third, investigation of human specimens revealed that Brm mRNA and protein levels are attenuated in prostate cancer. Fourth, Brm down-regulation was associated with an increased proliferative index, consistent with the mouse model. Lastly, gene expression profiling showed that Brm loss alters factors upstream of E2F1; this was confirmed in murine models, wherein Brm loss induced E2F1 deregulation in a tissue-specific manner. Combined, these data identify Brm as a major effector of serum androgen-induced proliferation in the prostate that is disrupted in human disease, and indicate that loss of Brm confers a proliferative advantage in prostate cancer.

Standard name | LIN_SILENCED_BY_TUMOR_MICROENVIRONMENT
Systematic name | M19768
Organism | Homo sapiens
PMID | 19074894
Authors | Lin HJ,Zuo T,Lin CH,Kuo CT,Liyanarachchi S,Sun S,Shen R,Deatherage DE,Potter D,Asamoto L,Lin S,Yan PS,Cheng AL,Ostrowski MC,Huang TH
Category | C2
Sub-category | CGP
Brief description | Genes downregulated in MCF10A cells (breast cancer) co-cultured with cancer-associated fibroblasts (CAF).
Full description | The interplay between histone modifications and promoter hypermethylation provides a causative explanation for epigenetic gene silencing in cancer. Less is known about the upstream initiators that direct this process. Here, we report that the Cystatin M (CST6) tumor suppressor gene is concurrently down-regulated with other loci in breast epithelial cells cocultured with cancer-associated fibroblasts (CAF). Promoter hypermethylation of CST6 is associated with aberrant AKT1 activation in epithelial cells, as well as the disabled INNP4B regulator resulting from the suppression by CAFs. Repressive chromatin, marked by trimethyl-H3K27 and dimethyl-H3K9, and de novo DNA methylation is established at the promoter. The findings suggest that microenvironmental stimuli are triggers in this epigenetic cascade, leading to the long-term silencing of CST6 in breast tumors. Our present findings implicate a causal mechanism defining how tumor stromal fibroblasts support neoplastic progression by manipulating the epigenome of mammary epithelial cells. The result also highlights the importance of direct cell-cell contact between epithelial cells and the surrounding fibroblasts that confer this epigenetic perturbation. Because this two-way interaction is anticipated, the described coculture system can be used to determine the effect of epithelial factors on fibroblasts in future studies.

Standard name | SAKAI_TUMOR_INFILTRATING_MONOCYTES_DN
Systematic name | M8180
Organism | Homo sapiens
PMID | 19074895
Authors | Sakai Y,Honda M,Fujinaga H,Tatsumi I,Mizukoshi E,Nakamoto Y,Kaneko S
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated in inflammatory monocytes infiltrating hepatocellular carcinoma (HCC).
Full description | Hepatocellular carcinoma (HCC) is frequently associated with infiltrating mononuclear inflammatory cells. We performed laser capture microdissection of HCC-infiltrating and noncancerous liver-infiltrating mononuclear inflammatory cells in patients with chronic hepatitis C (CH-C) and examined gene expression profiles. HCC-infiltrating mononuclear inflammatory cells had an expression profile distinct from noncancerous liver-infiltrating mononuclear inflammatory cells; they differed with regard to genes involved in biological processes, such as antigen presentation, ubiquitin-proteasomal proteolysis, and responses to hypoxia and oxidative stress. Immunohistochemical analysis and gene expression databases suggested that the up-regulated genes involved macrophages and Th1 and Th2 CD4 cells. We next examined the gene expression profile of peripheral blood mononuclear cells (PBMC) obtained from CH-C patients with or without HCC. The expression profiles of PBMCs from patients with HCC differed significantly from those of patients without HCC (P < 0.0005). Many of the up-regulated genes in HCC-infiltrating mononuclear inflammatory cells were also differentially expressed by PBMCs of HCC patients. Analysis of the commonly up-regulated or down-regulated genes in HCC-infiltrating mononuclear inflammatory cells and PBMCs of HCC patients showed networks of nucleophosmin, SMAD3, and proliferating cell nuclear antigen that are involved with redox status, the cell cycle, and the proteasome system, along with immunologic genes, suggesting regulation of anticancer immunity. Thus, exploring the gene expression profile of PBMCs may be a surrogate approach for the assessment of local HCC-infiltrating mononuclear inflammatory cells.

Standard name | SAKAI_TUMOR_INFILTRATING_MONOCYTES_UP
Systematic name | M14614
Organism | Homo sapiens
PMID | 19074895
Authors | Sakai Y,Honda M,Fujinaga H,Tatsumi I,Mizukoshi E,Nakamoto Y,Kaneko S
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated in inflammatory monocytes infiltrating hepatocellular carcinoma (HCC).
Full description | Hepatocellular carcinoma (HCC) is frequently associated with infiltrating mononuclear inflammatory cells. We performed laser capture microdissection of HCC-infiltrating and noncancerous liver-infiltrating mononuclear inflammatory cells in patients with chronic hepatitis C (CH-C) and examined gene expression profiles. HCC-infiltrating mononuclear inflammatory cells had an expression profile distinct from noncancerous liver-infiltrating mononuclear inflammatory cells; they differed with regard to genes involved in biological processes, such as antigen presentation, ubiquitin-proteasomal proteolysis, and responses to hypoxia and oxidative stress. Immunohistochemical analysis and gene expression databases suggested that the up-regulated genes involved macrophages and Th1 and Th2 CD4 cells. We next examined the gene expression profile of peripheral blood mononuclear cells (PBMC) obtained from CH-C patients with or without HCC. The expression profiles of PBMCs from patients with HCC differed significantly from those of patients without HCC (P < 0.0005). Many of the up-regulated genes in HCC-infiltrating mononuclear inflammatory cells were also differentially expressed by PBMCs of HCC patients. Analysis of the commonly up-regulated or down-regulated genes in HCC-infiltrating mononuclear inflammatory cells and PBMCs of HCC patients showed networks of nucleophosmin, SMAD3, and proliferating cell nuclear antigen that are involved with redox status, the cell cycle, and the proteasome system, along with immunologic genes, suggesting regulation of anticancer immunity. Thus, exploring the gene expression profile of PBMCs may be a surrogate approach for the assessment of local HCC-infiltrating mononuclear inflammatory cells.

Standard name | SAKAI_CHRONIC_HEPATITIS_VS_LIVER_CANCER_DN
Systematic name | M15473
Organism | Homo sapiens
PMID | 19074895
Authors | Sakai Y,Honda M,Fujinaga H,Tatsumi I,Mizukoshi E,Nakamoto Y,Kaneko S
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated in peripheral blood monocytes (PBMC) of patients with hepatocellular carcinoma (HCC) compared to those with chronic hepatitis.
Full description | Hepatocellular carcinoma (HCC) is frequently associated with infiltrating mononuclear inflammatory cells. We performed laser capture microdissection of HCC-infiltrating and noncancerous liver-infiltrating mononuclear inflammatory cells in patients with chronic hepatitis C (CH-C) and examined gene expression profiles. HCC-infiltrating mononuclear inflammatory cells had an expression profile distinct from noncancerous liver-infiltrating mononuclear inflammatory cells; they differed with regard to genes involved in biological processes, such as antigen presentation, ubiquitin-proteasomal proteolysis, and responses to hypoxia and oxidative stress. Immunohistochemical analysis and gene expression databases suggested that the up-regulated genes involved macrophages and Th1 and Th2 CD4 cells. We next examined the gene expression profile of peripheral blood mononuclear cells (PBMC) obtained from CH-C patients with or without HCC. The expression profiles of PBMCs from patients with HCC differed significantly from those of patients without HCC (P < 0.0005). Many of the up-regulated genes in HCC-infiltrating mononuclear inflammatory cells were also differentially expressed by PBMCs of HCC patients. Analysis of the commonly up-regulated or down-regulated genes in HCC-infiltrating mononuclear inflammatory cells and PBMCs of HCC patients showed networks of nucleophosmin, SMAD3, and proliferating cell nuclear antigen that are involved with redox status, the cell cycle, and the proteasome system, along with immunologic genes, suggesting regulation of anticancer immunity. Thus, exploring the gene expression profile of PBMCs may be a surrogate approach for the assessment of local HCC-infiltrating mononuclear inflammatory cells.

Standard name | JEON_SMAD6_TARGETS_UP
Systematic name | M4592
Organism | Homo sapiens
PMID | 19047146
Authors | Jeon HS,Dracheva T,Yang SH,Meerzaman D,Fukuoka J,Shakoori A,Shilo K,Travis WD,Jen J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in H1299 cells (lung cancer) upon knockdown of SMAD6 [GeneID=4091] by RNAi.
Full description | The malignant transformation in several types of cancer, including lung cancer, results in a loss of growth inhibition by transforming growth factor-beta (TGF-beta). Here, we show that SMAD6 expression is associated with a reduced survival in lung cancer patients. Short hairpin RNA (shRNA)-mediated knockdown of SMAD6 in lung cancer cell lines resulted in reduced cell viability and increased apoptosis as well as inhibition of cell cycle progression. However, these results were not seen in Beas2B, a normal bronchial epithelial cell line. To better understand the mechanism underlying the association of SMAD6 with poor patient survival, we used a lentivirus construct carrying shRNA for SMAD6 to knock down expression of the targeted gene. Through gene expression analysis, we observed that knockdown of SMAD6 led to the activation of TGF-beta signaling through up-regulation of plasminogen activator inhibitor-1 and phosphorylation of SMAD2/3. Furthermore, SMAD6 knockdown activated the c-Jun NH2-terminal kinase pathway and reduced phosphorylation of Rb-1, resulting in increased G0-G1 cell arrest and apoptosis in the lung cancer cell line H1299. These results jointly suggest that SMAD6 plays a critical role in supporting lung cancer cell growth and survival. Targeted inactivation of SMAD6 may provide a novel therapeutic strategy for lung cancers expressing this gene.

Standard name | JEON_SMAD6_TARGETS_DN
Systematic name | M13678
Organism | Homo sapiens
PMID | 19047146
Authors | Jeon HS,Dracheva T,Yang SH,Meerzaman D,Fukuoka J,Shakoori A,Shilo K,Travis WD,Jen J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in H1299 cells (lung cancer) upon knockdown of SMAD6 [GeneID=4091] by RNAi.
Full description | The malignant transformation in several types of cancer, including lung cancer, results in a loss of growth inhibition by transforming growth factor-beta (TGF-beta). Here, we show that SMAD6 expression is associated with a reduced survival in lung cancer patients. Short hairpin RNA (shRNA)-mediated knockdown of SMAD6 in lung cancer cell lines resulted in reduced cell viability and increased apoptosis as well as inhibition of cell cycle progression. However, these results were not seen in Beas2B, a normal bronchial epithelial cell line. To better understand the mechanism underlying the association of SMAD6 with poor patient survival, we used a lentivirus construct carrying shRNA for SMAD6 to knock down expression of the targeted gene. Through gene expression analysis, we observed that knockdown of SMAD6 led to the activation of TGF-beta signaling through up-regulation of plasminogen activator inhibitor-1 and phosphorylation of SMAD2/3. Furthermore, SMAD6 knockdown activated the c-Jun NH2-terminal kinase pathway and reduced phosphorylation of Rb-1, resulting in increased G0-G1 cell arrest and apoptosis in the lung cancer cell line H1299. These results jointly suggest that SMAD6 plays a critical role in supporting lung cancer cell growth and survival. Targeted inactivation of SMAD6 may provide a novel therapeutic strategy for lung cancers expressing this gene.

Standard name | WANG_PROSTATE_CANCER_ANDROGEN_INDEPENDENT
Systematic name | M16347
Organism | Homo sapiens
PMID | 19047173
Authors | Wang G,Wang J,Sadar MD
Category | C2
Sub-category | CGP
Brief description | Genes changed in prostate cancer: androgen independent vs androgen dependent samples.
Full description | The androgen-signaling pathway plays an important role in the development and hormonal progression of prostate cancer to the castrate-resistant stage (also called androgen-independent or hormone refractory). The Wnt pathway and beta-catenin contribute to prostate biology and pathology. Here application of Affymetrix GeneChip analysis revealed the genomic similarity of the LNCaP hollow fiber model to clinical samples and identified genes with differential expression during hormonal progression. The fiber model samples clustered according to the expression profile of androgen-regulated genes to provide genomic evidence for the reactivation of the AR signaling pathway in castrate-resistant prostate cancer. Pathway-based characterization of gene expression identified activation of the Wnt pathway. Together with the increased expression of AR and beta-catenin, there was increased nuclear colocalization and interaction of endogenous AR and beta-catenin in castrate-resistant prostate cancer from castrated mice. Surprisingly, no interaction or colocalization of AR and beta-catenin could be detected in xenografts from noncastrated mice. These studies provide the first in vivo evidence to support aberrant activation of the AR through the Wnt/beta-catenin signaling pathway during progression of prostate cancer to the terminal castrate-resistant stage.

Standard name | SUNG_METASTASIS_STROMA_UP
Systematic name | M9483
Organism | Homo sapiens
PMID | 19047182
Authors | Sung SY,Hsieh CL,Law A,Zhau HE,Pathak S,Multani AS,Lim S,Coleman IM,Wu LC,Figg WD,Dahut WL,Nelson P,Lee JK,Amin MB,Lyles R,Johnstone PA,Marshall FF,Chung LW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in metastatic vs non-metastatic stromal cells originated from either bone or prostate tissues.
Full description | Human bone stromal cells, after three-dimensional coculture with human prostate cancer (PCa) cells in vitro, underwent permanent cytogenetic and gene expression changes with reactive oxygen species serving as mediators. The evolved stromal cells are highly inductive of human PCa growth in mice, and expressed increased levels of extracellular matrix (versican and tenascin) and chemokine (BDFN, CCL5, CXCL5, and CXCL16) genes. These genes were validated in clinical tissue and/or serum specimens and could be the predictors for invasive and bone metastatic PCa. These results, combined with our previous observations, support the concept of permanent genetic and behavioral changes of PCa epithelial cells after being either cocultured with prostate or bone stromal cells as three-dimensional prostate organoids or grown as tumor xenografts in mice. These observations collectively suggest coevolution of cancer and stromal cells occurred under three-dimensional growth condition, which ultimately accelerates cancer growth and metastasis.

Standard name | SUNG_METASTASIS_STROMA_DN
Systematic name | M2904
Organism | Homo sapiens
PMID | 19047182
Authors | Sung SY,Hsieh CL,Law A,Zhau HE,Pathak S,Multani AS,Lim S,Coleman IM,Wu LC,Figg WD,Dahut WL,Nelson P,Lee JK,Amin MB,Lyles R,Johnstone PA,Marshall FF,Chung LW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in metastatic vs non-metastatic stromal cells originated from either bone or prostate tissues.
Full description | Human bone stromal cells, after three-dimensional coculture with human prostate cancer (PCa) cells in vitro, underwent permanent cytogenetic and gene expression changes with reactive oxygen species serving as mediators. The evolved stromal cells are highly inductive of human PCa growth in mice, and expressed increased levels of extracellular matrix (versican and tenascin) and chemokine (BDFN, CCL5, CXCL5, and CXCL16) genes. These genes were validated in clinical tissue and/or serum specimens and could be the predictors for invasive and bone metastatic PCa. These results, combined with our previous observations, support the concept of permanent genetic and behavioral changes of PCa epithelial cells after being either cocultured with prostate or bone stromal cells as three-dimensional prostate organoids or grown as tumor xenografts in mice. These observations collectively suggest coevolution of cancer and stromal cells occurred under three-dimensional growth condition, which ultimately accelerates cancer growth and metastasis.

Standard name | SHIN_B_CELL_LYMPHOMA_CLUSTER_1
Systematic name | M1383
Organism | Mus musculus
PMID | 19010892
Authors | Shin DM,Shaffer DJ,Wang H,Roopenian DC,Morse HC 3rd
Category | C2
Sub-category | CGP
Brief description | Cluster 1 of genes distinguishing among different B lymphocyte neoplasms.
Full description | Aside from Myc-activating translocations characteristic of plasmacytomas (PCT), little is known about genetic factors and signaling pathways responsible for the development of spontaneous B-cell lineage lymphomas of mice. Here, we characterized the transcriptional profiles of PCT, centroblastic diffuse large B-cell lymphomas (CBL), and high-grade splenic marginal zone B-cell lymphoma (MZL++) using high-throughput quantitative reverse transcription-PCR. Expression profiles of CBL and MZL++ were strikingly similar and quite unlike that of PCT. Among the genes expressed at significantly higher levels by PCT were a number involved in NOTCH signaling, a finding supported by gene set enrichment analyses of microarray data. To investigate the importance of this pathway, NOTCH signaling was blocked in PCT cell lines by treatment with a gamma-secretase inhibitor (GSI) or transduction of a dominant-negative mutant of MAML1. These treatments resulted in reduced expression of NOTCH transcriptional targets in association with impaired proliferation and increased apoptosis. GSI treatment of transformed plasma cells in a primary PCT also induced apoptosis. These results integrate NOTCH activation with oncogenic signaling pathways downstream of translocated Myc in the pathogenesis of mouse PCT, two signaling pathways also implicated in development of human multiple myeloma and T-cell lymphoblastic lymphoma.

Standard name | SHIN_B_CELL_LYMPHOMA_CLUSTER_2
Systematic name | M1384
Organism | Mus musculus
PMID | 19010892
Authors | Shin DM,Shaffer DJ,Wang H,Roopenian DC,Morse HC 3rd
Category | C2
Sub-category | CGP
Brief description | Cluster 2 of genes distinguishing among different B lymphocyte neoplasms.
Full description | Aside from Myc-activating translocations characteristic of plasmacytomas (PCT), little is known about genetic factors and signaling pathways responsible for the development of spontaneous B-cell lineage lymphomas of mice. Here, we characterized the transcriptional profiles of PCT, centroblastic diffuse large B-cell lymphomas (CBL), and high-grade splenic marginal zone B-cell lymphoma (MZL++) using high-throughput quantitative reverse transcription-PCR. Expression profiles of CBL and MZL++ were strikingly similar and quite unlike that of PCT. Among the genes expressed at significantly higher levels by PCT were a number involved in NOTCH signaling, a finding supported by gene set enrichment analyses of microarray data. To investigate the importance of this pathway, NOTCH signaling was blocked in PCT cell lines by treatment with a gamma-secretase inhibitor (GSI) or transduction of a dominant-negative mutant of MAML1. These treatments resulted in reduced expression of NOTCH transcriptional targets in association with impaired proliferation and increased apoptosis. GSI treatment of transformed plasma cells in a primary PCT also induced apoptosis. These results integrate NOTCH activation with oncogenic signaling pathways downstream of translocated Myc in the pathogenesis of mouse PCT, two signaling pathways also implicated in development of human multiple myeloma and T-cell lymphoblastic lymphoma.

Standard name | SHIN_B_CELL_LYMPHOMA_CLUSTER_3
Systematic name | M1387
Organism | Mus musculus
PMID | 19010892
Authors | Shin DM,Shaffer DJ,Wang H,Roopenian DC,Morse HC 3rd
Category | C2
Sub-category | CGP
Brief description | Cluster 3 of genes distinguishing among different B lymphocyte neoplasms.
Full description | Aside from Myc-activating translocations characteristic of plasmacytomas (PCT), little is known about genetic factors and signaling pathways responsible for the development of spontaneous B-cell lineage lymphomas of mice. Here, we characterized the transcriptional profiles of PCT, centroblastic diffuse large B-cell lymphomas (CBL), and high-grade splenic marginal zone B-cell lymphoma (MZL++) using high-throughput quantitative reverse transcription-PCR. Expression profiles of CBL and MZL++ were strikingly similar and quite unlike that of PCT. Among the genes expressed at significantly higher levels by PCT were a number involved in NOTCH signaling, a finding supported by gene set enrichment analyses of microarray data. To investigate the importance of this pathway, NOTCH signaling was blocked in PCT cell lines by treatment with a gamma-secretase inhibitor (GSI) or transduction of a dominant-negative mutant of MAML1. These treatments resulted in reduced expression of NOTCH transcriptional targets in association with impaired proliferation and increased apoptosis. GSI treatment of transformed plasma cells in a primary PCT also induced apoptosis. These results integrate NOTCH activation with oncogenic signaling pathways downstream of translocated Myc in the pathogenesis of mouse PCT, two signaling pathways also implicated in development of human multiple myeloma and T-cell lymphoblastic lymphoma.

Standard name | SHIN_B_CELL_LYMPHOMA_CLUSTER_5
Systematic name | M1388
Organism | Mus musculus
PMID | 19010892
Authors | Shin DM,Shaffer DJ,Wang H,Roopenian DC,Morse HC 3rd
Category | C2
Sub-category | CGP
Brief description | Cluster 5 of genes distinguishing among different B lymphocyte neoplasms.
Full description | Aside from Myc-activating translocations characteristic of plasmacytomas (PCT), little is known about genetic factors and signaling pathways responsible for the development of spontaneous B-cell lineage lymphomas of mice. Here, we characterized the transcriptional profiles of PCT, centroblastic diffuse large B-cell lymphomas (CBL), and high-grade splenic marginal zone B-cell lymphoma (MZL++) using high-throughput quantitative reverse transcription-PCR. Expression profiles of CBL and MZL++ were strikingly similar and quite unlike that of PCT. Among the genes expressed at significantly higher levels by PCT were a number involved in NOTCH signaling, a finding supported by gene set enrichment analyses of microarray data. To investigate the importance of this pathway, NOTCH signaling was blocked in PCT cell lines by treatment with a gamma-secretase inhibitor (GSI) or transduction of a dominant-negative mutant of MAML1. These treatments resulted in reduced expression of NOTCH transcriptional targets in association with impaired proliferation and increased apoptosis. GSI treatment of transformed plasma cells in a primary PCT also induced apoptosis. These results integrate NOTCH activation with oncogenic signaling pathways downstream of translocated Myc in the pathogenesis of mouse PCT, two signaling pathways also implicated in development of human multiple myeloma and T-cell lymphoblastic lymphoma.

Standard name | SHIN_B_CELL_LYMPHOMA_CLUSTER_6
Systematic name | M1390
Organism | Mus musculus
PMID | 19010892
Authors | Shin DM,Shaffer DJ,Wang H,Roopenian DC,Morse HC 3rd
Category | C2
Sub-category | CGP
Brief description | Cluster 6 of genes distinguishing among different B lymphocyte neoplasms.
Full description | Aside from Myc-activating translocations characteristic of plasmacytomas (PCT), little is known about genetic factors and signaling pathways responsible for the development of spontaneous B-cell lineage lymphomas of mice. Here, we characterized the transcriptional profiles of PCT, centroblastic diffuse large B-cell lymphomas (CBL), and high-grade splenic marginal zone B-cell lymphoma (MZL++) using high-throughput quantitative reverse transcription-PCR. Expression profiles of CBL and MZL++ were strikingly similar and quite unlike that of PCT. Among the genes expressed at significantly higher levels by PCT were a number involved in NOTCH signaling, a finding supported by gene set enrichment analyses of microarray data. To investigate the importance of this pathway, NOTCH signaling was blocked in PCT cell lines by treatment with a gamma-secretase inhibitor (GSI) or transduction of a dominant-negative mutant of MAML1. These treatments resulted in reduced expression of NOTCH transcriptional targets in association with impaired proliferation and increased apoptosis. GSI treatment of transformed plasma cells in a primary PCT also induced apoptosis. These results integrate NOTCH activation with oncogenic signaling pathways downstream of translocated Myc in the pathogenesis of mouse PCT, two signaling pathways also implicated in development of human multiple myeloma and T-cell lymphoblastic lymphoma.

Standard name | SHIN_B_CELL_LYMPHOMA_CLUSTER_7
Systematic name | M1391
Organism | Mus musculus
PMID | 19010892
Authors | Shin DM,Shaffer DJ,Wang H,Roopenian DC,Morse HC 3rd
Category | C2
Sub-category | CGP
Brief description | Cluster 7 of genes distinguishing among different B lymphocyte neoplasms.
Full description | Aside from Myc-activating translocations characteristic of plasmacytomas (PCT), little is known about genetic factors and signaling pathways responsible for the development of spontaneous B-cell lineage lymphomas of mice. Here, we characterized the transcriptional profiles of PCT, centroblastic diffuse large B-cell lymphomas (CBL), and high-grade splenic marginal zone B-cell lymphoma (MZL++) using high-throughput quantitative reverse transcription-PCR. Expression profiles of CBL and MZL++ were strikingly similar and quite unlike that of PCT. Among the genes expressed at significantly higher levels by PCT were a number involved in NOTCH signaling, a finding supported by gene set enrichment analyses of microarray data. To investigate the importance of this pathway, NOTCH signaling was blocked in PCT cell lines by treatment with a gamma-secretase inhibitor (GSI) or transduction of a dominant-negative mutant of MAML1. These treatments resulted in reduced expression of NOTCH transcriptional targets in association with impaired proliferation and increased apoptosis. GSI treatment of transformed plasma cells in a primary PCT also induced apoptosis. These results integrate NOTCH activation with oncogenic signaling pathways downstream of translocated Myc in the pathogenesis of mouse PCT, two signaling pathways also implicated in development of human multiple myeloma and T-cell lymphoblastic lymphoma.

Standard name | SHIN_B_CELL_LYMPHOMA_CLUSTER_8
Systematic name | M1392
Organism | Mus musculus
PMID | 19010892
Authors | Shin DM,Shaffer DJ,Wang H,Roopenian DC,Morse HC 3rd
Category | C2
Sub-category | CGP
Brief description | Cluster 8 of genes distinguishing among different B lymphocyte neoplasms.
Full description | Aside from Myc-activating translocations characteristic of plasmacytomas (PCT), little is known about genetic factors and signaling pathways responsible for the development of spontaneous B-cell lineage lymphomas of mice. Here, we characterized the transcriptional profiles of PCT, centroblastic diffuse large B-cell lymphomas (CBL), and high-grade splenic marginal zone B-cell lymphoma (MZL++) using high-throughput quantitative reverse transcription-PCR. Expression profiles of CBL and MZL++ were strikingly similar and quite unlike that of PCT. Among the genes expressed at significantly higher levels by PCT were a number involved in NOTCH signaling, a finding supported by gene set enrichment analyses of microarray data. To investigate the importance of this pathway, NOTCH signaling was blocked in PCT cell lines by treatment with a gamma-secretase inhibitor (GSI) or transduction of a dominant-negative mutant of MAML1. These treatments resulted in reduced expression of NOTCH transcriptional targets in association with impaired proliferation and increased apoptosis. GSI treatment of transformed plasma cells in a primary PCT also induced apoptosis. These results integrate NOTCH activation with oncogenic signaling pathways downstream of translocated Myc in the pathogenesis of mouse PCT, two signaling pathways also implicated in development of human multiple myeloma and T-cell lymphoblastic lymphoma.

Standard name | SHIN_B_CELL_LYMPHOMA_CLUSTER_9
Systematic name | M1393
Organism | Mus musculus
PMID | 19010892
Authors | Shin DM,Shaffer DJ,Wang H,Roopenian DC,Morse HC 3rd
Category | C2
Sub-category | CGP
Brief description | Cluster 9 of genes distinguishing among different B lymphocyte neoplasms.
Full description | Aside from Myc-activating translocations characteristic of plasmacytomas (PCT), little is known about genetic factors and signaling pathways responsible for the development of spontaneous B-cell lineage lymphomas of mice. Here, we characterized the transcriptional profiles of PCT, centroblastic diffuse large B-cell lymphomas (CBL), and high-grade splenic marginal zone B-cell lymphoma (MZL++) using high-throughput quantitative reverse transcription-PCR. Expression profiles of CBL and MZL++ were strikingly similar and quite unlike that of PCT. Among the genes expressed at significantly higher levels by PCT were a number involved in NOTCH signaling, a finding supported by gene set enrichment analyses of microarray data. To investigate the importance of this pathway, NOTCH signaling was blocked in PCT cell lines by treatment with a gamma-secretase inhibitor (GSI) or transduction of a dominant-negative mutant of MAML1. These treatments resulted in reduced expression of NOTCH transcriptional targets in association with impaired proliferation and increased apoptosis. GSI treatment of transformed plasma cells in a primary PCT also induced apoptosis. These results integrate NOTCH activation with oncogenic signaling pathways downstream of translocated Myc in the pathogenesis of mouse PCT, two signaling pathways also implicated in development of human multiple myeloma and T-cell lymphoblastic lymphoma.

Standard name | ZHANG_RESPONSE_TO_IKK_INHIBITOR_AND_TNF_UP
Systematic name | M19826
Organism | Homo sapiens
PMID | 19010928
Authors | Zhang Y,Gavriil M,Lucas J,Mandiyan S,Follettie M,Diesl V,Sum FW,Powell D,Haney S,Abraham R,Arndt K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in BxPC3 cells (pancreatic cancer) after treatment with TNF [GeneID=7124] or IKI-1, an inhibitor of IkappaB kinase (IKK).
Full description | Tumor necrosis factor alpha (TNFalpha) has been used to treat patients with certain tumor types. However, its antitumor activity has been undermined by the activation of IkappaBalpha kinase (IKK), which in turn activates nuclear factor-kappaB (NF-kappaB) to help cancer cells survive. Therefore, inhibition of TNFalpha-induced IKK activity with specific IKK inhibitor represents an attractive strategy to treat cancer patients. This study reveals IKI-1 as a potent small molecule inhibitor of IKKalpha and IKKbeta, which effectively blocked TNFalpha-mediated IKK activation and subsequent NF-kappaB activity. Using gene profiling analysis, we show that IKI-1 blocked most of the TNFalpha-mediated mRNA expression, including many genes that play important roles in cell survival. We further show that in vitro and in vivo combination of TNFalpha with IKI-1 had superior potency than either agent alone. This increased potency was due primarily to the increased apoptosis in the presence of both TNFalpha and IKI-1. Additionally, IKKbeta small interfering RNA transfected cells were more sensitive to the treatment of TNFalpha. The study suggests that the limited efficacy of TNFalpha in cancer treatment was due in part to the activation of NF-kappaB, allowing tumor cells to escape apoptosis. Therefore, the combination of IKI-1 with TNFalpha may improve the efficacy of TNFalpha for certain tumor types.

Standard name | ZHANG_RESPONSE_TO_IKK_INHIBITOR_AND_TNF_DN
Systematic name | M9160
Organism | Homo sapiens
PMID | 19010928
Authors | Zhang Y,Gavriil M,Lucas J,Mandiyan S,Follettie M,Diesl V,Sum FW,Powell D,Haney S,Abraham R,Arndt K
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in BxPC3 cells (pancreatic cancer) after treatment with TNF [GeneID=7124] or IKI-1, an inhibitor of IkappaB kinase (IKK).
Full description | Tumor necrosis factor alpha (TNFalpha) has been used to treat patients with certain tumor types. However, its antitumor activity has been undermined by the activation of IkappaBalpha kinase (IKK), which in turn activates nuclear factor-kappaB (NF-kappaB) to help cancer cells survive. Therefore, inhibition of TNFalpha-induced IKK activity with specific IKK inhibitor represents an attractive strategy to treat cancer patients. This study reveals IKI-1 as a potent small molecule inhibitor of IKKalpha and IKKbeta, which effectively blocked TNFalpha-mediated IKK activation and subsequent NF-kappaB activity. Using gene profiling analysis, we show that IKI-1 blocked most of the TNFalpha-mediated mRNA expression, including many genes that play important roles in cell survival. We further show that in vitro and in vivo combination of TNFalpha with IKI-1 had superior potency than either agent alone. This increased potency was due primarily to the increased apoptosis in the presence of both TNFalpha and IKI-1. Additionally, IKKbeta small interfering RNA transfected cells were more sensitive to the treatment of TNFalpha. The study suggests that the limited efficacy of TNFalpha in cancer treatment was due in part to the activation of NF-kappaB, allowing tumor cells to escape apoptosis. Therefore, the combination of IKI-1 with TNFalpha may improve the efficacy of TNFalpha for certain tumor types.

Standard name | MORI_PRE_BI_LYMPHOCYTE_UP
Systematic name | M1395
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the B lymphocyte developmental signature, based on expression profiling of lymphomas from the Emu-myc transgenic mice: the Pre-BI stage.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_PRE_BI_LYMPHOCYTE_DN
Systematic name | M6455
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the B lymphocyte developmental signature, based on expression profiling of lymphomas from the Emu-myc transgenic mice: the Pre-BI stage.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_LARGE_PRE_BII_LYMPHOCYTE_UP
Systematic name | M19287
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the B lymphocyte developmental signature, based on expression profiling of lymphomas from the Emu-myc transgenic mice: the Large Pre-BII stage.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_LARGE_PRE_BII_LYMPHOCYTE_DN
Systematic name | M4856
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the B lymphocyte developmental signature, based on expression profiling of lymphomas from the Emu-myc transgenic mice: the Large Pre-BII stage.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_SMALL_PRE_BII_LYMPHOCYTE_UP
Systematic name | M19751
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the B lymphocyte developmental signature, based on expression profiling of lymphomas from the Emu-myc transgenic mice: the Small Pre-BII stage.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_SMALL_PRE_BII_LYMPHOCYTE_DN
Systematic name | M13396
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the B lymphocyte developmental signature, based on expression profiling of lymphomas from the Emu-myc transgenic mice: the Small Pre-BII stage.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_IMMATURE_B_LYMPHOCYTE_UP
Systematic name | M11262
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the B lymphocyte developmental signature based on expression profiling of lymphomas from the Emu-myc transgenic mice: the immature B stage.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_IMMATURE_B_LYMPHOCYTE_DN
Systematic name | M18917
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the B lymphocyte developmental signature based on expression profiling of lymphomas from the Emu-myc transgenic mice: the immature B stage.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_MATURE_B_LYMPHOCYTE_UP
Systematic name | M17083
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the B lymphocyte developmental signature, based on expression profiling of lymphomas from the Emu-myc transgenic mice: the mature B
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_MATURE_B_LYMPHOCYTE_DN
Systematic name | M15847
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the B lymphocyte developmental signature, based on expression profiling of lymphomas from the Emu-myc transgenic mice: the mature B
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_PLASMA_CELL_UP
Systematic name | M1487
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the B lymphocyte developmental signature, based on expression profiling of lymphomas from the Emu-myc transgenic mice: plasma cell.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_PLASMA_CELL_DN
Systematic name | M19509
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the B lymphocyte developmental signature, based on expression profiling of lymphomas from the Emu-myc transgenic mice: plasma cell.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_EMU_MYC_LYMPHOMA_BY_ONSET_TIME_UP
Systematic name | M4939
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Genes correlated with the early tumor onset in the Emu-myc transgenic mouse lymphoma model.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | MORI_EMU_MYC_LYMPHOMA_BY_ONSET_TIME_DN
Systematic name | M3621
Organism | Mus musculus
PMID | 18922927
Authors | Mori S,Rempel RE,Chang JT,Yao G,Lagoo AS,Potti A,Bild A,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Genes correlated with the late tumor onset in the Emu-myc transgenic mouse lymphoma model.
Full description | The Emu-myc transgenic mouse has provided a valuable model for the study of B-cell lymphoma. Making use of gene expression analysis and, in particular, expression signatures of cell signaling pathway activation, we now show that several forms of B lymphoma can be identified in the Emu-myc mice associated with time of tumor onset. Furthermore, one form of Emu-myc tumor with pre-B character is shown to resemble human Burkitt lymphoma, whereas others exhibit more differentiated B-cell characteristics and show similarity with human diffuse large B-cell lymphoma in the pattern of gene expression, as well as oncogenic pathway activation. Importantly, we show that signatures of oncogenic pathway activity provide further dissection of the spectrum of diffuse large B-cell lymphoma, identifying a subset of patients who have very poor prognosis and could benefit from more aggressive or novel therapeutic strategies. Taken together, these studies provide insight into the complexity of the oncogenic process and a novel strategy for dissecting the heterogeneity of B lymphoma.

Standard name | COLLIS_PRKDC_SUBSTRATES
Systematic name | M4495
Organism | Homo sapiens
PMID | 15592499
Authors | Collis SJ,DeWeese TL,Jeggo PA,Parker AR
Category | C2
Sub-category | CGP
Brief description | Substrates of PRKDC [GeneID=5591].
Full description | Double-strand breaks (DSBs) arise endogenously during normal cellular processes and exogenously by genotoxic agents such as ionizing radiation (IR). DSBs are one of the most severe types of DNA damage, which if left unrepaired are lethal to the cell. Several different DNA repair pathways combat DSBs, with nonhomologous end-joining (NHEJ) being one of the most important in mammalian cells. Competent NHEJ catalyses repair of DSBs by joining together and ligating two free DNA ends of little homology (microhomology) or DNA ends of no homology. The core components of mammalian NHEJ are the catalytic subunit of DNA protein kinase (DNA-PK(cs)), Ku subunits Ku70 and Ku80, Artemis, XRCC4 and DNA ligase IV. DNA-PK is a nuclear serine/threonine protein kinase that comprises a catalytic subunit (DNA-PK(cs)), with the Ku subunits acting as the regulatory element. It has been proposed that DNA-PK is a molecular sensor for DNA damage that enhances the signal via phosphorylation of many downstream targets. The crucial role of DNA-PK in the repair of DSBs is highlighted by the hypersensitivity of DNA-PK(-/-) mice to IR and the high levels of unrepaired DSBs after genotoxic insult. Recently, DNA-PK has emerged as a suitable genetic target for molecular therapeutics such as siRNA, antisense and novel inhibitory small molecules. This review encompasses the recent literature regarding the role of DNA-PK in the protection of genomic stability and focuses on how this knowledge has aided the development of specific DNA-PK inhibitors, via both small molecule and directed molecular targeting techniques. This review promotes the inhibition of DNA-PK as a valid approach to enhance the tumor-cell-killing effects of treatments such as IR.

Standard name | COLLIS_PRKDC_REGULATORS
Systematic name | M5839
Organism | Homo sapiens
PMID | 15592499
Authors | Collis SJ,DeWeese TL,Jeggo PA,Parker AR
Category | C2
Sub-category | CGP
Brief description | Proteins that regulate activity of PRKDC [GeneID=5591].
Full description | Double-strand breaks (DSBs) arise endogenously during normal cellular processes and exogenously by genotoxic agents such as ionizing radiation (IR). DSBs are one of the most severe types of DNA damage, which if left unrepaired are lethal to the cell. Several different DNA repair pathways combat DSBs, with nonhomologous end-joining (NHEJ) being one of the most important in mammalian cells. Competent NHEJ catalyses repair of DSBs by joining together and ligating two free DNA ends of little homology (microhomology) or DNA ends of no homology. The core components of mammalian NHEJ are the catalytic subunit of DNA protein kinase (DNA-PK(cs)), Ku subunits Ku70 and Ku80, Artemis, XRCC4 and DNA ligase IV. DNA-PK is a nuclear serine/threonine protein kinase that comprises a catalytic subunit (DNA-PK(cs)), with the Ku subunits acting as the regulatory element. It has been proposed that DNA-PK is a molecular sensor for DNA damage that enhances the signal via phosphorylation of many downstream targets. The crucial role of DNA-PK in the repair of DSBs is highlighted by the hypersensitivity of DNA-PK(-/-) mice to IR and the high levels of unrepaired DSBs after genotoxic insult. Recently, DNA-PK has emerged as a suitable genetic target for molecular therapeutics such as siRNA, antisense and novel inhibitory small molecules. This review encompasses the recent literature regarding the role of DNA-PK in the protection of genomic stability and focuses on how this knowledge has aided the development of specific DNA-PK inhibitors, via both small molecule and directed molecular targeting techniques. This review promotes the inhibition of DNA-PK as a valid approach to enhance the tumor-cell-killing effects of treatments such as IR.

Standard name | TOMIDA_LUNG_CANCER_POOR_SURVIVAL
Systematic name | M1397
Organism | Homo sapiens
PMID | 17260014
Authors | Tomida S,Yanagisawa K,Koshikawa K,Yatabe Y,Mitsudomi T,Osada H,Takahashi T
Category | C2
Sub-category | CGP
Brief description | Metastatic signature genes that best distinguished between favorable and unfavorable prognosis for the non-small cell lung cancer (NSCLC) patients.
Full description | Although widespread metastasis is the major cause of human lung cancer-related deaths, its underlying mechanism remains largely unclear. Our genome-wide comparison of the expression profiles of a highly metastatic lung cancer cell line, NCI-H460-LNM35 (LNM35), and its parental clone, NCI-H460-N15 (N15), resulted in the identification of a cancer metastasis signature composed of 45 genes. Through gene ontology analysis, our study also provided insights into how this 45-gene metastasis signature may contribute to the acquisition of metastatic potential. By applying the signature to datasets of human cancer cases, we could demonstrate significant associations with a subset of cases with poor prognosis not only for the two datasets of cancers of the lung but also for cancers of the breast. Furthermore, we were able to show that enforced expression of the DLX4 homeobox gene, which was identified as a gene with significant downregulation in LNM35 as well as with significant association with favorable prognosis for lung cancer patients, markedly inhibited in vitro motility and invasion as well as in vivo metastasis via both hematogenous and lymphogenous routes. Taken together, these findings indicate that our combined transcriptome analysis is an efficient approach in the search for genes possessing both clinical usefulness in terms of prognostic prediction in human cancer cases and clear functional relevance for studying cancer biology in relation to metastasis.

Standard name | LEE_TARGETS_OF_PTCH1_AND_SUFU_UP
Systematic name | M7669
Organism | Mus musculus
PMID | 17452975
Authors | Lee Y,Kawagoe R,Sasai K,Li Y,Russell HR,Curran T,McKinnon PJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in medulloblastoma tumors from animals with inactivating mutations of one copy of PTCH1 or SUFU [GeneID=5727;51684] in conjunction with TP53 [GeneID=7157] loss.
Full description | The Sonic Hedgehog (SHH) signaling pathway is indispensable for development, and functions to activate a transcriptional program modulated by the GLI transcription factors. Here, we report that loss of a regulator of the SHH pathway, Suppressor of Fused (Sufu), resulted in early embryonic lethality in the mouse similar to inactivation of another SHH regulator, Patched1 (Ptch1). In contrast to Ptch1+/- mice, Sufu+/- mice were not tumor prone. However, in conjunction with p53 loss, Sufu+/- animals developed tumors including medulloblastoma and rhabdomyosarcoma. Tumors present in Sufu+/-p53-/- animals resulted from Sufu loss of heterozygosity. Sufu+/-p53-/- medulloblastomas also expressed a signature gene expression profile typical of aberrant SHH signaling, including upregulation of N-myc, Sfrp1, Ptch2 and cyclin D1. Finally, the Smoothened inhibitor, hedgehog antagonist, did not block growth of tumors arising from Sufu inactivation. These data demonstrate that Sufu is essential for development and functions as a tumor suppressor.

Standard name | LEE_TARGETS_OF_PTCH1_AND_SUFU_DN
Systematic name | M16478
Organism | Mus musculus
PMID | 17452975
Authors | Lee Y,Kawagoe R,Sasai K,Li Y,Russell HR,Curran T,McKinnon PJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in medulloblastoma tumors from animals with inactivating mutations of one copy of PTCH1 or SUFU [GeneID=5727;51684] in conjunction with TP53 [GeneID=7157] loss.
Full description | The Sonic Hedgehog (SHH) signaling pathway is indispensable for development, and functions to activate a transcriptional program modulated by the GLI transcription factors. Here, we report that loss of a regulator of the SHH pathway, Suppressor of Fused (Sufu), resulted in early embryonic lethality in the mouse similar to inactivation of another SHH regulator, Patched1 (Ptch1). In contrast to Ptch1+/- mice, Sufu+/- mice were not tumor prone. However, in conjunction with p53 loss, Sufu+/- animals developed tumors including medulloblastoma and rhabdomyosarcoma. Tumors present in Sufu+/-p53-/- animals resulted from Sufu loss of heterozygosity. Sufu+/-p53-/- medulloblastomas also expressed a signature gene expression profile typical of aberrant SHH signaling, including upregulation of N-myc, Sfrp1, Ptch2 and cyclin D1. Finally, the Smoothened inhibitor, hedgehog antagonist, did not block growth of tumors arising from Sufu inactivation. These data demonstrate that Sufu is essential for development and functions as a tumor suppressor.

Standard name | KAUFFMANN_DNA_REPAIR_GENES
Systematic name | M11563
Organism | Homo sapiens
PMID | 17891185
Authors | Kauffmann A,Rosselli F,Lazar V,Winnepenninckx V,Mansuet-Lupo A,Dessen P,van den Oord JJ,Spatz A,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes involved in DNA repair, compiled manually by the authors.
Full description | We have identified a gene-profile signature for human primary malignant melanoma associated with metastasis to distant sites and poor prognosis. We analyse the differential gene expression by looking at whole biological pathways rather than individual genes. Among the most significant pathways associated with progression to metastasis, we found the DNA replication (P=10(-14)) and the DNA repair pathways (P=10(-16)). We concentrated our analysis on DNA repair and found that 48 genes of this category, among a list of 234 genes, are associated with metastatic progression. These genes belong essentially to the pathways allowing recovery of stalled replication forks due to spontaneous blockage or induced DNA lesions. Because almost all these differentially expressed repair genes were overexpressed in primary tumors with bad prognosis, we speculate that primary melanoma cells that will metastasize try to replicate in a fast and error-free mode. In contrast to the progression from melanocytes to primary melanoma, genetic stability appears to be necessary for a melanoma cell to give rise to distant metastasis. This overexpression of repair genes explains nicely the extraordinary resistance of metastatic melanoma to chemo- and radio-therapy. Our results may open a new avenue for the discovery of drugs active on human metastatic melanoma.

Standard name | KAUFFMANN_DNA_REPLICATION_GENES
Systematic name | M9372
Organism | Homo sapiens
PMID | 17891185
Authors | Kauffmann A,Rosselli F,Lazar V,Winnepenninckx V,Mansuet-Lupo A,Dessen P,van den Oord JJ,Spatz A,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Genes involved in DNA replication, compiled manually by the authors.
Full description | We have identified a gene-profile signature for human primary malignant melanoma associated with metastasis to distant sites and poor prognosis. We analyse the differential gene expression by looking at whole biological pathways rather than individual genes. Among the most significant pathways associated with progression to metastasis, we found the DNA replication (P=10(-14)) and the DNA repair pathways (P=10(-16)). We concentrated our analysis on DNA repair and found that 48 genes of this category, among a list of 234 genes, are associated with metastatic progression. These genes belong essentially to the pathways allowing recovery of stalled replication forks due to spontaneous blockage or induced DNA lesions. Because almost all these differentially expressed repair genes were overexpressed in primary tumors with bad prognosis, we speculate that primary melanoma cells that will metastasize try to replicate in a fast and error-free mode. In contrast to the progression from melanocytes to primary melanoma, genetic stability appears to be necessary for a melanoma cell to give rise to distant metastasis. This overexpression of repair genes explains nicely the extraordinary resistance of metastatic melanoma to chemo- and radio-therapy. Our results may open a new avenue for the discovery of drugs active on human metastatic melanoma.

Standard name | NIKOLSKY_BREAST_CANCER_1Q21_AMPLICON
Systematic name | M5497
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 1q21 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_1Q32_AMPLICON
Systematic name | M1207
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 1q32 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_5P15_AMPLICON
Systematic name | M13766
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 5p15 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_6P24_P22_AMPLICON
Systematic name | M4276
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 6p24-p22 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_7P22_AMPLICON
Systematic name | M15884
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 7p22 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_7P15_AMPLICON
Systematic name | M18241
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 7p15 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_7Q21_Q22_AMPLICON
Systematic name | M5278
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 7q21-q22 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_8P12_P11_AMPLICON
Systematic name | M8293
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 8p12-p11 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_8Q12_Q22_AMPLICON
Systematic name | M13954
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 8q12-q22 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_8Q23_Q24_AMPLICON
Systematic name | M17936
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 8q23-q24 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_10Q22_AMPLICON
Systematic name | M4042
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 10q22 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_11Q12_Q14_AMPLICON
Systematic name | M1493
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 11q12-q14 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_12Q13_Q21_AMPLICON
Systematic name | M13709
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 12q13-q21 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_12Q24_AMPLICON
Systematic name | M8432
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 12q24 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_14Q22_AMPLICON
Systematic name | M17961
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 14q22 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_15Q26_AMPLICON
Systematic name | M1352
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 15q26 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_16P13_AMPLICON
Systematic name | M1788
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 16p13 identified in a study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_16Q24_AMPLICON
Systematic name | M12307
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 16q24 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_17P11_AMPLICON
Systematic name | M2253
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 17p11 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_17Q11_Q21_AMPLICON
Systematic name | M3434
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 17q11-q21 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_17Q21_Q25_AMPLICON
Systematic name | M15936
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 17q21-q25 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_19P13_AMPLICON
Systematic name | M14137
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 19p13 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_19Q13.1_AMPLICON
Systematic name | M8692
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 19q13.1 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_19Q13.4_AMPLICON
Systematic name | M4709
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 19q13.4 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_20P13_AMPLICON
Systematic name | M6821
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 20p13 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_20Q11_AMPLICON
Systematic name | M10837
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 20q11 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_20Q12_Q13_AMPLICON
Systematic name | M18973
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 20q12-q13 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_21Q22_AMPLICON
Systematic name | M5718
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 21q22 identified in a copy alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_BREAST_CANCER_22Q13_AMPLICON
Systematic name | M12053
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes within amplicon 22q13 identified in a copy number alterations study of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | NIKOLSKY_MUTATED_AND_AMPLIFIED_IN_BREAST_CANCER
Systematic name | M18108
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Genes both mutated and amplified in a panel of 191 breast tumor samples.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | WHITEHURST_PACLITAXEL_SENSITIVITY
Systematic name | M10597
Organism | Homo sapiens
PMID | 17429401
Authors | Whitehurst AW,Bodemann BO,Cardenas J,Ferguson D,Girard L,Peyton M,Minna JD,Michnoff C,Hao W,Roth MG,Xie XJ,White MA
Category | C2
Sub-category | CGP
Brief description | Genes that reduced viability of NCI-H1155 cells (non-small-cell lung cancer, NSCLC) in the presence of otherwise sublethal concentrations of paclitaxel [PubChem=4666], based on RNAi synthetic lethal screen.
Full description | Abundant evidence suggests that a unifying principle governing the molecular pathology of cancer is the co-dependent aberrant regulation of core machinery driving proliferation and suppressing apoptosis. Anomalous proteins engaged in support of this tumorigenic regulatory environment most probably represent optimal intervention targets in a heterogeneous population of cancer cells. The advent of RNA-mediated interference (RNAi)-based functional genomics provides the opportunity to derive unbiased comprehensive collections of validated gene targets supporting critical biological systems outside the framework of preconceived notions of mechanistic relationships. We have combined a high-throughput cell-based one-well/one-gene screening platform with a genome-wide synthetic library of chemically synthesized small interfering RNAs for systematic interrogation of the molecular underpinnings of cancer cell chemoresponsiveness. NCI-H1155, a human non-small-cell lung cancer line, was employed in a paclitaxel-dependent synthetic lethal screen designed to identify gene targets that specifically reduce cell viability in the presence of otherwise sublethal concentrations of paclitaxel. Using a stringent objective statistical algorithm to reduce false discovery rates below 5%, we isolated a panel of 87 genes that represent major focal points of the autonomous response of cancer cells to the abrogation of microtubule dynamics. Here we show that several of these targets sensitize lung cancer cells to paclitaxel concentrations 1,000-fold lower than otherwise required for a significant response, and we identify mechanistic relationships between cancer-associated aberrant gene expression programmes and the basic cellular machinery required for robust mitotic progression.

Standard name | STEGMEIER_PREMITOTIC_CELL_CYCLE_REGULATORS
Systematic name | M9183
Organism | Homo sapiens
PMID | 17443180
Authors | Stegmeier F,Rape M,Draviam VM,Nalepa G,Sowa ME,Ang XL,McDonald ER 3rd,Li MZ,Hannon GJ,Sorger PK,Kirschner MW,Harper JW,Elledge SJ
Category | C2
Sub-category | CGP
Brief description | Pre-mitotic cell cycle regulators (CDC) identified in an shRNA screen of the ubiquitin pathway components.
Full description | The spindle checkpoint prevents chromosome mis-segregation by delaying sister chromatid separation until all chromosomes have achieved bipolar attachment to the mitotic spindle. Its operation is essential for accurate chromosome segregation, whereas its dysregulation can contribute to birth defects and tumorigenesis. The target of the spindle checkpoint is the anaphase-promoting complex (APC), a ubiquitin ligase that promotes sister chromatid separation and progression to anaphase. Using a short hairpin RNA screen targeting components of the ubiquitin-proteasome pathway in human cells, we identified the deubiquitinating enzyme USP44 (ubiquitin-specific protease 44) as a critical regulator of the spindle checkpoint. USP44 is not required for the initial recognition of unattached kinetochores and the subsequent recruitment of checkpoint components. Instead, it prevents the premature activation of the APC by stabilizing the APC-inhibitory Mad2-Cdc20 complex. USP44 deubiquitinates the APC coactivator Cdc20 both in vitro and in vivo, and thereby directly counteracts the APC-driven disassembly of Mad2-Cdc20 complexes (discussed in an accompanying paper). Our findings suggest that a dynamic balance of ubiquitination by the APC and deubiquitination by USP44 contributes to the generation of the switch-like transition controlling anaphase entry, analogous to the way that phosphorylation and dephosphorylation of Cdk1 by Wee1 and Cdc25 controls entry into mitosis.

Standard name | TESAR_ALK_TARGETS_HUMAN_ES_4D_DN
Systematic name | M16516
Organism | Homo sapiens
PMID | 17597760
Authors | Tesar PJ,Chenoweth JG,Brook FA,Davies TJ,Evans EP,Mack DL,Gardner RL,McKay RD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hES cells (human embryonic stem cells) after treatment with the ALK [GeneID=238] inhibitor SB-431542 [PubChem=16079008].
Full description | The application of human embryonic stem (ES) cells in medicine and biology has an inherent reliance on understanding the starting cell population. Human ES cells differ from mouse ES cells and the specific embryonic origin of both cell types is unclear. Previous work suggested that mouse ES cells could only be obtained from the embryo before implantation in the uterus. Here we show that cell lines can be derived from the epiblast, a tissue of the post-implantation embryo that generates the embryo proper. These cells, which we refer to as EpiSCs (post-implantation epiblast-derived stem cells), express transcription factors known to regulate pluripotency, maintain their genomic integrity, and robustly differentiate into the major somatic cell types as well as primordial germ cells. The EpiSC lines are distinct from mouse ES cells in their epigenetic state and the signals controlling their differentiation. Furthermore, EpiSC and human ES cells share patterns of gene expression and signalling responses that normally function in the epiblast. These results show that epiblast cells can be maintained as stable cell lines and interrogated to understand how pluripotent cells generate distinct fates during early development.

Standard name | TESAR_ALK_TARGETS_HUMAN_ES_5D_UP
Systematic name | M19304
Organism | Homo sapiens
PMID | 17597760
Authors | Tesar PJ,Chenoweth JG,Brook FA,Davies TJ,Evans EP,Mack DL,Gardner RL,McKay RD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hES cells (human embryonic stem cells) after treatment with the ALK [GeneID=238] inhibitor SB-431542 [PubChem=4521392].
Full description | The application of human embryonic stem (ES) cells in medicine and biology has an inherent reliance on understanding the starting cell population. Human ES cells differ from mouse ES cells and the specific embryonic origin of both cell types is unclear. Previous work suggested that mouse ES cells could only be obtained from the embryo before implantation in the uterus. Here we show that cell lines can be derived from the epiblast, a tissue of the post-implantation embryo that generates the embryo proper. These cells, which we refer to as EpiSCs (post-implantation epiblast-derived stem cells), express transcription factors known to regulate pluripotency, maintain their genomic integrity, and robustly differentiate into the major somatic cell types as well as primordial germ cells. The EpiSC lines are distinct from mouse ES cells in their epigenetic state and the signals controlling their differentiation. Furthermore, EpiSC and human ES cells share patterns of gene expression and signalling responses that normally function in the epiblast. These results show that epiblast cells can be maintained as stable cell lines and interrogated to understand how pluripotent cells generate distinct fates during early development.

Standard name | TESAR_ALK_TARGETS_HUMAN_ES_5D_DN
Systematic name | M2811
Organism | Homo sapiens
PMID | 17597760
Authors | Tesar PJ,Chenoweth JG,Brook FA,Davies TJ,Evans EP,Mack DL,Gardner RL,McKay RD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hES cells (human embryonic stem cells) after treatment with the ALK [GeneID=238] inhibitor SB-431542 [PubChem=4521392].
Full description | The application of human embryonic stem (ES) cells in medicine and biology has an inherent reliance on understanding the starting cell population. Human ES cells differ from mouse ES cells and the specific embryonic origin of both cell types is unclear. Previous work suggested that mouse ES cells could only be obtained from the embryo before implantation in the uterus. Here we show that cell lines can be derived from the epiblast, a tissue of the post-implantation embryo that generates the embryo proper. These cells, which we refer to as EpiSCs (post-implantation epiblast-derived stem cells), express transcription factors known to regulate pluripotency, maintain their genomic integrity, and robustly differentiate into the major somatic cell types as well as primordial germ cells. The EpiSC lines are distinct from mouse ES cells in their epigenetic state and the signals controlling their differentiation. Furthermore, EpiSC and human ES cells share patterns of gene expression and signalling responses that normally function in the epiblast. These results show that epiblast cells can be maintained as stable cell lines and interrogated to understand how pluripotent cells generate distinct fates during early development.

Standard name | JI_METASTASIS_REPRESSED_BY_STK11
Systematic name | M18843
Organism | Homo sapiens
PMID | 17676035
Authors | Ji H,Ramsey MR,Hayes DN,Fan C,McNamara K,Kozlowski P,Torrice C,Wu MC,Shimamura T,Perera SA,Liang MC,Cai D,Naumov GN,Bao L,Contreras CM,Li D,Chen L,Krishnamurthy J,Koivunen J,Chirieac LR,Padera RF,Bronson RT,Lindeman NI,Christiani DC,Lin X,Shapiro GI,Jänne PA,Johnson BE,Meyerson M,Kwiatkowski DJ,Castrillon DH,Bardeesy N,Sharpless NE,Wong KK
Category | C2
Sub-category | CGP
Brief description | Adenocarcinoma metastatic program genes up-regulated in A549 and H2126 cells (lung cancer) lacking functional STK11 [GeneID=6794] but down-regulated by the normal gene.
Full description | Germline mutation in serine/threonine kinase 11 (STK11, also called LKB1) results in Peutz-Jeghers syndrome, characterized by intestinal hamartomas and increased incidence of epithelial cancers. Although uncommon in most sporadic cancers, inactivating somatic mutations of LKB1 have been reported in primary human lung adenocarcinomas and derivative cell lines. Here we used a somatically activatable mutant Kras-driven model of mouse lung cancer to compare the role of Lkb1 to other tumour suppressors in lung cancer. Although Kras mutation cooperated with loss of p53 or Ink4a/Arf (also known as Cdkn2a) in this system, the strongest cooperation was seen with homozygous inactivation of Lkb1. Lkb1-deficient tumours demonstrated shorter latency, an expanded histological spectrum (adeno-, squamous and large-cell carcinoma) and more frequent metastasis compared to tumours lacking p53 or Ink4a/Arf. Pulmonary tumorigenesis was also accelerated by hemizygous inactivation of Lkb1. Consistent with these findings, inactivation of LKB1 was found in 34% and 19% of 144 analysed human lung adenocarcinomas and squamous cell carcinomas, respectively. Expression profiling in human lung cancer cell lines and mouse lung tumours identified a variety of metastasis-promoting genes, such as NEDD9, VEGFC and CD24, as targets of LKB1 repression in lung cancer. These studies establish LKB1 as a critical barrier to pulmonary tumorigenesis, controlling initiation, differentiation and metastasis.

Standard name | GOTTWEIN_TARGETS_OF_KSHV_MIR_K12_11
Systematic name | M18201
Organism | Homo sapiens
PMID | 18075594
Authors | Gottwein E,Mukherjee N,Sachse C,Frenzel C,Majoros WH,Chi JT,Braich R,Manoharan M,Soutschek J,Ohler U,Cullen BR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in BJAB cell line (B lymphocyte) after expression of the viral microRNA miR-K12-11 which functions as an ortholog of cellular MIR155 [GeneID=406947].
Full description | All metazoan eukaryotes express microRNAs (miRNAs), roughly 22-nucleotide regulatory RNAs that can repress the expression of messenger RNAs bearing complementary sequences. Several DNA viruses also express miRNAs in infected cells, suggesting a role in viral replication and pathogenesis. Although specific viral miRNAs have been shown to autoregulate viral mRNAs or downregulate cellular mRNAs, the function of most viral miRNAs remains unknown. Here we report that the miR-K12-11 miRNA encoded by Kaposi's-sarcoma-associated herpes virus (KSHV) shows significant homology to cellular miR-155, including the entire miRNA 'seed' region. Using a range of assays, we show that expression of physiological levels of miR-K12-11 or miR-155 results in the downregulation of an extensive set of common mRNA targets, including genes with known roles in cell growth regulation. Our findings indicate that viral miR-K12-11 functions as an orthologue of cellular miR-155 and probably evolved to exploit a pre-existing gene regulatory pathway in B cells. Moreover, the known aetiological role of miR-155 in B-cell transformation suggests that miR-K12-11 may contribute to the induction of KSHV-positive B-cell tumours in infected patients.

Standard name | CHEN_NEUROBLASTOMA_COPY_NUMBER_GAINS
Systematic name | M1702
Organism | Homo sapiens
PMID | 18923524
Authors | Chen Y,Takita J,Choi YL,Kato M,Ohira M,Sanada M,Wang L,Soda M,Kikuchi A,Igarashi T,Nakagawara A,Hayashi Y,Mano H,Ogawa S
Category | C2
Sub-category | CGP
Brief description | High-grade amplification (copy number, CN >= 5) detected in primary neuroblastoma samples.
Full description | Neuroblastoma in advanced stages is one of the most intractable paediatric cancers, even with recent therapeutic advances. Neuroblastoma harbours a variety of genetic changes, including a high frequency of MYCN amplification, loss of heterozygosity at 1p36 and 11q, and gain of genetic material from 17q, all of which have been implicated in the pathogenesis of neuroblastoma. However, the scarcity of reliable molecular targets has hampered the development of effective therapeutic agents targeting neuroblastoma. Here we show that the anaplastic lymphoma kinase (ALK), originally identified as a fusion kinase in a subtype of non-Hodgkin's lymphoma (NPM-ALK) and more recently in adenocarcinoma of lung (EML4-ALK), is also a frequent target of genetic alteration in advanced neuroblastoma. According to our genome-wide scans of genetic lesions in 215 primary neuroblastoma samples using high-density single-nucleotide polymorphism genotyping microarrays, the ALK locus, centromeric to the MYCN locus, was identified as a recurrent target of copy number gain and gene amplification. Furthermore, DNA sequencing of ALK revealed eight novel missense mutations in 13 out of 215 (6.1%) fresh tumours and 8 out of 24 (33%) neuroblastoma-derived cell lines. All but one mutation in the primary samples (12 out of 13) were found in stages 3-4 of the disease and were harboured in the kinase domain. The mutated kinases were autophosphorylated and displayed increased kinase activity compared with the wild-type kinase. They were able to transform NIH3T3 fibroblasts as shown by their colony formation ability in soft agar and their capacity to form tumours in nude mice. Furthermore, we demonstrate that downregulation of ALK through RNA interference suppresses proliferation of neuroblastoma cells harbouring mutated ALK. We anticipate that our findings will provide new insights into the pathogenesis of advanced neuroblastoma and that ALK-specific kinase inhibitors might improve its clinical outcome.

Standard name | TCGA_GLIOBLASTOMA_COPY_NUMBER_UP
Systematic name | M5536
Organism | Homo sapiens
PMID | 18772890
Authors | Cancer Genome Atlas Research Network
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated and displaying increased copy number in glioblastoma samples.
Full description | Human cancer cells typically harbour multiple chromosomal aberrations, nucleotide substitutions and epigenetic modifications that drive malignant transformation. The Cancer Genome Atlas (TCGA) pilot project aims to assess the value of large-scale multi-dimensional analysis of these molecular characteristics in human cancer and to provide the data rapidly to the research community. Here we report the interim integrative analysis of DNA copy number, gene expression and DNA methylation aberrations in 206 glioblastomas--the most common type of adult brain cancer--and nucleotide sequence aberrations in 91 of the 206 glioblastomas. This analysis provides new insights into the roles of ERBB2, NF1 and TP53, uncovers frequent mutations of the phosphatidylinositol-3-OH kinase regulatory subunit gene PIK3R1, and provides a network view of the pathways altered in the development of glioblastoma. Furthermore, integration of mutation, DNA methylation and clinical treatment data reveals a link between MGMT promoter methylation and a hypermutator phenotype consequent to mismatch repair deficiency in treated glioblastomas, an observation with potential clinical implications. Together, these findings establish the feasibility and power of TCGA, demonstrating that it can rapidly expand knowledge of the molecular basis of cancer.

Standard name | TCGA_GLIOBLASTOMA_COPY_NUMBER_DN
Systematic name | M5520
Organism | Homo sapiens
PMID | 18772890
Authors | Cancer Genome Atlas Research Network
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated and displaying decreased copy number in glioblastoma samples.
Full description | Human cancer cells typically harbour multiple chromosomal aberrations, nucleotide substitutions and epigenetic modifications that drive malignant transformation. The Cancer Genome Atlas (TCGA) pilot project aims to assess the value of large-scale multi-dimensional analysis of these molecular characteristics in human cancer and to provide the data rapidly to the research community. Here we report the interim integrative analysis of DNA copy number, gene expression and DNA methylation aberrations in 206 glioblastomas--the most common type of adult brain cancer--and nucleotide sequence aberrations in 91 of the 206 glioblastomas. This analysis provides new insights into the roles of ERBB2, NF1 and TP53, uncovers frequent mutations of the phosphatidylinositol-3-OH kinase regulatory subunit gene PIK3R1, and provides a network view of the pathways altered in the development of glioblastoma. Furthermore, integration of mutation, DNA methylation and clinical treatment data reveals a link between MGMT promoter methylation and a hypermutator phenotype consequent to mismatch repair deficiency in treated glioblastomas, an observation with potential clinical implications. Together, these findings establish the feasibility and power of TCGA, demonstrating that it can rapidly expand knowledge of the molecular basis of cancer.

Standard name | DING_LUNG_CANCER_MUTATED_SIGNIFICANTLY
Systematic name | M16488
Organism | Homo sapiens
PMID | 18948947
Authors | Ding L,Getz G,Wheeler DA,Mardis ER,McLellan MD,Cibulskis K,Sougnez C,Greulich H,Muzny DM,Morgan MB,Fulton L,Fulton RS,Zhang Q,Wendl MC,Lawrence MS,Larson DE,Chen K,Dooling DJ,Sabo A,Hawes AC,Shen H,Jhangiani SN,Lewis LR,Hall O,Zhu Y,Mathew T,Ren Y,Yao J,Scherer SE,Clerc K,Metcalf GA,Ng B,Milosavljevic A,Gonzalez-Garay ML,Osborne JR,Meyer R,Shi X,Tang Y,Koboldt DC,Lin L,Abbott R,Miner TL,Pohl C,Fewell G,Haipek C,Schmidt H,Dunford-Shore BH,Kraja A,Crosby SD,Sawyer CS,Vickery T,Sander S,Robinson J,Winckler W,Baldwin J,Chirieac LR,Dutt A,Fennell T,Hanna M,Johnson BE,Onofrio RC,Thomas RK,Tonon G,Weir BA,Zhao X,Ziaugra L,Zody MC,Giordano T,Orringer MB,Roth JA,Spitz MR,Wistuba II,Ozenberger B,Good PJ,Chang AC,Beer DG,Watson MA,Ladanyi M,Broderick S,Yoshizawa A,Travis WD,Pao W,Province MA,Weinstock GM,Varmus HE,Gabriel SB,Lander ES,Gibbs RA,Meyerson M,Wilson RK
Category | C2
Sub-category | CGP
Brief description | The lung adenocarcinoma TSP (tumor sequencing project) genes that were found significantly mutated by at least one method.
Full description | Determining the genetic basis of cancer requires comprehensive analyses of large collections of histopathologically well-classified primary tumours. Here we report the results of a collaborative study to discover somatic mutations in 188 human lung adenocarcinomas. DNA sequencing of 623 genes with known or potential relationships to cancer revealed more than 1,000 somatic mutations across the samples. Our analysis identified 26 genes that are mutated at significantly high frequencies and thus are probably involved in carcinogenesis. The frequently mutated genes include tyrosine kinases, among them the EGFR homologue ERBB4; multiple ephrin receptor genes, notably EPHA3; vascular endothelial growth factor receptor KDR; and NTRK genes. These data provide evidence of somatic mutations in primary lung adenocarcinoma for several tumour suppressor genes involved in other cancers--including NF1, APC, RB1 and ATM--and for sequence changes in PTPRD as well as the frequently deleted gene LRP1B. The observed mutational profiles correlate with clinical features, smoking status and DNA repair defects. These results are reinforced by data integration including single nucleotide polymorphism array and gene expression array. Our findings shed further light on several important signalling pathways involved in lung adenocarcinoma, and suggest new molecular targets for treatment.

Standard name | DING_LUNG_CANCER_MUTATED_FREQUENTLY
Systematic name | M16718
Organism | Homo sapiens
PMID | 18948947
Authors | Ding L,Getz G,Wheeler DA,Mardis ER,McLellan MD,Cibulskis K,Sougnez C,Greulich H,Muzny DM,Morgan MB,Fulton L,Fulton RS,Zhang Q,Wendl MC,Lawrence MS,Larson DE,Chen K,Dooling DJ,Sabo A,Hawes AC,Shen H,Jhangiani SN,Lewis LR,Hall O,Zhu Y,Mathew T,Ren Y,Yao J,Scherer SE,Clerc K,Metcalf GA,Ng B,Milosavljevic A,Gonzalez-Garay ML,Osborne JR,Meyer R,Shi X,Tang Y,Koboldt DC,Lin L,Abbott R,Miner TL,Pohl C,Fewell G,Haipek C,Schmidt H,Dunford-Shore BH,Kraja A,Crosby SD,Sawyer CS,Vickery T,Sander S,Robinson J,Winckler W,Baldwin J,Chirieac LR,Dutt A,Fennell T,Hanna M,Johnson BE,Onofrio RC,Thomas RK,Tonon G,Weir BA,Zhao X,Ziaugra L,Zody MC,Giordano T,Orringer MB,Roth JA,Spitz MR,Wistuba II,Ozenberger B,Good PJ,Chang AC,Beer DG,Watson MA,Ladanyi M,Broderick S,Yoshizawa A,Travis WD,Pao W,Province MA,Weinstock GM,Varmus HE,Gabriel SB,Lander ES,Gibbs RA,Meyerson M,Wilson RK
Category | C2
Sub-category | CGP
Brief description | The lung adenocarcinoma TSP (tumor sequencing project) genes with significantly higher frequencies of nonsense, splice site, and frame-shift mutations.
Full description | Determining the genetic basis of cancer requires comprehensive analyses of large collections of histopathologically well-classified primary tumours. Here we report the results of a collaborative study to discover somatic mutations in 188 human lung adenocarcinomas. DNA sequencing of 623 genes with known or potential relationships to cancer revealed more than 1,000 somatic mutations across the samples. Our analysis identified 26 genes that are mutated at significantly high frequencies and thus are probably involved in carcinogenesis. The frequently mutated genes include tyrosine kinases, among them the EGFR homologue ERBB4; multiple ephrin receptor genes, notably EPHA3; vascular endothelial growth factor receptor KDR; and NTRK genes. These data provide evidence of somatic mutations in primary lung adenocarcinoma for several tumour suppressor genes involved in other cancers--including NF1, APC, RB1 and ATM--and for sequence changes in PTPRD as well as the frequently deleted gene LRP1B. The observed mutational profiles correlate with clinical features, smoking status and DNA repair defects. These results are reinforced by data integration including single nucleotide polymorphism array and gene expression array. Our findings shed further light on several important signalling pathways involved in lung adenocarcinoma, and suggest new molecular targets for treatment.

Standard name | DING_LUNG_CANCER_EXPRESSION_BY_COPY_NUMBER
Systematic name | M14670
Organism | Homo sapiens
PMID | 18948947
Authors | Ding L,Getz G,Wheeler DA,Mardis ER,McLellan MD,Cibulskis K,Sougnez C,Greulich H,Muzny DM,Morgan MB,Fulton L,Fulton RS,Zhang Q,Wendl MC,Lawrence MS,Larson DE,Chen K,Dooling DJ,Sabo A,Hawes AC,Shen H,Jhangiani SN,Lewis LR,Hall O,Zhu Y,Mathew T,Ren Y,Yao J,Scherer SE,Clerc K,Metcalf GA,Ng B,Milosavljevic A,Gonzalez-Garay ML,Osborne JR,Meyer R,Shi X,Tang Y,Koboldt DC,Lin L,Abbott R,Miner TL,Pohl C,Fewell G,Haipek C,Schmidt H,Dunford-Shore BH,Kraja A,Crosby SD,Sawyer CS,Vickery T,Sander S,Robinson J,Winckler W,Baldwin J,Chirieac LR,Dutt A,Fennell T,Hanna M,Johnson BE,Onofrio RC,Thomas RK,Tonon G,Weir BA,Zhao X,Ziaugra L,Zody MC,Giordano T,Orringer MB,Roth JA,Spitz MR,Wistuba II,Ozenberger B,Good PJ,Chang AC,Beer DG,Watson MA,Ladanyi M,Broderick S,Yoshizawa A,Travis WD,Pao W,Province MA,Weinstock GM,Varmus HE,Gabriel SB,Lander ES,Gibbs RA,Meyerson M,Wilson RK
Category | C2
Sub-category | CGP
Brief description | The lung adenocarcinoma TSP (tumor sequencing project) genes showing strong correlation between DNA copy number variation and gene expression.
Full description | Determining the genetic basis of cancer requires comprehensive analyses of large collections of histopathologically well-classified primary tumours. Here we report the results of a collaborative study to discover somatic mutations in 188 human lung adenocarcinomas. DNA sequencing of 623 genes with known or potential relationships to cancer revealed more than 1,000 somatic mutations across the samples. Our analysis identified 26 genes that are mutated at significantly high frequencies and thus are probably involved in carcinogenesis. The frequently mutated genes include tyrosine kinases, among them the EGFR homologue ERBB4; multiple ephrin receptor genes, notably EPHA3; vascular endothelial growth factor receptor KDR; and NTRK genes. These data provide evidence of somatic mutations in primary lung adenocarcinoma for several tumour suppressor genes involved in other cancers--including NF1, APC, RB1 and ATM--and for sequence changes in PTPRD as well as the frequently deleted gene LRP1B. The observed mutational profiles correlate with clinical features, smoking status and DNA repair defects. These results are reinforced by data integration including single nucleotide polymorphism array and gene expression array. Our findings shed further light on several important signalling pathways involved in lung adenocarcinoma, and suggest new molecular targets for treatment.

Standard name | ONDER_CDH1_TARGETS_2_UP
Systematic name | M13867
Organism | Homo sapiens
PMID | 18483246
Authors | Onder TT,Gupta PB,Mani SA,Yang J,Lander ES,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HMLE cells (immortalized nontransformed mammary epithelium) after E-cadhedrin (CDH1) [GeneID=999] knockdown by RNAi.
Full description | Loss of the epithelial adhesion molecule E-cadherin is thought to enable metastasis by disrupting intercellular contacts-an early step in metastatic dissemination. To further investigate the molecular basis of this notion, we use two methods to inhibit E-cadherin function that distinguish between E-cadherin's cell-cell adhesion and intracellular signaling functions. Whereas the disruption of cell-cell contacts alone does not enable metastasis, the loss of E-cadherin protein does, through induction of an epithelial-to-mesenchymal transition, invasiveness, and anoikis resistance. We find the E-cadherin binding partner beta-catenin to be necessary, but not sufficient, for induction of these phenotypes. In addition, gene expression analysis shows that E-cadherin loss results in the induction of multiple transcription factors, at least one of which, Twist, is necessary for E-cadherin loss-induced metastasis. These findings indicate that E-cadherin loss in tumors contributes to metastatic dissemination by inducing wide-ranging transcriptional and functional changes.

Standard name | ONDER_CDH1_TARGETS_2_DN
Systematic name | M4306
Organism | Homo sapiens
PMID | 18483246
Authors | Onder TT,Gupta PB,Mani SA,Yang J,Lander ES,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HMLE cells (immortalized nontransformed mammary epithelium) after E-cadhedrin (CDH1) [GeneID=999] knockdown by RNAi.
Full description | Loss of the epithelial adhesion molecule E-cadherin is thought to enable metastasis by disrupting intercellular contacts-an early step in metastatic dissemination. To further investigate the molecular basis of this notion, we use two methods to inhibit E-cadherin function that distinguish between E-cadherin's cell-cell adhesion and intracellular signaling functions. Whereas the disruption of cell-cell contacts alone does not enable metastasis, the loss of E-cadherin protein does, through induction of an epithelial-to-mesenchymal transition, invasiveness, and anoikis resistance. We find the E-cadherin binding partner beta-catenin to be necessary, but not sufficient, for induction of these phenotypes. In addition, gene expression analysis shows that E-cadherin loss results in the induction of multiple transcription factors, at least one of which, Twist, is necessary for E-cadherin loss-induced metastasis. These findings indicate that E-cadherin loss in tumors contributes to metastatic dissemination by inducing wide-ranging transcriptional and functional changes.

Standard name | ONDER_CDH1_TARGETS_1_UP
Systematic name | M18757
Organism | Homo sapiens
PMID | 18483246
Authors | Onder TT,Gupta PB,Mani SA,Yang J,Lander ES,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HMLE cells (mmortalized nontransformed mammary epithelial) by expression of a dominant-negative form of E-cadhedrin (CDH1) [GeneID=999].
Full description | Loss of the epithelial adhesion molecule E-cadherin is thought to enable metastasis by disrupting intercellular contacts-an early step in metastatic dissemination. To further investigate the molecular basis of this notion, we use two methods to inhibit E-cadherin function that distinguish between E-cadherin's cell-cell adhesion and intracellular signaling functions. Whereas the disruption of cell-cell contacts alone does not enable metastasis, the loss of E-cadherin protein does, through induction of an epithelial-to-mesenchymal transition, invasiveness, and anoikis resistance. We find the E-cadherin binding partner beta-catenin to be necessary, but not sufficient, for induction of these phenotypes. In addition, gene expression analysis shows that E-cadherin loss results in the induction of multiple transcription factors, at least one of which, Twist, is necessary for E-cadherin loss-induced metastasis. These findings indicate that E-cadherin loss in tumors contributes to metastatic dissemination by inducing wide-ranging transcriptional and functional changes.

Standard name | ONDER_CDH1_TARGETS_1_DN
Systematic name | M6822
Organism | Homo sapiens
PMID | 18483246
Authors | Onder TT,Gupta PB,Mani SA,Yang J,Lander ES,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HMLE cells (mmortalized nontransformed mammary epithelial) by expression of a dominant-negative form of E-cadhedrin (CDH1) [GeneID=999].
Full description | Loss of the epithelial adhesion molecule E-cadherin is thought to enable metastasis by disrupting intercellular contacts-an early step in metastatic dissemination. To further investigate the molecular basis of this notion, we use two methods to inhibit E-cadherin function that distinguish between E-cadherin's cell-cell adhesion and intracellular signaling functions. Whereas the disruption of cell-cell contacts alone does not enable metastasis, the loss of E-cadherin protein does, through induction of an epithelial-to-mesenchymal transition, invasiveness, and anoikis resistance. We find the E-cadherin binding partner beta-catenin to be necessary, but not sufficient, for induction of these phenotypes. In addition, gene expression analysis shows that E-cadherin loss results in the induction of multiple transcription factors, at least one of which, Twist, is necessary for E-cadherin loss-induced metastasis. These findings indicate that E-cadherin loss in tumors contributes to metastatic dissemination by inducing wide-ranging transcriptional and functional changes.

Standard name | ONDER_CDH1_TARGETS_3_UP
Systematic name | M844
Organism | Homo sapiens
PMID | 18483246
Authors | Onder TT,Gupta PB,Mani SA,Yang J,Lander ES,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HMLE cells (immortalized nontransformed mammary epithelial) cells after loss of function of E-cadhedrin (CDH1) [GeneID=999], which was achieved either by RNAi knockdown or by expression of a dominan-negative form of CDH1.
Full description | Loss of the epithelial adhesion molecule E-cadherin is thought to enable metastasis by disrupting intercellular contacts-an early step in metastatic dissemination. To further investigate the molecular basis of this notion, we use two methods to inhibit E-cadherin function that distinguish between E-cadherin's cell-cell adhesion and intracellular signaling functions. Whereas the disruption of cell-cell contacts alone does not enable metastasis, the loss of E-cadherin protein does, through induction of an epithelial-to-mesenchymal transition, invasiveness, and anoikis resistance. We find the E-cadherin binding partner beta-catenin to be necessary, but not sufficient, for induction of these phenotypes. In addition, gene expression analysis shows that E-cadherin loss results in the induction of multiple transcription factors, at least one of which, Twist, is necessary for E-cadherin loss-induced metastasis. These findings indicate that E-cadherin loss in tumors contributes to metastatic dissemination by inducing wide-ranging transcriptional and functional changes.

Standard name | ONDER_CDH1_TARGETS_3_DN
Systematic name | M11790
Organism | Homo sapiens
PMID | 18483246
Authors | Onder TT,Gupta PB,Mani SA,Yang J,Lander ES,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HMLE cells (immortalized nontransformed mammary epithelial) cells after loss of function of E-cadhedrin (CDH1) [GeneID=999], which was achieved either by RNAi knockdown or by expression of a dominan-negative form of CDH1.
Full description | Loss of the epithelial adhesion molecule E-cadherin is thought to enable metastasis by disrupting intercellular contacts-an early step in metastatic dissemination. To further investigate the molecular basis of this notion, we use two methods to inhibit E-cadherin function that distinguish between E-cadherin's cell-cell adhesion and intracellular signaling functions. Whereas the disruption of cell-cell contacts alone does not enable metastasis, the loss of E-cadherin protein does, through induction of an epithelial-to-mesenchymal transition, invasiveness, and anoikis resistance. We find the E-cadherin binding partner beta-catenin to be necessary, but not sufficient, for induction of these phenotypes. In addition, gene expression analysis shows that E-cadherin loss results in the induction of multiple transcription factors, at least one of which, Twist, is necessary for E-cadherin loss-induced metastasis. These findings indicate that E-cadherin loss in tumors contributes to metastatic dissemination by inducing wide-ranging transcriptional and functional changes.

Standard name | ONDER_CDH1_SIGNALING_VIA_CTNNB1
Systematic name | M15484
Organism | Homo sapiens
PMID | 18483246
Authors | Onder TT,Gupta PB,Mani SA,Yang J,Lander ES,Weinberg RA
Category | C2
Sub-category | CGP
Brief description | Genes changed in HMLE cells (mmortalized nontransformed mammary epithelium) after RNAi knockdown of both CDH1 and CTNNB1 [GeneID=999;1499], compared to the knockdown of CDH1 alone.
Full description | Loss of the epithelial adhesion molecule E-cadherin is thought to enable metastasis by disrupting intercellular contacts-an early step in metastatic dissemination. To further investigate the molecular basis of this notion, we use two methods to inhibit E-cadherin function that distinguish between E-cadherin's cell-cell adhesion and intracellular signaling functions. Whereas the disruption of cell-cell contacts alone does not enable metastasis, the loss of E-cadherin protein does, through induction of an epithelial-to-mesenchymal transition, invasiveness, and anoikis resistance. We find the E-cadherin binding partner beta-catenin to be necessary, but not sufficient, for induction of these phenotypes. In addition, gene expression analysis shows that E-cadherin loss results in the induction of multiple transcription factors, at least one of which, Twist, is necessary for E-cadherin loss-induced metastasis. These findings indicate that E-cadherin loss in tumors contributes to metastatic dissemination by inducing wide-ranging transcriptional and functional changes.

Standard name | ZEILSTRA_CD44_TARGETS_UP
Systematic name | M1398
Organism | Mus musculus
PMID | 18483247
Authors | Zeilstra J,Joosten SP,Dokter M,Verwiel E,Spaargaren M,Pals ST
Category | C2
Sub-category | CGP
Brief description | Genes implicated in apoptosis that were up-regulated in duodenum of CD44 [GeneID=960] knockout mice.
Full description | Mutation of the genes encoding the WNT signaling components adenomatous polyposis coli or beta-catenin plays a critical role in the initiation of colorectal cancer. These mutations cause constitutively active beta-catenin/TCF-mediated transcription, driving the transformation of intestinal crypts to colorectal cancer precursor lesions, called dysplastic aberrant crypt foci. CD44 is a prominent WNT signaling target in the intestine and is selectively expressed on the renewing epithelial cells lining the crypts. The expression of CD44 is dramatically increased in aberrant crypt foci in both humans and tumor-susceptible Apc(Min/+) mice, suggesting a role for CD44 in intestinal tumorigenesis. To study this role, we crossed C57BL/6J-Cd44(-/-) mice with C57BL/6J-Apc(Min/+) mice. Compared with C57BL/6J-Cd44(+/+)/Apc(Min/+) mice, C57BL/6J-Cd44(-/-)/Apc(Min/+) mice showed an almost 50% reduction in the number of intestinal adenomas. This reduction was primarily caused by a decrease in the formation of aberrant crypts, implying the involvement of CD44 in tumor initiation. The absence of CD44 in the normal (nonneoplastic) crypts of Cd44(-/-)/Apc(Min/+) mice did not alter the proliferative capacity and size of the intestinal stem cell and transit-amplifying compartments. However, compared with Cd44(+/+)/Apc(Min/+) mice, Cd44(-/-)/Apc(Min/+) showed an increase in the number of apoptotic epithelial cells at the base of the crypt which correlated with an increased expression of the proapoptotic genes Bok and Dr6. Our results show an important role for CD44 in intestinal tumorigenesis and suggest that CD44 does not affect proliferation but is involved in the control of the balance between survival and apoptosis in the intestinal crypt.

Standard name | ZEILSTRA_CD44_TARGETS_DN
Systematic name | M1400
Organism | Mus musculus
PMID | 18483247
Authors | Zeilstra J,Joosten SP,Dokter M,Verwiel E,Spaargaren M,Pals ST
Category | C2
Sub-category | CGP
Brief description | Genes implicated in apoptosis that were down-regulated in duodenum of CD44 [GeneID=960] knockout mice.
Full description | Mutation of the genes encoding the WNT signaling components adenomatous polyposis coli or beta-catenin plays a critical role in the initiation of colorectal cancer. These mutations cause constitutively active beta-catenin/TCF-mediated transcription, driving the transformation of intestinal crypts to colorectal cancer precursor lesions, called dysplastic aberrant crypt foci. CD44 is a prominent WNT signaling target in the intestine and is selectively expressed on the renewing epithelial cells lining the crypts. The expression of CD44 is dramatically increased in aberrant crypt foci in both humans and tumor-susceptible Apc(Min/+) mice, suggesting a role for CD44 in intestinal tumorigenesis. To study this role, we crossed C57BL/6J-Cd44(-/-) mice with C57BL/6J-Apc(Min/+) mice. Compared with C57BL/6J-Cd44(+/+)/Apc(Min/+) mice, C57BL/6J-Cd44(-/-)/Apc(Min/+) mice showed an almost 50% reduction in the number of intestinal adenomas. This reduction was primarily caused by a decrease in the formation of aberrant crypts, implying the involvement of CD44 in tumor initiation. The absence of CD44 in the normal (nonneoplastic) crypts of Cd44(-/-)/Apc(Min/+) mice did not alter the proliferative capacity and size of the intestinal stem cell and transit-amplifying compartments. However, compared with Cd44(+/+)/Apc(Min/+) mice, Cd44(-/-)/Apc(Min/+) showed an increase in the number of apoptotic epithelial cells at the base of the crypt which correlated with an increased expression of the proapoptotic genes Bok and Dr6. Our results show an important role for CD44 in intestinal tumorigenesis and suggest that CD44 does not affect proliferation but is involved in the control of the balance between survival and apoptosis in the intestinal crypt.

Standard name | CERVERA_SDHB_TARGETS_2
Systematic name | M19068
Organism | Homo sapiens
PMID | 18519664
Authors | Cervera AM,Apostolova N,Crespo FL,Mata M,McCreath KJ
Category | C2
Sub-category | CGP
Brief description | Genes present but differentially expressed between Hep3B cells (hepatocellular carcinoma, HCC) with RNAi knockdown of SDHB [GeneID=6390] and control cells.
Full description | Recently, enzymes of the tricarboxylic acid (TCA) cycle have emerged as novel tumor suppressors. In particular, mutations in the nuclear-encoded subunits of succinate dehydrogenase (SDHB, SDHC, and SDHD) cause paragangliomas and pheochromocytomas. Although the mechanism(s) by which disruption of mitochondrial metabolism leads to neoplasia is largely unknown, increasing evidence points to an activation of pseudohypoxia. In this study, we have shown that silencing of SDHB using DNA-based small interfering RNA resulted in major impairments in cellular proliferation, respiration, and a corresponding shift to glycolysis. The levels of reactive oxygen species, however, were unchanged. As expected, hypoxia-inducible factor-1 alpha (HIF-1 alpha) and HIF-2alpha were up-regulated in chronically silenced cells, suggesting that a pseudohypoxic state was attained. In addition, the c-Jun amino-terminal kinase and p38 kinase stress signaling proteins were hyperphosphorylated in SDHB-silenced cells. Microarray analysis showed that >400 genes were influenced (6-fold or more up-regulation or down-regulation) by silencing of SDHB, confirming the importance of the TCA cycle in cellular metabolism. Examples of dysregulated genes included those involved in proliferation, adhesion, and the hypoxia pathway. Of interest, SDHB-silenced cells had a greater capacity to adhere to extracellular matrix components, including fibronectin and laminin, than control cells, thus suggesting a possible mechanism of tumor initiation. Although transient silencing of the HIF-1 alpha transcription factor in SDHB-silenced cells had little effect on the expression of a subset of up-regulated genes, it partially reversed the adhesion phenotype to fibronectin, pointing to a potentially important role for HIF-1 in this process.

Standard name | ROZANOV_MMP14_TARGETS_SUBSET
Systematic name | M9167
Organism | Homo sapiens
PMID | 18519667
Authors | Rozanov DV,Savinov AY,Williams R,Liu K,Golubkov VS,Krajewski S,Strongin AY
Category | C2
Sub-category | CGP
Brief description | Genes linked to the ECM maintenance and angiogenesis that were changed in HT1080 cells (fibrosarcoma) over-expressing MMP14 [GeneID=4323] compared to those with knockdown of the gene by RNAi.
Full description | Invasion-promoting MT1-MMP is directly linked to tumorigenesis and metastasis. Our studies led us to identify those genes, the expression of which is universally linked to MT1-MMP in multiple tumor types. Genome-wide expression profiling of MT1-MMP-overexpressing versus MT1-MMP-silenced cancer cells and a further data mining analysis of the preexisting expression database of 190 human tumors of 14 cancer types led us to identify 11 genes, the expression of which correlated firmly and universally with that of MT1-MMP (P < 0.00001). These genes included regulators of energy metabolism (NNT), trafficking and membrane fusion (SLCO2A1 and ANXA7), signaling and transcription (NR3C1, JAG1, PI3K delta, and CK2 alpha), chromatin rearrangement (SMARCA1), cell division (STK38/NDR1), apoptosis (DAPK1), and mRNA splicing (SNRPB2). Our subsequent extensive analysis of cultured cells, tumor xenografts, and cancer patient biopsies supported our data mining. Our results suggest that transcriptional reprogramming of the specific downstream genes, which themselves are associated with tumorigenesis, represents a distinctive molecular signature of the proteolytically active MT1-MMP. We suggest that the transactivation activity of MT1-MMP contributes to the promigratory cell phenotype, which is induced by this tumorigenic proteinase. The activated downstream gene network then begins functioning in unison with MT1-MMP to rework the signaling, transport, cell division, energy metabolism, and other critical cell functions and to commit the cell to migration, invasion, and, consequently, tumorigenesis.

Standard name | ROZANOV_MMP14_CORRELATED
Systematic name | M2987
Organism | Homo sapiens
PMID | 18519667
Authors | Rozanov DV,Savinov AY,Williams R,Liu K,Golubkov VS,Krajewski S,Strongin AY
Category | C2
Sub-category | CGP
Brief description | Genes whose expression most uniformly correlated with that of MMP14 [GeneID=4323] both in HT1080 cells (fibrosarcoma) and in 190 human tumors.
Full description | Invasion-promoting MT1-MMP is directly linked to tumorigenesis and metastasis. Our studies led us to identify those genes, the expression of which is universally linked to MT1-MMP in multiple tumor types. Genome-wide expression profiling of MT1-MMP-overexpressing versus MT1-MMP-silenced cancer cells and a further data mining analysis of the preexisting expression database of 190 human tumors of 14 cancer types led us to identify 11 genes, the expression of which correlated firmly and universally with that of MT1-MMP (P < 0.00001). These genes included regulators of energy metabolism (NNT), trafficking and membrane fusion (SLCO2A1 and ANXA7), signaling and transcription (NR3C1, JAG1, PI3K delta, and CK2 alpha), chromatin rearrangement (SMARCA1), cell division (STK38/NDR1), apoptosis (DAPK1), and mRNA splicing (SNRPB2). Our subsequent extensive analysis of cultured cells, tumor xenografts, and cancer patient biopsies supported our data mining. Our results suggest that transcriptional reprogramming of the specific downstream genes, which themselves are associated with tumorigenesis, represents a distinctive molecular signature of the proteolytically active MT1-MMP. We suggest that the transactivation activity of MT1-MMP contributes to the promigratory cell phenotype, which is induced by this tumorigenic proteinase. The activated downstream gene network then begins functioning in unison with MT1-MMP to rework the signaling, transport, cell division, energy metabolism, and other critical cell functions and to commit the cell to migration, invasion, and, consequently, tumorigenesis.

Standard name | ROZANOV_MMP14_TARGETS_UP
Systematic name | M12890
Organism | Homo sapiens
PMID | 18519667
Authors | Rozanov DV,Savinov AY,Williams R,Liu K,Golubkov VS,Krajewski S,Strongin AY
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HT1080 cells (fibrosarcoma) over-expressing MMP14 [GeneID=4323] compared to those with knockdown of the gene by RNAi.
Full description | Invasion-promoting MT1-MMP is directly linked to tumorigenesis and metastasis. Our studies led us to identify those genes, the expression of which is universally linked to MT1-MMP in multiple tumor types. Genome-wide expression profiling of MT1-MMP-overexpressing versus MT1-MMP-silenced cancer cells and a further data mining analysis of the preexisting expression database of 190 human tumors of 14 cancer types led us to identify 11 genes, the expression of which correlated firmly and universally with that of MT1-MMP (P < 0.00001). These genes included regulators of energy metabolism (NNT), trafficking and membrane fusion (SLCO2A1 and ANXA7), signaling and transcription (NR3C1, JAG1, PI3K delta, and CK2 alpha), chromatin rearrangement (SMARCA1), cell division (STK38/NDR1), apoptosis (DAPK1), and mRNA splicing (SNRPB2). Our subsequent extensive analysis of cultured cells, tumor xenografts, and cancer patient biopsies supported our data mining. Our results suggest that transcriptional reprogramming of the specific downstream genes, which themselves are associated with tumorigenesis, represents a distinctive molecular signature of the proteolytically active MT1-MMP. We suggest that the transactivation activity of MT1-MMP contributes to the promigratory cell phenotype, which is induced by this tumorigenic proteinase. The activated downstream gene network then begins functioning in unison with MT1-MMP to rework the signaling, transport, cell division, energy metabolism, and other critical cell functions and to commit the cell to migration, invasion, and, consequently, tumorigenesis.

Standard name | ROZANOV_MMP14_TARGETS_DN
Systematic name | M5522
Organism | Homo sapiens
PMID | 18519667
Authors | Rozanov DV,Savinov AY,Williams R,Liu K,Golubkov VS,Krajewski S,Strongin AY
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HT1080 cells (fibrosarcoma) over-expressing MMP14 [GeneID=4323] compared to those with knockdown of the gene by RNAi.
Full description | Invasion-promoting MT1-MMP is directly linked to tumorigenesis and metastasis. Our studies led us to identify those genes, the expression of which is universally linked to MT1-MMP in multiple tumor types. Genome-wide expression profiling of MT1-MMP-overexpressing versus MT1-MMP-silenced cancer cells and a further data mining analysis of the preexisting expression database of 190 human tumors of 14 cancer types led us to identify 11 genes, the expression of which correlated firmly and universally with that of MT1-MMP (P < 0.00001). These genes included regulators of energy metabolism (NNT), trafficking and membrane fusion (SLCO2A1 and ANXA7), signaling and transcription (NR3C1, JAG1, PI3K delta, and CK2 alpha), chromatin rearrangement (SMARCA1), cell division (STK38/NDR1), apoptosis (DAPK1), and mRNA splicing (SNRPB2). Our subsequent extensive analysis of cultured cells, tumor xenografts, and cancer patient biopsies supported our data mining. Our results suggest that transcriptional reprogramming of the specific downstream genes, which themselves are associated with tumorigenesis, represents a distinctive molecular signature of the proteolytically active MT1-MMP. We suggest that the transactivation activity of MT1-MMP contributes to the promigratory cell phenotype, which is induced by this tumorigenic proteinase. The activated downstream gene network then begins functioning in unison with MT1-MMP to rework the signaling, transport, cell division, energy metabolism, and other critical cell functions and to commit the cell to migration, invasion, and, consequently, tumorigenesis.

Standard name | LANDEMAINE_LUNG_METASTASIS
Systematic name | M5914
Organism | Homo sapiens
PMID | 18676831
Authors | Landemaine T,Jackson A,Bellahcène A,Rucci N,Sin S,Abad BM,Sierra A,Boudinet A,Guinebretière JM,Ricevuto E,Noguès C,Briffod M,Bièche I,Cherel P,Garcia T,Castronovo V,Teti A,Lidereau R,Driouch K
Category | C2
Sub-category | CGP
Brief description | Genes associated with metastasis of breast cancer in the lung compared to the non-lung metastasis.
Full description | The lungs are a frequent target of metastatic breast cancer cells, but the underlying molecular mechanisms are unclear. All existing data were obtained either using statistical association between gene expression measurements found in primary tumors and clinical outcome, or using experimentally derived signatures from mouse tumor models. Here, we describe a distinct approach that consists of using tissue surgically resected from lung metastatic lesions and comparing their gene expression profiles with those from nonpulmonary sites, all coming from breast cancer patients. We show that the gene expression profiles of organ-specific metastatic lesions can be used to predict lung metastasis in breast cancer. We identified a set of 21 lung metastasis-associated genes. Using a cohort of 72 lymph node-negative breast cancer patients, we developed a 6-gene prognostic classifier that discriminated breast primary cancers with a significantly higher risk of lung metastasis. We then validated the predictive ability of the 6-gene signature in 3 independent cohorts of breast cancers consisting of a total of 721 patients. Finally, we show that the signature improves risk stratification independently of known standard clinical variables and a previously established lung metastasis signature based on an experimental breast cancer metastasis model.

Standard name | CERVERA_SDHB_TARGETS_1_UP
Systematic name | M15549
Organism | Homo sapiens
PMID | 18519664
Authors | Cervera AM,Apostolova N,Crespo FL,Mata M,McCreath KJ
Category | C2
Sub-category | CGP
Brief description | Genes turned on in Hep3B cells (hepatocellular carcinoma, HCC) upon knockdown of SDHB [GeneID=6390] by RNAi.
Full description | Recently, enzymes of the tricarboxylic acid (TCA) cycle have emerged as novel tumor suppressors. In particular, mutations in the nuclear-encoded subunits of succinate dehydrogenase (SDHB, SDHC, and SDHD) cause paragangliomas and pheochromocytomas. Although the mechanism(s) by which disruption of mitochondrial metabolism leads to neoplasia is largely unknown, increasing evidence points to an activation of pseudohypoxia. In this study, we have shown that silencing of SDHB using DNA-based small interfering RNA resulted in major impairments in cellular proliferation, respiration, and a corresponding shift to glycolysis. The levels of reactive oxygen species, however, were unchanged. As expected, hypoxia-inducible factor-1 alpha (HIF-1 alpha) and HIF-2alpha were up-regulated in chronically silenced cells, suggesting that a pseudohypoxic state was attained. In addition, the c-Jun amino-terminal kinase and p38 kinase stress signaling proteins were hyperphosphorylated in SDHB-silenced cells. Microarray analysis showed that >400 genes were influenced (6-fold or more up-regulation or down-regulation) by silencing of SDHB, confirming the importance of the TCA cycle in cellular metabolism. Examples of dysregulated genes included those involved in proliferation, adhesion, and the hypoxia pathway. Of interest, SDHB-silenced cells had a greater capacity to adhere to extracellular matrix components, including fibronectin and laminin, than control cells, thus suggesting a possible mechanism of tumor initiation. Although transient silencing of the HIF-1 alpha transcription factor in SDHB-silenced cells had little effect on the expression of a subset of up-regulated genes, it partially reversed the adhesion phenotype to fibronectin, pointing to a potentially important role for HIF-1 in this process.

Standard name | CERVERA_SDHB_TARGETS_1_DN
Systematic name | M11404
Organism | Homo sapiens
PMID | 18519664
Authors | Cervera AM,Apostolova N,Crespo FL,Mata M,McCreath KJ
Category | C2
Sub-category | CGP
Brief description | Genes turned off in Hep3B cells (hepatocellular carcinoma, HCC) upon knockdown of SDHB [GeneID=6390] by RNAi.
Full description | Recently, enzymes of the tricarboxylic acid (TCA) cycle have emerged as novel tumor suppressors. In particular, mutations in the nuclear-encoded subunits of succinate dehydrogenase (SDHB, SDHC, and SDHD) cause paragangliomas and pheochromocytomas. Although the mechanism(s) by which disruption of mitochondrial metabolism leads to neoplasia is largely unknown, increasing evidence points to an activation of pseudohypoxia. In this study, we have shown that silencing of SDHB using DNA-based small interfering RNA resulted in major impairments in cellular proliferation, respiration, and a corresponding shift to glycolysis. The levels of reactive oxygen species, however, were unchanged. As expected, hypoxia-inducible factor-1 alpha (HIF-1 alpha) and HIF-2alpha were up-regulated in chronically silenced cells, suggesting that a pseudohypoxic state was attained. In addition, the c-Jun amino-terminal kinase and p38 kinase stress signaling proteins were hyperphosphorylated in SDHB-silenced cells. Microarray analysis showed that >400 genes were influenced (6-fold or more up-regulation or down-regulation) by silencing of SDHB, confirming the importance of the TCA cycle in cellular metabolism. Examples of dysregulated genes included those involved in proliferation, adhesion, and the hypoxia pathway. Of interest, SDHB-silenced cells had a greater capacity to adhere to extracellular matrix components, including fibronectin and laminin, than control cells, thus suggesting a possible mechanism of tumor initiation. Although transient silencing of the HIF-1 alpha transcription factor in SDHB-silenced cells had little effect on the expression of a subset of up-regulated genes, it partially reversed the adhesion phenotype to fibronectin, pointing to a potentially important role for HIF-1 in this process.

Standard name | LE_EGR2_TARGETS_DN
Systematic name | M15148
Organism | Mus musculus
PMID | 15695336
Authors | Le N,Nagarajan R,Wang JY,Araki T,Schmidt RE,Milbrandt J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in P14 nerves of transgenic mice having hypomorhic (reduced function) allele of EGR2 [GeneID=1959].
Full description | Egr2 is a transcription factor required for peripheral nerve myelination in rodents, and mutations in Egr2 are associated with congenital hypomyelinating neuropathy (CHN) in humans. To further study its role in myelination, we generated mice harboring a hypomorphic Egr2 allele (Egr2Lo) that survive for up to 3 weeks postnatally, a period of active myelination in rodents. These Egr2Lo/Lo mice provided the opportunity to study the molecular effects of Egr2 deficiency on Schwann cell biology, an analysis that was not possible previously, because of the perinatal lethality of Egr2-null mice. Egr2Lo/Lo mice phenocopy CHN, as evidenced by the severe hypomyelination and increased numbers of proliferating Schwann cells of the peripheral nerves. Comparison of sciatic nerve gene expression profiles during development and after crush injury with those of Egr2Lo/Lo Schwann cells revealed that they are developmentally arrested, with down-regulation of myelination-related genes and up-regulation of genes associated with immature and promyelinating Schwann cells. One of the abnormally elevated genes in Egr2Lo/Lo Schwann cells, Sox2, encodes a transcription factor that is crucial for maintenance of neural stem cell pluripotency. Wild-type Schwann cells infected with Sox2 adenovirus or lentivirus inhibited expression of myelination-associated genes (e.g., myelin protein zero; Mpz), and failed to myelinate axons in vitro, but had an enhanced proliferative response to beta-neuregulin. The characterization of a mouse model of CHN has provided insight into Schwann cell differentiation and allowed the identification of Sox2 as a negative regulator of myelination.

Standard name | ROSS_ACUTE_MYELOID_LEUKEMIA_CBF
Systematic name | M7804
Organism | Homo sapiens
PMID | 15226186
Authors | Ross ME,Mahfouz R,Onciu M,Liu HC,Zhou X,Song G,Shurtleff SA,Pounds S,Cheng C,Ma J,Ribeiro RC,Rubnitz JE,Girtman K,Williams WK,Raimondi SC,Liang DC,Shih LY,Pui CH,Downing JR
Category | C2
Sub-category | CGP
Brief description | Top 100 probe sets for core-binding factor (CBF) acute myeloid leukemia (AML): contains CBFB MYH11 [GeneID=865;4629] or AML1 ETO [GeneID=861;862] fusions.
Full description | Contemporary treatment of pediatric acute myeloid leukemia (AML) requires the assignment of patients to specific risk groups. To explore whether expression profiling of leukemic blasts could accurately distinguish between the known risk groups of AML, we analyzed 130 pediatric and 20 adult AML diagnostic bone marrow or peripheral blood samples using the Affymetrix U133A microarray. Class discriminating genes were identified for each of the major prognostic subtypes of pediatric AML, including t(15;17)[PML-RARalpha], t(8;21)[AML1-ETO], inv(16) [CBFbeta-MYH11], MLL chimeric fusion genes, and cases classified as FAB-M7. When subsets of these genes were used in supervised learning algorithms, an overall classification accuracy of more than 93% was achieved. Moreover, we were able to use the expression signatures generated from the pediatric samples to accurately classify adult de novo AMLs with the same genetic lesions. The class discriminating genes also provided novel insights into the molecular pathobiology of these leukemias. Finally, using a combined pediatric data set of 130 AMLs and 137 acute lymphoblastic leukemias, we identified an expression signature for cases with MLL chimeric fusion genes irrespective of lineage. Surprisingly, AMLs containing partial tandem duplications of MLL failed to cluster with MLL chimeric fusion gene cases, suggesting a significant difference in their underlying mechanism of transformation.

Standard name | BYSTRYKH_SCP2_QTL
Systematic name | M17138
Organism | Mus musculus
PMID | 15711547
Authors | Bystrykh L,Weersing E,Dontje B,Sutton S,Pletcher MT,Wiltshire T,Su AI,Vellenga E,Wang J,Manly KF,Lu L,Chesler EJ,Alberts R,Jansen RC,Williams RW,Cooke MP,de Haan G
Category | C2
Sub-category | CGP
Brief description | Genes that physically map to the hematopoietic stem cell (HSC) proliferation QTL (quantitative trait locus) Scp2.
Full description | We combined large-scale mRNA expression analysis and gene mapping to identify genes and loci that control hematopoietic stem cell (HSC) function. We measured mRNA expression levels in purified HSCs isolated from a panel of densely genotyped recombinant inbred mouse strains. We mapped quantitative trait loci (QTLs) associated with variation in expression of thousands of transcripts. By comparing the physical transcript position with the location of the controlling QTL, we identified polymorphic cis-acting stem cell genes. We also identified multiple trans-acting control loci that modify expression of large numbers of genes. These groups of coregulated transcripts identify pathways that specify variation in stem cells. We illustrate this concept with the identification of candidate genes involved with HSC turnover. We compared expression QTLs in HSCs and brain from the same mice and identified both shared and tissue-specific QTLs. Our data are accessible through WebQTL, a web-based interface that allows custom genetic linkage analysis and identification of coregulated transcripts.

Standard name | KENNY_CTNNB1_TARGETS_UP
Systematic name | M11067
Organism | Mus musculus
PMID | 15642117
Authors | Kenny PA,Enver T,Ashworth A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HC11 cells (mammary epithelium) by expression of constantly active CTNNB1 [GeneID=1499].
Full description | BACKGROUND: Deregulation of the Wnt/ beta-catenin signal transduction pathway has been implicated in the pathogenesis of tumours in the mammary gland, colon and other tissues. Mutations in components of this pathway result in beta-catenin stabilization and accumulation, and the aberrant modulation of beta-catenin/TCF target genes. Such alterations in the cellular transcriptional profile are believed to underlie the pathogenesis of these cancers. We have sought to identify novel target genes of this pathway in mouse mammary epithelial cells. METHODS: Gene expression microarray analysis of mouse mammary epithelial cells inducibly expressing a constitutively active mutant of beta-catenin was used to identify target genes of this pathway. RESULTS: The differential expression in response to DeltaNbeta-catenin for five putative target genes, Autotaxin, Extracellular Matrix Protein 1 (Ecm1), CD14, Hypoxia-inducible gene 2 (Hig2) and Receptor Activity Modifying Protein 3 (RAMP3), was independently validated by northern blotting. Each of these genes encodes either a receptor or a secreted protein, modulation of which may underlie the interactions between Wnt/beta-catenin tumour cells and between the tumour and its microenvironment. One of these genes, Hig2, previously shown to be induced by both hypoxia and glucose deprivation in human cervical carcinoma cells, was strongly repressed upon DeltaNbeta-catenin induction. The predicted N-terminus of Hig2 contains a putative signal peptide suggesting it might be secreted. Consistent with this, a Hig2-EGFP fusion protein was able to enter the secretory pathway and was detected in conditioned medium. Mutation of critical residues in the putative signal sequence abolished its secretion. The expression of human HIG2 was examined in a panel of human tumours and was found to be significantly downregulated in kidney tumours compared to normal adjacent tissue. CONCLUSIONS: HIG2 represents a novel non-cell autonomous target of the Wnt pathway which is potentially involved in human cancer.

Standard name | CHEOK_RESPONSE_TO_MERCAPTOPURINE_DN
Systematic name | M12605
Organism | Homo sapiens
PMID | 12704389
Authors | Cheok MH,Yang W,Pui CH,Downing JR,Cheng C,Naeve CW,Relling MV,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes specifically down-regulated in pediadric acute lymphoblastic leukemia (ALL) patients by mercaptopurine [PubChem=667490].
Full description | To elucidate the genomics of cellular responses to cancer treatment, we analyzed the expression of over 9,600 human genes in acute lymphoblastic leukemia cells before and after in vivo treatment with methotrexate and mercaptopurine given alone or in combination. Based on changes in gene expression, we identified 124 genes that accurately discriminated among the four treatments. Discriminating genes included those involved in apoptosis, mismatch repair, cell cycle control and stress response. Only 14% of genes that changed when these medications were given as single agents also changed when they were given together. These data indicate that lymphoid leukemia cells of different molecular subtypes share common pathways of genomic response to the same treatment, that changes in gene expression are treatment-specific and that gene expression can illuminate differences in cellular response to drug combinations versus single agents.

Standard name | NELSON_RESPONSE_TO_ANDROGEN_DN
Systematic name | M16830
Organism | Homo sapiens
PMID | 12185249
Authors | Nelson PS,Clegg N,Arnold H,Ferguson C,Bonham M,White J,Hood L,Lin B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in LNCaP cells (prostate cancer) in response to synthetic androgen R1881 [PubChem=13766].
Full description | The human prostate gland is an important target organ of androgenic hormones. Testosterone and dihydrotestosterone interact with the androgen receptor to regulate vital aspects of prostate growth and function including cellular proliferation, differentiation, apoptosis, metabolism, and secretory activity. Our objective in this study was to characterize the temporal program of transcription that reflects the cellular response to androgens and to identify specific androgen-regulated genes (ARGs) or gene networks that participate in these responses. We used cDNA microarrays representing about 20,000 distinct human genes to profile androgen-responsive transcripts in the LNCaP adenocarcinoma cell line and identified 146 genes with transcript alterations more than 3-fold. Of these, 103 encode proteins with described functional roles, and 43 represent transcripts that have yet to be characterized. Temporal gene expression profiles grouped the ARGs into four distinct cohorts. Five uncharacterized ARGs demonstrated exclusive or high expression levels in the prostate relative to other tissues studied. A search of available DNA sequence upstream of 28 ARGs identified 25 with homology to the androgen response-element consensus-binding motif. These results identify previously uncharacterized and unsuspected genes whose expression levels are directly or indirectly regulated by androgens; further, they provide a comprehensive temporal view of the transcriptional program of human androgen-responsive cells.

Standard name | TARTE_PLASMA_CELL_VS_B_LYMPHOCYTE_UP
Systematic name | M4552
Organism | Homo sapiens
PMID | 12663452
Authors | Tarte K,Zhan F,De Vos J,Klein B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in plasma cells compared with B lymphocytes.
Full description | Plasma cells (PCs), the end point of B-cell differentiation, are a heterogeneous cell compartment comprising several cell subsets from short-lived highly proliferative plasmablasts to long-lived nondividing fully mature PCs. Whereas the major transcription factors driving the differentiation of B cells to PCs were recently identified, the subtle genetic changes that underlie the transition from plasmablasts to mature PCs are poorly understood. We recently described an in vitro model making it possible to obtain a large number of cells with the morphologic, phenotypic, and functional characteristics of normal polyclonal plasmablastic cells (PPCs). Using Affymetrix microarrays we compared the gene expression profiles of these PPCs with those of mature PCs isolated from tonsils (TPCs) and bone marrow (BMPCs), and with those of B cells purified from peripheral blood (PBB cells) and tonsils (TBCs). Unsupervised principal component analysis clearly distinguished the 5 cell populations on the basis of their differentiation and proliferation status. Detailed statistical analysis allowed the identification of 85 PC genes and 40 B-cell genes, overexpressed, respectively, in the 3 PC subsets or in the 2 B-cell subsets. In addition, several signaling molecules and antiapoptotic proteins were found to be induced in BMPCs compared with PPCs and could be involved in the accumulation and prolonged survival of BMPCs in close contact with specialized stromal microenvironment. These data should help to better understand the molecular events that regulate commitment to a PC fate, mediate PC maintenance in survival niches, and could facilitate PC immortalization in plasma cell dyscrasias.

Standard name | BYSTROEM_CORRELATED_WITH_IL5_DN
Systematic name | M1401
Organism | Mus musculus
PMID | 14525773
Authors | Byström J,Wynn TA,Domachowske JB,Rosenberg HF
Category | C2
Sub-category | CGP
Brief description | Genes whose expression in bone marrow samples correlated inversely with increased levels of serum IL5 [GeneID=3567].
Full description | Interleukin-5 (IL-5) is a hematopoietic differentiation factor that promotes the development of mature eosinophils from progenitors in bone marrow. We present a multifactorial microarray study documenting the transcriptional events in bone marrow of wild-type and IL-5-deficient mice at baseline and in response to infection with Schistosoma mansoni. The microarray data were analyzed by a 4-way subtractive algorithm that eliminated confounding non-IL-5-related sequelae of schistosome infection as well as alterations in gene expression among uninfected mice. Among the most prominent findings, we observed 7- to 40-fold increased expression of transcripts encoding the classic eosinophil granule proteins (eosinophil peroxidase, major basic protein, the ribonucleases) together with arachidonate-15-lipoxygenase and protease inhibitor plasminogen activator inhibitor 2 (PAI-2), in the IL-5-producing, infected wild-type mice only. This was accompanied by increased transcription of genes involved in secretory protein biosynthesis and granule-vesicle formation. Interestingly, we did not detect increased expression of genes encoding eosinophil-related chemokine receptors (CCR1, CCR3) or members of the GATA or CCAAT/enhancer binding protein (C/EBP) transcription factor families. These data suggest that the IL-5-responsive progenitors in the mouse bone marrow are already significantly committed to the eosinophil lineage and that IL-5 promotes differentiation of these committed progenitors into cells with recognizable and characteristic cytoplasmic granules and granule proteins.

Standard name | SWEET_KRAS_TARGETS_DN
Systematic name | M4359
Organism | Homo sapiens
PMID | 15608639
Authors | Sweet-Cordero A,Mukherjee S,Subramanian A,You H,Roix JJ,Ladd-Acosta C,Mesirov J,Golub TR,Jacks T
Category | C2
Sub-category | CGP
Brief description | Genes upregulated in control vs KRAS [GeneID=3845] knockdown in a human cell line.
Full description | Using advanced gene targeting methods, generating mouse models of cancer that accurately reproduce the genetic alterations present in human tumors is now relatively straightforward. The challenge is to determine to what extent such models faithfully mimic human disease with respect to the underlying molecular mechanisms that accompany tumor progression. Here we describe a method for comparing mouse models of cancer with human tumors using gene-expression profiling. We applied this method to the analysis of a model of Kras2-mediated lung cancer and found a good relationship to human lung adenocarcinoma, thereby validating the model. Furthermore, we found that whereas a gene-expression signature of KRAS2 activation was not identifiable when analyzing human tumors with known KRAS2 mutation status alone, integrating mouse and human data uncovered a gene-expression signature of KRAS2 mutation in human lung cancer. We confirmed the importance of this signature by gene-expression analysis of short hairpin RNA-mediated inhibition of oncogenic Kras2. These experiments identified both a pattern of gene expression indicative of KRAS2 mutation and potential effectors of oncogenic KRAS2 activity in human cancer. This approach provides a strategy for using genomic analysis of animal models to probe human disease.

Standard name | SHEPARD_CRUSH_AND_BURN_MUTANT_UP
Systematic name | M10828
Organism | Danio rerio
PMID | 16150706
Authors | Shepard JL,Amatruda JF,Stern HM,Subramanian A,Finkelstein D,Ziai J,Finley KR,Pfaff KL,Hersey C,Zhou Y,Barut B,Freedman M,Lee C,Spitsbergen J,Neuberg D,Weber G,Golub TR,Glickman JN,Kutok JL,Aster JC,Zon LI
Category | C2
Sub-category | CGP
Brief description | Human orthologs of genes up-regulated in the crb ('crash and burn') zebrafish mutant that represents a loss-of-function mutation in BMYB [GeneID=4605].
Full description | A major goal of cancer research has been to identify genes that contribute to cancer formation. The similar pathology between zebrafish and human tumors, as well as the past success of large-scale genetic screens in uncovering human disease genes, makes zebrafish an ideal system in which to find such new genes. Here, we show that a zebrafish forward genetic screen uncovered multiple cell proliferation mutants including one mutant, crash&burn (crb), that represents a loss-of-function mutation in bmyb, a transcriptional regulator and member of a putative proto-oncogene family. crb mutant embryos have defects in mitotic progression and spindle formation, and exhibit genome instability. Regulation of cyclin B levels by bmyb appears to be the mechanism of mitotic accumulation in crb. Carcinogenesis studies reveal increased cancer susceptibility in adult crb heterozygotes. Gene-expression signatures associated with loss of bmyb in zebrafish are also correlated with conserved signatures in human tumor samples, and down-regulation of the B-myb signature genes is associated with retention of p53 function. Our findings show that zebrafish screens can uncover cancer pathways, and demonstrate that loss of function of bmyb is associated with cancer.

Standard name | ROSS_AML_WITH_PML_RARA_FUSION
Systematic name | M15368
Organism | Homo sapiens
PMID | 15226186
Authors | Ross ME,Mahfouz R,Onciu M,Liu HC,Zhou X,Song G,Shurtleff SA,Pounds S,Cheng C,Ma J,Ribeiro RC,Rubnitz JE,Girtman K,Williams WK,Raimondi SC,Liang DC,Shih LY,Pui CH,Downing JR
Category | C2
Sub-category | CGP
Brief description | Top 100 probe sets for pediatric acute myeloid leukemia (AML) subtype t(15;17): has PML RARA fusion [GeneID=5371;5914].
Full description | Contemporary treatment of pediatric acute myeloid leukemia (AML) requires the assignment of patients to specific risk groups. To explore whether expression profiling of leukemic blasts could accurately distinguish between the known risk groups of AML, we analyzed 130 pediatric and 20 adult AML diagnostic bone marrow or peripheral blood samples using the Affymetrix U133A microarray. Class discriminating genes were identified for each of the major prognostic subtypes of pediatric AML, including t(15;17)[PML-RARalpha], t(8;21)[AML1-ETO], inv(16) [CBFbeta-MYH11], MLL chimeric fusion genes, and cases classified as FAB-M7. When subsets of these genes were used in supervised learning algorithms, an overall classification accuracy of more than 93% was achieved. Moreover, we were able to use the expression signatures generated from the pediatric samples to accurately classify adult de novo AMLs with the same genetic lesions. The class discriminating genes also provided novel insights into the molecular pathobiology of these leukemias. Finally, using a combined pediatric data set of 130 AMLs and 137 acute lymphoblastic leukemias, we identified an expression signature for cases with MLL chimeric fusion genes irrespective of lineage. Surprisingly, AMLs containing partial tandem duplications of MLL failed to cluster with MLL chimeric fusion gene cases, suggesting a significant difference in their underlying mechanism of transformation.

Standard name | LEI_HOXC8_TARGETS_UP
Systematic name | M1402
Organism | Mus musculus
PMID | 15699330
Authors | Lei H,Wang H,Juan AH,Ruddle FH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblasts) by overexpression of HOXC8 [GeneID=3224].
Full description | Hox genes encode transcription factors that control spatial patterning during embryogenesis. To date, downstream targets of Hox genes have proven difficult to identify. Here, we describe studies designed to identify target genes under the control of the murine transcription factor Hoxc8. We used a mouse 16,463 gene oligonucleotide microarray to identify mRNAs whose expression was altered by the overexpression of Hoxc8 in C57BL/6J mouse embryo fibroblasts (MEF) in cell culture (in vitro). We identified a total of 34 genes whose expression was changed by 2-fold or greater: 16 genes were up-regulated, and 18 genes were down-regulated. The majority of genes encoded proteins involved in critical biological processes, such as cell adhesion, migration, metabolism, apoptosis, and tumorigenesis. Two genes showed high levels of regulation: (i) secreted phosphoprotein 1 (Spp1), also known as osteopontin (OPN), was down-regulated 4.8-fold, and (ii) frizzled homolog 2 (Drosophila) (Fzd2) was up-regulated 4.4-fold. Chromatin immunoprecipitation (ChIP) analysis confirmed the direct interaction between the OPN promoter and Hoxc8 protein in vivo, supporting the view that OPN is a direct transcriptional target of Hoxc8.

Standard name | PARK_HSC_VS_MULTIPOTENT_PROGENITORS_DN
Systematic name | M1403
Organism | Mus musculus
PMID | 11781229
Authors | Park IK,He Y,Lin F,Laerum OD,Tian Q,Bumgarner R,Klug CA,Li K,Kuhr C,Doyle MJ,Xie T,Schummer M,Sun Y,Goldsmith A,Clarke MF,Weissman IL,Hood L,Li L
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in long term hematopoietic stem cells (LT-HSC) compared to multipotent progenitor (MPP) cells.
Full description | Hematopoietic stem cells (HSCs) have self-renewal capacity and multilineage developmental potentials. The molecular mechanisms that control the self-renewal of HSCs are still largely unknown. Here, a systematic approach using bioinformatics and array hybridization techniques to analyze gene expression profiles in HSCs is described. To enrich mRNAs predominantly expressed in uncommitted cell lineages, 54 000 cDNA clones generated from a highly enriched population of HSCs and a mixed population of stem and early multipotent progenitor (MPP) cells were arrayed on nylon membranes (macroarray or high-density array), and subtracted with cDNA probes derived from mature lineage cells including spleen, thymus, and bone marrow. Five thousand cDNA clones with very low hybridization signals were selected for sequencing and further analysis using microarrays on glass slides. Two populations of cells, HSCs and MPP cells, were compared for differential gene expression using microarray analysis. HSCs have the ability to self-renew, while MPP cells have lost the capacity for self-renewal. A large number of genes that were differentially expressed by enriched populations of HSCs and MPP cells were identified. These included transcription factors, signaling molecules, and previously unknown genes.

Standard name | LEE_LIVER_CANCER_CIPROFIBRATE_DN
Systematic name | M11640
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma (HCC) induced by ciprofibrate [PubChem=2763].
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | ASTON_MAJOR_DEPRESSIVE_DISORDER_DN
Systematic name | M11011
Organism | Homo sapiens
PMID | 15303102
Authors | Aston C,Jiang L,Sokolov BP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the temporal cortex samples from patients with major depressive disorder.
Full description | Major depressive disorder is one of the most common and devastating psychiatric disorders. To identify candidate mechanisms for major depressive disorder, we compared gene expression in the temporal cortex from 12 patients with major depressive disorder and 14 matched controls using Affymetrix HgU95A microarrays. Significant expression changes were revealed in families of genes involved in neurodevelopment, signal transduction and cell communication. Among these, the expression of 17 genes related to oligodendrocyte function was significantly (P < 0.05, fold change > 1.4) decreased in patients with major depressive disorder. Eight of these 17 genes encode structural components of myelin (CNP, MAG, MAL, MOG, MOBP, PMP22, PLLP, PLP1). Five other genes encode enzymes involved in the synthesis of myelin constituents (ASPA, UGT8), or are essential in regulation of myelin formation (ENPP2, EDG2, TF, KLK6). One gene, that is, SOX10, encodes a transcription factor regulating other myelination-related genes. OLIG2 is a transcription factor present exclusively in oligodendrocytes and oligodendrocyte precursors. Another gene, ERBB3, is involved in oligodendrocyte differentiation. In addition to myelination-related genes, there were significant changes in multiple genes involved in axonal growth/synaptic function. These findings suggest that major depressive disorder may be associated with changes in cell communication and signal transduction mechanisms that contribute to abnormalities in oligodendroglia and synaptic function. Taken together with other studies, these findings indicate that major depressive disorder may share common oligodendroglial abnormalities with schizophrenia and bipolar disorder.

Standard name | STANELLE_E2F1_TARGETS
Systematic name | M16061
Organism | Homo sapiens
PMID | 11937641
Authors | Stanelle J,Stiewe T,Theseling CC,Peter M,Pützer BM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by induction of E2F1 expression in Saos2 (osteosarcoma) cells.
Full description | The p16/RB/E2F regulatory pathway, which controls transit through the G1 restriction point of the cell cycle, is one of the most frequent targets of genetic alterations in human cancer. Any of these alterations results in the deregulated expression of the transcription factor E2F, one of the key mediators of cell cycle progression. Under these conditions, E2F1 also participates in the induction of apoptosis by a p53-dependent pathway, and independently of p53. Recently, we identified the p53-homolog p73 as a first direct target of p53-independent apoptosis. Here, we used a cDNA microarray to screen an inducible E2F1-expressing Saos-2 cell line for E2F1 target genes. Expression analysis by cDNA microarray and RT-PCR revealed novel E2F1 target genes involved in E2F1-regulated cellular functions such as cell cycle control, DNA replication and apoptosis. In addition, the identification of novel E2F1 target genes participating in the processes of angiogenesis, invasion and metastasis supports the view that E2F1 plays a central role in many aspects of cancer development. These results provide new insight into the role of E2F1 in tumorigenesis as a basis for the development of novel anti-cancer therapeutics.

Standard name | CHESLER_BRAIN_D6MIT150_QTL_CIS
Systematic name | M12143
Organism | Mus musculus
PMID | 15711545
Authors | Chesler EJ,Lu L,Shou S,Qu Y,Gu J,Wang J,Hsu HC,Mountz JD,Baldwin NE,Langston MA,Threadgill DW,Manly KF,Williams RW
Category | C2
Sub-category | CGP
Brief description | Cis-regulatory QTLs (quantitative trait loci) found at the D6Mit150 region.
Full description | Patterns of gene expression in the central nervous system are highly variable and heritable. This genetic variation among normal individuals leads to considerable structural, functional and behavioral differences. We devised a general approach to dissect genetic networks systematically across biological scale, from base pairs to behavior, using a reference population of recombinant inbred strains. We profiled gene expression using Affymetrix oligonucleotide arrays in the BXD recombinant inbred strains, for which we have extensive SNP and haplotype data. We integrated a complementary database comprising 25 years of legacy phenotypic data on these strains. Covariance among gene expression and pharmacological and behavioral traits is often highly significant, corroborates known functional relations and is often generated by common quantitative trait loci. We found that a small number of major-effect quantitative trait loci jointly modulated large sets of transcripts and classical neural phenotypes in patterns specific to each tissue. We developed new analytic and graph theoretical approaches to study shared genetic modulation of networks of traits using gene sets involved in neural synapse function as an example. We built these tools into an open web resource called WebQTL that can be used to test a broad array of hypotheses.

Standard name | SHIPP_DLBCL_CURED_VS_FATAL_DN
Systematic name | M11685
Organism | Homo sapiens
PMID | 11786909
Authors | Shipp MA,Ross KN,Tamayo P,Weng AP,Kutok JL,Aguiar RC,Gaasenbeek M,Angelo M,Reich M,Pinkus GS,Ray TS,Koval MA,Last KW,Norton A,Lister TA,Mesirov J,Neuberg DS,Lander ES,Aster JC,Golub TR
Category | C2
Sub-category | CGP
Brief description | Top 50 down-regulated markers for the diffused large B-cell lymphoma (DLBCL) that distinguished between cured and fatal/refractory clinical outcomes.
Full description | Diffuse large B-cell lymphoma (DLBCL), the most common lymphoid malignancy in adults, is curable in less than 50% of patients. Prognostic models based on pre-treatment characteristics, such as the International Prognostic Index (IPI), are currently used to predict outcome in DLBCL. However, clinical outcome models identify neither the molecular basis of clinical heterogeneity, nor specific therapeutic targets. We analyzed the expression of 6,817 genes in diagnostic tumor specimens from DLBCL patients who received cyclophosphamide, adriamycin, vincristine and prednisone (CHOP)-based chemotherapy, and applied a supervised learning prediction method to identify cured versus fatal or refractory disease. The algorithm classified two categories of patients with very different five-year overall survival rates (70% versus 12%). The model also effectively delineated patients within specific IPI risk categories who were likely to be cured or to die of their disease. Genes implicated in DLBCL outcome included some that regulate responses to B-cell-receptor signaling, critical serine/threonine phosphorylation pathways and apoptosis. Our data indicate that supervised learning classification techniques can predict outcome in DLBCL and identify rational targets for intervention.

Standard name | GRANDVAUX_IFN_RESPONSE_NOT_VIA_IRF3
Systematic name | M6318
Organism | Homo sapiens
PMID | 11991981
Authors | Grandvaux N,Servant MJ,tenOever B,Sen GC,Balachandran S,Barber GN,Lin R,Hiscott J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Jurkat cells (T lymphocyte) by IFN1@, and IFNB1 [GeneID=3438;3456] but not by overexpression of a constitutively active form of IRF3 [GeneID=3661].
Full description | Ubiquitously expressed interferon regulatory factor 3 (IRF-3) is directly activated after virus infection and functions as a key activator of the immediate-early alpha/beta interferon (IFN) genes, as well as the RANTES chemokine gene. In the present study, a tetracycline-inducible expression system expressing a constitutively active form of IRF-3 (IRF-3 5D) was combined with DNA microarray analysis to identify target genes regulated by IRF-3. Changes in mRNA expression profiles of 8,556 genes were monitored after Tet-inducible expression of IRF-3 5D. Among the genes upregulated by IRF-3 were transcripts for several known IFN-stimulated genes (ISGs). Subsequent analysis revealed that IRF-3 directly induced the expression of ISG56 in an IFN-independent manner through the IFN-stimulated responsive elements (ISREs) of the ISG56 promoter. These results demonstrate that, in addition to its role in the formation of a functional immediate-early IFN-beta enhanceosome, IRF-3 is able to discriminate among ISRE-containing genes involved in the establishment of the antiviral state as a direct response to virus infection.

Standard name | UEDA_CENTRAL_CLOCK
Systematic name | M2637
Organism | Mus musculus
PMID | 15273285
Authors | Ueda HR,Chen W,Minami Y,Honma S,Honma K,Iino M,Hashimoto S
Category | C2
Sub-category | CGP
Brief description | Molecular timetable composed of 96 time-indicating genes (103 probes) in the central (suprachiasmatic nucleus (SCN)) clock.
Full description | Detection of individual body time (BT) via a single-time-point assay has been a longstanding unfulfilled dream in medicine, because BT information can be exploited to maximize potency and minimize toxicity during drug administration and thus will enable highly optimized medication. To achieve this dream, we created a molecular timetable composed of >100 time-indicating genes, whose gene expression levels can represent internal BT. Here we describe a robust method called the molecular-timetable method for BT detection from a single-time-point expression profile. The power of this method is demonstrated by the sensitive and accurate detection of BT and the sensitive diagnosis of rhythm disorders. These results demonstrate the feasibility of BT detection based on single-time-point sampling, suggest the potential for expression-based diagnosis of rhythm disorders, and may translate functional genomics into chronotherapy and personalized medicine.

Standard name | BYSTRYKH_HEMATOPOIESIS_STEM_CELL_FGF3
Systematic name | M10331
Organism | Mus musculus
PMID | 15711547
Authors | Bystrykh L,Weersing E,Dontje B,Sutton S,Pletcher MT,Wiltshire T,Su AI,Vellenga E,Wang J,Manly KF,Lu L,Chesler EJ,Alberts R,Jansen RC,Williams RW,Cooke MP,de Haan G
Category | C2
Sub-category | CGP
Brief description | Genes whose expression is coregulated with that of FGF3 [GeneID=2248] in hematopoietic stem cells (HSC).
Full description | We combined large-scale mRNA expression analysis and gene mapping to identify genes and loci that control hematopoietic stem cell (HSC) function. We measured mRNA expression levels in purified HSCs isolated from a panel of densely genotyped recombinant inbred mouse strains. We mapped quantitative trait loci (QTLs) associated with variation in expression of thousands of transcripts. By comparing the physical transcript position with the location of the controlling QTL, we identified polymorphic cis-acting stem cell genes. We also identified multiple trans-acting control loci that modify expression of large numbers of genes. These groups of coregulated transcripts identify pathways that specify variation in stem cells. We illustrate this concept with the identification of candidate genes involved with HSC turnover. We compared expression QTLs in HSCs and brain from the same mice and identified both shared and tissue-specific QTLs. Our data are accessible through WebQTL, a web-based interface that allows custom genetic linkage analysis and identification of coregulated transcripts.

Standard name | GOLUB_ALL_VS_AML_UP
Systematic name | M4275
Organism | Homo sapiens
PMID | 10521349
Authors | Golub TR,Slonim DK,Tamayo P,Huard C,Gaasenbeek M,Mesirov JP,Coller H,Loh ML,Downing JR,Caligiuri MA,Bloomfield CD,Lander ES
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes highly correlated with acute lymphoblastic leukemia (ALL) vs acute myeloid leukemia (AML).
Full description | Although cancer classification has improved over the past 30 years, there has been no general approach for identifying new cancer classes (class discovery) or for assigning tumors to known classes (class prediction). Here, a generic approach to cancer classification based on gene expression monitoring by DNA microarrays is described and applied to human acute leukemias as a test case. A class discovery procedure automatically discovered the distinction between acute myeloid leukemia (AML) and acute lymphoblastic leukemia (ALL) without previous knowledge of these classes. An automatically derived class predictor was able to determine the class of new leukemia cases. The results demonstrate the feasibility of cancer classification based solely on gene expression monitoring and suggest a general strategy for discovering and predicting cancer classes for other types of cancer, independent of previous biological knowledge.

Standard name | HOUSTIS_ROS
Systematic name | M6891
Organism | Mus musculus
PMID | 16612386
Authors | Houstis N,Rosen ED,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes known to modulate ROS or whose expression changes in response to ROS
Full description | Insulin resistance is a cardinal feature of type 2 diabetes and is characteristic of a wide range of other clinical and experimental settings. Little is known about why insulin resistance occurs in so many contexts. Do the various insults that trigger insulin resistance act through a common mechanism? Or, as has been suggested, do they use distinct cellular pathways? Here we report a genomic analysis of two cellular models of insulin resistance, one induced by treatment with the cytokine tumour-necrosis factor-alpha and the other with the glucocorticoid dexamethasone. Gene expression analysis suggests that reactive oxygen species (ROS) levels are increased in both models, and we confirmed this through measures of cellular redox state. ROS have previously been proposed to be involved in insulin resistance, although evidence for a causal role has been scant. We tested this hypothesis in cell culture using six treatments designed to alter ROS levels, including two small molecules and four transgenes; all ameliorated insulin resistance to varying degrees. One of these treatments was tested in obese, insulin-resistant mice and was shown to improve insulin sensitivity and glucose homeostasis. Together, our findings suggest that increased ROS levels are an important trigger for insulin resistance in numerous settings.

Standard name | BASSO_B_LYMPHOCYTE_NETWORK
Systematic name | M10633
Organism | Homo sapiens
PMID | 15778709
Authors | Basso K,Margolin AA,Stolovitzky G,Klein U,Dalla-Favera R,Califano A
Category | C2
Sub-category | CGP
Brief description | Genes which comprise the top 1% of highly interconnected genes (major hubs) that account for most of gene interactions in the reconstructed regulatory networks from expression profiles in B lymphocytes.
Full description | Cellular phenotypes are determined by the differential activity of networks linking coregulated genes. Available methods for the reverse engineering of such networks from genome-wide expression profiles have been successful only in the analysis of lower eukaryotes with simple genomes. Using a new method called ARACNe (algorithm for the reconstruction of accurate cellular networks), we report the reconstruction of regulatory networks from expression profiles of human B cells. The results are suggestive a hierarchical, scale-free network, where a few highly interconnected genes (hubs) account for most of the interactions. Validation of the network against available data led to the identification of MYC as a major hub, which controls a network comprising known target genes as well as new ones, which were biochemically validated. The newly identified MYC targets include some major hubs. This approach can be generally useful for the analysis of normal and pathologic networks in mammalian cells.

Standard name | BYSTRYKH_HEMATOPOIESIS_STEM_CELL_QTL_CIS
Systematic name | M8699
Organism | Mus musculus
PMID | 15711547
Authors | Bystrykh L,Weersing E,Dontje B,Sutton S,Pletcher MT,Wiltshire T,Su AI,Vellenga E,Wang J,Manly KF,Lu L,Chesler EJ,Alberts R,Jansen RC,Williams RW,Cooke MP,de Haan G
Category | C2
Sub-category | CGP
Brief description | Transcripts in hematopoietic stem cells (HSC) which are cis-regulated (i.e., modulated by a QTL (quantitative trait locus) in close proximity to the gene).
Full description | We combined large-scale mRNA expression analysis and gene mapping to identify genes and loci that control hematopoietic stem cell (HSC) function. We measured mRNA expression levels in purified HSCs isolated from a panel of densely genotyped recombinant inbred mouse strains. We mapped quantitative trait loci (QTLs) associated with variation in expression of thousands of transcripts. By comparing the physical transcript position with the location of the controlling QTL, we identified polymorphic cis-acting stem cell genes. We also identified multiple trans-acting control loci that modify expression of large numbers of genes. These groups of coregulated transcripts identify pathways that specify variation in stem cells. We illustrate this concept with the identification of candidate genes involved with HSC turnover. We compared expression QTLs in HSCs and brain from the same mice and identified both shared and tissue-specific QTLs. Our data are accessible through WebQTL, a web-based interface that allows custom genetic linkage analysis and identification of coregulated transcripts.

Standard name | SCHUHMACHER_MYC_TARGETS_DN
Systematic name | M969
Organism | Homo sapiens
PMID | 11139609
Authors | Schuhmacher M,Kohlhuber F,Hölzel M,Kaiser C,Burtscher H,Jarsch M,Bornkamm GW,Laux G,Polack A,Weidle UH,Eick D
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in P493-6 cells (Burkitt's lymphoma) induced to express MYC [GeneID=4609].
Full description | The proto-oncogene c-myc (myc) encodes a transcription factor (Myc) that promotes growth, proliferation and apoptosis. Myc has been suggested to induce these effects by induction/repression of downstream genes. Here we report the identification of potential Myc target genes in a human B cell line that grows and proliferates depending on conditional myc expression. Oligonucleotide microarrays were applied to identify downstream genes of Myc at the level of cytoplasmic mRNA. In addition, we identified potential Myc target genes in nuclear run-on experiments by changes in their transcription rate. The identified genes belong to gene classes whose products are involved in amino acid/protein synthesis, lipid metabolism, protein turnover/folding, nucleotide/DNA synthesis, transport, nucleolus function/RNA binding, transcription and splicing, oxidative stress and signal transduction. The identified targets support our current view that myc acts as a master gene for growth control and increases transcription of a large variety of genes.

Standard name | LEI_HOXC8_TARGETS_DN
Systematic name | M1404
Organism | Mus musculus
PMID | 15699330
Authors | Lei H,Wang H,Juan AH,Ruddle FH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblasts) by overexpression of HOXC8 [GeneID=3224].
Full description | Hox genes encode transcription factors that control spatial patterning during embryogenesis. To date, downstream targets of Hox genes have proven difficult to identify. Here, we describe studies designed to identify target genes under the control of the murine transcription factor Hoxc8. We used a mouse 16,463 gene oligonucleotide microarray to identify mRNAs whose expression was altered by the overexpression of Hoxc8 in C57BL/6J mouse embryo fibroblasts (MEF) in cell culture (in vitro). We identified a total of 34 genes whose expression was changed by 2-fold or greater: 16 genes were up-regulated, and 18 genes were down-regulated. The majority of genes encoded proteins involved in critical biological processes, such as cell adhesion, migration, metabolism, apoptosis, and tumorigenesis. Two genes showed high levels of regulation: (i) secreted phosphoprotein 1 (Spp1), also known as osteopontin (OPN), was down-regulated 4.8-fold, and (ii) frizzled homolog 2 (Drosophila) (Fzd2) was up-regulated 4.4-fold. Chromatin immunoprecipitation (ChIP) analysis confirmed the direct interaction between the OPN promoter and Hoxc8 protein in vivo, supporting the view that OPN is a direct transcriptional target of Hoxc8.

Standard name | CHESLER_BRAIN_QTL_CIS
Systematic name | M17500
Organism | Mus musculus
PMID | 15711545
Authors | Chesler EJ,Lu L,Shou S,Qu Y,Gu J,Wang J,Hsu HC,Mountz JD,Baldwin NE,Langston MA,Threadgill DW,Manly KF,Williams RW
Category | C2
Sub-category | CGP
Brief description | Best cis-regulated quantitative trait loci (QTLs) in the mouse genome which modulate transcription in brain tissue.
Full description | Patterns of gene expression in the central nervous system are highly variable and heritable. This genetic variation among normal individuals leads to considerable structural, functional and behavioral differences. We devised a general approach to dissect genetic networks systematically across biological scale, from base pairs to behavior, using a reference population of recombinant inbred strains. We profiled gene expression using Affymetrix oligonucleotide arrays in the BXD recombinant inbred strains, for which we have extensive SNP and haplotype data. We integrated a complementary database comprising 25 years of legacy phenotypic data on these strains. Covariance among gene expression and pharmacological and behavioral traits is often highly significant, corroborates known functional relations and is often generated by common quantitative trait loci. We found that a small number of major-effect quantitative trait loci jointly modulated large sets of transcripts and classical neural phenotypes in patterns specific to each tissue. We developed new analytic and graph theoretical approaches to study shared genetic modulation of networks of traits using gene sets involved in neural synapse function as an example. We built these tools into an open web resource called WebQTL that can be used to test a broad array of hypotheses.

Standard name | ROSS_AML_WITH_CBFB_MYH11_FUSION
Systematic name | M5236
Organism | Homo sapiens
PMID | 15226186
Authors | Ross ME,Mahfouz R,Onciu M,Liu HC,Zhou X,Song G,Shurtleff SA,Pounds S,Cheng C,Ma J,Ribeiro RC,Rubnitz JE,Girtman K,Williams WK,Raimondi SC,Liang DC,Shih LY,Pui CH,Downing JR
Category | C2
Sub-category | CGP
Brief description | Top 63 probe sets for pediatric acute myeloid leukemia (AML) subtype inv(16); has a CBFB-MYH11 fusion [GeneID=865;4629].
Full description | Contemporary treatment of pediatric acute myeloid leukemia (AML) requires the assignment of patients to specific risk groups. To explore whether expression profiling of leukemic blasts could accurately distinguish between the known risk groups of AML, we analyzed 130 pediatric and 20 adult AML diagnostic bone marrow or peripheral blood samples using the Affymetrix U133A microarray. Class discriminating genes were identified for each of the major prognostic subtypes of pediatric AML, including t(15;17)[PML-RARalpha], t(8;21)[AML1-ETO], inv(16) [CBFbeta-MYH11], MLL chimeric fusion genes, and cases classified as FAB-M7. When subsets of these genes were used in supervised learning algorithms, an overall classification accuracy of more than 93% was achieved. Moreover, we were able to use the expression signatures generated from the pediatric samples to accurately classify adult de novo AMLs with the same genetic lesions. The class discriminating genes also provided novel insights into the molecular pathobiology of these leukemias. Finally, using a combined pediatric data set of 130 AMLs and 137 acute lymphoblastic leukemias, we identified an expression signature for cases with MLL chimeric fusion genes irrespective of lineage. Surprisingly, AMLs containing partial tandem duplications of MLL failed to cluster with MLL chimeric fusion gene cases, suggesting a significant difference in their underlying mechanism of transformation.

Standard name | IIZUKA_LIVER_CANCER_PROGRESSION_L0_L1_UP
Systematic name | M2152
Organism | Homo sapiens
PMID | 15710396
Authors | Iizuka N,Oka M,Yamada-Okabe H,Mori N,Tamesa T,Okada T,Takemoto N,Sakamoto K,Hamada K,Ishitsuka H,Miyamoto T,Uchimura S,Hamamoto Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during transition from L0 (non-tumor, not infected with HCV) to L1 (non-tumor, infected with HCV) in the development of hepatocellular carcinoma.
Full description | Using high-density oligonucleotide array, we comprehensively analyzed expression levels of 12600 genes in 50 hepatocellular carcinoma (HCC) samples with positive hepatitis C virus (HCV) serology (well (G1), moderately (G2), and poorly (G3) differentiated tumors) and 11 non-tumorous livers (L1 and L0) with and without HCV infection. We searched for discriminatory genes of transition (L0 vs. L1, L1 vs. G1, G1 vs. G2, G2 vs. G3) with a supervised learning method, and then arranged the samples by self-organizing map (SOM) with the discriminatory gene sets. The SOM arranged the five clusters on a unique sigmoidal curve in the order L0, L1, G1, G2, and G3. The sample arrangement reproduced development-related features of HCC such as p53 abnormality. Strikingly, G2 tumors without venous invasion were located closer to the G1 cluster, and most G2 tumors with venous invasion were located closer to the G3 cluster (P=0.001 by Fisher's exact test). Our present profiling data will serve as a framework to understand the relation between the development and dedifferentiation of HCC.

Standard name | IIZUKA_LIVER_CANCER_PROGRESSION_L1_G1_DN
Systematic name | M8659
Organism | Homo sapiens
PMID | 15710396
Authors | Iizuka N,Oka M,Yamada-Okabe H,Mori N,Tamesa T,Okada T,Takemoto N,Sakamoto K,Hamada K,Ishitsuka H,Miyamoto T,Uchimura S,Hamamoto Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during transition from L1 (non-tumor, infected with HCV) to G1 (well differentiated tumor, infected with HCV) in the development of hepatocellular carcinoma.
Full description | Using high-density oligonucleotide array, we comprehensively analyzed expression levels of 12600 genes in 50 hepatocellular carcinoma (HCC) samples with positive hepatitis C virus (HCV) serology (well (G1), moderately (G2), and poorly (G3) differentiated tumors) and 11 non-tumorous livers (L1 and L0) with and without HCV infection. We searched for discriminatory genes of transition (L0 vs. L1, L1 vs. G1, G1 vs. G2, G2 vs. G3) with a supervised learning method, and then arranged the samples by self-organizing map (SOM) with the discriminatory gene sets. The SOM arranged the five clusters on a unique sigmoidal curve in the order L0, L1, G1, G2, and G3. The sample arrangement reproduced development-related features of HCC such as p53 abnormality. Strikingly, G2 tumors without venous invasion were located closer to the G1 cluster, and most G2 tumors with venous invasion were located closer to the G3 cluster (P=0.001 by Fisher's exact test). Our present profiling data will serve as a framework to understand the relation between the development and dedifferentiation of HCC.

Standard name | FERRANDO_TAL1_NEIGHBORS
Systematic name | M1007
Organism | Homo sapiens
PMID | 12086890
Authors | Ferrando AA,Neuberg DS,Staunton J,Loh ML,Huard C,Raimondi SC,Behm FG,Pui CH,Downing JR,Gilliland DG,Lander ES,Golub TR,Look AT
Category | C2
Sub-category | CGP
Brief description | Nearest neighbors of TAL1 [GeneID=6886], based on the close agreement of their expression profiles with that of TAL1 in pediatric T cell acute lymphoblastic leukemia (T-ALL)
Full description | Human T cell leukemias can arise from oncogenes activated by specific chromosomal translocations involving the T cell receptor genes. Here we show that five different T cell oncogenes (HOX11, TAL1, LYL1, LMO1, and LMO2) are often aberrantly expressed in the absence of chromosomal abnormalities. Using oligonucleotide microarrays, we identified several gene expression signatures that were indicative of leukemic arrest at specific stages of normal thymocyte development: LYL1+ signature (pro-T), HOX11+ (early cortical thymocyte), and TAL1+ (late cortical thymocyte). Hierarchical clustering analysis of gene expression signatures grouped samples according to their shared oncogenic pathways and identified HOX11L2 activation as a novel event in T cell leukemogenesis. These findings have clinical importance, since HOX11 activation is significantly associated with a favorable prognosis, while expression of TAL1, LYL1, or, surprisingly, HOX11L2 confers a much worse response to treatment. Our results illustrate the power of gene expression profiles to elucidate transformation pathways relevant to human leukemia.

Standard name | BYSTRYKH_HEMATOPOIESIS_STEM_CELL_AND_BRAIN_QTL_TRANS
Systematic name | M14242
Organism | Mus musculus
PMID | 15711547
Authors | Bystrykh L,Weersing E,Dontje B,Sutton S,Pletcher MT,Wiltshire T,Su AI,Vellenga E,Wang J,Manly KF,Lu L,Chesler EJ,Alberts R,Jansen RC,Williams RW,Cooke MP,de Haan G
Category | C2
Sub-category | CGP
Brief description | Genes trans-regulated by the same QTL (quantitative trait loci) in brain and hematopoietic stem cells (HSC).
Full description | We combined large-scale mRNA expression analysis and gene mapping to identify genes and loci that control hematopoietic stem cell (HSC) function. We measured mRNA expression levels in purified HSCs isolated from a panel of densely genotyped recombinant inbred mouse strains. We mapped quantitative trait loci (QTLs) associated with variation in expression of thousands of transcripts. By comparing the physical transcript position with the location of the controlling QTL, we identified polymorphic cis-acting stem cell genes. We also identified multiple trans-acting control loci that modify expression of large numbers of genes. These groups of coregulated transcripts identify pathways that specify variation in stem cells. We illustrate this concept with the identification of candidate genes involved with HSC turnover. We compared expression QTLs in HSCs and brain from the same mice and identified both shared and tissue-specific QTLs. Our data are accessible through WebQTL, a web-based interface that allows custom genetic linkage analysis and identification of coregulated transcripts.

Standard name | LEE_LIVER_CANCER_MYC_TGFA_DN
Systematic name | M17372
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma (HCC) tissue of MYC and TGFA [GeneID=4609;7039] double transgenic mice.
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | IIZUKA_LIVER_CANCER_PROGRESSION_G1_G2_DN
Systematic name | M16374
Organism | Homo sapiens
PMID | 15710396
Authors | Iizuka N,Oka M,Yamada-Okabe H,Mori N,Tamesa T,Okada T,Takemoto N,Sakamoto K,Hamada K,Ishitsuka H,Miyamoto T,Uchimura S,Hamamoto Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during transition from G1 (well differentiated tumor, infected with HCV) to G2 (moderately differentiated tumor, infected with HCV) in the development of hepatocellular carcinoma.
Full description | Using high-density oligonucleotide array, we comprehensively analyzed expression levels of 12600 genes in 50 hepatocellular carcinoma (HCC) samples with positive hepatitis C virus (HCV) serology (well (G1), moderately (G2), and poorly (G3) differentiated tumors) and 11 non-tumorous livers (L1 and L0) with and without HCV infection. We searched for discriminatory genes of transition (L0 vs. L1, L1 vs. G1, G1 vs. G2, G2 vs. G3) with a supervised learning method, and then arranged the samples by self-organizing map (SOM) with the discriminatory gene sets. The SOM arranged the five clusters on a unique sigmoidal curve in the order L0, L1, G1, G2, and G3. The sample arrangement reproduced development-related features of HCC such as p53 abnormality. Strikingly, G2 tumors without venous invasion were located closer to the G1 cluster, and most G2 tumors with venous invasion were located closer to the G3 cluster (P=0.001 by Fisher's exact test). Our present profiling data will serve as a framework to understand the relation between the development and dedifferentiation of HCC.

Standard name | GOLDRATH_HOMEOSTATIC_PROLIFERATION
Systematic name | M3592
Organism | Mus musculus
PMID | 15548615
Authors | Goldrath AW,Luckey CJ,Park R,Benoist C,Mathis D
Category | C2
Sub-category | CGP
Brief description | Up-regulated in CD8+ [GeneID=925] T lymphocytes undergoing homeostatic proliferation (HP) versus the naive cells; these genes are not up-regulated versus effector or memory cell population.
Full description | Naive T cells proliferate independently of cognate antigen when introduced into lymphopenic hosts. Lymphopenia-induced proliferation depends on low-affinity MHC/self-peptide complexes and on IL-7. To elucidate the intracellular signals mediating this proliferation, we analyzed changes in gene expression in naive CD8+ T cells at different times after their transfer into a lymphopenic environment. The genes induced in response to lymphopenia were largely an attenuated subset of those turned up by full antigenic stimulation, including genes related to cell cycling, whereas excluding genes specifically associated with effector activity. After the initial phase of proliferation in an empty compartment, the naive T cells adopted a stable pattern of gene expression similar to that of antigen-experienced memory cells. Thus, T cells proliferating in lymphopenic hosts do not exhibit a unique gene-expression profile, instead relying on traditional signals for this antigen-independent proliferation; this process ultimately results in differentiation to authentic memory cells.

Standard name | LAMB_CCND1_TARGETS
Systematic name | M2935
Organism | Homo sapiens
PMID | 12914697
Authors | Lamb J,Ramaswamy S,Ford HL,Contreras B,Martinez RV,Kittrell FS,Zahnow CA,Patterson N,Golub TR,Ewen ME
Category | C2
Sub-category | CGP
Brief description | The cyclin D1 signature: genes whose expression correlated with the levels of CCND1 [GeneID=595].
Full description | Here we describe how patterns of gene expression in human tumors have been deconvoluted to reveal a mechanism of action for the cyclin D1 oncogene. Computational analysis of the expression patterns of thousands of genes across hundreds of tumor specimens suggested that a transcription factor, C/EBPbeta/Nf-Il6, participates in the consequences of cyclin D1 overexpression. Functional analyses confirmed the involvement of C/EBPbeta in the regulation of genes affected by cyclin D1 and established this protein as an indispensable effector of a potentially important facet of cyclin D1 biology. This work demonstrates that tumor gene expression databases can be used to study the function of a human oncogene in situ.

Standard name | GNATENKO_PLATELET_SIGNATURE
Systematic name | M15669
Organism | Homo sapiens
PMID | 12433680
Authors | Gnatenko DV,Dunn JJ,McCorkle SR,Weissmann D,Perrotta PL,Bahou WF
Category | C2
Sub-category | CGP
Brief description | Top 50 most up-regulated genes in human platelet cells.
Full description | Human platelets are anucleate blood cells that retain cytoplasmic mRNA and maintain functionally intact protein translational capabilities. We have adapted complementary techniques of microarray and serial analysis of gene expression (SAGE) for genetic profiling of highly purified human blood platelets. Microarray analysis using the Affymetrix HG-U95Av2 approximately 12 600-probe set maximally identified the expression of 2147 (range, 13%-17%) platelet-expressed transcripts, with approximately 22% collectively involved in metabolism and receptor/signaling, and an overrepresentation of genes with unassigned function (32%). In contrast, a modified SAGE protocol using the Type IIS restriction enzyme MmeI (generating 21-base pair [bp] or 22-bp tags) demonstrated that 89% of tags represented mitochondrial (mt) transcripts (enriched in 16S and 12S ribosomal RNAs), presumably related to persistent mt-transcription in the absence of nuclear-derived transcripts. The frequency of non-mt SAGE tags paralleled average difference values (relative expression) for the most abundant transcripts as determined by microarray analysis, establishing the concordance of both techniques for platelet profiling. Quantitative reverse transcription-polymerase chain reaction (PCR) confirmed the highest frequency of mt-derived transcripts, along with the mRNAs for neurogranin (NGN, a protein kinase C substrate) and the complement lysis inhibitor clusterin among the top 5 most abundant transcripts. For confirmatory characterization, immunoblots and flow cytometric analyses were performed, establishing abundant cell-surface expression of clusterin and intracellular expression of NGN. These observations demonstrate a strong correlation between high transcript abundance and protein expression, and they establish the validity of transcript analysis as a tool for identifying novel platelet proteins that may regulate normal and pathologic platelet (and/or megakaryocyte) functions.

Standard name | KIM_GERMINAL_CENTER_T_HELPER_UP
Systematic name | M1405
Organism | Homo sapiens
PMID | 15213097
Authors | Kim CH,Lim HW,Kim JR,Rott L,Hillsamer P,Butcher EC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in germinal center T helper cells compared to other CD4+ [GeneID=920] T lymphocyte types.
Full description | Gene expression profiling was used to compare the gene expression patterns of human germinal center (GC) T helper (Th) cells with other CD4+ T-cell subsets (naive, central, and effector memory T cells). GC-Th cells, specifically localized in germinal centers to help B cells, are distantly related to central and effector memory T cells in global gene expression profiles. GC-Th cells displayed substantial differences in mRNA for adhesion molecules, chemoattractant receptors, and cytokines compared with other populations. Distinct expression of transcriptional factors by GC-Th cells is consistent with the hypothesis that they may be different from other T cells in cell lineage. Interestingly, CXCL13, a critical chemokine for B-cell entry to lymphoid follicles, is one of the most highly up-regulated genes in GC-Th cells. GC-Th cells (but not other T cells) produce and secrete large amounts of functional CXCL13 upon T-cell receptor activation, a process that is dependent on costimulation, requires translation and transcription, and is dramatically enhanced by activation in the presence of GC-B cells. This study revealed for the first time the unique gene expression program of GC-Th cells.

Standard name | SHEPARD_BMYB_MORPHOLINO_DN
Systematic name | M11840
Organism | Danio rerio
PMID | 16150706
Authors | Shepard JL,Amatruda JF,Stern HM,Subramanian A,Finkelstein D,Ziai J,Finley KR,Pfaff KL,Hersey C,Zhou Y,Barut B,Freedman M,Lee C,Spitsbergen J,Neuberg D,Weber G,Golub TR,Glickman JN,Kutok JL,Aster JC,Zon LI
Category | C2
Sub-category | CGP
Brief description | Human orthologs of genes down-regulated in zebra fish after knockdown of BMYB [GeneID=4605] by morpholino.
Full description | A major goal of cancer research has been to identify genes that contribute to cancer formation. The similar pathology between zebrafish and human tumors, as well as the past success of large-scale genetic screens in uncovering human disease genes, makes zebrafish an ideal system in which to find such new genes. Here, we show that a zebrafish forward genetic screen uncovered multiple cell proliferation mutants including one mutant, crash&burn (crb), that represents a loss-of-function mutation in bmyb, a transcriptional regulator and member of a putative proto-oncogene family. crb mutant embryos have defects in mitotic progression and spindle formation, and exhibit genome instability. Regulation of cyclin B levels by bmyb appears to be the mechanism of mitotic accumulation in crb. Carcinogenesis studies reveal increased cancer susceptibility in adult crb heterozygotes. Gene-expression signatures associated with loss of bmyb in zebrafish are also correlated with conserved signatures in human tumor samples, and down-regulation of the B-myb signature genes is associated with retention of p53 function. Our findings show that zebrafish screens can uncover cancer pathways, and demonstrate that loss of function of bmyb is associated with cancer.

Standard name | BYSTRYKH_HEMATOPOIESIS_STEM_CELL_AND_BRAIN_QTL_CIS
Systematic name | M13133
Organism | Mus musculus
PMID | 15711547
Authors | Bystrykh L,Weersing E,Dontje B,Sutton S,Pletcher MT,Wiltshire T,Su AI,Vellenga E,Wang J,Manly KF,Lu L,Chesler EJ,Alberts R,Jansen RC,Williams RW,Cooke MP,de Haan G
Category | C2
Sub-category | CGP
Brief description | Genes associated with the same cis-regulatory QTL (quantitative trait loci) in both brain and hematopoietic stem cells (HSC).
Full description | We combined large-scale mRNA expression analysis and gene mapping to identify genes and loci that control hematopoietic stem cell (HSC) function. We measured mRNA expression levels in purified HSCs isolated from a panel of densely genotyped recombinant inbred mouse strains. We mapped quantitative trait loci (QTLs) associated with variation in expression of thousands of transcripts. By comparing the physical transcript position with the location of the controlling QTL, we identified polymorphic cis-acting stem cell genes. We also identified multiple trans-acting control loci that modify expression of large numbers of genes. These groups of coregulated transcripts identify pathways that specify variation in stem cells. We illustrate this concept with the identification of candidate genes involved with HSC turnover. We compared expression QTLs in HSCs and brain from the same mice and identified both shared and tissue-specific QTLs. Our data are accessible through WebQTL, a web-based interface that allows custom genetic linkage analysis and identification of coregulated transcripts.

Standard name | LEE_LIVER_CANCER_ACOX1_DN
Systematic name | M14811
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma of ACOX1 [GeneID=51] knockout mice.
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | SMITH_TERT_TARGETS_UP
Systematic name | M17742
Organism | Homo sapiens
PMID | 12717449
Authors | Smith LL,Coller HA,Roberts JM
Category | C2
Sub-category | CGP
Brief description | Genes consistently up-regulated in HMEC cells (primary mammary epithelium) upon expression of TERT [GeneID=7015] off a retroviral vector.
Full description | Most somatic cells do not express sufficient amounts of telomerase to maintain a constant telomere length during cycles of chromosome replication. Consequently, there is a limit to the number of doublings somatic cells can undergo before telomere shortening triggers an irreversible state of cellular senescence. Ectopic expression of telomerase overcomes this limitation, and in conjunction with specific oncogenes can transform cells to a tumorigenic phenotype. However, recent studies have questioned whether the stabilization of chromosome ends entirely explains the ability of telomerase to promote tumorigenesis and have resulted in the hypothesis that telomerase has a second function that also supports cell division. Here we show that ectopic expression of telomerase in human mammary epithelial cells (HMECs) results in a diminished requirement for exogenous mitogens and that this correlates with telomerase-dependent induction of genes that promote cell growth. Furthermore, we show that inhibiting expression of one of these genes, the epidermal growth factor receptor (EGFR), reverses the enhanced proliferation caused by telomerase. We conclude that telomerase may affect proliferation of epithelial cells not only by stabilizing telomeres, but also by affecting the expression of growth-promoting genes.

Standard name | LEE_LIVER_CANCER_MYC_UP
Systematic name | M2742
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) induced by overexpression of MYC [GeneID=4609].
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | IIZUKA_LIVER_CANCER_PROGRESSION_L0_L1_DN
Systematic name | M16962
Organism | Homo sapiens
PMID | 15710396
Authors | Iizuka N,Oka M,Yamada-Okabe H,Mori N,Tamesa T,Okada T,Takemoto N,Sakamoto K,Hamada K,Ishitsuka H,Miyamoto T,Uchimura S,Hamamoto Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during transition from L0 (non-tumor, not infected with HCV) to L1 (non-tumor, infected with HCV) in the development of hepatocellular carcinoma.
Full description | Using high-density oligonucleotide array, we comprehensively analyzed expression levels of 12600 genes in 50 hepatocellular carcinoma (HCC) samples with positive hepatitis C virus (HCV) serology (well (G1), moderately (G2), and poorly (G3) differentiated tumors) and 11 non-tumorous livers (L1 and L0) with and without HCV infection. We searched for discriminatory genes of transition (L0 vs. L1, L1 vs. G1, G1 vs. G2, G2 vs. G3) with a supervised learning method, and then arranged the samples by self-organizing map (SOM) with the discriminatory gene sets. The SOM arranged the five clusters on a unique sigmoidal curve in the order L0, L1, G1, G2, and G3. The sample arrangement reproduced development-related features of HCC such as p53 abnormality. Strikingly, G2 tumors without venous invasion were located closer to the G1 cluster, and most G2 tumors with venous invasion were located closer to the G3 cluster (P=0.001 by Fisher's exact test). Our present profiling data will serve as a framework to understand the relation between the development and dedifferentiation of HCC.

Standard name | JECHLINGER_EPITHELIAL_TO_MESENCHYMAL_TRANSITION_UP
Systematic name | M1406
Organism | Mus musculus
PMID | 14562044
Authors | Jechlinger M,Grunert S,Tamir IH,Janda E,Lüdemann S,Waerner T,Seither P,Weith A,Beug H,Kraut N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during epithelial to mesenchymal transition (EMT) induced by TGFB1 [GeneID=7040] in the EpH4 cells (mammary epithelium cell line transformed by HRAS [GeneID=3265]).
Full description | Epithelial-to-mesenchymal transition (EMT), a switch of polarized epithelial cells to a migratory, fibroblastoid phenotype, is increasingly considered as an important event during malignant tumor progression and metastasis. To identify molecular players involved in EMT and metastasis, we performed expression profiling of a set of combined in vitro/in vivo cellular models, based on clonal, fully polarized mammary epithelial cells. Seven closely related cell pairs were used, which were modified by defined oncogenes and/or external factors and showed specific aspects of epithelial plasticity relevant to cell migration, local invasion and metastasis. Since mRNA levels do not necessarily reflect protein levels in cells, we used an improved expression profiling method based on polysome-bound RNA, suitable to analyse global gene expression on Affymetrix chips. A substantial fraction of all regulated genes was found to be exclusively controlled at the translational level. Furthermore, profiling of the above multiple cell pairs allowed one to identify small numbers of genes by cluster analysis, specifically correlating gene expression with EMT, metastasis, scattering and/or oncogene function. A small set of genes specifically regulated during EMT was identified, including key regulators and signaling pathways involved in cell proliferation, epithelial polarity, survival and trans-differentiation to mesenchymal-like cells with invasive behavior.

Standard name | DER_IFN_ALPHA_RESPONSE_UP
Systematic name | M3652
Organism | Homo sapiens
PMID | 9861020
Authors | Der SD,Zhou A,Williams BR,Silverman RH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HT1080 cells (fibrosarcoma) by treatment with interferon alpha for 6 h.
Full description | The pleiotropic activities of interferons (IFNs) are mediated primarily through the transcriptional regulation of many downstream effector genes. The mRNA profiles from IFN-alpha, -beta, or -gamma treatments of the human fibrosarcoma cell line, HT1080, were determined by using oligonucleotide arrays with probe sets corresponding to more than 6,800 human genes. Among these were transcripts for known IFN-stimulated genes (ISGs), the expression of which were consistent with previous studies in which the particular ISG was characterized as responsive to either Type I (alpha, beta) or Type II (gamma) IFNs, or both. Importantly, many novel IFN-stimulated genes were identified that were diverse in their known biological functions. For instance, several novel ISGs were identified that are implicated in apoptosis (including RAP46/Bag-1, phospholipid scramblase, and hypoxia inducible factor-1alpha). Furthermore, several IFN-repressed genes also were identified. These results demonstrate the usefulness of oligonucleotide arrays in monitoring mammalian gene expression on a broad and unprecedented scale. In particular, these findings provide insights into the basic mechanisms of IFN actions and ultimately may contribute to better therapeutic uses for IFNs.

Standard name | KANNAN_TP53_TARGETS_UP
Systematic name | M16229
Organism | Homo sapiens
PMID | 11402317
Authors | Kannan K,Amariglio N,Rechavi G,Jakob-Hirsch J,Kela I,Kaminski N,Getz G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Primary up-regulated targets of TP53 [GeneID=7157] in the H1299 (lung cancer) cell line.
Full description | The transcriptional program regulated by the tumor suppressor p53 was analysed using oligonucleotide microarrays. A human lung cancer cell line that expresses the temperature sensitive murine p53 was utilized to quantitate mRNA levels of various genes at different time points after shifting the temperature to 32 degrees C. Inhibition of protein synthesis by cycloheximide (CHX) was used to distinguish between primary and secondary target genes regulated by p53. In the absence of CHX, 259 and 125 genes were up or down-regulated respectively; only 38 and 24 of these genes were up and down-regulated by p53 also in the presence of CHX and are considered primary targets in this cell line. Cluster analysis of these data using the super paramagnetic clustering (SPC) algorithm demonstrate that the primary genes can be distinguished as a single cluster among a large pool of p53 regulated genes. This procedure identified additional genes that co-cluster with the primary targets and can also be classified as such genes. In addition to cell cycle (e.g. p21, TGF-beta, Cyclin E) and apoptosis (e.g. Fas, Bak, IAP) related genes, the primary targets of p53 include genes involved in many aspects of cell function, including cell adhesion (e.g. Thymosin, Smoothelin), signaling (e.g. H-Ras, Diacylglycerol kinase), transcription (e.g. ATF3, LISCH7), neuronal growth (e.g. Ninjurin, NSCL2) and DNA repair (e.g. BTG2, DDB2). The results suggest that p53 activates concerted opposing signals and exerts its effect through a diverse network of transcriptional changes that collectively alter the cell phenotype in response to stress.

Standard name | WELCH_GATA1_TARGETS
Systematic name | M1407
Organism | Mus musculus
PMID | 15297311
Authors | Welch JJ,Watts JA,Vakoc CR,Yao Y,Wang H,Hardison RC,Blobel GA,Chodosh LA,Weiss MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated after GATA1 [GeneID=2623] activation in G1E-ER4 cells (erythroid precursors engineered to express GATA1 upon addition of estradiol [PubChem=5757]).
Full description | Transcription factor GATA-1 is required for erythropoiesis, yet its full actions are unknown. We performed transcriptome analysis of G1E-ER4 cells, a GATA-1-null erythroblast line that undergoes synchronous erythroid maturation when GATA-1 activity is restored. We interrogated more than 9000 transcripts at 6 time points representing the transition from late burst forming unit-erythroid (BFU-E) to basophilic erythroblast stages. Our findings illuminate several new aspects of GATA-1 function. First, the large number of genes responding quickly to restoration of GATA-1 extends the repertoire of its potential targets. Second, many transcripts were rapidly down-regulated, highlighting the importance of GATA-1 in gene repression. Third, up-regulation of some known GATA-1 targets was delayed, suggesting that auxiliary factors are required. For example, induction of the direct GATA-1 target gene beta major globin was late and, surprisingly, required new protein synthesis. In contrast, the gene encoding Fog1, which cooperates with GATA-1 in beta globin transcription, was rapidly induced independently of protein synthesis. Guided by bioinformatic analysis, we demonstrated that selected regions of the Fog1 gene exhibit enhancer activity and in vivo occupancy by GATA-1. These findings define a regulatory loop for beta globin expression and, more generally, demonstrate how transcriptome analysis can be used to generate testable hypotheses regarding transcriptional networks.

Standard name | FRASOR_RESPONSE_TO_ESTRADIOL_UP
Systematic name | M17641
Organism | Homo sapiens
PMID | 14973112
Authors | Frasor J,Stossi F,Danes JM,Komm B,Lyttle CR,Katzenellenbogen BS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) by estradiol (E2) [PubChem=5757].
Full description | Selective estrogen receptor modulators (SERMs) such as tamoxifen are effective in the treatment of many estrogen receptor-positive breast cancers and have also proven to be effective in the prevention of breast cancer in women at high risk for the disease. The comparative abilities of tamoxifen versus raloxifene in breast cancer prevention are currently being compared in the Study of Tamoxifen and Raloxifene trial. To better understand the actions of these compounds in breast cancer, we have examined their effects on the expression of approximately 12,000 genes, using Affymetrix GeneChip microarrays, with quantitative PCR verification in many cases, categorizing their actions as agonist, antagonist, or partial agonist/antagonist. Analysis of gene stimulation and inhibition by the SERMs trans-hydroxytamoxifen (TOT) and raloxifene (Ral) or ICI 182,780 (ICI) and by estradiol (E2) in estrogen receptor-containing MCF-7 human breast cancer cells revealed that (a) TOT was the most E2-like of the three compounds, (b) all three compounds either partially or fully antagonized the action of E2 on most genes, with the order of antagonist activity being ICI > Ral > TOT, (c) TOT and Ral, but not ICI, displayed partial agonist/partial antagonist activity on a number of E2-regulated genes, (d) several stimulatory cell cycle-related genes were down-regulated exclusively by ICI, (e) the estrogen-like activity of Ral nearly always overlapped with that of TOT, indicating that Ral has little unique agonist activity different from that of TOT, and (f) some genes were specifically up-regulated by TOT but not Ral, ICI, or E2. Hence, gene expression profiling can discern fundamental differences among SERMs and provides insight into the distinct biologies of TOT, Ral, and ICI in breast cancer.

Standard name | LEE_LIVER_CANCER_MYC_TGFA_UP
Systematic name | M3432
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) tissue of MYC and TGFA [GeneID=4609;7039] double transgenic mice.
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | FLECHNER_PBL_KIDNEY_TRANSPLANT_OK_VS_DONOR_DN
Systematic name | M9905
Organism | Homo sapiens
PMID | 15307835
Authors | Flechner SM,Kurian SM,Head SR,Sharp SM,Whisenant TC,Zhang J,Chismar JD,Horvath S,Mondala T,Gilmartin T,Cook DJ,Kay SA,Walker JR,Salomon DR
Category | C2
Sub-category | CGP
Brief description | Genes downregulated in peripheral blood lymphocytes (PBL) from patients with well functioning kidneys more than 1-year post transplant compared to those from normal living kidney donors.
Full description | A major challenge for kidney transplantation is balancing the need for immunosuppression to prevent rejection, while minimizing drug-induced toxicities. We used DNA microarrays (HG-U95Av2 GeneChips, Affymetrix) to determine gene expression profiles for kidney biopsies and peripheral blood lymphocytes (PBLs) in transplant patients including normal donor kidneys, well-functioning transplants without rejection, kidneys undergoing acute rejection, and transplants with renal dysfunction without rejection. We developed a data analysis schema based on expression signal determination, class comparison and prediction, hierarchical clustering, statistical power analysis and real-time quantitative PCR validation. We identified distinct gene expression signatures for both biopsies and PBLs that correlated significantly with each of the different classes of transplant patients. This is the most complete report to date using commercial arrays to identify unique expression signatures in transplant biopsies distinguishing acute rejection, acute dysfunction without rejection and well-functioning transplants with no rejection history. We demonstrate for the first time the successful application of high density DNA chip analysis of PBL as a diagnostic tool for transplantation. The significance of these results, if validated in a multicenter prospective trial, would be the establishment of a metric based on gene expression signatures for monitoring the immune status and immunosuppression of transplanted patients.

Standard name | DORSAM_HOXA9_TARGETS_UP
Systematic name | M10445
Organism | Homo sapiens
PMID | 14604967
Authors | Dorsam ST,Ferrell CM,Dorsam GP,Derynck MK,Vijapurkar U,Khodabakhsh D,Pau B,Bernstein H,Haqq CM,Largman C,Lawrence HJ
Category | C2
Sub-category | CGP
Brief description | HOXA9 [GeneID=3205] targets up-regulated in hematopoietic stem cells.
Full description | Hematopoietic defects in HOXA9(-/-) mice demonstrate a key role for this homeoprotein in blood cell development. Conversely, enforced HOXA9 expression is leukemogenic in mice, and HOXA9 is frequently activated in human acute myeloid leukemia (AML). Although HOXA9 is thought to function as a transcription factor, few downstream targets have been identified. We searched for early HOXA9 target genes by using a transient overexpression strategy in 3 hematopoietic cell lines (2 myeloid, 1 lymphoid). cDNA microarray analyses identified 220 genes whose expression was modulated at least 2-fold. Expression signatures in myeloid and lymphoid cells demonstrated that HOXA9 functions as both an activator and repressor of a variety of genes in cell-specific patterns suggesting that the transcriptional effects of HOXA9 are largely dependent on the cell context. Transient transcription assays and target gene expression patterns in HOXA9(-/-) marrow cells imply that we have identified direct physiologic targets. Many target genes are expressed in CD34+ stem cells or are members of gene families involved in proliferation or myeloid differentiation. Expression of 14 HOXA9 target genes correlated with high-level HOXA9 expression in primary AML. These data suggest that many genes identified in this survey may mediate the biologic effects of HOXA9 in normal and leukemic hematopoiesis.

Standard name | DER_IFN_BETA_RESPONSE_DN
Systematic name | M17607
Organism | Homo sapiens
PMID | 9861020
Authors | Der SD,Zhou A,Williams BR,Silverman RH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HT1080 (fibrosarcoma) cells by treatment with interferon beta for 6 h.
Full description | The pleiotropic activities of interferons (IFNs) are mediated primarily through the transcriptional regulation of many downstream effector genes. The mRNA profiles from IFN-alpha, -beta, or -gamma treatments of the human fibrosarcoma cell line, HT1080, were determined by using oligonucleotide arrays with probe sets corresponding to more than 6,800 human genes. Among these were transcripts for known IFN-stimulated genes (ISGs), the expression of which were consistent with previous studies in which the particular ISG was characterized as responsive to either Type I (alpha, beta) or Type II (gamma) IFNs, or both. Importantly, many novel IFN-stimulated genes were identified that were diverse in their known biological functions. For instance, several novel ISGs were identified that are implicated in apoptosis (including RAP46/Bag-1, phospholipid scramblase, and hypoxia inducible factor-1alpha). Furthermore, several IFN-repressed genes also were identified. These results demonstrate the usefulness of oligonucleotide arrays in monitoring mammalian gene expression on a broad and unprecedented scale. In particular, these findings provide insights into the basic mechanisms of IFN actions and ultimately may contribute to better therapeutic uses for IFNs.

Standard name | IIZUKA_LIVER_CANCER_PROGRESSION_G2_G3_UP
Systematic name | M9096
Organism | Homo sapiens
PMID | 15710396
Authors | Iizuka N,Oka M,Yamada-Okabe H,Mori N,Tamesa T,Okada T,Takemoto N,Sakamoto K,Hamada K,Ishitsuka H,Miyamoto T,Uchimura S,Hamamoto Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during transition from G2 (moderately differentiated tumor, infected with HCV) to G3 (poorly differentiated tumor, infected with HCV) in the development of hepatocellular carcinoma.
Full description | Using high-density oligonucleotide array, we comprehensively analyzed expression levels of 12600 genes in 50 hepatocellular carcinoma (HCC) samples with positive hepatitis C virus (HCV) serology (well (G1), moderately (G2), and poorly (G3) differentiated tumors) and 11 non-tumorous livers (L1 and L0) with and without HCV infection. We searched for discriminatory genes of transition (L0 vs. L1, L1 vs. G1, G1 vs. G2, G2 vs. G3) with a supervised learning method, and then arranged the samples by self-organizing map (SOM) with the discriminatory gene sets. The SOM arranged the five clusters on a unique sigmoidal curve in the order L0, L1, G1, G2, and G3. The sample arrangement reproduced development-related features of HCC such as p53 abnormality. Strikingly, G2 tumors without venous invasion were located closer to the G1 cluster, and most G2 tumors with venous invasion were located closer to the G3 cluster (P=0.001 by Fisher's exact test). Our present profiling data will serve as a framework to understand the relation between the development and dedifferentiation of HCC.

Standard name | KLEIN_PRIMARY_EFFUSION_LYMPHOMA_DN
Systematic name | M18825
Organism | Homo sapiens
PMID | 12531789
Authors | Klein U,Gloghini A,Gaidano G,Chadburn A,Cesarman E,Dalla-Favera R,Carbone A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in AIDS-related primary effusion lymphoma (PEL) samples compared to other tumor subtypes and normal B lymphocytes.
Full description | AIDS-related primary effusion lymphoma (PEL) is an HIV-associated malignancy characterized by the ability of the tumor cells to specifically home in the serous body cavities. Here we used gene expression profile analysis (about 12 000 genes) to further define the phenotype of PEL and to investigate the lymphoma relationship to normal B cells and to other tumor subtypes, including non-Hodgkin lymphomas (NHLs) of immunocompetent hosts and AIDS-associated NHL (AIDS-NHL). The results showed that PEL displayed a common gene expression profile that is clearly distinct from all NHLs of immunocompetent hosts and AIDS-NHL subtypes and, in contrast to those, is not related to germinal center (GC) or memory B cells. The gene expression profile of PEL was defined as plasmablastic because it showed features of both immunoblasts identified by Epstein-Barr virus (EBV)-transformed lymphoblastoid cell lines and AIDS immunoblastic lymphoma, and plasma cells, as defined by multiple myeloma cell lines. Finally, our results identify a set of genes specifically expressed in PEL tumor cells. Their expression was validated at the protein level, suggesting their potential pathogenetic and clinical significance.

Standard name | SHEPARD_BMYB_TARGETS
Systematic name | M15973
Organism | Danio rerio
PMID | 16150706
Authors | Shepard JL,Amatruda JF,Stern HM,Subramanian A,Finkelstein D,Ziai J,Finley KR,Pfaff KL,Hersey C,Zhou Y,Barut B,Freedman M,Lee C,Spitsbergen J,Neuberg D,Weber G,Golub TR,Glickman JN,Kutok JL,Aster JC,Zon LI
Category | C2
Sub-category | CGP
Brief description | Human orthologs of BMYB [GeneID=4605] target genes in zebra fish, identified as commonly changed in the BMYB loss of function mutant crb ('crush and burn') and after knockdown of BMYB by morpholino.
Full description | A major goal of cancer research has been to identify genes that contribute to cancer formation. The similar pathology between zebrafish and human tumors, as well as the past success of large-scale genetic screens in uncovering human disease genes, makes zebrafish an ideal system in which to find such new genes. Here, we show that a zebrafish forward genetic screen uncovered multiple cell proliferation mutants including one mutant, crash&burn (crb), that represents a loss-of-function mutation in bmyb, a transcriptional regulator and member of a putative proto-oncogene family. crb mutant embryos have defects in mitotic progression and spindle formation, and exhibit genome instability. Regulation of cyclin B levels by bmyb appears to be the mechanism of mitotic accumulation in crb. Carcinogenesis studies reveal increased cancer susceptibility in adult crb heterozygotes. Gene-expression signatures associated with loss of bmyb in zebrafish are also correlated with conserved signatures in human tumor samples, and down-regulation of the B-myb signature genes is associated with retention of p53 function. Our findings show that zebrafish screens can uncover cancer pathways, and demonstrate that loss of function of bmyb is associated with cancer.

Standard name | KANNAN_TP53_TARGETS_DN
Systematic name | M11403
Organism | Homo sapiens
PMID | 11402317
Authors | Kannan K,Amariglio N,Rechavi G,Jakob-Hirsch J,Kela I,Kaminski N,Getz G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Primary down-regulated targets of TP53 [GeneID=7157] in the H1299 (lung cancer) cell line.
Full description | The transcriptional program regulated by the tumor suppressor p53 was analysed using oligonucleotide microarrays. A human lung cancer cell line that expresses the temperature sensitive murine p53 was utilized to quantitate mRNA levels of various genes at different time points after shifting the temperature to 32 degrees C. Inhibition of protein synthesis by cycloheximide (CHX) was used to distinguish between primary and secondary target genes regulated by p53. In the absence of CHX, 259 and 125 genes were up or down-regulated respectively; only 38 and 24 of these genes were up and down-regulated by p53 also in the presence of CHX and are considered primary targets in this cell line. Cluster analysis of these data using the super paramagnetic clustering (SPC) algorithm demonstrate that the primary genes can be distinguished as a single cluster among a large pool of p53 regulated genes. This procedure identified additional genes that co-cluster with the primary targets and can also be classified as such genes. In addition to cell cycle (e.g. p21, TGF-beta, Cyclin E) and apoptosis (e.g. Fas, Bak, IAP) related genes, the primary targets of p53 include genes involved in many aspects of cell function, including cell adhesion (e.g. Thymosin, Smoothelin), signaling (e.g. H-Ras, Diacylglycerol kinase), transcription (e.g. ATF3, LISCH7), neuronal growth (e.g. Ninjurin, NSCL2) and DNA repair (e.g. BTG2, DDB2). The results suggest that p53 activates concerted opposing signals and exerts its effect through a diverse network of transcriptional changes that collectively alter the cell phenotype in response to stress.

Standard name | CHANG_POU5F1_TARGETS_UP
Systematic name | M9138
Organism | Homo sapiens
PMID | 18676852
Authors | Chang CC,Shieh GS,Wu P,Lin CC,Shiau AL,Wu CL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by POU5F1 [GeneID=5460] in bladder cancer cell lines.
Full description | Cancer and embryonic stem cells exhibit similar behavior, including immortal, undifferentiated, and invasive activities. Here, we show that in clinical samples bladder tumors with intense expression of stem cell marker Oct-3/4 (also known as POU5F1) are associated with further disease progression, greater metastasis, and shorter cancer-related survival compared with those with moderate and low expressions. Expression of Oct-3/4 is detected in human bladder transitional cell carcinoma samples and cell lines. Overexpression of Oct-3/4 enhances, whereas knockdown of Oct-3/4 expression by RNA interference reduces, migration and invasion of bladder cancer cells. Oct-3/4 can up-regulate fibroblast growth factor-4 and matrix metalloproteinase-2 (MMP-2), MMP-9, and MMP-13 production, which may contribute to tumor metastasis. Finally, we show that Ad5WS4, an E1B-55 kD-deleted adenovirus driven by the Oct-3/4 promoter, exerts potent antitumor activity against bladder cancer in a syngeneic murine tumor model. Therefore, our results implicate that Oct-3/4 may be useful as a novel tumor biological and prognostic marker and probably as a potential therapeutic target for bladder cancer.

Standard name | CHANG_POU5F1_TARGETS_DN
Systematic name | M19735
Organism | Homo sapiens
PMID | 18676852
Authors | Chang CC,Shieh GS,Wu P,Lin CC,Shiau AL,Wu CL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by POU5F1 [GeneID=5460] in bladder cancer cell lines.
Full description | Cancer and embryonic stem cells exhibit similar behavior, including immortal, undifferentiated, and invasive activities. Here, we show that in clinical samples bladder tumors with intense expression of stem cell marker Oct-3/4 (also known as POU5F1) are associated with further disease progression, greater metastasis, and shorter cancer-related survival compared with those with moderate and low expressions. Expression of Oct-3/4 is detected in human bladder transitional cell carcinoma samples and cell lines. Overexpression of Oct-3/4 enhances, whereas knockdown of Oct-3/4 expression by RNA interference reduces, migration and invasion of bladder cancer cells. Oct-3/4 can up-regulate fibroblast growth factor-4 and matrix metalloproteinase-2 (MMP-2), MMP-9, and MMP-13 production, which may contribute to tumor metastasis. Finally, we show that Ad5WS4, an E1B-55 kD-deleted adenovirus driven by the Oct-3/4 promoter, exerts potent antitumor activity against bladder cancer in a syngeneic murine tumor model. Therefore, our results implicate that Oct-3/4 may be useful as a novel tumor biological and prognostic marker and probably as a potential therapeutic target for bladder cancer.

Standard name | SANA_TNF_SIGNALING_DN
Systematic name | M19467
Organism | Homo sapiens
PMID | 15749026
Authors | Sana TR,Janatpour MJ,Sathe M,McEvoy LM,McClanahan TK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in five primary endothelial cell types (lung, aortic, iliac, dermal, and colon) by TNF [GeneID=7124].
Full description | To investigate the potential molecular mediators of tissue-specific recruitment, we explored the influence of different cytokine challenges on gene expression regulation in five primary endothelial cells (ECs), representing two different phenotypes: iliac artery and aortic (macrovascular); lung, colon and dermal (microvascular). We challenged ECs with cytokines that elicit different patterns of inflammatory and immune responses in immune cells: tumor necrosis factor (TNF-alpha), interferon-gamma (IFN-gamma) or interleukin-4 (IL-4), and used microarrays containing approximately 40,000 unique cDNAs, to assess changes in differential gene expression relative to untreated cells. Five hundred and sixty three sequences changed by at least 2.5 fold in one or more of the 15 possible EC /cytokine combinations. The list included highly regulated adhesion molecules, chemokines, cytokines, metalloproteases, and IFN-gamma-induced genes. Overall, IFN-gamma caused the largest number of gene expression changes and its profile was least correlated with IL-4. In addition to clusters that were predominantly EC/cytokine specific, we also observed several clusters that were regulated by more than one cytokine across several ECs. Furthermore, we identified genes that were reciprocally expressed in response to different cytokines that could serve as markers of inflammatory and immune expression. These results confirm the importance of microenvironment in primary ECs that could have important applications in developing targeted therapies for vascular diseases.

Standard name | TARTE_PLASMA_CELL_VS_PLASMABLAST_UP
Systematic name | M4872
Organism | Homo sapiens
PMID | 12663452
Authors | Tarte K,Zhan F,De Vos J,Klein B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mature plasma cells compared with plasmablastic B lymphocytes.
Full description | Plasma cells (PCs), the end point of B-cell differentiation, are a heterogeneous cell compartment comprising several cell subsets from short-lived highly proliferative plasmablasts to long-lived nondividing fully mature PCs. Whereas the major transcription factors driving the differentiation of B cells to PCs were recently identified, the subtle genetic changes that underlie the transition from plasmablasts to mature PCs are poorly understood. We recently described an in vitro model making it possible to obtain a large number of cells with the morphologic, phenotypic, and functional characteristics of normal polyclonal plasmablastic cells (PPCs). Using Affymetrix microarrays we compared the gene expression profiles of these PPCs with those of mature PCs isolated from tonsils (TPCs) and bone marrow (BMPCs), and with those of B cells purified from peripheral blood (PBB cells) and tonsils (TBCs). Unsupervised principal component analysis clearly distinguished the 5 cell populations on the basis of their differentiation and proliferation status. Detailed statistical analysis allowed the identification of 85 PC genes and 40 B-cell genes, overexpressed, respectively, in the 3 PC subsets or in the 2 B-cell subsets. In addition, several signaling molecules and antiapoptotic proteins were found to be induced in BMPCs compared with PPCs and could be involved in the accumulation and prolonged survival of BMPCs in close contact with specialized stromal microenvironment. These data should help to better understand the molecular events that regulate commitment to a PC fate, mediate PC maintenance in survival niches, and could facilitate PC immortalization in plasma cell dyscrasias.

Standard name | WILLERT_WNT_SIGNALING
Systematic name | M1805
Organism | Homo sapiens
PMID | 12095419
Authors | Willert J,Epping M,Pollack JR,Brown PO,Nusse R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NCCIT cell line (embryonic teratocarcinoma) after stimulation with WNT3A [GeneID=89780].
Full description | BACKGROUND: Wnt signaling is implicated in many developmental decisions, including stem cell control, as well as in cancer. There are relatively few target genes known of the Wnt pathway. RESULTS: We have identified target genes of Wnt signaling using microarray technology and human embryonic carcinoma cells stimulated with active Wnt protein. The ~50 genes upregulated early after Wnt addition include the previously known Wnt targets Cyclin D1, MYC, ID2 and betaTRCP. The newly identified targets, which include MSX1, MSX2, Nucleophosmin, Follistatin, TLE/Groucho, Ubc4/5E2, CBP/P300, Frizzled and REST/NRSF, have important implications for understanding the roles of Wnts in development and cancer. The protein synthesis inhibitor cycloheximide blocks induction by Wnt, consistent with a requirement for newly synthesized beta-catenin protein prior to target gene activation. The promoters of nearly all the target genes we identified have putative TCF binding sites, and we show that the TCF binding site is required for induction of Follistatin. Several of the target genes have a cooperative response to a combination of Wnt and BMP. CONCLUSIONS: Wnt signaling activates genes that promote stem cell fate and inhibit cellular differentiation and regulates a remarkable number of genes involved in its own signaling system.

Standard name | BYSTRYKH_HEMATOPOIESIS_STEM_CELL_RUNX1
Systematic name | M12486
Organism | Mus musculus
PMID | 15711547
Authors | Bystrykh L,Weersing E,Dontje B,Sutton S,Pletcher MT,Wiltshire T,Su AI,Vellenga E,Wang J,Manly KF,Lu L,Chesler EJ,Alberts R,Jansen RC,Williams RW,Cooke MP,de Haan G
Category | C2
Sub-category | CGP
Brief description | Genes whose expression is coregulated with that of RUNX1 [GeneID=861] in hematopoietic stem cells (HSC).
Full description | We combined large-scale mRNA expression analysis and gene mapping to identify genes and loci that control hematopoietic stem cell (HSC) function. We measured mRNA expression levels in purified HSCs isolated from a panel of densely genotyped recombinant inbred mouse strains. We mapped quantitative trait loci (QTLs) associated with variation in expression of thousands of transcripts. By comparing the physical transcript position with the location of the controlling QTL, we identified polymorphic cis-acting stem cell genes. We also identified multiple trans-acting control loci that modify expression of large numbers of genes. These groups of coregulated transcripts identify pathways that specify variation in stem cells. We illustrate this concept with the identification of candidate genes involved with HSC turnover. We compared expression QTLs in HSCs and brain from the same mice and identified both shared and tissue-specific QTLs. Our data are accessible through WebQTL, a web-based interface that allows custom genetic linkage analysis and identification of coregulated transcripts.

Standard name | KENNY_CTNNB1_TARGETS_DN
Systematic name | M19134
Organism | Mus musculus
PMID | 15642117
Authors | Kenny PA,Enver T,Ashworth A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HC11 cells (mammary epithelium) by expression of constantly active CTNNB1 [GeneID=1499].
Full description | BACKGROUND: Deregulation of the Wnt/ beta-catenin signal transduction pathway has been implicated in the pathogenesis of tumours in the mammary gland, colon and other tissues. Mutations in components of this pathway result in beta-catenin stabilization and accumulation, and the aberrant modulation of beta-catenin/TCF target genes. Such alterations in the cellular transcriptional profile are believed to underlie the pathogenesis of these cancers. We have sought to identify novel target genes of this pathway in mouse mammary epithelial cells. METHODS: Gene expression microarray analysis of mouse mammary epithelial cells inducibly expressing a constitutively active mutant of beta-catenin was used to identify target genes of this pathway. RESULTS: The differential expression in response to DeltaNbeta-catenin for five putative target genes, Autotaxin, Extracellular Matrix Protein 1 (Ecm1), CD14, Hypoxia-inducible gene 2 (Hig2) and Receptor Activity Modifying Protein 3 (RAMP3), was independently validated by northern blotting. Each of these genes encodes either a receptor or a secreted protein, modulation of which may underlie the interactions between Wnt/beta-catenin tumour cells and between the tumour and its microenvironment. One of these genes, Hig2, previously shown to be induced by both hypoxia and glucose deprivation in human cervical carcinoma cells, was strongly repressed upon DeltaNbeta-catenin induction. The predicted N-terminus of Hig2 contains a putative signal peptide suggesting it might be secreted. Consistent with this, a Hig2-EGFP fusion protein was able to enter the secretory pathway and was detected in conditioned medium. Mutation of critical residues in the putative signal sequence abolished its secretion. The expression of human HIG2 was examined in a panel of human tumours and was found to be significantly downregulated in kidney tumours compared to normal adjacent tissue. CONCLUSIONS: HIG2 represents a novel non-cell autonomous target of the Wnt pathway which is potentially involved in human cancer.

Standard name | CHEOK_RESPONSE_TO_MERCAPTOPURINE_AND_LD_MTX_UP
Systematic name | M11031
Organism | Homo sapiens
PMID | 12704389
Authors | Cheok MH,Yang W,Pui CH,Downing JR,Cheng C,Naeve CW,Relling MV,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes specifically up-regulated in pediatric acute lymphoblastic leukemia (ALL) patients by mercaptopurine [PubChem=667490] and low-dose methotrexate (LDMTX) [PubChem=4112].
Full description | To elucidate the genomics of cellular responses to cancer treatment, we analyzed the expression of over 9,600 human genes in acute lymphoblastic leukemia cells before and after in vivo treatment with methotrexate and mercaptopurine given alone or in combination. Based on changes in gene expression, we identified 124 genes that accurately discriminated among the four treatments. Discriminating genes included those involved in apoptosis, mismatch repair, cell cycle control and stress response. Only 14% of genes that changed when these medications were given as single agents also changed when they were given together. These data indicate that lymphoid leukemia cells of different molecular subtypes share common pathways of genomic response to the same treatment, that changes in gene expression are treatment-specific and that gene expression can illuminate differences in cellular response to drug combinations versus single agents.

Standard name | CHESLER_BRAIN_QTL_TRANS
Systematic name | M7189
Organism | Mus musculus
PMID | 15711545
Authors | Chesler EJ,Lu L,Shou S,Qu Y,Gu J,Wang J,Hsu HC,Mountz JD,Baldwin NE,Langston MA,Threadgill DW,Manly KF,Williams RW
Category | C2
Sub-category | CGP
Brief description | Best trans-regulated quantitative trait loci (QTLs) in the mouse genome which modulate transcription in brain tissue.
Full description | Patterns of gene expression in the central nervous system are highly variable and heritable. This genetic variation among normal individuals leads to considerable structural, functional and behavioral differences. We devised a general approach to dissect genetic networks systematically across biological scale, from base pairs to behavior, using a reference population of recombinant inbred strains. We profiled gene expression using Affymetrix oligonucleotide arrays in the BXD recombinant inbred strains, for which we have extensive SNP and haplotype data. We integrated a complementary database comprising 25 years of legacy phenotypic data on these strains. Covariance among gene expression and pharmacological and behavioral traits is often highly significant, corroborates known functional relations and is often generated by common quantitative trait loci. We found that a small number of major-effect quantitative trait loci jointly modulated large sets of transcripts and classical neural phenotypes in patterns specific to each tissue. We developed new analytic and graph theoretical approaches to study shared genetic modulation of networks of traits using gene sets involved in neural synapse function as an example. We built these tools into an open web resource called WebQTL that can be used to test a broad array of hypotheses.

Standard name | IIZUKA_LIVER_CANCER_PROGRESSION_G1_G2_UP
Systematic name | M5071
Organism | Homo sapiens
PMID | 15710396
Authors | Iizuka N,Oka M,Yamada-Okabe H,Mori N,Tamesa T,Okada T,Takemoto N,Sakamoto K,Hamada K,Ishitsuka H,Miyamoto T,Uchimura S,Hamamoto Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during transition from G1 (well differentiated tumor, infected with HCV) to G2 (moderately differentiated tumor, infected with HCV) in the development of hepatocellular carcinoma.
Full description | Using high-density oligonucleotide array, we comprehensively analyzed expression levels of 12600 genes in 50 hepatocellular carcinoma (HCC) samples with positive hepatitis C virus (HCV) serology (well (G1), moderately (G2), and poorly (G3) differentiated tumors) and 11 non-tumorous livers (L1 and L0) with and without HCV infection. We searched for discriminatory genes of transition (L0 vs. L1, L1 vs. G1, G1 vs. G2, G2 vs. G3) with a supervised learning method, and then arranged the samples by self-organizing map (SOM) with the discriminatory gene sets. The SOM arranged the five clusters on a unique sigmoidal curve in the order L0, L1, G1, G2, and G3. The sample arrangement reproduced development-related features of HCC such as p53 abnormality. Strikingly, G2 tumors without venous invasion were located closer to the G1 cluster, and most G2 tumors with venous invasion were located closer to the G3 cluster (P=0.001 by Fisher's exact test). Our present profiling data will serve as a framework to understand the relation between the development and dedifferentiation of HCC.

Standard name | BECKER_TAMOXIFEN_RESISTANCE_UP
Systematic name | M10814
Organism | Homo sapiens
PMID | 15657362
Authors | Becker M,Sommer A,Krätzschmar JR,Seidel H,Pohlenz HD,Fichtner I
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in a breast cancer cell line resistant to tamoxifen [PubChem=5376] compared to the parental line sensitive to the drug.
Full description | The reasons why human mammary tumors become resistant to tamoxifen therapy are mainly unknown. Changes in gene expression may occur as cells acquire resistance to antiestrogens. We therefore undertook a comparative gene expression analysis of tamoxifen-sensitive and tamoxifen-resistant human breast cancer in vivo models using Affymetrix oligonucleotide arrays to analyze differential gene expression. Total RNAs from the tamoxifen-sensitive patient-derived mammary carcinoma xenograft MaCa 3366 and the tamoxifen-resistant model MaCa 3366/TAM were hybridized to Affymetrix HuGeneFL and to Hu95Av2 arrays. Pairwise comparisons and clustering algorithms were applied to identify differentially expressed genes and patterns of gene expression. As revealed by cluster analysis, the tamoxifen-sensitive and the tamoxifen-resistant breast carcinomas differed regarding their gene expression pattern. More than 100 transcripts are changed in abundance in MaCa 3366/TAM as compared with MaCa 3366. Among the genes that are differentially expressed in the tamoxifen-resistant tumors, there are several IFN-inducible and estrogen-responsive genes, and genes known to be involved in breast carcinogenesis. The genes neuronatin (NNAT) and bone marrow stem cell antigen 2 (BST2) were sharply up-regulated in MaCa 3366/TAM. The differential expression of four genes (NNAT, BST2, IGFBP5, and BCAS1) was confirmed by Taqman PCR. Our results provide the starting point for deriving markers for tamoxifen resistance by differential gene expression profiling in a human breast cancer model of acquired tamoxifen resistance. Finally, genes whose expression profiles are distinctly changed between the two xenograft lines will be further evaluated as potential targets for diagnostic or therapeutic approaches of tamoxifen-resistant breast cancer.

Standard name | SHEPARD_CRUSH_AND_BURN_MUTANT_DN
Systematic name | M2148
Organism | Danio rerio
PMID | 16150706
Authors | Shepard JL,Amatruda JF,Stern HM,Subramanian A,Finkelstein D,Ziai J,Finley KR,Pfaff KL,Hersey C,Zhou Y,Barut B,Freedman M,Lee C,Spitsbergen J,Neuberg D,Weber G,Golub TR,Glickman JN,Kutok JL,Aster JC,Zon LI
Category | C2
Sub-category | CGP
Brief description | Human orthologs of genes down-regulated in the crb ('crash and burn') zebrafish mutant that represents a loss-of-function mutation in BMYB [GeneID=4605].
Full description | A major goal of cancer research has been to identify genes that contribute to cancer formation. The similar pathology between zebrafish and human tumors, as well as the past success of large-scale genetic screens in uncovering human disease genes, makes zebrafish an ideal system in which to find such new genes. Here, we show that a zebrafish forward genetic screen uncovered multiple cell proliferation mutants including one mutant, crash&burn (crb), that represents a loss-of-function mutation in bmyb, a transcriptional regulator and member of a putative proto-oncogene family. crb mutant embryos have defects in mitotic progression and spindle formation, and exhibit genome instability. Regulation of cyclin B levels by bmyb appears to be the mechanism of mitotic accumulation in crb. Carcinogenesis studies reveal increased cancer susceptibility in adult crb heterozygotes. Gene-expression signatures associated with loss of bmyb in zebrafish are also correlated with conserved signatures in human tumor samples, and down-regulation of the B-myb signature genes is associated with retention of p53 function. Our findings show that zebrafish screens can uncover cancer pathways, and demonstrate that loss of function of bmyb is associated with cancer.

Standard name | KIM_GERMINAL_CENTER_T_HELPER_DN
Systematic name | M1408
Organism | Homo sapiens
PMID | 15213097
Authors | Kim CH,Lim HW,Kim JR,Rott L,Hillsamer P,Butcher EC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in germinal center T helper cells compared to other CD4+ [GeneID=920] T lymphocyte types.
Full description | Gene expression profiling was used to compare the gene expression patterns of human germinal center (GC) T helper (Th) cells with other CD4+ T-cell subsets (naive, central, and effector memory T cells). GC-Th cells, specifically localized in germinal centers to help B cells, are distantly related to central and effector memory T cells in global gene expression profiles. GC-Th cells displayed substantial differences in mRNA for adhesion molecules, chemoattractant receptors, and cytokines compared with other populations. Distinct expression of transcriptional factors by GC-Th cells is consistent with the hypothesis that they may be different from other T cells in cell lineage. Interestingly, CXCL13, a critical chemokine for B-cell entry to lymphoid follicles, is one of the most highly up-regulated genes in GC-Th cells. GC-Th cells (but not other T cells) produce and secrete large amounts of functional CXCL13 upon T-cell receptor activation, a process that is dependent on costimulation, requires translation and transcription, and is dramatically enhanced by activation in the presence of GC-B cells. This study revealed for the first time the unique gene expression program of GC-Th cells.

Standard name | RADAEVA_RESPONSE_TO_IFNA1_UP
Systematic name | M13763
Organism | Homo sapiens
PMID | 11910354
Authors | Radaeva S,Jaruga B,Hong F,Kim WH,Fan S,Cai H,Strom S,Liu Y,El-Assal O,Gao B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary hepatocytes and Hep3B (hepatocyte) cells in response to IFNA [GeneID=3439].
Full description | BACKGROUND & AIMS: Interferon (IFN)-alpha therapy is currently the primary choice for viral hepatitis and a promising treatment for hepatocellular carcinoma (HCC). Primary mouse and rat hepatocytes respond poorly to IFN-alpha stimulation. Thus, it is very important to examine the IFN-alpha signal pathway in primary human hepatocytes. METHODS: The IFN-alpha-activated signals and genes in primary human hepatocytes and hepatoma cells were examined by Western blotting and microarray analyses. RESULTS: Primary human hepatocytes respond very well to IFN-alpha stimulation as shown by activation of multiple signal transducer and activator of transcription factor (STAT) 1, 2, 3, 5, and multiple genes. The differential response to IFN-alpha stimulation in primary human and mouse hepatocytes may be caused by expression of predominant functional IFN-alpha receptor 2c (IFNAR2c) in primary human hepatocytes vs. expression of predominant inhibitory IFNAR2a in mouse hepatocytes. Microarray analyses of primary human hepatocytes show that IFN-alpha up-regulates about 44 genes by over 2-fold and down-regulates about 9 genes by 50%. The up-regulated genes include a variety of antiviral and tumor suppressors/proapoptotic genes. The down-regulated genes include c-myc and c-Met, the hepatocyte growth factor (HGF) receptor. Down-regulation of c-Met is caused by IFN-alpha suppression of the c-Met promoter through down-regulation of Sp1 binding and results in attenuation of HGF-induced signals and cell proliferation. CONCLUSIONS: IFN-alpha directly targets human hepatocytes, followed by activation of multiple STATs and regulation of a wide variety of genes, which may contribute to the antiviral and antitumor activities of IFN-alpha in human liver.

Standard name | PEART_HDAC_PROLIFERATION_CLUSTER_UP
Systematic name | M1409
Organism | Homo sapiens
PMID | 15738394
Authors | Peart MJ,Smyth GK,van Laar RK,Bowtell DD,Richon VM,Marks PA,Holloway AJ,Johnstone RW
Category | C2
Sub-category | CGP
Brief description | Cell proliferation genes up-regulated by histone deacetylase (HDAC) inhibitors SAHA and depsipeptide [PubChem=5311;5352062].
Full description | Histone deacetylase inhibitors (HDACis) inhibit tumor cell growth and survival, possibly through their ability to regulate the expression of specific proliferative and/or apoptotic genes. However, the HDACi-regulated genes necessary and/or sufficient for their biological effects remain undefined. We demonstrate that the HDACis suberoylanilide hydroxamic acid (SAHA) and depsipeptide regulate a highly overlapping gene set with at least 22% of genes showing altered expression over a 16-h culture period. SAHA and depsipeptide coordinately regulated the expression of several genes within distinct apoptosis and cell cycle pathways. Multiple genes within the Myc, type beta TGF, cyclin/cyclin-dependent kinase, TNF, Bcl-2, and caspase pathways were regulated in a manner that favored induction of apoptosis and decreased cellular proliferation. APAF-1, a gene central to the intrinsic apoptotic pathway, was induced by SAHA and depsipeptide and shown to be important, but not essential, for HDACi-induced cell death. Overexpression of p16(INK4A) and arrest of cells in G(1) can suppress HDACi-mediated apoptosis. Although p16(INK4A) did not affect the genome-wide transcription changes mediated by SAHA, a small number of apoptotic genes, including BCLXL and B-MYB, were differentially regulated in a manner consistent with attenuated HDACi-mediated apoptosis in arrested cells. We demonstrate that different HDACi alter transcription of a large and common set of genes that control diverse molecular pathways important for cell survival and proliferation. The ability of HDACi to target multiple apoptotic and cell proliferation pathways may provide a competitive advantage over other chemotherapeutic agents because suppression/loss of a single pathway may not confer resistance to these agents.

Standard name | TARTE_PLASMA_CELL_VS_B_LYMPHOCYTE_DN
Systematic name | M17812
Organism | Homo sapiens
PMID | 12663452
Authors | Tarte K,Zhan F,De Vos J,Klein B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in plasma cells compared with B lymphocytes.
Full description | Plasma cells (PCs), the end point of B-cell differentiation, are a heterogeneous cell compartment comprising several cell subsets from short-lived highly proliferative plasmablasts to long-lived nondividing fully mature PCs. Whereas the major transcription factors driving the differentiation of B cells to PCs were recently identified, the subtle genetic changes that underlie the transition from plasmablasts to mature PCs are poorly understood. We recently described an in vitro model making it possible to obtain a large number of cells with the morphologic, phenotypic, and functional characteristics of normal polyclonal plasmablastic cells (PPCs). Using Affymetrix microarrays we compared the gene expression profiles of these PPCs with those of mature PCs isolated from tonsils (TPCs) and bone marrow (BMPCs), and with those of B cells purified from peripheral blood (PBB cells) and tonsils (TBCs). Unsupervised principal component analysis clearly distinguished the 5 cell populations on the basis of their differentiation and proliferation status. Detailed statistical analysis allowed the identification of 85 PC genes and 40 B-cell genes, overexpressed, respectively, in the 3 PC subsets or in the 2 B-cell subsets. In addition, several signaling molecules and antiapoptotic proteins were found to be induced in BMPCs compared with PPCs and could be involved in the accumulation and prolonged survival of BMPCs in close contact with specialized stromal microenvironment. These data should help to better understand the molecular events that regulate commitment to a PC fate, mediate PC maintenance in survival niches, and could facilitate PC immortalization in plasma cell dyscrasias.

Standard name | PARK_HSC_VS_MULTIPOTENT_PROGENITORS_UP
Systematic name | M1412
Organism | Mus musculus
PMID | 11781229
Authors | Park IK,He Y,Lin F,Laerum OD,Tian Q,Bumgarner R,Klug CA,Li K,Kuhr C,Doyle MJ,Xie T,Schummer M,Sun Y,Goldsmith A,Clarke MF,Weissman IL,Hood L,Li L
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in long term hematopoietic stem cells (LT-HSC) compared to multipotent progenitor (MPP) cells.
Full description | Hematopoietic stem cells (HSCs) have self-renewal capacity and multilineage developmental potentials. The molecular mechanisms that control the self-renewal of HSCs are still largely unknown. Here, a systematic approach using bioinformatics and array hybridization techniques to analyze gene expression profiles in HSCs is described. To enrich mRNAs predominantly expressed in uncommitted cell lineages, 54 000 cDNA clones generated from a highly enriched population of HSCs and a mixed population of stem and early multipotent progenitor (MPP) cells were arrayed on nylon membranes (macroarray or high-density array), and subtracted with cDNA probes derived from mature lineage cells including spleen, thymus, and bone marrow. Five thousand cDNA clones with very low hybridization signals were selected for sequencing and further analysis using microarrays on glass slides. Two populations of cells, HSCs and MPP cells, were compared for differential gene expression using microarray analysis. HSCs have the ability to self-renew, while MPP cells have lost the capacity for self-renewal. A large number of genes that were differentially expressed by enriched populations of HSCs and MPP cells were identified. These included transcription factors, signaling molecules, and previously unknown genes.

Standard name | YAGI_AML_RELAPSE_PROGNOSIS
Systematic name | M15262
Organism | Homo sapiens
PMID | 12738660
Authors | Yagi T,Morimoto A,Eguchi M,Hibi S,Sako M,Ishii E,Mizutani S,Imashuku S,Ohki M,Ichikawa H
Category | C2
Sub-category | CGP
Brief description | Genes associated with clinical prognosis of pediatric AML (acute myeloid leukemia): good prognosis=no relapse > 3 years; poor prognosis=relapse < 1 year or no response to therapy.
Full description | Most patients with acute myeloid leukemia (AML) enter complete remission (CR) after treatment with chemotherapy, but a large number of them experience relapse with resistant disease. To identify genes that are associated with their prognoses, we analyzed gene expression in 54 pediatric patients with AML using an oligonucleotide microarray that contained 12 566 probe sets. A supervised approach using the Student t test selected a prognostic set of 35 genes, some of which are associated with the regulation of cell cycle and apoptosis. Most of these genes had not previously been reported to be associated with prognosis and were not correlated with morphologically classified French-American-British (FAB) subtypes or with karyotypes. These results indicate the existence of prognosis-associated genes that are independent of cell lineage and cytogenetic abnormalities, and they can provide therapeutic direction for individual risk-adapted therapy for pediatric AML patients.

Standard name | SHIPP_DLBCL_CURED_VS_FATAL_UP
Systematic name | M3334
Organism | Homo sapiens
PMID | 11786909
Authors | Shipp MA,Ross KN,Tamayo P,Weng AP,Kutok JL,Aguiar RC,Gaasenbeek M,Angelo M,Reich M,Pinkus GS,Ray TS,Koval MA,Last KW,Norton A,Lister TA,Mesirov J,Neuberg DS,Lander ES,Aster JC,Golub TR
Category | C2
Sub-category | CGP
Brief description | Top 50 up-regulated markers for the diffused large B-cell lymphoma (DLBCL) that distinguished between cured and fatal/refractory clinical outcomes.
Full description | Diffuse large B-cell lymphoma (DLBCL), the most common lymphoid malignancy in adults, is curable in less than 50% of patients. Prognostic models based on pre-treatment characteristics, such as the International Prognostic Index (IPI), are currently used to predict outcome in DLBCL. However, clinical outcome models identify neither the molecular basis of clinical heterogeneity, nor specific therapeutic targets. We analyzed the expression of 6,817 genes in diagnostic tumor specimens from DLBCL patients who received cyclophosphamide, adriamycin, vincristine and prednisone (CHOP)-based chemotherapy, and applied a supervised learning prediction method to identify cured versus fatal or refractory disease. The algorithm classified two categories of patients with very different five-year overall survival rates (70% versus 12%). The model also effectively delineated patients within specific IPI risk categories who were likely to be cured or to die of their disease. Genes implicated in DLBCL outcome included some that regulate responses to B-cell-receptor signaling, critical serine/threonine phosphorylation pathways and apoptosis. Our data indicate that supervised learning classification techniques can predict outcome in DLBCL and identify rational targets for intervention.

Standard name | FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_REJECTED_VS_OK_UP
Systematic name | M19695
Organism | Homo sapiens
PMID | 15307835
Authors | Flechner SM,Kurian SM,Head SR,Sharp SM,Whisenant TC,Zhang J,Chismar JD,Horvath S,Mondala T,Gilmartin T,Cook DJ,Kay SA,Walker JR,Salomon DR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in kidney biopsies from patients with acute transplant rejection compared to the biopsies from patients with well functioning kidneys more than 1-year post transplant.
Full description | A major challenge for kidney transplantation is balancing the need for immunosuppression to prevent rejection, while minimizing drug-induced toxicities. We used DNA microarrays (HG-U95Av2 GeneChips, Affymetrix) to determine gene expression profiles for kidney biopsies and peripheral blood lymphocytes (PBLs) in transplant patients including normal donor kidneys, well-functioning transplants without rejection, kidneys undergoing acute rejection, and transplants with renal dysfunction without rejection. We developed a data analysis schema based on expression signal determination, class comparison and prediction, hierarchical clustering, statistical power analysis and real-time quantitative PCR validation. We identified distinct gene expression signatures for both biopsies and PBLs that correlated significantly with each of the different classes of transplant patients. This is the most complete report to date using commercial arrays to identify unique expression signatures in transplant biopsies distinguishing acute rejection, acute dysfunction without rejection and well-functioning transplants with no rejection history. We demonstrate for the first time the successful application of high density DNA chip analysis of PBL as a diagnostic tool for transplantation. The significance of these results, if validated in a multicenter prospective trial, would be the establishment of a metric based on gene expression signatures for monitoring the immune status and immunosuppression of transplanted patients.

Standard name | LEE_LIVER_CANCER_ACOX1_UP
Systematic name | M19612
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma of ACOX1 [GeneID=51] knockout mice.
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | IIZUKA_LIVER_CANCER_PROGRESSION_G2_G3_DN
Systematic name | M4707
Organism | Homo sapiens
PMID | 15710396
Authors | Iizuka N,Oka M,Yamada-Okabe H,Mori N,Tamesa T,Okada T,Takemoto N,Sakamoto K,Hamada K,Ishitsuka H,Miyamoto T,Uchimura S,Hamamoto Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during transition from G2 (moderately differentiated tumor, infected with HCV) to G3 (poorly differentiated tumor, infected with HCV) in the development of hepatocellular carcinoma.
Full description | Using high-density oligonucleotide array, we comprehensively analyzed expression levels of 12600 genes in 50 hepatocellular carcinoma (HCC) samples with positive hepatitis C virus (HCV) serology (well (G1), moderately (G2), and poorly (G3) differentiated tumors) and 11 non-tumorous livers (L1 and L0) with and without HCV infection. We searched for discriminatory genes of transition (L0 vs. L1, L1 vs. G1, G1 vs. G2, G2 vs. G3) with a supervised learning method, and then arranged the samples by self-organizing map (SOM) with the discriminatory gene sets. The SOM arranged the five clusters on a unique sigmoidal curve in the order L0, L1, G1, G2, and G3. The sample arrangement reproduced development-related features of HCC such as p53 abnormality. Strikingly, G2 tumors without venous invasion were located closer to the G1 cluster, and most G2 tumors with venous invasion were located closer to the G3 cluster (P=0.001 by Fisher's exact test). Our present profiling data will serve as a framework to understand the relation between the development and dedifferentiation of HCC.

Standard name | CHEOK_RESPONSE_TO_MERCAPTOPURINE_UP
Systematic name | M19652
Organism | Homo sapiens
PMID | 12704389
Authors | Cheok MH,Yang W,Pui CH,Downing JR,Cheng C,Naeve CW,Relling MV,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes specifically up-regulated in pediadric acute lymphoblastic leukemia (ALL) patients by mercaptopurine [PubChem=667490].
Full description | To elucidate the genomics of cellular responses to cancer treatment, we analyzed the expression of over 9,600 human genes in acute lymphoblastic leukemia cells before and after in vivo treatment with methotrexate and mercaptopurine given alone or in combination. Based on changes in gene expression, we identified 124 genes that accurately discriminated among the four treatments. Discriminating genes included those involved in apoptosis, mismatch repair, cell cycle control and stress response. Only 14% of genes that changed when these medications were given as single agents also changed when they were given together. These data indicate that lymphoid leukemia cells of different molecular subtypes share common pathways of genomic response to the same treatment, that changes in gene expression are treatment-specific and that gene expression can illuminate differences in cellular response to drug combinations versus single agents.

Standard name | UEDA_PERIFERAL_CLOCK
Systematic name | M12498
Organism | Mus musculus
PMID | 15273285
Authors | Ueda HR,Chen W,Minami Y,Honma S,Honma K,Iino M,Hashimoto S
Category | C2
Sub-category | CGP
Brief description | Molecular timetable composed of 162 time-indicating genes (182 probes) in the peripheral (liver) clock.
Full description | Detection of individual body time (BT) via a single-time-point assay has been a longstanding unfulfilled dream in medicine, because BT information can be exploited to maximize potency and minimize toxicity during drug administration and thus will enable highly optimized medication. To achieve this dream, we created a molecular timetable composed of >100 time-indicating genes, whose gene expression levels can represent internal BT. Here we describe a robust method called the molecular-timetable method for BT detection from a single-time-point expression profile. The power of this method is demonstrated by the sensitive and accurate detection of BT and the sensitive diagnosis of rhythm disorders. These results demonstrate the feasibility of BT detection based on single-time-point sampling, suggest the potential for expression-based diagnosis of rhythm disorders, and may translate functional genomics into chronotherapy and personalized medicine.

Standard name | CHESLER_BRAIN_HIGHEST_GENETIC_VARIANCE
Systematic name | M427
Organism | Mus musculus
PMID | 15711545
Authors | Chesler EJ,Lu L,Shou S,Qu Y,Gu J,Wang J,Hsu HC,Mountz JD,Baldwin NE,Langston MA,Threadgill DW,Manly KF,Williams RW
Category | C2
Sub-category | CGP
Brief description | Neurologically relevant transcripts with highest variance accounted for by mouse strain (genotype) differences.
Full description | Patterns of gene expression in the central nervous system are highly variable and heritable. This genetic variation among normal individuals leads to considerable structural, functional and behavioral differences. We devised a general approach to dissect genetic networks systematically across biological scale, from base pairs to behavior, using a reference population of recombinant inbred strains. We profiled gene expression using Affymetrix oligonucleotide arrays in the BXD recombinant inbred strains, for which we have extensive SNP and haplotype data. We integrated a complementary database comprising 25 years of legacy phenotypic data on these strains. Covariance among gene expression and pharmacological and behavioral traits is often highly significant, corroborates known functional relations and is often generated by common quantitative trait loci. We found that a small number of major-effect quantitative trait loci jointly modulated large sets of transcripts and classical neural phenotypes in patterns specific to each tissue. We developed new analytic and graph theoretical approaches to study shared genetic modulation of networks of traits using gene sets involved in neural synapse function as an example. We built these tools into an open web resource called WebQTL that can be used to test a broad array of hypotheses.

Standard name | CHEN_LUNG_CANCER_SURVIVAL
Systematic name | M8526
Organism | Homo sapiens
PMID | 14573703
Authors | Chen G,Gharib TG,Wang H,Huang CC,Kuick R,Thomas DG,Shedden KA,Misek DE,Taylor JM,Giordano TJ,Kardia SL,Iannettoni MD,Yee J,Hogg PJ,Orringer MB,Hanash SM,Beer DG
Category | C2
Sub-category | CGP
Brief description | Protein profiles associated with survival in lung adenocarcinoma.
Full description | Morphologic assessment of lung tumors is informative but insufficient to adequately predict patient outcome. We previously identified transcriptional profiles that predict patient survival, and here we identify proteins associated with patient survival in lung adenocarcinoma. A total of 682 individual protein spots were quantified in 90 lung adenocarcinomas by using quantitative two-dimensional polyacrylamide gel electrophoresis analysis. A leave-one-out cross-validation procedure using the top 20 survival-associated proteins identified by Cox modeling indicated that protein profiles as a whole can predict survival in stage I tumor patients (P = 0.01). Thirty-three of 46 survival-associated proteins were identified by using mass spectrometry. Expression of 12 candidate proteins was confirmed as tumor-derived with immunohistochemical analysis and tissue microarrays. Oligonucleotide microarray results from both the same tumors and from an independent study showed mRNAs associated with survival for 11 of 27 encoded genes. Combined analysis of protein and mRNA data revealed 11 components of the glycolysis pathway as associated with poor survival. Among these candidates, phosphoglycerate kinase 1 was associated with survival in the protein study, in both mRNA studies and in an independent validation set of 117 adenocarcinomas and squamous lung tumors using tissue microarrays. Elevated levels of phosphoglycerate kinase 1 in the serum were also significantly correlated with poor outcome in a validation set of 107 patients with lung adenocarcinomas using ELISA analysis. These studies identify new prognostic biomarkers and indicate that protein expression profiles can predict the outcome of patients with early-stage lung cancer.

Standard name | POMEROY_MEDULLOBLASTOMA_DESMOPLASIC_VS_CLASSIC_UP
Systematic name | M3274
Organism | Homo sapiens
PMID | 11807556
Authors | Pomeroy SL,Tamayo P,Gaasenbeek M,Sturla LM,Angelo M,McLaughlin ME,Kim JY,Goumnerova LC,Black PM,Lau C,Allen JC,Zagzag D,Olson JM,Curran T,Wetmore C,Biegel JA,Poggio T,Mukherjee S,Rifkin R,Califano A,Stolovitzky G,Louis DN,Mesirov JP,Lander ES,Golub TR
Category | C2
Sub-category | CGP
Brief description | Top up-regulated marker genes for medulloblastoma classification: desmoplastic vs classic morphology.
Full description | Embryonal tumours of the central nervous system (CNS) represent a heterogeneous group of tumours about which little is known biologically, and whose diagnosis, on the basis of morphologic appearance alone, is controversial. Medulloblastomas, for example, are the most common malignant brain tumour of childhood, but their pathogenesis is unknown, their relationship to other embryonal CNS tumours is debated, and patients' response to therapy is difficult to predict. We approached these problems by developing a classification system based on DNA microarray gene expression data derived from 99 patient samples. Here we demonstrate that medulloblastomas are molecularly distinct from other brain tumours including primitive neuroectodermal tumours (PNETs), atypical teratoid/rhabdoid tumours (AT/RTs) and malignant gliomas. Previously unrecognized evidence supporting the derivation of medulloblastomas from cerebellar granule cells through activation of the Sonic Hedgehog (SHH) pathway was also revealed. We show further that the clinical outcome of children with medulloblastomas is highly predictable on the basis of the gene expression profiles of their tumours at diagnosis.

Standard name | WIELAND_UP_BY_HBV_INFECTION
Systematic name | M11620
Organism | Homo sapiens
PMID | 15100412
Authors | Wieland S,Thimme R,Purcell RH,Chisari FV
Category | C2
Sub-category | CGP
Brief description | Genes induced in the liver during hepatitis B (HBV) viral clearance in chimpanzees.
Full description | Previous studies in hepatitis B virus (HBV)-infected humans and chimpanzees suggest that control of HBV infection involves the cells, effector functions, and molecular mediators of the immune response. The objective of the current study was to identify, in the liver of acutely HBV-infected chimpanzees, the spectrum of virus-induced and immune response-related genes that regulate the infection. The results demonstrate that HBV does not induce any genes during entry and expansion, suggesting it is a stealth virus early in the infection. In contrast, a large number of T cell-derived IFN-gamma-regulated genes are induced in the liver during viral clearance, reflecting the impact of an adaptive T cell response that inhibits viral replication and kills infected cells, thereby terminating the infection.

Standard name | SHEPARD_BMYB_MORPHOLINO_UP
Systematic name | M10209
Organism | Danio rerio
PMID | 16150706
Authors | Shepard JL,Amatruda JF,Stern HM,Subramanian A,Finkelstein D,Ziai J,Finley KR,Pfaff KL,Hersey C,Zhou Y,Barut B,Freedman M,Lee C,Spitsbergen J,Neuberg D,Weber G,Golub TR,Glickman JN,Kutok JL,Aster JC,Zon LI
Category | C2
Sub-category | CGP
Brief description | Human orthologs of genes up-regulated in zebra fish after knockdown of BMYB [GeneID=4605] by morpholino.
Full description | A major goal of cancer research has been to identify genes that contribute to cancer formation. The similar pathology between zebrafish and human tumors, as well as the past success of large-scale genetic screens in uncovering human disease genes, makes zebrafish an ideal system in which to find such new genes. Here, we show that a zebrafish forward genetic screen uncovered multiple cell proliferation mutants including one mutant, crash&burn (crb), that represents a loss-of-function mutation in bmyb, a transcriptional regulator and member of a putative proto-oncogene family. crb mutant embryos have defects in mitotic progression and spindle formation, and exhibit genome instability. Regulation of cyclin B levels by bmyb appears to be the mechanism of mitotic accumulation in crb. Carcinogenesis studies reveal increased cancer susceptibility in adult crb heterozygotes. Gene-expression signatures associated with loss of bmyb in zebrafish are also correlated with conserved signatures in human tumor samples, and down-regulation of the B-myb signature genes is associated with retention of p53 function. Our findings show that zebrafish screens can uncover cancer pathways, and demonstrate that loss of function of bmyb is associated with cancer.

Standard name | GOLUB_ALL_VS_AML_DN
Systematic name | M6761
Organism | Homo sapiens
PMID | 10521349
Authors | Golub TR,Slonim DK,Tamayo P,Huard C,Gaasenbeek M,Mesirov JP,Coller H,Loh ML,Downing JR,Caligiuri MA,Bloomfield CD,Lander ES
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes highly correlated with acute lymphoblastic leukemia (ALL) vs acute myeloid leukemia (AML).
Full description | Although cancer classification has improved over the past 30 years, there has been no general approach for identifying new cancer classes (class discovery) or for assigning tumors to known classes (class prediction). Here, a generic approach to cancer classification based on gene expression monitoring by DNA microarrays is described and applied to human acute leukemias as a test case. A class discovery procedure automatically discovered the distinction between acute myeloid leukemia (AML) and acute lymphoblastic leukemia (ALL) without previous knowledge of these classes. An automatically derived class predictor was able to determine the class of new leukemia cases. The results demonstrate the feasibility of cancer classification based solely on gene expression monitoring and suggest a general strategy for discovering and predicting cancer classes for other types of cancer, independent of previous biological knowledge.

Standard name | DISTECHE_ESCAPED_FROM_X_INACTIVATION
Systematic name | M16091
Organism | Homo sapiens
PMID | 12900543
Authors | Disteche CM,Filippova GN,Tsuchiya KD
Category | C2
Sub-category | CGP
Brief description | Genes that escape X inactivation.
Full description | Although the process of X inactivation in mammalian cells silences the majority of genes on the inactivated X chromosome, some genes escape this chromosome-wide silencing. Genes that escape X inactivation present a unique opportunity to study the process of silencing and the mechanisms that protect some genes from being turned off. In this review, we will discuss evolutionary aspects of escape from X inactivation, in relation to the divergence of the sex chromosomes. Molecular characteristics, expression, and epigenetic modifications of genes that escape will be presented, including their developmental regulation and the implications of chromatin domains along the X chromosome in modeling the escape process.

Standard name | DER_IFN_BETA_RESPONSE_UP
Systematic name | M13453
Organism | Homo sapiens
PMID | 9861020
Authors | Der SD,Zhou A,Williams BR,Silverman RH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HT1080 (fibrosarcoma) cells by treatment with interferon beta for 6 h.
Full description | The pleiotropic activities of interferons (IFNs) are mediated primarily through the transcriptional regulation of many downstream effector genes. The mRNA profiles from IFN-alpha, -beta, or -gamma treatments of the human fibrosarcoma cell line, HT1080, were determined by using oligonucleotide arrays with probe sets corresponding to more than 6,800 human genes. Among these were transcripts for known IFN-stimulated genes (ISGs), the expression of which were consistent with previous studies in which the particular ISG was characterized as responsive to either Type I (alpha, beta) or Type II (gamma) IFNs, or both. Importantly, many novel IFN-stimulated genes were identified that were diverse in their known biological functions. For instance, several novel ISGs were identified that are implicated in apoptosis (including RAP46/Bag-1, phospholipid scramblase, and hypoxia inducible factor-1alpha). Furthermore, several IFN-repressed genes also were identified. These results demonstrate the usefulness of oligonucleotide arrays in monitoring mammalian gene expression on a broad and unprecedented scale. In particular, these findings provide insights into the basic mechanisms of IFN actions and ultimately may contribute to better therapeutic uses for IFNs.

Standard name | MANALO_HYPOXIA_DN
Systematic name | M18562
Organism | Homo sapiens
PMID | 15374877
Authors | Manalo DJ,Rowan A,Lavoie T,Natarajan L,Kelly BD,Ye SQ,Garcia JG,Semenza GL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in response to both hypoxia and overexpression of an active form of HIF1A [GeneID=3091].
Full description | Hypoxia-inducible factor 1 (HIF-1) activates transcription of genes encoding angiogenic growth factors, which are secreted by hypoxic cells and stimulate endothelial cells, leading to angiogenesis. To determine whether HIF-1 also mediates cell-autonomous responses to hypoxia, we have compared gene expression profiles in arterial endothelial cells cultured under nonhypoxic versus hypoxic conditions and in nonhypoxic cells infected with adenovirus encoding beta-galactosidase versus a constitutively active form of HIF-1alpha (AdCA5). There were 245 gene probes that showed at least 1.5-fold increase in expression in response to hypoxia and in response to AdCA5; 325 gene probes showed at least 1.5-fold decrease in expression in response to hypoxia and in response to AdCA5. The largest category of genes down-regulated by both hypoxia and AdCA5 encoded proteins involved in cell growth/proliferation. Many genes up-regulated by both hypoxia and AdCA5 encoded cytokines/growth factors, receptors, and other signaling proteins. Transcription factors accounted for the largest group of HIF-1-regulated genes, indicating that HIF-1 controls a network of transcriptional responses to hypoxia in endothelial cells. Infection of endothelial cells with AdCA5 under nonhypoxic conditions was sufficient to induce increased basement membrane invasion and tube formation similar to the responses induced by hypoxia, indicating that HIF-1 mediates cell-autonomous activation of endothelial cells.

Standard name | CHESLER_BRAIN_HIGHEST_EXPRESSION
Systematic name | M4519
Organism | Mus musculus
PMID | 15711545
Authors | Chesler EJ,Lu L,Shou S,Qu Y,Gu J,Wang J,Hsu HC,Mountz JD,Baldwin NE,Langston MA,Threadgill DW,Manly KF,Williams RW
Category | C2
Sub-category | CGP
Brief description | Neurologically relevant transcripts with highest abundance fold range in brain tissue among mouse strains.
Full description | Patterns of gene expression in the central nervous system are highly variable and heritable. This genetic variation among normal individuals leads to considerable structural, functional and behavioral differences. We devised a general approach to dissect genetic networks systematically across biological scale, from base pairs to behavior, using a reference population of recombinant inbred strains. We profiled gene expression using Affymetrix oligonucleotide arrays in the BXD recombinant inbred strains, for which we have extensive SNP and haplotype data. We integrated a complementary database comprising 25 years of legacy phenotypic data on these strains. Covariance among gene expression and pharmacological and behavioral traits is often highly significant, corroborates known functional relations and is often generated by common quantitative trait loci. We found that a small number of major-effect quantitative trait loci jointly modulated large sets of transcripts and classical neural phenotypes in patterns specific to each tissue. We developed new analytic and graph theoretical approaches to study shared genetic modulation of networks of traits using gene sets involved in neural synapse function as an example. We built these tools into an open web resource called WebQTL that can be used to test a broad array of hypotheses.

Standard name | MAGRANGEAS_MULTIPLE_MYELOMA_IGG_VS_IGA_DN
Systematic name | M1414
Organism | Homo sapiens
PMID | 12623842
Authors | Magrangeas F,Nasser V,Avet-Loiseau H,Loriod B,Decaux O,Granjeaud S,Bertucci F,Birnbaum D,Nguyen C,Harousseau JL,Bataille R,Houlgatte R,Minvielle S
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes discriminating multiple myeloma samples by type of immunoglobulin they produce: IgG vs IgA.
Full description | Although multiple myeloma (MM) is a unique entity, a marked heterogeneity is actually observed among the patients, which has been first related to immunoglobulin (Ig) types and light chain subtypes and more recently to chromosomal abnormalities. To further investigate this genetic heterogeneity, we analyzed gene expression profiles of 92 primary tumors according to their Ig types and light chain subtypes with DNA microarrays. Several clusters of genes involved in various biologic functions such as immune response, cell cycle control, signaling, apoptosis, cell adhesion, and structure significantly discriminated IgA- from IgG-MM. Genes associated with inhibition of differentiation and apoptosis induction were up-regulated while genes associated with immune response, cell cycle control, and apoptosis were down-regulated in IgA-MM. According to the expression of the 61 most discriminating genes, BJ-MM represented a separate subgroup that did not express either the genes characteristic of IgG-MM or those of IgA-MM at a high level. This suggests that transcriptional programs associated to the switch could be maintained up to plasma cell differentiation. Several genes whose products are known to stimulate bone remodeling discriminate between kappa- and lambda-MM. One of these genes, Mip-1alpha, was overexpressed in the kappa subgroup. In addition, we established a strong association (P =.0001) between kappa subgroup expressing high levels of Mip-1alpha and active myeloma bone disease. This study shows that DNA microarrays enable us to perform a molecular dissection of the bioclinical diversity of MM and provide new molecular tools to investigate the pathogenesis of malignant plasma cells.

Standard name | LEE_LIVER_CANCER_MYC_E2F1_DN
Systematic name | M5636
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma (HCC) from MYC and E2F1 [GeneID=4609;1869] double transgenic mice.
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | BYSTROEM_CORRELATED_WITH_IL5_UP
Systematic name | M1415
Organism | Mus musculus
PMID | 14525773
Authors | Byström J,Wynn TA,Domachowske JB,Rosenberg HF
Category | C2
Sub-category | CGP
Brief description | Genes whose expression in bone marrow samples correlated directly with increased levels of serum IL5 [GeneID=3567].
Full description | Interleukin-5 (IL-5) is a hematopoietic differentiation factor that promotes the development of mature eosinophils from progenitors in bone marrow. We present a multifactorial microarray study documenting the transcriptional events in bone marrow of wild-type and IL-5-deficient mice at baseline and in response to infection with Schistosoma mansoni. The microarray data were analyzed by a 4-way subtractive algorithm that eliminated confounding non-IL-5-related sequelae of schistosome infection as well as alterations in gene expression among uninfected mice. Among the most prominent findings, we observed 7- to 40-fold increased expression of transcripts encoding the classic eosinophil granule proteins (eosinophil peroxidase, major basic protein, the ribonucleases) together with arachidonate-15-lipoxygenase and protease inhibitor plasminogen activator inhibitor 2 (PAI-2), in the IL-5-producing, infected wild-type mice only. This was accompanied by increased transcription of genes involved in secretory protein biosynthesis and granule-vesicle formation. Interestingly, we did not detect increased expression of genes encoding eosinophil-related chemokine receptors (CCR1, CCR3) or members of the GATA or CCAAT/enhancer binding protein (C/EBP) transcription factor families. These data suggest that the IL-5-responsive progenitors in the mouse bone marrow are already significantly committed to the eosinophil lineage and that IL-5 promotes differentiation of these committed progenitors into cells with recognizable and characteristic cytoplasmic granules and granule proteins.

Standard name | CHESLER_BRAIN_D6MIT150_QTL_TRANS
Systematic name | M15964
Organism | Mus musculus
PMID | 15711545
Authors | Chesler EJ,Lu L,Shou S,Qu Y,Gu J,Wang J,Hsu HC,Mountz JD,Baldwin NE,Langston MA,Threadgill DW,Manly KF,Williams RW
Category | C2
Sub-category | CGP
Brief description | Neurologically relevant genes modulated in brain tissue by a trans-regulatory QTL (quantitative trait locus) near D6Mit150 marker.
Full description | Patterns of gene expression in the central nervous system are highly variable and heritable. This genetic variation among normal individuals leads to considerable structural, functional and behavioral differences. We devised a general approach to dissect genetic networks systematically across biological scale, from base pairs to behavior, using a reference population of recombinant inbred strains. We profiled gene expression using Affymetrix oligonucleotide arrays in the BXD recombinant inbred strains, for which we have extensive SNP and haplotype data. We integrated a complementary database comprising 25 years of legacy phenotypic data on these strains. Covariance among gene expression and pharmacological and behavioral traits is often highly significant, corroborates known functional relations and is often generated by common quantitative trait loci. We found that a small number of major-effect quantitative trait loci jointly modulated large sets of transcripts and classical neural phenotypes in patterns specific to each tissue. We developed new analytic and graph theoretical approaches to study shared genetic modulation of networks of traits using gene sets involved in neural synapse function as an example. We built these tools into an open web resource called WebQTL that can be used to test a broad array of hypotheses.

Standard name | NELSON_RESPONSE_TO_ANDROGEN_UP
Systematic name | M13903
Organism | Homo sapiens
PMID | 12185249
Authors | Nelson PS,Clegg N,Arnold H,Ferguson C,Bonham M,White J,Hood L,Lin B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in LNCaP cells (prostate cancer) in response to synthetic androgen R1881 [PubChem=13766].
Full description | The human prostate gland is an important target organ of androgenic hormones. Testosterone and dihydrotestosterone interact with the androgen receptor to regulate vital aspects of prostate growth and function including cellular proliferation, differentiation, apoptosis, metabolism, and secretory activity. Our objective in this study was to characterize the temporal program of transcription that reflects the cellular response to androgens and to identify specific androgen-regulated genes (ARGs) or gene networks that participate in these responses. We used cDNA microarrays representing about 20,000 distinct human genes to profile androgen-responsive transcripts in the LNCaP adenocarcinoma cell line and identified 146 genes with transcript alterations more than 3-fold. Of these, 103 encode proteins with described functional roles, and 43 represent transcripts that have yet to be characterized. Temporal gene expression profiles grouped the ARGs into four distinct cohorts. Five uncharacterized ARGs demonstrated exclusive or high expression levels in the prostate relative to other tissues studied. A search of available DNA sequence upstream of 28 ARGs identified 25 with homology to the androgen response-element consensus-binding motif. These results identify previously uncharacterized and unsuspected genes whose expression levels are directly or indirectly regulated by androgens; further, they provide a comprehensive temporal view of the transcriptional program of human androgen-responsive cells.

Standard name | LIN_APC_TARGETS
Systematic name | M17434
Organism | Homo sapiens
PMID | 11522623
Authors | Lin YM,Ono K,Satoh S,Ishiguro H,Fujita M,Miwa N,Tanaka T,Tsunoda T,Yang KC,Nakamura Y,Furukawa Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by forced expression of APC [GeneID=324] in the APC-deficient SW480 cell line (colon cancer).
Full description | To elucidate the molecular mechanism of colorectal carcinogenesis, we have been attempting to isolate genes involved in the beta-catenin/T-cell factor pathway. In the experiments reported here, analysis by cDNA microarray indicated that AF17, a fusion partner of the MLL gene in acute leukemias with t(11;17)(q23;q21), was transactivated according to accumulation of beta-catenin. Expression of AF17 was significantly enhanced in 8 of the 12 colorectal cancer tissues examined. Introduction of a plasmid designed to express AF17 stimulated growth of NIH3T3 cells, and fluorescence-activated cell sorter analysis indicated that the AF17 regulation of cell-cycle progression was occurring mainly at the G(2)-M transition. Our results suggest that the AF17 gene product is likely to be involved in the beta-catenin-T-cell factor/lymphoid enhancer factor signaling pathway and to function as a growth-promoting, oncogenic protein. These findings should aid development of new strategies for diagnosis, treatment, and prevention of colon cancers and acute leukemias by clarifying the pathogenesis of these conditions.

Standard name | VANTVEER_BREAST_CANCER_METASTASIS_DN
Systematic name | M9826
Organism | Homo sapiens
PMID | 11823860
Authors | van 't Veer LJ,Dai H,van de Vijver MJ,He YD,Hart AA,Mao M,Peterse HL,van der Kooy K,Marton MJ,Witteveen AT,Schreiber GJ,Kerkhoven RM,Roberts C,Linsley PS,Bernards R,Friend SH
Category | C2
Sub-category | CGP
Brief description | Genes whose expression is significantly and negatively correlated with poor breast cancer clinical outcome (defined as developing distant metastases in less than 5 years).
Full description | Breast cancer patients with the same stage of disease can have markedly different treatment responses and overall outcome. The strongest predictors for metastases (for example, lymph node status and histological grade) fail to classify accurately breast tumours according to their clinical behaviour. Chemotherapy or hormonal therapy reduces the risk of distant metastases by approximately one-third; however, 70-80% of patients receiving this treatment would have survived without it. None of the signatures of breast cancer gene expression reported to date allow for patient-tailored therapy strategies. Here we used DNA microarray analysis on primary breast tumours of 117 young patients, and applied supervised classification to identify a gene expression signature strongly predictive of a short interval to distant metastases ('poor prognosis' signature) in patients without tumour cells in local lymph nodes at diagnosis (lymph node negative). In addition, we established a signature that identifies tumours of BRCA1 carriers. The poor prognosis signature consists of genes regulating cell cycle, invasion, metastasis and angiogenesis. This gene expression profile will outperform all currently used clinical parameters in predicting disease outcome. Our findings provide a strategy to select patients who would benefit from adjuvant therapy.

Standard name | BROCKE_APOPTOSIS_REVERSED_BY_IL6
Systematic name | M8244
Organism | Homo sapiens
PMID | 12969979
Authors | Brocke-Heidrich K,Kretzschmar AK,Pfeifer G,Henze C,Löffler D,Koczan D,Thiesen HJ,Burger R,Gramatzki M,Horn F
Category | C2
Sub-category | CGP
Brief description | Genes changed in INA-6 cells (multiple myeloma, MM) by re-addition of IL6 [GeneID=3569] after its initial withdrawal for 12h.
Full description | Interleukin 6 (IL-6) is a growth and survival factor for multiple myeloma cells. As we report here, the IL-6-dependent human myeloma cell line INA-6 responds with a remarkably rapid and complete apoptosis to cytokine withdrawal. Among the antiapoptotic members of the B-cell lymphoma-2 (Bcl-2) family of apoptosis regulators, only myeloid cell factor-1 (Mcl-1) was slightly induced by IL-6. Overexpression studies demonstrated, however, that IL-6 does not exert its survival effect primarily through this pathway. The IL-6 signal transduction pathways required for survival and the target genes controlled by them were analyzed by using mutated receptor chimeras. The activation of signal transducer and activator of transcription 3 (Stat3) turned out to be obligatory for the survival of INA-6 cells. The same held true for survival and growth of XG-1 myeloma cells. Gene expression profiling of INA-6 cells by using oligonucleotide microarrays revealed many novel IL-6 target genes, among them several genes coding for transcriptional regulators involved in B-lymphocyte differentiation as well as for growth factors and receptors potentially implicated in autocrine or paracrine growth control. Regulation of most IL-6 target genes required the activation of Stat3, underscoring its central role for IL-6 signal transduction. Taken together, our data provide evidence for the existence of an as yet unknown Stat3-dependent survival pathway in myeloma cells.

Standard name | POMEROY_MEDULLOBLASTOMA_DESMOPLASIC_VS_CLASSIC_DN
Systematic name | M8510
Organism | Homo sapiens
PMID | 11807556
Authors | Pomeroy SL,Tamayo P,Gaasenbeek M,Sturla LM,Angelo M,McLaughlin ME,Kim JY,Goumnerova LC,Black PM,Lau C,Allen JC,Zagzag D,Olson JM,Curran T,Wetmore C,Biegel JA,Poggio T,Mukherjee S,Rifkin R,Califano A,Stolovitzky G,Louis DN,Mesirov JP,Lander ES,Golub TR
Category | C2
Sub-category | CGP
Brief description | Top down-regulated marker genes for medulloblastoma classification: desmoplastic vs classic morphology.
Full description | Embryonal tumours of the central nervous system (CNS) represent a heterogeneous group of tumours about which little is known biologically, and whose diagnosis, on the basis of morphologic appearance alone, is controversial. Medulloblastomas, for example, are the most common malignant brain tumour of childhood, but their pathogenesis is unknown, their relationship to other embryonal CNS tumours is debated, and patients' response to therapy is difficult to predict. We approached these problems by developing a classification system based on DNA microarray gene expression data derived from 99 patient samples. Here we demonstrate that medulloblastomas are molecularly distinct from other brain tumours including primitive neuroectodermal tumours (PNETs), atypical teratoid/rhabdoid tumours (AT/RTs) and malignant gliomas. Previously unrecognized evidence supporting the derivation of medulloblastomas from cerebellar granule cells through activation of the Sonic Hedgehog (SHH) pathway was also revealed. We show further that the clinical outcome of children with medulloblastomas is highly predictable on the basis of the gene expression profiles of their tumours at diagnosis.

Standard name | FRASOR_RESPONSE_TO_ESTRADIOL_DN
Systematic name | M3002
Organism | Homo sapiens
PMID | 14973112
Authors | Frasor J,Stossi F,Danes JM,Komm B,Lyttle CR,Katzenellenbogen BS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) by estradiol (E2) [PubChem=5757].
Full description | Selective estrogen receptor modulators (SERMs) such as tamoxifen are effective in the treatment of many estrogen receptor-positive breast cancers and have also proven to be effective in the prevention of breast cancer in women at high risk for the disease. The comparative abilities of tamoxifen versus raloxifene in breast cancer prevention are currently being compared in the Study of Tamoxifen and Raloxifene trial. To better understand the actions of these compounds in breast cancer, we have examined their effects on the expression of approximately 12,000 genes, using Affymetrix GeneChip microarrays, with quantitative PCR verification in many cases, categorizing their actions as agonist, antagonist, or partial agonist/antagonist. Analysis of gene stimulation and inhibition by the SERMs trans-hydroxytamoxifen (TOT) and raloxifene (Ral) or ICI 182,780 (ICI) and by estradiol (E2) in estrogen receptor-containing MCF-7 human breast cancer cells revealed that (a) TOT was the most E2-like of the three compounds, (b) all three compounds either partially or fully antagonized the action of E2 on most genes, with the order of antagonist activity being ICI > Ral > TOT, (c) TOT and Ral, but not ICI, displayed partial agonist/partial antagonist activity on a number of E2-regulated genes, (d) several stimulatory cell cycle-related genes were down-regulated exclusively by ICI, (e) the estrogen-like activity of Ral nearly always overlapped with that of TOT, indicating that Ral has little unique agonist activity different from that of TOT, and (f) some genes were specifically up-regulated by TOT but not Ral, ICI, or E2. Hence, gene expression profiling can discern fundamental differences among SERMs and provides insight into the distinct biologies of TOT, Ral, and ICI in breast cancer.

Standard name | CHEOK_RESPONSE_TO_HD_MTX_DN
Systematic name | M4535
Organism | Homo sapiens
PMID | 12704389
Authors | Cheok MH,Yang W,Pui CH,Downing JR,Cheng C,Naeve CW,Relling MV,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes specifically down-regulated in pediatric acute lymphoblastic leukemia (ALL) patients by high-dose methotrexate (HDMTX) [PubChem=4112].
Full description | To elucidate the genomics of cellular responses to cancer treatment, we analyzed the expression of over 9,600 human genes in acute lymphoblastic leukemia cells before and after in vivo treatment with methotrexate and mercaptopurine given alone or in combination. Based on changes in gene expression, we identified 124 genes that accurately discriminated among the four treatments. Discriminating genes included those involved in apoptosis, mismatch repair, cell cycle control and stress response. Only 14% of genes that changed when these medications were given as single agents also changed when they were given together. These data indicate that lymphoid leukemia cells of different molecular subtypes share common pathways of genomic response to the same treatment, that changes in gene expression are treatment-specific and that gene expression can illuminate differences in cellular response to drug combinations versus single agents.

Standard name | TENEDINI_MEGAKARYOCYTE_MARKERS
Systematic name | M6752
Organism | Homo sapiens
PMID | 15271793
Authors | Tenedini E,Fagioli ME,Vianelli N,Tazzari PL,Ricci F,Tagliafico E,Ricci P,Gugliotta L,Martinelli G,Tura S,Baccarani M,Ferrari S,Catani L
Category | C2
Sub-category | CGP
Brief description | Genes essential to the development of megakaryocytes, as expressed in normal cells and essential thrombocythemic cells (ET).
Full description | Gene expression profiles of bone marrow (BM) CD34-derived megakaryocytic cells (MKs) were compared in patients with essential thrombocythemia (ET) and healthy subjects using oligonucleotide microarray analysis to identify differentially expressed genes and disease-specific transcripts. We found that proapoptotic genes such as BAX, BNIP3, and BNIP3L were down-regulated in ET MKs together with genes that are components of the mitochondrial permeability transition pore complex, a system with a pivotal role in apoptosis. Conversely, antiapoptotic genes such as IGF1-R and CFLAR were up-regulated in the malignant cells, as was the SDF1 gene, which favors cell survival. On the basis of the array results, we characterized apoptosis of normal and ET MKs by time-course evaluation of annexin-V and sub-G1 peak DNA stainings of immature and mature MKs after culture in serum-free medium with an optimal thrombopoietin concentration, and annexin-V-positive MKs only, with decreasing thrombopoietin concentrations. ET MKs were more resistant to apoptosis than their normal counterparts. We conclude that imbalance between proliferation and apoptosis seems to be an important step in malignant ET megakaryocytopoiesis.

Standard name | TARTE_PLASMA_CELL_VS_PLASMABLAST_DN
Systematic name | M19745
Organism | Homo sapiens
PMID | 12663452
Authors | Tarte K,Zhan F,De Vos J,Klein B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mature plasma cells compared with plasmablastic B lymphocytes.
Full description | Plasma cells (PCs), the end point of B-cell differentiation, are a heterogeneous cell compartment comprising several cell subsets from short-lived highly proliferative plasmablasts to long-lived nondividing fully mature PCs. Whereas the major transcription factors driving the differentiation of B cells to PCs were recently identified, the subtle genetic changes that underlie the transition from plasmablasts to mature PCs are poorly understood. We recently described an in vitro model making it possible to obtain a large number of cells with the morphologic, phenotypic, and functional characteristics of normal polyclonal plasmablastic cells (PPCs). Using Affymetrix microarrays we compared the gene expression profiles of these PPCs with those of mature PCs isolated from tonsils (TPCs) and bone marrow (BMPCs), and with those of B cells purified from peripheral blood (PBB cells) and tonsils (TBCs). Unsupervised principal component analysis clearly distinguished the 5 cell populations on the basis of their differentiation and proliferation status. Detailed statistical analysis allowed the identification of 85 PC genes and 40 B-cell genes, overexpressed, respectively, in the 3 PC subsets or in the 2 B-cell subsets. In addition, several signaling molecules and antiapoptotic proteins were found to be induced in BMPCs compared with PPCs and could be involved in the accumulation and prolonged survival of BMPCs in close contact with specialized stromal microenvironment. These data should help to better understand the molecular events that regulate commitment to a PC fate, mediate PC maintenance in survival niches, and could facilitate PC immortalization in plasma cell dyscrasias.

Standard name | SMITH_LIVER_CANCER
Systematic name | M18761
Organism | Homo sapiens
PMID | 12591738
Authors | Smith MW,Yue ZN,Geiss GK,Sadovnikova NY,Carter VS,Boix L,Lazaro CA,Rosenberg GB,Bumgarner RE,Fausto N,Bruix J,Katze MG
Category | C2
Sub-category | CGP
Brief description | Potential marker genes specifically up-regulated in the majority of hepatocellular carcinoma (HCC) tumors.
Full description | Hepatocellular carcinoma (HCC) is a common primary cancer associated frequently with hepatitis C virus (HCV). To gain insight into the molecular mechanisms of hepatocarcinogenesis, and to identify potential HCC markers, we performed cDNA microarray analysis on surgical liver samples from 20 HCV-infected patients. RNA from individual tumors was compared with RNA isolated from adjacent nontumor tissue that was cirrhotic in all of the cases. Gene expression changes related to cirrhosis were filtered out using experiments in which pooled RNA from HCV-infected cirrhotic liver without tumors was compared with pooled RNA from normal liver. Expression of approximately 13,600 genes was analyzed using the advanced analysis tools of the Rosetta Resolver System. This analysis revealed a set of 50 potential HCC marker genes, which were up-regulated in the majority of the tumors analyzed, much more widely than common clinical markers such as cell proliferation-related genes. This HCC marker set contained several cancer-related genes, including serine/threonine kinase 15 (STK15), which has been implicated in chromosome segregation abnormalities but which has not been linked previously with liver cancer. In addition, a set of genes encoding secreted or plasma proteins was identified, including plasma glutamate carboxypeptidase (PGCP) and two secreted phospholipases A2 (PLA2G13 and PLA2G7). These genes may provide potential HCC serological markers because of their strong up-regulation in more than half of the tumors analyzed. Thus, high throughput methods coupled with high-order statistical analyses may result in the development of new diagnostic tools for liver malignancies.

Standard name | JECHLINGER_EPITHELIAL_TO_MESENCHYMAL_TRANSITION_DN
Systematic name | M1417
Organism | Mus musculus
PMID | 14562044
Authors | Jechlinger M,Grunert S,Tamir IH,Janda E,Lüdemann S,Waerner T,Seither P,Weith A,Beug H,Kraut N
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during epithelial to mesenchymal transition (EMT) induced by TGFB1 [GeneID=7040] in the EpH4 cells (mammary epithelium cell line transformed by HRAS [GeneID=3265]).
Full description | Epithelial-to-mesenchymal transition (EMT), a switch of polarized epithelial cells to a migratory, fibroblastoid phenotype, is increasingly considered as an important event during malignant tumor progression and metastasis. To identify molecular players involved in EMT and metastasis, we performed expression profiling of a set of combined in vitro/in vivo cellular models, based on clonal, fully polarized mammary epithelial cells. Seven closely related cell pairs were used, which were modified by defined oncogenes and/or external factors and showed specific aspects of epithelial plasticity relevant to cell migration, local invasion and metastasis. Since mRNA levels do not necessarily reflect protein levels in cells, we used an improved expression profiling method based on polysome-bound RNA, suitable to analyse global gene expression on Affymetrix chips. A substantial fraction of all regulated genes was found to be exclusively controlled at the translational level. Furthermore, profiling of the above multiple cell pairs allowed one to identify small numbers of genes by cluster analysis, specifically correlating gene expression with EMT, metastasis, scattering and/or oncogene function. A small set of genes specifically regulated during EMT was identified, including key regulators and signaling pathways involved in cell proliferation, epithelial polarity, survival and trans-differentiation to mesenchymal-like cells with invasive behavior.

Standard name | ROSS_AML_WITH_MLL_FUSIONS
Systematic name | M454
Organism | Homo sapiens
PMID | 15226186
Authors | Ross ME,Mahfouz R,Onciu M,Liu HC,Zhou X,Song G,Shurtleff SA,Pounds S,Cheng C,Ma J,Ribeiro RC,Rubnitz JE,Girtman K,Williams WK,Raimondi SC,Liang DC,Shih LY,Pui CH,Downing JR
Category | C2
Sub-category | CGP
Brief description | Top 100 probe sets for pediatric acute myeloid leukemia (AML) subtypes with chimeric MLL fusions [GeneID=4297].
Full description | Contemporary treatment of pediatric acute myeloid leukemia (AML) requires the assignment of patients to specific risk groups. To explore whether expression profiling of leukemic blasts could accurately distinguish between the known risk groups of AML, we analyzed 130 pediatric and 20 adult AML diagnostic bone marrow or peripheral blood samples using the Affymetrix U133A microarray. Class discriminating genes were identified for each of the major prognostic subtypes of pediatric AML, including t(15;17)[PML-RARalpha], t(8;21)[AML1-ETO], inv(16) [CBFbeta-MYH11], MLL chimeric fusion genes, and cases classified as FAB-M7. When subsets of these genes were used in supervised learning algorithms, an overall classification accuracy of more than 93% was achieved. Moreover, we were able to use the expression signatures generated from the pediatric samples to accurately classify adult de novo AMLs with the same genetic lesions. The class discriminating genes also provided novel insights into the molecular pathobiology of these leukemias. Finally, using a combined pediatric data set of 130 AMLs and 137 acute lymphoblastic leukemias, we identified an expression signature for cases with MLL chimeric fusion genes irrespective of lineage. Surprisingly, AMLs containing partial tandem duplications of MLL failed to cluster with MLL chimeric fusion gene cases, suggesting a significant difference in their underlying mechanism of transformation.

Standard name | GRANDVAUX_IRF3_TARGETS_UP
Systematic name | M5133
Organism | Homo sapiens
PMID | 11991981
Authors | Grandvaux N,Servant MJ,tenOever B,Sen GC,Balachandran S,Barber GN,Lin R,Hiscott J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Jurkat cells (T lymphocyte) by expression of a constitutively active form of IRF3 [GeneID=3661].
Full description | Ubiquitously expressed interferon regulatory factor 3 (IRF-3) is directly activated after virus infection and functions as a key activator of the immediate-early alpha/beta interferon (IFN) genes, as well as the RANTES chemokine gene. In the present study, a tetracycline-inducible expression system expressing a constitutively active form of IRF-3 (IRF-3 5D) was combined with DNA microarray analysis to identify target genes regulated by IRF-3. Changes in mRNA expression profiles of 8,556 genes were monitored after Tet-inducible expression of IRF-3 5D. Among the genes upregulated by IRF-3 were transcripts for several known IFN-stimulated genes (ISGs). Subsequent analysis revealed that IRF-3 directly induced the expression of ISG56 in an IFN-independent manner through the IFN-stimulated responsive elements (ISREs) of the ISG56 promoter. These results demonstrate that, in addition to its role in the formation of a functional immediate-early IFN-beta enhanceosome, IRF-3 is able to discriminate among ISRE-containing genes involved in the establishment of the antiviral state as a direct response to virus infection.

Standard name | LEE_LIVER_CANCER_MYC_E2F1_UP
Systematic name | M4420
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) from MYC and E2F1 [GeneID=4609;1869] double transgenic mice.
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | ASTON_MAJOR_DEPRESSIVE_DISORDER_UP
Systematic name | M25
Organism | Homo sapiens
PMID | 15303102
Authors | Aston C,Jiang L,Sokolov BP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the temporal cortex samples from patients with major depressive disorder.
Full description | Major depressive disorder is one of the most common and devastating psychiatric disorders. To identify candidate mechanisms for major depressive disorder, we compared gene expression in the temporal cortex from 12 patients with major depressive disorder and 14 matched controls using Affymetrix HgU95A microarrays. Significant expression changes were revealed in families of genes involved in neurodevelopment, signal transduction and cell communication. Among these, the expression of 17 genes related to oligodendrocyte function was significantly (P < 0.05, fold change > 1.4) decreased in patients with major depressive disorder. Eight of these 17 genes encode structural components of myelin (CNP, MAG, MAL, MOG, MOBP, PMP22, PLLP, PLP1). Five other genes encode enzymes involved in the synthesis of myelin constituents (ASPA, UGT8), or are essential in regulation of myelin formation (ENPP2, EDG2, TF, KLK6). One gene, that is, SOX10, encodes a transcription factor regulating other myelination-related genes. OLIG2 is a transcription factor present exclusively in oligodendrocytes and oligodendrocyte precursors. Another gene, ERBB3, is involved in oligodendrocyte differentiation. In addition to myelination-related genes, there were significant changes in multiple genes involved in axonal growth/synaptic function. These findings suggest that major depressive disorder may be associated with changes in cell communication and signal transduction mechanisms that contribute to abnormalities in oligodendroglia and synaptic function. Taken together with other studies, these findings indicate that major depressive disorder may share common oligodendroglial abnormalities with schizophrenia and bipolar disorder.

Standard name | LE_EGR2_TARGETS_UP
Systematic name | M12804
Organism | Mus musculus
PMID | 15695336
Authors | Le N,Nagarajan R,Wang JY,Araki T,Schmidt RE,Milbrandt J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in P14 nerves of transgenic mice having hypomorhic (reduced function) allele of EGR2 [GeneID=1959].
Full description | Egr2 is a transcription factor required for peripheral nerve myelination in rodents, and mutations in Egr2 are associated with congenital hypomyelinating neuropathy (CHN) in humans. To further study its role in myelination, we generated mice harboring a hypomorphic Egr2 allele (Egr2Lo) that survive for up to 3 weeks postnatally, a period of active myelination in rodents. These Egr2Lo/Lo mice provided the opportunity to study the molecular effects of Egr2 deficiency on Schwann cell biology, an analysis that was not possible previously, because of the perinatal lethality of Egr2-null mice. Egr2Lo/Lo mice phenocopy CHN, as evidenced by the severe hypomyelination and increased numbers of proliferating Schwann cells of the peripheral nerves. Comparison of sciatic nerve gene expression profiles during development and after crush injury with those of Egr2Lo/Lo Schwann cells revealed that they are developmentally arrested, with down-regulation of myelination-related genes and up-regulation of genes associated with immature and promyelinating Schwann cells. One of the abnormally elevated genes in Egr2Lo/Lo Schwann cells, Sox2, encodes a transcription factor that is crucial for maintenance of neural stem cell pluripotency. Wild-type Schwann cells infected with Sox2 adenovirus or lentivirus inhibited expression of myelination-associated genes (e.g., myelin protein zero; Mpz), and failed to myelinate axons in vitro, but had an enhanced proliferative response to beta-neuregulin. The characterization of a mouse model of CHN has provided insight into Schwann cell differentiation and allowed the identification of Sox2 as a negative regulator of myelination.

Standard name | FERNANDEZ_BOUND_BY_MYC
Systematic name | M3456
Organism | Homo sapiens
PMID | 12695333
Authors | Fernandez PC,Frank SR,Wang L,Schroeder M,Liu S,Greene J,Cocito A,Amati B
Category | C2
Sub-category | CGP
Brief description | Genes identified by ChIP within the high-affinity group of MYC [GeneID=4609] targets.
Full description | The transcription factor Myc is induced by mitogenic signals and regulates downstream cellular responses. If overexpressed, Myc promotes malignant transformation. Myc modulates expression of diverse genes in experimental systems, but few are proven direct targets. Here, we present a large-scale screen for genomic Myc-binding sites in live human cells. We used bioinformatics to select consensus DNA elements (CACGTG or E-boxes) situated in the 5' regulatory region of genes and measured Myc binding to those sequences in vivo by quantitative chromatin immunoprecipitation. Strikingly, most promoter-associated E-boxes showed selective recovery with Myc, unlike non-E-box promoters or E-boxes in bulk genomic DNA. Promoter E-boxes were distributed in two groups bound by Myc at distinct frequencies. The high-affinity group included an estimated 11% of all cellular loci, was highly conserved among different cells, and was bound independently of Myc expression levels. Overexpressed Myc associated at increased frequency with low-affinity targets and, at extreme levels, also with other sequences, suggesting that some binding was not sequence-specific. The strongest DNA-sequence parameter defining high-affinity targets was the location of E-boxes within CpG islands, correlating with an open, preacetylated state of chromatin. Myc further enhanced histone acetylation, with or without accompanying induction of mRNA expression. Our findings point to a high regulatory and biological diversity among Myc-target genes.

Standard name | FLECHNER_PBL_KIDNEY_TRANSPLANT_OK_VS_DONOR_UP
Systematic name | M19681
Organism | Homo sapiens
PMID | 15307835
Authors | Flechner SM,Kurian SM,Head SR,Sharp SM,Whisenant TC,Zhang J,Chismar JD,Horvath S,Mondala T,Gilmartin T,Cook DJ,Kay SA,Walker JR,Salomon DR
Category | C2
Sub-category | CGP
Brief description | Genes upregulated in peripheral blood lymphocytes (PBL) from patients with well functioning kidneys more than 1-year post transplant compared to those from normal living kidney donors.
Full description | A major challenge for kidney transplantation is balancing the need for immunosuppression to prevent rejection, while minimizing drug-induced toxicities. We used DNA microarrays (HG-U95Av2 GeneChips, Affymetrix) to determine gene expression profiles for kidney biopsies and peripheral blood lymphocytes (PBLs) in transplant patients including normal donor kidneys, well-functioning transplants without rejection, kidneys undergoing acute rejection, and transplants with renal dysfunction without rejection. We developed a data analysis schema based on expression signal determination, class comparison and prediction, hierarchical clustering, statistical power analysis and real-time quantitative PCR validation. We identified distinct gene expression signatures for both biopsies and PBLs that correlated significantly with each of the different classes of transplant patients. This is the most complete report to date using commercial arrays to identify unique expression signatures in transplant biopsies distinguishing acute rejection, acute dysfunction without rejection and well-functioning transplants with no rejection history. We demonstrate for the first time the successful application of high density DNA chip analysis of PBL as a diagnostic tool for transplantation. The significance of these results, if validated in a multicenter prospective trial, would be the establishment of a metric based on gene expression signatures for monitoring the immune status and immunosuppression of transplanted patients.

Standard name | ROSS_AML_OF_FAB_M7_TYPE
Systematic name | M4621
Organism | Homo sapiens
PMID | 15226186
Authors | Ross ME,Mahfouz R,Onciu M,Liu HC,Zhou X,Song G,Shurtleff SA,Pounds S,Cheng C,Ma J,Ribeiro RC,Rubnitz JE,Girtman K,Williams WK,Raimondi SC,Liang DC,Shih LY,Pui CH,Downing JR
Category | C2
Sub-category | CGP
Brief description | Top 100 probe sets for pediatric acute myeloid leukemia (AML) subtype FAB M7 (also known as acute megakaryoblastic leukemia, AMKL).
Full description | Contemporary treatment of pediatric acute myeloid leukemia (AML) requires the assignment of patients to specific risk groups. To explore whether expression profiling of leukemic blasts could accurately distinguish between the known risk groups of AML, we analyzed 130 pediatric and 20 adult AML diagnostic bone marrow or peripheral blood samples using the Affymetrix U133A microarray. Class discriminating genes were identified for each of the major prognostic subtypes of pediatric AML, including t(15;17)[PML-RARalpha], t(8;21)[AML1-ETO], inv(16) [CBFbeta-MYH11], MLL chimeric fusion genes, and cases classified as FAB-M7. When subsets of these genes were used in supervised learning algorithms, an overall classification accuracy of more than 93% was achieved. Moreover, we were able to use the expression signatures generated from the pediatric samples to accurately classify adult de novo AMLs with the same genetic lesions. The class discriminating genes also provided novel insights into the molecular pathobiology of these leukemias. Finally, using a combined pediatric data set of 130 AMLs and 137 acute lymphoblastic leukemias, we identified an expression signature for cases with MLL chimeric fusion genes irrespective of lineage. Surprisingly, AMLs containing partial tandem duplications of MLL failed to cluster with MLL chimeric fusion gene cases, suggesting a significant difference in their underlying mechanism of transformation.

Standard name | MOOTHA_VOXPHOS
Systematic name | M18264
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Genes involved in oxidative phosphorylation; based on literature and sequence annotation resources and converted to Affymetrix HG-U133A probe sets.
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | FLECHNER_PBL_KIDNEY_TRANSPLANT_REJECTED_VS_OK_DN
Systematic name | M3682
Organism | Homo sapiens
PMID | 15307835
Authors | Flechner SM,Kurian SM,Head SR,Sharp SM,Whisenant TC,Zhang J,Chismar JD,Horvath S,Mondala T,Gilmartin T,Cook DJ,Kay SA,Walker JR,Salomon DR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in peripheral blood lymphocytes (PBL) from patients with acute transplant rejection compared to those from patients with well functioning kidneys more than 1-year post transplant.
Full description | A major challenge for kidney transplantation is balancing the need for immunosuppression to prevent rejection, while minimizing drug-induced toxicities. We used DNA microarrays (HG-U95Av2 GeneChips, Affymetrix) to determine gene expression profiles for kidney biopsies and peripheral blood lymphocytes (PBLs) in transplant patients including normal donor kidneys, well-functioning transplants without rejection, kidneys undergoing acute rejection, and transplants with renal dysfunction without rejection. We developed a data analysis schema based on expression signal determination, class comparison and prediction, hierarchical clustering, statistical power analysis and real-time quantitative PCR validation. We identified distinct gene expression signatures for both biopsies and PBLs that correlated significantly with each of the different classes of transplant patients. This is the most complete report to date using commercial arrays to identify unique expression signatures in transplant biopsies distinguishing acute rejection, acute dysfunction without rejection and well-functioning transplants with no rejection history. We demonstrate for the first time the successful application of high density DNA chip analysis of PBL as a diagnostic tool for transplantation. The significance of these results, if validated in a multicenter prospective trial, would be the establishment of a metric based on gene expression signatures for monitoring the immune status and immunosuppression of transplanted patients.

Standard name | DER_IFN_GAMMA_RESPONSE_DN
Systematic name | M8478
Organism | Homo sapiens
PMID | 9861020
Authors | Der SD,Zhou A,Williams BR,Silverman RH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HT1080 (fibrosarcoma) cells by treatment with interferon gamma for 6 h.
Full description | The pleiotropic activities of interferons (IFNs) are mediated primarily through the transcriptional regulation of many downstream effector genes. The mRNA profiles from IFN-alpha, -beta, or -gamma treatments of the human fibrosarcoma cell line, HT1080, were determined by using oligonucleotide arrays with probe sets corresponding to more than 6,800 human genes. Among these were transcripts for known IFN-stimulated genes (ISGs), the expression of which were consistent with previous studies in which the particular ISG was characterized as responsive to either Type I (alpha, beta) or Type II (gamma) IFNs, or both. Importantly, many novel IFN-stimulated genes were identified that were diverse in their known biological functions. For instance, several novel ISGs were identified that are implicated in apoptosis (including RAP46/Bag-1, phospholipid scramblase, and hypoxia inducible factor-1alpha). Furthermore, several IFN-repressed genes also were identified. These results demonstrate the usefulness of oligonucleotide arrays in monitoring mammalian gene expression on a broad and unprecedented scale. In particular, these findings provide insights into the basic mechanisms of IFN actions and ultimately may contribute to better therapeutic uses for IFNs.

Standard name | SANA_RESPONSE_TO_IFNG_UP
Systematic name | M4551
Organism | Homo sapiens
PMID | 15749026
Authors | Sana TR,Janatpour MJ,Sathe M,McEvoy LM,McClanahan TK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in five primary endothelial cell types (lung, aortic, iliac, dermal, and colon) by IFNG [GeneID=3458].
Full description | To investigate the potential molecular mediators of tissue-specific recruitment, we explored the influence of different cytokine challenges on gene expression regulation in five primary endothelial cells (ECs), representing two different phenotypes: iliac artery and aortic (macrovascular); lung, colon and dermal (microvascular). We challenged ECs with cytokines that elicit different patterns of inflammatory and immune responses in immune cells: tumor necrosis factor (TNF-alpha), interferon-gamma (IFN-gamma) or interleukin-4 (IL-4), and used microarrays containing approximately 40,000 unique cDNAs, to assess changes in differential gene expression relative to untreated cells. Five hundred and sixty three sequences changed by at least 2.5 fold in one or more of the 15 possible EC /cytokine combinations. The list included highly regulated adhesion molecules, chemokines, cytokines, metalloproteases, and IFN-gamma-induced genes. Overall, IFN-gamma caused the largest number of gene expression changes and its profile was least correlated with IL-4. In addition to clusters that were predominantly EC/cytokine specific, we also observed several clusters that were regulated by more than one cytokine across several ECs. Furthermore, we identified genes that were reciprocally expressed in response to different cytokines that could serve as markers of inflammatory and immune expression. These results confirm the importance of microenvironment in primary ECs that could have important applications in developing targeted therapies for vascular diseases.

Standard name | SANA_TNF_SIGNALING_UP
Systematic name | M17466
Organism | Homo sapiens
PMID | 15749026
Authors | Sana TR,Janatpour MJ,Sathe M,McEvoy LM,McClanahan TK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in five primary endothelial cell types (lung, aortic, iliac, dermal, and colon) by TNF [GeneID=7124].
Full description | To investigate the potential molecular mediators of tissue-specific recruitment, we explored the influence of different cytokine challenges on gene expression regulation in five primary endothelial cells (ECs), representing two different phenotypes: iliac artery and aortic (macrovascular); lung, colon and dermal (microvascular). We challenged ECs with cytokines that elicit different patterns of inflammatory and immune responses in immune cells: tumor necrosis factor (TNF-alpha), interferon-gamma (IFN-gamma) or interleukin-4 (IL-4), and used microarrays containing approximately 40,000 unique cDNAs, to assess changes in differential gene expression relative to untreated cells. Five hundred and sixty three sequences changed by at least 2.5 fold in one or more of the 15 possible EC /cytokine combinations. The list included highly regulated adhesion molecules, chemokines, cytokines, metalloproteases, and IFN-gamma-induced genes. Overall, IFN-gamma caused the largest number of gene expression changes and its profile was least correlated with IL-4. In addition to clusters that were predominantly EC/cytokine specific, we also observed several clusters that were regulated by more than one cytokine across several ECs. Furthermore, we identified genes that were reciprocally expressed in response to different cytokines that could serve as markers of inflammatory and immune expression. These results confirm the importance of microenvironment in primary ECs that could have important applications in developing targeted therapies for vascular diseases.

Standard name | POMEROY_MEDULLOBLASTOMA_PROGNOSIS_UP
Systematic name | M18328
Organism | Homo sapiens
PMID | 11807556
Authors | Pomeroy SL,Tamayo P,Gaasenbeek M,Sturla LM,Angelo M,McLaughlin ME,Kim JY,Goumnerova LC,Black PM,Lau C,Allen JC,Zagzag D,Olson JM,Curran T,Wetmore C,Biegel JA,Poggio T,Mukherjee S,Rifkin R,Califano A,Stolovitzky G,Louis DN,Mesirov JP,Lander ES,Golub TR
Category | C2
Sub-category | CGP
Brief description | Top marker genes in medulloblastoma associated with good response to treatment (good outcome).
Full description | Embryonal tumours of the central nervous system (CNS) represent a heterogeneous group of tumours about which little is known biologically, and whose diagnosis, on the basis of morphologic appearance alone, is controversial. Medulloblastomas, for example, are the most common malignant brain tumour of childhood, but their pathogenesis is unknown, their relationship to other embryonal CNS tumours is debated, and patients' response to therapy is difficult to predict. We approached these problems by developing a classification system based on DNA microarray gene expression data derived from 99 patient samples. Here we demonstrate that medulloblastomas are molecularly distinct from other brain tumours including primitive neuroectodermal tumours (PNETs), atypical teratoid/rhabdoid tumours (AT/RTs) and malignant gliomas. Previously unrecognized evidence supporting the derivation of medulloblastomas from cerebellar granule cells through activation of the Sonic Hedgehog (SHH) pathway was also revealed. We show further that the clinical outcome of children with medulloblastomas is highly predictable on the basis of the gene expression profiles of their tumours at diagnosis.

Standard name | SCHUHMACHER_MYC_TARGETS_UP
Systematic name | M12243
Organism | Homo sapiens
PMID | 11139609
Authors | Schuhmacher M,Kohlhuber F,Hölzel M,Kaiser C,Burtscher H,Jarsch M,Bornkamm GW,Laux G,Polack A,Weidle UH,Eick D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in P493-6 cells (Burkitt's lymphoma) induced to express MYC [GeneID=4609].
Full description | The proto-oncogene c-myc (myc) encodes a transcription factor (Myc) that promotes growth, proliferation and apoptosis. Myc has been suggested to induce these effects by induction/repression of downstream genes. Here we report the identification of potential Myc target genes in a human B cell line that grows and proliferates depending on conditional myc expression. Oligonucleotide microarrays were applied to identify downstream genes of Myc at the level of cytoplasmic mRNA. In addition, we identified potential Myc target genes in nuclear run-on experiments by changes in their transcription rate. The identified genes belong to gene classes whose products are involved in amino acid/protein synthesis, lipid metabolism, protein turnover/folding, nucleotide/DNA synthesis, transport, nucleolus function/RNA binding, transcription and splicing, oxidative stress and signal transduction. The identified targets support our current view that myc acts as a master gene for growth control and increases transcription of a large variety of genes.

Standard name | SWEET_KRAS_TARGETS_UP
Systematic name | M2448
Organism | Homo sapiens
PMID | 15608639
Authors | Sweet-Cordero A,Mukherjee S,Subramanian A,You H,Roix JJ,Ladd-Acosta C,Mesirov J,Golub TR,Jacks T
Category | C2
Sub-category | CGP
Brief description | Genes upregulated in KRAS [GeneID=3845] knockdown vs control in a human cell line.
Full description | Using advanced gene targeting methods, generating mouse models of cancer that accurately reproduce the genetic alterations present in human tumors is now relatively straightforward. The challenge is to determine to what extent such models faithfully mimic human disease with respect to the underlying molecular mechanisms that accompany tumor progression. Here we describe a method for comparing mouse models of cancer with human tumors using gene-expression profiling. We applied this method to the analysis of a model of Kras2-mediated lung cancer and found a good relationship to human lung adenocarcinoma, thereby validating the model. Furthermore, we found that whereas a gene-expression signature of KRAS2 activation was not identifiable when analyzing human tumors with known KRAS2 mutation status alone, integrating mouse and human data uncovered a gene-expression signature of KRAS2 mutation in human lung cancer. We confirmed the importance of this signature by gene-expression analysis of short hairpin RNA-mediated inhibition of oncogenic Kras2. These experiments identified both a pattern of gene expression indicative of KRAS2 mutation and potential effectors of oncogenic KRAS2 activity in human cancer. This approach provides a strategy for using genomic analysis of animal models to probe human disease.

Standard name | CHEOK_RESPONSE_TO_HD_MTX_UP
Systematic name | M114
Organism | Homo sapiens
PMID | 12704389
Authors | Cheok MH,Yang W,Pui CH,Downing JR,Cheng C,Naeve CW,Relling MV,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes specifically up-regulated in pediatric acute lymphoblastic leukemia (ALL) patients by high-dose methotrexate (HDMTX) [PubChem=4112].
Full description | To elucidate the genomics of cellular responses to cancer treatment, we analyzed the expression of over 9,600 human genes in acute lymphoblastic leukemia cells before and after in vivo treatment with methotrexate and mercaptopurine given alone or in combination. Based on changes in gene expression, we identified 124 genes that accurately discriminated among the four treatments. Discriminating genes included those involved in apoptosis, mismatch repair, cell cycle control and stress response. Only 14% of genes that changed when these medications were given as single agents also changed when they were given together. These data indicate that lymphoid leukemia cells of different molecular subtypes share common pathways of genomic response to the same treatment, that changes in gene expression are treatment-specific and that gene expression can illuminate differences in cellular response to drug combinations versus single agents.

Standard name | MAGRANGEAS_MULTIPLE_MYELOMA_IGG_VS_IGA_UP
Systematic name | M1419
Organism | Homo sapiens
PMID | 12623842
Authors | Magrangeas F,Nasser V,Avet-Loiseau H,Loriod B,Decaux O,Granjeaud S,Bertucci F,Birnbaum D,Nguyen C,Harousseau JL,Bataille R,Houlgatte R,Minvielle S
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes discriminating multiple myeloma samples by type of immunoglobulin they produce: IgG vs IgA.
Full description | Although multiple myeloma (MM) is a unique entity, a marked heterogeneity is actually observed among the patients, which has been first related to immunoglobulin (Ig) types and light chain subtypes and more recently to chromosomal abnormalities. To further investigate this genetic heterogeneity, we analyzed gene expression profiles of 92 primary tumors according to their Ig types and light chain subtypes with DNA microarrays. Several clusters of genes involved in various biologic functions such as immune response, cell cycle control, signaling, apoptosis, cell adhesion, and structure significantly discriminated IgA- from IgG-MM. Genes associated with inhibition of differentiation and apoptosis induction were up-regulated while genes associated with immune response, cell cycle control, and apoptosis were down-regulated in IgA-MM. According to the expression of the 61 most discriminating genes, BJ-MM represented a separate subgroup that did not express either the genes characteristic of IgG-MM or those of IgA-MM at a high level. This suggests that transcriptional programs associated to the switch could be maintained up to plasma cell differentiation. Several genes whose products are known to stimulate bone remodeling discriminate between kappa- and lambda-MM. One of these genes, Mip-1alpha, was overexpressed in the kappa subgroup. In addition, we established a strong association (P =.0001) between kappa subgroup expressing high levels of Mip-1alpha and active myeloma bone disease. This study shows that DNA microarrays enable us to perform a molecular dissection of the bioclinical diversity of MM and provide new molecular tools to investigate the pathogenesis of malignant plasma cells.

Standard name | OKUMURA_INFLAMMATORY_RESPONSE_LPS
Systematic name | M1911
Organism | Homo sapiens
PMID | 12855579
Authors | Okumura S,Kashiwakura J,Tomita H,Matsumoto K,Nakajima T,Saito H,Okayama Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mast cells (MC) after stimulation with a bacterial lipopolysaccharide (LPS).
Full description | Rodent mast cells (MCs) are reported to play a pivotal role in both innate and adaptive immunity. However, there is so far no evidence that human MCs are involved in innate immunity. We found that a functional Toll-like receptor 4 (TLR4) was expressed on human MCs when it was up-regulated by interferon gamma (IFN-gamma). To systematically explore how human MCs modulate the immune system following TLR4-mediated activation and FcepsilonRI aggregation, we used high-density oligonucleotide probe arrays (GeneChip) to compare the lipopolysaccharide (LPS)-induced gene expression profile with the IgE/anti-IgE-mediated profile in MCs. Both a shared core response, and LPS- or anti-IgE-specific programs of gene expression were observed in MCs. Furthermore, MCs exhibited an antiviral response gene program in response to IFN-gamma, and LPS sustained that expression. Compared with the LPS-stimulated gene expression profile of human peripheral blood mononuclear cells, LPS-stimulated MCs specifically induced a subset of genes that included a Th2 cytokine and chemokines that recruit Th2 cells and eosinophils. These results reveal that human MCs express tailored pathogen- and antigen-specific immune responses and that human MCs may play important roles in innate and adaptive immunity.

Standard name | SMITH_TERT_TARGETS_DN
Systematic name | M1217
Organism | Homo sapiens
PMID | 12717449
Authors | Smith LL,Coller HA,Roberts JM
Category | C2
Sub-category | CGP
Brief description | Genes consistently down-regulated in HMEC cells (primary mammary epithelium) upon expression of TERT [GeneID=7015] off a retroviral vector.
Full description | Most somatic cells do not express sufficient amounts of telomerase to maintain a constant telomere length during cycles of chromosome replication. Consequently, there is a limit to the number of doublings somatic cells can undergo before telomere shortening triggers an irreversible state of cellular senescence. Ectopic expression of telomerase overcomes this limitation, and in conjunction with specific oncogenes can transform cells to a tumorigenic phenotype. However, recent studies have questioned whether the stabilization of chromosome ends entirely explains the ability of telomerase to promote tumorigenesis and have resulted in the hypothesis that telomerase has a second function that also supports cell division. Here we show that ectopic expression of telomerase in human mammary epithelial cells (HMECs) results in a diminished requirement for exogenous mitogens and that this correlates with telomerase-dependent induction of genes that promote cell growth. Furthermore, we show that inhibiting expression of one of these genes, the epidermal growth factor receptor (EGFR), reverses the enhanced proliferation caused by telomerase. We conclude that telomerase may affect proliferation of epithelial cells not only by stabilizing telomeres, but also by affecting the expression of growth-promoting genes.

Standard name | SHIPP_DLBCL_VS_FOLLICULAR_LYMPHOMA_DN
Systematic name | M8813
Organism | Homo sapiens
PMID | 11786909
Authors | Shipp MA,Ross KN,Tamayo P,Weng AP,Kutok JL,Aguiar RC,Gaasenbeek M,Angelo M,Reich M,Pinkus GS,Ray TS,Koval MA,Last KW,Norton A,Lister TA,Mesirov J,Neuberg DS,Lander ES,Aster JC,Golub TR
Category | C2
Sub-category | CGP
Brief description | Top 50 down-regulated markers distinguishing diffuse large B-cell lymphoma (DLBCL) from follicular lymphoma (FL) samples.
Full description | Diffuse large B-cell lymphoma (DLBCL), the most common lymphoid malignancy in adults, is curable in less than 50% of patients. Prognostic models based on pre-treatment characteristics, such as the International Prognostic Index (IPI), are currently used to predict outcome in DLBCL. However, clinical outcome models identify neither the molecular basis of clinical heterogeneity, nor specific therapeutic targets. We analyzed the expression of 6,817 genes in diagnostic tumor specimens from DLBCL patients who received cyclophosphamide, adriamycin, vincristine and prednisone (CHOP)-based chemotherapy, and applied a supervised learning prediction method to identify cured versus fatal or refractory disease. The algorithm classified two categories of patients with very different five-year overall survival rates (70% versus 12%). The model also effectively delineated patients within specific IPI risk categories who were likely to be cured or to die of their disease. Genes implicated in DLBCL outcome included some that regulate responses to B-cell-receptor signaling, critical serine/threonine phosphorylation pathways and apoptosis. Our data indicate that supervised learning classification techniques can predict outcome in DLBCL and identify rational targets for intervention.

Standard name | LEE_LIVER_CANCER_DENA_DN
Systematic name | M1424
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma (HCC) induced by diethylnitrosamine (DENA) [PubChem=5921].
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | SANA_RESPONSE_TO_IFNG_DN
Systematic name | M9583
Organism | Homo sapiens
PMID | 15749026
Authors | Sana TR,Janatpour MJ,Sathe M,McEvoy LM,McClanahan TK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in five primary endothelial cell types (lung, aortic, iliac, dermal, and colon) by IFNG [GeneID=3458].
Full description | To investigate the potential molecular mediators of tissue-specific recruitment, we explored the influence of different cytokine challenges on gene expression regulation in five primary endothelial cells (ECs), representing two different phenotypes: iliac artery and aortic (macrovascular); lung, colon and dermal (microvascular). We challenged ECs with cytokines that elicit different patterns of inflammatory and immune responses in immune cells: tumor necrosis factor (TNF-alpha), interferon-gamma (IFN-gamma) or interleukin-4 (IL-4), and used microarrays containing approximately 40,000 unique cDNAs, to assess changes in differential gene expression relative to untreated cells. Five hundred and sixty three sequences changed by at least 2.5 fold in one or more of the 15 possible EC /cytokine combinations. The list included highly regulated adhesion molecules, chemokines, cytokines, metalloproteases, and IFN-gamma-induced genes. Overall, IFN-gamma caused the largest number of gene expression changes and its profile was least correlated with IL-4. In addition to clusters that were predominantly EC/cytokine specific, we also observed several clusters that were regulated by more than one cytokine across several ECs. Furthermore, we identified genes that were reciprocally expressed in response to different cytokines that could serve as markers of inflammatory and immune expression. These results confirm the importance of microenvironment in primary ECs that could have important applications in developing targeted therapies for vascular diseases.

Standard name | CHEOK_RESPONSE_TO_MERCAPTOPURINE_AND_LD_MTX_DN
Systematic name | M2978
Organism | Homo sapiens
PMID | 12704389
Authors | Cheok MH,Yang W,Pui CH,Downing JR,Cheng C,Naeve CW,Relling MV,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes specifically down-regulated in pediatric acute lymphoblastic leukemia (ALL) patients by mercaptopurine [PubChem=667490] and low-dose methotrexate (LDMTX) [PubChem=4112].
Full description | To elucidate the genomics of cellular responses to cancer treatment, we analyzed the expression of over 9,600 human genes in acute lymphoblastic leukemia cells before and after in vivo treatment with methotrexate and mercaptopurine given alone or in combination. Based on changes in gene expression, we identified 124 genes that accurately discriminated among the four treatments. Discriminating genes included those involved in apoptosis, mismatch repair, cell cycle control and stress response. Only 14% of genes that changed when these medications were given as single agents also changed when they were given together. These data indicate that lymphoid leukemia cells of different molecular subtypes share common pathways of genomic response to the same treatment, that changes in gene expression are treatment-specific and that gene expression can illuminate differences in cellular response to drug combinations versus single agents.

Standard name | LEE_LIVER_CANCER_MYC_DN
Systematic name | M18496
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma (HCC) induced by overexpression of MYC [GeneID=4609].
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | LEE_LIVER_CANCER_CIPROFIBRATE_UP
Systematic name | M2195
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) induced by ciprofibrate [PubChem=2763].
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | IIZUKA_LIVER_CANCER_PROGRESSION_L1_G1_UP
Systematic name | M11507
Organism | Homo sapiens
PMID | 15710396
Authors | Iizuka N,Oka M,Yamada-Okabe H,Mori N,Tamesa T,Okada T,Takemoto N,Sakamoto K,Hamada K,Ishitsuka H,Miyamoto T,Uchimura S,Hamamoto Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during transition from L1 (non-tumor, infected with HCV) to G1 (well differentiated tumor, infected with HCV) in the development of hepatocellular carcinoma.
Full description | Using high-density oligonucleotide array, we comprehensively analyzed expression levels of 12600 genes in 50 hepatocellular carcinoma (HCC) samples with positive hepatitis C virus (HCV) serology (well (G1), moderately (G2), and poorly (G3) differentiated tumors) and 11 non-tumorous livers (L1 and L0) with and without HCV infection. We searched for discriminatory genes of transition (L0 vs. L1, L1 vs. G1, G1 vs. G2, G2 vs. G3) with a supervised learning method, and then arranged the samples by self-organizing map (SOM) with the discriminatory gene sets. The SOM arranged the five clusters on a unique sigmoidal curve in the order L0, L1, G1, G2, and G3. The sample arrangement reproduced development-related features of HCC such as p53 abnormality. Strikingly, G2 tumors without venous invasion were located closer to the G1 cluster, and most G2 tumors with venous invasion were located closer to the G3 cluster (P=0.001 by Fisher's exact test). Our present profiling data will serve as a framework to understand the relation between the development and dedifferentiation of HCC.

Standard name | POMEROY_MEDULLOBLASTOMA_PROGNOSIS_DN
Systematic name | M6693
Organism | Homo sapiens
PMID | 11807556
Authors | Pomeroy SL,Tamayo P,Gaasenbeek M,Sturla LM,Angelo M,McLaughlin ME,Kim JY,Goumnerova LC,Black PM,Lau C,Allen JC,Zagzag D,Olson JM,Curran T,Wetmore C,Biegel JA,Poggio T,Mukherjee S,Rifkin R,Califano A,Stolovitzky G,Louis DN,Mesirov JP,Lander ES,Golub TR
Category | C2
Sub-category | CGP
Brief description | Top marker genes in medulloblastoma associated with poor response to treatment (poor outcome).
Full description | Embryonal tumours of the central nervous system (CNS) represent a heterogeneous group of tumours about which little is known biologically, and whose diagnosis, on the basis of morphologic appearance alone, is controversial. Medulloblastomas, for example, are the most common malignant brain tumour of childhood, but their pathogenesis is unknown, their relationship to other embryonal CNS tumours is debated, and patients' response to therapy is difficult to predict. We approached these problems by developing a classification system based on DNA microarray gene expression data derived from 99 patient samples. Here we demonstrate that medulloblastomas are molecularly distinct from other brain tumours including primitive neuroectodermal tumours (PNETs), atypical teratoid/rhabdoid tumours (AT/RTs) and malignant gliomas. Previously unrecognized evidence supporting the derivation of medulloblastomas from cerebellar granule cells through activation of the Sonic Hedgehog (SHH) pathway was also revealed. We show further that the clinical outcome of children with medulloblastomas is highly predictable on the basis of the gene expression profiles of their tumours at diagnosis.

Standard name | LU_IL4_SIGNALING
Systematic name | M10558
Organism | Homo sapiens
PMID | 15591113
Authors | Lu X,Nechushtan H,Ding F,Rosado MF,Singal R,Alizadeh AA,Lossos IS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in peripheral B lymphocytes after incubation with IL4 [GeneID=3565] for 4 h.
Full description | Diffuse large B-cell lymphomas (DLBCLs) can be subclassified into germinal center B-cell (GCB)-like and activated B-cell (ABC)-like tumors characterized by long and short survival, respectively. In contrast to ABC-like DLBCL, GCB-like tumors exhibit high expression of components of the interleukin 4 (IL-4) signaling pathway and of IL-4 target genes such as BCL6 and HGAL, whose high expression independently predicts better survival. These observations suggest distinct activity of the IL-4 signaling pathway in DLBCL subtypes. Herein, we demonstrate similar IL-4 expression but qualitatively different IL-4 effects on GCB-like and ABC-like DLBCL. In GCB-like DLBCL, IL-4 induces expression of its target genes, activates signal transducers and activators of transcription 6 (STAT6) signaling, and increases cell proliferation. In contrast, in the ABC-like DLBCL, IL-4 activates AKT, decreases cell proliferation by cell cycle arrest, and does not induce gene expression due to aberrant Janus kinase (JAK)-STAT6 signaling attributed to STAT6 dephosphorylation. We found distinct expression profiles of tyrosine phosphatases in DLBCL subtypes and identified putative STAT6 tyrosine phosphatases-protein tyrosine phosphatase nonreceptor type 1 (PTPN1) and PTPN2, whose expression is significantly higher in ABC-like DLBCL. These differences in tyrosine phosphatase expression might underlie distinct expression profiles of some of the IL-4 target genes and could contribute to a different clinical outcome of patients with GCB-like and ABC-like DLBCLs.

Standard name | BYSTRYKH_HEMATOPOIESIS_STEM_CELL_QTL_TRANS
Systematic name | M2388
Organism | Mus musculus
PMID | 15711547
Authors | Bystrykh L,Weersing E,Dontje B,Sutton S,Pletcher MT,Wiltshire T,Su AI,Vellenga E,Wang J,Manly KF,Lu L,Chesler EJ,Alberts R,Jansen RC,Williams RW,Cooke MP,de Haan G
Category | C2
Sub-category | CGP
Brief description | Transcripts in hematopoietic stem cells (HSC) which are trans-regulated (i.e., modulated by a QTL (quantitative trait locus) not in a close proximity to the gene).
Full description | We combined large-scale mRNA expression analysis and gene mapping to identify genes and loci that control hematopoietic stem cell (HSC) function. We measured mRNA expression levels in purified HSCs isolated from a panel of densely genotyped recombinant inbred mouse strains. We mapped quantitative trait loci (QTLs) associated with variation in expression of thousands of transcripts. By comparing the physical transcript position with the location of the controlling QTL, we identified polymorphic cis-acting stem cell genes. We also identified multiple trans-acting control loci that modify expression of large numbers of genes. These groups of coregulated transcripts identify pathways that specify variation in stem cells. We illustrate this concept with the identification of candidate genes involved with HSC turnover. We compared expression QTLs in HSCs and brain from the same mice and identified both shared and tissue-specific QTLs. Our data are accessible through WebQTL, a web-based interface that allows custom genetic linkage analysis and identification of coregulated transcripts.

Standard name | BYSTRYKH_HEMATOPOIESIS_STEM_CELL_FLI1
Systematic name | M3254
Organism | Mus musculus
PMID | 15711547
Authors | Bystrykh L,Weersing E,Dontje B,Sutton S,Pletcher MT,Wiltshire T,Su AI,Vellenga E,Wang J,Manly KF,Lu L,Chesler EJ,Alberts R,Jansen RC,Williams RW,Cooke MP,de Haan G
Category | C2
Sub-category | CGP
Brief description | Genes whose expression is coregulated with that of FLI1 [GeneID=2313] in hematopoietic stem cells (HSC).
Full description | We combined large-scale mRNA expression analysis and gene mapping to identify genes and loci that control hematopoietic stem cell (HSC) function. We measured mRNA expression levels in purified HSCs isolated from a panel of densely genotyped recombinant inbred mouse strains. We mapped quantitative trait loci (QTLs) associated with variation in expression of thousands of transcripts. By comparing the physical transcript position with the location of the controlling QTL, we identified polymorphic cis-acting stem cell genes. We also identified multiple trans-acting control loci that modify expression of large numbers of genes. These groups of coregulated transcripts identify pathways that specify variation in stem cells. We illustrate this concept with the identification of candidate genes involved with HSC turnover. We compared expression QTLs in HSCs and brain from the same mice and identified both shared and tissue-specific QTLs. Our data are accessible through WebQTL, a web-based interface that allows custom genetic linkage analysis and identification of coregulated transcripts.

Standard name | MAGRANGEAS_MULTIPLE_MYELOMA_IGLL_VS_IGLK_DN
Systematic name | M1420
Organism | Homo sapiens
PMID | 12623842
Authors | Magrangeas F,Nasser V,Avet-Loiseau H,Loriod B,Decaux O,Granjeaud S,Bertucci F,Birnbaum D,Nguyen C,Harousseau JL,Bataille R,Houlgatte R,Minvielle S
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes discriminating multiple myeloma samples by the ype of immunoglobulin light chain they produce: Ig lambda (IGLL) vs Ig kappa (IGLK).
Full description | Although multiple myeloma (MM) is a unique entity, a marked heterogeneity is actually observed among the patients, which has been first related to immunoglobulin (Ig) types and light chain subtypes and more recently to chromosomal abnormalities. To further investigate this genetic heterogeneity, we analyzed gene expression profiles of 92 primary tumors according to their Ig types and light chain subtypes with DNA microarrays. Several clusters of genes involved in various biologic functions such as immune response, cell cycle control, signaling, apoptosis, cell adhesion, and structure significantly discriminated IgA- from IgG-MM. Genes associated with inhibition of differentiation and apoptosis induction were up-regulated while genes associated with immune response, cell cycle control, and apoptosis were down-regulated in IgA-MM. According to the expression of the 61 most discriminating genes, BJ-MM represented a separate subgroup that did not express either the genes characteristic of IgG-MM or those of IgA-MM at a high level. This suggests that transcriptional programs associated to the switch could be maintained up to plasma cell differentiation. Several genes whose products are known to stimulate bone remodeling discriminate between kappa- and lambda-MM. One of these genes, Mip-1alpha, was overexpressed in the kappa subgroup. In addition, we established a strong association (P =.0001) between kappa subgroup expressing high levels of Mip-1alpha and active myeloma bone disease. This study shows that DNA microarrays enable us to perform a molecular dissection of the bioclinical diversity of MM and provide new molecular tools to investigate the pathogenesis of malignant plasma cells.

Standard name | FERRANDO_LYL1_NEIGHBORS
Systematic name | M4175
Organism | Homo sapiens
PMID | 12086890
Authors | Ferrando AA,Neuberg DS,Staunton J,Loh ML,Huard C,Raimondi SC,Behm FG,Pui CH,Downing JR,Gilliland DG,Lander ES,Golub TR,Look AT
Category | C2
Sub-category | CGP
Brief description | Nearest neighbors of LYL1 [GeneID=4066], based on the close agreement of their expression profiles with that of LYL1 in pediatric T cell acute lymphoblastic leukemia (T-ALL).
Full description | Human T cell leukemias can arise from oncogenes activated by specific chromosomal translocations involving the T cell receptor genes. Here we show that five different T cell oncogenes (HOX11, TAL1, LYL1, LMO1, and LMO2) are often aberrantly expressed in the absence of chromosomal abnormalities. Using oligonucleotide microarrays, we identified several gene expression signatures that were indicative of leukemic arrest at specific stages of normal thymocyte development: LYL1+ signature (pro-T), HOX11+ (early cortical thymocyte), and TAL1+ (late cortical thymocyte). Hierarchical clustering analysis of gene expression signatures grouped samples according to their shared oncogenic pathways and identified HOX11L2 activation as a novel event in T cell leukemogenesis. These findings have clinical importance, since HOX11 activation is significantly associated with a favorable prognosis, while expression of TAL1, LYL1, or, surprisingly, HOX11L2 confers a much worse response to treatment. Our results illustrate the power of gene expression profiles to elucidate transformation pathways relevant to human leukemia.

Standard name | VANTVEER_BREAST_CANCER_METASTASIS_UP
Systematic name | M500
Organism | Homo sapiens
PMID | 11823860
Authors | van 't Veer LJ,Dai H,van de Vijver MJ,He YD,Hart AA,Mao M,Peterse HL,van der Kooy K,Marton MJ,Witteveen AT,Schreiber GJ,Kerkhoven RM,Roberts C,Linsley PS,Bernards R,Friend SH
Category | C2
Sub-category | CGP
Brief description | Genes whose expression is significantly and positively correlated with poor breast cancer clinical outcome (defined as developing distant metastases in less than 5 years).
Full description | Breast cancer patients with the same stage of disease can have markedly different treatment responses and overall outcome. The strongest predictors for metastases (for example, lymph node status and histological grade) fail to classify accurately breast tumours according to their clinical behaviour. Chemotherapy or hormonal therapy reduces the risk of distant metastases by approximately one-third; however, 70-80% of patients receiving this treatment would have survived without it. None of the signatures of breast cancer gene expression reported to date allow for patient-tailored therapy strategies. Here we used DNA microarray analysis on primary breast tumours of 117 young patients, and applied supervised classification to identify a gene expression signature strongly predictive of a short interval to distant metastases ('poor prognosis' signature) in patients without tumour cells in local lymph nodes at diagnosis (lymph node negative). In addition, we established a signature that identifies tumours of BRCA1 carriers. The poor prognosis signature consists of genes regulating cell cycle, invasion, metastasis and angiogenesis. This gene expression profile will outperform all currently used clinical parameters in predicting disease outcome. Our findings provide a strategy to select patients who would benefit from adjuvant therapy.

Standard name | COLLER_MYC_TARGETS_UP
Systematic name | M5955
Organism | Homo sapiens
PMID | 10737792
Authors | Coller HA,Grandori C,Tamayo P,Colbert T,Lander ES,Eisenman RN,Golub TR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 293T (transformed fetal renal cell) upon expression of MYC [GeneID=4609].
Full description | MYC affects normal and neoplastic cell proliferation by altering gene expression, but the precise pathways remain unclear. We used oligonucleotide microarray analysis of 6,416 genes and expressed sequence tags to determine changes in gene expression caused by activation of c-MYC in primary human fibroblasts. In these experiments, 27 genes were consistently induced, and 9 genes were repressed. The identity of the genes revealed that MYC may affect many aspects of cell physiology altered in transformed cells: cell growth, cell cycle, adhesion, and cytoskeletal organization. Identified targets possibly linked to MYC's effects on cell growth include the nucleolar proteins nucleolin and fibrillarin, as well as the eukaryotic initiation factor 5A. Among the cell cycle genes identified as targets, the G1 cyclin D2 and the cyclin-dependent kinase binding protein CksHs2 were induced whereas the cyclin-dependent kinase inhibitor p21(Cip1) was repressed. A role for MYC in regulating cell adhesion and structure is suggested by repression of genes encoding the extracellular matrix proteins fibronectin and collagen, and the cytoskeletal protein tropomyosin. A possible mechanism for MYC-mediated apoptosis was revealed by identification of the tumor necrosis factor receptor associated protein TRAP1 as a MYC target. Finally, two immunophilins, peptidyl-prolyl cis-trans isomerase F and FKBP52, the latter of which plays a role in cell division in Arabidopsis, were up-regulated by MYC. We also explored pattern-matching methods as an alternative approach for identifying MYC target genes. The genes that displayed an expression profile most similar to endogenous Myc in microarray-based expression profiling of myeloid differentiation models were highly enriched for MYC target genes.

Standard name | MANALO_HYPOXIA_UP
Systematic name | M259
Organism | Homo sapiens
PMID | 15374877
Authors | Manalo DJ,Rowan A,Lavoie T,Natarajan L,Kelly BD,Ye SQ,Garcia JG,Semenza GL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in response to both hypoxia and overexpression of an active form of HIF1A [GeneID=3091].
Full description | Hypoxia-inducible factor 1 (HIF-1) activates transcription of genes encoding angiogenic growth factors, which are secreted by hypoxic cells and stimulate endothelial cells, leading to angiogenesis. To determine whether HIF-1 also mediates cell-autonomous responses to hypoxia, we have compared gene expression profiles in arterial endothelial cells cultured under nonhypoxic versus hypoxic conditions and in nonhypoxic cells infected with adenovirus encoding beta-galactosidase versus a constitutively active form of HIF-1alpha (AdCA5). There were 245 gene probes that showed at least 1.5-fold increase in expression in response to hypoxia and in response to AdCA5; 325 gene probes showed at least 1.5-fold decrease in expression in response to hypoxia and in response to AdCA5. The largest category of genes down-regulated by both hypoxia and AdCA5 encoded proteins involved in cell growth/proliferation. Many genes up-regulated by both hypoxia and AdCA5 encoded cytokines/growth factors, receptors, and other signaling proteins. Transcription factors accounted for the largest group of HIF-1-regulated genes, indicating that HIF-1 controls a network of transcriptional responses to hypoxia in endothelial cells. Infection of endothelial cells with AdCA5 under nonhypoxic conditions was sufficient to induce increased basement membrane invasion and tube formation similar to the responses induced by hypoxia, indicating that HIF-1 mediates cell-autonomous activation of endothelial cells.

Standard name | REN_BOUND_BY_E2F
Systematic name | M4493
Organism | Homo sapiens
PMID | 11799067
Authors | Ren B,Cam H,Takahashi Y,Volkert T,Terragni J,Young RA,Dynlacht BD
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters were bound by E2F1 and E2F4 [GeneID=1869;1874] in the primary fibroblasts WI-38, by ChIP on chip assay.
Full description | The E2F transcription factor family is known to play a key role in the timely expression of genes required for cell cycle progression and proliferation, but only a few E2F target genes have been identified. We explored the possibility that E2F regulators play a broader role by identifying additional genes bound by E2F in living human cells. A protocol was developed to identify genomic binding sites for DNA-binding factors in mammalian cells that combines immunoprecipitation of cross-linked protein-DNA complexes with DNA microarray analysis. Among approximately 1200 genes expressed during cell cycle entry, we found that the promoters of 127 were bound by the E2F4 transcription factor in primary fibroblasts. A subset of these targets was also bound by E2F1. Most previously identified target genes known to have roles in DNA replication and cell cycle control and represented on the microarray were confirmed by this analysis. We also identified a remarkable cadre of genes with no previous connection to E2F regulation, including genes that encode components of the DNA damage checkpoint and repair pathways, as well as factors involved in chromatin assembly/condensation, chromosome segregation, and the mitotic spindle checkpoint. Our data indicate that E2F directly links cell cycle progression with the coordinate regulation of genes essential for both the synthesis of DNA as well as its surveillance.

Standard name | DORSAM_HOXA9_TARGETS_DN
Systematic name | M6051
Organism | Homo sapiens
PMID | 14604967
Authors | Dorsam ST,Ferrell CM,Dorsam GP,Derynck MK,Vijapurkar U,Khodabakhsh D,Pau B,Bernstein H,Haqq CM,Largman C,Lawrence HJ
Category | C2
Sub-category | CGP
Brief description | HOXA9 [GeneID=3205] targets down-regulated in hematopoietic stem cells.
Full description | Hematopoietic defects in HOXA9(-/-) mice demonstrate a key role for this homeoprotein in blood cell development. Conversely, enforced HOXA9 expression is leukemogenic in mice, and HOXA9 is frequently activated in human acute myeloid leukemia (AML). Although HOXA9 is thought to function as a transcription factor, few downstream targets have been identified. We searched for early HOXA9 target genes by using a transient overexpression strategy in 3 hematopoietic cell lines (2 myeloid, 1 lymphoid). cDNA microarray analyses identified 220 genes whose expression was modulated at least 2-fold. Expression signatures in myeloid and lymphoid cells demonstrated that HOXA9 functions as both an activator and repressor of a variety of genes in cell-specific patterns suggesting that the transcriptional effects of HOXA9 are largely dependent on the cell context. Transient transcription assays and target gene expression patterns in HOXA9(-/-) marrow cells imply that we have identified direct physiologic targets. Many target genes are expressed in CD34+ stem cells or are members of gene families involved in proliferation or myeloid differentiation. Expression of 14 HOXA9 target genes correlated with high-level HOXA9 expression in primary AML. These data suggest that many genes identified in this survey may mediate the biologic effects of HOXA9 in normal and leukemic hematopoiesis.

Standard name | FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_REJECTED_VS_OK_DN
Systematic name | M1475
Organism | Homo sapiens
PMID | 15307835
Authors | Flechner SM,Kurian SM,Head SR,Sharp SM,Whisenant TC,Zhang J,Chismar JD,Horvath S,Mondala T,Gilmartin T,Cook DJ,Kay SA,Walker JR,Salomon DR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in kidney biopsies from patients with acute transplant rejection compared to the biopsies from patients with well functioning kidneys more than 1-year post transplant.
Full description | A major challenge for kidney transplantation is balancing the need for immunosuppression to prevent rejection, while minimizing drug-induced toxicities. We used DNA microarrays (HG-U95Av2 GeneChips, Affymetrix) to determine gene expression profiles for kidney biopsies and peripheral blood lymphocytes (PBLs) in transplant patients including normal donor kidneys, well-functioning transplants without rejection, kidneys undergoing acute rejection, and transplants with renal dysfunction without rejection. We developed a data analysis schema based on expression signal determination, class comparison and prediction, hierarchical clustering, statistical power analysis and real-time quantitative PCR validation. We identified distinct gene expression signatures for both biopsies and PBLs that correlated significantly with each of the different classes of transplant patients. This is the most complete report to date using commercial arrays to identify unique expression signatures in transplant biopsies distinguishing acute rejection, acute dysfunction without rejection and well-functioning transplants with no rejection history. We demonstrate for the first time the successful application of high density DNA chip analysis of PBL as a diagnostic tool for transplantation. The significance of these results, if validated in a multicenter prospective trial, would be the establishment of a metric based on gene expression signatures for monitoring the immune status and immunosuppression of transplanted patients.

Standard name | SHIPP_DLBCL_VS_FOLLICULAR_LYMPHOMA_UP
Systematic name | M104
Organism | Homo sapiens
PMID | 11786909
Authors | Shipp MA,Ross KN,Tamayo P,Weng AP,Kutok JL,Aguiar RC,Gaasenbeek M,Angelo M,Reich M,Pinkus GS,Ray TS,Koval MA,Last KW,Norton A,Lister TA,Mesirov J,Neuberg DS,Lander ES,Aster JC,Golub TR
Category | C2
Sub-category | CGP
Brief description | Top 50 up-regulated markers distinguishing diffuse large B-cell lymphoma (DLBCL) from follicular lymphoma (FL) samples.
Full description | Diffuse large B-cell lymphoma (DLBCL), the most common lymphoid malignancy in adults, is curable in less than 50% of patients. Prognostic models based on pre-treatment characteristics, such as the International Prognostic Index (IPI), are currently used to predict outcome in DLBCL. However, clinical outcome models identify neither the molecular basis of clinical heterogeneity, nor specific therapeutic targets. We analyzed the expression of 6,817 genes in diagnostic tumor specimens from DLBCL patients who received cyclophosphamide, adriamycin, vincristine and prednisone (CHOP)-based chemotherapy, and applied a supervised learning prediction method to identify cured versus fatal or refractory disease. The algorithm classified two categories of patients with very different five-year overall survival rates (70% versus 12%). The model also effectively delineated patients within specific IPI risk categories who were likely to be cured or to die of their disease. Genes implicated in DLBCL outcome included some that regulate responses to B-cell-receptor signaling, critical serine/threonine phosphorylation pathways and apoptosis. Our data indicate that supervised learning classification techniques can predict outcome in DLBCL and identify rational targets for intervention.

Standard name | GRANDVAUX_IRF3_TARGETS_DN
Systematic name | M11814
Organism | Homo sapiens
PMID | 11991981
Authors | Grandvaux N,Servant MJ,tenOever B,Sen GC,Balachandran S,Barber GN,Lin R,Hiscott J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Jurkat cells (T lymphocyte) by expression of a constitutively active form of IRF3 [GeneID=3661].
Full description | Ubiquitously expressed interferon regulatory factor 3 (IRF-3) is directly activated after virus infection and functions as a key activator of the immediate-early alpha/beta interferon (IFN) genes, as well as the RANTES chemokine gene. In the present study, a tetracycline-inducible expression system expressing a constitutively active form of IRF-3 (IRF-3 5D) was combined with DNA microarray analysis to identify target genes regulated by IRF-3. Changes in mRNA expression profiles of 8,556 genes were monitored after Tet-inducible expression of IRF-3 5D. Among the genes upregulated by IRF-3 were transcripts for several known IFN-stimulated genes (ISGs). Subsequent analysis revealed that IRF-3 directly induced the expression of ISG56 in an IFN-independent manner through the IFN-stimulated responsive elements (ISREs) of the ISG56 promoter. These results demonstrate that, in addition to its role in the formation of a functional immediate-early IFN-beta enhanceosome, IRF-3 is able to discriminate among ISRE-containing genes involved in the establishment of the antiviral state as a direct response to virus infection.

Standard name | IIZUKA_LIVER_CANCER_EARLY_RECURRENCE
Systematic name | M10382
Organism | Homo sapiens
PMID | 12648972
Authors | Iizuka N,Oka M,Yamada-Okabe H,Nishida M,Maeda Y,Mori N,Takao T,Tamesa T,Tangoku A,Tabuchi H,Hamada K,Nakayama H,Ishitsuka H,Miyamoto T,Hirabayashi A,Uchimura S,Hamamoto Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma (HCC) tumors with higher risk of early intrahepatic recurrence. The single up-regulated gene (GenBank Accession=AC000063) has been excluded from the signature.
Full description | BACKGROUND: Hepatocellular carcinoma has a poor prognosis because of the high intrahepatic recurrence rate. There are technological limitations to traditional methods such as TNM staging for accurate prediction of recurrence, suggesting that new techniques are needed. METHODS: We investigated mRNA expression profiles in tissue specimens from a training set, comprising 33 patients with hepatocellular carcinoma, with high-density oligonucleotide microarrays representing about 6000 genes. We used this training set in a supervised learning manner to construct a predictive system, consisting of 12 genes, with the Fisher linear classifier. We then compared the predictive performance of our system with that of a predictive system with a support vector machine (SVM-based system) on a blinded set of samples from 27 newly enrolled patients. FINDINGS: Early intrahepatic recurrence within 1 year after curative surgery occurred in 12 (36%) and eight (30%) patients in the training and blinded sets, respectively. Our system correctly predicted early intrahepatic recurrence or non-recurrence in 25 (93%) of 27 samples in the blinded set and had a positive predictive value of 88% and a negative predictive value of 95%. By contrast, the SVM-based system predicted early intrahepatic recurrence or non-recurrence correctly in only 16 (60%) individuals in the blinded set, and the result yielded a positive predictive value of only 38% and a negative predictive value of 79%. INTERPRETATION: Our system predicted early intrahepatic recurrence or non-recurrence for patients with hepatocellular carcinoma much more accurately than the SVM-based system, suggesting that our system could serve as a new method for characterising the metastatic potential of hepatocellular carcinoma.

Standard name | RADAEVA_RESPONSE_TO_IFNA1_DN
Systematic name | M19208
Organism | Homo sapiens
PMID | 11910354
Authors | Radaeva S,Jaruga B,Hong F,Kim WH,Fan S,Cai H,Strom S,Liu Y,El-Assal O,Gao B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary hepatocytes and Hep3B (hepatocyte) cells in response to IFNA [GeneID=3439].
Full description | BACKGROUND & AIMS: Interferon (IFN)-alpha therapy is currently the primary choice for viral hepatitis and a promising treatment for hepatocellular carcinoma (HCC). Primary mouse and rat hepatocytes respond poorly to IFN-alpha stimulation. Thus, it is very important to examine the IFN-alpha signal pathway in primary human hepatocytes. METHODS: The IFN-alpha-activated signals and genes in primary human hepatocytes and hepatoma cells were examined by Western blotting and microarray analyses. RESULTS: Primary human hepatocytes respond very well to IFN-alpha stimulation as shown by activation of multiple signal transducer and activator of transcription factor (STAT) 1, 2, 3, 5, and multiple genes. The differential response to IFN-alpha stimulation in primary human and mouse hepatocytes may be caused by expression of predominant functional IFN-alpha receptor 2c (IFNAR2c) in primary human hepatocytes vs. expression of predominant inhibitory IFNAR2a in mouse hepatocytes. Microarray analyses of primary human hepatocytes show that IFN-alpha up-regulates about 44 genes by over 2-fold and down-regulates about 9 genes by 50%. The up-regulated genes include a variety of antiviral and tumor suppressors/proapoptotic genes. The down-regulated genes include c-myc and c-Met, the hepatocyte growth factor (HGF) receptor. Down-regulation of c-Met is caused by IFN-alpha suppression of the c-Met promoter through down-regulation of Sp1 binding and results in attenuation of HGF-induced signals and cell proliferation. CONCLUSIONS: IFN-alpha directly targets human hepatocytes, followed by activation of multiple STATs and regulation of a wide variety of genes, which may contribute to the antiviral and antitumor activities of IFN-alpha in human liver.

Standard name | BECKER_TAMOXIFEN_RESISTANCE_DN
Systematic name | M15676
Organism | Homo sapiens
PMID | 15657362
Authors | Becker M,Sommer A,Krätzschmar JR,Seidel H,Pohlenz HD,Fichtner I
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in a breast cancer cell line resistant to tamoxifen [PubChem=5376] compared to the parental line sensitive to the drug.
Full description | The reasons why human mammary tumors become resistant to tamoxifen therapy are mainly unknown. Changes in gene expression may occur as cells acquire resistance to antiestrogens. We therefore undertook a comparative gene expression analysis of tamoxifen-sensitive and tamoxifen-resistant human breast cancer in vivo models using Affymetrix oligonucleotide arrays to analyze differential gene expression. Total RNAs from the tamoxifen-sensitive patient-derived mammary carcinoma xenograft MaCa 3366 and the tamoxifen-resistant model MaCa 3366/TAM were hybridized to Affymetrix HuGeneFL and to Hu95Av2 arrays. Pairwise comparisons and clustering algorithms were applied to identify differentially expressed genes and patterns of gene expression. As revealed by cluster analysis, the tamoxifen-sensitive and the tamoxifen-resistant breast carcinomas differed regarding their gene expression pattern. More than 100 transcripts are changed in abundance in MaCa 3366/TAM as compared with MaCa 3366. Among the genes that are differentially expressed in the tamoxifen-resistant tumors, there are several IFN-inducible and estrogen-responsive genes, and genes known to be involved in breast carcinogenesis. The genes neuronatin (NNAT) and bone marrow stem cell antigen 2 (BST2) were sharply up-regulated in MaCa 3366/TAM. The differential expression of four genes (NNAT, BST2, IGFBP5, and BCAS1) was confirmed by Taqman PCR. Our results provide the starting point for deriving markers for tamoxifen resistance by differential gene expression profiling in a human breast cancer model of acquired tamoxifen resistance. Finally, genes whose expression profiles are distinctly changed between the two xenograft lines will be further evaluated as potential targets for diagnostic or therapeutic approaches of tamoxifen-resistant breast cancer.

Standard name | PEART_HDAC_PROLIFERATION_CLUSTER_DN
Systematic name | M1421
Organism | Homo sapiens
PMID | 15738394
Authors | Peart MJ,Smyth GK,van Laar RK,Bowtell DD,Richon VM,Marks PA,Holloway AJ,Johnstone RW
Category | C2
Sub-category | CGP
Brief description | Cell proliferation genes down-regulated by histone deacetylase (HDAC) inhibitors SAHA and depsipeptide [PubChem=5311;5352062].
Full description | Histone deacetylase inhibitors (HDACis) inhibit tumor cell growth and survival, possibly through their ability to regulate the expression of specific proliferative and/or apoptotic genes. However, the HDACi-regulated genes necessary and/or sufficient for their biological effects remain undefined. We demonstrate that the HDACis suberoylanilide hydroxamic acid (SAHA) and depsipeptide regulate a highly overlapping gene set with at least 22% of genes showing altered expression over a 16-h culture period. SAHA and depsipeptide coordinately regulated the expression of several genes within distinct apoptosis and cell cycle pathways. Multiple genes within the Myc, type beta TGF, cyclin/cyclin-dependent kinase, TNF, Bcl-2, and caspase pathways were regulated in a manner that favored induction of apoptosis and decreased cellular proliferation. APAF-1, a gene central to the intrinsic apoptotic pathway, was induced by SAHA and depsipeptide and shown to be important, but not essential, for HDACi-induced cell death. Overexpression of p16(INK4A) and arrest of cells in G(1) can suppress HDACi-mediated apoptosis. Although p16(INK4A) did not affect the genome-wide transcription changes mediated by SAHA, a small number of apoptotic genes, including BCLXL and B-MYB, were differentially regulated in a manner consistent with attenuated HDACi-mediated apoptosis in arrested cells. We demonstrate that different HDACi alter transcription of a large and common set of genes that control diverse molecular pathways important for cell survival and proliferation. The ability of HDACi to target multiple apoptotic and cell proliferation pathways may provide a competitive advantage over other chemotherapeutic agents because suppression/loss of a single pathway may not confer resistance to these agents.

Standard name | KLEIN_PRIMARY_EFFUSION_LYMPHOMA_UP
Systematic name | M12993
Organism | Homo sapiens
PMID | 12531789
Authors | Klein U,Gloghini A,Gaidano G,Chadburn A,Cesarman E,Dalla-Favera R,Carbone A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in AIDS-related primary effusion lymphoma (PEL) samples compared to other tumor subtypes and normal B lymphocytes.
Full description | AIDS-related primary effusion lymphoma (PEL) is an HIV-associated malignancy characterized by the ability of the tumor cells to specifically home in the serous body cavities. Here we used gene expression profile analysis (about 12 000 genes) to further define the phenotype of PEL and to investigate the lymphoma relationship to normal B cells and to other tumor subtypes, including non-Hodgkin lymphomas (NHLs) of immunocompetent hosts and AIDS-associated NHL (AIDS-NHL). The results showed that PEL displayed a common gene expression profile that is clearly distinct from all NHLs of immunocompetent hosts and AIDS-NHL subtypes and, in contrast to those, is not related to germinal center (GC) or memory B cells. The gene expression profile of PEL was defined as plasmablastic because it showed features of both immunoblasts identified by Epstein-Barr virus (EBV)-transformed lymphoblastoid cell lines and AIDS immunoblastic lymphoma, and plasma cells, as defined by multiple myeloma cell lines. Finally, our results identify a set of genes specifically expressed in PEL tumor cells. Their expression was validated at the protein level, suggesting their potential pathogenetic and clinical significance.

Standard name | SASAKI_ADULT_T_CELL_LEUKEMIA
Systematic name | M15171
Organism | Homo sapiens
PMID | 15471956
Authors | Sasaki H,Nishikata I,Shiraga T,Akamatsu E,Fukami T,Hidaka T,Kubuki Y,Okayama A,Hamada K,Okabe H,Murakami Y,Tsubouchi H,Morishita K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in adult T-cell leukemia (ATL) cells compared to T lymphocytes from healthy controls.
Full description | Adult T-cell leukemia (ATL) caused by human T-cell leukemia virus type 1 (HTLV-1) infection, occurs in 2% to 4% of the HTLV-1 carriers with a long latent period, suggesting that additional alterations participate in the development of ATL. To characterize and identify novel markers of ATL, we examined the expression profiles of more than 12 000 genes in 8 cases of acute-type ATL using microarray. One hundred ninety-two genes containing interleukin 2 (IL-2) receptor alpha were up-regulated more than 2-fold compared with CD4(+) and CD4(+)CD45RO(+) T cells, and tumor suppressor in lung cancer 1 (TSLC1), caveolin 1, and prostaglandin D2 synthase showed increased expression of more than 30-fold. TSLC1 is a cell adhesion molecule originally identified as a tumor suppressor in the lung but lacks its expression in normal or activated T cells. We confirmed ectopic expression of the TSLC1 in all acute-type ATL cells and in 7 of 10 ATL- or HTLV-1-infected T-cell lines. Introduction of TSLC1 into a human ATL cell line ED enhanced both self-aggregation and adhesion ability to vascular endothelial cells. These results suggested that the ectopic expression of TSLC1 could provide a novel marker for acute-type ATL and may participate in tissue invasion, a characteristic feature of the malignant ATL cells.

Standard name | COLLER_MYC_TARGETS_DN
Systematic name | M19620
Organism | Homo sapiens
PMID | 10737792
Authors | Coller HA,Grandori C,Tamayo P,Colbert T,Lander ES,Eisenman RN,Golub TR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 293T (transformed fetal renal cell) upon expression of MYC [GeneID=4609].
Full description | MYC affects normal and neoplastic cell proliferation by altering gene expression, but the precise pathways remain unclear. We used oligonucleotide microarray analysis of 6,416 genes and expressed sequence tags to determine changes in gene expression caused by activation of c-MYC in primary human fibroblasts. In these experiments, 27 genes were consistently induced, and 9 genes were repressed. The identity of the genes revealed that MYC may affect many aspects of cell physiology altered in transformed cells: cell growth, cell cycle, adhesion, and cytoskeletal organization. Identified targets possibly linked to MYC's effects on cell growth include the nucleolar proteins nucleolin and fibrillarin, as well as the eukaryotic initiation factor 5A. Among the cell cycle genes identified as targets, the G1 cyclin D2 and the cyclin-dependent kinase binding protein CksHs2 were induced whereas the cyclin-dependent kinase inhibitor p21(Cip1) was repressed. A role for MYC in regulating cell adhesion and structure is suggested by repression of genes encoding the extracellular matrix proteins fibronectin and collagen, and the cytoskeletal protein tropomyosin. A possible mechanism for MYC-mediated apoptosis was revealed by identification of the tumor necrosis factor receptor associated protein TRAP1 as a MYC target. Finally, two immunophilins, peptidyl-prolyl cis-trans isomerase F and FKBP52, the latter of which plays a role in cell division in Arabidopsis, were up-regulated by MYC. We also explored pattern-matching methods as an alternative approach for identifying MYC target genes. The genes that displayed an expression profile most similar to endogenous Myc in microarray-based expression profiling of myeloid differentiation models were highly enriched for MYC target genes.

Standard name | LEE_LIVER_CANCER_E2F1_DN
Systematic name | M15346
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma (HCC) induced by overexpression of E2F1 [GeneID=1869].
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | LEE_LIVER_CANCER_DENA_UP
Systematic name | M16524
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) induced by diethylnitrosamine (DENA) [PubChem=5921].
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_OK_VS_DONOR_DN
Systematic name | M15841
Organism | Homo sapiens
PMID | 15307835
Authors | Flechner SM,Kurian SM,Head SR,Sharp SM,Whisenant TC,Zhang J,Chismar JD,Horvath S,Mondala T,Gilmartin T,Cook DJ,Kay SA,Walker JR,Salomon DR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in kidney biopsies from patients with well functioning kidneys more than 1-year post transplant compared to the biopsies from normal living kidney donors.
Full description | A major challenge for kidney transplantation is balancing the need for immunosuppression to prevent rejection, while minimizing drug-induced toxicities. We used DNA microarrays (HG-U95Av2 GeneChips, Affymetrix) to determine gene expression profiles for kidney biopsies and peripheral blood lymphocytes (PBLs) in transplant patients including normal donor kidneys, well-functioning transplants without rejection, kidneys undergoing acute rejection, and transplants with renal dysfunction without rejection. We developed a data analysis schema based on expression signal determination, class comparison and prediction, hierarchical clustering, statistical power analysis and real-time quantitative PCR validation. We identified distinct gene expression signatures for both biopsies and PBLs that correlated significantly with each of the different classes of transplant patients. This is the most complete report to date using commercial arrays to identify unique expression signatures in transplant biopsies distinguishing acute rejection, acute dysfunction without rejection and well-functioning transplants with no rejection history. We demonstrate for the first time the successful application of high density DNA chip analysis of PBL as a diagnostic tool for transplantation. The significance of these results, if validated in a multicenter prospective trial, would be the establishment of a metric based on gene expression signatures for monitoring the immune status and immunosuppression of transplanted patients.

Standard name | MAGRANGEAS_MULTIPLE_MYELOMA_IGLL_VS_IGLK_UP
Systematic name | M1422
Organism | Homo sapiens
PMID | 12623842
Authors | Magrangeas F,Nasser V,Avet-Loiseau H,Loriod B,Decaux O,Granjeaud S,Bertucci F,Birnbaum D,Nguyen C,Harousseau JL,Bataille R,Houlgatte R,Minvielle S
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes discriminating multiple myeloma samples by the ype of immunoglobulin light chain they produce: Ig lambda (IGLL) vs Ig kappa (IGLK).
Full description | Although multiple myeloma (MM) is a unique entity, a marked heterogeneity is actually observed among the patients, which has been first related to immunoglobulin (Ig) types and light chain subtypes and more recently to chromosomal abnormalities. To further investigate this genetic heterogeneity, we analyzed gene expression profiles of 92 primary tumors according to their Ig types and light chain subtypes with DNA microarrays. Several clusters of genes involved in various biologic functions such as immune response, cell cycle control, signaling, apoptosis, cell adhesion, and structure significantly discriminated IgA- from IgG-MM. Genes associated with inhibition of differentiation and apoptosis induction were up-regulated while genes associated with immune response, cell cycle control, and apoptosis were down-regulated in IgA-MM. According to the expression of the 61 most discriminating genes, BJ-MM represented a separate subgroup that did not express either the genes characteristic of IgG-MM or those of IgA-MM at a high level. This suggests that transcriptional programs associated to the switch could be maintained up to plasma cell differentiation. Several genes whose products are known to stimulate bone remodeling discriminate between kappa- and lambda-MM. One of these genes, Mip-1alpha, was overexpressed in the kappa subgroup. In addition, we established a strong association (P =.0001) between kappa subgroup expressing high levels of Mip-1alpha and active myeloma bone disease. This study shows that DNA microarrays enable us to perform a molecular dissection of the bioclinical diversity of MM and provide new molecular tools to investigate the pathogenesis of malignant plasma cells.

Standard name | FLECHNER_PBL_KIDNEY_TRANSPLANT_REJECTED_VS_OK_UP
Systematic name | M10243
Organism | Homo sapiens
PMID | 15307835
Authors | Flechner SM,Kurian SM,Head SR,Sharp SM,Whisenant TC,Zhang J,Chismar JD,Horvath S,Mondala T,Gilmartin T,Cook DJ,Kay SA,Walker JR,Salomon DR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in peripheral blood lymphocytes (PBL) from patients with acute transplant rejection compared to those from patients with well functioning kidneys more than 1-year post transplant.
Full description | A major challenge for kidney transplantation is balancing the need for immunosuppression to prevent rejection, while minimizing drug-induced toxicities. We used DNA microarrays (HG-U95Av2 GeneChips, Affymetrix) to determine gene expression profiles for kidney biopsies and peripheral blood lymphocytes (PBLs) in transplant patients including normal donor kidneys, well-functioning transplants without rejection, kidneys undergoing acute rejection, and transplants with renal dysfunction without rejection. We developed a data analysis schema based on expression signal determination, class comparison and prediction, hierarchical clustering, statistical power analysis and real-time quantitative PCR validation. We identified distinct gene expression signatures for both biopsies and PBLs that correlated significantly with each of the different classes of transplant patients. This is the most complete report to date using commercial arrays to identify unique expression signatures in transplant biopsies distinguishing acute rejection, acute dysfunction without rejection and well-functioning transplants with no rejection history. We demonstrate for the first time the successful application of high density DNA chip analysis of PBL as a diagnostic tool for transplantation. The significance of these results, if validated in a multicenter prospective trial, would be the establishment of a metric based on gene expression signatures for monitoring the immune status and immunosuppression of transplanted patients.

Standard name | FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_OK_VS_DONOR_UP
Systematic name | M4023
Organism | Homo sapiens
PMID | 15307835
Authors | Flechner SM,Kurian SM,Head SR,Sharp SM,Whisenant TC,Zhang J,Chismar JD,Horvath S,Mondala T,Gilmartin T,Cook DJ,Kay SA,Walker JR,Salomon DR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in kidney biopsies from patients with well functioning kidneys more than 1-year post transplant compared to the biopsies from normal living kidney donors.
Full description | A major challenge for kidney transplantation is balancing the need for immunosuppression to prevent rejection, while minimizing drug-induced toxicities. We used DNA microarrays (HG-U95Av2 GeneChips, Affymetrix) to determine gene expression profiles for kidney biopsies and peripheral blood lymphocytes (PBLs) in transplant patients including normal donor kidneys, well-functioning transplants without rejection, kidneys undergoing acute rejection, and transplants with renal dysfunction without rejection. We developed a data analysis schema based on expression signal determination, class comparison and prediction, hierarchical clustering, statistical power analysis and real-time quantitative PCR validation. We identified distinct gene expression signatures for both biopsies and PBLs that correlated significantly with each of the different classes of transplant patients. This is the most complete report to date using commercial arrays to identify unique expression signatures in transplant biopsies distinguishing acute rejection, acute dysfunction without rejection and well-functioning transplants with no rejection history. We demonstrate for the first time the successful application of high density DNA chip analysis of PBL as a diagnostic tool for transplantation. The significance of these results, if validated in a multicenter prospective trial, would be the establishment of a metric based on gene expression signatures for monitoring the immune status and immunosuppression of transplanted patients.

Standard name | GOLDRATH_IMMUNE_MEMORY
Systematic name | M10845
Organism | Mus musculus
PMID | 15548615
Authors | Goldrath AW,Luckey CJ,Park R,Benoist C,Mathis D
Category | C2
Sub-category | CGP
Brief description | 'Memory genes' expressed uniquely in CD8+ [GeneID=925] memory T lymphocytes (compared with effector or naive cells)
Full description | Naive T cells proliferate independently of cognate antigen when introduced into lymphopenic hosts. Lymphopenia-induced proliferation depends on low-affinity MHC/self-peptide complexes and on IL-7. To elucidate the intracellular signals mediating this proliferation, we analyzed changes in gene expression in naive CD8+ T cells at different times after their transfer into a lymphopenic environment. The genes induced in response to lymphopenia were largely an attenuated subset of those turned up by full antigenic stimulation, including genes related to cell cycling, whereas excluding genes specifically associated with effector activity. After the initial phase of proliferation in an empty compartment, the naive T cells adopted a stable pattern of gene expression similar to that of antigen-experienced memory cells. Thus, T cells proliferating in lymphopenic hosts do not exhibit a unique gene-expression profile, instead relying on traditional signals for this antigen-independent proliferation; this process ultimately results in differentiation to authentic memory cells.

Standard name | LEE_LIVER_CANCER_E2F1_UP
Systematic name | M18438
Organism | Mus musculus
PMID | 15565109
Authors | Lee JS,Chu IS,Mikaelyan A,Calvisi DF,Heo J,Reddy JK,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) induced by overexpression of E2F1 [GeneID=1869].
Full description | Genetically modified mice have been extensively used for analyzing the molecular events that occur during tumor development. In many, if not all, cases, however, it is uncertain to what extent the mouse models reproduce features observed in the corresponding human conditions. This is due largely to lack of precise methods for direct and comprehensive comparison at the molecular level of the mouse and human tumors. Here we use global gene expression patterns of 68 hepatocellular carcinomas (HCCs) from seven different mouse models and 91 human HCCs from predefined subclasses to obtain direct comparison of the molecular features of mouse and human HCCs. Gene expression patterns in HCCs from Myc, E2f1 and Myc E2f1 transgenic mice were most similar to those of the better survival group of human HCCs, whereas the expression patterns in HCCs from Myc Tgfa transgenic mice and in diethylnitrosamine-induced mouse HCCs were most similar to those of the poorer survival group of human HCCs. Gene expression patterns in HCCs from Acox1(-/-) mice and in ciprofibrate-induced HCCs were least similar to those observed in human HCCs. We conclude that our approach can effectively identify appropriate mouse models to study human cancers.

Standard name | ROSS_AML_WITH_AML1_ETO_FUSION
Systematic name | M8043
Organism | Homo sapiens
PMID | 15226186
Authors | Ross ME,Mahfouz R,Onciu M,Liu HC,Zhou X,Song G,Shurtleff SA,Pounds S,Cheng C,Ma J,Ribeiro RC,Rubnitz JE,Girtman K,Williams WK,Raimondi SC,Liang DC,Shih LY,Pui CH,Downing JR
Category | C2
Sub-category | CGP
Brief description | Top 100 probe sets for pediatric acute myeloid leukemia (AML) subtype t(8;21) ; has AML1 ETO fusion [GeneID=861;862].
Full description | Contemporary treatment of pediatric acute myeloid leukemia (AML) requires the assignment of patients to specific risk groups. To explore whether expression profiling of leukemic blasts could accurately distinguish between the known risk groups of AML, we analyzed 130 pediatric and 20 adult AML diagnostic bone marrow or peripheral blood samples using the Affymetrix U133A microarray. Class discriminating genes were identified for each of the major prognostic subtypes of pediatric AML, including t(15;17)[PML-RARalpha], t(8;21)[AML1-ETO], inv(16) [CBFbeta-MYH11], MLL chimeric fusion genes, and cases classified as FAB-M7. When subsets of these genes were used in supervised learning algorithms, an overall classification accuracy of more than 93% was achieved. Moreover, we were able to use the expression signatures generated from the pediatric samples to accurately classify adult de novo AMLs with the same genetic lesions. The class discriminating genes also provided novel insights into the molecular pathobiology of these leukemias. Finally, using a combined pediatric data set of 130 AMLs and 137 acute lymphoblastic leukemias, we identified an expression signature for cases with MLL chimeric fusion genes irrespective of lineage. Surprisingly, AMLs containing partial tandem duplications of MLL failed to cluster with MLL chimeric fusion gene cases, suggesting a significant difference in their underlying mechanism of transformation.

Standard name | BHATTACHARYA_EMBRYONIC_STEM_CELL
Systematic name | M4282
Organism | Homo sapiens
PMID | 15070671
Authors | Bhattacharya B,Miura T,Brandenberger R,Mejido J,Luo Y,Yang AX,Joshi BH,Ginis I,Thies RS,Amit M,Lyons I,Condie BG,Itskovitz-Eldor J,Rao MS,Puri RK
Category | C2
Sub-category | CGP
Brief description | The 'stemnes' signature: genes up-regulated and common to 6 human embryonic stem cell lines tested.
Full description | Human embryonic stem (huES) cells have the ability to differentiate into a variety of cell lineages and potentially provide a source of differentiated cells for many therapeutic uses. However, little is known about the mechanism of differentiation of huES cells and factors regulating cell development. We have used high-quality microarrays containing 16 659 seventy-base pair oligonucleotides to examine gene expression in 6 of the 11 available huES cell lines. Expression was compared against pooled RNA from multiple tissues (universal RNA) and genes enriched in huES cells were identified. All 6 cell lines expressed multiple markers of the undifferentiated state and shared significant homology in gene expression (overall similarity coefficient > 0.85).A common subset of 92 genes was identified that included Nanog, GTCM-1, connexin 43 (GJA1), oct-4, and TDGF1 (cripto). Gene expression was confirmed by a variety of techniques including comparison with databases, reverse transcriptase-polymerase chain reaction, focused cDNA microarrays, and immunocytochemistry. Comparison with published stemness genes revealed a limited overlap, suggesting little similarity with other stem cell populations. Several novel ES cell-specific expressed sequence tags were identified and mapped to the human genome. These results represent the first detailed characterization of undifferentiated huES cells and provide a unique set of markers to profile and better understand the biology of huES cells.

Standard name | OSAWA_TNF_TARGETS
Systematic name | M15412
Organism | Homo sapiens
PMID | 12682234
Authors | Osawa Y,Nagaki M,Banno Y,Brenner DA,Nozawa Y,Moriwaki H,Nakashima S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Hc cells (normal hepatocyte) by TNF [GeneID=7124].
Full description | Using a cDNA microarray analysis, we identified x-ray-inducible immediate early response factor-1 (IEX-1) as a proapoptotic gene which was induced by TNF-alpha and also depend on NF-kappaB activation in Hc human hepatocytes. In these cells only the original form of IEX-1, termed IEX-1S, but not its longer transcript IEX-1L, was expressed. Overexpression of IEX-1S resulted in promotion of TNF-alpha-induced apoptosis in Hc cells expressing a mutant form of IkappaB. This proapoptotic action can be explained by its inhibitory findings on survival signals; inhibition of TNF-alpha-induced activation and expression of phosphatidylinositol 3-kinase (PI3K)/Akt, and also blockage of expression of Mcl-1, an antiapoptotic Bcl-2 family member which is located downstream of Akt, was inhibited by IEX-1S. LY 294002, an inhibitor of PI3K, increased IEX-1S expression induced by TNF-alpha and accelerated TNF-alpha-induced apoptosis in IkappaB-treated Hc cells. Overexpression of the dominant-negative Akt enhanced, but the constitutively active Akt suppressed, TNF-alpha-induced IEX-1S expression, suggesting that PI3K/Akt negatively regulated IEX-1S expression. These results demonstrate that NF-kappaB-dependent recruitment of IEX-1S may play a proapoptotic role in TNF-alpha-stimulated hepatocytes through blockage of the PI3K/Akt pathway. Moreover, the reciprocal cross-talk between IEX-1S and PI3K/Akt may closely be involved in the regulation of TNF-alpha-induced hepatocyte apoptosis.

Standard name | DER_IFN_GAMMA_RESPONSE_UP
Systematic name | M15615
Organism | Homo sapiens
PMID | 9861020
Authors | Der SD,Zhou A,Williams BR,Silverman RH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HT1080 (fibrosarcoma) cells by treatment with interferon gamma for 6 h.
Full description | The pleiotropic activities of interferons (IFNs) are mediated primarily through the transcriptional regulation of many downstream effector genes. The mRNA profiles from IFN-alpha, -beta, or -gamma treatments of the human fibrosarcoma cell line, HT1080, were determined by using oligonucleotide arrays with probe sets corresponding to more than 6,800 human genes. Among these were transcripts for known IFN-stimulated genes (ISGs), the expression of which were consistent with previous studies in which the particular ISG was characterized as responsive to either Type I (alpha, beta) or Type II (gamma) IFNs, or both. Importantly, many novel IFN-stimulated genes were identified that were diverse in their known biological functions. For instance, several novel ISGs were identified that are implicated in apoptosis (including RAP46/Bag-1, phospholipid scramblase, and hypoxia inducible factor-1alpha). Furthermore, several IFN-repressed genes also were identified. These results demonstrate the usefulness of oligonucleotide arrays in monitoring mammalian gene expression on a broad and unprecedented scale. In particular, these findings provide insights into the basic mechanisms of IFN actions and ultimately may contribute to better therapeutic uses for IFNs.

Standard name | HASLINGER_B_CLL_WITH_17P13_DELETION
Systematic name | M3256
Organism | Homo sapiens
PMID | 15459216
Authors | Haslinger C,Schweifer N,Stilgenbauer S,Döhner H,Lichter P,Kraut N,Stratowa C,Abseher R
Category | C2
Sub-category | CGP
Brief description | Genes changed in the B cell chronic lymphocytic leukemia (B-CLL) with deletions in the 17p13 region.
Full description | PURPOSE: Genomic aberrations and mutational status of the immunoglobulin variable heavy chain (VH) gene have been shown to be among the most important predictors for outcome in patients with B-cell chronic lymphocytic leukemia (B-CLL). In this study, we report on differential gene expression patterns that are characteristic for genetically defined B-CLL subtypes. MATERIALS AND METHODS: One hundred genetically well-characterized B-CLL samples, together with 11 healthy control samples, were analyzed using oligonucleotide arrays, which test for the expression of some 12,000 human genes. RESULTS: Aiming at microarray-based subclassification, class predictors were constructed using sets of differentially expressed genes, which yielded in zero or low misclassification rates. Furthermore, a significant number of the differentially expressed genes clustered in chromosomal regions affected by the respective genomic losses/gains. Deletions affecting chromosome bands 11q22-q23 and 17p13 led to a reduced expression of the corresponding genes, such as ATM and p53, while trisomy 12 resulted in the upregulation of genes mapping to chromosome arm 12q. Using an unsupervised analysis algorithm, expression profiling allowed partitioning into predominantly VH-mutated versus unmutated patient groups; however, association of the expression profile with the VH mutational status could only be detected in male patients. CONCLUSION: The finding that the most significantly differentially expressed genes are located in the corresponding aberrant chromosomal regions indicates that a gene dosage effect may exert a pathogenic role in B-CLL. The significant difference in the partitioning of male and female B-CLL samples suggests that the genomic signature for the VH mutational status might be sex-related.

Standard name | YAO_HOXA10_TARGETS_VIA_PROGESTERONE_UP
Systematic name | M10660
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the uteri of ovariectomized mice 6 h after progesterone [PubChem=5994] injection: HOXA10 [GeneID=3206] knockout vs wild type animals.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | ZHAN_MULTIPLE_MYELOMA_CD1_UP
Systematic name | M1190
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 up-regulated genes in cluster CD-1 of multiple myeloma samples with the characteristic expression spike of CCND1 [GeneID=595].
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | ABBUD_LIF_SIGNALING_1_DN
Systematic name | M1423
Organism | Mus musculus
PMID | 14576184
Authors | Abbud RA,Kelleher R,Melmed S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in AtT20 cells (pituitary cancer) after treatment with LIF [GeneID=3976].
Full description | Leukemia inhibitory factor (LIF) mediates the hypothalamo-pituitary-adrenal stress response. Transgenic mice overexpressing LIF in the developing pituitary have altered pituitary differentiation with expansion of corticotropes, maintenance of Rathke's cleft cysts, and suppression of all other pituitary cell types. Affymetrix GeneChips were used to identify modulators of LIF effects in corticotrope (AtT-20) and somatolactotrope (GH(3)) cells. In addition to genes known to respond to LIF in corticotrope cells [e.g. suppressor of cytokine signaling-3 (SOCS-3), signal transducer and activator of transcription-3, SH2 domain-containing tyrosine phosphatase-1, and proopiomelanocortin (POMC)], corticotrope-specific changes were also observed for genes involved in glycolysis and gluconeogenesis, transcription factors, signaling molecules, and expressed sequence tags. Two transcription factors identified, CCAAT/enhancer-binding protein beta (C/EBPbeta) and glial cell-derived neurotrophic factor (GDNF)-inducible factor (GIF), dose-dependently induced expression of the rat POMC promoter when overexpressed in AtT-20 cells. LIF further induced POMC transcription with C/EBPbeta, but not with GIF. C/EBPbeta also induced expression of the SOCS-3 promoter that was further enhanced by cotreatment with LIF. However, GIF did not affect SOCS-3 expression. These results indicate that C/EBPbeta and GIF are downstream effectors of LIF corticotrope action. LIF also stimulates the expression of inhibitors of its actions, such as SOCS-3 and SH2 domain-containing tyrosine phosphatase-1. alpha(2)-HS-glycoprotein (AHSG)/fetuin, a secreted protein that antagonizes bone TGFbeta/bone morphogenic protein signaling, was induced by LIF in a signal transducer and activator of transcription-3-dependent fashion. Pretreatment with AHSG/fetuin blocked LIF-induced expression of the POMC promoter independently of SOCS-3. Thus, using GeneChips, C/EBPbeta and GIF have been identified as novel mediators and AHSG/fetuin as an inhibitor of LIF action in corticotropes.

Standard name | SANSOM_APC_TARGETS_UP
Systematic name | M1428
Organism | Mus musculus
PMID | 15198980
Authors | Sansom OJ,Reed KR,Hayes AJ,Ireland H,Brinkmann H,Newton IP,Batlle E,Simon-Assmann P,Clevers H,Nathke IS,Clarke AR,Winton DJ
Category | C2
Sub-category | CGP
Brief description | Top genes up-regulated at day 5 of Cre-Lox induced APC [GeneID=324] knockout in the intestine.
Full description | Although Apc is well characterized as a tumor-suppressor gene in the intestine, the precise mechanism of this suppression remains to be defined. Using a novel inducible Ahcre transgenic line in conjunction with a loxP-flanked Apc allele we, show that loss of Apc acutely activates Wnt signaling through the nuclear accumulation of beta-catenin. Coincidentally, it perturbs differentiation, migration, proliferation, and apoptosis, such that Apc-deficient cells maintain a crypt progenitor-like phenotype. Critically, for the first time we confirm a series of Wnt target molecules in an in vivo setting and also identify a series of new candidate targets within the same setting.

Standard name | NAKAJIMA_EOSINOPHIL
Systematic name | M8344
Organism | Homo sapiens
PMID | 11493461
Authors | Nakajima T,Matsumoto K,Suto H,Tanaka K,Ebisawa M,Tomita H,Yuki K,Katsunuma T,Akasawa A,Hashida R,Sugita Y,Ogawa H,Ra C,Saito H
Category | C2
Sub-category | CGP
Brief description | Top 30 increased eosinophil specific transcripts.
Full description | Mast cells (MCs) and eosinophils are thought to play important roles in evoking allergic inflammation. Cell-type--specific gene expression was screened among 12,000 genes in human MCs and eosinophils with the use of high-density oligonucleotide probe arrays. In comparison with other leukocytes, MCs expressed 140 cell-type--specific transcripts, whereas eosinophils expressed only 34. Among the transcripts for expected MC-specific proteins such as tryptase, major basic protein (MBP), which had been thought to be eosinophil specific, was ranked fourth in terms of amounts of increased MC-specific messenger RNA. Mature eosinophils were almost lacking this transcript. MCs obtained from 4 different sources (ie, lung, skin, adult peripheral blood progenitor--derived and cord blood progenitor--derived MCs, and eosinophils) were found to have high protein levels of MBP in their granules with the use of flow cytometric and confocal laser scanning microscopic analyses. The present finding that MCs can produce abundant MBP is crucial because many reports regarding allergic pathogenesis have been based on earlier findings that MBP was almost unique to eosinophils and not produced by MCs. (Blood. 2001;98:1127-1134)

Standard name | BROWN_MYELOID_CELL_DEVELOPMENT_UP
Systematic name | M1430
Organism | Mus musculus
PMID | 16769770
Authors | Brown AL,Wilkinson CR,Waterman SR,Kok CH,Salerno DG,Diakiw SM,Reynolds B,Scott HS,Tsykin A,Glonek GF,Goodall GJ,Solomon PJ,Gonda TJ,D'Andrea RJ
Category | C2
Sub-category | CGP
Brief description | Genes defining differentiation potential of the bipotential myeloid cell line FDB.
Full description | Mechanisms controlling the balance between proliferation and self-renewal versus growth suppression and differentiation during normal and leukemic myelopoiesis are not understood. We have used the bi-potent FDB1 myeloid cell line model, which is responsive to myelopoietic cytokines and activated mutants of the granulocyte macrophage-colony stimulating factor (GM-CSF) receptor, having differential signaling and leukemogenic activity. This model is suited to large-scale gene-profiling, and we have used a factorial time-course design to generate a substantial and powerful data set. Linear modeling was used to identify gene-expression changes associated with continued proliferation, differentiation, or leukemic receptor signaling. We focused on the changing transcription factor profile, defined a set of novel genes with potential to regulate myeloid growth and differentiation, and demonstrated that the FDB1 cell line model is responsive to forced expression of oncogenes identified in this study. We also identified gene-expression changes associated specifically with the leukemic GM-CSF receptor mutant, V449E. Signaling from this receptor mutant down-regulates CCAAT/enhancer-binding protein alpha (C/EBPalpha) target genes and generates changes characteristic of a specific acute myeloid leukemia signature, defined previously by gene-expression profiling and associated with C/EBPalpha mutations.

Standard name | NADLER_OBESITY_UP
Systematic name | M1431
Organism | Mus musculus
PMID | 11027337
Authors | Nadler ST,Stoehr JP,Schueler KL,Tanimoto G,Yandell BS,Attie AD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in adipose tissue from obese mouse strains compared to the lean ones.
Full description | Obesity is strongly correlated with type 2 diabetes mellitus, a common disorder of glucose and lipid metabolism. Although adipocytes are critical in obesity, their role in diabetes has only recently been appreciated. We conducted studies by using DNA microarrays to identify differences in gene expression in adipose tissue from lean, obese, and obese-diabetic mice. The expression level of over 11,000 transcripts was analyzed, and 214 transcripts showed significant differences between lean and obese mice. Surprisingly, the expression of genes normally associated with adipocyte differentiation were down-regulated in obesity. Not all obese individuals will become diabetic; many remain normoglycemic despite profound obesity. Understanding the transition to obesity with concomitant diabetes will provide important clues to the pathogenesis of type 2 diabetes. Therefore, we examined the levels of gene expression in adipose tissue from five groups of obese mice with varying degrees of hyperglycemia, and we identified 88 genes whose expression strongly correlated with diabetes severity. This group included many genes that are known to be involved in signal transduction and energy metabolism as well as genes not previously examined in the context of diabetes. Our data show that a decrease in expression of genes normally involved in adipogenesis is associated with obesity, and we further identify genes important for subsequent development of type 2 diabetes mellitus.

Standard name | SANSOM_APC_TARGETS_DN
Systematic name | M1432
Organism | Mus musculus
PMID | 15198980
Authors | Sansom OJ,Reed KR,Hayes AJ,Ireland H,Brinkmann H,Newton IP,Batlle E,Simon-Assmann P,Clevers H,Nathke IS,Clarke AR,Winton DJ
Category | C2
Sub-category | CGP
Brief description | Top genes down-regulated at day 5 of Cre-Lox induced APC [GeneID=324] knockout in the intestine.
Full description | Although Apc is well characterized as a tumor-suppressor gene in the intestine, the precise mechanism of this suppression remains to be defined. Using a novel inducible Ahcre transgenic line in conjunction with a loxP-flanked Apc allele we, show that loss of Apc acutely activates Wnt signaling through the nuclear accumulation of beta-catenin. Coincidentally, it perturbs differentiation, migration, proliferation, and apoptosis, such that Apc-deficient cells maintain a crypt progenitor-like phenotype. Critically, for the first time we confirm a series of Wnt target molecules in an in vivo setting and also identify a series of new candidate targets within the same setting.

Standard name | ADDYA_ERYTHROID_DIFFERENTIATION_BY_HEMIN
Systematic name | M11516
Organism | Homo sapiens
PMID | 15252187
Authors | Addya S,Keller MA,Delgrosso K,Ponte CM,Vadigepalli R,Gonye GE,Surrey S
Category | C2
Sub-category | CGP
Brief description | Selected genes changed in K562 (immortalized erythroleukemia) cells induced by hemin [PubChem=26945] treatment to express erythroid properties.
Full description | Understanding regulation of fetal and embryonic hemoglobin expression is critical, since their expression decreases clinical severity in sickle cell disease and beta-thalassemia. K562 cells, a human erythroleukemia cell line, can differentiate along erythroid or megakaryocytic lineages and serve as a model for regulation of fetal/embryonic globin expression. We used microarray expression profiling to characterize transcriptomes from K562 cells treated for various times with hemin, an inducer of erythroid commitment. Approximately 5,000 genes were expressed irrespective of treatment. Comparative expression analysis (CEA) identified 899 genes as differentially expressed; analysis by the self-organizing map (SOM) algorithm clustered 425 genes into 8 distinct expression patterns, 322 of which were shared by both analyses. Differential expression of a subset of genes was validated by real-time RT-PCR. Analysis of 5'-flanking regions from differentially expressed genes by PAINT v3.0 software showed enrichment in specific transcription regulatory elements (TREs), some localizing to different expression clusters. This finding suggests coordinate regulation of cluster members by specific TREs. Finally, our findings provide new insights into rate-limiting steps in the appearance of heme-containing hemoglobin tetramers in these cells.

Standard name | ZHANG_TARGETS_OF_EWSR1_FLI1_FUSION
Systematic name | M18322
Organism | Homo sapiens
PMID | 15930281
Authors | Hu-Lieskovan S,Zhang J,Wu L,Shimada H,Schofield DE,Triche TJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RD-EF cells (rhabdomyosarcoma) engineered to express EWSR1-FLI1 fusion [GeneID=2130;2313] and which are also highly expressed in Ewing's famliy tumors.
Full description | Tumor-specific translocations are common in tumors of mesenchymal origin. Whether the translocation determines the phenotype, or vice versa, is debatable. Ewing's family tumors (EFT) are consistently associated with an EWS-FLI1 translocation and a primitive neural phenotype. Histogenesis and classification are therefore uncertain. To test whether EWS-FLI1 fusion gene expression is responsible for the primitive neuroectodermal phenotype of EFT, we established a tetracycline-inducible EWS-FLI1 expression system in a rhabdomyosarcoma cell line RD. Cell morphology changed after EWS-FLI1 expression, resembling cultured EFT cells. Xenografts showed typical EFT features, distinct from tumors formed by parental RD. Neuron-specific microtubule gene MAPT, parasympathetic marker cholecystokinin, and epithelial marker keratin 18 were up-regulated. Conversely, myogenesis was diminished. Comparison of the up-regulated genes in RD-EF with the Ewing's signature genes identified important EWS-FLI1 downstream genes, many involved in neural crest differentiation. These results were validated by real-time reverse transcription-PCR analysis and RNA interference technology using small interfering RNA against EWS-FLI1 breakpoint. The present study shows that the neural phenotype of Ewing's tumors is attributable to the EWS-FLI1 expression and the resultant phenotype resembles developing neural crest. Such tumors have a limited neural phenotype regardless of tissue of origin. These findings challenge traditional views of histogenesis and tumor origin.

Standard name | ZHAN_MULTIPLE_MYELOMA_SUBGROUPS
Systematic name | M17405
Organism | Homo sapiens
PMID | 11861292
Authors | Zhan F,Hardin J,Kordsmeier B,Bumm K,Zheng M,Tian E,Sanderson R,Yang Y,Wilson C,Zangari M,Anaissie E,Morris C,Muwalla F,van Rhee F,Fassas A,Crowley J,Tricot G,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | Top genes up-regulated in MM4 vs MM1 subgroup of multiple myeloma samples.
Full description | Bone marrow plasma cells (PCs) from 74 patients with newly diagnosed multiple myeloma (MM), 5 with monoclonal gammopathy of undetermined significance (MGUS), and 31 healthy volunteers (normal PCs) were purified by CD138(+) selection. Gene expression of purified PCs and 7 MM cell lines were profiled using high-density oligonucleotide microarrays interrogating about 6800 genes. On hierarchical clustering analysis, normal and MM PCs were differentiated and 4 distinct subgroups of MM (MM1, MM2, MM3, and MM4) were identified. The expression pattern of MM1 was similar to normal PCs and MGUS, whereas MM4 was similar to MM cell lines. Clinical parameters linked to poor prognosis, abnormal karyotype (P =.002) and high serum beta(2)-microglobulin levels (P =.0005), were most prevalent in MM4. Also, genes involved in DNA metabolism and cell cycle control were overexpressed in a comparison of MM1 and MM4. In addition, using chi(2) and Wilcoxon rank sum tests, 120 novel candidate disease genes were identified that discriminate normal and malignant PCs (P <.0001); many are involved in adhesion, apoptosis, cell cycle, drug resistance, growth arrest, oncogenesis, signaling, and transcription. A total of 156 genes, including FGFR3 and CCND1, exhibited highly elevated (spiked) expression in at least 4 of the 74 MM cases (range, 4-25 spikes). Elevated expression of these 2 genes was caused by the translocation t(4;14)(p16;q32) or t(11;14)(q13;q32). Thus, novel candidate MM disease genes have been identified using gene expression profiling and this profiling has led to the development of a gene-based classification system for MM.

Standard name | HADDAD_T_LYMPHOCYTE_AND_NK_PROGENITOR_UP
Systematic name | M17082
Organism | Homo sapiens
PMID | 15331438
Authors | Haddad R,Guardiola P,Izac B,Thibault C,Radich J,Delezoide AL,Baillou C,Lemoine FM,Gluckman JC,Pflumio F,Canque B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hematopoietic progenitor cells (HPC) of T lymphocyte and NK (natural killer) lineage.
Full description | The early stages of human lymphopoiesis are poorly characterized. Here, we compared the lymphoid potential of a novel umbilical cord blood CD34(+)CD45RA(hi)CD7(+) hematopoietic progenitor cell (HPC) population with that of CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs, previously proposed as candidate common lymphoid progenitors. Limiting-dilution and clonal analysis, fetal thymic organ cultures, and culture onto Notch ligand Delta-like-1-expressing OP9 cells, showed that although CD34(+)CD45RA(hi)CD7(+) HPCs could generate cells of the 3 lymphoid lineages, their potential was skewed toward the T/natural killer (T/NK) lineages. In contrast, CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs predominantly exhibited a B-cell potential. Gene expression profiling with DNA microarrays confirmed that CD34(+)CD45RA(hi)CD7(+) HPCs selectively expressed T-lymphoid and NK lineage-committed genes while retaining expression of genes affiliated to the granulomonocytic lineage, whereas CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs displayed a typical pro-B-cell transcription profile and essentially lacked genes unrelated to the B lineage. In addition, both populations could be generated in vitro from CD34(+)CD45RA(int)CD7(-) and CD34(+)CD45RA(hi)Lin(-) HPCs with mixed lymphomyeloid potential, from which they emerged independently with different growth/differentiation factor requirements. These findings indicate that CD34(+)CD45RA(hi)CD7(+) and CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs correspond to multipotent early lymphoid progenitors polarized toward either the T/NK or B lineage, respectively.

Standard name | MA_MYELOID_DIFFERENTIATION_DN
Systematic name | M1433
Organism | Mus musculus
PMID | 12130493
Authors | Ma X,Husain T,Peng H,Lin S,Mironenko O,Maun N,Johnson S,Tuck D,Berliner N,Krause DS,Perkins AS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during myeloid differentiation induced by tretinoin (ATRA) [PubChem=444795] and IL3 [GeneID=3652] in the EML cell line (myeloid progenitor).
Full description | With the goal of creating a resource for in-depth study of myelopoiesis, we have executed a 2-pronged strategy to obtain a complementary DNA (cDNA) clone set enriched in hematopoietic genes. One aspect is a library subtraction to enrich for underrepresented transcripts present at early stages of hematopoiesis. For this, a hematopoietic cDNA library from primary murine bone marrow cells enriched for primitive progenitors was used as tester. The subtraction used 10 000 known genes and expressed sequence tags (ESTs) as driver. The 2304 randomly picked clones from the subtracted cDNA libraries represent 1255 distinct genes, of which 622 (50%) are named genes, 386 (30%) match uncharacterized ESTs, and 247 (20%) are novel. The second aspect of our strategy was to complement this subtracted library with genes known to be involved in myeloid cell differentiation and function. The resulting cDNAs were arrayed on polylysine-coated glass slides. The microarrays were used to analyze gene expression in primary and cultured murine bone marrow-derived progenitors. We found expression of various types of genes, including regulatory cytokines and their receptors, signal transduction genes, and transcription factors. To assess gene expression during myeloid differentiation, we examined patterns of change during induced differentiation of EML cells. Several hundred of the genes underwent fluctuations in expression level during myeloid cell differentiation. The complete database, accessible on the World Wide Web at http://yale130132115135.med.yale.edu/, allows for retrieval of information regarding these genes. Our microarray allows for genomewide expression analysis of myeloid stem cells, which will help in defining the regulatory mechanisms of stem cell differentiation.

Standard name | GALINDO_IMMUNE_RESPONSE_TO_ENTEROTOXIN
Systematic name | M1435
Organism | Mus musculus
PMID | 12824169
Authors | Galindo CL,Sha J,Ribardo DA,Fadl AA,Pillai L,Chopra AK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in macrophages by aerolysin-related cytotoxic enterotoxin (Act) from Aeromonas hydrophila.
Full description | A cytotoxic enterotoxin (Act) of Aeromonas hydrophila possesses several biological activities, and it induces an inflammatory response in the host. In this study, we used microarrays to gain a global and molecular view of the cellular transcriptional responses to Act and to identify important genes up-regulated by this toxin. Total RNA was isolated at 0, 2, and 12 h from Act-treated macrophages and applied to Affymetrix MGU74 arrays, and the data were processed using a multi-analysis approach to identify genes that might be critical in the inflammatory process evoked by Act. Seventy-six genes were significantly and consistently up-regulated. Many of these genes were immune-related, and several were transcription factors, adhesion molecules, and cytokines. Additionally, we identified several apoptosis-associated genes that were significantly up-regulated in Act-treated macrophages. Act-induced apoptosis of macrophages was confirmed by annexin V staining and DNA laddering. Quantitative reverse transcriptase-polymerase chain reaction (RT-PCR) and enzyme-linked immunosorbent assay were used to verify increased expression of some inflammatory and apoptosis-associated genes identified by the microarray analysis. To further confirm Act-induced increases in gene expression, real-time RT-PCR was also used for selected genes. Taken together, the array data provided for the first time a global view of Act-mediated signal transduction and clearly demonstrated an inflammatory response and apoptosis mediated by this toxin in host cells at the molecular level.

Standard name | VERNELL_RETINOBLASTOMA_PATHWAY_DN
Systematic name | M12456
Organism | Homo sapiens
PMID | 12923195
Authors | Vernell R,Helin K,Müller H
Category | C2
Sub-category | CGP
Brief description | Cluster 2: genes down-regulated by RB1, CDNK2A [GeneID=1029;5925], and one of the E2Fs (E2F1, E2F2, or E2F3 [GeneID=1869;1870;1871]).
Full description | Deregulation of the retinoblastoma protein (pRB) pathway is a hallmark of human cancer. The core members of this pathway include the tumor suppressor protein, pRB, which through binding to a number of cellular proteins, most notably members of the E2F transcription factor family, regulates progression through the cell division cycle. With the aim of identifying transcriptional changes provoked by deregulation of the pRB pathway, we have used cell lines that conditionally express a constitutively active phosphorylation site mutant of pRB (pRBDeltaCDK) or p16INK4A (p16). The expression of pRBDeltaCDK and p16 resulted in significant repression and activation of a large number of genes as measured by high density oligonucleotide array analysis. Transcriptional changes were found in genes that are essential for DNA replication and cell proliferation. In agreement with previous results, we found a high degree of overlap between genes regulated by p16 and pRB. Data we have obtained previously for E2F family members showed that 74 of the genes repressed by pRB and p16 were induced by the E2Fs and 23 genes that were induced by pRB and p16 were repressed by the E2Fs. Thus, we have identified 97 genes as physiological targets of the pRB pathway, and the further characterization of these genes should provide insights into how this pathway controls proliferation. We show that Gibbs sampling detects enrichment of several sequence motifs, including E2F consensus binding sites, in the upstream regions of these genes and use this enrichment in an in silico filtering process to refine microarray derived gene lists.

Standard name | HASLINGER_B_CLL_WITH_MUTATED_VH_GENES
Systematic name | M11120
Organism | Homo sapiens
PMID | 15459216
Authors | Haslinger C,Schweifer N,Stilgenbauer S,Döhner H,Lichter P,Kraut N,Stratowa C,Abseher R
Category | C2
Sub-category | CGP
Brief description | Genes changed in the B cell chronic lymphocytic leukemia (B-CLL) with mutations in the variable immunoglobulin veriable heavy chain (VH) genes.
Full description | PURPOSE: Genomic aberrations and mutational status of the immunoglobulin variable heavy chain (VH) gene have been shown to be among the most important predictors for outcome in patients with B-cell chronic lymphocytic leukemia (B-CLL). In this study, we report on differential gene expression patterns that are characteristic for genetically defined B-CLL subtypes. MATERIALS AND METHODS: One hundred genetically well-characterized B-CLL samples, together with 11 healthy control samples, were analyzed using oligonucleotide arrays, which test for the expression of some 12,000 human genes. RESULTS: Aiming at microarray-based subclassification, class predictors were constructed using sets of differentially expressed genes, which yielded in zero or low misclassification rates. Furthermore, a significant number of the differentially expressed genes clustered in chromosomal regions affected by the respective genomic losses/gains. Deletions affecting chromosome bands 11q22-q23 and 17p13 led to a reduced expression of the corresponding genes, such as ATM and p53, while trisomy 12 resulted in the upregulation of genes mapping to chromosome arm 12q. Using an unsupervised analysis algorithm, expression profiling allowed partitioning into predominantly VH-mutated versus unmutated patient groups; however, association of the expression profile with the VH mutational status could only be detected in male patients. CONCLUSION: The finding that the most significantly differentially expressed genes are located in the corresponding aberrant chromosomal regions indicates that a gene dosage effect may exert a pathogenic role in B-CLL. The significant difference in the partitioning of male and female B-CLL samples suggests that the genomic signature for the VH mutational status might be sex-related.

Standard name | CROMER_METASTASIS_UP
Systematic name | M7061
Organism | Homo sapiens
PMID | 14676830
Authors | Cromer A,Carles A,Millon R,Ganguli G,Chalmel F,Lemaire F,Young J,Dembélé D,Thibault C,Muller D,Poch O,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Metastatic propensity markers of head and neck squamous cell carcinoma (HNSCC): up-regulated in metastatic vs non-metastatic tumors.
Full description | Head and neck squamous cell carcinoma (HNSCC) is the sixth most common cancer among men in the developed world. There is a need, for both clinical and scientific reasons, to find markers to identify patients with aggressive disease as early as possible, and to understand the events leading to malignant transformation and susceptibility to metastasis. We report the first large-scale gene expression analysis of a unique HNSCC location, the hypopharynx. Four normal and 34 tumour samples were analysed with 12 600 gene microarrays. Clusters of differentially expressed genes were identified in the chromosomal regions 3q27.3, 17q21.2-q21.31, 7q11.22-q22.1 and 11q13.1-q13.3, which, interestingly, have already been identified by comparative genomic hybridization (CGH) as major regions of gene amplification. We showed that six overexpressed genes (EIF4G1, DVL3, EPHB4, MCM7, BRMS1 and SART1) located in these regions are indeed amplified. We report 119 genes that are highly differentially expressed between 'early' tumours and normal samples. Of these, we validated by quantitative PCR six novel poorly characterized genes. These genes are potential new markers of HNSCC. Comparing patients with relatively nonaggressive and aggressive tumours (without or with clinical evidence of metastasis 3 years after surgery), we identified 164 differentially expressed genes potentially involved in the acquisition of metastatic potential. This study contributes to the understanding of HNSCC, staging patients into prognostic groups and identifying high-risk patients who may benefit from more aggressive treatment.

Standard name | ZHAN_MULTIPLE_MYELOMA_CD1_AND_CD2_DN
Systematic name | M16649
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Genes commonly down-regulated in CD-1 and CD-2 clusters of multiple myeloma samples and which were higher expressed in the CD-1 group.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | GUO_HEX_TARGETS_UP
Systematic name | M1436
Organism | Mus musculus
PMID | 12791650
Authors | Guo Y,Chan R,Ramsey H,Li W,Xie X,Shelley WC,Martinez-Barbera JP,Bort B,Zaret K,Yoder M,Hromas R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in day 6 embryoid bodies derived from embryonic stem cells (ES) with HEX [GeneID=3087] knockout.
Full description | The first hematopoietic and endothelial progenitors are derived from a common embryonic precursor termed the hemangioblast. The genetic cascades that regulate the differentiation of the hemangioblast to hematopoietic and endothelial cells are largely unknown. In general, much of embryonic development is coordinately regulated by temporal and spatial expression of transcription factors, such as the Homeobox (Hox) gene family. We and others isolated a divergent homeobox gene termed Hex (or Prh) that is preferentially expressed in hematopoietic and endothelial cells. Using in vitro Hex-/- embryonic stem (ES) cell differentiation, in vivo yolk sac hematopoietic progenitor assays, and chimeric mouse analysis, we found that Hex is required for differentiation of the hemangioblast to definitive embryonic hematopoietic progenitors and to a lesser extent endothelial cells. Therefore, Hex is a novel regulator of hemangioblast differentiation to hematopoietic and endothelial cells.

Standard name | WANG_IMMORTALIZED_BY_HOXA9_AND_MEIS1_DN
Systematic name | M1437
Organism | Mus musculus
PMID | 15755900
Authors | Wang GG,Pasillas MP,Kamps MP
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in myeloid progenitors immortalized by HOXA9 [GeneID=3205] vs those immortalized by HOXA9 and MEIS1 [GeneID=4211].
Full description | Meis1 is a homeodomain transcription factor coexpressed with Hoxa9 in most human acute myeloid leukemias (AMLs). In mouse models of leukemia produced by Hoxa9, Meis1 accelerates leukemogenesis. Because Hoxa9 immortalizes myeloid progenitors in the absence of Meis1 expression, the contribution of Meis1 toward leukemia remains unclear. Here, we describe a cultured progenitor model in which Meis1 programs leukemogenicity. Progenitors immortalized by Hoxa9 in culture are myeloid-lineage restricted and only infrequently caused leukemia after more than 250 days. Coexpressed Meis1 programmed rapid AML-initiating character, maintained multipotent progenitor potential, and induced expression of genes associated with short-term hematopoietic stem cells (HSCs), such as FLT3 and CD34, whose expression also characterizes the leukemia-initiating stem cells of human AML. Meis1 leukemogenesis functions required binding to Pbx, binding to DNA, and a conserved function of its C-terminal tail. We hypothesize that Meis1 is required for the homing and survival of leukemic progenitors within their hematopoietic niches, functions mediated by HSC-specific genes such as CD34 and Fms-like tyrosine kinase 3 (FLT3), respectively. This is the first example of a transcription factor oncoprotein (Meis1) that establishes expression of a tyrosine kinase oncoprotein (FLT3), and explains their coexpression in human leukemia. This cultured progenitor model will be useful to define the genetic basis of leukemogenesis involving Hoxa9 and Meis1.

Standard name | ALCALAY_AML_BY_NPM1_LOCALIZATION_UP
Systematic name | M9377
Organism | Homo sapiens
PMID | 15831697
Authors | Alcalay M,Tiacci E,Bergomas R,Bigerna B,Venturini E,Minardi SP,Meani N,Diverio D,Bernard L,Tizzoni L,Volorio S,Luzi L,Colombo E,Lo Coco F,Mecucci C,Falini B,Pelicci PG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in acute myeloid leukemia (AML) with respect to cellular localization of NPM1 [GeneID=4869]: cytoplasmic vs. nucleolar.
Full description | Approximately one third of acute myeloid leukemias (AMLs) are characterized by aberrant cytoplasmic localization of nucleophosmin (NPMc+ AML), consequent to mutations in the NPM putative nucleolar localization signal. These events are mutually exclusive with the major AML-associated chromosomal rearrangements, and are frequently associated with normal karyotype, FLT3 mutations, and multilineage involvement. We report the gene expression profiles of 78 de novo AMLs (72 with normal karyotype; 6 without major chromosomal abnormalities) that were characterized for the subcellular localization and mutation status of NPM. Unsupervised clustering clearly separated NPMc+ from NPMc- AMLs, regardless of the presence of FLT3 mutations or non-major chromosomal rearrangements, supporting the concept that NPMc+ AML represents a distinct entity. The molecular signature of NPMc+ AML includes up-regulation of several genes putatively involved in the maintenance of a stem-cell phenotype, suggesting that NPMc+ AML may derive from a multipotent hematopoietic progenitor.

Standard name | FAELT_B_CLL_WITH_VH_REARRANGEMENTS_UP
Systematic name | M7202
Organism | Homo sapiens
PMID | 15817677
Authors | Fält S,Merup M,Tobin G,Thunberg U,Gahrton G,Rosenquist R,Wennborg A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in B-CLL (B-cell chronic lymphocytic leukemia) patients with mutated immunoglobulin variable heavy chain (VH) genes.
Full description | The usage of the immunoglobulin (Ig) V(H)3-21 gene is associated with poor prognosis in B-cell chronic lymphocytic leukemia (B-CLL) despite V(H) gene mutation status. Many V(H)3-21+ patients also display restricted heavy- and light-chain Ig gene rearrangements, implying a role of antigen selection in disease development. To explore the specific phenotypic/genotypic features among V(H)3-21+ B-CLLs, we compared gene expression patterns in 15 V(H)3-21+ and 24 non-V(H)3-21 patients (11 with unmutated and 13 with mutated V(H) genes) using Affymetrix microarray analysis (approximately 12,500 genes). A distinct expression profile was identified for V(H)3-21+ patients in contrast to the Ig-unmutated and -mutated groups. By applying different algorithms, the data enabled an efficient class discrimination of the V(H)3-21+ subset based on 27 or 57 genes. A set of genes was sorted out which, using different analytical methods, consistently gave a distinction between V(H)3-21+ and non-V(H)3-21 samples. Several of these genes are involved in regulation of DNA replication/cell-cycle control, transcription and protein kinase activity, which may render the V(H)3-21+ cells with a higher proliferative drive. However, no clear evidence of increased B-cell receptor signaling was found in the V(H)3-21+ group. Altogether, our identification of a specific V(H)3-21 profile may provide insights into the pathogenesis of the V(H)3-21+ subgroup.

Standard name | HEDVAT_ELF4_TARGETS_UP
Systematic name | M8716
Organism | Homo sapiens
PMID | 14625302
Authors | Hedvat CV,Yao J,Sokolic RA,Nimer SD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HEL cells (erythroleukemia) upon expression of ELF4 [GeneID=2000].
Full description | Myeloid ELF1-like factor (MEF), also known as ELF4, is a member of the ETS family of transcription factors which is expressed in hematopoietic cells. MEF-deficient mice have defects in natural killer cell and natural killer T cell development, suggesting a role for MEF in regulating innate immunity. MEF also functions in myeloid cells, where it can transactivate target genes. To identify MEF target genes in a myeloid environment, we created an inducible expression system and used oligonucleotide microarrays to examine the transcript profile of HEL cells after induction of MEF expression. Sixteen genes were reproducibly turned on or off more than 2-fold, 8 h after induction of MEF expression, and we examined one of the genes, interleukin-8 (IL-8), in greater detail. IL-8 is a CXC chemokine involved in neutrophil chemoattraction, angiogenesis, and stem cell mobilization. It is expressed by several tumor types, and its expression is regulated primarily transcriptionally. The IL-8 promoter contains three ETS binding sites, and we identified the specific site that binds MEF and is required for MEF responsiveness. MEF, but not the closely related ETS factors PEA3, ETS1, ETS2, ELF1, or PU.1, strongly activates the IL-8 promoter. MEF overexpression is sufficient to induce IL-8 protein expression, and reduction in MEF expression (using RNA interference) results in decreased IL-8 levels. These data demonstrates that MEF is an important regulator of IL-8 expression.

Standard name | XU_RESPONSE_TO_TRETINOIN_AND_NSC682994_UP
Systematic name | M1276
Organism | Homo sapiens
PMID | 16140955
Authors | Xu K,Guidez F,Glasow A,Chung D,Petrie K,Stegmaier K,Wang KK,Zhang J,Jing Y,Zelent A,Waxman S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated synergistically in NB4 cells (acute promyelocytic leukemia, APL) by tretinoin and NSC682994 [PubChem=444795;388304].
Full description | Differentiation induction is an effective therapy for acute promyelocytic leukemia (APL), which dramatically responds to all-trans-retinoic acid (ATRA). Recent studies have indicated that combinatorial use of retinoid and nonretinoid compounds, such as histone deacetylase inhibitors, arsenics, and PKA agonists, has higher therapeutic value in this disease and potentially in other malignancies. In a screen of 370 compounds, we identified benzodithiophene analogues as potent enhancers of ATRA-induced APL cell differentiation. These effects were not associated with changes in global histone acetylation and, for the most potent compounds, were exerted at very low nanomolar concentrations, and were paralleled by enhancement of some, but not all, ATRA-modulated gene expressions. Investigating the mechanism underlying the effects of these drugs on ATRA-induced APL cell differentiation, we have shown that benzodithiophenes enhance ATRA-mediated dissociation and association of corepressor N-CoR and coactivator p300 acetyltransferase, respectively, with retinoic acid receptor (RAR) alpha proteins. These data suggest that benzodithiophenes act at the level of receptor activation, possibly by affecting posttranslational modification of the receptor (and/or coregulators), thus leading to an enhancement in ATRA-mediated effects on gene expression and APL cell differentiation. Given the specificities of these low benzodithiophene concentrations for PML-RARalpha and RARalpha, these drugs may be useful for combinatorial differentiation therapy of APL and possibly other acute myelogenous leukemia subtypes in which the overall ATRA signaling is suppressed.

Standard name | STOSSI_RESPONSE_TO_ESTRADIOL
Systematic name | M11695
Organism | Homo sapiens
PMID | 15033914
Authors | Stossi F,Barnett DH,Frasor J,Komm B,Lyttle CR,Katzenellenbogen BS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by estradiol (E2) [PubChem=5757] in U2OS cells (osteosarcoma) expressing ESR1 or ESR2 [GeneID=2099;2100].
Full description | Estrogens exert many important effects in bone, a tissue that contains both estrogen receptors alpha and beta (ERalpha and ERbeta). To compare the actions of these receptors, we generated U2OS human osteosarcoma cells stably expressing ERalpha or ERbeta, at levels comparable with those in osteoblasts, and we characterized their response to 17beta-estradiol (E2) over time using Affymetrix GeneChip microarrays to determine the expression of approximately 12,000 genes, followed by quantitative PCR verification of the regulation of selected genes. Of the approximately 100 regulated genes we identified, some were stimulated by E2 equally through ERalpha and ERbeta, whereas others were selectively stimulated via ERalpha or ERbeta. The E2-regulated genes showed three distinct temporal patterns of expression over the 48-h time course studied. Of the functional categories of the E2-regulated genes, most numerous were those encoding cytokines and factors associated with immune response, signal transduction, and cell migration and cytoskeleton regulation, indicating that E2 can exert effects on multiple pathways in these osteoblast-like cell lines. Of note, E2 up-regulated several genes associated with cell motility selectively via ERbeta, in keeping with the selective E2 enhancement of the motility of ERbeta-containing cells. On genes regulated equally by E2 via ERalpha or ERbeta, the phytoestrogen genistein preferentially stimulated gene expression via ERbeta. These studies indicate both common as well as distinct target genes for these two ERs, and identify many novel genes not previously known to be under estrogen regulation.

Standard name | YU_MYC_TARGETS_UP
Systematic name | M1249
Organism | Mus musculus
PMID | 16382050
Authors | Yu D,Cozma D,Park A,Thomas-Tikhonenko A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in B cell lymphoma tumors expressing an activated form of MYC [GeneID=4609].
Full description | The involvement of the c-Myc transcription factor in neoplastic transformation is well documented. However, which of its numerous target genes are crucial for tumorigenesis remains a frequently contested issue. We have recently established a non-transgenic murine model for B-cell lymphoma based on neoplastic conversion of p53-null bone marrow cells by conditionally active Myc. Using this model, we have identified a number of genes whose expression levels are affected by Myc during B-lymphomagenesis. Here we discuss their possible roles in neoplastic processes and describe an experimental approach allowing in vivo validation of these roles. We demonstrate that lymphoma cells overexpressing one of the Myc targets, the interleukin-10 receptor gene, have a very strong selective advantage over low IL10R expressors. Furthermore, Mcl1, a presumptive IL10R effector, also confers selective advantages when overexpressed in Myc-transformed hematopoietic cells. Thus, both IL10R and Mcl1 might be amenable to therapeutic interventions, and new targets can be identified and validated using the selection approach.

Standard name | MOREAUX_B_LYMPHOCYTE_MATURATION_BY_TACI_DN
Systematic name | M9193
Organism | Homo sapiens
PMID | 15827134
Authors | Moreaux J,Cremer FW,Reme T,Raab M,Mahtouk K,Kaukel P,Pantesco V,De Vos J,Jourdan E,Jauch A,Legouffe E,Moos M,Fiol G,Goldschmidt H,Rossi JF,Hose D,Klein B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in normal bone marrow plasma cells (BMPC) compared to polyclonal plasmablasts (PPC) that also distinguished multiple myeloma (MM) samples by expression of levels of TACI [GeneID=23495].
Full description | B-cell activating factor (BAFF) and a proliferation-inducing ligand (APRIL) have been shown to promote multiple myeloma (MM) cell growth. We show that the main site of production for BAFF and APRIL is the bone marrow (BM) environment, and that production is mainly by monocytes and neutrophils. In addition, osteoclasts produce very high levels of APRIL, unlike BM stromal cells. Myeloma cells (MMCs) express TACI (transmembrane activator and calcium modulator and cyclophilin ligand interactor), the receptor of BAFF/APRIL, at varying levels. TACI expression is a good indicator of a BAFF-binding receptor. Expression data of purified MMCs from 65 newly diagnosed patients have been generated using Affymetrix microarrays and were analyzed by supervised clustering of groups with higher (TACI(hi)) versus lower (TACI(lo)) TACI expression levels. Patients in the TACI(lo) group had clinical parameters associated with bad prognosis. A set of 659 genes was differentially expressed between TACI(hi) and TACI(lo) MMCs. This set makes it possible to efficiently classify TACI(hi) and TACI(lo) MMCs in an independent cohort of 40 patients. TACI(hi) MMCs displayed a mature plasma cell gene signature, indicating dependence on the BM environment. In contrast, the TACI(lo) group had a gene signature of plasmablasts, suggesting an attenuated dependence on the BM environment. Taken together, our findings suggest using gene expression profiling to identify the group of patients who might benefit most from treatment with BAFF/APRIL inhibitors.

Standard name | ABBUD_LIF_SIGNALING_2_UP
Systematic name | M1439
Organism | Rattus norvegicus
PMID | 14576184
Authors | Abbud RA,Kelleher R,Melmed S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in GH3 cells (pituitary cancer) after treatment with LIF [GeneID=3976].
Full description | Leukemia inhibitory factor (LIF) mediates the hypothalamo-pituitary-adrenal stress response. Transgenic mice overexpressing LIF in the developing pituitary have altered pituitary differentiation with expansion of corticotropes, maintenance of Rathke's cleft cysts, and suppression of all other pituitary cell types. Affymetrix GeneChips were used to identify modulators of LIF effects in corticotrope (AtT-20) and somatolactotrope (GH(3)) cells. In addition to genes known to respond to LIF in corticotrope cells [e.g. suppressor of cytokine signaling-3 (SOCS-3), signal transducer and activator of transcription-3, SH2 domain-containing tyrosine phosphatase-1, and proopiomelanocortin (POMC)], corticotrope-specific changes were also observed for genes involved in glycolysis and gluconeogenesis, transcription factors, signaling molecules, and expressed sequence tags. Two transcription factors identified, CCAAT/enhancer-binding protein beta (C/EBPbeta) and glial cell-derived neurotrophic factor (GDNF)-inducible factor (GIF), dose-dependently induced expression of the rat POMC promoter when overexpressed in AtT-20 cells. LIF further induced POMC transcription with C/EBPbeta, but not with GIF. C/EBPbeta also induced expression of the SOCS-3 promoter that was further enhanced by cotreatment with LIF. However, GIF did not affect SOCS-3 expression. These results indicate that C/EBPbeta and GIF are downstream effectors of LIF corticotrope action. LIF also stimulates the expression of inhibitors of its actions, such as SOCS-3 and SH2 domain-containing tyrosine phosphatase-1. alpha(2)-HS-glycoprotein (AHSG)/fetuin, a secreted protein that antagonizes bone TGFbeta/bone morphogenic protein signaling, was induced by LIF in a signal transducer and activator of transcription-3-dependent fashion. Pretreatment with AHSG/fetuin blocked LIF-induced expression of the POMC promoter independently of SOCS-3. Thus, using GeneChips, C/EBPbeta and GIF have been identified as novel mediators and AHSG/fetuin as an inhibitor of LIF action in corticotropes.

Standard name | PARK_HSC_MARKERS
Systematic name | M6509
Organism | Mus musculus
PMID | 11781229
Authors | Park IK,He Y,Lin F,Laerum OD,Tian Q,Bumgarner R,Klug CA,Li K,Kuhr C,Doyle MJ,Xie T,Schummer M,Sun Y,Goldsmith A,Clarke MF,Weissman IL,Hood L,Li L
Category | C2
Sub-category | CGP
Brief description | Genes in a cCDNA library from hematopoietic stem cells (HSC) after subtraction of lineage-specific markers.
Full description | Hematopoietic stem cells (HSCs) have self-renewal capacity and multilineage developmental potentials. The molecular mechanisms that control the self-renewal of HSCs are still largely unknown. Here, a systematic approach using bioinformatics and array hybridization techniques to analyze gene expression profiles in HSCs is described. To enrich mRNAs predominantly expressed in uncommitted cell lineages, 54 000 cDNA clones generated from a highly enriched population of HSCs and a mixed population of stem and early multipotent progenitor (MPP) cells were arrayed on nylon membranes (macroarray or high-density array), and subtracted with cDNA probes derived from mature lineage cells including spleen, thymus, and bone marrow. Five thousand cDNA clones with very low hybridization signals were selected for sequencing and further analysis using microarrays on glass slides. Two populations of cells, HSCs and MPP cells, were compared for differential gene expression using microarray analysis. HSCs have the ability to self-renew, while MPP cells have lost the capacity for self-renewal. A large number of genes that were differentially expressed by enriched populations of HSCs and MPP cells were identified. These included transcription factors, signaling molecules, and previously unknown genes.

Standard name | FERRANDO_T_ALL_WITH_MLL_ENL_FUSION_UP
Systematic name | M6434
Organism | Homo sapiens
PMID | 12637319
Authors | Ferrando AA,Armstrong SA,Neuberg DS,Sallan SE,Silverman LB,Korsmeyer SJ,Look AT
Category | C2
Sub-category | CGP
Brief description | Top 100 genes positively associated with T-cell acute lymphoblastic leukemia MLL T-ALL) expressing MLL-ENL fusion [GeneID=4297;4298].
Full description | Rearrangements of the MLL locus, located on human chromosome 11q23, are frequent in both infant and therapy-related leukemias. Gene expression analysis of MLL-rearranged B-precursor acute lymphoblastic leukemias (MLL B-ALLs) has identified these cases as a unique subtype of leukemia, characterized by the expression of genes associated with both lymphoid and myeloid hematopoietic lineages. Here we show that MLL fusions also generate a distinct genetic subtype of T-lineage ALL (MLL T-ALL), in which leukemic cells are characterized by an early arrest in thymocyte differentiation, with suggestive evidence of commitment to the gammadelta lineage. Interestingly, multiple genes linked to cell proliferation (eg, PCNA, MYC, CDK2, and POLA) were down-regulated in MLL-fusion samples, relative to those transformed by other T-ALL oncogenes (P <.000 001, Fisher exact test). Overall, MLL T-ALL cases consistently demonstrated increased levels of expression of a subset of major HOX genes--HOXA9, HOXA10, and HOXC6--and the MEIS1 HOX coregulator (P <.008, one-sided Wilcoxon test), a pattern of gene expression that was reiterated in MLL B-ALLs. However, expression of myeloid lineage genes, previously reported in MLL B-ALLs, was not identified in T-lineage cases with this abnormality, suggesting that myeloid gene dysregulation is dispensable in leukemic transformation mediated by MLL fusion proteins. Our findings implicate dysregulation of HOX gene family members as a dominant mechanism of leukemic transformation induced by chimeric MLL oncogenes.

Standard name | HOFMANN_CELL_LYMPHOMA_DN
Systematic name | M8537
Organism | Homo sapiens
PMID | 11468180
Authors | Hofmann WK,de Vos S,Tsukasaki K,Wachsman W,Pinkus GS,Said JW,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in lymph nodes from patients with mantle cell lymphoma (MCL) compared to the non-malignant hyperplastic lymph nodes.
Full description | An imbalance between cellular apoptosis and survival may be critical for the pathogenesis of lymphoma. Therefore, the gene expression pattern in lymph node preparations from patients with mantle cell lymphoma (MCL) was compared to the pattern in nonmalignant hyperplastic lymph nodes (HLs). Oligonucleotide microarray analysis was performed comparing 5 MCLs to 4 HLs using high-density microarrays. The expression data were analyzed using Genespring software. For confirmation, the expression of selected genes was analyzed by real-time polymerase chain reaction using the RNA extracted from 16 MCL and 12 HL samples. The focus was on 42 genes that were at least 3-fold down-regulated in MCL; in addition to the B-cell leukemia 2 (BCL2) system other apoptotic pathways were altered in MCL. The FAS-associated via death domain (FADD) gene that acts downstream of the FAS cascade as a key gene to induce apoptosis was more than 10-fold down-regulated in MCL. Furthermore, the death-associated protein 6 (DAXX) gene, the caspase 2 (CASP2) gene, and the RIPK1 domain containing adapter with death domain (RAIDD) gene, which are key genes in other proapoptotic pathways, were also decreased in the MCL samples. The suggestion is made that in addition to the known overexpression of cyclin D1, which drives entry into the cell cycle, disturbances of pathways associated with apoptosis contribute to the development of MCL. (Blood. 2001;98:787-794)

Standard name | ZHAN_MULTIPLE_MYELOMA_CD1_VS_CD2_UP
Systematic name | M1679
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD-1 compared to CD-2 cluster of multiple myeloma samples.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | MATSUDA_NATURAL_KILLER_DIFFERENTIATION
Systematic name | M18517
Organism | Mus musculus
PMID | 16357323
Authors | Matsuda JL,Zhang Q,Ndonye R,Richardson SK,Howell AR,Gapin L
Category | C2
Sub-category | CGP
Brief description | Genes changed between developmental stages of Valpha14i natural killer T lymphocyte cells (NKT).
Full description | Valpha14i natural killer T (NKT)-cell function has been implicated in a number of disease conditions. The molecular events that drive Valpha14i NKT-cell development remain elusive. We recently showed that T-bet is required for the terminal maturation of these cells. Here we identify some of the genetic targets of T-bet during Valpha14i NKT-cell lineage development. Microarray gene-expression analyses on developing Valpha14i NKT cells were performed and provide a molecular framework to study these maturation events. In vitro ectopic expression of T-bet in immature Valpha14i NKT cells, which do not yet express T-bet, was sufficient to promote Valpha14i NKT-cell maturation, driving the expression of multiple genes, including those that participate in migration, survival, and effector functions. By regulating the expression of T-helper 1 (Th1)-associated cytokines, chemokines, chemokine receptors, and molecules involved in cytolysis, T-bet defines the unique lineage attributes of mature Valpha14i NKT cells and acts to link these attributes to a developmental process.

Standard name | WANG_TARGETS_OF_MLL_CBP_FUSION_UP
Systematic name | M1440
Organism | Mus musculus
PMID | 15635450
Authors | Wang J,Iwasaki H,Krivtsov A,Febbo PG,Thorner AR,Ernst P,Anastasiadou E,Kutok JL,Kogan SC,Zinkel SS,Fisher JK,Hess JL,Golub TR,Armstrong SA,Akashi K,Korsmeyer SJ
Category | C2
Sub-category | CGP
Brief description | Top 50 genes up-regulated in granulocyte/macrophage progenitors (GMP) upon expression of MLL-CBP fusion [GeneID=4297;1387].
Full description | Chromosomal translocations that fuse the mixed lineage leukemia (MLL) gene with multiple partners typify acute leukemias of infancy as well as therapy-related leukemias. We utilized a conditional knockin strategy to bypass the embryonic lethality caused by MLL-CBP expression and to assess the immediate effects of induced MLL-CBP expression on hematopoiesis. Within days of activating MLL-CBP, the fusion protein selectively expanded granulocyte/macrophage progenitors (GMP) and enhanced their self-renewal/proliferation. MLL-CBP altered the gene expression program of GMP, upregulating a subset of genes including Hox a9. Inhibition of Hox a9 expression by RNA interference demonstrated that MLL-CBP required Hox a9 for its enhanced cell expansion. Following exposure to sublethal gamma-irradiation or N-ethyl-N-nitrosourea (ENU), MLL-CBP mice developed myelomonocytic hyperplasia and progressed to fatal myeloproliferative disorders. These represented the spectrum of therapy-induced acute myelomonocytic leukemia/chronic myelomonocytic leukemia/myelodysplastic/myeloproliferative disorder similar to that seen in humans possessing the t(11;16). This model of MLL-CBP therapy-related myeloproliferative disease demonstrates the selectivity of this MLL fusion for GMP cells and its ability to initiate leukemogenesis in conjunction with cooperating mutations.

Standard name | STONER_ESOPHAGEAL_CARCINOGENESIS_UP
Systematic name | M1442
Organism | Rattus norvegicus
PMID | 18676871
Authors | Stoner GD,Dombkowski AA,Reen RK,Cukovic D,Salagrama S,Wang LS,Lechner JF
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in esophagus by the carcinogen NMBA [PubChem=13643] and brought back to normal by a diet with PEITC [PubChem=16741] or black raspberries.
Full description | Our recent study identified 2,261 dysregulated genes in the esophagi of rats that received a 1-week exposure to the carcinogen N-nitrosomethylbenzylamine (NMBA). We further reported that 1,323 of these genes were positively modulated to near-normal levels of expression in NMBA-treated animals that consumed dietary phenylethyl isothiocyanate (PEITC), a constituent of cruciferous vegetables. Herein, we report our results with companion animals that were fed a diet containing 5% freeze-dried black raspberries (BRB) instead of PEITC. We found that 462 of the 2,261 NMBA-dysregulated genes in rat esophagus were restored to near-normal levels of expression by BRB. Further, we have identified 53 NMBA-dysregulated genes that are positively modulated by both PEITC and BRB. These 53 common genes include genes involved in phase I and II metabolism, oxidative damage, and oncogenes and tumor suppressor genes that regulate apoptosis, cell cycling, and angiogenesis. Because both PEITC and BRB maintain near-normal levels of expression of these 53 genes, their dysregulation during the early phase of NMBA-induced esophageal cancer may be especially important in the genesis of the disease.

Standard name | STONER_ESOPHAGEAL_CARCINOGENESIS_DN
Systematic name | M1444
Organism | Rattus norvegicus
PMID | 18676871
Authors | Stoner GD,Dombkowski AA,Reen RK,Cukovic D,Salagrama S,Wang LS,Lechner JF
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in esophagus by the carcinogen NMBA [PubChem=13643] and brought back to normal by a diet with PEITC [PubChem=16741] or black raspberries.
Full description | Our recent study identified 2,261 dysregulated genes in the esophagi of rats that received a 1-week exposure to the carcinogen N-nitrosomethylbenzylamine (NMBA). We further reported that 1,323 of these genes were positively modulated to near-normal levels of expression in NMBA-treated animals that consumed dietary phenylethyl isothiocyanate (PEITC), a constituent of cruciferous vegetables. Herein, we report our results with companion animals that were fed a diet containing 5% freeze-dried black raspberries (BRB) instead of PEITC. We found that 462 of the 2,261 NMBA-dysregulated genes in rat esophagus were restored to near-normal levels of expression by BRB. Further, we have identified 53 NMBA-dysregulated genes that are positively modulated by both PEITC and BRB. These 53 common genes include genes involved in phase I and II metabolism, oxidative damage, and oncogenes and tumor suppressor genes that regulate apoptosis, cell cycling, and angiogenesis. Because both PEITC and BRB maintain near-normal levels of expression of these 53 genes, their dysregulation during the early phase of NMBA-induced esophageal cancer may be especially important in the genesis of the disease.

Standard name | HASLINGER_B_CLL_WITH_13Q14_DELETION
Systematic name | M3941
Organism | Homo sapiens
PMID | 15459216
Authors | Haslinger C,Schweifer N,Stilgenbauer S,Döhner H,Lichter P,Kraut N,Stratowa C,Abseher R
Category | C2
Sub-category | CGP
Brief description | Genes changed in the B cell chronic lymphocytic leukemia (B-CLL) with deletions in the 13q14 region.
Full description | PURPOSE: Genomic aberrations and mutational status of the immunoglobulin variable heavy chain (VH) gene have been shown to be among the most important predictors for outcome in patients with B-cell chronic lymphocytic leukemia (B-CLL). In this study, we report on differential gene expression patterns that are characteristic for genetically defined B-CLL subtypes. MATERIALS AND METHODS: One hundred genetically well-characterized B-CLL samples, together with 11 healthy control samples, were analyzed using oligonucleotide arrays, which test for the expression of some 12,000 human genes. RESULTS: Aiming at microarray-based subclassification, class predictors were constructed using sets of differentially expressed genes, which yielded in zero or low misclassification rates. Furthermore, a significant number of the differentially expressed genes clustered in chromosomal regions affected by the respective genomic losses/gains. Deletions affecting chromosome bands 11q22-q23 and 17p13 led to a reduced expression of the corresponding genes, such as ATM and p53, while trisomy 12 resulted in the upregulation of genes mapping to chromosome arm 12q. Using an unsupervised analysis algorithm, expression profiling allowed partitioning into predominantly VH-mutated versus unmutated patient groups; however, association of the expression profile with the VH mutational status could only be detected in male patients. CONCLUSION: The finding that the most significantly differentially expressed genes are located in the corresponding aberrant chromosomal regions indicates that a gene dosage effect may exert a pathogenic role in B-CLL. The significant difference in the partitioning of male and female B-CLL samples suggests that the genomic signature for the VH mutational status might be sex-related.

Standard name | HOFMANN_CELL_LYMPHOMA_UP
Systematic name | M10783
Organism | Homo sapiens
PMID | 11468180
Authors | Hofmann WK,de Vos S,Tsukasaki K,Wachsman W,Pinkus GS,Said JW,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in lymph nodes from patients with mantle cell lymphoma (MCL) compared to the non-malignant hyperplastic lymph nodes.
Full description | An imbalance between cellular apoptosis and survival may be critical for the pathogenesis of lymphoma. Therefore, the gene expression pattern in lymph node preparations from patients with mantle cell lymphoma (MCL) was compared to the pattern in nonmalignant hyperplastic lymph nodes (HLs). Oligonucleotide microarray analysis was performed comparing 5 MCLs to 4 HLs using high-density microarrays. The expression data were analyzed using Genespring software. For confirmation, the expression of selected genes was analyzed by real-time polymerase chain reaction using the RNA extracted from 16 MCL and 12 HL samples. The focus was on 42 genes that were at least 3-fold down-regulated in MCL; in addition to the B-cell leukemia 2 (BCL2) system other apoptotic pathways were altered in MCL. The FAS-associated via death domain (FADD) gene that acts downstream of the FAS cascade as a key gene to induce apoptosis was more than 10-fold down-regulated in MCL. Furthermore, the death-associated protein 6 (DAXX) gene, the caspase 2 (CASP2) gene, and the RIPK1 domain containing adapter with death domain (RAIDD) gene, which are key genes in other proapoptotic pathways, were also decreased in the MCL samples. The suggestion is made that in addition to the known overexpression of cyclin D1, which drives entry into the cell cycle, disturbances of pathways associated with apoptosis contribute to the development of MCL. (Blood. 2001;98:787-794)

Standard name | GUO_HEX_TARGETS_DN
Systematic name | M1445
Organism | Mus musculus
PMID | 12791650
Authors | Guo Y,Chan R,Ramsey H,Li W,Xie X,Shelley WC,Martinez-Barbera JP,Bort B,Zaret K,Yoder M,Hromas R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in day 6 embryoid bodies derived from embryonic stem cells (ES) with HEX [GeneID=3087] knockout.
Full description | The first hematopoietic and endothelial progenitors are derived from a common embryonic precursor termed the hemangioblast. The genetic cascades that regulate the differentiation of the hemangioblast to hematopoietic and endothelial cells are largely unknown. In general, much of embryonic development is coordinately regulated by temporal and spatial expression of transcription factors, such as the Homeobox (Hox) gene family. We and others isolated a divergent homeobox gene termed Hex (or Prh) that is preferentially expressed in hematopoietic and endothelial cells. Using in vitro Hex-/- embryonic stem (ES) cell differentiation, in vivo yolk sac hematopoietic progenitor assays, and chimeric mouse analysis, we found that Hex is required for differentiation of the hemangioblast to definitive embryonic hematopoietic progenitors and to a lesser extent endothelial cells. Therefore, Hex is a novel regulator of hemangioblast differentiation to hematopoietic and endothelial cells.

Standard name | HSIAO_LIVER_SPECIFIC_GENES
Systematic name | M13283
Organism | Homo sapiens
PMID | 11773596
Authors | Hsiao LL,Dangond F,Yoshida T,Hong R,Jensen RV,Misra J,Dillon W,Lee KF,Clark KE,Haverty P,Weng Z,Mutter GL,Frosch MP,Macdonald ME,Milford EL,Crum CP,Bueno R,Pratt RE,Mahadevappa M,Warrington JA,Stephanopoulos G,Gullans SR
Category | C2
Sub-category | CGP
Brief description | Liver selective genes
Full description | This study creates a compendium of gene expression in normal human tissues suitable as a reference for defining basic organ systems biology. Using oligonucleotide microarrays, we analyze 59 samples representing 19 distinct tissue types. Of approximately 7,000 genes analyzed, 451 genes are expressed in all tissue types and designated as housekeeping genes. These genes display significant variation in expression levels among tissues and are sufficient for discerning tissue-specific expression signatures, indicative of fundamental differences in biochemical processes. In addition, subsets of tissue-selective genes are identified that define key biological processes characterizing each organ. This compendium highlights similarities and differences among organ systems and different individuals and also provides a publicly available resource (Human Gene Expression Index, the HuGE Index, http://www.hugeindex.org) for future studies of pathophysiology.

Standard name | GILDEA_METASTASIS
Systematic name | M2386
Organism | Homo sapiens
PMID | 12438227
Authors | Gildea JJ,Seraj MJ,Oxford G,Harding MA,Hampton GM,Moskaluk CA,Frierson HF,Conaway MR,Theodorescu D
Category | C2
Sub-category | CGP
Brief description | Top genes down-regulated in metastatic (T24T) vs non-metastatic (T24) bladder cancer cell lines.
Full description | To discover novel metastasis suppressor genes that are clinically relevant in common human cancers, we used isogenic human bladder cancer cell lines and used DNA microarray technology to identify genes whose expression diminishes as a function of invasive and metastatic competence. We then evaluated the expression profile of such genes in 105 pathologically characterized tumors from seven common organ sites, and we identified one gene, RhoGDI2, whose expression was diminished as a function of primary tumor stage and grade. When RhoGDI2 was transferred back into cells with metastatic ability that lacked its expression, it suppressed experimental lung metastasis but did not affect in vitro growth, colony formation, or in vivo tumorigenicity. In addition, RhoGDI2 reconstitution in these cells blocked invasion in an organotypic assay and led to a reduction of in vitro motility. These results indicate that RhoGDI2 is a metastasis suppressor gene, a marker of aggressive human cancer, and a promising target for therapy.

Standard name | ZHAN_MULTIPLE_MYELOMA_SPIKED
Systematic name | M896
Organism | Homo sapiens
PMID | 11861292
Authors | Zhan F,Hardin J,Kordsmeier B,Bumm K,Zheng M,Tian E,Sanderson R,Yang Y,Wilson C,Zangari M,Anaissie E,Morris C,Muwalla F,van Rhee F,Fassas A,Crowley J,Tricot G,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | 'Spiked' genes: genes most highly up-regulated in multiple myeloma samples; were not differentially expressed as compared to the normal plasma cells.
Full description | Bone marrow plasma cells (PCs) from 74 patients with newly diagnosed multiple myeloma (MM), 5 with monoclonal gammopathy of undetermined significance (MGUS), and 31 healthy volunteers (normal PCs) were purified by CD138(+) selection. Gene expression of purified PCs and 7 MM cell lines were profiled using high-density oligonucleotide microarrays interrogating about 6800 genes. On hierarchical clustering analysis, normal and MM PCs were differentiated and 4 distinct subgroups of MM (MM1, MM2, MM3, and MM4) were identified. The expression pattern of MM1 was similar to normal PCs and MGUS, whereas MM4 was similar to MM cell lines. Clinical parameters linked to poor prognosis, abnormal karyotype (P =.002) and high serum beta(2)-microglobulin levels (P =.0005), were most prevalent in MM4. Also, genes involved in DNA metabolism and cell cycle control were overexpressed in a comparison of MM1 and MM4. In addition, using chi(2) and Wilcoxon rank sum tests, 120 novel candidate disease genes were identified that discriminate normal and malignant PCs (P <.0001); many are involved in adhesion, apoptosis, cell cycle, drug resistance, growth arrest, oncogenesis, signaling, and transcription. A total of 156 genes, including FGFR3 and CCND1, exhibited highly elevated (spiked) expression in at least 4 of the 74 MM cases (range, 4-25 spikes). Elevated expression of these 2 genes was caused by the translocation t(4;14)(p16;q32) or t(11;14)(q13;q32). Thus, novel candidate MM disease genes have been identified using gene expression profiling and this profiling has led to the development of a gene-based classification system for MM.

Standard name | MUNSHI_MULTIPLE_MYELOMA_DN
Systematic name | M3900
Organism | Homo sapiens
PMID | 12969976
Authors | Munshi NC,Hideshima T,Carrasco D,Shammas M,Auclair D,Davies F,Mitsiades N,Mitsiades C,Kim RS,Li C,Rajkumar SV,Fonseca R,Bergsagel L,Chauhan D,Anderson KC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in multiple myeloma (MM) compared to normal plasma cells from the patient's identical twin.
Full description | Genetic heterogeneity between individuals confounds the comparison of gene profiling of multiple myeloma (MM) cells versus normal plasma cells (PCs). To overcome this barrier, we compared the gene expression profile of CD138+ MM cells from a patient bone marrow (BM) sample with CD138+ PCs from a genetically identical twin BM sample using microarray profiling. Two hundred and ninety-six genes were up-regulated and 103 genes were down-regulated at least 2-fold in MM cells versus normal twin PCs. Highly expressed genes in MM cells included cell survival pathway genes such as mcl-1, dad-1, caspase 8, and FADD-like apoptosis regulator (FLIP); oncogenes/transcriptional factors such as Jun-D, Xbp-1, calmodulin, Calnexin, and FGFR-3; stress response and ubiquitin/proteasome pathway-related genes and various ribosomal genes reflecting increased metabolic and translational activity. Genes that were down-regulated in MM cells versus healthy twin PCs included RAD51, killer cell immunoglobulin-like receptor protein, and apoptotic protease activating factor. Microarray results were further confirmed by Western blot analyses, immunohistochemistry, fluorescent in situ hybridization (FISH), and functional assays of telomerase activity and bone marrow angiogenesis. This molecular profiling provides potential insights into mechanisms of malignant transformation in MM. For example, FGFR3, xbp-1, and both mcl-1 and dad-1 may mediate transformation, differentiation, and survival, respectively, and may have clinical implications. By identifying genes uniquely altered in MM cells compared with normal PCs in an identical genotypic background, the current study provides the framework to identify novel therapeutic targets.

Standard name | ASTIER_INTEGRIN_SIGNALING
Systematic name | M3590
Organism | Homo sapiens
PMID | 12393420
Authors | Astier AL,Xu R,Svoboda M,Hinds E,Munoz O,de Beaumont R,Crean CD,Gabig T,Freedman AS
Category | C2
Sub-category | CGP
Brief description | Integrin signaling signature in precursor B leukemia (PBL) cells: fibronectin (FN1) [GeneID=2335] vs control treatment with poly-L-lysine.
Full description | The physical interactions between B cells and stromal cells from the lymphoid tissue microenvironment are critical to the survival of normal and malignant B cells. They are principally mediated by integrins expressed on B cells and counterreceptors on stromal cells. Specifically, alpha4beta1 integrin engagement rescues B cells from physiological or drug-induced apoptosis. Therefore, in order to understand the mechanisms by which integrins prevent apoptosis in leukemia B cells, we compared the temporal gene expression profiles induced by beta1-integrin ligation with fibronectin (Fn) or adhesion by poly-L-Lysine in serum-starved precursor B leukemia cells. Among the 38 selected differentially expressed genes, 6 genes involved in adhesion (VAV2, EPB41L1, CORO1A), proliferation (FRAP1, CCT4), and intercellular communication (GJB3) were validated by real-time quantitative polymerase chain reaction (RT-Q-PCR). Gene expression modulation could also be validated at the protein level for 5 other genes. We show that integrin stimulation up-regulated FBI-1 expression but inhibited CD79a, Requiem, c-Fos, and caspase 7 induction when the cells underwent apoptosis. We further demonstrate that Fn stimulation also inhibits caspase 3 activation but increases XIAP and survivin expression. Moreover, integrin stimulation also prevents caspase activation induced by doxorubicin. Therefore, we identified genes modulated by adhesion of human precursor B leukemia cells that regulate proliferation and apoptosis, highlighting new pathways that might provide insights into future therapy aiming at targeting apoptosis of leukemia cells.

Standard name | ZHAN_MULTIPLE_MYELOMA_LB_UP
Systematic name | M14744
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 up-regulated genes in cluster LB of multiple myeloma samples belonging to the low bone disease group.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | HASLINGER_B_CLL_WITH_11Q23_DELETION
Systematic name | M11509
Organism | Homo sapiens
PMID | 15459216
Authors | Haslinger C,Schweifer N,Stilgenbauer S,Döhner H,Lichter P,Kraut N,Stratowa C,Abseher R
Category | C2
Sub-category | CGP
Brief description | Genes changed in the B cell chronic lymphocytic leukemia (B-CLL) with deletions in the 11q23 region.
Full description | PURPOSE: Genomic aberrations and mutational status of the immunoglobulin variable heavy chain (VH) gene have been shown to be among the most important predictors for outcome in patients with B-cell chronic lymphocytic leukemia (B-CLL). In this study, we report on differential gene expression patterns that are characteristic for genetically defined B-CLL subtypes. MATERIALS AND METHODS: One hundred genetically well-characterized B-CLL samples, together with 11 healthy control samples, were analyzed using oligonucleotide arrays, which test for the expression of some 12,000 human genes. RESULTS: Aiming at microarray-based subclassification, class predictors were constructed using sets of differentially expressed genes, which yielded in zero or low misclassification rates. Furthermore, a significant number of the differentially expressed genes clustered in chromosomal regions affected by the respective genomic losses/gains. Deletions affecting chromosome bands 11q22-q23 and 17p13 led to a reduced expression of the corresponding genes, such as ATM and p53, while trisomy 12 resulted in the upregulation of genes mapping to chromosome arm 12q. Using an unsupervised analysis algorithm, expression profiling allowed partitioning into predominantly VH-mutated versus unmutated patient groups; however, association of the expression profile with the VH mutational status could only be detected in male patients. CONCLUSION: The finding that the most significantly differentially expressed genes are located in the corresponding aberrant chromosomal regions indicates that a gene dosage effect may exert a pathogenic role in B-CLL. The significant difference in the partitioning of male and female B-CLL samples suggests that the genomic signature for the VH mutational status might be sex-related.

Standard name | LEI_MYB_TARGETS
Systematic name | M863
Organism | Homo sapiens
PMID | 15105423
Authors | Lei W,Rushton JJ,Davis LM,Liu F,Ness SA
Category | C2
Sub-category | CGP
Brief description | Myb-regulated genes in MCF7 (breast cancer) and lung epithelial cell lines overexpressing MYBL2, MYBL1 or MYB [GeneID=4605;4603;4602].
Full description | The A-Myb and c-Myb transcription factors share a highly conserved DNA-binding domain and activate the same promoters in reporter gene assays. However, the two proteins have distinct biological activities, and expressing them individually in human cells leads to the activation of distinct sets of endogenous genes, suggesting that each protein has a unique transcriptional specificity. Here, the structural and functional features of the Myb proteins were compared, using assays of endogenous gene expression to measure changes in specificity. When the Myb proteins were tested in different cell types, they activated unique and nearly nonoverlapping sets of genes in each cellular context. Deletion and domain swap experiments identified small, discreet positive and negative elements in A-Myb and c-Myb that were required for the regulation of specific genes, such as DHRS2, DSIPI, and mim-1. The results suggest that individual functional elements in the transcriptional activation domains are responsible for activating specific cellular genes in a context-specific manner. The results also have important implications for interpreting results from reporter gene assays, which fail to detect the differences in activity identified through endogenous gene assays, and fusion protein constructs that alter the transcriptional activation domains and the activities of the Myb proteins.

Standard name | BROWN_MYELOID_CELL_DEVELOPMENT_DN
Systematic name | M1447
Organism | Mus musculus
PMID | 16769770
Authors | Brown AL,Wilkinson CR,Waterman SR,Kok CH,Salerno DG,Diakiw SM,Reynolds B,Scott HS,Tsykin A,Glonek GF,Goodall GJ,Solomon PJ,Gonda TJ,D'Andrea RJ
Category | C2
Sub-category | CGP
Brief description | Genes defining proliferation and self renewal potential of the bipotential myeloid cell line FDB.
Full description | Mechanisms controlling the balance between proliferation and self-renewal versus growth suppression and differentiation during normal and leukemic myelopoiesis are not understood. We have used the bi-potent FDB1 myeloid cell line model, which is responsive to myelopoietic cytokines and activated mutants of the granulocyte macrophage-colony stimulating factor (GM-CSF) receptor, having differential signaling and leukemogenic activity. This model is suited to large-scale gene-profiling, and we have used a factorial time-course design to generate a substantial and powerful data set. Linear modeling was used to identify gene-expression changes associated with continued proliferation, differentiation, or leukemic receptor signaling. We focused on the changing transcription factor profile, defined a set of novel genes with potential to regulate myeloid growth and differentiation, and demonstrated that the FDB1 cell line model is responsive to forced expression of oncogenes identified in this study. We also identified gene-expression changes associated specifically with the leukemic GM-CSF receptor mutant, V449E. Signaling from this receptor mutant down-regulates CCAAT/enhancer-binding protein alpha (C/EBPalpha) target genes and generates changes characteristic of a specific acute myeloid leukemia signature, defined previously by gene-expression profiling and associated with C/EBPalpha mutations.

Standard name | ROETH_TERT_TARGETS_DN
Systematic name | M2891
Organism | Homo sapiens
PMID | 15741219
Authors | Röth A,Baerlocher GM,Schertzer M,Chavez E,Dührsen U,Lansdorp PM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T lymphocytes overexpressing TERT [GeneID=7015] off a retrovirus vector.
Full description | Little is known about the long-term consequences of overexpression of the human telomerase reverse transcriptase (hTERT) gene in T lymphocytes. To address this issue, we transduced polyclonal as well as clonally derived populations of naive and memory CD44 T cells from 2 healthy donors (aged 24 and 34 years) with retroviral vectors encoding green fluorescence protein (GFP) and hTERT (GFP-hTERT) or GFP alone. After transduction, cells were sorted on the basis of GFP expression and cultured in vitro until senescence. T cells transduced with hTERT exhibited high stable telomerase activity throughout the culture period. Relative to GFP controls, minor changes in overall gene expression were observed yet the proliferative lifespan of the hTERT-transduced populations was significantly increased and the rate of telomere loss was lower. Nevertheless, hTERT-transduced cells showed progressive telomere loss and had shorter telomeres at senescence than controls (2.3 +/- 0.3 kilobase [kb] versus 3.4 +/- 0.1 kb). Furthermore, a population of cells with 4N DNA consisting of binucleated cells with connected nuclei emerged in the hTERT-transduced cells prior to senescence. We conclude that overexpression of hTERT in CD4+ T cells provides a proliferative advantage independent of the average telomere length but does not prevent eventual genetic instability and replicative senescence.

Standard name | NEMETH_INFLAMMATORY_RESPONSE_LPS_UP
Systematic name | M1448
Organism | Mus musculus
PMID | 12766259
Authors | Németh ZH,Leibovich SJ,Deitch EA,Vizi ES,Szabó C,Hasko G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RAW 264.7 cells (macrophage) 3 hr after stimulation with bacterial lipopolysaccharide (LPS).
Full description | Adenosine is released into the extracellular space from nerve terminals and cells subjected to ischemic stress. This nucleoside modulates a plethora of cellular functions via occupancy of specific receptors. Adenosine is also an important endogenous regulator of macrophage function, because it suppresses the production of a number of proinflammatory cytokines by these cells. However, the mechanisms of this anti-inflammatory effect have not been well characterized. We hypothesized that adenosine may exert some of its anti-inflammatory effects by decreasing activation of the transcription factor nuclear factor-kappaB (NF-kappaB), because gene expression of most of the proinflammatory cytokines inhibited by adenosine is dependent on NF-kappaB activation. Using bacterial lipopolysaccharide (LPS)-stimulated RAW 264.7 macrophages, we found that adenosine as well as adenosine receptor agonists decreased the production of tumor necrosis factor (TNF)-alpha, a typical NF-kappaB-regulated cytokine. This effect of adenosine was not due to an action on the process of TNF-alpha release, because adenosine suppressed also the intracellular levels of TNF-alpha. However, cDNA microarray analysis revealed that mRNA levels of neither TNF-alpha nor other cytokines were altered by adenosine in either LPS-activated or quiescent macrophages. In addition, although LPS induced expression of a number of other, noncytokine genes, including the adenosine A2b receptor, adenosine did not affect the expression of these genes. Furthermore, adenosine as well as adenosine receptor agonists failed to decrease LPS-induced NF-kappaB DNA binding, NF-kappaB promoter activity, p65 nuclear translocation, and inhibitory kappaB degradation. Together, our results suggest that the anti-inflammatory effects of adenosine are independent of NF-kappaB.

Standard name | LI_WILMS_TUMOR_VS_FETAL_KIDNEY_1_DN
Systematic name | M13108
Organism | Homo sapiens
PMID | 12057921
Authors | Li CM,Guo M,Borczuk A,Powell CA,Wei M,Thaker HM,Friedman R,Klein U,Tycko B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Wilm's tumor samples compared to fetal kidney.
Full description | Wilms' tumor (WT) has been considered a prototype for arrested cellular differentiation in cancer, but previous studies have relied on selected markers. We have now performed an unbiased survey of gene expression in WTs using oligonucleotide microarrays. Statistical criteria identified 357 genes as differentially expressed between WTs and fetal kidneys. This set contained 124 matches to genes on a microarray used by Stuart and colleagues (Stuart RO, Bush KT, Nigam SK: Changes in global gene expression patterns during development and maturation of the rat kidney. Proc Natl Acad Sci USA 2001, 98:5649-5654) to establish genes with stage-specific expression in the developing rat kidney. Mapping between the two data sets showed that WTs systematically overexpressed genes corresponding to the earliest stage of metanephric development, and underexpressed genes corresponding to later stages. Automated clustering identified a smaller group of 27 genes that were highly expressed in WTs compared to fetal kidney and heterologous tumor and normal tissues. This signature set was enriched in genes encoding transcription factors. Four of these, PAX2, EYA1, HBF2, and HOXA11, are essential for cell survival and proliferation in early metanephric development, whereas others, including SIX1, MOX1, and SALL2, are predicted to act at this stage. SIX1 and SALL2 proteins were expressed in the condensing mesenchyme in normal human fetal kidneys, but were absent (SIX1) or reduced (SALL2) in cells at other developmental stages. These data imply that the blastema in WTs has progressed to the committed stage in the mesenchymal-epithelial transition, where it is partially arrested in differentiation. The WT-signature set also contained the Wnt receptor FZD7, the tumor antigen PRAME, the imprinted gene NNAT and the metastasis-associated transcription factor E1AF.

Standard name | HESS_TARGETS_OF_HOXA9_AND_MEIS1_DN
Systematic name | M14829
Organism | Mus musculus
PMID | 16507773
Authors | Hess JL,Bittner CB,Zeisig DT,Bach C,Fuchs U,Borkhardt A,Frampton J,Slany RK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hematopoietic precursor cells conditionally expressing HOXA9 and MEIS1 [GeneID=3205;4211].
Full description | Abdominal-type HoxA genes in combination with Meis1 are well-documented on-cogenes in various leukemias but it is unclear how they exert their transforming function. Here we used a system of conditional transformation by an inducible mixed lineage leukemia-eleven-nineteen leukemia (MLL-ENL) oncoprotein to overexpress Hoxa9 and Meis1 in primary hematopoietic cells. Arrays identified c-Myb and a c-Myb target (Gstm1) among the genes with the strongest response to Hoxa9/Meis1. c-Myb overexpression was verified by Northern blot and quantitative reverse transcription-polymerase chain reaction (RT-PCR). Also MLL-ENL activated c-Myb through up-regulation of Hoxa9 and Meis1. Consequently, short-term suppression of c-Myb by small inhibitory RNA (siRNA) efficiently inhibited transformation by MLL-ENL but did not impair transformation by transcription factor E2A-hepatic leukemia factor (E2A-HLF). The anti c-Myb siRNA effect was abrogated by coexpression of a c-Myb derivative with a mutated siRNA target site. The introduction of a dominant-negative c-Myb mutant had a similar but weaker effect on MLL-ENL-mediated transformation. Hematopoietic precursors from mice homozygous for a hypo-morphic c-Myb allele were more severely affected and could be transformed neither by MLL-ENL nor by E2A-HLF. Ectopic expression of c-Myb induced a differentiation block but c-Myb alone was not transforming in a replating assay similar to Hoxa9/Meis1. These results suggest that c-Myb is essential but not sufficient for Hoxa9/Meis1 mediated transformation.

Standard name | HALMOS_CEBPA_TARGETS_DN
Systematic name | M8604
Organism | Homo sapiens
PMID | 15205324
Authors | Halmos B,Bassères DS,Monti S,D'Aló F,Dayaram T,Ferenczi K,Wouters BJ,Huettner CS,Golub TR,Tenen DG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in H358 cells (lung cancer) by inducible expression of CEBPA [GeneID=1050] off plasmid vector.
Full description | We showed previously that CCAAT/enhancer binding protein alpha (C/EBP alpha), a tissue-specific transcription factor, is a candidate tumor suppressor in lung cancer. In the present study, we have performed a transcriptional profiling study of C/EBP alpha target genes using an inducible cell line system. This study led to the identification of hepatocyte nuclear factor 3beta (HNF3 beta), a transcription factor known to play a role in airway differentiation, as a downstream target of C/EBP alpha. We found down-regulation of HNF3 beta expression in a large proportion of lung cancer cell lines examined and identified two novel mutants of HNF3 beta, as well as hypermethylation of the HNF3 beta promoter. We also developed a tetracycline-inducible cell line model to study the cellular consequences of HNF3 beta expression. Conditional expression of HNF3 beta led to significant growth reduction, proliferation arrest, apoptosis, and loss of clonogenic ability, suggesting additionally that HNF3 beta is a novel tumor suppressor in lung cancer. This is the first study to show genetic abnormalities of lung-specific differentiation pathways in the development of lung cancer.

Standard name | NADLER_OBESITY_DN
Systematic name | M1449
Organism | Mus musculus
PMID | 11027337
Authors | Nadler ST,Stoehr JP,Schueler KL,Tanimoto G,Yandell BS,Attie AD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in adipose tissue from obese mouse strains compared to the lean ones.
Full description | Obesity is strongly correlated with type 2 diabetes mellitus, a common disorder of glucose and lipid metabolism. Although adipocytes are critical in obesity, their role in diabetes has only recently been appreciated. We conducted studies by using DNA microarrays to identify differences in gene expression in adipose tissue from lean, obese, and obese-diabetic mice. The expression level of over 11,000 transcripts was analyzed, and 214 transcripts showed significant differences between lean and obese mice. Surprisingly, the expression of genes normally associated with adipocyte differentiation were down-regulated in obesity. Not all obese individuals will become diabetic; many remain normoglycemic despite profound obesity. Understanding the transition to obesity with concomitant diabetes will provide important clues to the pathogenesis of type 2 diabetes. Therefore, we examined the levels of gene expression in adipose tissue from five groups of obese mice with varying degrees of hyperglycemia, and we identified 88 genes whose expression strongly correlated with diabetes severity. This group included many genes that are known to be involved in signal transduction and energy metabolism as well as genes not previously examined in the context of diabetes. Our data show that a decrease in expression of genes normally involved in adipogenesis is associated with obesity, and we further identify genes important for subsequent development of type 2 diabetes mellitus.

Standard name | FERRANDO_T_ALL_WITH_MLL_ENL_FUSION_DN
Systematic name | M7715
Organism | Homo sapiens
PMID | 12637319
Authors | Ferrando AA,Armstrong SA,Neuberg DS,Sallan SE,Silverman LB,Korsmeyer SJ,Look AT
Category | C2
Sub-category | CGP
Brief description | Top 100 genes negatively associated with T-cell acute lymphoblastic leukemia MLL T-ALL) expressing MLL-ENL fusion [GeneID=4297;4298].
Full description | Rearrangements of the MLL locus, located on human chromosome 11q23, are frequent in both infant and therapy-related leukemias. Gene expression analysis of MLL-rearranged B-precursor acute lymphoblastic leukemias (MLL B-ALLs) has identified these cases as a unique subtype of leukemia, characterized by the expression of genes associated with both lymphoid and myeloid hematopoietic lineages. Here we show that MLL fusions also generate a distinct genetic subtype of T-lineage ALL (MLL T-ALL), in which leukemic cells are characterized by an early arrest in thymocyte differentiation, with suggestive evidence of commitment to the gammadelta lineage. Interestingly, multiple genes linked to cell proliferation (eg, PCNA, MYC, CDK2, and POLA) were down-regulated in MLL-fusion samples, relative to those transformed by other T-ALL oncogenes (P <.000 001, Fisher exact test). Overall, MLL T-ALL cases consistently demonstrated increased levels of expression of a subset of major HOX genes--HOXA9, HOXA10, and HOXC6--and the MEIS1 HOX coregulator (P <.008, one-sided Wilcoxon test), a pattern of gene expression that was reiterated in MLL B-ALLs. However, expression of myeloid lineage genes, previously reported in MLL B-ALLs, was not identified in T-lineage cases with this abnormality, suggesting that myeloid gene dysregulation is dispensable in leukemic transformation mediated by MLL fusion proteins. Our findings implicate dysregulation of HOX gene family members as a dominant mechanism of leukemic transformation induced by chimeric MLL oncogenes.

Standard name | WANG_IMMORTALIZED_BY_HOXA9_AND_MEIS1_UP
Systematic name | M1450
Organism | Mus musculus
PMID | 15755900
Authors | Wang GG,Pasillas MP,Kamps MP
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in myeloid progenitors immortalized by HOXA9 [GeneID=3205] vs those immortalized by HOXA9 and MEIS1 [GeneID=4211].
Full description | Meis1 is a homeodomain transcription factor coexpressed with Hoxa9 in most human acute myeloid leukemias (AMLs). In mouse models of leukemia produced by Hoxa9, Meis1 accelerates leukemogenesis. Because Hoxa9 immortalizes myeloid progenitors in the absence of Meis1 expression, the contribution of Meis1 toward leukemia remains unclear. Here, we describe a cultured progenitor model in which Meis1 programs leukemogenicity. Progenitors immortalized by Hoxa9 in culture are myeloid-lineage restricted and only infrequently caused leukemia after more than 250 days. Coexpressed Meis1 programmed rapid AML-initiating character, maintained multipotent progenitor potential, and induced expression of genes associated with short-term hematopoietic stem cells (HSCs), such as FLT3 and CD34, whose expression also characterizes the leukemia-initiating stem cells of human AML. Meis1 leukemogenesis functions required binding to Pbx, binding to DNA, and a conserved function of its C-terminal tail. We hypothesize that Meis1 is required for the homing and survival of leukemic progenitors within their hematopoietic niches, functions mediated by HSC-specific genes such as CD34 and Fms-like tyrosine kinase 3 (FLT3), respectively. This is the first example of a transcription factor oncoprotein (Meis1) that establishes expression of a tyrosine kinase oncoprotein (FLT3), and explains their coexpression in human leukemia. This cultured progenitor model will be useful to define the genetic basis of leukemogenesis involving Hoxa9 and Meis1.

Standard name | NEMETH_INFLAMMATORY_RESPONSE_LPS_DN
Systematic name | M1452
Organism | Mus musculus
PMID | 12766259
Authors | Németh ZH,Leibovich SJ,Deitch EA,Vizi ES,Szabó C,Hasko G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in RAW 264.7 cells (macrophage) 3 hr after stimulation with bacterial lipopolysaccharide (LPS).
Full description | Adenosine is released into the extracellular space from nerve terminals and cells subjected to ischemic stress. This nucleoside modulates a plethora of cellular functions via occupancy of specific receptors. Adenosine is also an important endogenous regulator of macrophage function, because it suppresses the production of a number of proinflammatory cytokines by these cells. However, the mechanisms of this anti-inflammatory effect have not been well characterized. We hypothesized that adenosine may exert some of its anti-inflammatory effects by decreasing activation of the transcription factor nuclear factor-kappaB (NF-kappaB), because gene expression of most of the proinflammatory cytokines inhibited by adenosine is dependent on NF-kappaB activation. Using bacterial lipopolysaccharide (LPS)-stimulated RAW 264.7 macrophages, we found that adenosine as well as adenosine receptor agonists decreased the production of tumor necrosis factor (TNF)-alpha, a typical NF-kappaB-regulated cytokine. This effect of adenosine was not due to an action on the process of TNF-alpha release, because adenosine suppressed also the intracellular levels of TNF-alpha. However, cDNA microarray analysis revealed that mRNA levels of neither TNF-alpha nor other cytokines were altered by adenosine in either LPS-activated or quiescent macrophages. In addition, although LPS induced expression of a number of other, noncytokine genes, including the adenosine A2b receptor, adenosine did not affect the expression of these genes. Furthermore, adenosine as well as adenosine receptor agonists failed to decrease LPS-induced NF-kappaB DNA binding, NF-kappaB promoter activity, p65 nuclear translocation, and inhibitory kappaB degradation. Together, our results suggest that the anti-inflammatory effects of adenosine are independent of NF-kappaB.

Standard name | GALE_APL_WITH_FLT3_MUTATED_DN
Systematic name | M12139
Organism | Homo sapiens
PMID | 16105978
Authors | Gale RE,Hills R,Pizzey AR,Kottaridis PD,Swirsky D,Gilkes AF,Nugent E,Mills KI,Wheatley K,Solomon E,Burnett AK,Linch DC,Grimwade D,NCRI Adult Leukaemia Working Party
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in acute promyelocytic leukemia (APL) patients with mutated FLT3 [GeneID=2322].
Full description | The prognostic significance of FLT3 mutations in acute promyelocytic leukemia (APL) is not firmly established and is of particular interest given the opportunities for targeted therapies using FLT3 inhibitors. We studied 203 patients with PML-RARA-positive APL; 43% of the patients had an FLT3 mutation (65 internal tandem duplications [ITDs], 19 D835/I836, 4 ITD+D835/I836). Both mutations were associated with higher white blood cell (WBC) count at presentation; 75% of the patients with WBC counts of 10 x 10(9)/L or greater had mutant FLT3. FLT3/ITDs were correlated with M3v subtype (P < .001), bcr3 PML breakpoint (P < .001), and expression of reciprocal RARA-PML transcripts (P = .01). Microarray analysis revealed differences in expression profiles among patients with FLT3/ITD, D835/I836, and wild-type FLT3. Patients with mutant FLT3 had a higher rate of induction death (19% vs 9%; P = .04, but no significant difference in relapse risk (28% vs 23%; P = .5) or overall survival (59% vs 67%; P = .2) at 5 years. In in vitro differentiation assays using primary APL blasts (n = 6), the FLT3 inhibitor CEP-701 had a greater effect on cell survival/proliferation in FLT3/ITD+ cells, but this inhibition was reduced in the presence of ATRA. Furthermore, in the presence of CEP-701, ATRA-induced differentiation was reduced in FLT3/ITD+ cells. These data carry implications for the use of FLT3 inhibitors as frontline therapy for APL.

Standard name | ZHAN_MULTIPLE_MYELOMA_CD1_AND_CD2_UP
Systematic name | M3889
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Genes commonly up-regulated in CD-1 and CD-2 clusters of multiple myeloma samples and which were higher expressed in the CD-1 group.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | NADLER_HYPERGLYCEMIA_AT_OBESITY
Systematic name | M1453
Organism | Mus musculus
PMID | 11027337
Authors | Nadler ST,Stoehr JP,Schueler KL,Tanimoto G,Yandell BS,Attie AD
Category | C2
Sub-category | CGP
Brief description | Genes correlated with the development of hyperglycemia in obese mice.
Full description | Obesity is strongly correlated with type 2 diabetes mellitus, a common disorder of glucose and lipid metabolism. Although adipocytes are critical in obesity, their role in diabetes has only recently been appreciated. We conducted studies by using DNA microarrays to identify differences in gene expression in adipose tissue from lean, obese, and obese-diabetic mice. The expression level of over 11,000 transcripts was analyzed, and 214 transcripts showed significant differences between lean and obese mice. Surprisingly, the expression of genes normally associated with adipocyte differentiation were down-regulated in obesity. Not all obese individuals will become diabetic; many remain normoglycemic despite profound obesity. Understanding the transition to obesity with concomitant diabetes will provide important clues to the pathogenesis of type 2 diabetes. Therefore, we examined the levels of gene expression in adipose tissue from five groups of obese mice with varying degrees of hyperglycemia, and we identified 88 genes whose expression strongly correlated with diabetes severity. This group included many genes that are known to be involved in signal transduction and energy metabolism as well as genes not previously examined in the context of diabetes. Our data show that a decrease in expression of genes normally involved in adipogenesis is associated with obesity, and we further identify genes important for subsequent development of type 2 diabetes mellitus.

Standard name | RORIE_TARGETS_OF_EWSR1_FLI1_FUSION_UP
Systematic name | M3169
Organism | Homo sapiens
PMID | 14973077
Authors | Rorie CJ,Thomas VD,Chen P,Pierce HH,O'Bryan JP,Weissman BE
Category | C2
Sub-category | CGP
Brief description | ES/PNET (Ewing sarcoma; primitive neuroectodermal tumors) markers up-regulated in neuroblastoma cell lines expressing ESWR1-FLI1 [GeneID=2130;2313] fusion protein.
Full description | Neuroblastoma (NB) and the Ewing sarcoma (ES)/peripheral primitive neuroectodermal tumor (PNET) family are pediatric cancers derived from neural crest cells. Although NBs display features of the sympathetic nervous system, ES/PNETs express markers consistent with parasympathetic differentiation. To examine the control of these differentiation markers, we generated NB x ES/PNET somatic cell hybrids. NB-specific markers were suppressed in the hybrids, whereas ES/PNET-specific markers were unaffected. These results suggested that the Ews/Fli-1 fusion gene, resulting from a translocation unique to ES/PNETs, might account for the loss of NB-specific markers. To test this hypothesis, we generated two different NB cell lines that stably expressed the Ews/Fli-1 gene. We observed that heterologous expression of the Ews/Fli-1 protein led to the suppression of NB-specific markers and de novo expression of ES/PNET markers. To determine the extent of changes in differentiation, we used the Affymetrix GeneChip Array system to observe global transcriptional changes of genes. This analysis revealed that the gene expression pattern of the Ews/Fli-1-expressing NB cells resembled that observed in pooled ES/PNET cell lines and differed significantly from the NB parental cells. Therefore, we propose that Ews/Fli-1 contributes to the etiology of ES/PNET by subverting the differentiation program of its neural crest precursor cell to a less differentiated and more proliferative state.

Standard name | ZHAN_MULTIPLE_MYELOMA_PR_UP
Systematic name | M4888
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 up-regulated genes in cluster PR of multiple myeloma samples characterized by increased expression of proliferation and cell cycle genes.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | HALMOS_CEBPA_TARGETS_UP
Systematic name | M11064
Organism | Homo sapiens
PMID | 15205324
Authors | Halmos B,Bassères DS,Monti S,D'Aló F,Dayaram T,Ferenczi K,Wouters BJ,Huettner CS,Golub TR,Tenen DG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in H358 cells (lung cancer) by inducible expression of CEBPA [GeneID=1050] off plasmid vector.
Full description | We showed previously that CCAAT/enhancer binding protein alpha (C/EBP alpha), a tissue-specific transcription factor, is a candidate tumor suppressor in lung cancer. In the present study, we have performed a transcriptional profiling study of C/EBP alpha target genes using an inducible cell line system. This study led to the identification of hepatocyte nuclear factor 3beta (HNF3 beta), a transcription factor known to play a role in airway differentiation, as a downstream target of C/EBP alpha. We found down-regulation of HNF3 beta expression in a large proportion of lung cancer cell lines examined and identified two novel mutants of HNF3 beta, as well as hypermethylation of the HNF3 beta promoter. We also developed a tetracycline-inducible cell line model to study the cellular consequences of HNF3 beta expression. Conditional expression of HNF3 beta led to significant growth reduction, proliferation arrest, apoptosis, and loss of clonogenic ability, suggesting additionally that HNF3 beta is a novel tumor suppressor in lung cancer. This is the first study to show genetic abnormalities of lung-specific differentiation pathways in the development of lung cancer.

Standard name | YU_MYC_TARGETS_DN
Systematic name | M3923
Organism | Mus musculus
PMID | 16382050
Authors | Yu D,Cozma D,Park A,Thomas-Tikhonenko A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in B cell lymphoma tumors expressing an activated form of MYC [GeneID=4609].
Full description | The involvement of the c-Myc transcription factor in neoplastic transformation is well documented. However, which of its numerous target genes are crucial for tumorigenesis remains a frequently contested issue. We have recently established a non-transgenic murine model for B-cell lymphoma based on neoplastic conversion of p53-null bone marrow cells by conditionally active Myc. Using this model, we have identified a number of genes whose expression levels are affected by Myc during B-lymphomagenesis. Here we discuss their possible roles in neoplastic processes and describe an experimental approach allowing in vivo validation of these roles. We demonstrate that lymphoma cells overexpressing one of the Myc targets, the interleukin-10 receptor gene, have a very strong selective advantage over low IL10R expressors. Furthermore, Mcl1, a presumptive IL10R effector, also confers selective advantages when overexpressed in Myc-transformed hematopoietic cells. Thus, both IL10R and Mcl1 might be amenable to therapeutic interventions, and new targets can be identified and validated using the selection approach.

Standard name | NUMATA_CSF3_SIGNALING_VIA_STAT3
Systematic name | M1454
Organism | Mus musculus
PMID | 15664994
Authors | Numata A,Shimoda K,Kamezaki K,Haro T,Kakumitsu H,Shide K,Kato K,Miyamoto T,Yamashita Y,Oshima Y,Nakajima H,Iwama A,Aoki K,Takase K,Gondo H,Mano H,Harada M
Category | C2
Sub-category | CGP
Brief description | Target genes for STAT3 [GeneID=20848] in CSF3 [GeneID=12985] signaling during myeloblast differentiation to neutrophils.
Full description | The Janus kinase (Jak)-Stat pathway plays an essential role in cytokine signaling. Granulocyte colony-stimulating factor (G-CSF) promotes granulopoiesis and granulocytic differentiation, and Stat3 is the principle Stat protein activated by G-CSF. Upon treatment with G-CSF, the interleukin-3-dependent cell line 32D clone 3(32Dcl3) differentiates into neutrophils, and 32Dcl3 cells expressing dominant-negative Stat3 (32Dcl3/DNStat3) proliferate in G-CSF without differentiation. Gene expression profile and quantitative PCR analysis of G-CSF-stimulated cell lines revealed that the expression of C/EBPalpha was up-regulated by the activation of Stat3. In addition, activated Stat3 bound to CCAAT/enhancer-binding protein (C/EBP)alpha, leading to the enhancement of the transcription activity of C/EBPalpha. Conditional expression of C/EBPalpha in 32Dcl3/DNStat3 cells after G-CSF stimulation abolishes the G-CSF-dependent cell proliferation and induces granulocytic differentiation. Although granulocyte-specific genes, such as the G-CSF receptor, lysozyme M, and neutrophil gelatinase-associated lipocalin precursor (NGAL) are regulated by Stat3, only NGAL was induced by the restoration of C/EBPalpha after stimulation with G-CSF in 32Dcl3/DNStat3 cells. These results show that one of the major roles of Stat3 in the G-CSF signaling pathway is to augment the function of C/EBPalpha, which is essential for myeloid differentiation. Additionally, cooperation of C/EBPalpha with other Stat3-activated proteins are required for the induction of some G-CSF responsive genes including lysozyme M and the G-CSF receptor.

Standard name | ZHAN_MULTIPLE_MYELOMA_UP
Systematic name | M3958
Organism | Homo sapiens
PMID | 11861292
Authors | Zhan F,Hardin J,Kordsmeier B,Bumm K,Zheng M,Tian E,Sanderson R,Yang Y,Wilson C,Zangari M,Anaissie E,Morris C,Muwalla F,van Rhee F,Fassas A,Crowley J,Tricot G,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | Genes most significantly up-regulated in multiple myeloma samples, compared to normal bone marrow plasma cells.
Full description | Bone marrow plasma cells (PCs) from 74 patients with newly diagnosed multiple myeloma (MM), 5 with monoclonal gammopathy of undetermined significance (MGUS), and 31 healthy volunteers (normal PCs) were purified by CD138(+) selection. Gene expression of purified PCs and 7 MM cell lines were profiled using high-density oligonucleotide microarrays interrogating about 6800 genes. On hierarchical clustering analysis, normal and MM PCs were differentiated and 4 distinct subgroups of MM (MM1, MM2, MM3, and MM4) were identified. The expression pattern of MM1 was similar to normal PCs and MGUS, whereas MM4 was similar to MM cell lines. Clinical parameters linked to poor prognosis, abnormal karyotype (P =.002) and high serum beta(2)-microglobulin levels (P =.0005), were most prevalent in MM4. Also, genes involved in DNA metabolism and cell cycle control were overexpressed in a comparison of MM1 and MM4. In addition, using chi(2) and Wilcoxon rank sum tests, 120 novel candidate disease genes were identified that discriminate normal and malignant PCs (P <.0001); many are involved in adhesion, apoptosis, cell cycle, drug resistance, growth arrest, oncogenesis, signaling, and transcription. A total of 156 genes, including FGFR3 and CCND1, exhibited highly elevated (spiked) expression in at least 4 of the 74 MM cases (range, 4-25 spikes). Elevated expression of these 2 genes was caused by the translocation t(4;14)(p16;q32) or t(11;14)(q13;q32). Thus, novel candidate MM disease genes have been identified using gene expression profiling and this profiling has led to the development of a gene-based classification system for MM.

Standard name | LENAOUR_DENDRITIC_CELL_MATURATION_UP
Systematic name | M4562
Organism | Homo sapiens
PMID | 11279020
Authors | Le Naour F,Hohenkirk L,Grolleau A,Misek DE,Lescure P,Geiger JD,Hanash S,Beretta L
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during in vitro maturation of CD14+ [GeneID=929] monocytes (day 0) into immature (day 7) and mature dendritic cells (day 14).
Full description | Dendritic cells (DCs) are antigen-presenting cells that play a major role in initiating primary immune responses. We have utilized two independent approaches, DNA microarrays and proteomics, to analyze the expression profile of human CD14(+) blood monocytes and their derived DCs. Analysis of gene expression changes at the RNA level using oligonucleotide microarrays complementary to 6300 human genes showed that approximately 40% of the genes were expressed in DCs. A total of 255 genes (4%) were found to be regulated during DC differentiation or maturation. Most of these genes were not previously associated with DCs and included genes encoding secreted proteins as well as genes involved in cell adhesion, signaling, and lipid metabolism. Protein analysis of the same cell populations was done using two-dimensional gel electrophoresis. A total of 900 distinct protein spots were included, and 4% of them exhibited quantitative changes during DC differentiation and maturation. Differentially expressed proteins were identified by mass spectrometry and found to represent proteins with Ca(2+) binding, fatty acid binding, or chaperone activities as well as proteins involved in cell motility. In addition, proteomic analysis provided an assessment of post-translational modifications. The chaperone protein, calreticulin, was found to undergo cleavage, yielding a novel form. The combined oligonucleotide microarray and proteomic approaches have uncovered novel genes associated with DC differentiation and maturation and has allowed analysis of post-translational modifications of specific proteins as part of these processes.

Standard name | TAVOR_CEBPA_TARGETS_DN
Systematic name | M19872
Organism | Homo sapiens
PMID | 14517214
Authors | Tavor S,Park DJ,Gery S,Vuong PT,Gombart AF,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in KCL22 cells (chronic myelogenous leukemia, CML, with BCR-ABL1 [GeneID=613;25] fusion) by expression of CEBPA [GeneID=1050].
Full description | The transcription factor C/EBPalpha plays a critical role in the process of granulocytic differentiation. Recently, mutations that abrogated transcriptional activation of C/EBPalpha were detected in acute myeloid leukemia patient samples. Moreover, the progression of chronic myelogenous leukemia (CML) to blast crisis in patients was correlated with down-modulation of C/EBPalpha. The KCL22 cell line, derived from BCR-ABL+ CML in blast crisis, expressed wild-type C/EBPepsilon protein but not a functional C/EBPalpha, -beta, and -gamma. Restoration of C/EBPalpha expression in KCL22 cells triggered a profound proliferative arrest, a block in the G2/M phase of the cell cycle and a gradual increase in apoptosis. Within 3 days of inducing expression of C/EBPalpha, a remarkable neutrophilic differentiation of the KCL22 blast cells occurred as shown by morphologic changes, induction of expression of CD11b, primary, secondary, and tertiary granule proteins, and granulocyte colony-stimulating factor receptor. Using high density oligonucleotide microarrays, the gene expression profile of KCL22 cells stably transfected with C/EBPalpha was compared with that of empty vector, and we identified genes not previously known to be regulated by C/EBPalpha. These included the up-regulation of those genes important for regulation of hematopoietic stem cell homing, granulocytic differentiation, and cell cycle, whereas down-regulation occurred for genes coding for signaling molecules and transcription factors that are implicated in regulation of proliferation and differentiation of hematopoietic cells. Our study showed that restoration of C/EBPalpha expression in BCR-ABL+ leukemic cells in blast crisis is sufficient for rapid neutrophil differentiation suggesting a potential therapeutic role for ectopic transfer of C/EBPalpha in acute phase of CML.

Standard name | LENAOUR_DENDRITIC_CELL_MATURATION_DN
Systematic name | M3069
Organism | Homo sapiens
PMID | 11279020
Authors | Le Naour F,Hohenkirk L,Grolleau A,Misek DE,Lescure P,Geiger JD,Hanash S,Beretta L
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during in vitro maturation of CD14+ [GeneID=929] monocytes (day 0) into immature (day 7) and mature dendritic cells (day 14).
Full description | Dendritic cells (DCs) are antigen-presenting cells that play a major role in initiating primary immune responses. We have utilized two independent approaches, DNA microarrays and proteomics, to analyze the expression profile of human CD14(+) blood monocytes and their derived DCs. Analysis of gene expression changes at the RNA level using oligonucleotide microarrays complementary to 6300 human genes showed that approximately 40% of the genes were expressed in DCs. A total of 255 genes (4%) were found to be regulated during DC differentiation or maturation. Most of these genes were not previously associated with DCs and included genes encoding secreted proteins as well as genes involved in cell adhesion, signaling, and lipid metabolism. Protein analysis of the same cell populations was done using two-dimensional gel electrophoresis. A total of 900 distinct protein spots were included, and 4% of them exhibited quantitative changes during DC differentiation and maturation. Differentially expressed proteins were identified by mass spectrometry and found to represent proteins with Ca(2+) binding, fatty acid binding, or chaperone activities as well as proteins involved in cell motility. In addition, proteomic analysis provided an assessment of post-translational modifications. The chaperone protein, calreticulin, was found to undergo cleavage, yielding a novel form. The combined oligonucleotide microarray and proteomic approaches have uncovered novel genes associated with DC differentiation and maturation and has allowed analysis of post-translational modifications of specific proteins as part of these processes.

Standard name | WANG_TARGETS_OF_MLL_CBP_FUSION_DN
Systematic name | M1455
Organism | Mus musculus
PMID | 15635450
Authors | Wang J,Iwasaki H,Krivtsov A,Febbo PG,Thorner AR,Ernst P,Anastasiadou E,Kutok JL,Kogan SC,Zinkel SS,Fisher JK,Hess JL,Golub TR,Armstrong SA,Akashi K,Korsmeyer SJ
Category | C2
Sub-category | CGP
Brief description | Top 50 genes down-regulated in granulocyte/macrophage progenitors (GMP) upon expression of MLL-CBP fusion [GeneID=4297;1387].
Full description | Chromosomal translocations that fuse the mixed lineage leukemia (MLL) gene with multiple partners typify acute leukemias of infancy as well as therapy-related leukemias. We utilized a conditional knockin strategy to bypass the embryonic lethality caused by MLL-CBP expression and to assess the immediate effects of induced MLL-CBP expression on hematopoiesis. Within days of activating MLL-CBP, the fusion protein selectively expanded granulocyte/macrophage progenitors (GMP) and enhanced their self-renewal/proliferation. MLL-CBP altered the gene expression program of GMP, upregulating a subset of genes including Hox a9. Inhibition of Hox a9 expression by RNA interference demonstrated that MLL-CBP required Hox a9 for its enhanced cell expansion. Following exposure to sublethal gamma-irradiation or N-ethyl-N-nitrosourea (ENU), MLL-CBP mice developed myelomonocytic hyperplasia and progressed to fatal myeloproliferative disorders. These represented the spectrum of therapy-induced acute myelomonocytic leukemia/chronic myelomonocytic leukemia/myelodysplastic/myeloproliferative disorder similar to that seen in humans possessing the t(11;16). This model of MLL-CBP therapy-related myeloproliferative disease demonstrates the selectivity of this MLL fusion for GMP cells and its ability to initiate leukemogenesis in conjunction with cooperating mutations.

Standard name | HADDAD_B_LYMPHOCYTE_PROGENITOR
Systematic name | M939
Organism | Homo sapiens
PMID | 15331438
Authors | Haddad R,Guardiola P,Izac B,Thibault C,Radich J,Delezoide AL,Baillou C,Lemoine FM,Gluckman JC,Pflumio F,Canque B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hematopoietic progenitor cells (HPC) of B lymphocyte lineage CD34+CD45RA+CD10+ [GeneID=947;5788;4311].
Full description | The early stages of human lymphopoiesis are poorly characterized. Here, we compared the lymphoid potential of a novel umbilical cord blood CD34(+)CD45RA(hi)CD7(+) hematopoietic progenitor cell (HPC) population with that of CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs, previously proposed as candidate common lymphoid progenitors. Limiting-dilution and clonal analysis, fetal thymic organ cultures, and culture onto Notch ligand Delta-like-1-expressing OP9 cells, showed that although CD34(+)CD45RA(hi)CD7(+) HPCs could generate cells of the 3 lymphoid lineages, their potential was skewed toward the T/natural killer (T/NK) lineages. In contrast, CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs predominantly exhibited a B-cell potential. Gene expression profiling with DNA microarrays confirmed that CD34(+)CD45RA(hi)CD7(+) HPCs selectively expressed T-lymphoid and NK lineage-committed genes while retaining expression of genes affiliated to the granulomonocytic lineage, whereas CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs displayed a typical pro-B-cell transcription profile and essentially lacked genes unrelated to the B lineage. In addition, both populations could be generated in vitro from CD34(+)CD45RA(int)CD7(-) and CD34(+)CD45RA(hi)Lin(-) HPCs with mixed lymphomyeloid potential, from which they emerged independently with different growth/differentiation factor requirements. These findings indicate that CD34(+)CD45RA(hi)CD7(+) and CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs correspond to multipotent early lymphoid progenitors polarized toward either the T/NK or B lineage, respectively.

Standard name | PARK_HSC_AND_MULTIPOTENT_PROGENITORS
Systematic name | M1456
Organism | Mus musculus
PMID | 11781229
Authors | Park IK,He Y,Lin F,Laerum OD,Tian Q,Bumgarner R,Klug CA,Li K,Kuhr C,Doyle MJ,Xie T,Schummer M,Sun Y,Goldsmith A,Clarke MF,Weissman IL,Hood L,Li L
Category | C2
Sub-category | CGP
Brief description | Genes commonly expressed in long term hematopoietic stem cells (HSC) and multipotent progenitors (MPP).
Full description | Hematopoietic stem cells (HSCs) have self-renewal capacity and multilineage developmental potentials. The molecular mechanisms that control the self-renewal of HSCs are still largely unknown. Here, a systematic approach using bioinformatics and array hybridization techniques to analyze gene expression profiles in HSCs is described. To enrich mRNAs predominantly expressed in uncommitted cell lineages, 54 000 cDNA clones generated from a highly enriched population of HSCs and a mixed population of stem and early multipotent progenitor (MPP) cells were arrayed on nylon membranes (macroarray or high-density array), and subtracted with cDNA probes derived from mature lineage cells including spleen, thymus, and bone marrow. Five thousand cDNA clones with very low hybridization signals were selected for sequencing and further analysis using microarrays on glass slides. Two populations of cells, HSCs and MPP cells, were compared for differential gene expression using microarray analysis. HSCs have the ability to self-renew, while MPP cells have lost the capacity for self-renewal. A large number of genes that were differentially expressed by enriched populations of HSCs and MPP cells were identified. These included transcription factors, signaling molecules, and previously unknown genes.

Standard name | GREENBAUM_E2A_TARGETS_DN
Systematic name | M1457
Organism | Mus musculus
PMID | 15310760
Authors | Greenbaum S,Lazorchak AS,Zhuang Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pre-B lymphocytes upon Cre-Lox knockout of E2A [GeneID=6929].
Full description | The transcription factors encoded by the E2A gene have been shown to play essential roles in the initiation and progression of lymphocyte development. However, there is still a lack of comprehensive understanding of E2A downstream genes in B-cell development. We previously developed a gene tagging-based chromatin immunoprecipitation (ChIP) system to directly evaluate E2A target genes in B-cell development. Here, we have improved this ChIP strategy and used it in conjunction with microarray analysis on E2A-deficient pre-B-cell lines to determine E2A target genes in lymphocyte development. Both microarray data and ChIP studies confirmed that E2A directly controls IgH gene expression. The microarray assay also revealed genes that were significantly up-regulated after E2A disruption. ChIP analysis showed that E2A was most likely to be directly involved in repression of some of these target genes such as Nfil3 and FGFR2. An inducible E2A reconstitution system further demonstrated that E2A-mediated repression of Nfil3 and FGFR2 was reversible. Collectively, these findings indicate that E2A is a positive regulator for one set of genes and a negative regulator for another set of genes in developing B lymphocytes.

Standard name | NGUYEN_NOTCH1_TARGETS_UP
Systematic name | M15592
Organism | Homo sapiens
PMID | 16618808
Authors | Nguyen BC,Lefort K,Mandinova A,Antonini D,Devgan V,Della Gatta G,Koster MI,Zhang Z,Wang J,Tommasi di Vignano A,Kitajewski J,Chiorino G,Roop DR,Missero C,Dotto GP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary keratinocytes by expression of constantly active NOTCH1 [GeneID=4851].
Full description | Notch signaling promotes commitment of keratinocytes to differentiation and suppresses tumorigenesis. p63, a p53 family member, has been implicated in establishment of the keratinocyte cell fate and/or maintenance of epithelial self-renewal. Here we show that p63 expression is suppressed by Notch1 activation in both mouse and human keratinocytes through a mechanism independent of cell cycle withdrawal and requiring down-modulation of selected interferon-responsive genes, including IRF7 and/or IRF3. In turn, elevated p63 expression counteracts the ability of Notch1 to restrict growth and promote differentiation. p63 functions as a selective modulator of Notch1-dependent transcription and function, with the Hes-1 gene as one of its direct negative targets. Thus, a complex cross-talk between Notch and p63 is involved in the balance between keratinocyte self-renewal and differentiation.

Standard name | ZHAN_MULTIPLE_MYELOMA_CD2_UP
Systematic name | M18513
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 up-regulated genes in cluster CD-2 of multiple myeloma samples with the characteristic expression spike of CCND3 [GeneID=896].
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | HASLINGER_B_CLL_WITH_CHROMOSOME_12_TRISOMY
Systematic name | M1536
Organism | Homo sapiens
PMID | 15459216
Authors | Haslinger C,Schweifer N,Stilgenbauer S,Döhner H,Lichter P,Kraut N,Stratowa C,Abseher R
Category | C2
Sub-category | CGP
Brief description | Genes changed in the B cell chronic lymphocytic leukemia (B-CLL) with trisomy of chromosome 12.
Full description | PURPOSE: Genomic aberrations and mutational status of the immunoglobulin variable heavy chain (VH) gene have been shown to be among the most important predictors for outcome in patients with B-cell chronic lymphocytic leukemia (B-CLL). In this study, we report on differential gene expression patterns that are characteristic for genetically defined B-CLL subtypes. MATERIALS AND METHODS: One hundred genetically well-characterized B-CLL samples, together with 11 healthy control samples, were analyzed using oligonucleotide arrays, which test for the expression of some 12,000 human genes. RESULTS: Aiming at microarray-based subclassification, class predictors were constructed using sets of differentially expressed genes, which yielded in zero or low misclassification rates. Furthermore, a significant number of the differentially expressed genes clustered in chromosomal regions affected by the respective genomic losses/gains. Deletions affecting chromosome bands 11q22-q23 and 17p13 led to a reduced expression of the corresponding genes, such as ATM and p53, while trisomy 12 resulted in the upregulation of genes mapping to chromosome arm 12q. Using an unsupervised analysis algorithm, expression profiling allowed partitioning into predominantly VH-mutated versus unmutated patient groups; however, association of the expression profile with the VH mutational status could only be detected in male patients. CONCLUSION: The finding that the most significantly differentially expressed genes are located in the corresponding aberrant chromosomal regions indicates that a gene dosage effect may exert a pathogenic role in B-CLL. The significant difference in the partitioning of male and female B-CLL samples suggests that the genomic signature for the VH mutational status might be sex-related.

Standard name | ABBUD_LIF_SIGNALING_1_UP
Systematic name | M1458
Organism | Mus musculus
PMID | 14576184
Authors | Abbud RA,Kelleher R,Melmed S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in AtT20 cells (pituitary cancer) after treatment with LIF [GeneID=3976].
Full description | Leukemia inhibitory factor (LIF) mediates the hypothalamo-pituitary-adrenal stress response. Transgenic mice overexpressing LIF in the developing pituitary have altered pituitary differentiation with expansion of corticotropes, maintenance of Rathke's cleft cysts, and suppression of all other pituitary cell types. Affymetrix GeneChips were used to identify modulators of LIF effects in corticotrope (AtT-20) and somatolactotrope (GH(3)) cells. In addition to genes known to respond to LIF in corticotrope cells [e.g. suppressor of cytokine signaling-3 (SOCS-3), signal transducer and activator of transcription-3, SH2 domain-containing tyrosine phosphatase-1, and proopiomelanocortin (POMC)], corticotrope-specific changes were also observed for genes involved in glycolysis and gluconeogenesis, transcription factors, signaling molecules, and expressed sequence tags. Two transcription factors identified, CCAAT/enhancer-binding protein beta (C/EBPbeta) and glial cell-derived neurotrophic factor (GDNF)-inducible factor (GIF), dose-dependently induced expression of the rat POMC promoter when overexpressed in AtT-20 cells. LIF further induced POMC transcription with C/EBPbeta, but not with GIF. C/EBPbeta also induced expression of the SOCS-3 promoter that was further enhanced by cotreatment with LIF. However, GIF did not affect SOCS-3 expression. These results indicate that C/EBPbeta and GIF are downstream effectors of LIF corticotrope action. LIF also stimulates the expression of inhibitors of its actions, such as SOCS-3 and SH2 domain-containing tyrosine phosphatase-1. alpha(2)-HS-glycoprotein (AHSG)/fetuin, a secreted protein that antagonizes bone TGFbeta/bone morphogenic protein signaling, was induced by LIF in a signal transducer and activator of transcription-3-dependent fashion. Pretreatment with AHSG/fetuin blocked LIF-induced expression of the POMC promoter independently of SOCS-3. Thus, using GeneChips, C/EBPbeta and GIF have been identified as novel mediators and AHSG/fetuin as an inhibitor of LIF action in corticotropes.

Standard name | ABRAHAM_ALPC_VS_MULTIPLE_MYELOMA_UP
Systematic name | M18077
Organism | Homo sapiens
PMID | 15388584
Authors | Abraham RS,Ballman KV,Dispenzieri A,Grill DE,Manske MK,Price-Troska TL,Paz NG,Gertz MA,Fonseca R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in immunoglobulin light chain amyloidosis plasma cells (ALPC) compared to multiple myeloma (MM) cells.
Full description | Immunoglobulin light chain amyloidosis (AL) is characterized by a clonal expansion of plasma cells within the bone marrow. Gene expression analysis was used to identify a unique molecular profile for AL using enriched plasma cells (CD138+) from the bone marrow of 24 patients with AL and 28 patients with multiple myeloma (MM) and 6 healthy controls. Class prediction analysis (PAM) revealed a subset of 12 genes, which included TNFRSF7 (CD27), SDF-1, and PSMA2, that distinguished between these 2 groups with an estimated and observed accuracy of classification of 92%. This model was validated with an independent dataset of 11 patients with AL and 12 patients with MM with 87% accuracy. Differential expression for the most discriminant genes in the 12-gene subset was validated using quantitative real-time polymerase chain reaction and protein expression analysis, which upheld the observations from the micro-array expression data. Functional analyses using a novel network mapping software revealed a number of potentially significant pathways that were dysregulated in patients with AL, with those regulating proliferation, apoptosis, cell signaling, chemotaxis, and migration being substantially represented. This study provides new insight into the molecular profile of clonal plasma cells and its functional relevance in the pathogenesis of light chain amyloidosis.

Standard name | THEILGAARD_NEUTROPHIL_AT_SKIN_WOUND_UP
Systematic name | M2117
Organism | Homo sapiens
PMID | 15187151
Authors | Theilgaard-Mönch K,Knudsen S,Follin P,Borregaard N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in polymorphonuclear neutrophilic granulocytes (PMNs) attracted to skin wounds.
Full description | To investigate the cellular fate and function of polymorphonuclear neutrophilic granulocytes (PMNs) attracted to skin wounds, we used a human skin-wounding model and microarray technology to define differentially expressed genes in PMNs from peripheral blood, and PMNs that had transmigrated to skin lesions. After migration to skin lesions, PMNs demonstrated a significant transcriptional response including genes from several different functional categories. The up-regulation of anti-apoptotic genes concomitant with the down-regulation of proapoptotic genes suggested a transient anti-apoptotic priming of PMNs. Among the up-regulated genes were cytokines and chemokines critical for chemotaxis of macrophages, T cells, and PMNs, and for the modulation of their inflammatory responses. PMNs in skin lesions down-regulated receptors mediating chemotaxis and anti-microbial activity, but up-regulated other receptors involved in inflammatory responses. These findings indicate a change of responsiveness to chemotactic and immunoregulatory mediators once PMNs have migrated to skin lesions and have been activated. Other effects of the up-regulated cytokines/chemokines/enzymes were critical for wound healing. These included the breakdown of fibrin clots and degradation of extracellular matrix, the promotion of angiogenesis, the migration and proliferation of keratinocytes and fibroblasts, the adhesion of keratinocytes to the dermal layer, and finally, the induction of anti-microbial gene expression in keratinocytes. Notably, the up-regulation of genes, which activate lysosomal proteases, indicate a priming of skin lesion-PMNs for degradation of phagocytosed material. These findings demonstrate that migration of PMNs to skin lesions induces a transcriptional activation program, which regulates cellular fate and function, and promotes wound healing.

Standard name | GERY_CEBP_TARGETS
Systematic name | M12338
Organism | Mus musculus
PMID | 15985538
Authors | Gery S,Gombart AF,Yi WS,Koeffler C,Hofmann WK,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes changed in NIH 3T3 cells (embryonic fibroblast) by expression of one or more of C/EBP proteins: CEBPA, CEBPB, CEBPG, and CEBPD [GeneID=1050;1051;1054;1052].
Full description | CCAAT/enhancer-binding proteins (C/EBPs) are a family of transcription factors that regulate cell growth and differentiation in numerous cell types. To identify novel C/EBP-target genes, we performed transcriptional profiling using inducible NIH 3T3 cell lines expressing 1 of 4 members of the C/EBP family. Functional analysis revealed a previously unknown link between C/EBP proteins and circadian clock genes. Our microarray data showed that the expression levels of 2 core components of the circadian network, Per2 and Rev-Erbalpha, were significantly altered by C/EBPs. Recent studies suggested that Per2 behaves as a tumor suppressor gene in mice. Therefore, we focused our additional studies on Per2. We showed that Per2 expression is up-regulated by C/EBPalpha and C/EBPepsilon. Per2 levels were reduced in lymphoma cell lines and in acute myeloid leukemia (AML) patient samples. In addition, we generated stable K562 cells that expressed an inducible Per2 gene. Induction of Per2 expression resulted in growth inhibition, cell cycle arrest, apoptosis, and loss of clonogenic ability. These results suggest that Per2 is a downstream C/EBPalpha-target gene involved in AML, and its disruption might be involved in initiation and/or progression of AML.

Standard name | VERHAAK_AML_WITH_NPM1_MUTATED_UP
Systematic name | M4861
Organism | Homo sapiens
PMID | 16109776
Authors | Verhaak RG,Goudswaard CS,Putten van W,Bijl MA,Sanders MA,Hugens W,Uitterlinden AG,Erpelinck CA,Delwel R,Löwenberg B,Valk PJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in acute myeloid leukemia (AML) patients with mutated NPM1 [GeneID=4869].
Full description | Mutations in nucleophosmin NPM1 are the most frequent acquired molecular abnormalities in acute myeloid leukemia (AML). We determined the NPM1 mutation status in a clinically and molecularly well-characterized patient cohort of 275 patients with newly diagnosed AML by denaturing high-performance liquid chromatography (dHPLC). We show that NPM1 mutations are significantly underrepresented in patients younger than 35 years. NPM1 mutations positively correlate with AML with high white blood cell counts, normal karyotypes, and fms-like tyrosine kinase-3 gene (FLT3) internal tandem duplication (ITD) mutations. NPM1 mutations associate inversely with the occurrence of CCAAT/enhancer-binding protein-alpha (CEBPA) and NRAS mutations. With respect to gene expression profiling, we show that AML cases with an NPM1 mutation cluster in specific subtypes of AML with previously established gene expression signatures, are highly associated with a homeobox gene-specific expression signature, and can be predicted with high accuracy. We demonstrate that patients with intermediate cytogenetic risk AML without FLT3 ITD mutations but with NPM1 mutations have a significantly better overall survival (OS) and event-free survival (EFS) than those without NPM1 mutations. Finally, in multivariable analysis NPM1 mutations express independent favorable prognostic value with regard to OS, EFS, and disease-free survival (DFS).

Standard name | KANG_IMMORTALIZED_BY_TERT_UP
Systematic name | M5360
Organism | Homo sapiens
PMID | 15579653
Authors | Kang SK,Putnam L,Dufour J,Ylostalo J,Jung JS,Bunnell BA
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the signature of adipose stromal cells (ADSC) immortalized by forced expression of telomerase (TERT) [GeneID=7015].
Full description | Expression of TERT, the catalytic protein subunit of the telomerase complex, can be used to generate cell lines that expand indefinitely and retain multilineage potential. We have created immortal adipose stromal cell lines (ATSCs) by stably transducing nonhuman primate-derived ATSCs with a retroviral vector expressing TERT. Transduced cells (ATSC-TERT) had an increased level of telomerase activity and increased mean telomere length in the absence of malignant cellular transformation. Long-term culture of the ATSC-TERT cells demonstrated that the cells retain the ability to undergo differentiation along multiple lineages such as adipogenic, chondrogenic, and neurogenic. Untransduced cells demonstrated markedly reduced multilineage and self-renewal potentials after 12 passages in vitro. To determine the functional role of telomerase during osteogenesis, we examined osteogenic differentiation potential of ATSC-TERT cells in vitro. Compared with naive ATSCs, which typically begin to accumulate calcium after 3-4 weeks of induction by osteogenic differentiation medium, ATSC-TERT cells were found to accumulate significant amounts of calcium after only 1 week of culture in osteogenic induction medium. The cells have increased production of osteoblastic markers, such as AP2, osteoblast-specific factor 2, chondroitin sulfate proteoglycan 4, and the tumor necrosis factor receptor superfamily, compared with control ATSCs, indicating that telomerase expression may aid in maintaining the osteogenic stem cell pool during in vitro expansion. These results show that ectopic expression of the telomerase gene in nonhuman primate ATSCs prevents senescence-associated impairment of osteoblast functions and that telomerase therapy may be a useful strategy for bone regeneration and repair.

Standard name | BASSO_CD40_SIGNALING_DN
Systematic name | M1899
Organism | Homo sapiens
PMID | 15331443
Authors | Basso K,Klein U,Niu H,Stolovitzky GA,Tu Y,Califano A,Cattoretti G,Dalla-Favera R
Category | C2
Sub-category | CGP
Brief description | Gene down-regulated by CD40 [GeneID=958] signaling in Ramos cells (EBV negative Burkitt lymphoma).
Full description | Substantial evidence indicates that signaling through the CD40 receptor (CD40) is required for germinal center (GC) and memory B-cell formation. However, it is not fully understood at which stages of B-cell development the CD40 pathway is activated in vivo. To address this question, we induced CD40 signaling in human transformed GC B cells in vitro and identified a CD40 gene expression signature by DNA microarray analysis. This signature was then investigated in the gene expression profiles of normal B cells and found in pre- and post-GC B cells (naive and memory) but, surprisingly, not in GC B cells. This finding was validated in lymphoid tissues by showing that the nuclear factor-kappaB (NF-kappaB) transcription factors, which translocate to the nucleus upon CD40 stimulation, are retained in the cytoplasm in most GC B cells, indicating the absence of CD40 signaling. Nevertheless, a subset of centrocytes and B cells in the subepithelium showed nuclear staining of multiple NF-kappaB subunits, suggesting that a fraction of naive and memory B cells may be subject to CD40 signaling or to other signals that activate NF-kappaB. Together, these results show that GC expansion occurs in the absence of CD40 signaling, which may act only in the initial and final stages of the GC reaction.

Standard name | ZHAN_MULTIPLE_MYELOMA_MF_UP
Systematic name | M10770
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 up-regulated genes in cluster MF of multiple myeloma samples with characteristic expression spike of MAF family transcription factors.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | PETROVA_ENDOTHELIUM_LYMPHATIC_VS_BLOOD_DN
Systematic name | M1459
Organism | Homo sapiens
PMID | 12198161
Authors | Petrova TV,Mäkinen T,Mäkelä TP,Saarela J,Virtanen I,Ferrell RE,Finegold DN,Kerjaschki D,Ylä-Herttuala S,Alitalo K
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in BEC (blood endothelial cells) compared to LEC (lymphatic endothelial cells).
Full description | Lymphatic vessels are essential for fluid homeostasis, immune surveillance and fat adsorption, and also serve as a major route for tumor metastasis in many types of cancer. We found that isolated human primary lymphatic and blood vascular endothelial cells (LECs and BECs, respectively) show interesting differences in gene expression relevant for their distinct functions in vivo. Although these phenotypes are stable in vitro and in vivo, overexpression of the homeobox transcription factor Prox-1 in the BECs was capable of inducing LEC-specific gene transcription in the BECs, and, surprisingly, Prox-1 suppressed the expression of approximately 40% of the BEC-specific genes. Prox-1 did not have global effects on the expression of LEC-specific genes in other cell types, except that it up-regulated cyclin E1 and E2 mRNAs and activated the cyclin e promoter in various cell types. These data suggest that Prox-1 acts as a cell proliferation inducer and a fate determination factor for the LECs. Furthermore, the data provide insights into the phenotypic diversity of endothelial cells and into the possibility of transcriptional reprogramming of differentiated endothelial cells.

Standard name | JAIN_NFKB_SIGNALING
Systematic name | M17646
Organism | Homo sapiens
PMID | 15578091
Authors | Jain A,Ma CA,Lopez-Granados E,Means G,Brady W,Orange JS,Liu S,Holland S,Derry JM
Category | C2
Sub-category | CGP
Brief description | Genes abnormally regulated in response to CD40L and IL4 [GeneID=959;3565] stimulation of B lymphocytes from patients with a hypomorphic mutation of IKBKG [GeneID=8517].
Full description | Hypomorphic mutations in the zinc finger domain of NF-kappaB essential modulator (NEMO) cause X-linked hyper-IgM syndrome with ectodermal dysplasia (XHM-ED). Here we report that patient B cells are characterized by an absence of Ig somatic hypermutation (SHM) and defective class switch recombination (CSR) despite normal induction of activation-induced cytidine deaminase (AID) and Iepsilon-Cepsilon transcripts. This indicates that AID expression alone is insufficient to support neutralizing antibody responses. Furthermore, we show that patient B cells stimulated with CD40 ligand are impaired in both p65 and c-Rel activation, and whereas addition of IL-4 can enhance p65 activity, c-Rel activity remains deficient. This suggests that these NF-kappaB components have different activation requirements and that IL-4 can augment some but not all NEMO-dependent NF-kappaB signaling. Finally, using microarray analysis of patient B cells we identified downstream effects of impaired NF-kappaB activation and candidate factors that may be necessary for CSR and SHM in B cells.

Standard name | ROETH_TERT_TARGETS_UP
Systematic name | M18660
Organism | Homo sapiens
PMID | 15741219
Authors | Röth A,Baerlocher GM,Schertzer M,Chavez E,Dührsen U,Lansdorp PM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T lymphocytes overexpressing TERT [GeneID=7015] off a retrovirus vector.
Full description | Little is known about the long-term consequences of overexpression of the human telomerase reverse transcriptase (hTERT) gene in T lymphocytes. To address this issue, we transduced polyclonal as well as clonally derived populations of naive and memory CD44 T cells from 2 healthy donors (aged 24 and 34 years) with retroviral vectors encoding green fluorescence protein (GFP) and hTERT (GFP-hTERT) or GFP alone. After transduction, cells were sorted on the basis of GFP expression and cultured in vitro until senescence. T cells transduced with hTERT exhibited high stable telomerase activity throughout the culture period. Relative to GFP controls, minor changes in overall gene expression were observed yet the proliferative lifespan of the hTERT-transduced populations was significantly increased and the rate of telomere loss was lower. Nevertheless, hTERT-transduced cells showed progressive telomere loss and had shorter telomeres at senescence than controls (2.3 +/- 0.3 kilobase [kb] versus 3.4 +/- 0.1 kb). Furthermore, a population of cells with 4N DNA consisting of binucleated cells with connected nuclei emerged in the hTERT-transduced cells prior to senescence. We conclude that overexpression of hTERT in CD4+ T cells provides a proliferative advantage independent of the average telomere length but does not prevent eventual genetic instability and replicative senescence.

Standard name | PETROVA_ENDOTHELIUM_LYMPHATIC_VS_BLOOD_UP
Systematic name | M1461
Organism | Homo sapiens
PMID | 12198161
Authors | Petrova TV,Mäkinen T,Mäkelä TP,Saarela J,Virtanen I,Ferrell RE,Finegold DN,Kerjaschki D,Ylä-Herttuala S,Alitalo K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in LEC (lymphatic endothelial cells) compared to BEC (blood endothelial cells).
Full description | Lymphatic vessels are essential for fluid homeostasis, immune surveillance and fat adsorption, and also serve as a major route for tumor metastasis in many types of cancer. We found that isolated human primary lymphatic and blood vascular endothelial cells (LECs and BECs, respectively) show interesting differences in gene expression relevant for their distinct functions in vivo. Although these phenotypes are stable in vitro and in vivo, overexpression of the homeobox transcription factor Prox-1 in the BECs was capable of inducing LEC-specific gene transcription in the BECs, and, surprisingly, Prox-1 suppressed the expression of approximately 40% of the BEC-specific genes. Prox-1 did not have global effects on the expression of LEC-specific genes in other cell types, except that it up-regulated cyclin E1 and E2 mRNAs and activated the cyclin e promoter in various cell types. These data suggest that Prox-1 acts as a cell proliferation inducer and a fate determination factor for the LECs. Furthermore, the data provide insights into the phenotypic diversity of endothelial cells and into the possibility of transcriptional reprogramming of differentiated endothelial cells.

Standard name | LI_WILMS_TUMOR_VS_FETAL_KIDNEY_1_UP
Systematic name | M12621
Organism | Homo sapiens
PMID | 12057921
Authors | Li CM,Guo M,Borczuk A,Powell CA,Wei M,Thaker HM,Friedman R,Klein U,Tycko B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Wilm's tumor samples compared to fetal kidney.
Full description | Wilms' tumor (WT) has been considered a prototype for arrested cellular differentiation in cancer, but previous studies have relied on selected markers. We have now performed an unbiased survey of gene expression in WTs using oligonucleotide microarrays. Statistical criteria identified 357 genes as differentially expressed between WTs and fetal kidneys. This set contained 124 matches to genes on a microarray used by Stuart and colleagues (Stuart RO, Bush KT, Nigam SK: Changes in global gene expression patterns during development and maturation of the rat kidney. Proc Natl Acad Sci USA 2001, 98:5649-5654) to establish genes with stage-specific expression in the developing rat kidney. Mapping between the two data sets showed that WTs systematically overexpressed genes corresponding to the earliest stage of metanephric development, and underexpressed genes corresponding to later stages. Automated clustering identified a smaller group of 27 genes that were highly expressed in WTs compared to fetal kidney and heterologous tumor and normal tissues. This signature set was enriched in genes encoding transcription factors. Four of these, PAX2, EYA1, HBF2, and HOXA11, are essential for cell survival and proliferation in early metanephric development, whereas others, including SIX1, MOX1, and SALL2, are predicted to act at this stage. SIX1 and SALL2 proteins were expressed in the condensing mesenchyme in normal human fetal kidneys, but were absent (SIX1) or reduced (SALL2) in cells at other developmental stages. These data imply that the blastema in WTs has progressed to the committed stage in the mesenchymal-epithelial transition, where it is partially arrested in differentiation. The WT-signature set also contained the Wnt receptor FZD7, the tumor antigen PRAME, the imprinted gene NNAT and the metastasis-associated transcription factor E1AF.

Standard name | STAEGE_EWING_FAMILY_TUMOR
Systematic name | M10582
Organism | Homo sapiens
PMID | 15548687
Authors | Staege MS,Hutter C,Neumann I,Foja S,Hattenhorst UE,Hansen G,Afar D,Burdach SE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Ewing family tumors (EFT) compared with normal bone marrow samples.
Full description | Ewing family tumors (EFTs) are small round blue cell tumors that show features of neuroectodermal differentiation. However, the histogenetic origin of EFTs is still a matter of debate. We used high-density DNA microarrays for the identification of EFT-specific gene expression profiles in comparison with normal tissues of diverse origin. We identified 37 genes that are up-regulated in EFTs compared with normal tissues and validated expression of these genes in EFTs by both conventional and quantitative reverse transcription-polymerase chain reaction. The expression pattern of EFT-associated genes in normal tissues indicated a high similarity between EFTs and fetal and neuronal as well as endothelial tissues and supports the concept that a primitive neural crest-derived progenitor at the transition to mesenchymal and endothelial differentiation is transformed in EFTs. EFT-associated genes could be used for molecular discrimination between EFTs and other small round blue cell tumors and clearly identified a cell line (SK-N-MC) that was initially established as neuroblastoma as being an EFT. Ectopic expression of the EFT-specific EWS-FLI1 fusion protein in human embryonic kidney (HEK293) cells was not sufficient to induce the complete EFT-specific gene expression signature, suggesting that the EFT-specific gene expression profile is not just a consequence of EWS-FLI1 expression but depends on the histogenetic background of the EFT stem cell.

Standard name | GALE_APL_WITH_FLT3_MUTATED_UP
Systematic name | M3845
Organism | Homo sapiens
PMID | 16105978
Authors | Gale RE,Hills R,Pizzey AR,Kottaridis PD,Swirsky D,Gilkes AF,Nugent E,Mills KI,Wheatley K,Solomon E,Burnett AK,Linch DC,Grimwade D,NCRI Adult Leukaemia Working Party
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in acute promyelocytic leukemia (APL) patients with mutated FLT3 [GeneID=2322].
Full description | The prognostic significance of FLT3 mutations in acute promyelocytic leukemia (APL) is not firmly established and is of particular interest given the opportunities for targeted therapies using FLT3 inhibitors. We studied 203 patients with PML-RARA-positive APL; 43% of the patients had an FLT3 mutation (65 internal tandem duplications [ITDs], 19 D835/I836, 4 ITD+D835/I836). Both mutations were associated with higher white blood cell (WBC) count at presentation; 75% of the patients with WBC counts of 10 x 10(9)/L or greater had mutant FLT3. FLT3/ITDs were correlated with M3v subtype (P < .001), bcr3 PML breakpoint (P < .001), and expression of reciprocal RARA-PML transcripts (P = .01). Microarray analysis revealed differences in expression profiles among patients with FLT3/ITD, D835/I836, and wild-type FLT3. Patients with mutant FLT3 had a higher rate of induction death (19% vs 9%; P = .04, but no significant difference in relapse risk (28% vs 23%; P = .5) or overall survival (59% vs 67%; P = .2) at 5 years. In in vitro differentiation assays using primary APL blasts (n = 6), the FLT3 inhibitor CEP-701 had a greater effect on cell survival/proliferation in FLT3/ITD+ cells, but this inhibition was reduced in the presence of ATRA. Furthermore, in the presence of CEP-701, ATRA-induced differentiation was reduced in FLT3/ITD+ cells. These data carry implications for the use of FLT3 inhibitors as frontline therapy for APL.

Standard name | AFFAR_YY1_TARGETS_UP
Systematic name | M1466
Organism | Mus musculus
PMID | 16611997
Authors | Affar el B,Gay F,Shi Y,Liu H,Huarte M,Wu S,Collins T,Li E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) expressing ~25% of YY1 [GeneID=7528].
Full description | Constitutive ablation of the Yin Yang 1 (YY1) transcription factor in mice results in peri-implantation lethality. In this study, we used homologous recombination to generate knockout mice carrying yy1 alleles expressing various amounts of YY1. Phenotypic analysis of yy1 mutant embryos expressing approximately 75%, approximately 50%, and approximately 25% of the normal complement of YY1 identified a dosage-dependent requirement for YY1 during late embryogenesis. Indeed, reduction of YY1 levels impairs embryonic growth and viability in a dose-dependent manner. Analysis of the corresponding mouse embryonic fibroblast cells also revealed a tight correlation between YY1 dosage and cell proliferation, with a complete ablation of YY1 inducing cytokinesis failure and cell cycle arrest. Consistently, RNA interference-mediated inhibition of YY1 in HeLa cells prevents cytokinesis, causes proliferative arrest, and increases cellular sensitivity to various apoptotic agents. Genome-wide expression profiling identified a plethora of YY1 target genes that have been implicated in cell growth, proliferation, cytokinesis, apoptosis, development, and differentiation, suggesting that YY1 coordinates multiple essential biological processes through a complex transcriptional network. These data not only shed new light on the molecular basis for YY1 developmental roles and cellular functions, but also provide insight into the general mechanisms controlling eukaryotic cell proliferation, apoptosis, and differentiation.

Standard name | THEILGAARD_NEUTROPHIL_AT_SKIN_WOUND_DN
Systematic name | M11234
Organism | Homo sapiens
PMID | 15187151
Authors | Theilgaard-Mönch K,Knudsen S,Follin P,Borregaard N
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in polymorphonuclear neutrophilic granulocytes (PMNs) attracted to skin wounds.
Full description | To investigate the cellular fate and function of polymorphonuclear neutrophilic granulocytes (PMNs) attracted to skin wounds, we used a human skin-wounding model and microarray technology to define differentially expressed genes in PMNs from peripheral blood, and PMNs that had transmigrated to skin lesions. After migration to skin lesions, PMNs demonstrated a significant transcriptional response including genes from several different functional categories. The up-regulation of anti-apoptotic genes concomitant with the down-regulation of proapoptotic genes suggested a transient anti-apoptotic priming of PMNs. Among the up-regulated genes were cytokines and chemokines critical for chemotaxis of macrophages, T cells, and PMNs, and for the modulation of their inflammatory responses. PMNs in skin lesions down-regulated receptors mediating chemotaxis and anti-microbial activity, but up-regulated other receptors involved in inflammatory responses. These findings indicate a change of responsiveness to chemotactic and immunoregulatory mediators once PMNs have migrated to skin lesions and have been activated. Other effects of the up-regulated cytokines/chemokines/enzymes were critical for wound healing. These included the breakdown of fibrin clots and degradation of extracellular matrix, the promotion of angiogenesis, the migration and proliferation of keratinocytes and fibroblasts, the adhesion of keratinocytes to the dermal layer, and finally, the induction of anti-microbial gene expression in keratinocytes. Notably, the up-regulation of genes, which activate lysosomal proteases, indicate a priming of skin lesion-PMNs for degradation of phagocytosed material. These findings demonstrate that migration of PMNs to skin lesions induces a transcriptional activation program, which regulates cellular fate and function, and promotes wound healing.

Standard name | AFFAR_YY1_TARGETS_DN
Systematic name | M1471
Organism | Mus musculus
PMID | 16611997
Authors | Affar el B,Gay F,Shi Y,Liu H,Huarte M,Wu S,Collins T,Li E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblast) expressing ~25% of YY1 [GeneID=7528].
Full description | Constitutive ablation of the Yin Yang 1 (YY1) transcription factor in mice results in peri-implantation lethality. In this study, we used homologous recombination to generate knockout mice carrying yy1 alleles expressing various amounts of YY1. Phenotypic analysis of yy1 mutant embryos expressing approximately 75%, approximately 50%, and approximately 25% of the normal complement of YY1 identified a dosage-dependent requirement for YY1 during late embryogenesis. Indeed, reduction of YY1 levels impairs embryonic growth and viability in a dose-dependent manner. Analysis of the corresponding mouse embryonic fibroblast cells also revealed a tight correlation between YY1 dosage and cell proliferation, with a complete ablation of YY1 inducing cytokinesis failure and cell cycle arrest. Consistently, RNA interference-mediated inhibition of YY1 in HeLa cells prevents cytokinesis, causes proliferative arrest, and increases cellular sensitivity to various apoptotic agents. Genome-wide expression profiling identified a plethora of YY1 target genes that have been implicated in cell growth, proliferation, cytokinesis, apoptosis, development, and differentiation, suggesting that YY1 coordinates multiple essential biological processes through a complex transcriptional network. These data not only shed new light on the molecular basis for YY1 developmental roles and cellular functions, but also provide insight into the general mechanisms controlling eukaryotic cell proliferation, apoptosis, and differentiation.

Standard name | FAELT_B_CLL_WITH_VH_REARRANGEMENTS_DN
Systematic name | M10389
Organism | Homo sapiens
PMID | 15817677
Authors | Fält S,Merup M,Tobin G,Thunberg U,Gahrton G,Rosenquist R,Wennborg A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in B-CLL (B-cell chronic lymphocytic leukemia) patients with mutated immunoglobulin variable heavy chain (VH) genes.
Full description | The usage of the immunoglobulin (Ig) V(H)3-21 gene is associated with poor prognosis in B-cell chronic lymphocytic leukemia (B-CLL) despite V(H) gene mutation status. Many V(H)3-21+ patients also display restricted heavy- and light-chain Ig gene rearrangements, implying a role of antigen selection in disease development. To explore the specific phenotypic/genotypic features among V(H)3-21+ B-CLLs, we compared gene expression patterns in 15 V(H)3-21+ and 24 non-V(H)3-21 patients (11 with unmutated and 13 with mutated V(H) genes) using Affymetrix microarray analysis (approximately 12,500 genes). A distinct expression profile was identified for V(H)3-21+ patients in contrast to the Ig-unmutated and -mutated groups. By applying different algorithms, the data enabled an efficient class discrimination of the V(H)3-21+ subset based on 27 or 57 genes. A set of genes was sorted out which, using different analytical methods, consistently gave a distinction between V(H)3-21+ and non-V(H)3-21 samples. Several of these genes are involved in regulation of DNA replication/cell-cycle control, transcription and protein kinase activity, which may render the V(H)3-21+ cells with a higher proliferative drive. However, no clear evidence of increased B-cell receptor signaling was found in the V(H)3-21+ group. Altogether, our identification of a specific V(H)3-21 profile may provide insights into the pathogenesis of the V(H)3-21+ subgroup.

Standard name | VERNELL_RETINOBLASTOMA_PATHWAY_UP
Systematic name | M15969
Organism | Homo sapiens
PMID | 12923195
Authors | Vernell R,Helin K,Müller H
Category | C2
Sub-category | CGP
Brief description | Cluster 1: genes up-regulated by RB1, CDNK2A [GeneID=1029;5925], and one of the E2Fs (E2F1, E2F2, or E2F3 [GeneID=1869;1870;1871]).
Full description | Deregulation of the retinoblastoma protein (pRB) pathway is a hallmark of human cancer. The core members of this pathway include the tumor suppressor protein, pRB, which through binding to a number of cellular proteins, most notably members of the E2F transcription factor family, regulates progression through the cell division cycle. With the aim of identifying transcriptional changes provoked by deregulation of the pRB pathway, we have used cell lines that conditionally express a constitutively active phosphorylation site mutant of pRB (pRBDeltaCDK) or p16INK4A (p16). The expression of pRBDeltaCDK and p16 resulted in significant repression and activation of a large number of genes as measured by high density oligonucleotide array analysis. Transcriptional changes were found in genes that are essential for DNA replication and cell proliferation. In agreement with previous results, we found a high degree of overlap between genes regulated by p16 and pRB. Data we have obtained previously for E2F family members showed that 74 of the genes repressed by pRB and p16 were induced by the E2Fs and 23 genes that were induced by pRB and p16 were repressed by the E2Fs. Thus, we have identified 97 genes as physiological targets of the pRB pathway, and the further characterization of these genes should provide insights into how this pathway controls proliferation. We show that Gibbs sampling detects enrichment of several sequence motifs, including E2F consensus binding sites, in the upstream regions of these genes and use this enrichment in an in silico filtering process to refine microarray derived gene lists.

Standard name | ALCALAY_AML_BY_NPM1_LOCALIZATION_DN
Systematic name | M19867
Organism | Homo sapiens
PMID | 15831697
Authors | Alcalay M,Tiacci E,Bergomas R,Bigerna B,Venturini E,Minardi SP,Meani N,Diverio D,Bernard L,Tizzoni L,Volorio S,Luzi L,Colombo E,Lo Coco F,Mecucci C,Falini B,Pelicci PG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in acute myeloid leukemia (AML) with respect to cellular localization of NPM1 [GeneID=4869]: cytoplasmic vs. nucleolar.
Full description | Approximately one third of acute myeloid leukemias (AMLs) are characterized by aberrant cytoplasmic localization of nucleophosmin (NPMc+ AML), consequent to mutations in the NPM putative nucleolar localization signal. These events are mutually exclusive with the major AML-associated chromosomal rearrangements, and are frequently associated with normal karyotype, FLT3 mutations, and multilineage involvement. We report the gene expression profiles of 78 de novo AMLs (72 with normal karyotype; 6 without major chromosomal abnormalities) that were characterized for the subcellular localization and mutation status of NPM. Unsupervised clustering clearly separated NPMc+ from NPMc- AMLs, regardless of the presence of FLT3 mutations or non-major chromosomal rearrangements, supporting the concept that NPMc+ AML represents a distinct entity. The molecular signature of NPMc+ AML includes up-regulation of several genes putatively involved in the maintenance of a stem-cell phenotype, suggesting that NPMc+ AML may derive from a multipotent hematopoietic progenitor.

Standard name | KANG_IMMORTALIZED_BY_TERT_DN
Systematic name | M1514
Organism | Homo sapiens
PMID | 15579653
Authors | Kang SK,Putnam L,Dufour J,Ylostalo J,Jung JS,Bunnell BA
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the signature of adipose stromal cells (ADSC) immortalized by forced expression of telomerase (TERT) [GeneID=7015].
Full description | Expression of TERT, the catalytic protein subunit of the telomerase complex, can be used to generate cell lines that expand indefinitely and retain multilineage potential. We have created immortal adipose stromal cell lines (ATSCs) by stably transducing nonhuman primate-derived ATSCs with a retroviral vector expressing TERT. Transduced cells (ATSC-TERT) had an increased level of telomerase activity and increased mean telomere length in the absence of malignant cellular transformation. Long-term culture of the ATSC-TERT cells demonstrated that the cells retain the ability to undergo differentiation along multiple lineages such as adipogenic, chondrogenic, and neurogenic. Untransduced cells demonstrated markedly reduced multilineage and self-renewal potentials after 12 passages in vitro. To determine the functional role of telomerase during osteogenesis, we examined osteogenic differentiation potential of ATSC-TERT cells in vitro. Compared with naive ATSCs, which typically begin to accumulate calcium after 3-4 weeks of induction by osteogenic differentiation medium, ATSC-TERT cells were found to accumulate significant amounts of calcium after only 1 week of culture in osteogenic induction medium. The cells have increased production of osteoblastic markers, such as AP2, osteoblast-specific factor 2, chondroitin sulfate proteoglycan 4, and the tumor necrosis factor receptor superfamily, compared with control ATSCs, indicating that telomerase expression may aid in maintaining the osteogenic stem cell pool during in vitro expansion. These results show that ectopic expression of the telomerase gene in nonhuman primate ATSCs prevents senescence-associated impairment of osteoblast functions and that telomerase therapy may be a useful strategy for bone regeneration and repair.

Standard name | HESS_TARGETS_OF_HOXA9_AND_MEIS1_UP
Systematic name | M1319
Organism | Mus musculus
PMID | 16507773
Authors | Hess JL,Bittner CB,Zeisig DT,Bach C,Fuchs U,Borkhardt A,Frampton J,Slany RK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hematopoietic precursor cells conditionally expressing HOXA9 and MEIS1 [GeneID=3205;4211].
Full description | Abdominal-type HoxA genes in combination with Meis1 are well-documented on-cogenes in various leukemias but it is unclear how they exert their transforming function. Here we used a system of conditional transformation by an inducible mixed lineage leukemia-eleven-nineteen leukemia (MLL-ENL) oncoprotein to overexpress Hoxa9 and Meis1 in primary hematopoietic cells. Arrays identified c-Myb and a c-Myb target (Gstm1) among the genes with the strongest response to Hoxa9/Meis1. c-Myb overexpression was verified by Northern blot and quantitative reverse transcription-polymerase chain reaction (RT-PCR). Also MLL-ENL activated c-Myb through up-regulation of Hoxa9 and Meis1. Consequently, short-term suppression of c-Myb by small inhibitory RNA (siRNA) efficiently inhibited transformation by MLL-ENL but did not impair transformation by transcription factor E2A-hepatic leukemia factor (E2A-HLF). The anti c-Myb siRNA effect was abrogated by coexpression of a c-Myb derivative with a mutated siRNA target site. The introduction of a dominant-negative c-Myb mutant had a similar but weaker effect on MLL-ENL-mediated transformation. Hematopoietic precursors from mice homozygous for a hypo-morphic c-Myb allele were more severely affected and could be transformed neither by MLL-ENL nor by E2A-HLF. Ectopic expression of c-Myb induced a differentiation block but c-Myb alone was not transforming in a replating assay similar to Hoxa9/Meis1. These results suggest that c-Myb is essential but not sufficient for Hoxa9/Meis1 mediated transformation.

Standard name | YAO_HOXA10_TARGETS_VIA_PROGESTERONE_DN
Systematic name | M4435
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the uteri of ovariectomized mice 6 h after progesterone [PubChem=5994] injection: HOXA10 [GeneID=3206] knockout vs wild type animals.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | NGUYEN_NOTCH1_TARGETS_DN
Systematic name | M14650
Organism | Homo sapiens
PMID | 16618808
Authors | Nguyen BC,Lefort K,Mandinova A,Antonini D,Devgan V,Della Gatta G,Koster MI,Zhang Z,Wang J,Tommasi di Vignano A,Kitajewski J,Chiorino G,Roop DR,Missero C,Dotto GP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary keratinocytes by expression of constantly active NOTCH1 [GeneID=4851].
Full description | Notch signaling promotes commitment of keratinocytes to differentiation and suppresses tumorigenesis. p63, a p53 family member, has been implicated in establishment of the keratinocyte cell fate and/or maintenance of epithelial self-renewal. Here we show that p63 expression is suppressed by Notch1 activation in both mouse and human keratinocytes through a mechanism independent of cell cycle withdrawal and requiring down-modulation of selected interferon-responsive genes, including IRF7 and/or IRF3. In turn, elevated p63 expression counteracts the ability of Notch1 to restrict growth and promote differentiation. p63 functions as a selective modulator of Notch1-dependent transcription and function, with the Hes-1 gene as one of its direct negative targets. Thus, a complex cross-talk between Notch and p63 is involved in the balance between keratinocyte self-renewal and differentiation.

Standard name | MOREAUX_MULTIPLE_MYELOMA_BY_TACI_UP
Systematic name | M19025
Organism | Homo sapiens
PMID | 15827134
Authors | Moreaux J,Cremer FW,Reme T,Raab M,Mahtouk K,Kaukel P,Pantesco V,De Vos J,Jourdan E,Jauch A,Legouffe E,Moos M,Fiol G,Goldschmidt H,Rossi JF,Hose D,Klein B
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes distinguishing in multiple myeloma (MM) samples with higher expression of TACI [GeneID=23495].
Full description | B-cell activating factor (BAFF) and a proliferation-inducing ligand (APRIL) have been shown to promote multiple myeloma (MM) cell growth. We show that the main site of production for BAFF and APRIL is the bone marrow (BM) environment, and that production is mainly by monocytes and neutrophils. In addition, osteoclasts produce very high levels of APRIL, unlike BM stromal cells. Myeloma cells (MMCs) express TACI (transmembrane activator and calcium modulator and cyclophilin ligand interactor), the receptor of BAFF/APRIL, at varying levels. TACI expression is a good indicator of a BAFF-binding receptor. Expression data of purified MMCs from 65 newly diagnosed patients have been generated using Affymetrix microarrays and were analyzed by supervised clustering of groups with higher (TACI(hi)) versus lower (TACI(lo)) TACI expression levels. Patients in the TACI(lo) group had clinical parameters associated with bad prognosis. A set of 659 genes was differentially expressed between TACI(hi) and TACI(lo) MMCs. This set makes it possible to efficiently classify TACI(hi) and TACI(lo) MMCs in an independent cohort of 40 patients. TACI(hi) MMCs displayed a mature plasma cell gene signature, indicating dependence on the BM environment. In contrast, the TACI(lo) group had a gene signature of plasmablasts, suggesting an attenuated dependence on the BM environment. Taken together, our findings suggest using gene expression profiling to identify the group of patients who might benefit most from treatment with BAFF/APRIL inhibitors.

Standard name | CHIARETTI_ACUTE_LYMPHOBLASTIC_LEUKEMIA_ZAP70
Systematic name | M305
Organism | Homo sapiens
PMID | 16160012
Authors | Chiaretti S,Guarini A,Propris De MS,Tavolaro S,Intoppa S,Vitale A,Iacobelli S,Elia L,Ariola C,Ritz J,Foà R
Category | C2
Sub-category | CGP
Brief description | Differentially expressed genes between high vs low ZAP70 [GeneID=7535] acute lymphoblastic leukemia (ALL) cases with no known molecular aberrations.
Full description | We evaluated the expression of 2 members of the Syk family, ZAP-70 and Syk, in acute lymphoblastic leukemia (ALL) samples, using data derived from a series of 33 T-ALL and 95 B-lineage adult ALL patients analyzed by oligonucleotide arrays. Of the B-lineage ALL cases, 37 were BCR/ABL+, 10 were ALL1/AF4+, 5 were E2A/PBX1+, and 43 carried no known molecular abnormality. ZAP-70 was highly expressed in T-ALL. A high ZAP-70 expression was also found in a proportion of B-lineage ALL, the highest levels being associated with the E2A/PBX1+ group and the lowest with ALL1/AF4+ cases (P < .001). A higher ZAP-70 expression was also observed in the pre-B group (P < .001). Remarkably, Syk expression was always preserved, suggesting that ZAP-70 expression is not substitutive of Syk. At the protein level, ZAP-70 was evaluated on 39 newly diagnosed ALL patients (25 adults, 14 children) and was detected in 23 cases (59%). ZAP-70 expression was consistently found in Ig mu+ cases. Evaluation of long-term outcome in cases without molecular abnormalities showed that the higher levels of ZAP-70 were coupled to a higher relapse rate. In ALL, ZAP-70 expression is associated with the E2A/PBX1 rearrangement and pre-B stage and may have a prognostic role and be a candidate molecule for targeted therapies.

Standard name | PETROVA_PROX1_TARGETS_DN
Systematic name | M1472
Organism | Homo sapiens
PMID | 12198161
Authors | Petrova TV,Mäkinen T,Mäkelä TP,Saarela J,Virtanen I,Ferrell RE,Finegold DN,Kerjaschki D,Ylä-Herttuala S,Alitalo K
Category | C2
Sub-category | CGP
Brief description | Genes specific to BEC (blood endothelium cells) repressed in BEC by expression of PROX1 [GeneID=5629] off adenovirus vector.
Full description | Lymphatic vessels are essential for fluid homeostasis, immune surveillance and fat adsorption, and also serve as a major route for tumor metastasis in many types of cancer. We found that isolated human primary lymphatic and blood vascular endothelial cells (LECs and BECs, respectively) show interesting differences in gene expression relevant for their distinct functions in vivo. Although these phenotypes are stable in vitro and in vivo, overexpression of the homeobox transcription factor Prox-1 in the BECs was capable of inducing LEC-specific gene transcription in the BECs, and, surprisingly, Prox-1 suppressed the expression of approximately 40% of the BEC-specific genes. Prox-1 did not have global effects on the expression of LEC-specific genes in other cell types, except that it up-regulated cyclin E1 and E2 mRNAs and activated the cyclin e promoter in various cell types. These data suggest that Prox-1 acts as a cell proliferation inducer and a fate determination factor for the LECs. Furthermore, the data provide insights into the phenotypic diversity of endothelial cells and into the possibility of transcriptional reprogramming of differentiated endothelial cells.

Standard name | HOEGERKORP_CD44_TARGETS_DIRECT_DN
Systematic name | M1823
Organism | Homo sapiens
PMID | 12411303
Authors | Högerkorp CM,Bilke S,Breslin T,Ingvarsson S,Borrebaeck CA
Category | C2
Sub-category | CGP
Brief description | Genes directly down-regulated by CD44 [GeneID=960] stimulation of B lymphocytes.
Full description | A number of studies have implicated a role for the cell surface glycoprotein CD44 in several biologic events, such as lymphopoiesis, homing, lymphocyte activation, and apoptosis. We have earlier reported that signaling via CD44 on naive B cells in addition to B-cell receptor (BCR) and CD40 engagement generated a germinal center-like phenotype. To further characterize the global role of CD44 in B differentiation, we examined the expression profile of human B cells cultured in vitro in the presence or absence of CD44 ligation, together with anti-immunoglobulin (anti-Ig) and anti-CD40 antibodies. The data sets derived from DNA microarrays were analyzed using a novel statistical analysis scheme created to retrieve the most likely expression pattern of CD44 ligation. Our results show that genes such as interleukin-6 (IL-6), IL-1alpha, and beta(2)-adrenergic receptor (beta(2)-AR) were specifically up-regulated by CD44 ligation, suggesting a novel role for CD44 in immunoregulation and inflammation.

Standard name | BENNETT_SYSTEMIC_LUPUS_ERYTHEMATOSUS
Systematic name | M12175
Organism | Homo sapiens
PMID | 12642603
Authors | Bennett L,Palucka AK,Arce E,Cantrell V,Borvak J,Banchereau J,Pascual V
Category | C2
Sub-category | CGP
Brief description | Genes significantly up-regulated in the blood mononuclear cells from patients with systemic lupus erythematosus compared to those from healthy persons.
Full description | Systemic lupus erythematosus (SLE) is a prototype systemic autoimmune disease characterized by flares of high morbidity. Using oligonucleotide microarrays, we now show that active SLE can be distinguished by a remarkably homogeneous gene expression pattern with overexpression of granulopoiesis-related and interferon (IFN)-induced genes. Using the most stringent statistical analysis (Bonferroni correction), 15 genes were found highly up-regulated in SLE patients, 14 of which are targets of IFN and one, defensin DEFA-3, a major product of immature granulocytes. A more liberal correction (Benjamini and Hochberg correction) yielded 18 additional genes, 12 of which are IFN-regulated and 4 granulocyte-specific. Indeed immature neutrophils were identified in a large fraction of SLE patients white blood cells. High dose glucocorticoids, a standard treatment of disease flares, shuts down the interferon signature, further supporting the role of this cytokine in SLE. The expression of 10 genes correlated with disease activity according to the SLEDAI. The most striking correlation (P < 0.001, r = 0.55) was found with the formyl peptide receptor-like 1 protein that mediates chemotactic activities of defensins. Therefore, while the IFN signature confirms the central role of this cytokine in SLE, microarray analysis of blood cells reveals that immature granulocytes may be involved in SLE pathogenesis.

Standard name | XU_RESPONSE_TO_TRETINOIN_UP
Systematic name | M4385
Organism | Homo sapiens
PMID | 16140955
Authors | Xu K,Guidez F,Glasow A,Chung D,Petrie K,Stegmaier K,Wang KK,Zhang J,Jing Y,Zelent A,Waxman S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NB4 cells (acute promyelocytic leukemia, APL) by tretinoin [PubChem=444795] alone.
Full description | Differentiation induction is an effective therapy for acute promyelocytic leukemia (APL), which dramatically responds to all-trans-retinoic acid (ATRA). Recent studies have indicated that combinatorial use of retinoid and nonretinoid compounds, such as histone deacetylase inhibitors, arsenics, and PKA agonists, has higher therapeutic value in this disease and potentially in other malignancies. In a screen of 370 compounds, we identified benzodithiophene analogues as potent enhancers of ATRA-induced APL cell differentiation. These effects were not associated with changes in global histone acetylation and, for the most potent compounds, were exerted at very low nanomolar concentrations, and were paralleled by enhancement of some, but not all, ATRA-modulated gene expressions. Investigating the mechanism underlying the effects of these drugs on ATRA-induced APL cell differentiation, we have shown that benzodithiophenes enhance ATRA-mediated dissociation and association of corepressor N-CoR and coactivator p300 acetyltransferase, respectively, with retinoic acid receptor (RAR) alpha proteins. These data suggest that benzodithiophenes act at the level of receptor activation, possibly by affecting posttranslational modification of the receptor (and/or coregulators), thus leading to an enhancement in ATRA-mediated effects on gene expression and APL cell differentiation. Given the specificities of these low benzodithiophene concentrations for PML-RARalpha and RARalpha, these drugs may be useful for combinatorial differentiation therapy of APL and possibly other acute myelogenous leukemia subtypes in which the overall ATRA signaling is suppressed.

Standard name | ABRAHAM_ALPC_VS_MULTIPLE_MYELOMA_DN
Systematic name | M9880
Organism | Homo sapiens
PMID | 15388584
Authors | Abraham RS,Ballman KV,Dispenzieri A,Grill DE,Manske MK,Price-Troska TL,Paz NG,Gertz MA,Fonseca R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in immunoglobulin light chain amyloidosis plasma cells (ALPC) compared to multiple myeloma (MM) cells.
Full description | Immunoglobulin light chain amyloidosis (AL) is characterized by a clonal expansion of plasma cells within the bone marrow. Gene expression analysis was used to identify a unique molecular profile for AL using enriched plasma cells (CD138+) from the bone marrow of 24 patients with AL and 28 patients with multiple myeloma (MM) and 6 healthy controls. Class prediction analysis (PAM) revealed a subset of 12 genes, which included TNFRSF7 (CD27), SDF-1, and PSMA2, that distinguished between these 2 groups with an estimated and observed accuracy of classification of 92%. This model was validated with an independent dataset of 11 patients with AL and 12 patients with MM with 87% accuracy. Differential expression for the most discriminant genes in the 12-gene subset was validated using quantitative real-time polymerase chain reaction and protein expression analysis, which upheld the observations from the micro-array expression data. Functional analyses using a novel network mapping software revealed a number of potentially significant pathways that were dysregulated in patients with AL, with those regulating proliferation, apoptosis, cell signaling, chemotaxis, and migration being substantially represented. This study provides new insight into the molecular profile of clonal plasma cells and its functional relevance in the pathogenesis of light chain amyloidosis.

Standard name | MENSE_HYPOXIA_UP
Systematic name | M11033
Organism | Homo sapiens
PMID | 16507782
Authors | Mense SM,Sengupta A,Zhou M,Lan C,Bentsman G,Volsky DJ,Zhang L
Category | C2
Sub-category | CGP
Brief description | Hypoxia response genes up-regulated in both astrocytes and HeLa cell line.
Full description | Oxygen is vital for the development and survival of mammals. In response to hypoxia, the brain initiates numerous adaptive responses at the organ level as well as at the molecular and cellular levels, including the alteration of gene expression. Astrocytes play critical roles in the proper functioning of the brain; thus the manner in which astrocytes respond to hypoxia is likely important in determining the outcome of brain hypoxia. Here, we used microarray gene expression profiling and data-analysis algorithms to identify and analyze hypoxia-responsive genes in primary human astrocytes. We also compared gene expression patterns in astrocytes with those in human HeLa cells and pulmonary artery endothelial cells (ECs). Remarkably, in astrocytes, five times as many genes were induced as suppressed, whereas in HeLa and pulmonary ECs, as many as or more genes were suppressed than induced. More genes encoding hypoxia-inducible functions, such as glycolytic enzymes and angiogenic growth factors, were strongly induced in astrocytes compared with HeLa cells. Furthermore, gene ontology and computational algorithms revealed that many target genes of the EGF and insulin signaling pathways and the transcriptional regulators Myc, Jun, and p53 were selectively altered by hypoxia in astrocytes. Indeed, Western blot analysis confirmed that two major signal transducers mediating insulin and EGF action, Akt and MEK1/2, were activated by hypoxia in astrocytes. These results provide a global view of the signaling and regulatory network mediating oxygen regulation in human astrocytes

Standard name | MARCINIAK_ER_STRESS_RESPONSE_VIA_CHOP
Systematic name | M1477
Organism | Mus musculus
PMID | 15601821
Authors | Marciniak SJ,Yun CY,Oyadomari S,Novoa I,Zhang Y,Jungreis R,Nagata K,Harding HP,Ron D
Category | C2
Sub-category | CGP
Brief description | Endoplasmic retuculum (ER) stress response (caused by tunicamycin [PubChem=5282055]) genes dependent on CHOP [GeneID=13198].
Full description | Unfolded and malfolded client proteins impose a stress on the endoplasmic reticulum (ER), which contributes to cell death in pathophysiological conditions. The transcription factor C/EBP homologous protein (CHOP) is activated by ER stress, and CHOP deletion protects against its lethal consequences. We find that CHOP directly activates GADD34, which promotes ER client protein biosynthesis by dephosphorylating phospho-Ser 51 of the alpha-subunit of translation initiation factor 2 (eIF2alpha) in stressed cells. Thus, impaired GADD34 expression reduces client protein load and ER stress in CHOP(-/-) cells exposed to perturbations that impair ER function. CHOP(-/-) and GADD34 mutant cells accumulate less high molecular weight protein complexes in their stressed ER than wild-type cells. Furthermore, mice lacking GADD34-directed eIF2alpha dephosphorylation, like CHOP(-/-) mice, are resistant to renal toxicity of the ER stress-inducing drug tunicamycin. CHOP also activates ERO1alpha, which encodes an ER oxidase. Consequently, the ER of stressed CHOP(-/-) cells is relatively hypo-oxidizing. Pharmacological and genetic manipulations that promote a hypo-oxidizing ER reduce abnormal high molecular weight protein complexes in the stressed ER and protect from the lethal consequences of ER stress. CHOP deletion thus protects cells from ER stress by decreasing ER client protein load and changing redox conditions within the organelle.

Standard name | ZHAN_V2_LATE_DIFFERENTIATION_GENES
Systematic name | M13059
Organism | Homo sapiens
PMID | 12393520
Authors | Zhan F,Tian E,Bumm K,Smith R,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | The v2LDG set: 50 most variable late differentiation genes (LDG) with similar expression patterns in bone marrow plasma cells (BPC) and multiple myeloma (MM) samples.
Full description | To identify genes linked to normal plasma cell (PC) differentiation and to classify multiple myeloma (MM) with respect to the expression patterns of these genes, we analyzed global mRNA expression in CD19-enriched B cells (BCs) from 7 tonsils, CD138-enriched PCs from 11 tonsils, 31 normal bone marrow samples, and 74 MM bone marrow samples using microarrays interrogating 6800 genes. Hierarchical clustering analyses with 3288 genes clearly segregated the 4 cell types, and chi-square and Wilcoxin rank sum tests (P <.0005) identified 359 and 500 previously defined and novel genes that distinguish tonsil BCs from tonsil PCs (early differentiation genes [EDGs]), and tonsil PCs from bone marrow PCs (late differentiation genes [LDGs]), respectively. MM as a whole was found to have dramatically variable expression of EDGs and LDGs, and one-way analysis of variance (ANOVA) was used to identify the most variable EDGs (vEDGs) and LDGs (v1LDG and v2LDG). Hierarchical cluster analysis with these genes revealed that previously defined MM gene expression subgroups (MM1-MM4) could be linked to one of the 3 normal cell types. Clustering with 30 vEDGs revealed that 13 of 18 MM4 cases clustered with tonsil BCs (P =.000 05), whereas 14 of 15 MM3 cases clustered with tonsil PCs when using 50 v1LDG (P =.000 008), and 14 of 20 MM2 cases clustered with bone marrow PCs when using 50 v2LDG (P =.000 09). MM1 showed no significant linkage with normal cell types studied. Thus, genes whose expression is linked to distinct transitions in late-stage B-cell differentiation can be used to classify MM.

Standard name | DORSEY_GAB2_TARGETS
Systematic name | M14557
Organism | Homo sapiens
PMID | 11830491
Authors | Dorsey JF,Cunnick JM,Mane SM,Wu J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by expression of GAB2 [GeneID=9846] in K562 cells (chronic myeloid leukemia (CML) cell line with p210 BCR-ABL [GeneID=613;25]).
Full description | In the blast crisis phase of chronic myelogenous leukemia (CML), Bcr-Abl(+) myeloblasts fail to undergo terminal maturation. The extracellular signal-regulated kinase (Erk) mitogen-activated protein (MAP) kinase has been shown to mediate terminal differentiation of myeloid cells. Interestingly, Bcr-Abl(+) CML cell lines established from blast crisis were found to have low Erk MAP kinase activity. In this study, we analyzed the role of the Gab2 docking protein in regulation of the Erk MAP kinase in Bcr-Abl(+) K562 human CML cells. Overexpression of Gab2 in K562 cells resulted in transcriptional activation of the c-fos serum response element (SRE) promoter, whereas overexpression of SHP2, Grb2, and CrkL had no effect. Activation of the c-fos SRE transcriptional activity by Gab2 required tyrosine 604, which is a SHP2 docking site on Gab2, and the SHP2 tyrosine phosphatase activity. Elk1, c-Jun, and CHOP trans-reporting assays indicated that overexpression of Gab2 selectively activated the Erk2-Elk1 signaling pathway. To determine cellular consequences of elevating the Gab2 level in K562 cells, stable cell lines for doxycycline-inducible expression of the wild-type Gab2 (Gab2WT) and an SHP2-binding defective Gab2 (Gab2Tyr604Phe) were established. Analysis of these cell lines indicated that induction of Gab2WT expression, but not Gab2Tyr604Phe expression, led to Erk activation, growth arrest, cell spreading, and enlargement; expression of megakaryocyte/platelet lineage-specific integrins alphaIIb/beta3 (CD41/CD61); and upregulation of RNA for megakaryocyte/platelet proteins. All of these changes are characteristics of megakaryocytic differentiation. Together, these results reveal Gab2 as a limiting signaling component for Erk MAP kinase activation and terminal differentiation of K562 CML cells.

Standard name | HADDAD_T_LYMPHOCYTE_AND_NK_PROGENITOR_DN
Systematic name | M999
Organism | Homo sapiens
PMID | 15331438
Authors | Haddad R,Guardiola P,Izac B,Thibault C,Radich J,Delezoide AL,Baillou C,Lemoine FM,Gluckman JC,Pflumio F,Canque B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hematopoietic progenitor cells (HPC) of T lymphocyte and NK (natural killer) lineage.
Full description | The early stages of human lymphopoiesis are poorly characterized. Here, we compared the lymphoid potential of a novel umbilical cord blood CD34(+)CD45RA(hi)CD7(+) hematopoietic progenitor cell (HPC) population with that of CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs, previously proposed as candidate common lymphoid progenitors. Limiting-dilution and clonal analysis, fetal thymic organ cultures, and culture onto Notch ligand Delta-like-1-expressing OP9 cells, showed that although CD34(+)CD45RA(hi)CD7(+) HPCs could generate cells of the 3 lymphoid lineages, their potential was skewed toward the T/natural killer (T/NK) lineages. In contrast, CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs predominantly exhibited a B-cell potential. Gene expression profiling with DNA microarrays confirmed that CD34(+)CD45RA(hi)CD7(+) HPCs selectively expressed T-lymphoid and NK lineage-committed genes while retaining expression of genes affiliated to the granulomonocytic lineage, whereas CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs displayed a typical pro-B-cell transcription profile and essentially lacked genes unrelated to the B lineage. In addition, both populations could be generated in vitro from CD34(+)CD45RA(int)CD7(-) and CD34(+)CD45RA(hi)Lin(-) HPCs with mixed lymphomyeloid potential, from which they emerged independently with different growth/differentiation factor requirements. These findings indicate that CD34(+)CD45RA(hi)CD7(+) and CD34(+)CD45RA(hi)Lin(-)CD10(+) HPCs correspond to multipotent early lymphoid progenitors polarized toward either the T/NK or B lineage, respectively.

Standard name | NAKAJIMA_MAST_CELL
Systematic name | M389
Organism | Homo sapiens
PMID | 11493461
Authors | Nakajima T,Matsumoto K,Suto H,Tanaka K,Ebisawa M,Tomita H,Yuki K,Katsunuma T,Akasawa A,Hashida R,Sugita Y,Ogawa H,Ra C,Saito H
Category | C2
Sub-category | CGP
Brief description | Top 50 most-increased mast cell specific genes.
Full description | Mast cells (MCs) and eosinophils are thought to play important roles in evoking allergic inflammation. Cell-type--specific gene expression was screened among 12,000 genes in human MCs and eosinophils with the use of high-density oligonucleotide probe arrays. In comparison with other leukocytes, MCs expressed 140 cell-type--specific transcripts, whereas eosinophils expressed only 34. Among the transcripts for expected MC-specific proteins such as tryptase, major basic protein (MBP), which had been thought to be eosinophil specific, was ranked fourth in terms of amounts of increased MC-specific messenger RNA. Mature eosinophils were almost lacking this transcript. MCs obtained from 4 different sources (ie, lung, skin, adult peripheral blood progenitor--derived and cord blood progenitor--derived MCs, and eosinophils) were found to have high protein levels of MBP in their granules with the use of flow cytometric and confocal laser scanning microscopic analyses. The present finding that MCs can produce abundant MBP is crucial because many reports regarding allergic pathogenesis have been based on earlier findings that MBP was almost unique to eosinophils and not produced by MCs. (Blood. 2001;98:1127-1134)

Standard name | LIAN_NEUTROPHIL_GRANULE_CONSTITUENTS
Systematic name | M1478
Organism | Mus musculus
PMID | 11468144
Authors | Lian Z,Wang L,Yamaga S,Bonds W,Beazer-Barclay Y,Kluger Y,Gerstein M,Newburger PE,Berliner N,Weissman SM
Category | C2
Sub-category | CGP
Brief description | Granule constituents expressed during mouse promyelocytic cell line differentiation to neutrophils.
Full description | Although the mature neutrophil is one of the better characterized mammalian cell types, the mechanisms of myeloid differentiation are incompletely understood at the molecular level. A mouse promyelocytic cell line (MPRO), derived from murine bone marrow cells and arrested developmentally by a dominant-negative retinoic acid receptor, morphologically differentiates to mature neutrophils in the presence of 10 microM retinoic acid. An extensive catalog was prepared of the gene expression changes that occur during morphologic maturation. To do this, 3'-end differential display, oligonucleotide chip array hybridization, and 2-dimensional protein electrophoresis were used. A large number of genes whose mRNA levels are modulated during differentiation of MPRO cells were identified. The results suggest the involvement of several transcription regulatory factors not previously implicated in this process, but they also emphasize the importance of events other than the production of new transcription factors. Furthermore, gene expression patterns were compared at the level of mRNA and protein, and the correlation between 2 parameters was studied. (Blood. 2001;98:513-524)

Standard name | ZHAN_MULTIPLE_MYELOMA_MS_UP
Systematic name | M19632
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 up-regulated genes in cluster MS of multiple myeloma samples with characteristic expression spike of WHSC1 [GeneID=7468].
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | MA_MYELOID_DIFFERENTIATION_UP
Systematic name | M1479
Organism | Mus musculus
PMID | 12130493
Authors | Ma X,Husain T,Peng H,Lin S,Mironenko O,Maun N,Johnson S,Tuck D,Berliner N,Krause DS,Perkins AS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during myeloid differentiation induced by tretinoin (ATRA) [PubChem=444795] and IL3 [GeneID=3652] in the EML cell line (myeloid progenitor).
Full description | With the goal of creating a resource for in-depth study of myelopoiesis, we have executed a 2-pronged strategy to obtain a complementary DNA (cDNA) clone set enriched in hematopoietic genes. One aspect is a library subtraction to enrich for underrepresented transcripts present at early stages of hematopoiesis. For this, a hematopoietic cDNA library from primary murine bone marrow cells enriched for primitive progenitors was used as tester. The subtraction used 10 000 known genes and expressed sequence tags (ESTs) as driver. The 2304 randomly picked clones from the subtracted cDNA libraries represent 1255 distinct genes, of which 622 (50%) are named genes, 386 (30%) match uncharacterized ESTs, and 247 (20%) are novel. The second aspect of our strategy was to complement this subtracted library with genes known to be involved in myeloid cell differentiation and function. The resulting cDNAs were arrayed on polylysine-coated glass slides. The microarrays were used to analyze gene expression in primary and cultured murine bone marrow-derived progenitors. We found expression of various types of genes, including regulatory cytokines and their receptors, signal transduction genes, and transcription factors. To assess gene expression during myeloid differentiation, we examined patterns of change during induced differentiation of EML cells. Several hundred of the genes underwent fluctuations in expression level during myeloid cell differentiation. The complete database, accessible on the World Wide Web at http://yale130132115135.med.yale.edu/, allows for retrieval of information regarding these genes. Our microarray allows for genomewide expression analysis of myeloid stem cells, which will help in defining the regulatory mechanisms of stem cell differentiation.

Standard name | RADMACHER_AML_PROGNOSIS
Systematic name | M7815
Organism | Homo sapiens
PMID | 16670265
Authors | Radmacher MD,Marcucci G,Ruppert AS,Mrózek K,Whitman SP,Vardiman JW,Paschka P,Vukosavljevic T,Baldus CD,Kolitz JE,Caligiuri MA,Larson RA,Bloomfield CD,LastName M
Category | C2
Sub-category | CGP
Brief description | The 'Bullinger validation signature' [PMID=15084693] used to validate prediction of prognostic outcome of acute myeloid leukemia (AML) patients with a normal karyotype.
Full description | Patients with acute myeloid leukemia (AML) and normal karyotype are classified in an intermediate-risk group, albeit this subset is heterogeneous for clinical outcome. A recent complementary DNA microarray study identified a gene-expression signature that--when used to cluster normal karyotype patients--separated them into 2 prognostically relevant subgroups. We sought the first independent validation of the prognostic value of this signature. Using oligonucleotide microarrays to measure gene expression in samples from uniformly treated adults with karyotypically normal AML, we performed cluster analysis based on the previously identified signature. We also developed a well-defined classification rule using the signature to predict outcome for individual patients. Cluster analysis confirmed the prognostic utility of the signature: patient clusters differed in overall (P = .001) and disease-free (P = .001) survival. The signature-based classifier identified groups with differences in overall (P = .02) and disease-free (P = .05) survival. A strong association of the outcome classifier with the prognostically adverse FLT3 internal tandem duplication (FLT3 ITD) potentially explained the prognostic significance of the signature. However, in the subgroup of patients without FLT3 ITD there was a moderate difference in survival for the classifier-derived groups. Our analysis confirms the applicability of the gene-expression profiling strategy for outcome prediction in cytogenetically normal AML.

Standard name | CROMER_METASTASIS_DN
Systematic name | M8417
Organism | Homo sapiens
PMID | 14676830
Authors | Cromer A,Carles A,Millon R,Ganguli G,Chalmel F,Lemaire F,Young J,Dembélé D,Thibault C,Muller D,Poch O,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Metastatic propensity markers of head and neck squamous cell carcinoma (HNSCC): down-regulated in metastatic vs non-metastatic tumors.
Full description | Head and neck squamous cell carcinoma (HNSCC) is the sixth most common cancer among men in the developed world. There is a need, for both clinical and scientific reasons, to find markers to identify patients with aggressive disease as early as possible, and to understand the events leading to malignant transformation and susceptibility to metastasis. We report the first large-scale gene expression analysis of a unique HNSCC location, the hypopharynx. Four normal and 34 tumour samples were analysed with 12 600 gene microarrays. Clusters of differentially expressed genes were identified in the chromosomal regions 3q27.3, 17q21.2-q21.31, 7q11.22-q22.1 and 11q13.1-q13.3, which, interestingly, have already been identified by comparative genomic hybridization (CGH) as major regions of gene amplification. We showed that six overexpressed genes (EIF4G1, DVL3, EPHB4, MCM7, BRMS1 and SART1) located in these regions are indeed amplified. We report 119 genes that are highly differentially expressed between 'early' tumours and normal samples. Of these, we validated by quantitative PCR six novel poorly characterized genes. These genes are potential new markers of HNSCC. Comparing patients with relatively nonaggressive and aggressive tumours (without or with clinical evidence of metastasis 3 years after surgery), we identified 164 differentially expressed genes potentially involved in the acquisition of metastatic potential. This study contributes to the understanding of HNSCC, staging patients into prognostic groups and identifying high-risk patients who may benefit from more aggressive treatment.

Standard name | NOUZOVA_METHYLATED_IN_APL
Systematic name | M16097
Organism | Homo sapiens
PMID | 15302897
Authors | Nouzova M,Holtan N,Oshiro MM,Isett RB,Munoz-Rodriguez JL,List AF,Narro ML,Miller SJ,Merchant NC,Futscher BW
Category | C2
Sub-category | CGP
Brief description | Genes whose CpG islands are hyper-methylated in the NB4 cell line (APL, acute promyelocytic leukemia) compared to PBMC (normal peripheral peripheral blood mononuclear cells).
Full description | Dysregulation of epigenetic control is an important participant in carcinogenesis. The PML/RAR alpha translocation in acute promyelocytic leukemia (APL) is an example where the resultant fusion protein recruits histone deacetylase complexes to target genes resulting in their inappropriate transcriptional repression. All-trans-retinoic acid (ATRA) acts as a ligand that relieves this repression and produces an epigenetic transcriptional reprogramming of the cancer cell. CpG island microarrays were used to analyze the DNA methylation and histone acetylation state of the human APL cell line NB4 before and after differentiation with ATRA as well as normal peripheral blood mononuclear cells (PBMC). Over 70 CpG islands within 1 kb of transcription start of a known gene are aberrantly methylated in NB4 cells compared with PBMC; however, no changes in cytosine methylation were detected following ATRA-induced differentiation. With respect to histone H4 acetylation, over 100 single-copy CpG islands within 1 kb of transcription start of a known human gene became hyperacetylated following ATRA-induced differentiation. One CpG island was aberrantly methylated in NB4 cells, but became hyperacetylated and was induced following ATRA treatment and was associated with the HoxA1 gene, suggesting it may be a target gene of ATRA in APL. In addition to single-copy sequences, a selective increase in acetylation was detected in satellite DNA when compared with other high-copy sequences, such as Alu or rDNA. In summary, ATRA stimulates complex epigenomic changes during leukemic cell differentiation, and monitoring these changes may help to identify new targets of epigenetic dysfunction.

Standard name | ZHAN_MULTIPLE_MYELOMA_HP_UP
Systematic name | M13746
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 up-regulated genes in cluster HP of multiple myeloma samples characterized by a hyperploid signature.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | XU_RESPONSE_TO_TRETINOIN_DN
Systematic name | M12964
Organism | Homo sapiens
PMID | 16140955
Authors | Xu K,Guidez F,Glasow A,Chung D,Petrie K,Stegmaier K,Wang KK,Zhang J,Jing Y,Zelent A,Waxman S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NB4 cells (acute promyelocytic leukemia, APL) by tretinoin [PubChem=444795] alone.
Full description | Differentiation induction is an effective therapy for acute promyelocytic leukemia (APL), which dramatically responds to all-trans-retinoic acid (ATRA). Recent studies have indicated that combinatorial use of retinoid and nonretinoid compounds, such as histone deacetylase inhibitors, arsenics, and PKA agonists, has higher therapeutic value in this disease and potentially in other malignancies. In a screen of 370 compounds, we identified benzodithiophene analogues as potent enhancers of ATRA-induced APL cell differentiation. These effects were not associated with changes in global histone acetylation and, for the most potent compounds, were exerted at very low nanomolar concentrations, and were paralleled by enhancement of some, but not all, ATRA-modulated gene expressions. Investigating the mechanism underlying the effects of these drugs on ATRA-induced APL cell differentiation, we have shown that benzodithiophenes enhance ATRA-mediated dissociation and association of corepressor N-CoR and coactivator p300 acetyltransferase, respectively, with retinoic acid receptor (RAR) alpha proteins. These data suggest that benzodithiophenes act at the level of receptor activation, possibly by affecting posttranslational modification of the receptor (and/or coregulators), thus leading to an enhancement in ATRA-mediated effects on gene expression and APL cell differentiation. Given the specificities of these low benzodithiophene concentrations for PML-RARalpha and RARalpha, these drugs may be useful for combinatorial differentiation therapy of APL and possibly other acute myelogenous leukemia subtypes in which the overall ATRA signaling is suppressed.

Standard name | TAVOR_CEBPA_TARGETS_UP
Systematic name | M9709
Organism | Homo sapiens
PMID | 14517214
Authors | Tavor S,Park DJ,Gery S,Vuong PT,Gombart AF,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in KCL22 cells (chronic myelogenous leukemia, CML, with BCR-ABL1 [GeneID=613;25] fusion) by expression of CEBPA [GeneID=1050].
Full description | The transcription factor C/EBPalpha plays a critical role in the process of granulocytic differentiation. Recently, mutations that abrogated transcriptional activation of C/EBPalpha were detected in acute myeloid leukemia patient samples. Moreover, the progression of chronic myelogenous leukemia (CML) to blast crisis in patients was correlated with down-modulation of C/EBPalpha. The KCL22 cell line, derived from BCR-ABL+ CML in blast crisis, expressed wild-type C/EBPepsilon protein but not a functional C/EBPalpha, -beta, and -gamma. Restoration of C/EBPalpha expression in KCL22 cells triggered a profound proliferative arrest, a block in the G2/M phase of the cell cycle and a gradual increase in apoptosis. Within 3 days of inducing expression of C/EBPalpha, a remarkable neutrophilic differentiation of the KCL22 blast cells occurred as shown by morphologic changes, induction of expression of CD11b, primary, secondary, and tertiary granule proteins, and granulocyte colony-stimulating factor receptor. Using high density oligonucleotide microarrays, the gene expression profile of KCL22 cells stably transfected with C/EBPalpha was compared with that of empty vector, and we identified genes not previously known to be regulated by C/EBPalpha. These included the up-regulation of those genes important for regulation of hematopoietic stem cell homing, granulocytic differentiation, and cell cycle, whereas down-regulation occurred for genes coding for signaling molecules and transcription factors that are implicated in regulation of proliferation and differentiation of hematopoietic cells. Our study showed that restoration of C/EBPalpha expression in BCR-ABL+ leukemic cells in blast crisis is sufficient for rapid neutrophil differentiation suggesting a potential therapeutic role for ectopic transfer of C/EBPalpha in acute phase of CML.

Standard name | YAGI_AML_SURVIVAL
Systematic name | M18887
Organism | Homo sapiens
PMID | 12738660
Authors | Yagi T,Morimoto A,Eguchi M,Hibi S,Sako M,Ishii E,Mizutani S,Imashuku S,Ohki M,Ichikawa H
Category | C2
Sub-category | CGP
Brief description | Genes differentially expressed in pediatric AML (acute myeloid leukemia) samples from patients with good survival (>3 years without relapse) compared to those with poor survival (relapsed within one year after treatment).
Full description | Most patients with acute myeloid leukemia (AML) enter complete remission (CR) after treatment with chemotherapy, but a large number of them experience relapse with resistant disease. To identify genes that are associated with their prognoses, we analyzed gene expression in 54 pediatric patients with AML using an oligonucleotide microarray that contained 12 566 probe sets. A supervised approach using the Student t test selected a prognostic set of 35 genes, some of which are associated with the regulation of cell cycle and apoptosis. Most of these genes had not previously been reported to be associated with prognosis and were not correlated with morphologically classified French-American-British (FAB) subtypes or with karyotypes. These results indicate the existence of prognosis-associated genes that are independent of cell lineage and cytogenetic abnormalities, and they can provide therapeutic direction for individual risk-adapted therapy for pediatric AML patients.

Standard name | XU_CREBBP_TARGETS_UP
Systematic name | M17669
Organism | Mus musculus
PMID | 16424387
Authors | Xu W,Fukuyama T,Ney PA,Wang D,Rehg J,Boyd K,van Deursen JM,Brindle PK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pro-B lymphocytes after knockout of CREBBP [GeneID=1387].
Full description | CREB-binding protein (CBP) and its para-log p300 are transcriptional coactivators that physically or functionally interact with over 320 mammalian and viral proteins, including 36 that are essential for B cells in mice. CBP and p300 are generally considered limiting for transcription, yet their roles in adult cell lineages are largely unknown since homozygous null mutations in either gene or compound heterozygosity cause early embryonic lethality in mice. We tested the hypotheses that CBP and p300 are limiting and that each has unique properties in B cells, by using mice with Cre/LoxP conditional knockout alleles for CBP (CBP(flox)) and p300 (p300(flox)), which carry CD19(Cre) that initiates floxed gene recombination at the pro-B-cell stage. CD19(Cre)-mediated loss of CBP or p300 led to surprisingly modest deficits in B-cell numbers, whereas inactivation of both genes was not tolerated by peripheral B cells. There was a moderate decrease in B-cell receptor (BCR)-responsive gene expression in CBP or p300 homozygous null B cells, suggesting that CBP and p300 are essential for this signaling pathway that is crucial for B-cell homeostasis. These results indicate that individually CBP and p300 are partially limiting beyond the pro-B-cell stage and that other coactivators in B cells cannot replace their combined loss.

Standard name | VERHAAK_AML_WITH_NPM1_MUTATED_DN
Systematic name | M10117
Organism | Homo sapiens
PMID | 16109776
Authors | Verhaak RG,Goudswaard CS,Putten van W,Bijl MA,Sanders MA,Hugens W,Uitterlinden AG,Erpelinck CA,Delwel R,Löwenberg B,Valk PJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in acute myeloid leukemia (AML) patients with mutated NPM1 [GeneID=4869].
Full description | Mutations in nucleophosmin NPM1 are the most frequent acquired molecular abnormalities in acute myeloid leukemia (AML). We determined the NPM1 mutation status in a clinically and molecularly well-characterized patient cohort of 275 patients with newly diagnosed AML by denaturing high-performance liquid chromatography (dHPLC). We show that NPM1 mutations are significantly underrepresented in patients younger than 35 years. NPM1 mutations positively correlate with AML with high white blood cell counts, normal karyotypes, and fms-like tyrosine kinase-3 gene (FLT3) internal tandem duplication (ITD) mutations. NPM1 mutations associate inversely with the occurrence of CCAAT/enhancer-binding protein-alpha (CEBPA) and NRAS mutations. With respect to gene expression profiling, we show that AML cases with an NPM1 mutation cluster in specific subtypes of AML with previously established gene expression signatures, are highly associated with a homeobox gene-specific expression signature, and can be predicted with high accuracy. We demonstrate that patients with intermediate cytogenetic risk AML without FLT3 ITD mutations but with NPM1 mutations have a significantly better overall survival (OS) and event-free survival (EFS) than those without NPM1 mutations. Finally, in multivariable analysis NPM1 mutations express independent favorable prognostic value with regard to OS, EFS, and disease-free survival (DFS).

Standard name | RORIE_TARGETS_OF_EWSR1_FLI1_FUSION_DN
Systematic name | M15762
Organism | Homo sapiens
PMID | 14973077
Authors | Rorie CJ,Thomas VD,Chen P,Pierce HH,O'Bryan JP,Weissman BE
Category | C2
Sub-category | CGP
Brief description | Neuroblastoma markers down-regulated in neuroblastoma cell lines expressing ESWR1-FLI1 [GeneID=2130;2313] fusion protein.
Full description | Neuroblastoma (NB) and the Ewing sarcoma (ES)/peripheral primitive neuroectodermal tumor (PNET) family are pediatric cancers derived from neural crest cells. Although NBs display features of the sympathetic nervous system, ES/PNETs express markers consistent with parasympathetic differentiation. To examine the control of these differentiation markers, we generated NB x ES/PNET somatic cell hybrids. NB-specific markers were suppressed in the hybrids, whereas ES/PNET-specific markers were unaffected. These results suggested that the Ews/Fli-1 fusion gene, resulting from a translocation unique to ES/PNETs, might account for the loss of NB-specific markers. To test this hypothesis, we generated two different NB cell lines that stably expressed the Ews/Fli-1 gene. We observed that heterologous expression of the Ews/Fli-1 protein led to the suppression of NB-specific markers and de novo expression of ES/PNET markers. To determine the extent of changes in differentiation, we used the Affymetrix GeneChip Array system to observe global transcriptional changes of genes. This analysis revealed that the gene expression pattern of the Ews/Fli-1-expressing NB cells resembled that observed in pooled ES/PNET cell lines and differed significantly from the NB parental cells. Therefore, we propose that Ews/Fli-1 contributes to the etiology of ES/PNET by subverting the differentiation program of its neural crest precursor cell to a less differentiated and more proliferative state.

Standard name | APPEL_IMATINIB_RESPONSE
Systematic name | M5319
Organism | Homo sapiens
PMID | 15756019
Authors | Appel S,Rupf A,Weck MM,Schoor O,Brümmendorf TH,Weinschenk T,Grünebach F,Brossart P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by imatinib [PubChem=5291] during dendritic cell differentiation.
Full description | Dendritic cells are the most powerful antigen-presenting cells playing a decisive role for the initiation and maintenance of primary immune responses. However, signaling pathways involved in the differentiation of these cells have not been fully determined. Imatinib is a novel tyrosine kinase inhibitor effective against Abl kinases, c-Kit, and platelet-derived growth factor receptor. Using this compound, we show that human monocyte-derived dendritic cells generated in the presence of therapeutic concentrations of imatinib show a reduced expression of CD1a, MHC class I and II, and costimulatory molecules as well as decreased secretion of chemokines and cytokines resulting in an impaired capacity of dendritic cells to elicit primary T-cell responses. Using Western blot analyses, we found that these effects are mediated by inhibition of phosphatidylinositol 3-kinase/Akt pathways and a pronounced down-regulation of nuclear localized protein levels of nuclear factor-kappaB family members. Importantly, using blocking antibodies and tyrosine kinase inhibitors, we show that the inhibitory effects of imatinib on dendritic cell differentiation are not mediated via platelet-derived growth factor receptor and c-Kit. Taken together, our study reveals that imatinib inhibits dendritic cell differentiation and function via Akt and nuclear factor-kappaB signal transduction. Importantly, we show that imatinib can inhibit the function of normal, nonmalignant cells that may result in immunosuppression of these patients.

Standard name | YAGI_AML_FAB_MARKERS
Systematic name | M5103
Organism | Homo sapiens
PMID | 12738660
Authors | Yagi T,Morimoto A,Eguchi M,Hibi S,Sako M,Ishii E,Mizutani S,Imashuku S,Ohki M,Ichikawa H
Category | C2
Sub-category | CGP
Brief description | Genes specifically expressed in FAB subtypes M2, M4, M5 and M7 of pediatric AML (acute myeloid leukemia).
Full description | Most patients with acute myeloid leukemia (AML) enter complete remission (CR) after treatment with chemotherapy, but a large number of them experience relapse with resistant disease. To identify genes that are associated with their prognoses, we analyzed gene expression in 54 pediatric patients with AML using an oligonucleotide microarray that contained 12 566 probe sets. A supervised approach using the Student t test selected a prognostic set of 35 genes, some of which are associated with the regulation of cell cycle and apoptosis. Most of these genes had not previously been reported to be associated with prognosis and were not correlated with morphologically classified French-American-British (FAB) subtypes or with karyotypes. These results indicate the existence of prognosis-associated genes that are independent of cell lineage and cytogenetic abnormalities, and they can provide therapeutic direction for individual risk-adapted therapy for pediatric AML patients.

Standard name | ZHAN_MULTIPLE_MYELOMA_CD1_VS_CD2_DN
Systematic name | M7602
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD-1 compared to CD-2 cluster of multiple myeloma samples.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | MOREAUX_MULTIPLE_MYELOMA_BY_TACI_DN
Systematic name | M17193
Organism | Homo sapiens
PMID | 15827134
Authors | Moreaux J,Cremer FW,Reme T,Raab M,Mahtouk K,Kaukel P,Pantesco V,De Vos J,Jourdan E,Jauch A,Legouffe E,Moos M,Fiol G,Goldschmidt H,Rossi JF,Hose D,Klein B
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes distinguishing in multiple myeloma (MM) samples with lower expression of TACI [GeneID=23495].
Full description | B-cell activating factor (BAFF) and a proliferation-inducing ligand (APRIL) have been shown to promote multiple myeloma (MM) cell growth. We show that the main site of production for BAFF and APRIL is the bone marrow (BM) environment, and that production is mainly by monocytes and neutrophils. In addition, osteoclasts produce very high levels of APRIL, unlike BM stromal cells. Myeloma cells (MMCs) express TACI (transmembrane activator and calcium modulator and cyclophilin ligand interactor), the receptor of BAFF/APRIL, at varying levels. TACI expression is a good indicator of a BAFF-binding receptor. Expression data of purified MMCs from 65 newly diagnosed patients have been generated using Affymetrix microarrays and were analyzed by supervised clustering of groups with higher (TACI(hi)) versus lower (TACI(lo)) TACI expression levels. Patients in the TACI(lo) group had clinical parameters associated with bad prognosis. A set of 659 genes was differentially expressed between TACI(hi) and TACI(lo) MMCs. This set makes it possible to efficiently classify TACI(hi) and TACI(lo) MMCs in an independent cohort of 40 patients. TACI(hi) MMCs displayed a mature plasma cell gene signature, indicating dependence on the BM environment. In contrast, the TACI(lo) group had a gene signature of plasmablasts, suggesting an attenuated dependence on the BM environment. Taken together, our findings suggest using gene expression profiling to identify the group of patients who might benefit most from treatment with BAFF/APRIL inhibitors.

Standard name | ABBUD_LIF_SIGNALING_2_DN
Systematic name | M1481
Organism | Rattus norvegicus
PMID | 14576184
Authors | Abbud RA,Kelleher R,Melmed S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in GH3 cells (pituitary cancer) after treatment with LIF [GeneID=3976].
Full description | Leukemia inhibitory factor (LIF) mediates the hypothalamo-pituitary-adrenal stress response. Transgenic mice overexpressing LIF in the developing pituitary have altered pituitary differentiation with expansion of corticotropes, maintenance of Rathke's cleft cysts, and suppression of all other pituitary cell types. Affymetrix GeneChips were used to identify modulators of LIF effects in corticotrope (AtT-20) and somatolactotrope (GH(3)) cells. In addition to genes known to respond to LIF in corticotrope cells [e.g. suppressor of cytokine signaling-3 (SOCS-3), signal transducer and activator of transcription-3, SH2 domain-containing tyrosine phosphatase-1, and proopiomelanocortin (POMC)], corticotrope-specific changes were also observed for genes involved in glycolysis and gluconeogenesis, transcription factors, signaling molecules, and expressed sequence tags. Two transcription factors identified, CCAAT/enhancer-binding protein beta (C/EBPbeta) and glial cell-derived neurotrophic factor (GDNF)-inducible factor (GIF), dose-dependently induced expression of the rat POMC promoter when overexpressed in AtT-20 cells. LIF further induced POMC transcription with C/EBPbeta, but not with GIF. C/EBPbeta also induced expression of the SOCS-3 promoter that was further enhanced by cotreatment with LIF. However, GIF did not affect SOCS-3 expression. These results indicate that C/EBPbeta and GIF are downstream effectors of LIF corticotrope action. LIF also stimulates the expression of inhibitors of its actions, such as SOCS-3 and SH2 domain-containing tyrosine phosphatase-1. alpha(2)-HS-glycoprotein (AHSG)/fetuin, a secreted protein that antagonizes bone TGFbeta/bone morphogenic protein signaling, was induced by LIF in a signal transducer and activator of transcription-3-dependent fashion. Pretreatment with AHSG/fetuin blocked LIF-induced expression of the POMC promoter independently of SOCS-3. Thus, using GeneChips, C/EBPbeta and GIF have been identified as novel mediators and AHSG/fetuin as an inhibitor of LIF action in corticotropes.

Standard name | XU_CREBBP_TARGETS_DN
Systematic name | M4357
Organism | Mus musculus
PMID | 16424387
Authors | Xu W,Fukuyama T,Ney PA,Wang D,Rehg J,Boyd K,van Deursen JM,Brindle PK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pro-B lymphocytes after knockout of CREBBP [GeneID=1387].
Full description | CREB-binding protein (CBP) and its para-log p300 are transcriptional coactivators that physically or functionally interact with over 320 mammalian and viral proteins, including 36 that are essential for B cells in mice. CBP and p300 are generally considered limiting for transcription, yet their roles in adult cell lineages are largely unknown since homozygous null mutations in either gene or compound heterozygosity cause early embryonic lethality in mice. We tested the hypotheses that CBP and p300 are limiting and that each has unique properties in B cells, by using mice with Cre/LoxP conditional knockout alleles for CBP (CBP(flox)) and p300 (p300(flox)), which carry CD19(Cre) that initiates floxed gene recombination at the pro-B-cell stage. CD19(Cre)-mediated loss of CBP or p300 led to surprisingly modest deficits in B-cell numbers, whereas inactivation of both genes was not tolerated by peripheral B cells. There was a moderate decrease in B-cell receptor (BCR)-responsive gene expression in CBP or p300 homozygous null B cells, suggesting that CBP and p300 are essential for this signaling pathway that is crucial for B-cell homeostasis. These results indicate that individually CBP and p300 are partially limiting beyond the pro-B-cell stage and that other coactivators in B cells cannot replace their combined loss.

Standard name | IGLESIAS_E2F_TARGETS_DN
Systematic name | M1482
Organism | Mus musculus
PMID | 15146237
Authors | Iglesias A,Murga M,Laresgoiti U,Skoudy A,Bernales I,Fullaondo A,Moreno B,Lloreta J,Field SJ,Real FX,Zubiaga AM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pancreatic cells from mice with double knockout of E2F1 [GeneID=1869] and E2F2 [GeneID=1870] compared to wild type.
Full description | E2F transcription factors are thought to be key regulators of cell growth control. Here we use mutant mouse strains to investigate the function of E2F1 and E2F2 in vivo. E2F1/E2F2 compound-mutant mice develop nonautoimmune insulin-deficient diabetes and exocrine pancreatic dysfunction characterized by endocrine and exocrine cell dysplasia, a reduction in the number and size of acini and islets, and their replacement by ductal structures and adipose tissue. Mutant pancreatic cells exhibit increased rates of DNA replication but also of apoptosis, resulting in severe pancreatic atrophy. The expression of genes involved in DNA replication and cell cycle control was upregulated in the E2F1/E2F2 compound-mutant pancreas, suggesting that their expression is repressed by E2F1/E2F2 activities and that the inappropriate cell cycle found in the mutant pancreas is likely the result of the deregulated expression of these genes. Interestingly, the expression of ductal cell and adipocyte differentiation marker genes was also upregulated, whereas expression of pancreatic cell marker genes were downregulated. These results suggest that E2F1/E2F2 activity negatively controls growth of mature pancreatic cells and is necessary for the maintenance of differentiated pancreatic phenotypes in the adult.

Standard name | HOEGERKORP_CD44_TARGETS_TEMPORAL_UP
Systematic name | M8139
Organism | Homo sapiens
PMID | 12411303
Authors | Högerkorp CM,Bilke S,Breslin T,Ingvarsson S,Borrebaeck CA
Category | C2
Sub-category | CGP
Brief description | Genes temporally up-regulated by CD44 [GeneID=960] stimulation of B lymphocytes.
Full description | A number of studies have implicated a role for the cell surface glycoprotein CD44 in several biologic events, such as lymphopoiesis, homing, lymphocyte activation, and apoptosis. We have earlier reported that signaling via CD44 on naive B cells in addition to B-cell receptor (BCR) and CD40 engagement generated a germinal center-like phenotype. To further characterize the global role of CD44 in B differentiation, we examined the expression profile of human B cells cultured in vitro in the presence or absence of CD44 ligation, together with anti-immunoglobulin (anti-Ig) and anti-CD40 antibodies. The data sets derived from DNA microarrays were analyzed using a novel statistical analysis scheme created to retrieve the most likely expression pattern of CD44 ligation. Our results show that genes such as interleukin-6 (IL-6), IL-1alpha, and beta(2)-adrenergic receptor (beta(2)-AR) were specifically up-regulated by CD44 ligation, suggesting a novel role for CD44 in immunoregulation and inflammation.

Standard name | HOEGERKORP_CD44_TARGETS_TEMPORAL_DN
Systematic name | M11025
Organism | Homo sapiens
PMID | 12411303
Authors | Högerkorp CM,Bilke S,Breslin T,Ingvarsson S,Borrebaeck CA
Category | C2
Sub-category | CGP
Brief description | Genes temporally down-regulated by CD44 [GeneID=960] stimulation of B lymphocytes.
Full description | A number of studies have implicated a role for the cell surface glycoprotein CD44 in several biologic events, such as lymphopoiesis, homing, lymphocyte activation, and apoptosis. We have earlier reported that signaling via CD44 on naive B cells in addition to B-cell receptor (BCR) and CD40 engagement generated a germinal center-like phenotype. To further characterize the global role of CD44 in B differentiation, we examined the expression profile of human B cells cultured in vitro in the presence or absence of CD44 ligation, together with anti-immunoglobulin (anti-Ig) and anti-CD40 antibodies. The data sets derived from DNA microarrays were analyzed using a novel statistical analysis scheme created to retrieve the most likely expression pattern of CD44 ligation. Our results show that genes such as interleukin-6 (IL-6), IL-1alpha, and beta(2)-adrenergic receptor (beta(2)-AR) were specifically up-regulated by CD44 ligation, suggesting a novel role for CD44 in immunoregulation and inflammation.

Standard name | IGLESIAS_E2F_TARGETS_UP
Systematic name | M1484
Organism | Mus musculus
PMID | 15146237
Authors | Iglesias A,Murga M,Laresgoiti U,Skoudy A,Bernales I,Fullaondo A,Moreno B,Lloreta J,Field SJ,Real FX,Zubiaga AM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pancreatic cells from mice with double knockout of E2F1 [GeneID=1869] and E2F2 [GeneID=1870] compared to wild type.
Full description | E2F transcription factors are thought to be key regulators of cell growth control. Here we use mutant mouse strains to investigate the function of E2F1 and E2F2 in vivo. E2F1/E2F2 compound-mutant mice develop nonautoimmune insulin-deficient diabetes and exocrine pancreatic dysfunction characterized by endocrine and exocrine cell dysplasia, a reduction in the number and size of acini and islets, and their replacement by ductal structures and adipose tissue. Mutant pancreatic cells exhibit increased rates of DNA replication but also of apoptosis, resulting in severe pancreatic atrophy. The expression of genes involved in DNA replication and cell cycle control was upregulated in the E2F1/E2F2 compound-mutant pancreas, suggesting that their expression is repressed by E2F1/E2F2 activities and that the inappropriate cell cycle found in the mutant pancreas is likely the result of the deregulated expression of these genes. Interestingly, the expression of ductal cell and adipocyte differentiation marker genes was also upregulated, whereas expression of pancreatic cell marker genes were downregulated. These results suggest that E2F1/E2F2 activity negatively controls growth of mature pancreatic cells and is necessary for the maintenance of differentiated pancreatic phenotypes in the adult.

Standard name | MUNSHI_MULTIPLE_MYELOMA_UP
Systematic name | M4517
Organism | Homo sapiens
PMID | 12969976
Authors | Munshi NC,Hideshima T,Carrasco D,Shammas M,Auclair D,Davies F,Mitsiades N,Mitsiades C,Kim RS,Li C,Rajkumar SV,Fonseca R,Bergsagel L,Chauhan D,Anderson KC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in multiple myeloma (MM) compared to normal plasma cells from the patient's identical twin.
Full description | Genetic heterogeneity between individuals confounds the comparison of gene profiling of multiple myeloma (MM) cells versus normal plasma cells (PCs). To overcome this barrier, we compared the gene expression profile of CD138+ MM cells from a patient bone marrow (BM) sample with CD138+ PCs from a genetically identical twin BM sample using microarray profiling. Two hundred and ninety-six genes were up-regulated and 103 genes were down-regulated at least 2-fold in MM cells versus normal twin PCs. Highly expressed genes in MM cells included cell survival pathway genes such as mcl-1, dad-1, caspase 8, and FADD-like apoptosis regulator (FLIP); oncogenes/transcriptional factors such as Jun-D, Xbp-1, calmodulin, Calnexin, and FGFR-3; stress response and ubiquitin/proteasome pathway-related genes and various ribosomal genes reflecting increased metabolic and translational activity. Genes that were down-regulated in MM cells versus healthy twin PCs included RAD51, killer cell immunoglobulin-like receptor protein, and apoptotic protease activating factor. Microarray results were further confirmed by Western blot analyses, immunohistochemistry, fluorescent in situ hybridization (FISH), and functional assays of telomerase activity and bone marrow angiogenesis. This molecular profiling provides potential insights into mechanisms of malignant transformation in MM. For example, FGFR3, xbp-1, and both mcl-1 and dad-1 may mediate transformation, differentiation, and survival, respectively, and may have clinical implications. By identifying genes uniquely altered in MM cells compared with normal PCs in an identical genotypic background, the current study provides the framework to identify novel therapeutic targets.

Standard name | KAMMINGA_EZH2_TARGETS
Systematic name | M1486
Organism | Mus musculus
PMID | 16293602
Authors | Kamminga LM,Bystrykh LV,de Boer A,Houwer S,Douma J,Weersing E,Dontje B,de Haan G
Category | C2
Sub-category | CGP
Brief description | Putative targets or partners of EZH2 [GeneID=2146] in hematopoietic stem cells.
Full description | The molecular mechanism responsible for a decline of stem cell functioning after replicative stress remains unknown. We used mouse embryonic fibroblasts (MEFs) and hematopoietic stem cells (HSCs) to identify genes involved in the process of cellular aging. In proliferating and senescent MEFs one of the most differentially expressed transcripts was Enhancer of zeste homolog 2 (Ezh2), a Polycomb group protein (PcG) involved in histone methylation and deacetylation. Retroviral overexpression of Ezh2 in MEFs resulted in bypassing of the senescence program. More importantly, whereas normal HSCs were rapidly exhausted after serial transplantations, overexpression of Ezh2 completely conserved long-term repopulating potential. Animals that were reconstituted with 3 times serially transplanted control bone marrow cells all died due to hematopoietic failure. In contrast, similarly transplanted Ezh2-overexpressing stem cells restored stem cell quality to normal levels. In a genetic genomics screen, we identified novel putative Ezh2 target or partner stem cell genes that are associated with chromatin modification. Our data suggest that stabilization of the chromatin structure preserves HSC potential after replicative stress.

Standard name | ZHAN_MULTIPLE_MYELOMA_DN
Systematic name | M2523
Organism | Homo sapiens
PMID | 11861292
Authors | Zhan F,Hardin J,Kordsmeier B,Bumm K,Zheng M,Tian E,Sanderson R,Yang Y,Wilson C,Zangari M,Anaissie E,Morris C,Muwalla F,van Rhee F,Fassas A,Crowley J,Tricot G,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | Genes most significantly down-regulated in multiple myeloma samples, compared to normal bone marrow plasma cells.
Full description | Bone marrow plasma cells (PCs) from 74 patients with newly diagnosed multiple myeloma (MM), 5 with monoclonal gammopathy of undetermined significance (MGUS), and 31 healthy volunteers (normal PCs) were purified by CD138(+) selection. Gene expression of purified PCs and 7 MM cell lines were profiled using high-density oligonucleotide microarrays interrogating about 6800 genes. On hierarchical clustering analysis, normal and MM PCs were differentiated and 4 distinct subgroups of MM (MM1, MM2, MM3, and MM4) were identified. The expression pattern of MM1 was similar to normal PCs and MGUS, whereas MM4 was similar to MM cell lines. Clinical parameters linked to poor prognosis, abnormal karyotype (P =.002) and high serum beta(2)-microglobulin levels (P =.0005), were most prevalent in MM4. Also, genes involved in DNA metabolism and cell cycle control were overexpressed in a comparison of MM1 and MM4. In addition, using chi(2) and Wilcoxon rank sum tests, 120 novel candidate disease genes were identified that discriminate normal and malignant PCs (P <.0001); many are involved in adhesion, apoptosis, cell cycle, drug resistance, growth arrest, oncogenesis, signaling, and transcription. A total of 156 genes, including FGFR3 and CCND1, exhibited highly elevated (spiked) expression in at least 4 of the 74 MM cases (range, 4-25 spikes). Elevated expression of these 2 genes was caused by the translocation t(4;14)(p16;q32) or t(11;14)(q13;q32). Thus, novel candidate MM disease genes have been identified using gene expression profiling and this profiling has led to the development of a gene-based classification system for MM.

Standard name | BASSO_CD40_SIGNALING_UP
Systematic name | M8493
Organism | Homo sapiens
PMID | 15331443
Authors | Basso K,Klein U,Niu H,Stolovitzky GA,Tu Y,Califano A,Cattoretti G,Dalla-Favera R
Category | C2
Sub-category | CGP
Brief description | Gene up-regulated by CD40 [GeneID=958] signaling in Ramos cells (EBV negative Burkitt lymphoma).
Full description | Substantial evidence indicates that signaling through the CD40 receptor (CD40) is required for germinal center (GC) and memory B-cell formation. However, it is not fully understood at which stages of B-cell development the CD40 pathway is activated in vivo. To address this question, we induced CD40 signaling in human transformed GC B cells in vitro and identified a CD40 gene expression signature by DNA microarray analysis. This signature was then investigated in the gene expression profiles of normal B cells and found in pre- and post-GC B cells (naive and memory) but, surprisingly, not in GC B cells. This finding was validated in lymphoid tissues by showing that the nuclear factor-kappaB (NF-kappaB) transcription factors, which translocate to the nucleus upon CD40 stimulation, are retained in the cytoplasm in most GC B cells, indicating the absence of CD40 signaling. Nevertheless, a subset of centrocytes and B cells in the subepithelium showed nuclear staining of multiple NF-kappaB subunits, suggesting that a fraction of naive and memory B cells may be subject to CD40 signaling or to other signals that activate NF-kappaB. Together, these results show that GC expansion occurs in the absence of CD40 signaling, which may act only in the initial and final stages of the GC reaction.

Standard name | HASLINGER_B_CLL_WITH_6Q21_DELETION
Systematic name | M7362
Organism | Homo sapiens
PMID | 15459216
Authors | Haslinger C,Schweifer N,Stilgenbauer S,Döhner H,Lichter P,Kraut N,Stratowa C,Abseher R
Category | C2
Sub-category | CGP
Brief description | Genes changed in the B cell chronic lymphocytic leukemia (B-CLL) with deletions in the 6q21 region.
Full description | PURPOSE: Genomic aberrations and mutational status of the immunoglobulin variable heavy chain (VH) gene have been shown to be among the most important predictors for outcome in patients with B-cell chronic lymphocytic leukemia (B-CLL). In this study, we report on differential gene expression patterns that are characteristic for genetically defined B-CLL subtypes. MATERIALS AND METHODS: One hundred genetically well-characterized B-CLL samples, together with 11 healthy control samples, were analyzed using oligonucleotide arrays, which test for the expression of some 12,000 human genes. RESULTS: Aiming at microarray-based subclassification, class predictors were constructed using sets of differentially expressed genes, which yielded in zero or low misclassification rates. Furthermore, a significant number of the differentially expressed genes clustered in chromosomal regions affected by the respective genomic losses/gains. Deletions affecting chromosome bands 11q22-q23 and 17p13 led to a reduced expression of the corresponding genes, such as ATM and p53, while trisomy 12 resulted in the upregulation of genes mapping to chromosome arm 12q. Using an unsupervised analysis algorithm, expression profiling allowed partitioning into predominantly VH-mutated versus unmutated patient groups; however, association of the expression profile with the VH mutational status could only be detected in male patients. CONCLUSION: The finding that the most significantly differentially expressed genes are located in the corresponding aberrant chromosomal regions indicates that a gene dosage effect may exert a pathogenic role in B-CLL. The significant difference in the partitioning of male and female B-CLL samples suggests that the genomic signature for the VH mutational status might be sex-related.

Standard name | HANSON_HRAS_SIGNALING_VIA_NFKB
Systematic name | M1488
Organism | Mus musculus
PMID | 15492243
Authors | Hanson JL,Hawke NA,Kashatus D,Baldwin AS
Category | C2
Sub-category | CGP
Brief description | Genes changed by expression of activated form of HRas[GeneID=3265] in MEF cells (embryonic fibroblast) with or without p65/c-Rel complex [GeneID=5970;5966].
Full description | Extensive data indicate that oncoproteins, such as oncogenic H-Ras, initiate signal transduction cascades that ultimately lead to the activation of specific transcription factors. We and others have previously demonstrated that Ras activates the inherent transcriptional activation function of the transcription factor nuclear factor kappaB (NF-kappaB). Supportive of the importance of NF-kappaB in transformation, Ras-induced cellular transformation can be suppressed by expression of IkappaBalpha, an inhibitor of NF-kappaB, or by dominant-negative forms of the upstream activator IkappaB kinase (IKK). However, conclusive evidence for a requirement for NF-kappaB subunits in oncogenic transformation has not been reported. Furthermore, there is little understanding of the gene targets controlled by NF-kappaB that might support oncogenic conversion. The data presented here demonstrate that, although both p65 and c-Rel enhance the frequency of Ras-induced cellular transformation, these NF-kappaB subunits are not essential for Ras to transform spontaneously immortalized murine fibroblasts. Microarray analysis identified a set of genes induced by Ras that is dependent on NF-kappaB for their expression and that likely play contributory roles in promoting Ras-induced oncogenic transformation.

Standard name | FAELT_B_CLL_WITH_VH3_21_DN
Systematic name | M7218
Organism | Homo sapiens
PMID | 15817677
Authors | Fält S,Merup M,Tobin G,Thunberg U,Gahrton G,Rosenquist R,Wennborg A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in samples from B-CLL (B-cell chronic lymphocytic leukemia) with the immunoglobulin heavy chain VH3-21 gene.
Full description | The usage of the immunoglobulin (Ig) V(H)3-21 gene is associated with poor prognosis in B-cell chronic lymphocytic leukemia (B-CLL) despite V(H) gene mutation status. Many V(H)3-21+ patients also display restricted heavy- and light-chain Ig gene rearrangements, implying a role of antigen selection in disease development. To explore the specific phenotypic/genotypic features among V(H)3-21+ B-CLLs, we compared gene expression patterns in 15 V(H)3-21+ and 24 non-V(H)3-21 patients (11 with unmutated and 13 with mutated V(H) genes) using Affymetrix microarray analysis (approximately 12,500 genes). A distinct expression profile was identified for V(H)3-21+ patients in contrast to the Ig-unmutated and -mutated groups. By applying different algorithms, the data enabled an efficient class discrimination of the V(H)3-21+ subset based on 27 or 57 genes. A set of genes was sorted out which, using different analytical methods, consistently gave a distinction between V(H)3-21+ and non-V(H)3-21 samples. Several of these genes are involved in regulation of DNA replication/cell-cycle control, transcription and protein kinase activity, which may render the V(H)3-21+ cells with a higher proliferative drive. However, no clear evidence of increased B-cell receptor signaling was found in the V(H)3-21+ group. Altogether, our identification of a specific V(H)3-21 profile may provide insights into the pathogenesis of the V(H)3-21+ subgroup.

Standard name | GREENBAUM_E2A_TARGETS_UP
Systematic name | M1490
Organism | Mus musculus
PMID | 15310760
Authors | Greenbaum S,Lazorchak AS,Zhuang Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pre-B lymphocytes upon Cre-Lox knockout of E2A [GeneID=6929].
Full description | The transcription factors encoded by the E2A gene have been shown to play essential roles in the initiation and progression of lymphocyte development. However, there is still a lack of comprehensive understanding of E2A downstream genes in B-cell development. We previously developed a gene tagging-based chromatin immunoprecipitation (ChIP) system to directly evaluate E2A target genes in B-cell development. Here, we have improved this ChIP strategy and used it in conjunction with microarray analysis on E2A-deficient pre-B-cell lines to determine E2A target genes in lymphocyte development. Both microarray data and ChIP studies confirmed that E2A directly controls IgH gene expression. The microarray assay also revealed genes that were significantly up-regulated after E2A disruption. ChIP analysis showed that E2A was most likely to be directly involved in repression of some of these target genes such as Nfil3 and FGFR2. An inducible E2A reconstitution system further demonstrated that E2A-mediated repression of Nfil3 and FGFR2 was reversible. Collectively, these findings indicate that E2A is a positive regulator for one set of genes and a negative regulator for another set of genes in developing B lymphocytes.

Standard name | XU_RESPONSE_TO_TRETINOIN_AND_NSC682994_DN
Systematic name | M3905
Organism | Homo sapiens
PMID | 16140955
Authors | Xu K,Guidez F,Glasow A,Chung D,Petrie K,Stegmaier K,Wang KK,Zhang J,Jing Y,Zelent A,Waxman S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated synergistically in NB4 cells (acute promyelocytic leukemia, APL) by tretinoin and NSC682994 [PubChem=444795;388304].
Full description | Differentiation induction is an effective therapy for acute promyelocytic leukemia (APL), which dramatically responds to all-trans-retinoic acid (ATRA). Recent studies have indicated that combinatorial use of retinoid and nonretinoid compounds, such as histone deacetylase inhibitors, arsenics, and PKA agonists, has higher therapeutic value in this disease and potentially in other malignancies. In a screen of 370 compounds, we identified benzodithiophene analogues as potent enhancers of ATRA-induced APL cell differentiation. These effects were not associated with changes in global histone acetylation and, for the most potent compounds, were exerted at very low nanomolar concentrations, and were paralleled by enhancement of some, but not all, ATRA-modulated gene expressions. Investigating the mechanism underlying the effects of these drugs on ATRA-induced APL cell differentiation, we have shown that benzodithiophenes enhance ATRA-mediated dissociation and association of corepressor N-CoR and coactivator p300 acetyltransferase, respectively, with retinoic acid receptor (RAR) alpha proteins. These data suggest that benzodithiophenes act at the level of receptor activation, possibly by affecting posttranslational modification of the receptor (and/or coregulators), thus leading to an enhancement in ATRA-mediated effects on gene expression and APL cell differentiation. Given the specificities of these low benzodithiophene concentrations for PML-RARalpha and RARalpha, these drugs may be useful for combinatorial differentiation therapy of APL and possibly other acute myelogenous leukemia subtypes in which the overall ATRA signaling is suppressed.

Standard name | NOUZOVA_TRETINOIN_AND_H4_ACETYLATION
Systematic name | M15068
Organism | Homo sapiens
PMID | 15302897
Authors | Nouzova M,Holtan N,Oshiro MM,Isett RB,Munoz-Rodriguez JL,List AF,Narro ML,Miller SJ,Merchant NC,Futscher BW
Category | C2
Sub-category | CGP
Brief description | Genes whose CpG islands showed greatly increased histone H4 acetylation in NB4 cells (acute promyelocytic leukemia, APL) upon treatment with tretinoin [PubChem=444795].
Full description | Dysregulation of epigenetic control is an important participant in carcinogenesis. The PML/RAR alpha translocation in acute promyelocytic leukemia (APL) is an example where the resultant fusion protein recruits histone deacetylase complexes to target genes resulting in their inappropriate transcriptional repression. All-trans-retinoic acid (ATRA) acts as a ligand that relieves this repression and produces an epigenetic transcriptional reprogramming of the cancer cell. CpG island microarrays were used to analyze the DNA methylation and histone acetylation state of the human APL cell line NB4 before and after differentiation with ATRA as well as normal peripheral blood mononuclear cells (PBMC). Over 70 CpG islands within 1 kb of transcription start of a known gene are aberrantly methylated in NB4 cells compared with PBMC; however, no changes in cytosine methylation were detected following ATRA-induced differentiation. With respect to histone H4 acetylation, over 100 single-copy CpG islands within 1 kb of transcription start of a known human gene became hyperacetylated following ATRA-induced differentiation. One CpG island was aberrantly methylated in NB4 cells, but became hyperacetylated and was induced following ATRA treatment and was associated with the HoxA1 gene, suggesting it may be a target gene of ATRA in APL. In addition to single-copy sequences, a selective increase in acetylation was detected in satellite DNA when compared with other high-copy sequences, such as Alu or rDNA. In summary, ATRA stimulates complex epigenomic changes during leukemic cell differentiation, and monitoring these changes may help to identify new targets of epigenetic dysfunction.

Standard name | BRUNO_HEMATOPOIESIS
Systematic name | M1492
Organism | Mus musculus
PMID | 14701746
Authors | Bruno L,Hoffmann R,McBlane F,Brown J,Gupta R,Joshi C,Pearson S,Seidl T,Heyworth C,Enver T
Category | C2
Sub-category | CGP
Brief description | Genes that are rapidly down-regulated as multipotential cells of the FDCP-mix hematopoiesis model undergo differentiation and loose their self-renewal and proliferation properties.
Full description | The molecular mechanisms governing self-renewal, differentiation, and lineage specification remain unknown. Transcriptional profiling is likely to provide insight into these processes but, as yet, has been confined to static molecular profiles of stem and progenitors cells. We now provide a comprehensive, statistically robust, and dynamic analysis of multipotent hemopoietic progenitor cells undergoing self-renewal in response to interleukin-3 (IL-3) and multilineage differentiation in response to lineage-affiliated cytokines. Cells undergoing IL-3-dependent proliferative self-renewal displayed striking complexity, including expression of genes associated with different lineage programs, suggesting a highly responsive compartment poised to rapidly execute intrinsically or extrinsically initiated cell fate decisions. A remarkable general feature of early differentiation was a resolution of complexity through the downregulation of gene expression. Although effector genes characteristic of mature cells were upregulated late, coincident with morphological changes, lineage-specific changes in gene expression were observed prior to this, identifying genes which may provide early harbingers of unilineage commitment. Of particular interest were genes that displayed differential behavior irrespective of the lineage elaborated, many of which were rapidly downregulated within 4 to 8 h after exposure to a differentiation cue. These are likely to include genes important in self-renewal, the maintenance of multipotentiality, or the negative regulation of differentiation per se.

Standard name | MOREAUX_B_LYMPHOCYTE_MATURATION_BY_TACI_UP
Systematic name | M945
Organism | Homo sapiens
PMID | 15827134
Authors | Moreaux J,Cremer FW,Reme T,Raab M,Mahtouk K,Kaukel P,Pantesco V,De Vos J,Jourdan E,Jauch A,Legouffe E,Moos M,Fiol G,Goldschmidt H,Rossi JF,Hose D,Klein B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in normal bone marrow plasma cells (BMPC) compared to polyclonal plasmablasts (PPC) that also distinguished multiple myeloma (MM) samples by expression of levels of TACI (TNFRSF13B) [GeneID=23495].
Full description | B-cell activating factor (BAFF) and a proliferation-inducing ligand (APRIL) have been shown to promote multiple myeloma (MM) cell growth. We show that the main site of production for BAFF and APRIL is the bone marrow (BM) environment, and that production is mainly by monocytes and neutrophils. In addition, osteoclasts produce very high levels of APRIL, unlike BM stromal cells. Myeloma cells (MMCs) express TACI (transmembrane activator and calcium modulator and cyclophilin ligand interactor), the receptor of BAFF/APRIL, at varying levels. TACI expression is a good indicator of a BAFF-binding receptor. Expression data of purified MMCs from 65 newly diagnosed patients have been generated using Affymetrix microarrays and were analyzed by supervised clustering of groups with higher (TACI(hi)) versus lower (TACI(lo)) TACI expression levels. Patients in the TACI(lo) group had clinical parameters associated with bad prognosis. A set of 659 genes was differentially expressed between TACI(hi) and TACI(lo) MMCs. This set makes it possible to efficiently classify TACI(hi) and TACI(lo) MMCs in an independent cohort of 40 patients. TACI(hi) MMCs displayed a mature plasma cell gene signature, indicating dependence on the BM environment. In contrast, the TACI(lo) group had a gene signature of plasmablasts, suggesting an attenuated dependence on the BM environment. Taken together, our findings suggest using gene expression profiling to identify the group of patients who might benefit most from treatment with BAFF/APRIL inhibitors.

Standard name | PETROVA_PROX1_TARGETS_UP
Systematic name | M1495
Organism | Homo sapiens
PMID | 12198161
Authors | Petrova TV,Mäkinen T,Mäkelä TP,Saarela J,Virtanen I,Ferrell RE,Finegold DN,Kerjaschki D,Ylä-Herttuala S,Alitalo K
Category | C2
Sub-category | CGP
Brief description | Genes specific to LEC (lymphatic endothelium cells) induced in BEC (blood endothelium cells) by expression of PROX1 [GeneID=5629] off adenovirus vector.
Full description | Lymphatic vessels are essential for fluid homeostasis, immune surveillance and fat adsorption, and also serve as a major route for tumor metastasis in many types of cancer. We found that isolated human primary lymphatic and blood vascular endothelial cells (LECs and BECs, respectively) show interesting differences in gene expression relevant for their distinct functions in vivo. Although these phenotypes are stable in vitro and in vivo, overexpression of the homeobox transcription factor Prox-1 in the BECs was capable of inducing LEC-specific gene transcription in the BECs, and, surprisingly, Prox-1 suppressed the expression of approximately 40% of the BEC-specific genes. Prox-1 did not have global effects on the expression of LEC-specific genes in other cell types, except that it up-regulated cyclin E1 and E2 mRNAs and activated the cyclin e promoter in various cell types. These data suggest that Prox-1 acts as a cell proliferation inducer and a fate determination factor for the LECs. Furthermore, the data provide insights into the phenotypic diversity of endothelial cells and into the possibility of transcriptional reprogramming of differentiated endothelial cells.

Standard name | HOEGERKORP_CD44_TARGETS_DIRECT_UP
Systematic name | M14487
Organism | Homo sapiens
PMID | 12411303
Authors | Högerkorp CM,Bilke S,Breslin T,Ingvarsson S,Borrebaeck CA
Category | C2
Sub-category | CGP
Brief description | Genes directly up-regulated by CD44 [GeneID=960] stimulation of B lymphocytes.
Full description | A number of studies have implicated a role for the cell surface glycoprotein CD44 in several biologic events, such as lymphopoiesis, homing, lymphocyte activation, and apoptosis. We have earlier reported that signaling via CD44 on naive B cells in addition to B-cell receptor (BCR) and CD40 engagement generated a germinal center-like phenotype. To further characterize the global role of CD44 in B differentiation, we examined the expression profile of human B cells cultured in vitro in the presence or absence of CD44 ligation, together with anti-immunoglobulin (anti-Ig) and anti-CD40 antibodies. The data sets derived from DNA microarrays were analyzed using a novel statistical analysis scheme created to retrieve the most likely expression pattern of CD44 ligation. Our results show that genes such as interleukin-6 (IL-6), IL-1alpha, and beta(2)-adrenergic receptor (beta(2)-AR) were specifically up-regulated by CD44 ligation, suggesting a novel role for CD44 in immunoregulation and inflammation.

Standard name | KUMAR_TARGETS_OF_MLL_AF9_FUSION
Systematic name | M3284
Organism | Mus musculus
PMID | 14615372
Authors | Kumar AR,Hudson WA,Chen W,Nishiuchi R,Yao Q,Kersey JH
Category | C2
Sub-category | CGP
Brief description | Myeloid leukemia model in mice with germ-line MLL-AF9 fusion knock-in [GeneID=4297;4300]: genes changed in comparison among the leukemic, preleukemic and wild-type animals.
Full description | Identification of the targets of mixed lineage leukemia (MLL) fusion genes will assist in understanding the biology of MLL fusion gene leukemias and in development of better therapies. Numerous studies have implicated HOXA9 as one of the possible targets of MLL fusion proteins. To determine if HOXA9 was required for leukemia development by MLL fusion genes, we compared the effects of the Mll-AF9 knock-in mutation in mice in the presence or absence of Hoxa9. Both groups of mice showed myeloid expansion at 8 weeks and then developed myeloid leukemia with a similar incidence and time course. The leukemia in the mice lacking Hoxa9 generally displayed a more immature myeloid phenotype than that in the mice that were wild-type for Hoxa9. Gene expression profiling revealed that expression of Mll-AF9 led to overexpression of Hoxa5, Hoxa6, Hoxa7, Hoxa9, and Hoxa10. Thus, genes of the Hox-a cluster are important in defining the phenotype but not the incidence of Mll-AF9 leukemia. These results demonstrate that the Mll-AF9 fusion gene disrupts the expression of several Hox genes, none of which as a single gene is likely to be necessary for development of leukemia. Instead, we propose that the Hox code minimally defined by the Hoxa5-a9 cluster is central to MLL leukemogenesis.

Standard name | FAELT_B_CLL_WITH_VH3_21_UP
Systematic name | M15164
Organism | Homo sapiens
PMID | 15817677
Authors | Fält S,Merup M,Tobin G,Thunberg U,Gahrton G,Rosenquist R,Wennborg A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in samples from B-CLL (B-cell chronic lymphocytic leukemia) with the immunoglobulin heavy chain VH3-21 gene.
Full description | The usage of the immunoglobulin (Ig) V(H)3-21 gene is associated with poor prognosis in B-cell chronic lymphocytic leukemia (B-CLL) despite V(H) gene mutation status. Many V(H)3-21+ patients also display restricted heavy- and light-chain Ig gene rearrangements, implying a role of antigen selection in disease development. To explore the specific phenotypic/genotypic features among V(H)3-21+ B-CLLs, we compared gene expression patterns in 15 V(H)3-21+ and 24 non-V(H)3-21 patients (11 with unmutated and 13 with mutated V(H) genes) using Affymetrix microarray analysis (approximately 12,500 genes). A distinct expression profile was identified for V(H)3-21+ patients in contrast to the Ig-unmutated and -mutated groups. By applying different algorithms, the data enabled an efficient class discrimination of the V(H)3-21+ subset based on 27 or 57 genes. A set of genes was sorted out which, using different analytical methods, consistently gave a distinction between V(H)3-21+ and non-V(H)3-21 samples. Several of these genes are involved in regulation of DNA replication/cell-cycle control, transcription and protein kinase activity, which may render the V(H)3-21+ cells with a higher proliferative drive. However, no clear evidence of increased B-cell receptor signaling was found in the V(H)3-21+ group. Altogether, our identification of a specific V(H)3-21 profile may provide insights into the pathogenesis of the V(H)3-21+ subgroup.

Standard name | SESTO_RESPONSE_TO_UV_C8
Systematic name | M2948
Organism | Homo sapiens
PMID | 11867738
Authors | Sesto A,Navarro M,Burslem F,Jorcano JL
Category | C2
Sub-category | CGP
Brief description | Cluster 8: genes changed in primary keratinocytes by UVB irradiation.
Full description | UV radiation is the most important environmental skin aggressor, causing cancer and other problems. This paper reports the use of oligonucleotide microarray technology to determine changes in gene expression in human keratinocytes after UVB treatment. Examination of the effects of different doses at different times after irradiation gave a global picture of the keratinocyte response to this type of insult. Five hundred thirty-nine regulated transcripts were found and organized into nine different clusters depending on behavior patterns. Classification of these genes into 23 functional categories revealed that several biological processes are globally affected by UVB. In addition to confirming a majority up-regulation of the transcripts related to the UV-specific inflammatory and stress responses, significant increases were seen in the expression of genes involved in basal transcription, splicing, and translation as well as in the proteasome-mediated degradation category. On the other hand, those transcripts belonging to the metabolism and adhesion categories were strongly downregulated. These results demonstrate the complexity of the transcriptional profile of the UVB response, describe several cellular processes previously not known to be affected by UV irradiation, and serve as a basis for the global characterization of UV-regulated genes and pathways.

Standard name | KIM_HYPOXIA
Systematic name | M1496
Organism | Homo sapiens
PMID | 14499499
Authors | Kim H,Lee DK,Choi JW,Kim JS,Park SC,Youn HD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in normal fibroblasts under hypoxia conditions.
Full description | Little is known about the detail of hypoxia-responsive gene expression patterns in advanced age, even though aging is thought to be partially associated with a decreased response to hypoxia. In the present study, we identified several hypoxia-inducible genes and investigated the effect of aging on hypoxic gene expression profiles using cDNA microarray analysis of young/old human diploid fibroblasts. Of 7458 genes in the microarray, we found that genes involved in angiogenesis, defense against oxidative stress, and transcription regulation are severely impaired in senescent cell, which is consistent with the fact that aged cells have attenuated responses to various stimuli.

Standard name | GENTILE_UV_RESPONSE_CLUSTER_D9
Systematic name | M13686
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Cluster d9: genes progressively down-regulated in WS1 cells (fibroblast) through 24 h after irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | LIANG_SILENCED_BY_METHYLATION_2
Systematic name | M18085
Organism | Homo sapiens
PMID | 11861364
Authors | Liang G,Gonzales FA,Jones PA,Orntoft TF,Thykjaer T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T24 cells (bladder carcinoma) after treatment with decitabine (5-aza-2'-deoxycytidine) [PubChem=451668].
Full description | Hypermethylation of the promoters of cancer-related genes is often associated with their inactivation during tumorigenesis. Several preclinical and clinical trials have been developed to use DNA methylation inhibitors, such as 5-aza-2'-deoxycytidine (5-Aza-CdR) in attempts to reactivate silenced genes in human cancers. We used high-density oligonucleotide gene expression microarrays to examine the effects of 5-Aza-CdR treatment on human fibroblast cells (LD419) and a human bladder tumor cell line (T24). Data obtained 8 days after recovery from 5-Aza-CdR treatment showed that more genes were induced in tumorigenic cells (61 genes induced; >or=4-fold) than nontumorigenic cells (34 genes induced; >or= 4-fold). Approximately 60% of induced genes did not have CpG islands within their 5' regions, suggesting that some genes activated by 5-Aza-CdR may not result from the direct inhibition of promoter methylation. Interestingly, a high percentage of genes activated in both cell types belonged to the IFN signaling pathway, confirming data from other tumor cell types.

Standard name | IVANOVA_HEMATOPOIESIS_EARLY_PROGENITOR
Systematic name | M1606
Organism | Mus musculus
PMID | 12228721
Authors | Ivanova NB,Dimos JT,Schaniel C,Hackney JA,Moore KA,Lemischka IR
Category | C2
Sub-category | CGP
Brief description | Genes in the expression cluster 'Early Progenitors Shared': up-regulated in hematopoietic progenitors from adult bone marrow and from fetal liver.
Full description | Mechanisms regulating self-renewal and cell fate decisions in mammalian stem cells are poorly understood. We determined global gene expression profiles for mouse and human hematopoietic stem cells and other stages of the hematopoietic hierarchy. Murine and human hematopoietic stem cells share a number of expressed gene products, which define key conserved regulatory pathways in this developmental system. Moreover, in the mouse, a portion of the genetic program of hematopoietic stem cells is shared with embryonic and neural stem cells. This overlapping set of gene products represents a molecular signature of stem cells.

Standard name | LY_AGING_PREMATURE_DN
Systematic name | M1491
Organism | Homo sapiens
PMID | 10741968
Authors | Ly DH,Lockhart DJ,Lerner RA,Schultz PG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in fibroblasts from patients with Hutchinson-Gilford progeria (premature aging), compared to those from normal young individuals.
Full description | Messenger RNA levels were measured in actively dividing fibroblasts isolated from young, middle-age, and old-age humans and humans with progeria, a rare genetic disorder characterized by accelerated aging. Genes whose expression is associated with age-related phenotypes and diseases were identified. The data also suggest that an underlying mechanism of the aging process involves increasing errors in the mitotic machinery of dividing cells in the postreproductive stage of life. We propose that this dysfunction leads to chromosomal pathologies that result in misregulation of genes involved in the aging process.

Standard name | MARTINEZ_RESPONSE_TO_TRABECTEDIN
Systematic name | M5077
Organism | Homo sapiens
PMID | 11755394
Authors | Martinez EJ,Corey EJ,Owa T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by trabectedin [PubChem=3199] and its synthetic analog phthalascidin Pt 650 in HCT116 cells (colon cancer).
Full description | BACKGROUND: Ecteinascidin 743 (Et 743) is a potent antitumor marine alkaloid currently undergoing phase II clinical trials. The synthetic analog phthalascidin (Pt 650), a designed structural analog of Et 743 displays in vitro potency comparable to Et 743. In this study, we used a panel of 36 human cancer cell lines, flow cytometry and oligonucleotide microarrays to analyze further these two compounds in a parallel fashion with regard to both antitumor activity (phenotype) and gene expression (genotype) bases. RESULTS: The cancer panel experiment established that activity patterns of Et 743 and Pt 650 were essentially the same with their IC(50) values ranging from pM to low nM. By means of flow cytometric cell cycle analysis using HCT116 cells, they were shown to disrupt S phase progression after a 12-h treatment at 2.0 nM, eventually resulting in the late S and G2/M accumulation at the 24-h time point. Array-based gene expression monitoring also demonstrated that the Et 743 and Pt 650 profiles were highly similar in two distinct cancer cell lines, HCT116 colon and MDA-MB-435 breast. Characteristic changes were observed in subsets of genes involved in DNA damage response, transcription and signal transduction. In HCT116 carrying the wild-type p53 tumor suppressor gene, the up-regulation of several p53-responsive genes was evident. Furthermore, a subset of genes encoding DNA-binding proteins to specific promoter regions (e.g. the CCAAT box) was down-regulated in both cell lines, suggesting one potential mode of action of this series of antitumor agents. CONCLUSION: A combination of gene expression analysis using oligonucleotide microarrays and flow cytometry confirms an earlier finding that Et 743 and Pt 650 have remarkably similar biological activities.

Standard name | WEIGEL_OXIDATIVE_STRESS_BY_TBH_AND_H2O2
Systematic name | M11333
Organism | Homo sapiens
PMID | 12419474
Authors | Weigel AL,Handa JT,Hjelmeland LM
Category | C2
Sub-category | CGP
Brief description | Oxidative stress genes down-regulated in ARPE-19 cells (retinal pigmented epithelium) in response to tert-butyl hydroperoxide (tBH) and H2O2 [PubChem=6410;784].
Full description | Oxidative stress plays a key role in aging diseases of the posterior pole of the eye such as age-related macular degeneration. The oxidative stress response of in vitro RPE cells has been studied for a small number of genes. However, a comprehensive transcriptional response has yet to be elucidated. The purpose of this study was to determine if the transcription of a common set of genes is altered by exposure of ARPE-19 cells to three major generators of oxidative stress, hydrogen peroxide (H2O2), 4-hydroxynonenal (HNE), and tert-butylhydroperoxide (tBH). As expected, a common response was observed that included 35 genes differentially regulated by all three treatments. Of these, only one gene was upregulated, and only by one oxidant, while all other responses were downregulation. The majority of these genes fell into five functional categories: apoptosis, cell cycle regulation, cell-cell communication, signal transduction, and transcriptional regulation. Additionally, a large number of genes were differentially regulated by one oxidant only, including the majority of the conventional oxidative stress response genes present on the Clontech Human 1.2 microarray. This study raises questions regarding the generality of results that involve the use of a single oxidant and a single cell culture condition.

Standard name | BROWNE_HCMV_INFECTION_20HR_UP
Systematic name | M6122
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 20 h time point that were not up-regulated at the previous time point, 18 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | TAKAO_RESPONSE_TO_UVB_RADIATION_UP
Systematic name | M73
Organism | Homo sapiens
PMID | 11982916
Authors | Takao J,Ariizumi K,Dougherty II,Cruz PD Jr
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary tissue culture of epidermal kerationcytes after UVB irradiation.
Full description | Ultraviolet B (UVB) radiation is an important inducer of many biologic changes in skin, of which keratinocytes are a key target. To gain better insight into changes in gene expression generated in the early phase after UVB exposure, we used complementary RNA (cRNA) microarray hybridization to compare differences in mRNA expression of UVB-irradiated (single dose of 100 J/m2 broad-band UVB) and sham-irradiated primary cultured human keratinocytes. Six hours after irradiation, total RNA was isolated from keratinocytes, and cRNA was synthesized and hybridized to a GeneChip expression array (Affymetrix) consisting of 6800 genes. Based on a threshold of > twofold change, 187 genes (2.8%) were designated to be the most UVB-responsive. Surprisingly, none of these genes had been shown previously to be modulated by UVB. Conversely, several genes in the microarray that had been reported previously to be UVB- responsive by other methods showed less (< twofold) or no change. Northern blotting of seven differentially modulated genes produced results similar to those derived from microarray technology, thereby validating the accuracy of screening. Clustering based on known or likely functions indicated that among 88 upregulated genes, nine encode for cytochrome c subunits, six for ribosomal proteins, and two for regulators of apoptosis. By contrast, many of the 99 downregulated genes are involved in transcription, differentiation and transport. These findings indicate that keratinocytes respond to a single low dose of broad-band UVB irradiation by enhancing processes involved in energy production and translation, while suppressing those related to transcription, differentiation and transport.

Standard name | URS_ADIPOCYTE_DIFFERENTIATION_UP
Systematic name | M15476
Organism | Homo sapiens
PMID | 15051823
Authors | Urs S,Smith C,Campbell B,Saxton AM,Taylor J,Zhang B,Snoddy J,Jones Voy B,Moustaid-Moussa N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary adipocytes compared to preadipocytes.
Full description | Uncontrolled expansion of adipose tissue leads to obesity, a public health epidemic affecting >30% of adult Americans. Adipose mass increases in part through the recruitment and differentiation of an existing pool of preadipocytes (PA) into adipocytes (AD). Most studies investigating adipogenesis used primarily murine cell lines; much less is known about the relevant processes that occur in humans. Therefore, characterization of genes associated with adipocyte development is key to understanding the pathogenesis of obesity and developing treatments for this disorder. To address this issue, we performed large-scale analyses of human adipose gene expression using microarray technology. Differential gene expression between PA and AD was analyzed in 6 female patients using human cDNA microarray slides and data analyzed using the Stanford Microarray Database. Statistical analysis for the gene expression was performed using the SAS mixed models. Compared with PA, several genes involved in lipid metabolism were overexpressed in AD, including fatty acid binding protein, adipose differentiation-related protein, lipoprotein lipase, perilipin, and adipose most abundant transcript 1. Novel genes expressed in adipocytes included E2F5 transcriptional factor and SMARC (SWI/SNF-related, matrix associated, actin-dependent regulator of chromatin). PA predominantly expressed genes encoding extracellular matrix components such as fibronectin, matrix metalloprotein, and novel proteins such as lysyl oxidase. Despite the high differential expression of some of these genes, many did not differ significantly likely due to high variability and limited statistical power. A comprehensive list of differential gene expression is presented according to cellular function. In conclusion, these studies offer an overview of the gene expression profiles in PA and AD and identify new genes with potentially important functions in adipose tissue development and obesity that merit further investigation.

Standard name | LEE_AGING_NEOCORTEX_DN
Systematic name | M1497
Organism | Mus musculus
PMID | 10888876
Authors | Lee CK,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Downregulated in the neocortex of aged adult mice (30-month) vs young adult (5-month)
Full description | Ageing of the brain leads to impairments in cognitive and motor skills, and is the major risk factor for several common neurological disorders such as Alzheimer disease (AD) and Parkinson disease (PD). Recent studies suggest that normal brain ageing is associated with subtle morphological and functional alterations in specific neuronal circuits, as opposed to large-scale neuronal loss. In fact, ageing of the central nervous system in diverse mammalian species shares many features, such as atrophy of pyramidal neurons, synaptic atrophy, decrease of striatal dopamine receptors, accumulation of fluorescent pigments, cytoskeletal abnormalities, and reactive astrocytes and microglia. To provide the first global analysis of brain ageing at the molecular level, we used oligonucleotide arrays representing 6,347 genes to determine the gene-expression profile of the ageing neocortex and cerebellum in mice. Ageing resulted in a gene-expression profile indicative of an inflammatory response, oxidative stress and reduced neurotrophic support in both brain regions. At the transcriptional level, brain ageing in mice displays parallels with human neurodegenerative disorders. Caloric restriction, which retards the ageing process in mammals, selectively attenuated the age-associated induction of genes encoding inflammatory and stress responses.

Standard name | REN_ALVEOLAR_RHABDOMYOSARCOMA_UP
Systematic name | M768
Organism | Homo sapiens
PMID | 18701482
Authors | Ren YX,Finckenstein FG,Abdueva DA,Shahbazian V,Chung B,Weinberg KI,Triche TJ,Shimada H,Anderson MJ
Category | C2
Sub-category | CGP
Brief description | Genes commonly up-regulated in human alveolar rhabdomyosarcoma (ARMS) and its mouse model overexpressing PAX3-FOXO1 [GeneID=5077;2308] fusion.
Full description | Alveolar rhabdomyosarcomas (ARMS) are highly malignant soft-tissue sarcomas that arise in children, adolescents, and young adults. Although formation and expression of the PAX-FKHR fusion genes is thought to be the initiating event in this cancer, the role of PAX-FKHR in the neoplastic process remains largely unknown in a progenitor cell that is undefined. We hypothesize that PAX-FKHR determine the ARMS progenitor to the skeletal muscle lineage, which when coupled to the inactivation and/or activation of critical cell signaling pathways leads to the formation of ARMS. Because a number of studies have proposed that mesenchymal stem cells (MSC) are the progenitor for several of the sarcomas, we tested this hypothesis in MSCs. We show that PAX-FKHR induce skeletal myogenesis in MSCs by transactivating MyoD and myogenin. Despite exhibiting enhanced growth in vitro, the PAX-FKHR-expressing populations do not form colonies in soft agar or tumors in mice. Expression of dominant-negative p53, or the SV40 early region, elicits tumor formation in some of the PAX-FKHR-expressing populations. Additional activation of the Ras signaling pathway leads to highly malignant tumor formation for all of the populations. The PAX-FKHR-expressing tumors were shown to have histologic, immunohistochemical, and gene expression profiles similar to human ARMS. Our results show the critical role played by PAX-FKHR in determining the molecular, myogenic, and histologic phenotype of ARMS. More importantly, we identify MSCs as a progenitor that can give rise to ARMS.

Standard name | REN_ALVEOLAR_RHABDOMYOSARCOMA_DN
Systematic name | M19541
Organism | Homo sapiens
PMID | 18701482
Authors | Ren YX,Finckenstein FG,Abdueva DA,Shahbazian V,Chung B,Weinberg KI,Triche TJ,Shimada H,Anderson MJ
Category | C2
Sub-category | CGP
Brief description | Genes commonly down-regulated in human alveolar rhabdomyosarcoma (ARMS) and its mouse model overexpressing PAX3-FOXO1 [GeneID=5077;2308] fusion.
Full description | Alveolar rhabdomyosarcomas (ARMS) are highly malignant soft-tissue sarcomas that arise in children, adolescents, and young adults. Although formation and expression of the PAX-FKHR fusion genes is thought to be the initiating event in this cancer, the role of PAX-FKHR in the neoplastic process remains largely unknown in a progenitor cell that is undefined. We hypothesize that PAX-FKHR determine the ARMS progenitor to the skeletal muscle lineage, which when coupled to the inactivation and/or activation of critical cell signaling pathways leads to the formation of ARMS. Because a number of studies have proposed that mesenchymal stem cells (MSC) are the progenitor for several of the sarcomas, we tested this hypothesis in MSCs. We show that PAX-FKHR induce skeletal myogenesis in MSCs by transactivating MyoD and myogenin. Despite exhibiting enhanced growth in vitro, the PAX-FKHR-expressing populations do not form colonies in soft agar or tumors in mice. Expression of dominant-negative p53, or the SV40 early region, elicits tumor formation in some of the PAX-FKHR-expressing populations. Additional activation of the Ras signaling pathway leads to highly malignant tumor formation for all of the populations. The PAX-FKHR-expressing tumors were shown to have histologic, immunohistochemical, and gene expression profiles similar to human ARMS. Our results show the critical role played by PAX-FKHR in determining the molecular, myogenic, and histologic phenotype of ARMS. More importantly, we identify MSCs as a progenitor that can give rise to ARMS.

Standard name | TRAYNOR_RETT_SYNDROM_UP
Systematic name | M2712
Organism | Homo sapiens
PMID | 12418965
Authors | Traynor J,Agarwal P,Lazzeroni L,Francke U
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblasts from Rett syndrom patients who carry mutations inactivating MECP2 [GeneID=4204].
Full description | BACKGROUND: Females with the neurological disorder Rett syndrome are heterozygous for mutations in X-linked MECP2 that encodes methyl-CpG binding protein 2 (MeCP2) thought to act as a transcriptional repressor. To identify target genes for MeCP2 modulation, we studied global gene expression in single cell-derived wild-type and mutant MECP2 expressing fibroblast clones with four common mutations (R106W, R306C, 705delG, 1155del32) and in lymphoblastoid cell lines (LCLs) that included four mutant MeCP2 (T158M, 803delG, R168X and 1159del28) expressing, and five (1159del28, R106W, R255X, 803delG, 803delG) wild-type MeCP2 expressing lines. METHODS: Clonality and mutation status were verified by androgen receptor methylation assays for X-inactivation and by sequencing MECP2 transcripts. Expression studies were done with oligonucleotide microarrays (Affymetrix U95) and verified with real-time quantitative RT-PCR using Sybr Green. RESULTS: Expression of 49 transcripts was increased, and expression of 21 transcripts was decreased, in at least 3 of 4 mutant/wild-type fibroblast comparisons. Transcript levels of 11 genes, determined by quantitative RT-PCR, were highly correlated with the microarray data. Therefore, multiple additional clones from two Rett individuals were tested by RT-PCR only. Striking expression differences were found in both mutant and wildtype MeCP2 expressing clones. Comparing expression profiles of lymphoblastoid cell lines yielded 16 differentially expressed genes. CONCLUSIONS: MeCP2 deficiency does not lead to global deregulation of gene expression. Either MeCP2's in vivo function does not involve widespread transcriptional repression, or its function is redundant in cell types that also express other methyl-CpG binding proteins. Our data suggest that clonal fibroblast strains may show substantial inter-strain variation, making them a difficult and unstable resource for genome-wide expression profiling studies.

Standard name | MCCLUNG_DELTA_FOSB_TARGETS_8WK
Systematic name | M17173
Organism | Mus musculus
PMID | 14566342
Authors | McClung CA,Nestler EJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the nucleus accumbens (a major reward center in brain) 8 weeks after induction of deltaFosB, a FOSB [GeneID=2354] splice variant.
Full description | DeltaFosB (a truncated form of FosB) and CREB (cAMP response element binding protein) are transcription factors induced in the brain's reward pathways after chronic exposure to drugs of abuse. However, their mechanisms of action and the genes they regulate remain unclear. Using microarray analysis in the nucleus accumbens of inducible transgenic mice, we found that CREB and a dominant-negative CREB have opposite effects on gene expression, as do prolonged expression of DeltaFosB and the activator protein-1 (AP-1) antagonist DeltacJun. However, unlike CREB, short-term and prolonged DeltaFosB induction had opposing effects on gene expression. Gene expression induced by short-term DeltaFosB and by CREB was strikingly similar, and both reduced the rewarding effects of cocaine, whereas prolonged DeltaFosB expression increased drug reward. Gene expression after a short cocaine treatment was more dependent on CREB, whereas gene expression after a longer cocaine treatment became increasingly DeltaFosB dependent. These findings help define the molecular functions of CREB and DeltaFosB and identify clusters of genes that contribute to cocaine addiction.

Standard name | BRACHAT_RESPONSE_TO_METHOTREXATE_DN
Systematic name | M1498
Organism | Mus musculus
PMID | 12447701
Authors | Brachat A,Pierrat B,Xynos A,Brecht K,Simonen M,Brüngger A,Heim J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in FL5.12 cells (pro-B lymphocyte) in response to methotrexate [PubChem=4112].
Full description | DNA microarrays are powerful tools for the analysis of gene expression on a genomic scale. The importance of individual regulatory events for the process under study can however not be deduced unequivocally without additional experiments. We devised a strategy to identify central regulators of cancer drug responses by combining the results of microarray experiments with efficient methods for phenotypic testing of candidate genes. We exposed murine FL5.12 pro-B cells to cisplatin, camptothecin, methotrexate or paclitaxel, respectively and analysed the patterns of gene expression with cDNA microarrays. Drug-specific regulatory events as well as intersections between different apoptotic pathways, including previously studied responses to staurosporine and interleukin-3 (IL-3) deprivation, were identified. Genes shared by at least three pathways were chosen for further analysis. Ectopic expression of three such genes, TEAP, GP49B, and Lipin1 was found to have an anti-proliferative effect on pro-B cells. Interestingly, we identified hemoglobin alpha as a strong pro-apoptotic regulator. While hemoglobin-expressing cells were growing normally in the presence of IL-3, they displayed accelerated apoptosis with similar kinetics as Bax overexpressing cells upon IL-3 removal. The pro-apoptotic effect of hemoglobin was suppressed by Bcl-2 and was characterized by enhanced stimulation of caspase activity.

Standard name | BROWNE_HCMV_INFECTION_16HR_UP
Systematic name | M11383
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 16 h time point that were not up-regulated at the previous time point, 14 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | MODY_HIPPOCAMPUS_POSTNATAL
Systematic name | M10332
Organism | Mus musculus
PMID | 11438693
Authors | Mody M,Cao Y,Cui Z,Tay KY,Shyong A,Shimizu E,Pham K,Schultz P,Welsh D,Tsien JZ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hyppocampus at late postnatal stages (clusters 11 and 15).
Full description | We have analyzed the developmental molecular programs of the mouse hippocampus, a cortical structure critical for learning and memory, by means of large-scale DNA microarray techniques. Of 11,000 genes and expressed sequence tags examined, 1,926 showed dynamic changes during hippocampal development from embryonic day 16 to postnatal day 30. Gene-cluster analysis was used to group these genes into 16 distinct clusters with striking patterns that appear to correlate with major developmental hallmarks and cellular events. These include genes involved in neuronal proliferation, differentiation, and synapse formation. A complete list of the transcriptional changes has been compiled into a comprehensive gene profile database (http://BrainGenomics.Princeton.edu), which should prove valuable in advancing our understanding of the molecular and genetic programs underlying both the development and the functions of the mammalian brain.

Standard name | IYENGAR_RESPONSE_TO_ADIPOCYTE_FACTORS
Systematic name | M19259
Organism | Homo sapiens
PMID | 14508521
Authors | Iyengar P,Combs TP,Shah SJ,Gouon-Evans V,Pollard JW,Albanese C,Flanagan L,Tenniswood MP,Guha C,Lisanti MP,Pestell RG,Scherer PE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) in response to growth medium from L3T3-L1 cells (differentiated to pre-adipocytes).
Full description | Mammary epithelial cells are embedded in a unique extracellular environment to which adipocytes and other stromal cells contribute. Mammary epithelial cells are critically dependent on this milieu for survival. However, it remains unknown which adipocyte-secreted factors are required for the survival of the mammary epithelia and what role these adipokines play in the process of ductal carcinoma tumorigenesis. Here, we take a systematic molecular approach to investigate the multiple ways adipocytes and adipokines can uniquely influence the characteristics and phenotypic behavior of malignant breast ductal epithelial cells. Microarray analysis and luciferase reporter assays indicate that adipokines specifically induce several transcriptional programs involved in promoting tumorigenesis, including increased cell proliferation (IGF2, FOS, JUN, cyclin D1), invasive potential (MMP1, ATF3), survival (A20, NFkappaB), and angiogenesis. One of the key changes in the transformed ductal epithelial cells associated with the cell cycle involves the induction of NFkappaB (five-fold) and cyclin D1 (three-fold). We show that by regulating the transcription of these molecules, the synergistic activity of adipocyte-derived factors can potentiate MCF-7 cell proliferation. Furthermore, compared to other stromal cell-secreted factors, the full complement of adipokines shows an unparalleled ability to promote increased cell motility, migration, and the capacity for angiogenesis. Adipocyte-secreted factors can affect tumorigenesis by increasing the stabilization of pro-oncogenic factors such as beta-catenin and CDK6 as a result of a reduction in the gene expression of their inhibitors (i.e. p18). An in vivo coinjection system using 3T3-L1 adipocytes and SUM159PT cells effectively recapitulates the host-tumor interactions in primary tumors. Type VI collagen, a soluble extracellular matrix protein abundantly expressed in adipocytes, is further upregulated in adipocytes during tumorigenesis. It promotes GSK3beta phosphorylation, beta-catenin stabilization, and increased beta-catenin activity in breast cancer cells and may critically contribute towards tumorigenesis when not counterbalanced by other factors.

Standard name | JAZAERI_BREAST_CANCER_BRCA1_VS_BRCA2_DN
Systematic name | M16561
Organism | Homo sapiens
PMID | 12096084
Authors | Jazaeri AA,Yee CJ,Sotiriou C,Brantley KR,Boyd J,Liu ET
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes distinguishing between breast cancer tumors with mutated BRCA1 [GeneID=672] from those with mutated BRCA2 [GeneID=675].
Full description | BACKGROUND: Germline mutations in BRCA1 and BRCA2 are responsible for 5%-10% of epithelial ovarian cancers, but the molecular pathways affected by these mutations are unknown. We used complementary DNA (cDNA) microarrays to compare gene expression patterns in ovarian cancers associated with BRCA1 or BRCA2 mutations with gene expression patterns in sporadic epithelial ovarian cancers and to identify patterns common to both hereditary and sporadic tumors. METHODS: Tumor samples from 61 patients with pathologically confirmed epithelial ovarian adenocarcinoma with matched clinicopathologic features were studied, including 18 with BRCA1 founder mutations, 16 with BRCA2 founder mutations, and 27 without either founder mutation (termed sporadic cancers). The cDNA microarrays contained 7651 sequence-verified features. Gene expression data were analyzed with a modified two-sided F test, with P<.0001 considered statistically significant. The expression level of six genes was also studied with reverse transcription-polymerase chain reaction. RESULTS: The greatest contrast in gene expression was observed between tumors with BRCA1 mutations and those with BRCA2 mutations; 110 genes showed statistically significantly different expression levels (P<.0001). This group of genes could segregate sporadic tumors into two subgroups, BRCA1-like and BRCA2-like, suggesting that BRCA1-related and BRCA2-related pathways are also involved in sporadic ovarian cancers. Fifty-three genes were differentially expressed between tumors with BRCA1 mutations and sporadic tumors; six of the 53 mapped to Xp11.23 and were expressed at higher levels in tumors with BRCA1 mutations than in sporadic tumors. Compared with the immortalized ovarian surface epithelial cells used as reference, several interferon-inducible genes were overexpressed in the majority of tumors with a BRCA mutation and in sporadic tumors. CONCLUSIONS: Mutations in BRCA1 and BRCA2 may lead to carcinogenesis through distinct molecular pathways that also appear to be involved in sporadic cancers. Sporadic carcinogenic pathways may result from epigenetic aberrations of BRCA1 and BRCA2 or their downstream effectors.

Standard name | BURTON_ADIPOGENESIS_10
Systematic name | M1500
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Strongly down-regulated at 8-48 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | ABE_VEGFA_TARGETS_2HR
Systematic name | M13319
Organism | Homo sapiens
PMID | 12197474
Authors | Abe M,Sato Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HUVEC cells (endothelium) at 2 h after VEGFA [GeneID=7422] stimulation.
Full description | Vascular endothelial growth factor (VEGF) is one of the most important factors that stimulate angiogenesis and vascular permeability. To clarify the role of VEGF, we analysed a human cDNA chip containing 7267 human genes to identify genes induced by VEGF in human umbilical vein endothelial cells (HUVECs). One hundred thirty-nine cDNAs, including ninety-nine previously known and forty poorly characterized or novel sequences, were increased more than two-fold by VEGF within twenty-four hours of stimulation. Among them, only five are known to regulate angiogenesis: cyclooxygenase 2 (COX2), heparin-binding epidermal growth factor-like growth factor, early growth response 1 (EGR 1), CYR61, and angiopoietin 2. Fifty-three genes induced within the first two hours were thought to be directly induced by VEGF. Of these, Down syndrome candidate region 1 (maximum induction = 6.1-fold) was the most profoundly induced, followed by Mifl (KIAA0025; 5.5-fold), COX2 (4.7-fold), EGR 3 (3.7-fold), EGR 2 (3.2-fold), bactericidal/permeability-increasing protein (3.1-fold), and CD1B antigen, b polypeptide (3.1-fold). In addition to the genes mentioned above, there were many poorly characterized or novel genes induced by VEGF. Further analysis of these genes may aid in the elucidation of the molecular mechanisms of angiogenesis or vascular permeability stimulated by VEGF.

Standard name | SUZUKI_RESPONSE_TO_TSA_AND_DECITABINE_1A
Systematic name | M1501
Organism | Homo sapiens
PMID | 11992124
Authors | Suzuki H,Gabrielson E,Chen W,Anbazhagan R,van Engeland M,Weijenberg MP,Herman JG,Baylin SB
Category | C2
Sub-category | CGP
Brief description | Genes basally silent, with hypermethylated promoters, up-regulated by the combination of TSA and decitabine [PubChem=5562;451668] in RKO cells (colorectal cancer).
Full description | Aberrant hypermethylation of gene promoters is a major mechanism associated with inactivation of tumor-suppressor genes in cancer. We previously showed this transcriptional silencing to be mediated by both methylation and histone deacetylase activity, with methylation being dominant. Here, we have used cDNA microarray analysis to screen for genes that are epigenetically silenced in human colorectal cancer. By screening over 10,000 genes, we show that our approach can identify a substantial number of genes with promoter hypermethylation in a given cancer; these are distinct from genes with unmethylated promoters, for which increased expression is produced by histone deacetylase inhibition alone. Many of the hypermethylated genes we identified have high potential for roles in tumorigenesis by virtue of their predicted function and chromosome position. We also identified a group of genes that are preferentially hypermethylated in colorectal cancer and gastric cancer. One of these genes, SFRP1, belongs to a gene family; we show that hypermethylation of four genes in this family occurs very frequently in colorectal cancer, providing for (i) a unique potential mechanism for loss of tumor-suppressor gene function and (ii) construction of a molecular marker panel that could detect virtually all colorectal cancer.

Standard name | NATSUME_RESPONSE_TO_INTERFERON_BETA_UP
Systematic name | M6897
Organism | Homo sapiens
PMID | 16140920
Authors | Natsume A,Ishii D,Wakabayashi T,Tsuno T,Hatano H,Mizuno M,Yoshida J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T98 cells (glioma) 48 h after treatment with interferon beta.
Full description | Alkylating agents, such as temozolomide, are among the most effective cytotoxic agents used for malignant gliomas, but responses remain very poor. The DNA repair protein O6-methylguanine-DNA methyltransferase (MGMT) plays an important role in cellular resistance to alkylating agents. IFN-beta can act as a drug sensitizer, enhancing toxicity against a variety of neoplasias, and is widely used in combination with other antitumor agents such as nitrosoureas. Here, we show that IFN-beta sensitizes glioma cells that harbor the unmethylated MGMT promoter and are resistant to temozolomide. By means of oligonucleotide microarray and RNA interference, we reveal that the sensitizing effect of IFN-beta was possibly due to attenuation of MGMT expression via induction of the protein p53. Our study suggests that clinical efficacy of temozolomide might be improved by combination with IFN-beta using appropriate doses and schedules of administration.

Standard name | BLALOCK_ALZHEIMERS_DISEASE_INCIPIENT_UP
Systematic name | M6520
Organism | Homo sapiens
PMID | 14769913
Authors | Blalock EM,Geddes JW,Chen KC,Porter NM,Markesbery WR,Landfield PW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in patients at the incipient stage of Alzheimer's disease.
Full description | The pathogenesis of incipient Alzheimer's disease (AD) has been resistant to analysis because of the complexity of AD and the overlap of its early-stage markers with normal aging. Gene microarrays provide new tools for addressing complexity because they allow overviews of the simultaneous activity of multiple cellular pathways. However, microarray data interpretation is often hindered by low statistical power, high false positives or false negatives, and by uncertain relevance to functional endpoints. Here, we analyzed hippocampal gene expression of nine control and 22 AD subjects of varying severity on 31 separate microarrays. We then tested the correlation of each gene's expression with MiniMental Status Examination (MMSE) and neurofibrillary tangle (NFT) scores across all 31 subjects regardless of diagnosis. These well powered tests revealed a major transcriptional response comprising thousands of genes significantly correlated with AD markers. Several hundred of these genes were also correlated with AD markers across only control and incipient AD subjects (MMSE > 20). Biological process categories associated with incipient AD-correlated genes were identified statistically (ease program) and revealed up-regulation of many transcription factor/signaling genes regulating proliferation and differentiation, including tumor suppressors, oligodendrocyte growth factors, and protein kinase A modulators. In addition, up-regulation of adhesion, apoptosis, lipid metabolism, and initial inflammation processes occurred, and down-regulation of protein folding/metabolism/transport and some energy metabolism and signaling pathways took place. These findings suggest a new model of AD pathogenesis in which a genomically orchestrated up-regulation of tumor suppressor-mediated differentiation and involution processes induces the spread of pathology along myelinated axons.

Standard name | IVANOVA_HEMATOPOIESIS_MATURE_CELL
Systematic name | M11205
Organism | Mus musculus
PMID | 12228721
Authors | Ivanova NB,Dimos JT,Schaniel C,Hackney JA,Moore KA,Lemischka IR
Category | C2
Sub-category | CGP
Brief description | Genes in the expression cluster 'MBC Shared': up-regulated in mature blood cell populations from adult bone marrow and fetal liver.
Full description | Mechanisms regulating self-renewal and cell fate decisions in mammalian stem cells are poorly understood. We determined global gene expression profiles for mouse and human hematopoietic stem cells and other stages of the hematopoietic hierarchy. Murine and human hematopoietic stem cells share a number of expressed gene products, which define key conserved regulatory pathways in this developmental system. Moreover, in the mouse, a portion of the genetic program of hematopoietic stem cells is shared with embryonic and neural stem cells. This overlapping set of gene products represents a molecular signature of stem cells.

Standard name | DAZARD_UV_RESPONSE_CLUSTER_G3
Systematic name | M8463
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Cluster G3: genes increasingly up-regulated in NHEK cells (normal keratinocyte) after 6 h time point upon UV-B irradiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | SCHLINGEMANN_SKIN_CARCINOGENESIS_TPA_UP
Systematic name | M1502
Organism | Mus musculus
PMID | 12640676
Authors | Schlingemann J,Hess J,Wrobel G,Breitenbach U,Gebhardt C,Steinlein P,Kramer H,Fürstenberger G,Hahn M,Angel P,Lichter P
Category | C2
Sub-category | CGP
Brief description | Up-regulated in murine dorsal skin cells at 6 h after treatment with the phorbol ester carcinogen TPA [PubChem=4792].
Full description | Malignant transformation of mouse skin by chemical carcinogens and tumour promoters, such as the phorbol ester 12-O-tetradecanoylphorbol-13-acetate (TPA), is a multistage process that leads to squamous cell carcinoma (SCC) formation. In an effort to identify tumour-associated genes, we studied the influence of short-term TPA-treatment on the gene expression profile of murine skin. A comprehensive microarray with some 5,000 murine gene specific cDNA fragments was established and hybridised with pooled RNA derived from control and TPA-treated dorsal skin samples. Of these genes, 54 were up- and 35 were down-regulated upon TPA application. Additionally, we performed suppression subtractive hybridisation (SSH) with respective RNA pools to generate and analyse a cDNA library enriched for TPA-inducible genes. Expression data of selected genes were confirmed by quantitative real-time PCR and Northern blot analysis. Comparison of microarray and SSH data revealed that 26% of up-regulated genes identified by expression profiling matched with those present in the SSH library. Besides numerous known genes, we identified a large set of unknown cDNAs that represent previously unrecognised TPA-regulated genes in murine skin with potential function in tumour promotion. Additionally, some TPA-induced genes, such as Sprr1A, Saa3, JunB, Il4ralpha, Gp38, RalGDS and Slpi exhibit high basal level in advanced stages of skin carcinogenesis, suggesting that at least a subgroup of the identified TPA-regulated genes may contribute to tumour progression and metastasis.

Standard name | WEBER_METHYLATED_IN_COLON_CANCER
Systematic name | M14473
Organism | Homo sapiens
PMID | 16007088
Authors | Weber M,Davies JJ,Wittig D,Oakeley EJ,Haase M,Lam WL,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Genes identified as hypermethylated in SW48 cells (colon cancer).
Full description | Cytosine methylation is required for mammalian development and is often perturbed in human cancer. To determine how this epigenetic modification is distributed in the genomes of primary and transformed cells, we used an immunocapturing approach followed by DNA microarray analysis to generate methylation profiles of all human chromosomes at 80-kb resolution and for a large set of CpG islands. In primary cells we identified broad genomic regions of differential methylation with higher levels in gene-rich neighborhoods. Female and male cells had indistinguishable profiles for autosomes but differences on the X chromosome. The inactive X chromosome (Xi) was hypermethylated at only a subset of gene-rich regions and, unexpectedly, overall hypomethylated relative to its active counterpart. The chromosomal methylation profile of transformed cells was similar to that of primary cells. Nevertheless, we detected large genomic segments with hypomethylation in the transformed cell residing in gene-poor areas. Furthermore, analysis of 6,000 CpG islands showed that only a small set of promoters was methylated differentially, suggesting that aberrant methylation of CpG island promoters in malignancy might be less frequent than previously hypothesized.

Standard name | KAAB_FAILED_HEART_ATRIUM_DN
Systematic name | M10619
Organism | Homo sapiens
PMID | 15103417
Authors | Kääb S,Barth AS,Margerie D,Dugas M,Gebauer M,Zwermann L,Merk S,Pfeufer A,Steinmeyer K,Bleich M,Kreuzer E,Steinbeck G,Näbauer M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in atria of failing hearts (DCM and ICM) compared to healthy controls.
Full description | To obtain region- and disease-specific transcription profiles of human myocardial tissue, we explored mRNA expression from all four chambers of eight explanted failing [idiopathic dilated cardiomyopathy (DCM), n=5; ischemic cardiomyopathy (ICM), n=3], and five non-failing hearts using high-density oligonucleotide arrays (Affymetrix U95Av2). We performed pair-wise comparisons of gene expression in the categories (1) atria versus ventricles, (2) disease-regulated genes in atria and (3) disease-regulated genes in ventricles. In the 51 heart samples examined, 549 genes showed divergent distribution between atria and ventricles (272 genes with higher expression in atria, 277 genes with higher expression in ventricles). Two hundred and eighty-eight genes were differentially expressed in failing myocardium compared to non-failing hearts (19 genes regulated in atria and ventricles, 172 regulated in atria only, 97 genes regulated in ventricles only). For disease-regulated genes, down-regulation was 4.5-times more common than up-regulation. Functional classification according to Gene Ontology identified specific biological patterns for differentially expressed genes. Eleven genes were validated by RT-PCR showing a good correlation with the microarray data. Our goal was to determine a gene expression fingerprint of the heart, accounting for region- and disease-specific aspects. Recognizing common gene expression patterns in heart failure will significantly contribute to the understanding of heart failure and may eventually lead to the development of pathway-specific therapies.

Standard name | SU_PANCREAS
Systematic name | M19938
Organism | Homo sapiens
PMID | 11904358
Authors | Su AI,Cooke MP,Ching KA,Hakak Y,Walker JR,Wiltshire T,Orth AP,Vega RG,Sapinoso LM,Moqrich A,Patapoutian A,Hampton GM,Schultz PG,Hogenesch JB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated specifically in human pancreas.
Full description | High-throughput gene expression profiling has become an important tool for investigating transcriptional activity in a variety of biological samples. To date, the vast majority of these experiments have focused on specific biological processes and perturbations. Here, we have generated and analyzed gene expression from a set of samples spanning a broad range of biological conditions. Specifically, we profiled gene expression from 91 human and mouse samples across a diverse array of tissues, organs, and cell lines. Because these samples predominantly come from the normal physiological state in the human and mouse, this dataset represents a preliminary, but substantial, description of the normal mammalian transcriptome. We have used this dataset to illustrate methods of mining these data, and to reveal insights into molecular and physiological gene function, mechanisms of transcriptional regulation, disease etiology, and comparative genomics. Finally, to allow the scientific community to use this resource, we have built a free and publicly accessible website (http://expression.gnf.org) that integrates data visualization and curation of current gene annotations.

Standard name | RUAN_RESPONSE_TO_TROGLITAZONE_UP
Systematic name | M1504
Organism | Mus musculus
PMID | 12732648
Authors | Ruan H,Pownall HJ,Lodish HF
Category | C2
Sub-category | CGP
Brief description | Adipocyte abundant genes up-regulated in 3T3-L1 cells (fibroblasts induced to differentiate to adipocytes) in response to troglitazone [PubChem=5591].
Full description | Troglitazone (TGZ), a member of the thiazolidinedione class of anti-diabetic compounds and a peroxisome proliferator activator receptor-gamma (PPAR-gamma) agonist, restores systemic insulin sensitivity and improves the full insulin resistance syndrome in vivo. The mechanisms underlying its in vivo function are not understood. Here we investigated the potential functional interaction between PPAR-gamma and NF-kappaB in adipocytes. We show that TGZ selectively blocked tumor necrosis factor-alpha-induced and NF-kappaB-dependent repression of multiple adipocyte-specific genes and induction of growth phase and other genes. This occurs without interfering with NF-kappaB expression, activation, nuclear translocation, or DNA binding and without suppressing NF-kappaB-dependent survival signals. Notably, the expressions of some tumor necrosis factor-alpha-induced genes in adipocytes were unaffected by PPAR-gamma activation. In reporter gene assays in HeLa cells, ectopic expression of PPAR-gamma abolished induction of a NF-kappaB-responsive reporter gene by the p65 subunit (RelA) of NF-kappaB, and the inhibition was further enhanced in the presence of TGZ. Conversely, overexpression of p65 inhibited induction of a PPAR-gamma-responsive reporter gene by activated PPAR-gamma in a dose-dependent manner. The inhibitory effect was independent of the presence of NF-kappaB-binding sites in the promoter region. Other NF-kappaB family members, p50 and c-Rel as well as the S276A mutant of p65, blocked PPAR-gamma-mediated gene transcription less effectively. Thus, p65 antagonizes the transcriptional regulatory activity of PPAR-gamma in adipocytes, and PPAR-gamma activation can at least partially override the inhibitory effects of p65 on the expression of key adipocyte genes. Our data suggest that inhibition of NF-kappaB activity is a mechanism by which PPAR-gamma agonists improve insulin sensitivity in vivo and that adipocyte NF-kappaB is a potential therapeutic target for obesity-linked type 2 diabetes.

Standard name | WU_HBX_TARGETS_2_DN
Systematic name | M17517
Organism | Homo sapiens
PMID | 11439330
Authors | Wu CG,Salvay DM,Forgues M,Valerie K,Farnsworth J,Markin RS,Wang XW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by expression of HBV X protein (HBVgp3) [GeneID=944566] in primary hepatocytes.
Full description | Hepatitis B virus (HBV) is a major risk factor for the development of hepatocellular carcinoma (HCC). HBV encodes the potentially oncogenic HBx protein, which mainly functions as a transcriptional co-activator involving in multiple gene deregulations. However, mechanisms underlying HBx-mediated oncogenicity remain unclear. To determine the role(s) of HBx in the early genesis of HCC, we utilized the NCI Oncochip microarray that contains 2208 human cDNA clones to examine the gene expression profiles in either freshly isolated normal primary adult human hepatocytes (Hhep) or an HCC cell line (SK-Hep-1) ecotopically expressing HBx via an adenoviral system. The gene expression profiles also were determined in liver samples from HBV-infected chronic active hepatitis patients when compared with normal liver samples. The microarray results were validated through Northern blot analysis of the expression of selected genes. Using reciprocally labeling hybridizations, scatterplot analysis of gene expression ratios in human primary hepatocytes expressing HBx demonstrates that microarrays are highly reproducible. The comparison of gene expression profiles between HBx-expressing primary hepatocytes and HBV-infected liver samples shows a consistent alteration of many cellular genes including a subset of oncogenes (such as c-myc and c-myb) and tumor suppressor genes (such as APC, p53, WAF1 and WT1). Furthermore, clustering algorithm analysis showed distinctive gene expression profiles in Hhep and SK-Hep-1 cells. Our findings are consistent with the hypothesis that the deregulation of cellular genes by oncogenic HBx may be an early event that favors hepatocyte proliferation during liver carcinogenesis.

Standard name | ZAMORA_NOS2_TARGETS_UP
Systematic name | M1507
Organism | Mus musculus
PMID | 12381414
Authors | Zamora R,Vodovotz Y,Aulak KS,Kim PK,Kane JM 3rd,Alarcon L,Stuehr DJ,Billiar TR
Category | C2
Sub-category | CGP
Brief description | Up-regulated in hepatocytes upon expression of NOS2 [GeneID=4843].
Full description | Nitric oxide (NO) can modulate numerous genes directly; however, some genes may be modulated only in the presence of the inflammatory stimuli that increase the expression of the inducible nitric oxide synthase (iNOS). One method by which to examine changes in NO-mediated gene expression is to carry out a gene array analysis on NO-nai;ve cells. Herein, we report a gene array analysis on mRNA from iNOS-null (iNOS(-/-)) mouse hepatocytes harvested from mice exposed to NO by infection with an adenovirus expressing human iNOS (Ad-iNOS). Of the 6500 genes on this array, only approximately 200 were modulated either up or down by the increased iNOS activity according to our criteria for significance. Several clearly defined families of genes were modulated, including genes coding for proinflammatory transcription factors, cytokines, cytokine receptors, proteins associated with cell proliferation and cellular energetics, as well as proteins involved in apoptosis. Our results suggest that iNOS has a generally anti-inflammatory and anti-apoptotic role in hepatocytes but also acts to suppress proliferation and protein synthesis. The expression of iNOS results in increased expression of stress-related proteins, including heme oxygenase-1 (HO-1). We used HO-1 to confirm that a significant change identified by an analysis could be demonstrated as significant in cells and tissues. The elevation of HO-1 was confirmed at the protein level in hepatocytes in vitro. Furthermore, iNOS(-/-) mice experienced greatly increased liver injury subsequent to intestinal ischemia/reperfusion injury, associated with an inability to upregulate HO-1. This is the first study to address the global gene changes induced by iNOS in any cell type, and the findings presented herein may have clinical relevance for conditions such as septic or hemorrhagic shock in which hepatocytes, NO, and HO-1 play a crucial role.

Standard name | JIANG_AGING_CEREBRAL_CORTEX_UP
Systematic name | M1508
Organism | Mus musculus
PMID | 11172053
Authors | Jiang CH,Tsien JZ,Schultz PG,Hu Y
Category | C2
Sub-category | CGP
Brief description | Up-regulated in the cerebral cortex of aged (22 months) BALB/c mice, compared to young (2 months) controls
Full description | A better understanding of the molecular effects of aging in the brain may help to reveal important aspects of organismal aging, as well as processes that lead to age-related brain dysfunction. In this study, we have examined differences in gene expression in the hypothalamus and cortex of young and aged mice by using high-density oligonucleotide arrays. A number of key genes involved in neuronal structure and signaling are differentially expressed in both the aged hypothalamus and cortex, including synaptotagmin I, cAMP-dependent protein kinase C beta, apolipoprotein E, protein phosphatase 2A, and prostaglandin D. Misregulation of these proteins may contribute to age-related memory deficits and neurodegenerative diseases. In addition, many proteases that play essential roles in regulating neuropeptide metabolism, amyloid precursor protein processing, and neuronal apoptosis are up-regulated in the aged brain and likely contribute significantly to brain aging. Finally, a subset of these genes whose expression is affected by aging are oppositely affected by exposure of mice to an enriched environment, suggesting that these genes may play important roles in learning and memory.

Standard name | WEIGEL_OXIDATIVE_STRESS_RESPONSE
Systematic name | M14591
Organism | Homo sapiens
PMID | 12419474
Authors | Weigel AL,Handa JT,Hjelmeland LM
Category | C2
Sub-category | CGP
Brief description | Oxidative stress genes down-regulated in ARPE-19 cells (retinal pigmented epithelium) in response to HNE, tBH and H2O2 [PubChem=5283344;6410;784].
Full description | Oxidative stress plays a key role in aging diseases of the posterior pole of the eye such as age-related macular degeneration. The oxidative stress response of in vitro RPE cells has been studied for a small number of genes. However, a comprehensive transcriptional response has yet to be elucidated. The purpose of this study was to determine if the transcription of a common set of genes is altered by exposure of ARPE-19 cells to three major generators of oxidative stress, hydrogen peroxide (H2O2), 4-hydroxynonenal (HNE), and tert-butylhydroperoxide (tBH). As expected, a common response was observed that included 35 genes differentially regulated by all three treatments. Of these, only one gene was upregulated, and only by one oxidant, while all other responses were downregulation. The majority of these genes fell into five functional categories: apoptosis, cell cycle regulation, cell-cell communication, signal transduction, and transcriptional regulation. Additionally, a large number of genes were differentially regulated by one oxidant only, including the majority of the conventional oxidative stress response genes present on the Clontech Human 1.2 microarray. This study raises questions regarding the generality of results that involve the use of a single oxidant and a single cell culture condition.

Standard name | DEBIASI_APOPTOSIS_BY_REOVIRUS_INFECTION_UP
Systematic name | M14151
Organism | Homo sapiens
PMID | 12885910
Authors | DeBiasi RL,Clarke P,Meintzer S,Jotte R,Kleinschmidt-Demasters BK,Johnson GL,Tyler KL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HEK293 cells (embryonic kidney) at 6 h, 12 h or 24 h after infection with reovirus strain T3A (known as a strong inducer of apoptosis).
Full description | Reoviruses are a leading model for understanding cellular mechanisms of virus-induced apoptosis. Reoviruses induce apoptosis in multiple cell lines in vitro, and apoptosis plays a key role in virus-induced tissue injury of the heart and brain in vivo. The activation of transcription factors NF-kappaB and c-Jun are key events in reovirus-induced apoptosis, indicating that new gene expression is critical to this process. We used high-density oligonucleotide microarrays to analyze cellular transcriptional alterations in HEK293 cells after infection with reovirus strain T3A (i.e., apoptosis inducing) compared to infection with reovirus strain T1L (i.e., minimally apoptosis inducing) and uninfected cells. These strains also differ dramatically in their potential to induce apoptotic injury in hearts of infected mice in vivo-T3A is myocarditic, whereas T1L is not. Using high-throughput microarray analysis of over 12,000 genes, we identified differential expression of a defined subset of genes involved in apoptosis and DNA repair after reovirus infection. This provides the first comparative analysis of altered gene expression after infection with viruses of differing apoptotic phenotypes and provides insight into pathogenic mechanisms of virus-induced disease.

Standard name | BRACHAT_RESPONSE_TO_CISPLATIN
Systematic name | M1509
Organism | Mus musculus
PMID | 12447701
Authors | Brachat A,Pierrat B,Xynos A,Brecht K,Simonen M,Brüngger A,Heim J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in FL5.12 cells (pro-B lymphocyte) in response to cisplatin [PubChem=2767].
Full description | DNA microarrays are powerful tools for the analysis of gene expression on a genomic scale. The importance of individual regulatory events for the process under study can however not be deduced unequivocally without additional experiments. We devised a strategy to identify central regulators of cancer drug responses by combining the results of microarray experiments with efficient methods for phenotypic testing of candidate genes. We exposed murine FL5.12 pro-B cells to cisplatin, camptothecin, methotrexate or paclitaxel, respectively and analysed the patterns of gene expression with cDNA microarrays. Drug-specific regulatory events as well as intersections between different apoptotic pathways, including previously studied responses to staurosporine and interleukin-3 (IL-3) deprivation, were identified. Genes shared by at least three pathways were chosen for further analysis. Ectopic expression of three such genes, TEAP, GP49B, and Lipin1 was found to have an anti-proliferative effect on pro-B cells. Interestingly, we identified hemoglobin alpha as a strong pro-apoptotic regulator. While hemoglobin-expressing cells were growing normally in the presence of IL-3, they displayed accelerated apoptosis with similar kinetics as Bax overexpressing cells upon IL-3 removal. The pro-apoptotic effect of hemoglobin was suppressed by Bcl-2 and was characterized by enhanced stimulation of caspase activity.

Standard name | IVANOVA_HEMATOPOIESIS_LATE_PROGENITOR
Systematic name | M11166
Organism | Mus musculus
PMID | 12228721
Authors | Ivanova NB,Dimos JT,Schaniel C,Hackney JA,Moore KA,Lemischka IR
Category | C2
Sub-category | CGP
Brief description | Genes in the expression cluster 'Late Progenitors Shared': up-regulated in hematopoietic late progenitor cells from adult bone marrow and fetal liver.
Full description | Mechanisms regulating self-renewal and cell fate decisions in mammalian stem cells are poorly understood. We determined global gene expression profiles for mouse and human hematopoietic stem cells and other stages of the hematopoietic hierarchy. Murine and human hematopoietic stem cells share a number of expressed gene products, which define key conserved regulatory pathways in this developmental system. Moreover, in the mouse, a portion of the genetic program of hematopoietic stem cells is shared with embryonic and neural stem cells. This overlapping set of gene products represents a molecular signature of stem cells.

Standard name | LU_AGING_BRAIN_DN
Systematic name | M9112
Organism | Homo sapiens
PMID | 15190254
Authors | Lu T,Pan Y,Kao SY,Li C,Kohane I,Chan J,Yankner BA
Category | C2
Sub-category | CGP
Brief description | Age down-regulated genes in the human frontal cortex.
Full description | The ageing of the human brain is a cause of cognitive decline in the elderly and the major risk factor for Alzheimer's disease. The time in life when brain ageing begins is undefined. Here we show that transcriptional profiling of the human frontal cortex from individuals ranging from 26 to 106 years of age defines a set of genes with reduced expression after age 40. These genes play central roles in synaptic plasticity, vesicular transport and mitochondrial function. This is followed by induction of stress response, antioxidant and DNA repair genes. DNA damage is markedly increased in the promoters of genes with reduced expression in the aged cortex. Moreover, these gene promoters are selectively damaged by oxidative stress in cultured human neurons, and show reduced base-excision DNA repair. Thus, DNA damage may reduce the expression of selectively vulnerable genes involved in learning, memory and neuronal survival, initiating a programme of brain ageing that starts early in adult life.

Standard name | RUAN_RESPONSE_TO_TNF_UP
Systematic name | M1512
Organism | Mus musculus
PMID | 12732648
Authors | Ruan H,Pownall HJ,Lodish HF
Category | C2
Sub-category | CGP
Brief description | Adipocyte abundant genes up-regulated in 3T3-L1 cells (fibroblasts induced to differentiate to adipocytes) in response to TNF [GeneID=7124].
Full description | Troglitazone (TGZ), a member of the thiazolidinedione class of anti-diabetic compounds and a peroxisome proliferator activator receptor-gamma (PPAR-gamma) agonist, restores systemic insulin sensitivity and improves the full insulin resistance syndrome in vivo. The mechanisms underlying its in vivo function are not understood. Here we investigated the potential functional interaction between PPAR-gamma and NF-kappaB in adipocytes. We show that TGZ selectively blocked tumor necrosis factor-alpha-induced and NF-kappaB-dependent repression of multiple adipocyte-specific genes and induction of growth phase and other genes. This occurs without interfering with NF-kappaB expression, activation, nuclear translocation, or DNA binding and without suppressing NF-kappaB-dependent survival signals. Notably, the expressions of some tumor necrosis factor-alpha-induced genes in adipocytes were unaffected by PPAR-gamma activation. In reporter gene assays in HeLa cells, ectopic expression of PPAR-gamma abolished induction of a NF-kappaB-responsive reporter gene by the p65 subunit (RelA) of NF-kappaB, and the inhibition was further enhanced in the presence of TGZ. Conversely, overexpression of p65 inhibited induction of a PPAR-gamma-responsive reporter gene by activated PPAR-gamma in a dose-dependent manner. The inhibitory effect was independent of the presence of NF-kappaB-binding sites in the promoter region. Other NF-kappaB family members, p50 and c-Rel as well as the S276A mutant of p65, blocked PPAR-gamma-mediated gene transcription less effectively. Thus, p65 antagonizes the transcriptional regulatory activity of PPAR-gamma in adipocytes, and PPAR-gamma activation can at least partially override the inhibitory effects of p65 on the expression of key adipocyte genes. Our data suggest that inhibition of NF-kappaB activity is a mechanism by which PPAR-gamma agonists improve insulin sensitivity in vivo and that adipocyte NF-kappaB is a potential therapeutic target for obesity-linked type 2 diabetes.

Standard name | WHITESIDE_CISPLATIN_RESISTANCE_UP
Systematic name | M1499
Organism | Homo sapiens
PMID | 14737109
Authors | Whiteside MA,Chen DT,Desmond RA,Abdulkadir SA,Johanning GL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NCI-H2170 cells (lung cancer) upon induction of resistance to cisplatin [PubChem=2767].
Full description | In recent years, most cDNA microarray studies of chemotherapeutic drug resistance have not considered the temporal pattern of gene expression. The objective of this study was to examine systematically changes in gene expression of NCI-H226 and NCI-H2170 lung cancer cells treated weekly with IC10 doses of cisplatin. NCI-H226 lung cancer cells were treated weekly with an IC10 dose of cisplatin. Candidate genes with a fold change of 2.0 or more were identified from this study. A second experiment was conducted by exposing NCI-H2170 cells to cisplatin doses that were increased in week 4 and decreased in week 5. Overall, 44 genes were differentially expressed in both the NCI-H226 and NCI-H2170 cell lines. In the NCI-H2170 cell line, 24 genes had a twofold gene expression change from weeks 3 to 4. Real-time PCR found a significant correlation of the gene expression changes for seven genes of interest. This small time-ordered series identified novel genes associated with cisplatin resistance. This kind of analysis should be viewed as a first step towards building gene-regulatory networks.

Standard name | LEE_CALORIE_RESTRICTION_NEOCORTEX_UP
Systematic name | M1513
Organism | Mus musculus
PMID | 10888876
Authors | Lee CK,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Up-regulated in the neocortex of aged (30-month) mice subjected to caloric restriction since young adulthood.
Full description | Ageing of the brain leads to impairments in cognitive and motor skills, and is the major risk factor for several common neurological disorders such as Alzheimer disease (AD) and Parkinson disease (PD). Recent studies suggest that normal brain ageing is associated with subtle morphological and functional alterations in specific neuronal circuits, as opposed to large-scale neuronal loss. In fact, ageing of the central nervous system in diverse mammalian species shares many features, such as atrophy of pyramidal neurons, synaptic atrophy, decrease of striatal dopamine receptors, accumulation of fluorescent pigments, cytoskeletal abnormalities, and reactive astrocytes and microglia. To provide the first global analysis of brain ageing at the molecular level, we used oligonucleotide arrays representing 6,347 genes to determine the gene-expression profile of the ageing neocortex and cerebellum in mice. Ageing resulted in a gene-expression profile indicative of an inflammatory response, oxidative stress and reduced neurotrophic support in both brain regions. At the transcriptional level, brain ageing in mice displays parallels with human neurodegenerative disorders. Caloric restriction, which retards the ageing process in mammals, selectively attenuated the age-associated induction of genes encoding inflammatory and stress responses.

Standard name | JOSEPH_RESPONSE_TO_SODIUM_BUTYRATE_DN
Systematic name | M1515
Organism | Homo sapiens
PMID | 15318170
Authors | Joseph J,Mudduluru G,Antony S,Vashistha S,Ajitkumar P,Somasundaram K
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in H460 cells (non-small cell lung carcinoma, NSCLC) after treatment with sodium butyrate [PubChem=5222465].
Full description | Histone deacetylase (HDAC) inhibitors induce growth arrest and apoptosis in a variety of human cancer cells. Sodium butyrate (NaB), a short chain fatty acid, is a HDAC inhibitor and is produced in the colonic lumen as a consequence of microbial degradation of dietary fibers. In order to dissect out the mechanism of NaB-induced growth inhibition of cancer cells, we carried out expression profiling of a human lung carcinoma cell line (H460) treated with NaB using a cDNA microarray. Of the total 1728 genes analysed, there were 32 genes with a mean expression value of 2.0-fold and higher and 66 genes with a mean expression value 3.0-fold and lower in NaB-treated cells. For a few selected genes, we demonstrate that their expression pattern by semiquantitative reverse transcription-polymerase chain reaction (RT-PCR) analysis is matching with the results obtained by microarray analysis. Closer view at the expression profile of NaB-treated cells revealed the downregulation of a total of 16 genes associated with cytokine signaling, in particular, interferon gamma (IFNgamma) pathway. In good correlation, NaB-pretreated cells failed to induce interferon regulatory factor 1, an INFgamma target gene, efficiently upon IFNgamma addition. These results suggest that NaB inhibits proinflammatory cytokine signaling pathway, thus providing proof of mechanism for its anti-inflammatory activity. We also found that NaB induced three genes, which are known metastatic suppressors, and downregulated 11 genes, which have been shown to promote metastasis. Upregulation of metastatic suppressor Kangai 1 (KAI1) by NaB in a time-dependent manner was confirmed by RT-PCR analysis. The differential regulation of metastasis-associated genes by NaB provides explanation for the anti-invasive properties of NaB. Therefore, our study presents new evidence for pathways regulated by NaB, thus providing evidence for the mechanism behind anti-inflammatory and antimetastatic activities of NaB.

Standard name | IVANOVA_HEMATOPOIESIS_STEM_CELL_LONG_TERM
Systematic name | M16407
Organism | Mus musculus
PMID | 12228721
Authors | Ivanova NB,Dimos JT,Schaniel C,Hackney JA,Moore KA,Lemischka IR
Category | C2
Sub-category | CGP
Brief description | Genes in the expression cluster 'LT-HSC Shared': up-regulated in long term hematopoietic stem cells (LT-HSC) from adult bone marrow and fetal liver.
Full description | Mechanisms regulating self-renewal and cell fate decisions in mammalian stem cells are poorly understood. We determined global gene expression profiles for mouse and human hematopoietic stem cells and other stages of the hematopoietic hierarchy. Murine and human hematopoietic stem cells share a number of expressed gene products, which define key conserved regulatory pathways in this developmental system. Moreover, in the mouse, a portion of the genetic program of hematopoietic stem cells is shared with embryonic and neural stem cells. This overlapping set of gene products represents a molecular signature of stem cells.

Standard name | WEIGEL_OXIDATIVE_STRESS_BY_HNE_AND_H2O2
Systematic name | M347
Organism | Homo sapiens
PMID | 12419474
Authors | Weigel AL,Handa JT,Hjelmeland LM
Category | C2
Sub-category | CGP
Brief description | Oxidative stress genes down-regulated in ARPE-19 cells (retinal pigmented epithelium) in response to HNE and H2O2 [PubChem=5283344;784].
Full description | Oxidative stress plays a key role in aging diseases of the posterior pole of the eye such as age-related macular degeneration. The oxidative stress response of in vitro RPE cells has been studied for a small number of genes. However, a comprehensive transcriptional response has yet to be elucidated. The purpose of this study was to determine if the transcription of a common set of genes is altered by exposure of ARPE-19 cells to three major generators of oxidative stress, hydrogen peroxide (H2O2), 4-hydroxynonenal (HNE), and tert-butylhydroperoxide (tBH). As expected, a common response was observed that included 35 genes differentially regulated by all three treatments. Of these, only one gene was upregulated, and only by one oxidant, while all other responses were downregulation. The majority of these genes fell into five functional categories: apoptosis, cell cycle regulation, cell-cell communication, signal transduction, and transcriptional regulation. Additionally, a large number of genes were differentially regulated by one oxidant only, including the majority of the conventional oxidative stress response genes present on the Clontech Human 1.2 microarray. This study raises questions regarding the generality of results that involve the use of a single oxidant and a single cell culture condition.

Standard name | HU_GENOTOXIN_ACTION_DIRECT_VS_INDIRECT_4HR
Systematic name | M1516
Organism | Mus musculus
PMID | 15120960
Authors | Hu T,Gibson DP,Carr GJ,Torontali SM,Tiesman JP,Chaney JG,Aardema MJ
Category | C2
Sub-category | CGP
Brief description | Genes discriminating between direct (cisplatin, MMS, mitomycin C [PubChem=2767;4156;5746]) and indirect (paclitaxel, hydroxyurea, etoposide [PubChem=4666;3657;36462]) acting genotoxins at 4 h time point.
Full description | During the safety evaluation process of new drugs and chemicals, a battery of genotoxicity tests is conducted starting with in vitro genotoxicity assays. Obtaining positive results in in vitro genotoxicity tests is not uncommon. Follow-up studies to determine the biological relevance of positive genotoxicity results are costly, time consuming, and utilize animals. More efficient methods, especially for identifying a putative mode of action like an indirect mechanism of genotoxicity (where DNA molecules are not the initial primary targets), would greatly improve the risk assessment for genotoxins. To this end, we are participating in an International Life Sciences Institute (ILSI) project involving studies of gene expression changes caused by model genotoxins. The purpose of the work is to evaluate gene expression tools in general, and specifically for discriminating genotoxins that are direct-acting from indirect-acting. Our lab has evaluated gene expression changes as well as micronuclei (MN) in L5178Y TK(+/-) mouse lymphoma cells treated with six compounds. Direct-acting genotoxins (where DNA is the initial primary target) that were evaluated included the DNA crosslinking agents, mitomycin C (MMC) and cisplatin (CIS), and an alkylating agent, methyl methanesulfonate (MMS). Indirect-acting genotoxins included hydroxyurea (HU), a ribonucleotide reductase inhibitor, taxol (TXL), a microtubule inhibitor, and etoposide (ETOP), a DNA topoisomerase II inhibitor. Microarray gene expression analysis was conducted using Affymetrix mouse oligonucleotide arrays on RNA samples derived from cells which were harvested immediately after the 4 h chemical treatment, and 20 h after the 4 h chemical treatment. The evaluation of these experimental results yields evidence of differentially regulated genes at both 4 and 24 h time points that appear to have discriminating power for direct versus indirect genotoxins, and therefore may serve as a fingerprint for classifying chemicals when their mechanism of action is unknown.

Standard name | ZHOU_TNF_SIGNALING_4HR
Systematic name | M1520
Organism | Homo sapiens
PMID | 12673210
Authors | Zhou A,Scoggin S,Gaynor RB,Williams NS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HeLa cells (cervical carcinoma) at 4 h after stimulation with TNF [GeneID=7124].
Full description | Tumor necrosis factor alpha (TNF alpha) is a proinflammatory cytokine with important roles in regulating inflammatory responses as well as cell cycle proliferation and apoptosis. Although TNFalpha stimulates apoptosis, it also activates the transcription factor NF-kappa B, and studies have shown that inhibition of NF-kappa B potentiates the cytotoxicity of TNFalpha. Since several chemotherapy agents act like TNFalpha to both promote apoptosis and activate NF-kappa B, understanding the role of NF-kappa B in suppressing apoptosis may have significant clinical applications. To understand the effects of stimulation with TNFalpha and the role of NF-kappa B in regulating this response, a 23k human cDNA microarray was used to screen TNFalpha-inducible genes in HeLa cells. Real-time PCR verified expression changes in 16 of these genes and revealed three distinct temporal patterns of expression after TNFalpha stimulation. Using RNA interference to disrupt expression of the p65 subunit of NF-kappa B, all but two of the genes were shown to depend on this transcription factor for their expression, which correlated well with the existence of NF-kappa B binding sites in most of their promoters. Inflammatory, proapoptotic, and antiapoptotic genes were all shown to be regulated by NF-kappa B, demonstrating the wide variety of targets activated by NF-kappa B signaling and the necessity of differentiating among these genes for therapeutic purposes.

Standard name | MARCHINI_TRABECTEDIN_RESISTANCE_UP
Systematic name | M17330
Organism | Homo sapiens
PMID | 15661559
Authors | Marchini S,Marrazzo E,Bonomi R,Chiorino G,Zaffaroni M,Weissbach L,Hornicek FJ,Broggini M,Faircloth GT,D'Incalci M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in chondrosarcoma and ovarian carcinoma cell lines which developed resistance to trabectedin [PubChem=3199].
Full description | ET-743 (Yondelis(TM), Trabectedin) isolated from the tunicate Ecteinascidia turbinata, is being tested in phase II clinical trials in Europe and the United States of America (USA). Studies with different solid tumours have shown antitumour activity in advanced, pre-treated sarcomas as well as in drug-resistant breast and ovarian cancer. The primary mechanism of action for ET-743 has not been fully elucidated and different models have been suggested to explain its molecular mechanism of action. ET-743 binds tightly to the minor groove of DNA and previous data have suggested that ET-743 acts by interfering with RNA transcription. To further investigate the mechanism of in vitro drug resistance, we evaluated the gene expression profile in ovarian and chondrosarcoma cell lines selected for resistance to ET-743. We found 70 genes whose expression was modulated in both drug-resistant cell lines when compared with their respective parental drug-sensitive cell lines. This pattern of gene expression seems to be selective for ET-743-resistant cells, since ovarian cancer cells resistant to paclitaxel did not share the same gene expression changes. Data presented in this study reveal different molecular pathways that could be involved in the cellular mechanism of ET-743 resistance.

Standard name | GENTILE_UV_LOW_DOSE_UP
Systematic name | M17864
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated in WS1 (fibroblast) in response to irradiation with low dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | BLALOCK_ALZHEIMERS_DISEASE_DN
Systematic name | M17728
Organism | Homo sapiens
PMID | 14769913
Authors | Blalock EM,Geddes JW,Chen KC,Porter NM,Markesbery WR,Landfield PW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in brain from patients with Alzheimer's disease.
Full description | The pathogenesis of incipient Alzheimer's disease (AD) has been resistant to analysis because of the complexity of AD and the overlap of its early-stage markers with normal aging. Gene microarrays provide new tools for addressing complexity because they allow overviews of the simultaneous activity of multiple cellular pathways. However, microarray data interpretation is often hindered by low statistical power, high false positives or false negatives, and by uncertain relevance to functional endpoints. Here, we analyzed hippocampal gene expression of nine control and 22 AD subjects of varying severity on 31 separate microarrays. We then tested the correlation of each gene's expression with MiniMental Status Examination (MMSE) and neurofibrillary tangle (NFT) scores across all 31 subjects regardless of diagnosis. These well powered tests revealed a major transcriptional response comprising thousands of genes significantly correlated with AD markers. Several hundred of these genes were also correlated with AD markers across only control and incipient AD subjects (MMSE > 20). Biological process categories associated with incipient AD-correlated genes were identified statistically (ease program) and revealed up-regulation of many transcription factor/signaling genes regulating proliferation and differentiation, including tumor suppressors, oligodendrocyte growth factors, and protein kinase A modulators. In addition, up-regulation of adhesion, apoptosis, lipid metabolism, and initial inflammation processes occurred, and down-regulation of protein folding/metabolism/transport and some energy metabolism and signaling pathways took place. These findings suggest a new model of AD pathogenesis in which a genomically orchestrated up-regulation of tumor suppressor-mediated differentiation and involution processes induces the spread of pathology along myelinated axons.

Standard name | BROWNE_HCMV_INFECTION_16HR_DN
Systematic name | M19130
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 16 h time point that were not down-regulated at the previous time point, 14 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | WESTON_VEGFA_TARGETS_6HR
Systematic name | M1521
Organism | Homo sapiens
PMID | 12200464
Authors | Weston GC,Haviv I,Rogers PA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MMEC cells (myometrial endothelium) at 6 h after VEGFA [GeneID=7422] stimulation.
Full description | There is evidence that the vasculature of different organs display different functional characteristics in response to cytokines and growth factors. The aim of this study was to use cDNA gene expression microarray to analyse changes in gene expression following stimulation of myometrial microvascular endothelial cells (MMECs) with vascular endothelial growth factor (VEGF). Primary isolates of MMECs were obtained from fresh hysterectomy specimens and purified with magnetic beads. Cells were stimulated with 15 ng/ml VEGF for 3, 6 and 12 h, and two unstimulated experiments served as controls. A total of six arrays was performed over these time-points. A total of 110 genes were identified as up-regulated by VEGF, 19% of which (21 genes) have previously been reported as up-regulated by VEGF or by angiogenesis. Among the novel genes to be up-regulated by VEGF were brain-derived growth factor, oxytocin receptor and estrogen sulphotransferase. The significance of the genes identified in the physiological and pathological functioning of the myometrial vasculature is discussed.

Standard name | BANDRES_RESPONSE_TO_CARMUSTIN_WITHOUT_MGMT_24HR_UP
Systematic name | M6416
Organism | Homo sapiens
PMID | 15980968
Authors | Bandres E,Andion E,Escalada A,Honorato B,Catalan V,Cubedo E,Cordeu L,Garcia F,Zarate R,Zabalegui N,Garcia-Foncillas J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A172 cells (glioma, does not express MGMT [GeneID=4255]) by carmustine [PubChem=2578] at 24 h.
Full description | Chemotherapy with the alkylating agent BCNU (1,3-bis (2-chloroethyl)-1-nitrosourea) is the most commonly used chemotherapeutic agent for gliomas. However, the usefulness of this agent is limited because tumor cell resistance to BCNU is frequently found in clinical brain tumor therapy. The O6-methylguanine-DNA methyltransferase protein (MGMT) reverses alkylation at the O6 position of guanine and we have reported the role of MGMT in the response of brain tumors to alkylating agents. However, the different mechanisms underlying the patterns related to MGMT remain unclear. To better understand the molecular mechanism by which BCNU exerts its effect in glioma cell lines according MGMT expression, we used microarray technology to interrogate 3800 known genes and determine the gene expression profiles altered by BCNU treatment. Our results showed that treatment with BCNU alters the expression of a diverse group of genes in a time-dependent manner. A subset of gene changes was found common in both glioma cell lines and other subset is specific of each cell line. After 24 h of BCNU treatment, up-regulation of transcription factors involved in the nucleation of both RNA polymerase II and III transcription initiation complexes was reported. Interestingly, BCNU promoted the expression of actin-dependent regulators of chromatin. Similar effects were found with higher BCNU doses in MGMT+ cell line showing a similar mechanism that in MGMT-deficient cell with standard doses. Our data suggest that human glioma cell lines treated with BCNU, independently of MGMT expression, show changes in the expression of cell cycle and survival-related genes interfering the transcription mechanisms and the chromatin regulation.

Standard name | RAMALHO_STEMNESS_DN
Systematic name | M12763
Organism | Mus musculus
PMID | 12228720
Authors | Ramalho-Santos M,Yoon S,Matsuzaki Y,Mulligan RC,Melton DA
Category | C2
Sub-category | CGP
Brief description | Genes depleted in embryonic, neural and hematopoietic stem cells.
Full description | The transcriptional profiles of mouse embryonic, neural, and hematopoietic stem cells were compared to define a genetic program for stem cells. A total of 216 genes are enriched in all three types of stem cells, and several of these genes are clustered in the genome. When compared to differentiated cell types, stem cells express a significantly higher number of genes (represented by expressed sequence tags) whose functions are unknown. Embryonic and neural stem cells have many similarities at the transcriptional level. These results provide a foundation for a more detailed understanding of stem cell biology.

Standard name | ONGUSAHA_TP53_TARGETS
Systematic name | M1522
Organism | Mus musculus
PMID | 12802282
Authors | Ongusaha PP,Ouchi T,Kim KT,Nytko E,Kwak JC,Duda RB,Deng CX,Lee SW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) lacking TP53 and BRCA1 [GeneID=7157;672] by expression of TP53; most genes are further up-regulated by simultaneous expression of BRCA1.
Full description | The tumor suppressor protein BRCA1 has been shown to enhance p53 transcription, whereas activated p53 represses BRCA1 transcription. To further understand the functional interaction of these proteins, we investigated the role of BRCA1 in p53-induced phenotypes. We found that BRCA1 when subjected to forced expression acts synergistically with wild-type p53, resulting in irreversible growth arrest, as shown by VhD mouse fibroblast cells expressing a temperature-sensitive mutant of p53. Furthermore, reintroduction of both BRCA1 and p53 into BRCA1(-/-)/p53(-/-) mouse embryonic fibroblasts markedly increased the senescence phenotype compared to that induced by p53 alone. In particular, we found that BRCA1 expression attenuated p53-mediated cell death in response to gamma-irradiation. Moreover, microarray screening of 11 000 murine genes demonstrated that a set of genes upregulated by p53 is enhanced by coexpression of BRCA1 and p53, suggesting that BRCA1 and p53 exert a promoter selectivity leading to a specific phenotype. Taken together, our results provide evidence that BRCA1 is involved in p53-mediated growth suppression rather than apoptosis.

Standard name | GENTILE_UV_RESPONSE_CLUSTER_D4
Systematic name | M15468
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Cluster d4: genes progressively down-regulated in WS1 cells (fibroblast) through 12 h after irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | RHODES_CANCER_META_SIGNATURE
Systematic name | M1345
Organism | Homo sapiens
PMID | 15184677
Authors | Rhodes DR,Yu J,Shanker K,Deshpande N,Varambally R,Ghosh D,Barrette T,Pandey A,Chinnaiyan AM
Category | C2
Sub-category | CGP
Brief description | Genes commonly up-regulated in cancer relative to normal tissue, according to the meta-analysis of the OncoMine gene expression database.
Full description | Many studies have used DNA microarrays to identify the gene expression signatures of human cancer, yet the critical features of these often unmanageably large signatures remain elusive. To address this, we developed a statistical method, comparative metaprofiling, which identifies and assesses the intersection of multiple gene expression signatures from a diverse collection of microarray data sets. We collected and analyzed 40 published cancer microarray data sets, comprising 38 million gene expression measurements from >3,700 cancer samples. From this, we characterized a common transcriptional profile that is universally activated in most cancer types relative to the normal tissues from which they arose, likely reflecting essential transcriptional features of neoplastic transformation. In addition, we characterized a transcriptional profile that is commonly activated in various types of undifferentiated cancer, suggesting common molecular mechanisms by which cancer cells progress and avoid differentiation. Finally, we validated these transcriptional profiles on independent data sets.

Standard name | LIAN_LIPA_TARGETS_6M
Systematic name | M4345
Organism | Mus musculus
PMID | 16127159
Authors | Lian X,Yan C,Qin Y,Knox L,Li T,Du H
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated at 6 months of age in lungs from LIPA [GeneID=3988] knockout mice, which display pulmonary pathology.
Full description | The functional roles of neutral lipids in the lung are poorly understood. However, blocking cholesteryl ester and triglyceride metabolism in lysosomal acid lipase gene knockout mice (lal-/-) results in severe pathogenic phenotypes in the lung, including massive neutrophil infiltration, foamy macrophage accumulation, unwanted cell growth, and emphysema. To elucidate the mechanism underlining these pathologies, we performed Affymetrix GeneChip microarray analysis of 1-, 3-, and 6-month-old mice and identified aberrant gene expression that progressed with age. Among changed genes, matrix metalloproteinase (MMP)-12, apoptosis inhibitor 6 (Api-6), erythroblast transformation-specific domain (Ets) transcription factor family member Spi-C, and oncogene MafB were increased 100-, 70-, 40-, and 10-fold, respectively, in lal-/- lungs versus the wild-type lungs. The pathogenic increases of these molecules occurred primarily in alveolar type II epithelial cells. Transcriptional activities of the MMP-12 and Api-6 promoters were stimulated by Spi-C or MafB in respiratory epithelial cells. Treatment with 9-hydroxyoctadecanoic acids and ciglitazone significantly rescued lal-/- pulmonary inflammation and aberrant gene expression. In addition, both compounds as well as peroxisome proliferator-activated receptor gamma inhibited MMP-12 and Api-6 promoter activities. These data suggest that inflammation-triggered cell growth and emphysema during lysosomal acid lipase deficiency are partially caused by peroxisome proliferator-activated receptor-gamma inactivation.

Standard name | WU_HBX_TARGETS_1_DN
Systematic name | M5813
Organism | Homo sapiens
PMID | 11439330
Authors | Wu CG,Salvay DM,Forgues M,Valerie K,Farnsworth J,Markin RS,Wang XW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by expression of HBV X protein (HBVgp3) [GeneID=944566] in SK-Hep-1 cells (hepatocellular carcinoma).
Full description | Hepatitis B virus (HBV) is a major risk factor for the development of hepatocellular carcinoma (HCC). HBV encodes the potentially oncogenic HBx protein, which mainly functions as a transcriptional co-activator involving in multiple gene deregulations. However, mechanisms underlying HBx-mediated oncogenicity remain unclear. To determine the role(s) of HBx in the early genesis of HCC, we utilized the NCI Oncochip microarray that contains 2208 human cDNA clones to examine the gene expression profiles in either freshly isolated normal primary adult human hepatocytes (Hhep) or an HCC cell line (SK-Hep-1) ecotopically expressing HBx via an adenoviral system. The gene expression profiles also were determined in liver samples from HBV-infected chronic active hepatitis patients when compared with normal liver samples. The microarray results were validated through Northern blot analysis of the expression of selected genes. Using reciprocally labeling hybridizations, scatterplot analysis of gene expression ratios in human primary hepatocytes expressing HBx demonstrates that microarrays are highly reproducible. The comparison of gene expression profiles between HBx-expressing primary hepatocytes and HBV-infected liver samples shows a consistent alteration of many cellular genes including a subset of oncogenes (such as c-myc and c-myb) and tumor suppressor genes (such as APC, p53, WAF1 and WT1). Furthermore, clustering algorithm analysis showed distinctive gene expression profiles in Hhep and SK-Hep-1 cells. Our findings are consistent with the hypothesis that the deregulation of cellular genes by oncogenic HBx may be an early event that favors hepatocyte proliferation during liver carcinogenesis.

Standard name | HARRIS_HYPOXIA
Systematic name | M10508
Organism | Homo sapiens
PMID | 11902584
Authors | Harris AL
Category | C2
Sub-category | CGP
Brief description | Genes known to be induced by hypoxia
Full description | Cells undergo a variety of biological responses when placed in hypoxic conditions, including activation of signalling pathways that regulate proliferation, angiogenesis and death. Cancer cells have adapted these pathways, allowing tumours to survive and even grow under hypoxic conditions, and tumour hypoxia is associated with poor prognosis and resistance to radiation therapy. Many elements of the hypoxia-response pathway are therefore good candidates for therapeutic targeting.

Standard name | RUAN_RESPONSE_TO_TNF_TROGLITAZONE_DN
Systematic name | M1524
Organism | Mus musculus
PMID | 12732648
Authors | Ruan H,Pownall HJ,Lodish HF
Category | C2
Sub-category | CGP
Brief description | Adipocyte abundant genes down-regulated in 3T3-L1 cells (fibroblasts induced to differentiate to adipocytes) in response to troglitazone [PubChem=5591] and TNF [GeneID=7124].
Full description | Troglitazone (TGZ), a member of the thiazolidinedione class of anti-diabetic compounds and a peroxisome proliferator activator receptor-gamma (PPAR-gamma) agonist, restores systemic insulin sensitivity and improves the full insulin resistance syndrome in vivo. The mechanisms underlying its in vivo function are not understood. Here we investigated the potential functional interaction between PPAR-gamma and NF-kappaB in adipocytes. We show that TGZ selectively blocked tumor necrosis factor-alpha-induced and NF-kappaB-dependent repression of multiple adipocyte-specific genes and induction of growth phase and other genes. This occurs without interfering with NF-kappaB expression, activation, nuclear translocation, or DNA binding and without suppressing NF-kappaB-dependent survival signals. Notably, the expressions of some tumor necrosis factor-alpha-induced genes in adipocytes were unaffected by PPAR-gamma activation. In reporter gene assays in HeLa cells, ectopic expression of PPAR-gamma abolished induction of a NF-kappaB-responsive reporter gene by the p65 subunit (RelA) of NF-kappaB, and the inhibition was further enhanced in the presence of TGZ. Conversely, overexpression of p65 inhibited induction of a PPAR-gamma-responsive reporter gene by activated PPAR-gamma in a dose-dependent manner. The inhibitory effect was independent of the presence of NF-kappaB-binding sites in the promoter region. Other NF-kappaB family members, p50 and c-Rel as well as the S276A mutant of p65, blocked PPAR-gamma-mediated gene transcription less effectively. Thus, p65 antagonizes the transcriptional regulatory activity of PPAR-gamma in adipocytes, and PPAR-gamma activation can at least partially override the inhibitory effects of p65 on the expression of key adipocyte genes. Our data suggest that inhibition of NF-kappaB activity is a mechanism by which PPAR-gamma agonists improve insulin sensitivity in vivo and that adipocyte NF-kappaB is a potential therapeutic target for obesity-linked type 2 diabetes.

Standard name | SU_SALIVARY_GLAND
Systematic name | M19977
Organism | Homo sapiens
PMID | 11904358
Authors | Su AI,Cooke MP,Ching KA,Hakak Y,Walker JR,Wiltshire T,Orth AP,Vega RG,Sapinoso LM,Moqrich A,Patapoutian A,Hampton GM,Schultz PG,Hogenesch JB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated specifically in human salivary gland tissue.
Full description | High-throughput gene expression profiling has become an important tool for investigating transcriptional activity in a variety of biological samples. To date, the vast majority of these experiments have focused on specific biological processes and perturbations. Here, we have generated and analyzed gene expression from a set of samples spanning a broad range of biological conditions. Specifically, we profiled gene expression from 91 human and mouse samples across a diverse array of tissues, organs, and cell lines. Because these samples predominantly come from the normal physiological state in the human and mouse, this dataset represents a preliminary, but substantial, description of the normal mammalian transcriptome. We have used this dataset to illustrate methods of mining these data, and to reveal insights into molecular and physiological gene function, mechanisms of transcriptional regulation, disease etiology, and comparative genomics. Finally, to allow the scientific community to use this resource, we have built a free and publicly accessible website (http://expression.gnf.org) that integrates data visualization and curation of current gene annotations.

Standard name | BROWNE_HCMV_INFECTION_10HR_DN
Systematic name | M8416
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 10 h time point that were not down-regulated at the previous time point, 8 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | KAYO_CALORIE_RESTRICTION_MUSCLE_DN
Systematic name | M4270
Organism | Macaca mulatta
PMID | 11309484
Authors | Kayo T,Allison DB,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Downregulated in the vastus lateralis muscle of middle aged rhesus monkeys subjected to caloric restriction since young adulthood vs age matched controls
Full description | In laboratory rodents, caloric restriction (CR) retards several age-dependent physiological and biochemical changes in skeletal muscle, including increased steady-state levels of oxidative damage to lipids, DNA, and proteins. We have previously used high-density oligonucleotide arrays to show that CR can prevent or delay most of the major age-related transcriptional alterations in the gastrocnemius muscle of C57BL/6 mice. Here we report the effects of aging and adult-onset CR on the gene expression profile of 7,070 genes in the vastus lateralis muscle from rhesus monkeys. Gene expression analysis of aged rhesus monkeys (mean age of 26 years) was compared with that of young animals (mean age of 8 years). Aging resulted in a selective up-regulation of transcripts involved in inflammation and oxidative stress, and a down-regulation of genes involved in mitochondrial electron transport and oxidative phosphorylation. Middle-aged monkeys (mean age of 20 years) subjected to CR since early adulthood (mean age of 11 years) were studied to determine the gene expression profile induced by CR. CR resulted in an up-regulation of cytoskeletal protein-encoding genes, and also a decrease in the expression of genes involved in mitochondrial bioenergetics. Surprisingly, we did not observe any evidence for an inhibitory effect of adult-onset CR on age-related changes in gene expression. These results indicate that the induction of an oxidative stress-induced transcriptional response may be a common feature of aging in skeletal muscle of rodents and primates, but the extent to which CR modifies these responses may be species-specific.

Standard name | HENDRICKS_SMARCA4_TARGETS_UP
Systematic name | M15057
Organism | Homo sapiens
PMID | 14673169
Authors | Hendricks KB,Shanahan F,Lees E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ALAB cells (breast cancer) upon reintroduction of SMARCA4 [GeneID=6597] expressed off adenoviral vector.
Full description | Human BRG1, a subunit of the Swi/Snf chromatin remodeling apparatus, has been implicated in regulation of cellular proliferation and is a candidate tumor suppressor. Reintroduction of BRG1 into a breast tumor cell line, ALAB, carrying a defined mutation in the BRG1 gene, induced growth arrest. Gene expression data revealed that the arrest may in part be accounted for by down-regulation of select E2F target genes such as cyclin E, but more dramatically, by up-regulation of mRNAs for the cyclin-dependent kinase inhibitors p21 and p15. Protein levels of both p15 and p21 were induced, and p21 protein was recruited to a complex with cyclin-dependent kinase, CDK2, to inhibit its activity. BRG1 can associate with the p21 promoter in a p53-independent manner, suggesting that the induction of p21 by BRG1 may be direct. Further, using microarray and real-time PCR analysis we identified several novel BRG1-regulated genes. Our work provides further evidence for a role for BRG1 in the regulation of several genes involved in key steps in tumorigenesis and has revealed a potential mechanism for BRG1-induced growth arrest.

Standard name | ZHENG_RESPONSE_TO_ARSENITE_DN
Systematic name | M1525
Organism | Homo sapiens
PMID | 12679051
Authors | Zheng XH,Watts GS,Vaught S,Gandolfi AJ
Category | C2
Sub-category | CGP
Brief description | Down-regulated in HEK293 cells (kidney epithelium) by treatment with sodium arsenite [PubChem=26435].
Full description | Chronic, low-level exposure to arsenic frequently results in skin, lung, bladder, and kidney cancer. Since arsenic is primarily excreted via the kidney, this study focused on this target tissue. Gene array was used as a sensitive low-level monitor of the impact of arsenic on this target tissue. Arsenite [As(III)] was chosen as the chemical species of arsenic since As(III) species are touted as the cellular toxic form of arsenic. Human embryonic kidney cell line HEK293 cells were incubated with 1, 10, and 25 microM arsenite [As(III)] for 6 or 24 h. Total RNA from treated and control cells was isolated, reverse transcribed, and labeled with Cy3 or Cy5, and hybridized to a human cDNA microarray. Hybridizations were performed four times using independent total RNA preparations to ensure reproducibility. Raw data from 10 and 25 microM treated cells exposed for 6 h was normalized within, and between, hybridizations followed by identification of genes affected by arsenite exposure based on practical significance (2-fold change up or down) and reproducibility (affected in four of six measurements). In these studies, 20 genes (HMOX1, MT1E, or FOSL1, etc.) were up-regulated, and 19 genes (MYC, JAK1, or CENPE, etc.) were down-regulated. Genes identified at 10 and 25 microM arsenic exposure were then examined after 1 microM treatment for 6 or 24 h. Expression of affected genes showed a dose-dependent (1-25 microM) trend that was apparently not time-dependent (6 vs. 24 h). The affected genes indicate that even this realistic, low-level arsenite exposure was recognized by the HEK293 cells (e.g. metallothionein genes) and produced an oxidative stress (e.g. heme oxygenase gene). These affected genes were characterized as stress response genes, proto-oncogene, signaling molecules, transcription factors, chemokine receptors, proteolytic enzymes, ESTs, and unknown genes. These findings imply that arsenite induces complex cellular injury and the cellular adaptation to As(III) is associated with alterations in the expression of many genes.

Standard name | MURAKAMI_UV_RESPONSE_6HR_DN
Systematic name | M16756
Organism | Homo sapiens
PMID | 11532376
Authors | Murakami T,Fujimoto M,Ohtsuki M,Nakagawa H
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary keratinocytes at 6 h after UVB irradiation.
Full description | Ultraviolet B irradiation initiates and promotes skin cancers, photo-aging, and immune suppression. In order to elucidate the effect of these processes at the level of gene expression, we used cDNA microarray technology to examine the effect of ultraviolet B irradiation on 588 cancer-related genes in human keratinocytes at 1, 6, and 24 h post-irradiation with a mildly cytotoxic dose of ultraviolet B (170 mJ/cm(2)). The viability of the irradiated keratinocytes was 75% at 24 h post-irradiation. Various cytokeratins and transcription factors were up-regulated within 1 h post-irradiation. After 6 h, expression of a variety of genes related to growth regulation (e.g. p21(WAF1), notch 4, and smoothened), apoptosis (e.g. caspase 10, hTRIP, and CRAF1), DNA repair (ERCC1, XRCC1), cytokines (e.g. IL-6, IL-13, TGF-beta, and endothelin 2), and cell adhesion (e.g. RhoE, and RhoGDI) were altered in human keratinocytes. These data suggest the changes in a cascade of gene expression in human keratinocytes occurring within 24 h after UVB exposure. Although the roles of these cellular genes after UVB-irradiation remain to be elucidated, microarray analysis may provide a new view of gene expression in epidermal keratinocytes following UVB exposure.

Standard name | CHEN_LVAD_SUPPORT_OF_FAILING_HEART_DN
Systematic name | M7566
Organism | Homo sapiens
PMID | 12824457
Authors | Chen Y,Park S,Li Y,Missov E,Hou M,Han X,Hall JL,Miller LW,Bache RJ
Category | C2
Sub-category | CGP
Brief description | Down-regulated genesin the left ventricle myocardium of patients with heart failure following implantation of LVAD (left ventricular assist device).
Full description | Chronic unloading of the failing heart with a left ventricular assist device (LVAD) can decrease cardiac mass and myocyte size and has the potential to improve contractile function. To study the effect of chronic ventricular unloading on myocardial gene expression, a microarray (U133A, Affymetrix) profiling gene expression was compared before and after LVAD support in seven patients with idiopathic dilated cardiomyopathy and end-stage heart failure. On average, 1,374 +/- 155 genes were reported as increased and 1,629 +/- 45 as decreased after LVAD support. A total of 130 gene transcripts achieved the strict criteria for upregulation and 49 gene transcripts for downregulation after LVAD support. Upregulated genes included a large proportion of transcription factors, genes related to cell growth/apoptosis/DNA repair, cell structure proteins, metabolism, and cell signaling/communication. LVAD support resulted in downregulation of genes for a group of cytokines. To validate the array data, 10 altered genes were confirmed by real-time RT-PCR. Further study showed that the phosphoinositide-3-kinase-forkhead protein pathway and proteins related to nitric oxide synthesis, including eNOS and dimethylarginine dimethylaminohydrolase isoform 1 (DDAH1, an enzyme regulating endogenous nitric oxide synthase activity), were significantly increased during the cardiac remodeling process. Increased eNOS and DDAH1 expression after LVAD support may contribute to improved endothelial function of the failing hearts.

Standard name | RAMALHO_STEMNESS_UP
Systematic name | M9473
Organism | Mus musculus
PMID | 12228720
Authors | Ramalho-Santos M,Yoon S,Matsuzaki Y,Mulligan RC,Melton DA
Category | C2
Sub-category | CGP
Brief description | Genes enriched in embryonic, neural and hematopoietic stem cells.
Full description | The transcriptional profiles of mouse embryonic, neural, and hematopoietic stem cells were compared to define a genetic program for stem cells. A total of 216 genes are enriched in all three types of stem cells, and several of these genes are clustered in the genome. When compared to differentiated cell types, stem cells express a significantly higher number of genes (represented by expressed sequence tags) whose functions are unknown. Embryonic and neural stem cells have many similarities at the transcriptional level. These results provide a foundation for a more detailed understanding of stem cell biology.

Standard name | MARIADASON_RESPONSE_TO_CURCUMIN_SULINDAC_7
Systematic name | M1526
Organism | Homo sapiens
PMID | 10969808
Authors | Mariadason JM,Corner GA,Augenlicht LH
Category | C2
Sub-category | CGP
Brief description | Cluster 7: genes up-regulated in SW260 cells (colon cancer) by curcumin and sulindac [PubChem=969516;5352].
Full description | The short-chain fatty acid butyrate, produced by microbial fermentation of dietary fiber in the large intestine, is a physiological regulator of major pathways of colonic epithelial cell maturation: cell cycle arrest, lineage-specific differentiation, and apoptosis. Microarray analysis of 8,063 sequences demonstrated a complex cascade of reprogramming of SW620 colonic epithelial cells upon treatment with butyrate characterized by the progressive recruitment of gene sets as a function of time. Comparison with the effects of trichostatin A, in conjunction with differences in the kinetics of alteration of histone acetylation induced by butyrate and trichostatin A, identified subsets of induced and repressed genes likely coordinately regulated by altered histone acetylation. The butyrate response was also compared in detail with that of sulindac, a nonsteroidal anti-inflammatory drug with significant chemopreventive activity for colon cancer, and curcumin, a component of mustard and curry structurally and functionally related to sulindac that also has chemopreventive activity. Although gene clusters were identified that showed similar responses to butyrate and sulindac, the data were characterized by the extensive differences in the effects of the two agents. This was striking for functional classes of genes involved in signaling pathways and in cell cycle progression, although butyrate and sulindac induce a similar G0-G1 arrest, elevation of beta-catenin-Tcf signaling, and apoptotic cascade. As regards cell cycle arrest, the underlying mechanism in response to butyrate was most similar to that of the Caco-2 cell line that had spontaneously undergone a G0-G1 arrest and least similar to the G2-M arrest stimulated by curcumin. Thus, high-throughput microarray analysis of gene expression profiles can be used to characterize and distinguish the mechanisms of response of colonic epithelial cells to physiological and pharmacological inducers of cell maturation. This has important implications for characterization of chemopreventive agents and recognition of potential toxicity and synergies. The data bases, gene clusters, and analyses are available at http:// sequence.aecom.yu.edu/genome/.

Standard name | MCDOWELL_ACUTE_LUNG_INJURY_UP
Systematic name | M1527
Organism | Mus musculus
PMID | 12540486
Authors | McDowell SA,Gammon K,Zingarelli B,Bachurski CJ,Aronow BJ,Prows DR,Leikauf GD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the mouse model of acute lung injury induced by inhaling nickel sulfate [PubChem=24586].
Full description | The role of nitric oxide (NO) in acute lung injury remains controversial. Although inhaled NO increases oxygenation in clinical trials, inhibiting NO-synthase (NOS) can be protective. To examine the latter, nickel-exposed mice were treated with saline or NOS inhibitor, N(G)-nitro-L-arginine methyl ester (L-NAME). Initial microarray analysis of nickel-induced gene expression of saline-treated mice revealed increased inflammatory mediator, matrix injury-repair, and hypoxia-induced factor-mediated sequences and decreased lung-specific (e.g., surfactant-associated protein B and C) sequences. Compared with saline control, L-NAME-treated mice had enhanced survival with attenuated serum nitrate/nitrite, endothelial NOS activity, and lavage neutrophils and protein. Although initial cytokine (i.e., interferon-gamma, interleukins-1beta and -6, macrophage inflammatory protein-2, monocyte chemotactic protein-1, and tumor necrosis factor-alpha) gene expression was similar between groups, subsequent larger cytokine increases only occurred in saline-treated mice. Similarly, surfactant protein gene expression decreased initially in both groups yet was restored subsequently with L-NAME treatment. Interestingly, the role of inducible NOS (iNOS) in these responses seems minimal. iNOS gene expression was unaltered, iNOS activity and nitrotyrosine residues were undetectable, and an iNOS antagonist, aminoguanidine, failed to increase survival. Rather, systemic L-NAME treatment appears to attenuate pulmonary endothelial NOS activity, subsequent cytokine expression, inflammation, and protein permeability, and thereby restores surfactant gene expression and increases survival.

Standard name | SESTO_RESPONSE_TO_UV_C4
Systematic name | M9634
Organism | Homo sapiens
PMID | 11867738
Authors | Sesto A,Navarro M,Burslem F,Jorcano JL
Category | C2
Sub-category | CGP
Brief description | Cluster 4: genes changed in primary keratinocytes by UVB irradiation.
Full description | UV radiation is the most important environmental skin aggressor, causing cancer and other problems. This paper reports the use of oligonucleotide microarray technology to determine changes in gene expression in human keratinocytes after UVB treatment. Examination of the effects of different doses at different times after irradiation gave a global picture of the keratinocyte response to this type of insult. Five hundred thirty-nine regulated transcripts were found and organized into nine different clusters depending on behavior patterns. Classification of these genes into 23 functional categories revealed that several biological processes are globally affected by UVB. In addition to confirming a majority up-regulation of the transcripts related to the UV-specific inflammatory and stress responses, significant increases were seen in the expression of genes involved in basal transcription, splicing, and translation as well as in the proteasome-mediated degradation category. On the other hand, those transcripts belonging to the metabolism and adhesion categories were strongly downregulated. These results demonstrate the complexity of the transcriptional profile of the UVB response, describe several cellular processes previously not known to be affected by UV irradiation, and serve as a basis for the global characterization of UV-regulated genes and pathways.

Standard name | WANG_SMARCE1_TARGETS_DN
Systematic name | M4780
Organism | Homo sapiens
PMID | 16135788
Authors | Wang L,Baiocchi RA,Pal S,Mosialos G,Caligiuri M,Sif S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in BT549 cells (breast cancer) by expression of SMARCE1 [GeneID=6605] off a retroviral vector.
Full description | Mutation of BRG1, hBRM, and their associated factors, INI1 and BAF57, in primary human tumors has suggested that inactivation of human SWI/SNF (hSWI/SNF) complexes may be involved in neoplastic transformation. BT549 is an invasive human breast carcinoma cell line that lacks expression of BAF57, a key hSWI/SNF subunit that mediates interaction with transcriptional activators and corepressors. In this study we investigated the role of BAF57 in suppressing tumorigenesis by establishing BT549 stable cell lines that expresses full-length BAF57 protein. BT549 clones expressing BAF57 demonstrated marked phenotypic changes, slow growth kinetics, and restoration of contact inhibition. Altered growth was found to be due in part to cell cycle arrest and induction of apoptosis. Furthermore, microarray analysis revealed that BAF57-mediated cell death was associated with up-regulation of proapoptotic genes including the tumor suppressor familial cylindromatosis (CYLD), which was found to be a direct target of BAF57 as determined by chromatin immunoprecipitation analysis. Increased expression of CYLD in BT549 cells induced apoptosis, while its suppression by small interfering RNA inhibited cell death in BAF57 expressing BT549 cells. These findings demonstrate the importance of BAF57 in cell growth regulation and provide a novel link between hSWI/SNF chromatin remodelers and apoptosis.

Standard name | SU_TESTIS
Systematic name | M9746
Organism | Homo sapiens
PMID | 11904358
Authors | Su AI,Cooke MP,Ching KA,Hakak Y,Walker JR,Wiltshire T,Orth AP,Vega RG,Sapinoso LM,Moqrich A,Patapoutian A,Hampton GM,Schultz PG,Hogenesch JB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated specifically in human testis tissue.
Full description | High-throughput gene expression profiling has become an important tool for investigating transcriptional activity in a variety of biological samples. To date, the vast majority of these experiments have focused on specific biological processes and perturbations. Here, we have generated and analyzed gene expression from a set of samples spanning a broad range of biological conditions. Specifically, we profiled gene expression from 91 human and mouse samples across a diverse array of tissues, organs, and cell lines. Because these samples predominantly come from the normal physiological state in the human and mouse, this dataset represents a preliminary, but substantial, description of the normal mammalian transcriptome. We have used this dataset to illustrate methods of mining these data, and to reveal insights into molecular and physiological gene function, mechanisms of transcriptional regulation, disease etiology, and comparative genomics. Finally, to allow the scientific community to use this resource, we have built a free and publicly accessible website (http://expression.gnf.org) that integrates data visualization and curation of current gene annotations.

Standard name | TRAYNOR_RETT_SYNDROM_DN
Systematic name | M1227
Organism | Homo sapiens
PMID | 12418965
Authors | Traynor J,Agarwal P,Lazzeroni L,Francke U
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblasts from Rett syndrom patients who carry mutations inactivating MECP2 [GeneID=4204].
Full description | BACKGROUND: Females with the neurological disorder Rett syndrome are heterozygous for mutations in X-linked MECP2 that encodes methyl-CpG binding protein 2 (MeCP2) thought to act as a transcriptional repressor. To identify target genes for MeCP2 modulation, we studied global gene expression in single cell-derived wild-type and mutant MECP2 expressing fibroblast clones with four common mutations (R106W, R306C, 705delG, 1155del32) and in lymphoblastoid cell lines (LCLs) that included four mutant MeCP2 (T158M, 803delG, R168X and 1159del28) expressing, and five (1159del28, R106W, R255X, 803delG, 803delG) wild-type MeCP2 expressing lines. METHODS: Clonality and mutation status were verified by androgen receptor methylation assays for X-inactivation and by sequencing MECP2 transcripts. Expression studies were done with oligonucleotide microarrays (Affymetrix U95) and verified with real-time quantitative RT-PCR using Sybr Green. RESULTS: Expression of 49 transcripts was increased, and expression of 21 transcripts was decreased, in at least 3 of 4 mutant/wild-type fibroblast comparisons. Transcript levels of 11 genes, determined by quantitative RT-PCR, were highly correlated with the microarray data. Therefore, multiple additional clones from two Rett individuals were tested by RT-PCR only. Striking expression differences were found in both mutant and wildtype MeCP2 expressing clones. Comparing expression profiles of lymphoblastoid cell lines yielded 16 differentially expressed genes. CONCLUSIONS: MeCP2 deficiency does not lead to global deregulation of gene expression. Either MeCP2's in vivo function does not involve widespread transcriptional repression, or its function is redundant in cell types that also express other methyl-CpG binding proteins. Our data suggest that clonal fibroblast strains may show substantial inter-strain variation, making them a difficult and unstable resource for genome-wide expression profiling studies.

Standard name | SESTO_RESPONSE_TO_UV_C6
Systematic name | M4229
Organism | Homo sapiens
PMID | 11867738
Authors | Sesto A,Navarro M,Burslem F,Jorcano JL
Category | C2
Sub-category | CGP
Brief description | Cluster 6: genes changed in primary keratinocytes by UVB irradiation.
Full description | UV radiation is the most important environmental skin aggressor, causing cancer and other problems. This paper reports the use of oligonucleotide microarray technology to determine changes in gene expression in human keratinocytes after UVB treatment. Examination of the effects of different doses at different times after irradiation gave a global picture of the keratinocyte response to this type of insult. Five hundred thirty-nine regulated transcripts were found and organized into nine different clusters depending on behavior patterns. Classification of these genes into 23 functional categories revealed that several biological processes are globally affected by UVB. In addition to confirming a majority up-regulation of the transcripts related to the UV-specific inflammatory and stress responses, significant increases were seen in the expression of genes involved in basal transcription, splicing, and translation as well as in the proteasome-mediated degradation category. On the other hand, those transcripts belonging to the metabolism and adhesion categories were strongly downregulated. These results demonstrate the complexity of the transcriptional profile of the UVB response, describe several cellular processes previously not known to be affected by UV irradiation, and serve as a basis for the global characterization of UV-regulated genes and pathways.

Standard name | MCCLUNG_CREB1_TARGETS_DN
Systematic name | M3576
Organism | Mus musculus
PMID | 14566342
Authors | McClung CA,Nestler EJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the nucleus accumbens (a major reward center in the brain) 8 weeks after induction of CREB1 [GeneID=1385] expression in a transgenic Tet-Off system.
Full description | DeltaFosB (a truncated form of FosB) and CREB (cAMP response element binding protein) are transcription factors induced in the brain's reward pathways after chronic exposure to drugs of abuse. However, their mechanisms of action and the genes they regulate remain unclear. Using microarray analysis in the nucleus accumbens of inducible transgenic mice, we found that CREB and a dominant-negative CREB have opposite effects on gene expression, as do prolonged expression of DeltaFosB and the activator protein-1 (AP-1) antagonist DeltacJun. However, unlike CREB, short-term and prolonged DeltaFosB induction had opposing effects on gene expression. Gene expression induced by short-term DeltaFosB and by CREB was strikingly similar, and both reduced the rewarding effects of cocaine, whereas prolonged DeltaFosB expression increased drug reward. Gene expression after a short cocaine treatment was more dependent on CREB, whereas gene expression after a longer cocaine treatment became increasingly DeltaFosB dependent. These findings help define the molecular functions of CREB and DeltaFosB and identify clusters of genes that contribute to cocaine addiction.

Standard name | RODWELL_AGING_KIDNEY_NO_BLOOD_DN
Systematic name | M11837
Organism | Homo sapiens
PMID | 15562319
Authors | Rodwell GE,Sonu R,Zahn JM,Lund J,Wilhelmy J,Wang L,Xiao W,Mindrinos M,Crane E,Segal E,Myers BD,Brooks JD,Davis RW,Higgins J,Owen AB,Kim SK
Category | C2
Sub-category | CGP
Brief description | Genes whose expression decreases with age in normal kidney, excluding those with higher expression in blood.
Full description | In this study, we found 985 genes that change expression in the cortex and the medulla of the kidney with age. Some of the genes whose transcripts increase in abundance with age are known to be specifically expressed in immune cells, suggesting that immune surveillance or inflammation increases with age. The age-regulated genes show a similar aging profile in the cortex and the medulla, suggesting a common underlying mechanism for aging. Expression profiles of these age-regulated genes mark not only age, but also the relative health and physiology of the kidney in older individuals. Finally, the set of aging-regulated kidney genes suggests specific mechanisms and pathways that may play a role in kidney degeneration with age.

Standard name | SUZUKI_RESPONSE_TO_TSA_AND_DECITABINE_1B
Systematic name | M1530
Organism | Homo sapiens
PMID | 11992124
Authors | Suzuki H,Gabrielson E,Chen W,Anbazhagan R,van Engeland M,Weijenberg MP,Herman JG,Baylin SB
Category | C2
Sub-category | CGP
Brief description | Genes with some basal expression and partially methylated promoters, up-regulated by the combination of TSA and decitabine [PubChem=5562;451668] in RKO cells (colorectal cancer).
Full description | Aberrant hypermethylation of gene promoters is a major mechanism associated with inactivation of tumor-suppressor genes in cancer. We previously showed this transcriptional silencing to be mediated by both methylation and histone deacetylase activity, with methylation being dominant. Here, we have used cDNA microarray analysis to screen for genes that are epigenetically silenced in human colorectal cancer. By screening over 10,000 genes, we show that our approach can identify a substantial number of genes with promoter hypermethylation in a given cancer; these are distinct from genes with unmethylated promoters, for which increased expression is produced by histone deacetylase inhibition alone. Many of the hypermethylated genes we identified have high potential for roles in tumorigenesis by virtue of their predicted function and chromosome position. We also identified a group of genes that are preferentially hypermethylated in colorectal cancer and gastric cancer. One of these genes, SFRP1, belongs to a gene family; we show that hypermethylation of four genes in this family occurs very frequently in colorectal cancer, providing for (i) a unique potential mechanism for loss of tumor-suppressor gene function and (ii) construction of a molecular marker panel that could detect virtually all colorectal cancer.

Standard name | SESTO_RESPONSE_TO_UV_C2
Systematic name | M2589
Organism | Homo sapiens
PMID | 11867738
Authors | Sesto A,Navarro M,Burslem F,Jorcano JL
Category | C2
Sub-category | CGP
Brief description | Cluster 2: genes changed in primary keratinocytes by UVB irradiation.
Full description | UV radiation is the most important environmental skin aggressor, causing cancer and other problems. This paper reports the use of oligonucleotide microarray technology to determine changes in gene expression in human keratinocytes after UVB treatment. Examination of the effects of different doses at different times after irradiation gave a global picture of the keratinocyte response to this type of insult. Five hundred thirty-nine regulated transcripts were found and organized into nine different clusters depending on behavior patterns. Classification of these genes into 23 functional categories revealed that several biological processes are globally affected by UVB. In addition to confirming a majority up-regulation of the transcripts related to the UV-specific inflammatory and stress responses, significant increases were seen in the expression of genes involved in basal transcription, splicing, and translation as well as in the proteasome-mediated degradation category. On the other hand, those transcripts belonging to the metabolism and adhesion categories were strongly downregulated. These results demonstrate the complexity of the transcriptional profile of the UVB response, describe several cellular processes previously not known to be affected by UV irradiation, and serve as a basis for the global characterization of UV-regulated genes and pathways.

Standard name | KAAB_HEART_ATRIUM_VS_VENTRICLE_UP
Systematic name | M10952
Organism | Homo sapiens
PMID | 15103417
Authors | Kääb S,Barth AS,Margerie D,Dugas M,Gebauer M,Zwermann L,Merk S,Pfeufer A,Steinmeyer K,Bleich M,Kreuzer E,Steinbeck G,Näbauer M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the atria of healthy hearts, compared to venticles.
Full description | To obtain region- and disease-specific transcription profiles of human myocardial tissue, we explored mRNA expression from all four chambers of eight explanted failing [idiopathic dilated cardiomyopathy (DCM), n=5; ischemic cardiomyopathy (ICM), n=3], and five non-failing hearts using high-density oligonucleotide arrays (Affymetrix U95Av2). We performed pair-wise comparisons of gene expression in the categories (1) atria versus ventricles, (2) disease-regulated genes in atria and (3) disease-regulated genes in ventricles. In the 51 heart samples examined, 549 genes showed divergent distribution between atria and ventricles (272 genes with higher expression in atria, 277 genes with higher expression in ventricles). Two hundred and eighty-eight genes were differentially expressed in failing myocardium compared to non-failing hearts (19 genes regulated in atria and ventricles, 172 regulated in atria only, 97 genes regulated in ventricles only). For disease-regulated genes, down-regulation was 4.5-times more common than up-regulation. Functional classification according to Gene Ontology identified specific biological patterns for differentially expressed genes. Eleven genes were validated by RT-PCR showing a good correlation with the microarray data. Our goal was to determine a gene expression fingerprint of the heart, accounting for region- and disease-specific aspects. Recognizing common gene expression patterns in heart failure will significantly contribute to the understanding of heart failure and may eventually lead to the development of pathway-specific therapies.

Standard name | HU_GENOTOXIC_DAMAGE_24HR
Systematic name | M1531
Organism | Mus musculus
PMID | 15120960
Authors | Hu T,Gibson DP,Carr GJ,Torontali SM,Tiesman JP,Chaney JG,Aardema MJ
Category | C2
Sub-category | CGP
Brief description | Genes most consistently regulated at 24 h by all six genotoxins tested: cisplatin, methyl methanesulfonate, mitomycin C, taxol, hydroxyurea and etoposide [PubChem=2767;4156;5746;4666;3657;36462].
Full description | During the safety evaluation process of new drugs and chemicals, a battery of genotoxicity tests is conducted starting with in vitro genotoxicity assays. Obtaining positive results in in vitro genotoxicity tests is not uncommon. Follow-up studies to determine the biological relevance of positive genotoxicity results are costly, time consuming, and utilize animals. More efficient methods, especially for identifying a putative mode of action like an indirect mechanism of genotoxicity (where DNA molecules are not the initial primary targets), would greatly improve the risk assessment for genotoxins. To this end, we are participating in an International Life Sciences Institute (ILSI) project involving studies of gene expression changes caused by model genotoxins. The purpose of the work is to evaluate gene expression tools in general, and specifically for discriminating genotoxins that are direct-acting from indirect-acting. Our lab has evaluated gene expression changes as well as micronuclei (MN) in L5178Y TK(+/-) mouse lymphoma cells treated with six compounds. Direct-acting genotoxins (where DNA is the initial primary target) that were evaluated included the DNA crosslinking agents, mitomycin C (MMC) and cisplatin (CIS), and an alkylating agent, methyl methanesulfonate (MMS). Indirect-acting genotoxins included hydroxyurea (HU), a ribonucleotide reductase inhibitor, taxol (TXL), a microtubule inhibitor, and etoposide (ETOP), a DNA topoisomerase II inhibitor. Microarray gene expression analysis was conducted using Affymetrix mouse oligonucleotide arrays on RNA samples derived from cells which were harvested immediately after the 4 h chemical treatment, and 20 h after the 4 h chemical treatment. The evaluation of these experimental results yields evidence of differentially regulated genes at both 4 and 24 h time points that appear to have discriminating power for direct versus indirect genotoxins, and therefore may serve as a fingerprint for classifying chemicals when their mechanism of action is unknown.

Standard name | CUI_TCF21_TARGETS_UP
Systematic name | M7883
Organism | Mus musculus
PMID | 16207825
Authors | Cui S,Li C,Ema M,Weinstein J,Quaggin SE
Category | C2
Sub-category | CGP
Brief description | Genes most strongly up-regulated in kidney glomeruli isolated from TCF21 [GeneID=6943] knockout mice.
Full description | Mouse mutations have provided tremendous insights into the molecular basis of renal and glomerular development. However, genes often play important roles during multiple stages of nephrogenesis, making it difficult to determine the role of a gene in a specific cell lineage such as the podocyte. Conditional gene targeting and chimeric analysis are two possible approaches to dissect the function of genes in specific cell populations. However, these are labor-intensive and costly and require the generation, validation, and analysis of additional transgenic lines. For overcoming these shortcomings and, specifically, for studying the role of gene function in developing glomeruli, a technique to isolate and purify glomeruli from murine embryos was developed. Combined with gene expression profiling, this method was used to identify differentially expressed genes in glomeruli from Pod1 knockout (KO) mice that die in the perinatal period with multiple renal defects. Glomeruli from early developing stages (late S-shape/early capillary loop) onward can be isolated successfully from wild-type and KO kidneys at 18.5 d postcoitus, and RNA can readily be obtained and used for genome-wide microarray analysis. With this approach, 3986 genes that are differently expressed between glomeruli from Pod1 KO and wild-type mice were identified, including a four-fold reduction of alpha 8 integrin mRNA in glomeruli from Pod1 KO mice that was confirmed by immunostaining. This procedure may be adapted to any transgenic strain, providing a rapid and efficient method to dissect the function of specific genes in glomerular development.

Standard name | HEDENFALK_BREAST_CANCER_BRACX_UP
Systematic name | M6669
Organism | Homo sapiens
PMID | 12610208
Authors | Hedenfalk I,Ringner M,Ben-Dor A,Yakhini Z,Chen Y,Chebil G,Ach R,Loman N,Olsson H,Meltzer P,Borg A,Trent J
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes distinguishing between two groups of non-BRCA1/BRCA2 [GeneID=672;675] breast tumors (BRACx): group A vs group B.
Full description | In the decade since their discovery, the two major breast cancer susceptibility genes BRCA1 and BRCA2, have been shown conclusively to be involved in a significant fraction of families segregating breast and ovarian cancer. However, it has become equally clear that a large proportion of families segregating breast cancer alone are not caused by mutations in BRCA1 or BRCA2. Unfortunately, despite intensive effort, the identification of additional breast cancer predisposition genes has so far been unsuccessful, presumably because of genetic heterogeneity, low penetrance, or recessive/polygenic mechanisms. These non-BRCA1/2 breast cancer families (termed BRCAx families) comprise a histopathologically heterogeneous group, further supporting their origin from multiple genetic events. Accordingly, the identification of a method to successfully subdivide BRCAx families into recognizable groups could be of considerable value to further genetic analysis. We have previously shown that global gene expression analysis can identify unique and distinct expression profiles in breast tumors from BRCA1 and BRCA2 mutation carriers. Here we show that gene expression profiling can discover novel classes among BRCAx tumors, and differentiate them from BRCA1 and BRCA2 tumors. Moreover, microarray-based comparative genomic hybridization (CGH) to cDNA arrays revealed specific somatic genetic alterations within the BRCAx subgroups. These findings illustrate that, when gene expression-based classifications are used, BRCAx families can be grouped into homogeneous subsets, thereby potentially increasing the power of conventional genetic analysis.

Standard name | GEISS_RESPONSE_TO_DSRNA_DN
Systematic name | M19944
Organism | Homo sapiens
PMID | 11487589
Authors | Geiss G,Jin G,Guo J,Bumgarner R,Katze MG,Sen GC
Category | C2
Sub-category | CGP
Brief description | Genes down-pregulated by dsRNA in GRE cells (glioma; no interferon system).
Full description | Double-stranded (ds) RNA, a common component of virus-infected cells, is a potent inducer of the type I interferon and other cellular genes. For identifying the full repertoire of human dsRNA-regulated genes, a cDNA microarray hybridization screening was conducted using mRNA from dsRNA-treated GRE cells. Because these cells lack all type I interferon genes, the possibility of gene induction by autocrine actions of interferon was eliminated. Our screen identified 175 dsRNA-stimulated genes (DSG) and 95 dsRNA-repressed genes. A subset of the DSGs was also induced by different inflammatory cytokines and viruses demonstrating interconnections among disparate signaling pathways. Functionally, the DSGs encode proteins involved in signaling, apoptosis, RNA synthesis, protein synthesis and processing, cell metabolism, transport, and structure. Induction of such a diverse family of genes by dsRNA has major implications in host-virus interactions and in the use of RNA(i) technology for functional ablation of specific genes.

Standard name | CUI_TCF21_TARGETS_2_DN
Systematic name | M1533
Organism | Mus musculus
PMID | 16207825
Authors | Cui S,Li C,Ema M,Weinstein J,Quaggin SE
Category | C2
Sub-category | CGP
Brief description | All significantly down-regulated genes in kidney glomeruli isolated from TCF21 [Gene ID=6943] knockout mice.
Full description | Mouse mutations have provided tremendous insights into the molecular basis of renal and glomerular development. However, genes often play important roles during multiple stages of nephrogenesis, making it difficult to determine the role of a gene in a specific cell lineage such as the podocyte. Conditional gene targeting and chimeric analysis are two possible approaches to dissect the function of genes in specific cell populations. However, these are labor-intensive and costly and require the generation, validation, and analysis of additional transgenic lines. For overcoming these shortcomings and, specifically, for studying the role of gene function in developing glomeruli, a technique to isolate and purify glomeruli from murine embryos was developed. Combined with gene expression profiling, this method was used to identify differentially expressed genes in glomeruli from Pod1 knockout (KO) mice that die in the perinatal period with multiple renal defects. Glomeruli from early developing stages (late S-shape/early capillary loop) onward can be isolated successfully from wild-type and KO kidneys at 18.5 d postcoitus, and RNA can readily be obtained and used for genome-wide microarray analysis. With this approach, 3986 genes that are differently expressed between glomeruli from Pod1 KO and wild-type mice were identified, including a four-fold reduction of alpha 8 integrin mRNA in glomeruli from Pod1 KO mice that was confirmed by immunostaining. This procedure may be adapted to any transgenic strain, providing a rapid and efficient method to dissect the function of specific genes in glomerular development.

Standard name | VIETOR_IFRD1_TARGETS
Systematic name | M1534
Organism | Mus musculus
PMID | 12198164
Authors | Vietor I,Vadivelu SK,Wick N,Hoffman R,Cotten M,Seiser C,Fialka I,Wunderlich W,Haase A,Korinkova G,Brosch G,Huber LA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in c-JunER cells (mammary gland epithelum) by overexpression of IFRD1 [GeneID=3475] off an adenovirus vector.
Full description | The mammalian SIN3 complex consists of histone deacetylases (HDAC1, HDAC2), several known proteins (SAP30, N-CoR) and as yet unidentified proteins. Here we show that the mouse tetradecanoyl phorbol acetate induced sequence 7 (TIS7) protein is a novel transcriptional co-repressor that can associate with the SIN3 complex. We have identified tis7 as a gene that is up-regulated upon loss of polarity in a mouse mammary gland epithelial cell line expressing an estrogen-inducible c-JunER fusion protein. In unpolarized cells, TIS7 protein levels increase and TIS7 translocates into the nucleus. Overexpression of tis7 causes loss of polarity and represses a set of genes, as revealed by cDNA microarray analysis. We have shown that TIS7 protein interacts with several proteins of the SIN3 complex (mSin3B, HDAC1, N-CoR and SAP30) by yeast two-hybrid screening and co-immunoprecipitations. TIS7 co-immunoprecipitated HDAC complex is enzymatically active and represses a GAL4-dependent reporter transcription. The transcriptional repression of endogenous genes by tis7 overexpression is HDAC dependent. Thus, we propose TIS7 as a transcriptional co-repressor affecting the expression of specific genes in a HDAC activity-dependent manner during cell fate decisions, e.g. scattering.

Standard name | PAL_PRMT5_TARGETS_UP
Systematic name | M10688
Organism | Mus musculus
PMID | 15485929
Authors | Pal S,Vishwanath SN,Erdjument-Bromage H,Tempst P,Sif S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NIH-3T3 cells (fibroblast) after knockdown of PRMT5 [GeneID=10419] by RNAi.
Full description | Protein arginine methyltransferases (PRMTs) have been implicated in transcriptional activation and repression, but their role in controlling cell growth and proliferation remains obscure. We have recently shown that PRMT5 can interact with flag-tagged BRG1- and hBRM-based hSWI/SNF chromatin remodelers and that both complexes can specifically methylate histones H3 and H4. Here we report that PRMT5 can be found in association with endogenous hSWI/SNF complexes, which can methylate H3 and H4 N-terminal tails, and show that H3 arginine 8 and H4 arginine 3 are preferred sites of methylation by recombinant and hSWI/SNF-associated PRMT5. To elucidate the role played by PRMT5 in gene regulation, we have established a PRMT5 antisense cell line and determined by microarray analysis that more genes are derepressed when PRMT5 levels are reduced. Among the affected genes, we show that suppressor of tumorigenicity 7 (ST7) and nonmetastatic 23 (NM23) are direct targets of PRMT5-containing BRG1 and hBRM complexes. Furthermore, we demonstrate that expression of ST7 and NM23 is reduced in a cell line that overexpresses PRMT5 and that this decrease in expression correlates with H3R8 methylation, H3K9 deacetylation, and increased transformation of NIH 3T3 cells. These findings suggest that the BRG1- and hBRM-associated PRMT5 regulates cell growth and proliferation by controlling expression of genes involved in tumor suppression.

Standard name | VARELA_ZMPSTE24_TARGETS_DN
Systematic name | M5958
Organism | Mus musculus
PMID | 16079796
Authors | Varela I,Cadiñanos J,Pendás AM,Gutiérrez-Fernández A,Folgueras AR,Sánchez LM,Zhou Z,Rodríguez FJ,Stewart CL,Vega JA,Tryggvason K,Freije JM,López-Otín C
Category | C2
Sub-category | CGP
Brief description | Top genes down-regulated in liver tissue from mice with knockout of ZMPSTE24 [GeneID=10269].
Full description | Zmpste24 (also called FACE-1) is a metalloproteinase involved in the maturation of lamin A (Lmna), an essential component of the nuclear envelope. Both Zmpste24- and Lmna-deficient mice exhibit profound nuclear architecture abnormalities and multiple histopathological defects that phenocopy an accelerated ageing process. Similarly, diverse human progeroid syndromes are caused by mutations in ZMPSTE24 or LMNA genes. To elucidate the molecular mechanisms underlying these devastating diseases, we have analysed the transcriptional alterations occurring in tissues from Zmpste24-deficient mice. We demonstrate that Zmpste24 deficiency elicits a stress signalling pathway that is evidenced by a marked upregulation of p53 target genes, and accompanied by a senescence phenotype at the cellular level and accelerated ageing at the organismal level. These phenotypes are largely rescued in Zmpste24-/-Lmna+/- mice and partially reversed in Zmpste24-/-p53-/- mice. These findings provide evidence for the existence of a checkpoint response activated by the nuclear abnormalities caused by prelamin A accumulation, and support the concept that hyperactivation of the tumour suppressor p53 may cause accelerated ageing.

Standard name | SATO_SILENCED_BY_METHYLATION_IN_PANCREATIC_CANCER_2
Systematic name | M9702
Organism | Homo sapiens
PMID | 12839967
Authors | Sato N,Fukushima N,Maitra A,Matsubayashi H,Yeo CJ,Cameron JL,Hruban RH,Goggins M
Category | C2
Sub-category | CGP
Brief description | 50 most interesting genes up-regulated in the pancreatic cancer cell lines (AsPC1, Hs766T, MiaPaCa2, Panc1) but not in the non-neoplastic cells (HPDE) by decitabine (5-aza-2'-deoxycytidine) [PubChem=451668].
Full description | To identify potential targets for aberrant methylation in pancreatic cancer, we analyzed global changes in gene expression profiles of four pancreatic cancer cell lines after treatment with the demethylating agent 5-aza-2'-deoxycytidine (5Aza-dC) and/or the histone deacetylase inhibitor trichostatin A. A substantial number of genes were induced 5-fold or greater by 5Aza-dC alone (631 transcripts), trichostatin A alone (1196 transcripts), and by treatment with both agents (857 transcripts). Four hundred and seventy-five genes were markedly (>5-fold) induced after 5Aza-dC treatment in pancreatic cancer cell lines but not in a nonneoplastic pancreatic epithelial cell line. The methylation status of 11 of these 475 genes was examined in a panel of 42 pancreatic cancers, and all 11 of these genes were aberrantly methylated in pancreatic cancer but rarely, if any, methylated in 10 normal pancreatic ductal epithelia. These genes include UCHL1 (methylated in 100% of 42 pancreatic cancers), NPTX2 (98%), SARP2 (95%), CLDN5 (93%), reprimo (86%), LHX1 (76%), WNT7A (71%), FOXE1 (69%), TJP2 (64%), CDH3 (19%), and ST14 (10%). Three of these 11 genes (NPTX2, SARP2, and CLDN5) were selected for further analysis in a larger panel of specimens, and aberrant methylation of at least one of these three genes was detectable in 100% of 43 primary pancreatic cancers and in 18 of 24 (75%) pancreatic juice samples obtained from patients with pancreatic cancer. Thus, a substantial number of genes are induced by 5Aza-dC treatment of pancreatic cancer cells, and many of them may represent novel targets for aberrant methylation in pancreatic carcinoma.

Standard name | ZHANG_RESPONSE_TO_CANTHARIDIN_UP
Systematic name | M14118
Organism | Homo sapiens
PMID | 14639605
Authors | Zhang JP,Ying K,Xiao ZY,Zhou B,Huang QS,Wu HM,Yin M,Xie Y,Mao YM,Rui YC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HL-60 cells (promyeloid leukemia) by cantharidin [PubChem=6708701].
Full description | Cantharidin is a natural toxin that has antitumor properties and causes leukocytosis as well as increasing sensitivity of tumor cells resistant to other chemotherapeutic agents. There is limited information, however, on the molecular pharmacological mechanisms of cantharidin on human cancer cells. We have used cDNA microarrays to identify gene expression changes in HL-60 promyeloid leukemia cells exposed to cantharidin. Cantharidin-treated cells not only decreased expression of genes coding for proteins involved in DNA replication (e.g., DNA polymerase delta), DNA repair (e.g., FANCG, ERCC), energy metabolism (e.g., isocitrate dehydrogenase alpha, ADP/ATP translocase), but also decreased expression of genes coding for proteins that have oncogenic activity (e.g., c-myc, GTPase) or show tumor-specific expression (e.g., phosphatidylinositol 3-kinase). In contrast, these treated cells overexpressed several genes that encode intracellular and secreted growth-inhibitory proteins (e.g., BTG2, MCP-3) as well as proapoptotic genes (e.g., ATL-derived PMA-responsive peptide). Our findings suggest that alterations in specific genes functionally related to cell proliferation or apoptosis may be responsible for cantharidin-mediated cytotoxicity. We also found that exposure of HL-60 cells to cantharidin resulted in the decreased expression of multidrug resistance-associated protein genes (e.g., ABCA3, MOAT-B), suggesting that cantharidin may be used as an oncotherapy sensitizer, and the increased expression of genes in modulating cytokine production and inflammatory response (e.g., NFIL-3, N-formylpeptide receptor), which may partly explain the stimulating effects on leukocytosis. Our data provide new insight into the molecular mechanisms of cantharidin.

Standard name | HEDENFALK_BREAST_CANCER_BRACX_DN
Systematic name | M8941
Organism | Homo sapiens
PMID | 12610208
Authors | Hedenfalk I,Ringner M,Ben-Dor A,Yakhini Z,Chen Y,Chebil G,Ach R,Loman N,Olsson H,Meltzer P,Borg A,Trent J
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes distinguishing between two groups of non-BRCA1/BRCA2 [GeneID=672;675] breast tumors (BRACx): group A vs group B.
Full description | In the decade since their discovery, the two major breast cancer susceptibility genes BRCA1 and BRCA2, have been shown conclusively to be involved in a significant fraction of families segregating breast and ovarian cancer. However, it has become equally clear that a large proportion of families segregating breast cancer alone are not caused by mutations in BRCA1 or BRCA2. Unfortunately, despite intensive effort, the identification of additional breast cancer predisposition genes has so far been unsuccessful, presumably because of genetic heterogeneity, low penetrance, or recessive/polygenic mechanisms. These non-BRCA1/2 breast cancer families (termed BRCAx families) comprise a histopathologically heterogeneous group, further supporting their origin from multiple genetic events. Accordingly, the identification of a method to successfully subdivide BRCAx families into recognizable groups could be of considerable value to further genetic analysis. We have previously shown that global gene expression analysis can identify unique and distinct expression profiles in breast tumors from BRCA1 and BRCA2 mutation carriers. Here we show that gene expression profiling can discover novel classes among BRCAx tumors, and differentiate them from BRCA1 and BRCA2 tumors. Moreover, microarray-based comparative genomic hybridization (CGH) to cDNA arrays revealed specific somatic genetic alterations within the BRCAx subgroups. These findings illustrate that, when gene expression-based classifications are used, BRCAx families can be grouped into homogeneous subsets, thereby potentially increasing the power of conventional genetic analysis.

Standard name | JIANG_AGING_HYPOTHALAMUS_DN
Systematic name | M1535
Organism | Mus musculus
PMID | 11172053
Authors | Jiang CH,Tsien JZ,Schultz PG,Hu Y
Category | C2
Sub-category | CGP
Brief description | Down-regulated in the hypothalamus of aged (22 months) BALB/c mice, compared to young (2 months) controls
Full description | A better understanding of the molecular effects of aging in the brain may help to reveal important aspects of organismal aging, as well as processes that lead to age-related brain dysfunction. In this study, we have examined differences in gene expression in the hypothalamus and cortex of young and aged mice by using high-density oligonucleotide arrays. A number of key genes involved in neuronal structure and signaling are differentially expressed in both the aged hypothalamus and cortex, including synaptotagmin I, cAMP-dependent protein kinase C beta, apolipoprotein E, protein phosphatase 2A, and prostaglandin D. Misregulation of these proteins may contribute to age-related memory deficits and neurodegenerative diseases. In addition, many proteases that play essential roles in regulating neuropeptide metabolism, amyloid precursor protein processing, and neuronal apoptosis are up-regulated in the aged brain and likely contribute significantly to brain aging. Finally, a subset of these genes whose expression is affected by aging are oppositely affected by exposure of mice to an enriched environment, suggesting that these genes may play important roles in learning and memory.

Standard name | CHANG_IMMORTALIZED_BY_HPV31_DN
Systematic name | M12051
Organism | Homo sapiens
PMID | 10756030
Authors | Chang YE,Laimins LA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in normal keratinocytes immortalized by infection with the high risk HPV31 (human papilloma virus) strain.
Full description | Human papillomaviruses (HPVs) infect keratinocytes and induce proliferative lesions. In infected cells, viral gene products alter the activities of cellular proteins, such as Rb and p53, resulting in altered cell cycle response. It is likely that HPV gene products also alter expression of cellular genes. In this study we used microarray analysis to examine the global changes in gene expression induced by high-risk HPV type 31 (HPV31). Among 7,075 known genes and ESTs (expressed sequence tags) tested, we found that 178 were upregulated and 150 were downregulated twofold or more in HPV31 cells compared to normal human keratinocytes. While no specific pattern could be deduced from the list of genes that were upregulated, downregulated genes could be classified to three groups: genes that are involved in the regulation of cell growth, genes that are specifically expressed in keratinocytes, and genes whose expression is increased in response to interferon stimulation. The basal level of expression of several interferon-responsive genes was found to be downregulated in HPV31 cells by both microarray analysis and Northern blot analysis in different HPV31 cell lines. When cells were treated with alpha or gamma interferon, expression of interferon-inducible genes was impaired. At high doses of interferon, the effects were less pronounced. Among the genes repressed by HPV31 was the signal transducer and activator of transcription (Stat-1), which plays a major role in mediating the interferon response. Suppression of Stat-1 expression may contribute to a suppressed response to interferon as well as immune evasion.

Standard name | BROWNE_HCMV_INFECTION_24HR_DN
Systematic name | M14098
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 24 h time point that were not down-regulated at the previous time point, 20 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | MARIADASON_RESPONSE_TO_BUTYRATE_CURCUMIN_SULINDAC_TSA_8
Systematic name | M1537
Organism | Homo sapiens
PMID | 10969808
Authors | Mariadason JM,Corner GA,Augenlicht LH
Category | C2
Sub-category | CGP
Brief description | Cluster 8: genes down-regulated in SW260 cells (colon cancer) by sodium butyrate, curcumin, sulindac and TSA [PubChem=5222465;969516;5352;5562].
Full description | The short-chain fatty acid butyrate, produced by microbial fermentation of dietary fiber in the large intestine, is a physiological regulator of major pathways of colonic epithelial cell maturation: cell cycle arrest, lineage-specific differentiation, and apoptosis. Microarray analysis of 8,063 sequences demonstrated a complex cascade of reprogramming of SW620 colonic epithelial cells upon treatment with butyrate characterized by the progressive recruitment of gene sets as a function of time. Comparison with the effects of trichostatin A, in conjunction with differences in the kinetics of alteration of histone acetylation induced by butyrate and trichostatin A, identified subsets of induced and repressed genes likely coordinately regulated by altered histone acetylation. The butyrate response was also compared in detail with that of sulindac, a nonsteroidal anti-inflammatory drug with significant chemopreventive activity for colon cancer, and curcumin, a component of mustard and curry structurally and functionally related to sulindac that also has chemopreventive activity. Although gene clusters were identified that showed similar responses to butyrate and sulindac, the data were characterized by the extensive differences in the effects of the two agents. This was striking for functional classes of genes involved in signaling pathways and in cell cycle progression, although butyrate and sulindac induce a similar G0-G1 arrest, elevation of beta-catenin-Tcf signaling, and apoptotic cascade. As regards cell cycle arrest, the underlying mechanism in response to butyrate was most similar to that of the Caco-2 cell line that had spontaneously undergone a G0-G1 arrest and least similar to the G2-M arrest stimulated by curcumin. Thus, high-throughput microarray analysis of gene expression profiles can be used to characterize and distinguish the mechanisms of response of colonic epithelial cells to physiological and pharmacological inducers of cell maturation. This has important implications for characterization of chemopreventive agents and recognition of potential toxicity and synergies. The data bases, gene clusters, and analyses are available at http:// sequence.aecom.yu.edu/genome/.

Standard name | CHIBA_RESPONSE_TO_TSA_UP
Systematic name | M10372
Organism | Homo sapiens
PMID | 15452378
Authors | Chiba T,Yokosuka O,Fukai K,Kojima H,Tada M,Arai M,Imazeki F,Saisho H
Category | C2
Sub-category | CGP
Brief description | Cancer related genes up-regulated in any of four hepatoma cell lines following 24 h treatment with TSA [PubChem=5562].
Full description | OBJECTIVE: Histone deacetylase (HDAC) inhibitors have been reported to induce cell growth arrest, apoptosis and differentiation in tumor cells. The effect of the HDAC inhibitor, trichostatin A (TSA), on hepatoma cells, however, has not been well studied. In this study, we examined cell viability and gene expression profile in hepatoma cell lines treated with TSA. METHODS: To study cell growth inhibition and induction of apoptosis by TSA on human hepatoma cell lines including HuH7, Hep3B, HepG2, and PLC/PRF/5, cells were treated with TSA at various concentrations and analyzed by the 3-(4, 5-dimethyl-2-thiazolyl)-2H-tetrazolium bromide (MTT) and TUNEL assays, respectively. Changes in gene expression profile after exposure to TSA were assessed using a cDNA microarray consisting of 557 distinct cDNA of cancer-related genes. The levels of acetylated histones were examined by the chromatin immunoprecipitation (ChIP) assay using anti-acetylated histone H3 or H4 antibody. RESULTS: The MTT assay demonstrated that TSA showed cell growth inhibition not only in a concentration-dependent but also a time-dependent manner on all cell lines studied. The TUNEL assay also revealed the potential of TSA to induce apoptosis. The microarray analysis revealed that 8 genes including collagen type 1, alpha2 (COL1A2), insulin-like growth factor binding protein 2 (IGFBP2), integrin, alpha7 (ITGA7), basigin (BSG), quiescin Q6 (QSCN6), superoxide dismutase 3, extracellular (SOD3), nerve growth factor receptor (NGFR), and p53-induced protein (PIG11) exhibited substantial induction (ratio >2.0) after TSA treatment in multiple cell lines. ChIP assay, in general, showed a good correlation between the expression level of mRNA and levels of acetylated histones in these upregulated genes. CONCLUSIONS: This study showed cell growth inhibition and the gene expression profile in hepatoma cell lines exposed to TSA. The alteration in levels of acetylated histones was closely associated with expression of specific cancer-related genes in hepatoma cells.

Standard name | RAMASWAMY_METASTASIS_DN
Systematic name | M16963
Organism | Homo sapiens
PMID | 12469122
Authors | Ramaswamy S,Ross KN,Lander ES,Golub TR
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in metastatic vs primary solid tumors.
Full description | Metastasis is the principal event leading to death in individuals with cancer, yet its molecular basis is poorly understood. To explore the molecular differences between human primary tumors and metastases, we compared the gene-expression profiles of adenocarcinoma metastases of multiple tumor types to unmatched primary adenocarcinomas. We found a gene-expression signature that distinguished primary from metastatic adenocarcinomas. More notably, we found that a subset of primary tumors resembled metastatic tumors with respect to this gene-expression signature. We confirmed this finding by applying the expression signature to data on 279 primary solid tumors of diverse types. We found that solid tumors carrying the gene-expression signature were most likely to be associated with metastasis and poor clinical outcome (P < 0.03). These results suggest that the metastatic potential of human tumors is encoded in the bulk of a primary tumor, thus challenging the notion that metastases arise from rare cells within a primary tumor that have the ability to metastasize.

Standard name | MODY_HIPPOCAMPUS_NEONATAL
Systematic name | M7409
Organism | Mus musculus
PMID | 11438693
Authors | Mody M,Cao Y,Cui Z,Tay KY,Shyong A,Shimizu E,Pham K,Schultz P,Welsh D,Tsien JZ
Category | C2
Sub-category | CGP
Brief description | Genes highly expressed in the neonatal hippocampus (clusters 4 and 8).
Full description | We have analyzed the developmental molecular programs of the mouse hippocampus, a cortical structure critical for learning and memory, by means of large-scale DNA microarray techniques. Of 11,000 genes and expressed sequence tags examined, 1,926 showed dynamic changes during hippocampal development from embryonic day 16 to postnatal day 30. Gene-cluster analysis was used to group these genes into 16 distinct clusters with striking patterns that appear to correlate with major developmental hallmarks and cellular events. These include genes involved in neuronal proliferation, differentiation, and synapse formation. A complete list of the transcriptional changes has been compiled into a comprehensive gene profile database (http://BrainGenomics.Princeton.edu), which should prove valuable in advancing our understanding of the molecular and genetic programs underlying both the development and the functions of the mammalian brain.

Standard name | MCCLUNG_COCAINE_REWARD_5D
Systematic name | M1539
Organism | Mus musculus
PMID | 14566342
Authors | McClung CA,Nestler EJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the nucleus accumbens (a major reward center in the brain) after 5 days of cocaine [PubChem=5760] treatment.
Full description | DeltaFosB (a truncated form of FosB) and CREB (cAMP response element binding protein) are transcription factors induced in the brain's reward pathways after chronic exposure to drugs of abuse. However, their mechanisms of action and the genes they regulate remain unclear. Using microarray analysis in the nucleus accumbens of inducible transgenic mice, we found that CREB and a dominant-negative CREB have opposite effects on gene expression, as do prolonged expression of DeltaFosB and the activator protein-1 (AP-1) antagonist DeltacJun. However, unlike CREB, short-term and prolonged DeltaFosB induction had opposing effects on gene expression. Gene expression induced by short-term DeltaFosB and by CREB was strikingly similar, and both reduced the rewarding effects of cocaine, whereas prolonged DeltaFosB expression increased drug reward. Gene expression after a short cocaine treatment was more dependent on CREB, whereas gene expression after a longer cocaine treatment became increasingly DeltaFosB dependent. These findings help define the molecular functions of CREB and DeltaFosB and identify clusters of genes that contribute to cocaine addiction.

Standard name | KAYO_AGING_MUSCLE_UP
Systematic name | M16050
Organism | Macaca mulatta
PMID | 11309484
Authors | Kayo T,Allison DB,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Upregulated in the vastus lateralis muscle of aged vs young adult rhesus monkeys
Full description | In laboratory rodents, caloric restriction (CR) retards several age-dependent physiological and biochemical changes in skeletal muscle, including increased steady-state levels of oxidative damage to lipids, DNA, and proteins. We have previously used high-density oligonucleotide arrays to show that CR can prevent or delay most of the major age-related transcriptional alterations in the gastrocnemius muscle of C57BL/6 mice. Here we report the effects of aging and adult-onset CR on the gene expression profile of 7,070 genes in the vastus lateralis muscle from rhesus monkeys. Gene expression analysis of aged rhesus monkeys (mean age of 26 years) was compared with that of young animals (mean age of 8 years). Aging resulted in a selective up-regulation of transcripts involved in inflammation and oxidative stress, and a down-regulation of genes involved in mitochondrial electron transport and oxidative phosphorylation. Middle-aged monkeys (mean age of 20 years) subjected to CR since early adulthood (mean age of 11 years) were studied to determine the gene expression profile induced by CR. CR resulted in an up-regulation of cytoskeletal protein-encoding genes, and also a decrease in the expression of genes involved in mitochondrial bioenergetics. Surprisingly, we did not observe any evidence for an inhibitory effect of adult-onset CR on age-related changes in gene expression. These results indicate that the induction of an oxidative stress-induced transcriptional response may be a common feature of aging in skeletal muscle of rodents and primates, but the extent to which CR modifies these responses may be species-specific.

Standard name | VISALA_RESPONSE_TO_HEAT_SHOCK_AND_AGING_UP
Systematic name | M1540
Organism | Homo sapiens
PMID | 12618007
Authors | Visala Rao D,Boyle GM,Parsons PG,Watson K,Jones GL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated after heat shock in peripheral lympocytes from old donors, compared to those from the young ones.
Full description | Ageing results in a progressive, intrinsic and generalised imbalance of the control of regulatory systems. A key manifestation of this complex biological process includes the attenuation of the universal stress response. Here we provide the first global assessment of the ageing process as it affects the heat shock response, utilising human peripheral lymphocytes and cDNA microarray analysis. The genomic approach employed in our preliminary study was supplemented with a proteomic approach. In addition, the current study correlates the in vivo total antioxidant status with the age-related differential gene expression as well as the translational kinetics of heat shock proteins (hsps). Most of the genes encoding stress response proteins on the 4224 element microarray used in this study were significantly elevated after heat shock treatment of lymphocytes obtained from both young and old individuals albeit to a greater extent in the young. Cell signaling and signal transduction genes as well as some oxidoreductases showed varied response. Results from translational kinetics of induction of major hsps, from 0 to 24 h recovery period were broadly consistent with the differential expression of HSC 70 and HSP 40 genes. Total antioxidant levels in plasma from old individuals were found to be significantly lower by comparison with young, in agreement with the widely acknowledged role of oxidant homeostasis in the ageing process.

Standard name | CHUANG_OXIDATIVE_STRESS_RESPONSE_DN
Systematic name | M12948
Organism | Homo sapiens
PMID | 12414654
Authors | Chuang YY,Chen Y,Gadisetti,Chandramouli VR,Cook JA,Coffin D,Tsai MH,DeGraff W,Yan H,Zhao S,Russo A,Liu ET,Mitchell JB
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) after treatment with the oxydants: hydrogen peroxyde, menadione, and t-butyl hydroperoxyde [PubChem=784;4055;6410].
Full description | Global gene expression patterns in breast cancer cells after treatment with oxidants (hydrogen peroxide, menadione, and t-butyl hydroperoxide) were investigated in three replicate experiments. RNA collected after treatment (at 1, 3, 7, and 24 h) rather than after a single time point, enabled an analysis of gene expression patterns. Using a 17,000 microarray, template-based clustering and multidimensional scaling analysis of the gene expression over the entire time course identified 421 genes as being either up- or down-regulated by the three oxidants. In contrast, only 127 genes were identified for any single time point and a 2-fold change criteria. Surprisingly, the patterns of gene induction were highly similar among the three oxidants; however, differences were observed, particularly with respect to p53, IL-6, and heat-shock related genes. Replicate experiments increased the statistical confidence of the study, whereas changes in gene expression patterns over a time course demonstrated significant additional information versus a single time point. Analyzing the three oxidants simultaneously by template cluster analysis identified genes that heretofore have not been associated with oxidative stress.

Standard name | BROWNE_HCMV_INFECTION_14HR_DN
Systematic name | M13251
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 14 h time point that were not down-regulated at the previous time point, 12 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | DELASERNA_MYOD_TARGETS_DN
Systematic name | M1541
Organism | Mus musculus
PMID | 15870273
Authors | de la Serna IL,Ohkawa Y,Berkes CA,Bergstrom DA,Dacwag CS,Tapscott SJ,Imbalzano AN
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NIH 3T3 cells (fibroblasts) 24 h after inducing MyoD [GeneID=4654] differentiation program.
Full description | The activation of muscle-specific gene expression requires the coordinated action of muscle regulatory proteins and chromatin-remodeling enzymes. Microarray analysis performed in the presence or absence of a dominant-negative BRG1 ATPase demonstrated that approximately one-third of MyoD-induced genes were highly dependent on SWI/SNF enzymes. To understand the mechanism of activation, we performed chromatin immunoprecipitations analyzing the myogenin promoter. We found that H4 hyperacetylation preceded Brg1 binding in a MyoD-dependent manner but that MyoD binding occurred subsequent to H4 modification and Brg1 interaction. In the absence of functional SWI/SNF enzymes, muscle regulatory proteins did not bind to the myogenin promoter, thereby providing evidence for SWI/SNF-dependent activator binding. We observed that the homeodomain factor Pbx1, which cooperates with MyoD to stimulate myogenin expression, is constitutively bound to the myogenin promoter in a SWI/SNF-independent manner, suggesting a two-step mechanism in which MyoD initially interacts indirectly with the myogenin promoter and attracts chromatin-remodeling enzymes, which then facilitate direct binding by MyoD and other regulatory proteins.

Standard name | YAMAZAKI_TCEB3_TARGETS_UP
Systematic name | M1542
Organism | Mus musculus
PMID | 12604609
Authors | Yamazaki K,Aso T,Ohnishi Y,Ohno M,Tamura K,Shuin T,Kitajima S,Nakabeppu Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in embryonic stem cells from TCEB3 [GeneID=6924] knockout mice.
Full description | Elongin A is a transcription elongation factor that increases the overall rate of mRNA chain elongation by RNA polymerase II. To investigate the function of Elongin A in vivo, the two alleles of the Elongin A gene have been disrupted by homologous recombination in murine embryonic stem (ES) cells. The Elongin A-deficient ES cells are viable, but show a slow growth phenotype because they undergo a delayed mitosis. The cDNA microarray and RNase protection assay using the wild-type and Elongin A-deficient ES cells indicate that the expression of only a small subset of genes is affected in the mutant cells. Taken together, our results suggest that Elongin A regulates transcription of a subset but not all of genes and reveal a linkage between Elongin A function and cell cycle progression.

Standard name | HU_GENOTOXIN_ACTION_DIRECT_VS_INDIRECT_24HR
Systematic name | M1543
Organism | Mus musculus
PMID | 15120960
Authors | Hu T,Gibson DP,Carr GJ,Torontali SM,Tiesman JP,Chaney JG,Aardema MJ
Category | C2
Sub-category | CGP
Brief description | Genes discriminating between direct (cisplatin, MMS, mitomycin C [PubChem=2767;4156;5746]) and indirect (paclitaxel, hydroxyurea, etoposide [PubChem=4666;3657;36462]) acting genotoxins at 24 h time point.
Full description | During the safety evaluation process of new drugs and chemicals, a battery of genotoxicity tests is conducted starting with in vitro genotoxicity assays. Obtaining positive results in in vitro genotoxicity tests is not uncommon. Follow-up studies to determine the biological relevance of positive genotoxicity results are costly, time consuming, and utilize animals. More efficient methods, especially for identifying a putative mode of action like an indirect mechanism of genotoxicity (where DNA molecules are not the initial primary targets), would greatly improve the risk assessment for genotoxins. To this end, we are participating in an International Life Sciences Institute (ILSI) project involving studies of gene expression changes caused by model genotoxins. The purpose of the work is to evaluate gene expression tools in general, and specifically for discriminating genotoxins that are direct-acting from indirect-acting. Our lab has evaluated gene expression changes as well as micronuclei (MN) in L5178Y TK(+/-) mouse lymphoma cells treated with six compounds. Direct-acting genotoxins (where DNA is the initial primary target) that were evaluated included the DNA crosslinking agents, mitomycin C (MMC) and cisplatin (CIS), and an alkylating agent, methyl methanesulfonate (MMS). Indirect-acting genotoxins included hydroxyurea (HU), a ribonucleotide reductase inhibitor, taxol (TXL), a microtubule inhibitor, and etoposide (ETOP), a DNA topoisomerase II inhibitor. Microarray gene expression analysis was conducted using Affymetrix mouse oligonucleotide arrays on RNA samples derived from cells which were harvested immediately after the 4 h chemical treatment, and 20 h after the 4 h chemical treatment. The evaluation of these experimental results yields evidence of differentially regulated genes at both 4 and 24 h time points that appear to have discriminating power for direct versus indirect genotoxins, and therefore may serve as a fingerprint for classifying chemicals when their mechanism of action is unknown.

Standard name | JIANG_VHL_TARGETS
Systematic name | M18850
Organism | Homo sapiens
PMID | 12692265
Authors | Jiang Y,Zhang W,Kondo K,Klco JM,St Martin TB,Dufault MR,Madden SL,Kaelin WG Jr,Nacht M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 786-0 cells (renal carcinoma, RCC) upon expression of VHL [GeneID=7428] off a retroviral vector under normoxia (normal oxygen) condition.
Full description | The von Hippel-Lindau tumor suppressor, pVHL, is a key player in one of the best characterized hypoxia signaling pathways, the VHL-hypoxia-inducible factor (VHL-HIF) pathway. To better understand the role of VHL in the hypoxia signaling pathways of tumor cells, we used serial analysis of gene expression (SAGE) to investigate hypoxia-regulated gene expression in renal carcinoma cells (786-0), with and without VHL. The gene expression profiles of the cancer cells were compared to SAGE profiles from normal renal proximal tubule cells grown under both normoxia and hypoxia. The data suggest that the role of VHL as a tumor suppressor may be more complex than previously thought. Further, the data reveal that renal carcinoma cells have evolved an alternative hypoxia signaling pathway(s) compared with normal renal cells. These alternative hypoxia pathways demonstrate VHL-dependent and VHL-independent regulation. The genes involved in such pathways include those with potential importance in the physiological and pathological regulation of tumor growth and angiogenesis. Some of the genes identified as showing overexpression in the cancer cells, particularly those encoding secreted or membrane-bound proteins, could be potential biomarkers for tumors or targets for rational therapeutics that are dependent on VHL status.

Standard name | MACLACHLAN_BRCA1_TARGETS_DN
Systematic name | M10593
Organism | Homo sapiens
PMID | 10644742
Authors | MacLachlan TK,Somasundaram K,Sgagias M,Shifman Y,Muschel RJ,Cowan KH,El-Deiry WS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SW480 cells (colon cancer with mutated p53 [GeneID=7157]) upon expression of BRCA1 [GeneID=672] off an adenovirus vector.
Full description | The breast and ovarian cancer susceptibility gene product BRCA1 has been reported to be expressed in a cell cycle-dependent manner; possess transcriptional activity; associate with several proteins, including the p53 tumor suppressor; and play an integral role in certain types of DNA repair. We show here that ectopic expression of BRCA1 using an adenovirus vector (Ad-BRCA1) leads to dephosphorylation of the retinoblastoma protein accompanied by a decrease in cyclin-dependent kinase activity. Flow cytometric analysis on Ad-BRCA1-infected cells revealed a G(1) or G(2) phase accumulation. High density cDNA array screening of colon, lung, and breast cancer cells identified several genes affected by BRCA1 expression in a p53-independent manner, including DNA damage response genes and genes involved in cell cycle control. Notable changes included induction of the GADD45 and GADD153 genes and a reduction in cyclin B1 expression. Therefore, BRCA1 has the potential to modulate the expression of genes and function of proteins involved in cell cycle control and DNA damage response pathways.

Standard name | LEE_AGING_CEREBELLUM_DN
Systematic name | M1544
Organism | Mus musculus
PMID | 10888876
Authors | Lee CK,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Downregulated in the cerebellum of aged adult mice (30-month) vs young adult (5-month)
Full description | Ageing of the brain leads to impairments in cognitive and motor skills, and is the major risk factor for several common neurological disorders such as Alzheimer disease (AD) and Parkinson disease (PD). Recent studies suggest that normal brain ageing is associated with subtle morphological and functional alterations in specific neuronal circuits, as opposed to large-scale neuronal loss. In fact, ageing of the central nervous system in diverse mammalian species shares many features, such as atrophy of pyramidal neurons, synaptic atrophy, decrease of striatal dopamine receptors, accumulation of fluorescent pigments, cytoskeletal abnormalities, and reactive astrocytes and microglia. To provide the first global analysis of brain ageing at the molecular level, we used oligonucleotide arrays representing 6,347 genes to determine the gene-expression profile of the ageing neocortex and cerebellum in mice. Ageing resulted in a gene-expression profile indicative of an inflammatory response, oxidative stress and reduced neurotrophic support in both brain regions. At the transcriptional level, brain ageing in mice displays parallels with human neurodegenerative disorders. Caloric restriction, which retards the ageing process in mammals, selectively attenuated the age-associated induction of genes encoding inflammatory and stress responses.

Standard name | EHRLICH_ICF_SYNDROM_UP
Systematic name | M5053
Organism | Homo sapiens
PMID | 11741835
Authors | Ehrlich M,Buchanan KL,Tsien F,Jiang G,Sun B,Uicker W,Weemaes CM,Smeets D,Sperling K,Belohradsky BH,Tommerup N,Misek DE,Rouillard JM,Kuick R,Hanash SM
Category | C2
Sub-category | CGP
Brief description | Up-regulated in B lymphocytes from patients with ICF syndrom caused by mutations in DNMT3B [GeneID=1789] compared to normals.
Full description | ICF (immunodeficiency, centromeric region instability and facial anomalies) is a recessive disease caused by mutations in the DNA methyltransferase 3B gene (DNMT3B). Patients have immunodeficiency, chromosome 1 (Chr1) and Chr16 pericentromeric anomalies in mitogen-stimulated lymphocytes, a small decrease in overall genomic 5-methylcytosine levels and much hypomethylation of Chr1 and Chr16 juxtacentromeric heterochromatin. Microarray expression analysis was done on B-cell lymphoblastoid cell lines (LCLs) from ICF patients with diverse DNMT3B mutations and on control LCLs using oligonucleotide arrays for approximately 5600 different genes, 510 of which showed a lymphoid lineage-restricted expression pattern among several different lineages tested. A set of 32 genes had consistent and significant ICF-specific changes in RNA levels. Half of these genes play a role in immune function. ICF-specific increases in immunoglobulin (Ig) heavy constant mu and delta RNA and cell surface IgM and IgD and decreases in Ig(gamma) and Ig(alpha) RNA and surface IgG and IgA indicate inhibition of the later steps of lymphocyte maturation. ICF-specific increases were seen in RNA for RGS1, a B-cell specific inhibitor of G-protein signaling implicated in negative regulation of B-cell migration, and in RNA for the pro-apoptotic protein kinase C eta gene. ICF-associated decreases were observed in RNAs encoding proteins involved in activation, migration or survival of lymphoid cells, namely, transcription factor negative regulator ID3, the enhancer-binding MEF2C, the iron regulatory transferrin receptor, integrin beta7, the stress protein heme oxygenase and the lymphocyte-specific tumor necrosis factor receptor family members 7 and 17. No differences in promoter methylation were seen between ICF and normal LCLs for three ICF upregulated genes and one downregulated gene by a quantitative methylation assay [combined bisulfite restriction analysis (COBRA)]. Our data suggest that DNMT3B mutations in the ICF syndrome cause lymphogenesis-associated gene dysregulation by indirect effects on gene expression that interfere with normal lymphocyte signaling, maturation and migration.

Standard name | BROWNE_INTERFERON_RESPONSIVE_GENES
Systematic name | M9221
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast culture after treatment with interferon alpha for 6 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | MCCLUNG_DELTA_FOSB_TARGETS_2WK
Systematic name | M8645
Organism | Mus musculus
PMID | 14566342
Authors | McClung CA,Nestler EJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the nucleus accumbens (a major reward center in brain) 2 weeks after induction of deltaFosB, a FOSB [GeneID=2354] splice variant.
Full description | DeltaFosB (a truncated form of FosB) and CREB (cAMP response element binding protein) are transcription factors induced in the brain's reward pathways after chronic exposure to drugs of abuse. However, their mechanisms of action and the genes they regulate remain unclear. Using microarray analysis in the nucleus accumbens of inducible transgenic mice, we found that CREB and a dominant-negative CREB have opposite effects on gene expression, as do prolonged expression of DeltaFosB and the activator protein-1 (AP-1) antagonist DeltacJun. However, unlike CREB, short-term and prolonged DeltaFosB induction had opposing effects on gene expression. Gene expression induced by short-term DeltaFosB and by CREB was strikingly similar, and both reduced the rewarding effects of cocaine, whereas prolonged DeltaFosB expression increased drug reward. Gene expression after a short cocaine treatment was more dependent on CREB, whereas gene expression after a longer cocaine treatment became increasingly DeltaFosB dependent. These findings help define the molecular functions of CREB and DeltaFosB and identify clusters of genes that contribute to cocaine addiction.

Standard name | CUI_TCF21_TARGETS_DN
Systematic name | M6937
Organism | Mus musculus
PMID | 16207825
Authors | Cui S,Li C,Ema M,Weinstein J,Quaggin SE
Category | C2
Sub-category | CGP
Brief description | Genes most strongly down-regulated in kidney glomeruli isolated from TCF21 [GeneID=6943] knockout mice.
Full description | Mouse mutations have provided tremendous insights into the molecular basis of renal and glomerular development. However, genes often play important roles during multiple stages of nephrogenesis, making it difficult to determine the role of a gene in a specific cell lineage such as the podocyte. Conditional gene targeting and chimeric analysis are two possible approaches to dissect the function of genes in specific cell populations. However, these are labor-intensive and costly and require the generation, validation, and analysis of additional transgenic lines. For overcoming these shortcomings and, specifically, for studying the role of gene function in developing glomeruli, a technique to isolate and purify glomeruli from murine embryos was developed. Combined with gene expression profiling, this method was used to identify differentially expressed genes in glomeruli from Pod1 knockout (KO) mice that die in the perinatal period with multiple renal defects. Glomeruli from early developing stages (late S-shape/early capillary loop) onward can be isolated successfully from wild-type and KO kidneys at 18.5 d postcoitus, and RNA can readily be obtained and used for genome-wide microarray analysis. With this approach, 3986 genes that are differently expressed between glomeruli from Pod1 KO and wild-type mice were identified, including a four-fold reduction of alpha 8 integrin mRNA in glomeruli from Pod1 KO mice that was confirmed by immunostaining. This procedure may be adapted to any transgenic strain, providing a rapid and efficient method to dissect the function of specific genes in glomerular development.

Standard name | SU_THYMUS
Systematic name | M13095
Organism | Homo sapiens
PMID | 11904358
Authors | Su AI,Cooke MP,Ching KA,Hakak Y,Walker JR,Wiltshire T,Orth AP,Vega RG,Sapinoso LM,Moqrich A,Patapoutian A,Hampton GM,Schultz PG,Hogenesch JB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated specifically in human thymus.
Full description | High-throughput gene expression profiling has become an important tool for investigating transcriptional activity in a variety of biological samples. To date, the vast majority of these experiments have focused on specific biological processes and perturbations. Here, we have generated and analyzed gene expression from a set of samples spanning a broad range of biological conditions. Specifically, we profiled gene expression from 91 human and mouse samples across a diverse array of tissues, organs, and cell lines. Because these samples predominantly come from the normal physiological state in the human and mouse, this dataset represents a preliminary, but substantial, description of the normal mammalian transcriptome. We have used this dataset to illustrate methods of mining these data, and to reveal insights into molecular and physiological gene function, mechanisms of transcriptional regulation, disease etiology, and comparative genomics. Finally, to allow the scientific community to use this resource, we have built a free and publicly accessible website (http://expression.gnf.org) that integrates data visualization and curation of current gene annotations.

Standard name | KANG_FLUOROURACIL_RESISTANCE_DN
Systematic name | M12110
Organism | Homo sapiens
PMID | 14734480
Authors | Kang HC,Kim IJ,Park JH,Shin Y,Ku JL,Jung MS,Yoo BC,Kim HK,Park JG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in gastric cancer cell lines resistant to 5-fluorouracil [PubChem=3385].
Full description | PURPOSE: A major obstacle in chemotherapy is treatment failure due to anticancer drug resistance. The emergence of acquired resistance results from host factors and genetic or epigenetic changes in the cancer cells. The purpose of this study was to identify differentially expressed genes associated with acquisition of resistance in human gastric cancer cells. EXPERIMENTAL DESIGN: We performed global gene expression analysis in the acquired drug-resistant gastric cancer cell lines to the commonly used drugs 5-fluorouracil, doxorubicin, and cisplatin using Affymetrix HG-U133A microarray. The gene expression patterns of 10 chemoresistant gastric cancer cell lines were compared with those of four parent cell lines using fold-change and Wilcoxon's test for data analysis. RESULTS: We identified over 250 genes differentially expressed in 5-fluorouracil-, cisplatin-, or doxorubicin-resistant gastric cancer cell lines. Our expression analysis also identified eight multidrug resistance candidate genes that were associated with resistance to two or more of the tested chemotherapeutic agents. Among these, midkine (MDK), a heparin-binding growth factor, was overexpressed in all drug-resistant cell lines, strongly suggesting that MDK might contribute to multidrug resistance in gastric cancer cells. CONCLUSIONS: Our investigation provides comprehensive gene information associated with acquired resistance to anticancer drugs in gastric cancer cells and a basis for additional functional studies.

Standard name | BROWNE_HCMV_INFECTION_8HR_UP
Systematic name | M10695
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 8 h time point that were not up-regulated at the previous time point, 6 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | MARTINEZ_RESPONSE_TO_TRABECTEDIN_UP
Systematic name | M5190
Organism | Homo sapiens
PMID | 15897246
Authors | Martínez N,Sánchez-Beato M,Carnero A,Moneo V,Tercero JC,Fernández I,Navarrete M,Jimeno J,Piris MA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in at least 8 of 11 sarcoma cell lines by trabectedin [PubChem=3199].
Full description | Ecteinascidin 743 (ET-743; Yondelis, Trabectedin) is a marine anticancer agent that induces long-lasting objective remissions and tumor control in a subset of patients with pretreated/resistant soft-tissue sarcoma. Drug-induced tumor control is achievable in 22% of such patients, but there is no clear indication of the molecular features correlated with clinical sensitivity/resistance to ET-743. Nine low-passage, soft-tissue sarcoma cell lines, explanted from chemo-naive patients with different patterns of sensitivity, have been profiled with a cDNA microarray containing 6,700 cancer-related genes. The molecular signature of these cell lines was analyzed at baseline and at four different times after ET-743 exposure. The association of levels of TP53 mutation and TP73 expression with ET-743 sensitivity and cell cycle kinetics after treatment was also analyzed. Gene expression profile analysis revealed up-regulation of 86 genes and down-regulation of 244 genes in response to ET-743. The ET-743 gene expression signature identified a group of genes related with cell cycle control, stress, and DNA-damage response (JUNB, ATF3, CS-1, SAT, GADD45B, and ID2) that were up-regulated in all the cell lines studied. The transcriptional signature 72 hours after ET-743 administration, associated with ET-743 sensitivity, showed a more efficient induction of genes involved in DNA-damage response and apoptosis, such as RAD17, BRCA1, PAR4, CDKN1A, and P53DINP1, in the sensitive cell line group. The transcriptional signature described here may lead to the identification of ET-743 downstream mediators and transcription regulators and the proposal of strategies by which ET-743-sensitive tumors may be identified.

Standard name | JI_RESPONSE_TO_FSH_DN
Systematic name | M17537
Organism | Homo sapiens
PMID | 15386376
Authors | Ji Q,Liu PI,Chen PK,Aoyama C
Category | C2
Sub-category | CGP
Brief description | Down-regulated in ovarian epithelial cells (MCV152) 72 hours following FSH treatment, compared to untreated
Full description | Epidemiologic data have implicated reproductive follicle-stimulating hormone (FSH) as a probable risk factor for ovarian cancer (OC) development. Although pituitary and sex hormones have been reported to regulate OC cell growth, no information is available on the influence of FSH on gene expression profiles during ovarian surface epithelial (OSE) cell proliferation. This study evaluated the effect of FSH treatment on cell proliferation of various OSE cell lines and gene expression profiles with FSH treatment. Follicle-stimulating hormone receptor (FSHR) was found at higher expression at both transcriptional and protein levels in ovarian cancerous tissues compared to normal tissues, and FSH was shown to promote cell growth in 3 OSE cell lines. Furthermore, it was also found that overexpression of FSHR in Chinese hamster ovary (CHO) cells leads to cell proliferation. Using cDNA MicroArray analysis on MCV152 cells with FSH treatment, 91 genes were found upregulated and 68 genes downregulated for more than 2-fold after FSH treatment. Most of the genes were related to metabolism, cell proliferation and oncogenes. Downregulated genes included tumor suppressor genes (RB1, BRCA1, BS69) and the genes related to cell proliferation control. Pathway analysis found that FSH activates certain important enzymes in sterol biosynthesis pathways. FSH-induced gene expression profiles on MCV152 cells support the standing hypothesis that FSH is a probable risk factor for ovarian cancerous development.

Standard name | WESTON_VEGFA_TARGETS_12HR
Systematic name | M1545
Organism | Homo sapiens
PMID | 12200464
Authors | Weston GC,Haviv I,Rogers PA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MMEC cells (myometrial endothelium) at 12 h after VEGFA [GeneID=7422] stimulation.
Full description | There is evidence that the vasculature of different organs display different functional characteristics in response to cytokines and growth factors. The aim of this study was to use cDNA gene expression microarray to analyse changes in gene expression following stimulation of myometrial microvascular endothelial cells (MMECs) with vascular endothelial growth factor (VEGF). Primary isolates of MMECs were obtained from fresh hysterectomy specimens and purified with magnetic beads. Cells were stimulated with 15 ng/ml VEGF for 3, 6 and 12 h, and two unstimulated experiments served as controls. A total of six arrays was performed over these time-points. A total of 110 genes were identified as up-regulated by VEGF, 19% of which (21 genes) have previously been reported as up-regulated by VEGF or by angiogenesis. Among the novel genes to be up-regulated by VEGF were brain-derived growth factor, oxytocin receptor and estrogen sulphotransferase. The significance of the genes identified in the physiological and pathological functioning of the myometrial vasculature is discussed.

Standard name | KRASNOSELSKAYA_ILF3_TARGETS_UP
Systematic name | M8323
Organism | Homo sapiens
PMID | 12036489
Authors | Krasnoselskaya-Riz I,Spruill A,Chen YW,Schuster D,Teslovich T,Baker C,Kumar A,Stephan DA
Category | C2
Sub-category | CGP
Brief description | Up-regulated in GHOST(3)CXCR4 cells (osteosarcoma) upon ectopic expression of ILF3 [GeneID=3609].
Full description | Viral infection triggers a cascade of interferon response genes, but the mechanisms that prime such innate antiviral defenses are poorly understood. Among candidate cellular mediators of the antiviral response are the double-stranded RNA (dsRNA)-binding proteins. Here we show that a C-terminal variant of the ubiquitous dsRNA-binding protein, nuclear factor 90 (NF90ctv), can activate the interferon response genes in the absence of viral infection. NF90ctv-expressing cells were infected with the syncytium-inducing HIV-1 strain NL4-3 and were shown to inhibit viral replication. To gain insight into this mechanism of protection, we analyzed the expression profiles of NF90ctv-positive cells as compared with parental cells transduced with the empty vector. Of the 5600 genes represented on the expression arrays, 90 displayed significant (4-fold or more) changes in mRNA levels in NF90-expressing cells. About 50% are known interferon alpha/beta-stimulated genes. The microarray expression data were confirmed by quantitative reverse transcriptase-polymerase chain reaction analysis of six representative interferon-inducible genes. Electrophoretic mobility shift assays showed that the biological response is mediated by the activation of transcription factors in NF90ctv-expressing cells. Functional significance of the activated transcription complex was evaluated by transfection assays with luciferase reporter constructs driven by the interferon-inducible promoter from the 2'-5'-oligoadenylate synthetase (p69) gene. Resistance to HIV-1, caused by the expression of NF90ctv in the cell culture system, appears to be mediated in part by the induction of interferon response genes. This leads to a hypothesis as to the mechanism of action of NF90 in mediating endogenous antiviral responses.

Standard name | CHUANG_OXIDATIVE_STRESS_RESPONSE_UP
Systematic name | M10970
Organism | Homo sapiens
PMID | 12414654
Authors | Chuang YY,Chen Y,Gadisetti,Chandramouli VR,Cook JA,Coffin D,Tsai MH,DeGraff W,Yan H,Zhao S,Russo A,Liu ET,Mitchell JB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) after treatment with the oxydants: hydrogen peroxyde, menadione, and t-butyl hydroperoxyde [PubChem=784;4055;6410].
Full description | Global gene expression patterns in breast cancer cells after treatment with oxidants (hydrogen peroxide, menadione, and t-butyl hydroperoxide) were investigated in three replicate experiments. RNA collected after treatment (at 1, 3, 7, and 24 h) rather than after a single time point, enabled an analysis of gene expression patterns. Using a 17,000 microarray, template-based clustering and multidimensional scaling analysis of the gene expression over the entire time course identified 421 genes as being either up- or down-regulated by the three oxidants. In contrast, only 127 genes were identified for any single time point and a 2-fold change criteria. Surprisingly, the patterns of gene induction were highly similar among the three oxidants; however, differences were observed, particularly with respect to p53, IL-6, and heat-shock related genes. Replicate experiments increased the statistical confidence of the study, whereas changes in gene expression patterns over a time course demonstrated significant additional information versus a single time point. Analyzing the three oxidants simultaneously by template cluster analysis identified genes that heretofore have not been associated with oxidative stress.

Standard name | NATSUME_RESPONSE_TO_INTERFERON_BETA_DN
Systematic name | M2567
Organism | Homo sapiens
PMID | 16140920
Authors | Natsume A,Ishii D,Wakabayashi T,Tsuno T,Hatano H,Mizuno M,Yoshida J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T98 cells (glioma) 48 h after treatment with interferon beta.
Full description | Alkylating agents, such as temozolomide, are among the most effective cytotoxic agents used for malignant gliomas, but responses remain very poor. The DNA repair protein O6-methylguanine-DNA methyltransferase (MGMT) plays an important role in cellular resistance to alkylating agents. IFN-beta can act as a drug sensitizer, enhancing toxicity against a variety of neoplasias, and is widely used in combination with other antitumor agents such as nitrosoureas. Here, we show that IFN-beta sensitizes glioma cells that harbor the unmethylated MGMT promoter and are resistant to temozolomide. By means of oligonucleotide microarray and RNA interference, we reveal that the sensitizing effect of IFN-beta was possibly due to attenuation of MGMT expression via induction of the protein p53. Our study suggests that clinical efficacy of temozolomide might be improved by combination with IFN-beta using appropriate doses and schedules of administration.

Standard name | BAELDE_DIABETIC_NEPHROPATHY_UP
Systematic name | M97
Organism | Homo sapiens
PMID | 15042541
Authors | Baelde HJ,Eikmans M,Doran PP,Lappin DW,de Heer E,Bruijn JA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in glomeruli of kidneys from patients with diabetic nephropathy (type 2 diabetes mellitus).
Full description | BACKGROUND: Diabetic nephropathy (DN) is a frequent complication in patients with diabetes mellitus. To find improved intervention strategies in this disease, it is necessary to investigate the molecular mechanisms involved. To obtain more insight into processes that lead to DN, messenger RNA expression profiles of diabetic glomeruli and glomeruli from healthy individuals were compared. METHODS: Two morphologically normal kidneys and 2 kidneys from patients with DN were used for the study. Glomerular RNA was hybridized in duplicate on Human Genome U95Av2 Arrays (Affymetrix, Santa Clara, CA). Several transcripts were tested further in independent patient groups and at the protein level by immunohistochemistry. RESULTS: Ninety-six genes were upregulated in diabetic glomeruli, whereas 519 genes were downregulated. The list of overexpressed genes in DN includes aquaporin 1, calpain 3, hyaluronoglucosidase, and platelet/endothelial cell adhesion molecule. The list of downregulated genes includes bone morphogenetic protein 2, vascular endothelial growth factor (VEGF), fibroblast growth factor 1, insulin-like growth factor binding protein 2, and nephrin. A decrease in VEGF and nephrin could be validated at the protein level and also at the RNA level in renal biopsy specimens from 5 additional patients with diabetes. CONCLUSION: Results of oligonucleotide microarray analyses on control and diabetic glomeruli are presented and discussed in their relation to vascular damage, mesangial matrix expansion, proliferation, and proteinuria. Our findings suggest that progression of DN might result from diminished tissue repair capability.

Standard name | LINDVALL_IMMORTALIZED_BY_TERT_UP
Systematic name | M1549
Organism | Homo sapiens
PMID | 12702554
Authors | Lindvall C,Hou M,Komurasaki T,Zheng C,Henriksson M,Sedivy JM,Björkholm M,Teh BT,Nordenskjöld M,Xu D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in BJ cells (foreskin fibroblasts) immortalized by expression of TERT [GeneID=7015].
Full description | Reconstitution of telomerase activity by ectopic expression of telomerase reverse transcriptase (hTERT) results in an immortal phenotype in various types of normal human cells, including fibroblasts. Despite lack of transformation characteristics, it is unclear whether hTERT-immortalized cells are physiologically and biochemically the same as their normal counterparts. Here, we compared the gene expression profiles of normal and hTERT-immortalized fibroblasts by using a cDNA microarray containing 20,736 cDNA clones and identified 172 dysregulated genes or expressed sequence tags (ESTs). One of the highly expressed genes in the hTERT-immortalized fibroblasts (hTERT-BJ cells) encodes epiregulin, a potent growth factor. Blockade of epiregulin reduced the growth of hTERT-BJ cells and colony formation of hTERT-transformed fibroblasts. Moreover, inhibition of epiregulin function in immortal hTERT-BJ cells triggered a senescence program. Our results suggest that both activation of telomerase and subsequent induction of epiregulin are required for sustained cell proliferation. Given the significant difference in gene expression profiles between normal and hTERT-immortalized fibroblasts and the close relationship between epiregulin and tumorigenesis, we conclude that hTERT-immortalized cells may not replace their normal counterparts for studies of normal cell biology and that the use of hTERT for expansion of normal human cells for therapeutic purposes must be approached with caution.

Standard name | WU_HBX_TARGETS_3_UP
Systematic name | M6541
Organism | Homo sapiens
PMID | 11439330
Authors | Wu CG,Salvay DM,Forgues M,Valerie K,Farnsworth J,Markin RS,Wang XW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by expression of HBV X protein (HBVgp3) [GeneID=944566] both in SK-Hep-1 cells (hepatocellular carcinoma) and normal primary hepatocytes.
Full description | Hepatitis B virus (HBV) is a major risk factor for the development of hepatocellular carcinoma (HCC). HBV encodes the potentially oncogenic HBx protein, which mainly functions as a transcriptional co-activator involving in multiple gene deregulations. However, mechanisms underlying HBx-mediated oncogenicity remain unclear. To determine the role(s) of HBx in the early genesis of HCC, we utilized the NCI Oncochip microarray that contains 2208 human cDNA clones to examine the gene expression profiles in either freshly isolated normal primary adult human hepatocytes (Hhep) or an HCC cell line (SK-Hep-1) ecotopically expressing HBx via an adenoviral system. The gene expression profiles also were determined in liver samples from HBV-infected chronic active hepatitis patients when compared with normal liver samples. The microarray results were validated through Northern blot analysis of the expression of selected genes. Using reciprocally labeling hybridizations, scatterplot analysis of gene expression ratios in human primary hepatocytes expressing HBx demonstrates that microarrays are highly reproducible. The comparison of gene expression profiles between HBx-expressing primary hepatocytes and HBV-infected liver samples shows a consistent alteration of many cellular genes including a subset of oncogenes (such as c-myc and c-myb) and tumor suppressor genes (such as APC, p53, WAF1 and WT1). Furthermore, clustering algorithm analysis showed distinctive gene expression profiles in Hhep and SK-Hep-1 cells. Our findings are consistent with the hypothesis that the deregulation of cellular genes by oncogenic HBx may be an early event that favors hepatocyte proliferation during liver carcinogenesis.

Standard name | WANG_CISPLATIN_RESPONSE_AND_XPC_DN
Systematic name | M14385
Organism | Homo sapiens
PMID | 15107491
Authors | Wang G,Chuang L,Zhang X,Colton S,Dombkowski A,Reiners J,Diakiw A,Xu XS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in fibroblasts with defective XPC [GeneID=7508] in response to cisplatin [PubChem=2767].
Full description | XPC is an important DNA damage recognition protein involved in DNA nucleotide excision repair. We have studied the role of the XPC protein in cisplatin treatment-mediated cell cycle regulation. Through the comparison of microarray data obtained from human normal fibroblasts and two individual XPC-defective cell lines, 486 genes were identified as XPC-responsive genes in the cisplatin treatment (with a minimal 1.5-fold change) and 297 of these genes were further mapped to biological pathways and gene ontologies. The cell cycle and cell proliferation-related genes were the most affected genes by the XPC defect in the cisplatin treatment. Many other cellular function genes were also affected by the XPC defect in the treatment. Western blot hybridization results revealed that the XPC defect reduced the p53 responses to the cisplatin treatment. The ability to activate caspase-3 was also attenuated in the XPC cells with the treatment. These results suggest that the XPC protein plays a critical role in initiating the cisplatin DNA damaging treatment-mediated signal transduction process, resulting in activation of the p53 pathway and cell cycle arrest that allow DNA repair and apoptosis to take place. These results reveal an important role of the XPC protein in the cancer prevention.

Standard name | MURAKAMI_UV_RESPONSE_6HR_UP
Systematic name | M453
Organism | Homo sapiens
PMID | 11532376
Authors | Murakami T,Fujimoto M,Ohtsuki M,Nakagawa H
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary keratinocytes at 6 h after UVB irradiation.
Full description | Ultraviolet B irradiation initiates and promotes skin cancers, photo-aging, and immune suppression. In order to elucidate the effect of these processes at the level of gene expression, we used cDNA microarray technology to examine the effect of ultraviolet B irradiation on 588 cancer-related genes in human keratinocytes at 1, 6, and 24 h post-irradiation with a mildly cytotoxic dose of ultraviolet B (170 mJ/cm(2)). The viability of the irradiated keratinocytes was 75% at 24 h post-irradiation. Various cytokeratins and transcription factors were up-regulated within 1 h post-irradiation. After 6 h, expression of a variety of genes related to growth regulation (e.g. p21(WAF1), notch 4, and smoothened), apoptosis (e.g. caspase 10, hTRIP, and CRAF1), DNA repair (ERCC1, XRCC1), cytokines (e.g. IL-6, IL-13, TGF-beta, and endothelin 2), and cell adhesion (e.g. RhoE, and RhoGDI) were altered in human keratinocytes. These data suggest the changes in a cascade of gene expression in human keratinocytes occurring within 24 h after UVB exposure. Although the roles of these cellular genes after UVB-irradiation remain to be elucidated, microarray analysis may provide a new view of gene expression in epidermal keratinocytes following UVB exposure.

Standard name | BROWNE_HCMV_INFECTION_20HR_DN
Systematic name | M5601
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 20 h time point that were not down-regulated at the previous time point, 18 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | SIMBULAN_PARP1_TARGETS_UP
Systematic name | M1550
Organism | Mus musculus
PMID | 11016956
Authors | Simbulan-Rosenthal CM,Ly DH,Rosenthal DS,Konopka G,Luo R,Wang ZQ,Schultz PG,Smulson ME
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblasts) from PARP1 [GeneID=142] knockout mice.
Full description | Poly(ADP-ribose) polymerase (PARP) is implicated in the maintenance of genomic integrity, given that inhibition or depletion of this enzyme increases genomic instability in cells exposed to genotoxic agents. We previously showed that immortalized fibroblasts derived from PARP(-/-) mice exhibit an unstable tetraploid population, and partial chromosomal gains and losses in PARP(-/-) mice and immortalized fibroblasts are accompanied by changes in the expression of p53, Rb, and c-Jun, as well as other proteins. A tetraploid population has also now been detected in primary fibroblasts derived from PARP(-/-) mice. Oligonucleotide microarray analysis was applied to characterize more comprehensively the differences in gene expression between asynchronously dividing primary fibroblasts derived from PARP(-/-) mice and their wild-type littermates. Of the 11,000 genes monitored, 91 differentially expressed genes were identified. The loss of PARP results in down-regulation of the expression of several genes involved in regulation of cell cycle progression or mitosis, DNA replication, or chromosomal processing or assembly. PARP deficiency also up-regulates genes that encode extracellular matrix or cytoskeletal proteins that are implicated in cancer initiation or progression or in normal or premature aging. These results provide insight into the mechanism by which PARP deficiency impairs mitotic function, thereby resulting in the genomic alterations and chromosomal abnormalities as well as in altered expression of genes that may contribute to genomic instability, cancer, and aging.

Standard name | ULE_SPLICING_VIA_NOVA2
Systematic name | M1551
Organism | Mus musculus
PMID | 16041372
Authors | Ule J,Ule A,Spencer J,Williams A,Hu JS,Cline M,Wang H,Clark T,Fraser C,Ruggiu M,Zeeberg BR,Kane D,Weinstein JN,Blume J,Darnell RB
Category | C2
Sub-category | CGP
Brief description | Genes whose splicing in neocortex was most affected by knock out of NOVA2 [GeneID=4858].
Full description | Alternative RNA splicing greatly increases proteome diversity and may thereby contribute to tissue-specific functions. We carried out genome-wide quantitative analysis of alternative splicing using a custom Affymetrix microarray to assess the role of the neuronal splicing factor Nova in the brain. We used a stringent algorithm to identify 591 exons that were differentially spliced in the brain relative to immune tissues, and 6.6% of these showed major splicing defects in the neocortex of Nova2-/- mice. We tested 49 exons with the largest predicted Nova-dependent splicing changes and validated all 49 by RT-PCR. We analyzed the encoded proteins and found that all those with defined brain functions acted in the synapse (34 of 40, including neurotransmitter receptors, cation channels, adhesion and scaffold proteins) or in axon guidance (8 of 40). Moreover, of the 35 proteins with known interaction partners, 74% (26) interact with each other. Validating a large set of Nova RNA targets has led us to identify a multi-tiered network in which Nova regulates the exon content of RNAs encoding proteins that interact in the synapse.

Standard name | MARIADASON_REGULATED_BY_HISTONE_ACETYLATION_DN
Systematic name | M1552
Organism | Homo sapiens
PMID | 10969808
Authors | Mariadason JM,Corner GA,Augenlicht LH
Category | C2
Sub-category | CGP
Brief description | Cluster 10: genes down-regulated in SW260 cells (colon cancer) by sodium butyrate and TSA [PubChem=5222465;5562] with the same kinetics with which each alters the level of histone H4 acetylation.
Full description | The short-chain fatty acid butyrate, produced by microbial fermentation of dietary fiber in the large intestine, is a physiological regulator of major pathways of colonic epithelial cell maturation: cell cycle arrest, lineage-specific differentiation, and apoptosis. Microarray analysis of 8,063 sequences demonstrated a complex cascade of reprogramming of SW620 colonic epithelial cells upon treatment with butyrate characterized by the progressive recruitment of gene sets as a function of time. Comparison with the effects of trichostatin A, in conjunction with differences in the kinetics of alteration of histone acetylation induced by butyrate and trichostatin A, identified subsets of induced and repressed genes likely coordinately regulated by altered histone acetylation. The butyrate response was also compared in detail with that of sulindac, a nonsteroidal anti-inflammatory drug with significant chemopreventive activity for colon cancer, and curcumin, a component of mustard and curry structurally and functionally related to sulindac that also has chemopreventive activity. Although gene clusters were identified that showed similar responses to butyrate and sulindac, the data were characterized by the extensive differences in the effects of the two agents. This was striking for functional classes of genes involved in signaling pathways and in cell cycle progression, although butyrate and sulindac induce a similar G0-G1 arrest, elevation of beta-catenin-Tcf signaling, and apoptotic cascade. As regards cell cycle arrest, the underlying mechanism in response to butyrate was most similar to that of the Caco-2 cell line that had spontaneously undergone a G0-G1 arrest and least similar to the G2-M arrest stimulated by curcumin. Thus, high-throughput microarray analysis of gene expression profiles can be used to characterize and distinguish the mechanisms of response of colonic epithelial cells to physiological and pharmacological inducers of cell maturation. This has important implications for characterization of chemopreventive agents and recognition of potential toxicity and synergies. The data bases, gene clusters, and analyses are available at http:// sequence.aecom.yu.edu/genome/.

Standard name | IVANOVA_HEMATOPOIESIS_STEM_CELL
Systematic name | M6813
Organism | Mus musculus
PMID | 12228721
Authors | Ivanova NB,Dimos JT,Schaniel C,Hackney JA,Moore KA,Lemischka IR
Category | C2
Sub-category | CGP
Brief description | Genes in the expression cluster 'HSC Shared': up-regulated in hematopoietic stem cells (HSC) from adult bone marrow and fetal liver.
Full description | Mechanisms regulating self-renewal and cell fate decisions in mammalian stem cells are poorly understood. We determined global gene expression profiles for mouse and human hematopoietic stem cells and other stages of the hematopoietic hierarchy. Murine and human hematopoietic stem cells share a number of expressed gene products, which define key conserved regulatory pathways in this developmental system. Moreover, in the mouse, a portion of the genetic program of hematopoietic stem cells is shared with embryonic and neural stem cells. This overlapping set of gene products represents a molecular signature of stem cells.

Standard name | KUNINGER_IGF1_VS_PDGFB_TARGETS_DN
Systematic name | M14780
Organism | Mus musculus
PMID | 15475267
Authors | Kuninger D,Kuzmickas R,Peng B,Pintar JE,Rotwein P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in C2AS12 cells (myoblast) by IGF1 [GeneID=3479] vs PDGFB [GeneID=5155].
Full description | Peptide growth factors regulate cell fate by activating distinct signal transduction pathways that ultimately influence gene expression. Insulin-like growth factors (IGFs) play central roles in controlling somatic growth and participate in skeletal muscle development and regeneration. In cultured muscle cells, IGF action is critical both for maintaining viability during the transition from proliferating to differentiating myoblasts and for facilitating differentiation. By contrast, platelet-derived growth factor (PDGF) can sustain cell survival but inhibits differentiation. Here we examine the genetic programs that accompany IGF and PDGF action in myoblasts. Through analysis of high-density oligonucleotide arrays containing approximately 36,000 mouse probe sets, we identify 90 transcripts differentially induced by IGF-I, including 28 muscle-specific genes and 33 previously unannotated mRNAs, and 55 transcripts specifically stimulated by PDGF, including 14 unknowns. Detailed study of one IGF-induced mRNA shows that it encodes a protein related to a recently characterized repulsive guidance molecule postulated to regulate neuronal targeting during development. Our results demonstrate the power of transcriptional profiling for gene discovery and provide opportunities for investigating new proteins potentially involved in different aspects of growth factor action in muscle.

Standard name | MEDINA_SMARCA4_TARGETS
Systematic name | M1554
Organism | Homo sapiens
PMID | 15731117
Authors | Medina PP,Carretero J,Ballestar E,Angulo B,Lopez-Rios F,Esteller M,Sanchez-Cespedes M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in H1299 cells (lung cancer) by expression of SMARCA4 [GeneID=6597] off a plasmid vector.
Full description | BRG1, also called SMARCA4, is the catalytic subunit of the SWI/SNF chromatin-remodelling complex and influences transcriptional regulation by disrupting histone-DNA contacts in an ATP-dependent manner. BRG1 and other members of the SWI/SNF complex become inactivated in tumours, implying a role in cancer development. To understand the contribution of BRG1 to lung tumourigenesis, we restored BRG1 in H1299 lung cancer cells and used cDNA microarray analysis to identify changes in gene expression. Forty-three transcripts became activated, whereas two were repressed. Chromatin immunoprecipitation of resulting candidate genes revealed that the CYP3A4 and ZNF185 promoters recruited BRG1 and that recruitment to the CYP3A4 promoter was specific to this gene and did not involve the CYP3A5 or CYP3A7 family members. Moreover, specifically BRG1 but not its homologue BRM was recruited to the CYP3A4 and ZNF185 promoters. To explore their potential relevance in lung tumours, levels of CYP3A4 and ZNF185 transcripts were evaluated in seven additional lung cancer cell lines. CYP3A4 was undetectable in any of the lung cancer cells tested, and only the CYP3A5 family member was present in the A549 and Calu-3 cells. In contrast, the amount of ZNF185 transcript clearly varied among lung cancer cell lines and severely reduced levels were observed in BRG1-deficient cells, except those of A427. We extended these observations to 27 lung primary tumours using real-time RT-PCR (TaqMan) and observed that four (15%) and 14 (52%) of them had BRG1 and ZNF185 downregulation, respectively, when compared with normal lung. No significant correlation between reduced levels of BRG1 and ZNF185 was observed, indicating that additional mechanisms to BRG1 inactivation may contribute to the loss of ZNF185 expression in lung tumours. In conclusion, our results provide evidence that transcriptional activation of ZNF185 and CYP3A4 is mediated by direct association of BRG1 with their promoters and also indicate that a decreased level of ZNF185 is a common feature of lung tumours and may be of biological relevance in lung carcinogenesis.

Standard name | KANG_FLUOROURACIL_RESISTANCE_UP
Systematic name | M10540
Organism | Homo sapiens
PMID | 14734480
Authors | Kang HC,Kim IJ,Park JH,Shin Y,Ku JL,Jung MS,Yoo BC,Kim HK,Park JG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in gastric cancer cell lines resistant to 5-fluorouracil [PubChem=3385].
Full description | PURPOSE: A major obstacle in chemotherapy is treatment failure due to anticancer drug resistance. The emergence of acquired resistance results from host factors and genetic or epigenetic changes in the cancer cells. The purpose of this study was to identify differentially expressed genes associated with acquisition of resistance in human gastric cancer cells. EXPERIMENTAL DESIGN: We performed global gene expression analysis in the acquired drug-resistant gastric cancer cell lines to the commonly used drugs 5-fluorouracil, doxorubicin, and cisplatin using Affymetrix HG-U133A microarray. The gene expression patterns of 10 chemoresistant gastric cancer cell lines were compared with those of four parent cell lines using fold-change and Wilcoxon's test for data analysis. RESULTS: We identified over 250 genes differentially expressed in 5-fluorouracil-, cisplatin-, or doxorubicin-resistant gastric cancer cell lines. Our expression analysis also identified eight multidrug resistance candidate genes that were associated with resistance to two or more of the tested chemotherapeutic agents. Among these, midkine (MDK), a heparin-binding growth factor, was overexpressed in all drug-resistant cell lines, strongly suggesting that MDK might contribute to multidrug resistance in gastric cancer cells. CONCLUSIONS: Our investigation provides comprehensive gene information associated with acquired resistance to anticancer drugs in gastric cancer cells and a basis for additional functional studies.

Standard name | MAHAJAN_RESPONSE_TO_IL1A_DN
Systematic name | M12107
Organism | Homo sapiens
PMID | 12091409
Authors | Mahajan VB,Wei C,McDonnell PJ 3rd
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in corneal fibroblasts after treatment with IL1A [GeneID=3552].
Full description | PURPOSE: To identify changes in gene expression in human corneal fibroblasts after exposure to interleukin-1alpha. METHODS: RNA was isolated from cultured human corneal fibroblasts after treatment with interleukin-1alpha and subjected to DNA microarray analysis. Changes in gene expression were determined by comparison with untreated cells in three independent experiments after a Bayesian statistical analysis of variance. RESULTS: Changes in gene expression were reproducibly observed in 165 genes representing previously identified and novel chemokines, matrix molecules, membrane receptors, angiogenic mediators, and transcription factors that correlated with pathophysiological responses to inflammation. Dramatic increases in gene expression were observed with exodus-1 (CCL20), MMP-12, and RhoA. CONCLUSIONS: DNA microarray analysis of the corneal fibroblast response to interleukin-1alpha provides important insight into modeling changes in gene expression and suggests novel therapeutic targets for the control of corneal inflammation.

Standard name | RUAN_RESPONSE_TO_TNF_DN
Systematic name | M1555
Organism | Mus musculus
PMID | 12732648
Authors | Ruan H,Pownall HJ,Lodish HF
Category | C2
Sub-category | CGP
Brief description | Adipocyte abundant genes down-regulated in 3T3-L1 cells (fibroblasts induced to differentiate to adipocytes) in response to TNF [GeneID=7124].
Full description | Troglitazone (TGZ), a member of the thiazolidinedione class of anti-diabetic compounds and a peroxisome proliferator activator receptor-gamma (PPAR-gamma) agonist, restores systemic insulin sensitivity and improves the full insulin resistance syndrome in vivo. The mechanisms underlying its in vivo function are not understood. Here we investigated the potential functional interaction between PPAR-gamma and NF-kappaB in adipocytes. We show that TGZ selectively blocked tumor necrosis factor-alpha-induced and NF-kappaB-dependent repression of multiple adipocyte-specific genes and induction of growth phase and other genes. This occurs without interfering with NF-kappaB expression, activation, nuclear translocation, or DNA binding and without suppressing NF-kappaB-dependent survival signals. Notably, the expressions of some tumor necrosis factor-alpha-induced genes in adipocytes were unaffected by PPAR-gamma activation. In reporter gene assays in HeLa cells, ectopic expression of PPAR-gamma abolished induction of a NF-kappaB-responsive reporter gene by the p65 subunit (RelA) of NF-kappaB, and the inhibition was further enhanced in the presence of TGZ. Conversely, overexpression of p65 inhibited induction of a PPAR-gamma-responsive reporter gene by activated PPAR-gamma in a dose-dependent manner. The inhibitory effect was independent of the presence of NF-kappaB-binding sites in the promoter region. Other NF-kappaB family members, p50 and c-Rel as well as the S276A mutant of p65, blocked PPAR-gamma-mediated gene transcription less effectively. Thus, p65 antagonizes the transcriptional regulatory activity of PPAR-gamma in adipocytes, and PPAR-gamma activation can at least partially override the inhibitory effects of p65 on the expression of key adipocyte genes. Our data suggest that inhibition of NF-kappaB activity is a mechanism by which PPAR-gamma agonists improve insulin sensitivity in vivo and that adipocyte NF-kappaB is a potential therapeutic target for obesity-linked type 2 diabetes.

Standard name | BLALOCK_ALZHEIMERS_DISEASE_UP
Systematic name | M12921
Organism | Homo sapiens
PMID | 14769913
Authors | Blalock EM,Geddes JW,Chen KC,Porter NM,Markesbery WR,Landfield PW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in brain from patients with Alzheimer's disease.
Full description | The pathogenesis of incipient Alzheimer's disease (AD) has been resistant to analysis because of the complexity of AD and the overlap of its early-stage markers with normal aging. Gene microarrays provide new tools for addressing complexity because they allow overviews of the simultaneous activity of multiple cellular pathways. However, microarray data interpretation is often hindered by low statistical power, high false positives or false negatives, and by uncertain relevance to functional endpoints. Here, we analyzed hippocampal gene expression of nine control and 22 AD subjects of varying severity on 31 separate microarrays. We then tested the correlation of each gene's expression with MiniMental Status Examination (MMSE) and neurofibrillary tangle (NFT) scores across all 31 subjects regardless of diagnosis. These well powered tests revealed a major transcriptional response comprising thousands of genes significantly correlated with AD markers. Several hundred of these genes were also correlated with AD markers across only control and incipient AD subjects (MMSE > 20). Biological process categories associated with incipient AD-correlated genes were identified statistically (ease program) and revealed up-regulation of many transcription factor/signaling genes regulating proliferation and differentiation, including tumor suppressors, oligodendrocyte growth factors, and protein kinase A modulators. In addition, up-regulation of adhesion, apoptosis, lipid metabolism, and initial inflammation processes occurred, and down-regulation of protein folding/metabolism/transport and some energy metabolism and signaling pathways took place. These findings suggest a new model of AD pathogenesis in which a genomically orchestrated up-regulation of tumor suppressor-mediated differentiation and involution processes induces the spread of pathology along myelinated axons.

Standard name | DELASERNA_MYOD_TARGETS_UP
Systematic name | M1557
Organism | Mus musculus
PMID | 15870273
Authors | de la Serna IL,Ohkawa Y,Berkes CA,Bergstrom DA,Dacwag CS,Tapscott SJ,Imbalzano AN
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NIH 3T3 cells (fibroblasts) 24 h after inducing MyoD [GeneID=4654] differentiation program.
Full description | The activation of muscle-specific gene expression requires the coordinated action of muscle regulatory proteins and chromatin-remodeling enzymes. Microarray analysis performed in the presence or absence of a dominant-negative BRG1 ATPase demonstrated that approximately one-third of MyoD-induced genes were highly dependent on SWI/SNF enzymes. To understand the mechanism of activation, we performed chromatin immunoprecipitations analyzing the myogenin promoter. We found that H4 hyperacetylation preceded Brg1 binding in a MyoD-dependent manner but that MyoD binding occurred subsequent to H4 modification and Brg1 interaction. In the absence of functional SWI/SNF enzymes, muscle regulatory proteins did not bind to the myogenin promoter, thereby providing evidence for SWI/SNF-dependent activator binding. We observed that the homeodomain factor Pbx1, which cooperates with MyoD to stimulate myogenin expression, is constitutively bound to the myogenin promoter in a SWI/SNF-independent manner, suggesting a two-step mechanism in which MyoD initially interacts indirectly with the myogenin promoter and attracts chromatin-remodeling enzymes, which then facilitate direct binding by MyoD and other regulatory proteins.

Standard name | BURTON_ADIPOGENESIS_12
Systematic name | M1558
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Strongly down-regulated at 2 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | LEONARD_HYPOXIA
Systematic name | M19622
Organism | Homo sapiens
PMID | 12885785
Authors | Leonard MO,Cottell DC,Godson C,Brady HR,Taylor CT
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HK-2 cells kidney tubular epithelium) under hypoxia and down-regulated on re-oxygenation.
Full description | Epithelial cells of the kidney represent a primary target for hypoxic injury in ischemic acute renal failure (ARF); however, the underlying transcriptional mechanism(s) remain undefined. In this study, human proximal tubular epithelial cells (HK-2) exposed to hypoxia in vitro demonstrated a non-lethal but dysfunctional phenotype, closely reflective of the epithelial pathobiology of ARF. HK-2 cells exposed to hypoxia demonstrated increased paracellular permeability, decreased proliferation, loss of tight junctional integrity, and significant actin disassembly in the absence of cell death. Microarray analysis of transcriptomic changes underlying this response identified a distinct cohort of 48 genes with a closely shared hypoxia-dependent expression profile. Within this hypoxia-sensitive cluster were genes identified previously as hypoxia-inducible factor-1 (HIF-1)-dependent (e.g. vascular endothelial growth factor and adrenomedullin) as well as genes not previously known to be hypoxia-responsive (e.g. stanniocalcin 2). In hypoxia, HIF-1 bound to evolutionarily conserved hypoxia-response elements (HRE) in the promoters of these genes as well as to the HRE consensus motif. A further subset of these genes, not associated with transcriptional regulation by HIF-1, was also present, suggesting alternative HIF-1-independent pathways. Overexpression of HIF-1 alpha in normoxia induced the expression of a significant number of the hypoxia-dependent genes; however, it did not induce the pathophysiologic epithelial response. In summary, hypoxia-elicited alterations in renal proximal tubular epithelial cells in vitro closely resemble the epithelial pathophysiology of ARF. Our data indicate that although this event may rely heavily on HIF-1-dependent gene transcription, it is likely that separate hypoxia-dependent transcriptional regulators also play a role.

Standard name | KAYO_AGING_MUSCLE_DN
Systematic name | M17261
Organism | Macaca mulatta
PMID | 11309484
Authors | Kayo T,Allison DB,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Downregulated in the vastus lateralis muscle of aged vs young adult rhesus monkeys
Full description | In laboratory rodents, caloric restriction (CR) retards several age-dependent physiological and biochemical changes in skeletal muscle, including increased steady-state levels of oxidative damage to lipids, DNA, and proteins. We have previously used high-density oligonucleotide arrays to show that CR can prevent or delay most of the major age-related transcriptional alterations in the gastrocnemius muscle of C57BL/6 mice. Here we report the effects of aging and adult-onset CR on the gene expression profile of 7,070 genes in the vastus lateralis muscle from rhesus monkeys. Gene expression analysis of aged rhesus monkeys (mean age of 26 years) was compared with that of young animals (mean age of 8 years). Aging resulted in a selective up-regulation of transcripts involved in inflammation and oxidative stress, and a down-regulation of genes involved in mitochondrial electron transport and oxidative phosphorylation. Middle-aged monkeys (mean age of 20 years) subjected to CR since early adulthood (mean age of 11 years) were studied to determine the gene expression profile induced by CR. CR resulted in an up-regulation of cytoskeletal protein-encoding genes, and also a decrease in the expression of genes involved in mitochondrial bioenergetics. Surprisingly, we did not observe any evidence for an inhibitory effect of adult-onset CR on age-related changes in gene expression. These results indicate that the induction of an oxidative stress-induced transcriptional response may be a common feature of aging in skeletal muscle of rodents and primates, but the extent to which CR modifies these responses may be species-specific.

Standard name | KAAB_FAILED_HEART_ATRIUM_UP
Systematic name | M8009
Organism | Homo sapiens
PMID | 15103417
Authors | Kääb S,Barth AS,Margerie D,Dugas M,Gebauer M,Zwermann L,Merk S,Pfeufer A,Steinmeyer K,Bleich M,Kreuzer E,Steinbeck G,Näbauer M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in atria of failing hearts (DCM and ICM) compared to healthy controls.
Full description | To obtain region- and disease-specific transcription profiles of human myocardial tissue, we explored mRNA expression from all four chambers of eight explanted failing [idiopathic dilated cardiomyopathy (DCM), n=5; ischemic cardiomyopathy (ICM), n=3], and five non-failing hearts using high-density oligonucleotide arrays (Affymetrix U95Av2). We performed pair-wise comparisons of gene expression in the categories (1) atria versus ventricles, (2) disease-regulated genes in atria and (3) disease-regulated genes in ventricles. In the 51 heart samples examined, 549 genes showed divergent distribution between atria and ventricles (272 genes with higher expression in atria, 277 genes with higher expression in ventricles). Two hundred and eighty-eight genes were differentially expressed in failing myocardium compared to non-failing hearts (19 genes regulated in atria and ventricles, 172 regulated in atria only, 97 genes regulated in ventricles only). For disease-regulated genes, down-regulation was 4.5-times more common than up-regulation. Functional classification according to Gene Ontology identified specific biological patterns for differentially expressed genes. Eleven genes were validated by RT-PCR showing a good correlation with the microarray data. Our goal was to determine a gene expression fingerprint of the heart, accounting for region- and disease-specific aspects. Recognizing common gene expression patterns in heart failure will significantly contribute to the understanding of heart failure and may eventually lead to the development of pathway-specific therapies.

Standard name | INGA_TP53_TARGETS
Systematic name | M16284
Organism | Homo sapiens
PMID | 12446780
Authors | Inga A,Storici F,Darden TA,Resnick MA
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters contain TP53 [GeneID=7157] response elements.
Full description | Little is known about the mechanisms that regulate differential transactivation by p53. We developed a system in the yeast Saccharomyces cerevisiae that addresses p53 transactivation capacity from 26 different p53 response elements (REs) under conditions where all other factors, such as chromatin, are kept constant. The system relies on a tightly regulated promoter (rheostatable) that can provide for a broad range of p53 expression. The p53 transactivation capacity toward each 20- to 22-bp-long RE could be ranked by using a simple phenotypic assay. Surprisingly, there was as much as a 1,000-fold difference in transactivation. There was no correlation between the functional rank and statistical predictions of binding energy of the REs. Instead we found that the central sequence element in an RE greatly affects p53 transactivation capacity, possibly because of DNA structural properties. Our results suggest that intrinsic DNA binding affinity and p53 protein levels are important contributors to p53-induced differential transactivation. These results are also relevant to understanding the regulation by other families of transcription factors that recognize several sequence-related response elements and/or have tightly regulated expression. We found that p53 had weak activity towards half the apoptotic REs. In addition, p53 alleles associated with familial breast cancer, previously classified as wild type, showed subtle differences in transactivation capacity towards several REs.

Standard name | MARIADASON_REGULATED_BY_HISTONE_ACETYLATION_UP
Systematic name | M1559
Organism | Homo sapiens
PMID | 10969808
Authors | Mariadason JM,Corner GA,Augenlicht LH
Category | C2
Sub-category | CGP
Brief description | Cluster 9: genes up-regulated in SW260 cells (colon cancer) by sodium butyrate and TSA [PubChem=5222465;5562] with the same kinetics with which each alters the level of histone H4 acetylation.
Full description | The short-chain fatty acid butyrate, produced by microbial fermentation of dietary fiber in the large intestine, is a physiological regulator of major pathways of colonic epithelial cell maturation: cell cycle arrest, lineage-specific differentiation, and apoptosis. Microarray analysis of 8,063 sequences demonstrated a complex cascade of reprogramming of SW620 colonic epithelial cells upon treatment with butyrate characterized by the progressive recruitment of gene sets as a function of time. Comparison with the effects of trichostatin A, in conjunction with differences in the kinetics of alteration of histone acetylation induced by butyrate and trichostatin A, identified subsets of induced and repressed genes likely coordinately regulated by altered histone acetylation. The butyrate response was also compared in detail with that of sulindac, a nonsteroidal anti-inflammatory drug with significant chemopreventive activity for colon cancer, and curcumin, a component of mustard and curry structurally and functionally related to sulindac that also has chemopreventive activity. Although gene clusters were identified that showed similar responses to butyrate and sulindac, the data were characterized by the extensive differences in the effects of the two agents. This was striking for functional classes of genes involved in signaling pathways and in cell cycle progression, although butyrate and sulindac induce a similar G0-G1 arrest, elevation of beta-catenin-Tcf signaling, and apoptotic cascade. As regards cell cycle arrest, the underlying mechanism in response to butyrate was most similar to that of the Caco-2 cell line that had spontaneously undergone a G0-G1 arrest and least similar to the G2-M arrest stimulated by curcumin. Thus, high-throughput microarray analysis of gene expression profiles can be used to characterize and distinguish the mechanisms of response of colonic epithelial cells to physiological and pharmacological inducers of cell maturation. This has important implications for characterization of chemopreventive agents and recognition of potential toxicity and synergies. The data bases, gene clusters, and analyses are available at http:// sequence.aecom.yu.edu/genome/.

Standard name | DASU_IL6_SIGNALING_SCAR_UP
Systematic name | M292
Organism | Homo sapiens
PMID | 15095275
Authors | Dasu MR,Hawkins HK,Barrow RE,Xue H,Herndon DN
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hypertrophic scar fibroblasts in response to IL6 [GeneID=3569].
Full description | The structural rearrangement of collagen fibres in hypertrophic scar causes abnormal contracture, low tensile strength, and raised scars, which cause functional impairment and disfigurement. It is hypothesized that changes in the genes of cytokines, extracellular matrix proteins, and proteins regulating programmed cell death are related to hypertrophic scar formation. To test this hypothesis, fibroblasts were cultured from hypertrophic scars and their response to interleukin-6 (IL-6) stimulation was studied by defining their gene expression profiles. Affymetrix gene chip analysis was used to identify up- or down-regulation in the 12 625 genes present in the affymetrix array. RT-PCR and ELISA assays were used to validate microarray expression profiles further. Comparison of gene profiles showed an increase of 12 genes in hypertrophic scar fibroblasts compared with normal skin fibroblasts, while the expression of 14 genes decreased. Thirty-three genes were affected by IL-6 treatment in the hypertrophic scar fibroblasts, while 57 genes were affected in normal skin fibroblasts. Messenger RNA to beta-actin ratios for matrix metalloproteinase-1 (MMP-1) and MMP-3 were increased with IL-6 in normal skin fibroblasts from 2.43 +/- 0.06 to 5.50 +/- 0.45 and from 0.75 +/- 0.09 to 1.98 +/- 0.01, respectively. No change in these matrix metalloproteinases could be shown with IL-6 stimulation in hypertrophic scar fibroblasts. Secreted protein levels of pro-MMP-1 and MMP-3 were elevated in the supernatants from normal skin fibroblasts from 2.00 +/- 0.09 and 1.72 +/- 0.10 ng/ml to 4.60 +/- 0.12 and 3.41 +/- 0.20 ng/ml, respectively, after treatment with IL-6 (p < 0.05). No changes were observed in hypertrophic scar fibroblasts treated with IL-6. Values are means +/- SEM. The absence of any up-regulation of MMP-1 and MMP-3 in hypertrophic scar fibroblasts, in response to IL-6, suggests that suppression of matrix metalloproteinases may play a role in the excessive accumulation of collagen formed in hypertrophic scars. While the pathogenesis of abnormal hypertrophic scars remains poorly understood, the use of gene expression arrays may prove helpful in identifying the mechanisms responsible for this type of abnormal scar formation and in formulating an effective therapeutic protocol.

Standard name | LINDVALL_IMMORTALIZED_BY_TERT_DN
Systematic name | M1561
Organism | Homo sapiens
PMID | 12702554
Authors | Lindvall C,Hou M,Komurasaki T,Zheng C,Henriksson M,Sedivy JM,Björkholm M,Teh BT,Nordenskjöld M,Xu D
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in BJ cells (foreskin fibroblasts) immortalized by expression of TERT [GeneID=7015].
Full description | Reconstitution of telomerase activity by ectopic expression of telomerase reverse transcriptase (hTERT) results in an immortal phenotype in various types of normal human cells, including fibroblasts. Despite lack of transformation characteristics, it is unclear whether hTERT-immortalized cells are physiologically and biochemically the same as their normal counterparts. Here, we compared the gene expression profiles of normal and hTERT-immortalized fibroblasts by using a cDNA microarray containing 20,736 cDNA clones and identified 172 dysregulated genes or expressed sequence tags (ESTs). One of the highly expressed genes in the hTERT-immortalized fibroblasts (hTERT-BJ cells) encodes epiregulin, a potent growth factor. Blockade of epiregulin reduced the growth of hTERT-BJ cells and colony formation of hTERT-transformed fibroblasts. Moreover, inhibition of epiregulin function in immortal hTERT-BJ cells triggered a senescence program. Our results suggest that both activation of telomerase and subsequent induction of epiregulin are required for sustained cell proliferation. Given the significant difference in gene expression profiles between normal and hTERT-immortalized fibroblasts and the close relationship between epiregulin and tumorigenesis, we conclude that hTERT-immortalized cells may not replace their normal counterparts for studies of normal cell biology and that the use of hTERT for expansion of normal human cells for therapeutic purposes must be approached with caution.

Standard name | DAZARD_RESPONSE_TO_UV_SCC_DN
Systematic name | M7484
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SCC12B2 cells (squamous cell carcinoma) by UV-B irradiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | CHIBA_RESPONSE_TO_TSA
Systematic name | M16977
Organism | Homo sapiens
PMID | 15336447
Authors | Chiba T,Yokosuka O,Arai M,Tada M,Fukai K,Imazeki F,Kato M,Seki N,Saisho H
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in more than one of several human hepatoma cell lines by TSA [PubChem=5562].
Full description | BACKGROUND/AIMS: Epigenetics is the key factor in the regulation of gene expression. We conducted cDNA microarray analysis to screen for genes induced by histone deacetylase (HDAC) inhibition and examined epigenetic alterations. METHODS: Microarray analysis was performed in six hepatoma cell lines and primary hepatocytes treated with trichostatin A (TSA). mRNA expression of several genes was examined by reverse transcription-polymerase chain reaction in TSA-treated cells and hepatoma samples. Acetylated histones and methylation status in 5'CpG islands was assessed by chromatin immunoprecipitation (ChIP) assay and bisulfite genomic sequencing, respectively. RESULTS: Fifty-seven genes showed greater than 2-fold change after TSA treatment in multiple cell lines. Among them, four genes including p21(WAF1) exhibited substantial induction (greater than 5-fold changes). Decreased mRNA levels of these genes in hepatoma tissues were observed in more than half of patients. ChIP assay, in general, demonstrated a good correlation between mRNA expression and histone acetylation, but only a limited correlation with the methylated DNA in the promoter region. CONCLUSIONS: We identified 57 up-regulated genes by TSA treatment in hepatoma cells and some of them appeared to be cancer-related genes in hepatomas. The alterations in acetylated histones are likely closely associated with gene expression.

Standard name | RODWELL_AGING_KIDNEY_DN
Systematic name | M5408
Organism | Homo sapiens
PMID | 15562319
Authors | Rodwell GE,Sonu R,Zahn JM,Lund J,Wilhelmy J,Wang L,Xiao W,Mindrinos M,Crane E,Segal E,Myers BD,Brooks JD,Davis RW,Higgins J,Owen AB,Kim SK
Category | C2
Sub-category | CGP
Brief description | Genes whose expression decreases with age in normal kidney.
Full description | In this study, we found 985 genes that change expression in the cortex and the medulla of the kidney with age. Some of the genes whose transcripts increase in abundance with age are known to be specifically expressed in immune cells, suggesting that immune surveillance or inflammation increases with age. The age-regulated genes show a similar aging profile in the cortex and the medulla, suggesting a common underlying mechanism for aging. Expression profiles of these age-regulated genes mark not only age, but also the relative health and physiology of the kidney in older individuals. Finally, the set of aging-regulated kidney genes suggests specific mechanisms and pathways that may play a role in kidney degeneration with age.

Standard name | YIH_RESPONSE_TO_ARSENITE_C2
Systematic name | M1562
Organism | Homo sapiens
PMID | 12016162
Authors | Yih LH,Peck K,Lee TC
Category | C2
Sub-category | CGP
Brief description | Genes in cluster 2: moderately up-regulated in HFW cells (fibroblast) upon treatment with sodium arsenite [PubChem=26435] at all time points.
Full description | Arsenic compounds are widely distributed and arsenic ingestion is associated with many human diseases, including blackfoot disease, atherosclerosis, and cancers. However, the underlying mechanism of arsenic toxicity is not understood. In human fibroblast cells (HFW), arsenite is known to induce oxidative damage, chromosome aberrations, cell cycle arrest, and aneuploidy, and the manifestation of these cellular responses is dependent on changes in gene expression which can be analyzed using the cDNA microarray technique. In this study, cDNA microarray membranes with 568 human genes were used to examine mRNA profile changes in HFW cells treated for 0 to 24 h with 5 microM sodium arsenite. On the basis of the mean value for three independent experiments, 133 target genes were selected for a 2 x 3 self-organizing map cluster analysis; 94 were found to be induced by arsenite treatment, whereas 39 were repressed. These genes were categorized as signal transduction, transcriptional regulation, cell cycle control, stress responses, proteolytic enzymes, and miscellaneous. Significant changes in the signaling-related and transcriptional regulation genes indicated that arsenite induces complex toxicopathological injury.

Standard name | KANG_DOXORUBICIN_RESISTANCE_UP
Systematic name | M1037
Organism | Homo sapiens
PMID | 14734480
Authors | Kang HC,Kim IJ,Park JH,Shin Y,Ku JL,Jung MS,Yoo BC,Kim HK,Park JG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in gastric cancer cell lines: doxorubicin [PubChem=31703] resistant vs sensitive.
Full description | PURPOSE: A major obstacle in chemotherapy is treatment failure due to anticancer drug resistance. The emergence of acquired resistance results from host factors and genetic or epigenetic changes in the cancer cells. The purpose of this study was to identify differentially expressed genes associated with acquisition of resistance in human gastric cancer cells. EXPERIMENTAL DESIGN: We performed global gene expression analysis in the acquired drug-resistant gastric cancer cell lines to the commonly used drugs 5-fluorouracil, doxorubicin, and cisplatin using Affymetrix HG-U133A microarray. The gene expression patterns of 10 chemoresistant gastric cancer cell lines were compared with those of four parent cell lines using fold-change and Wilcoxon's test for data analysis. RESULTS: We identified over 250 genes differentially expressed in 5-fluorouracil-, cisplatin-, or doxorubicin-resistant gastric cancer cell lines. Our expression analysis also identified eight multidrug resistance candidate genes that were associated with resistance to two or more of the tested chemotherapeutic agents. Among these, midkine (MDK), a heparin-binding growth factor, was overexpressed in all drug-resistant cell lines, strongly suggesting that MDK might contribute to multidrug resistance in gastric cancer cells. CONCLUSIONS: Our investigation provides comprehensive gene information associated with acquired resistance to anticancer drugs in gastric cancer cells and a basis for additional functional studies.

Standard name | BROWNE_HCMV_INFECTION_48HR_DN
Systematic name | M12144
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 48 h time point that were not down-regulated at the previous time point, 24 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | BROWNE_HCMV_INFECTION_48HR_UP
Systematic name | M19929
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 48 h time point that were not up-regulated at the previous time point, 24 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | BURTON_ADIPOGENESIS_5
Systematic name | M1564
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Up-regulated at 48-96 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | WESTON_VEGFA_TARGETS
Systematic name | M1565
Organism | Homo sapiens
PMID | 12200464
Authors | Weston GC,Haviv I,Rogers PA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MMEC cells (myometrial endothelium) by VEGFA [GeneID=7422] stimulation.
Full description | There is evidence that the vasculature of different organs display different functional characteristics in response to cytokines and growth factors. The aim of this study was to use cDNA gene expression microarray to analyse changes in gene expression following stimulation of myometrial microvascular endothelial cells (MMECs) with vascular endothelial growth factor (VEGF). Primary isolates of MMECs were obtained from fresh hysterectomy specimens and purified with magnetic beads. Cells were stimulated with 15 ng/ml VEGF for 3, 6 and 12 h, and two unstimulated experiments served as controls. A total of six arrays was performed over these time-points. A total of 110 genes were identified as up-regulated by VEGF, 19% of which (21 genes) have previously been reported as up-regulated by VEGF or by angiogenesis. Among the novel genes to be up-regulated by VEGF were brain-derived growth factor, oxytocin receptor and estrogen sulphotransferase. The significance of the genes identified in the physiological and pathological functioning of the myometrial vasculature is discussed.

Standard name | CHEN_LVAD_SUPPORT_OF_FAILING_HEART_UP
Systematic name | M12300
Organism | Homo sapiens
PMID | 12824457
Authors | Chen Y,Park S,Li Y,Missov E,Hou M,Han X,Hall JL,Miller LW,Bache RJ
Category | C2
Sub-category | CGP
Brief description | Up-regulated genesin the left ventricle myocardium of patients with heart failure following implantation of LVAD (left ventricular assist device).
Full description | Chronic unloading of the failing heart with a left ventricular assist device (LVAD) can decrease cardiac mass and myocyte size and has the potential to improve contractile function. To study the effect of chronic ventricular unloading on myocardial gene expression, a microarray (U133A, Affymetrix) profiling gene expression was compared before and after LVAD support in seven patients with idiopathic dilated cardiomyopathy and end-stage heart failure. On average, 1,374 +/- 155 genes were reported as increased and 1,629 +/- 45 as decreased after LVAD support. A total of 130 gene transcripts achieved the strict criteria for upregulation and 49 gene transcripts for downregulation after LVAD support. Upregulated genes included a large proportion of transcription factors, genes related to cell growth/apoptosis/DNA repair, cell structure proteins, metabolism, and cell signaling/communication. LVAD support resulted in downregulation of genes for a group of cytokines. To validate the array data, 10 altered genes were confirmed by real-time RT-PCR. Further study showed that the phosphoinositide-3-kinase-forkhead protein pathway and proteins related to nitric oxide synthesis, including eNOS and dimethylarginine dimethylaminohydrolase isoform 1 (DDAH1, an enzyme regulating endogenous nitric oxide synthase activity), were significantly increased during the cardiac remodeling process. Increased eNOS and DDAH1 expression after LVAD support may contribute to improved endothelial function of the failing hearts.

Standard name | BROWNE_HCMV_INFECTION_8HR_DN
Systematic name | M7846
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 8 h time point that were not down-regulated at the previous time point, 6 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | APRELIKOVA_BRCA1_TARGETS
Systematic name | M1568
Organism | Mus musculus
PMID | 11384963
Authors | Aprelikova O,Pace AJ,Fang B,Koller BH,Liu ET
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in embryonic stem cells with BRCA1 [GeneID=672] loss of function (LOF).
Full description | BRCA1 gene is a tumor suppressor for breast and ovarian cancers with the putative role in DNA repair and transcription. To characterize the role of BRCA1 in transcriptional regulation, we analyzed gene expression profiles of mouse embryonic stem cells deficient in BRCA1 using microarray technology. We found that loss of BRCA1 correlated with decreased expression of several groups of genes including stress response genes, cytoskeleton genes, and genes involved in protein synthesis and degradation. Previous study showed that BRCA1 is a transcriptional co-activator of p53 protein; however the majority of p53 target genes remained at the same expression levels in BRCA1 knockout cells as in the wild type cells. The only p53 target gene down-regulated with the loss of BRCA1 was 14-3-3 sigma, a major G(2)/M checkpoint control gene. Similar to cells with decreased 14-3-3 sigma activity, BRCA1-deficient cells were unable to sustain G(2)/M growth arrest after exposure to ionizing radiation. We find that BRCA1 induction of 14-3-3 sigma requires the presence of wild type p53 and can be regulated by a minimal p53 response element.

Standard name | VERRECCHIA_RESPONSE_TO_TGFB1_C2
Systematic name | M4767
Organism | Homo sapiens
PMID | 11279127
Authors | Verrecchia F,Chu ML,Mauviel A
Category | C2
Sub-category | CGP
Brief description | Cluster 2: ECM related genes up-regulated in dermal fibroblasts within 30 min after TGFB1 [GeneID=7040] addition; reached a plateau after that.
Full description | Despite major advances in the understanding of the intimate mechanisms of transforming growth factor-beta (TGF-beta) signaling through the Smad pathway, little progress has been made in the identification of direct target genes. In this report, using cDNA microarrays, we have focussed our attention on the characterization of extracellular matrix-related genes rapidly induced by TGF-beta in human dermal fibroblasts and attempted to identify the ones whose up-regulation by TGF-beta is Smad-mediated. For a gene to qualify as a direct Smad target, we postulated that it had to meet the following criteria: (1) rapid (30 min) and significant (at least 2-fold) elevation of steady-state mRNA levels upon TGF-beta stimulation, (2) activation of the promoter by both exogenous TGF-beta and co-transfected Smad3 expression vector, (3) up-regulation of promoter activity by TGF-beta blocked by both dominant-negative Smad3 and inhibitory Smad7 expression vectors, and (4) promoter transactivation by TGF-beta not possible in Smad3(-/-) mouse embryo fibroblasts. Using this stringent approach, we have identified COL1A2, COL3A1, COL6A1, COL6A3, and tissue inhibitor of metalloproteases-1 as definite TGF-beta/Smad3 targets. Extrapolation of this approach to other extracellular matrix-related gene promoters also identified COL1A1 and COL5A2, but not COL6A2, as novel Smad targets. Together, these results represent a significant step toward the identification of novel, early-induced Smad-dependent TGF-beta target genes in fibroblasts.

Standard name | KIM_GASTRIC_CANCER_CHEMOSENSITIVITY
Systematic name | M14702
Organism | Homo sapiens
PMID | 15033468
Authors | Kim HK,Choi IJ,Kim HS,Kim JH,Kim E,Park IS,Chun JH,Kim IH,Kim IJ,Kang HC,Park JH,Bae JM,Lee JS,Park JG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in gastric cancer patients refractory to chemotherapy treatment with 5-fluorouracil and cisplatin [PubChem=3385;2767] compared to the sensitive state.
Full description | The mechanisms of intrinsic and/or acquired anti-cancer drug resistance have been described in in vitro resistance models, but the clinical relevance has remained undefined. We undertook a prospective study to identify correlations between gene expression and clinical resistance to 5-FU/cisplatin. We compared expression profiles from gastric cancer endoscopic biopsy specimens obtained at a chemosensitive state (partial remission after 5-FU/cisplatin) with those obtained at a refractory state (disease progression), using Affymetrix oligonucleotide microarray technology (U133A). Using 119 discriminating probes and a cross-validation approach, we were able to correctly identify the chemo-responsiveness of 7 pairs of training samples and 1 independent test pair. These exploratory data demonstrate that the gene expression profiles differ between chemosensitive and refractory state gastric cancer biopsy samples.

Standard name | BANDRES_RESPONSE_TO_CARMUSTIN_MGMT_24HR_DN
Systematic name | M7429
Organism | Homo sapiens
PMID | 15980968
Authors | Bandres E,Andion E,Escalada A,Honorato B,Catalan V,Cubedo E,Cordeu L,Garcia F,Zarate R,Zabalegui N,Garcia-Foncillas J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T98G cells (glioma, express MGMT [GeneID=4255]) by carmustine [PubChem=2578] at 24 h.
Full description | Chemotherapy with the alkylating agent BCNU (1,3-bis (2-chloroethyl)-1-nitrosourea) is the most commonly used chemotherapeutic agent for gliomas. However, the usefulness of this agent is limited because tumor cell resistance to BCNU is frequently found in clinical brain tumor therapy. The O6-methylguanine-DNA methyltransferase protein (MGMT) reverses alkylation at the O6 position of guanine and we have reported the role of MGMT in the response of brain tumors to alkylating agents. However, the different mechanisms underlying the patterns related to MGMT remain unclear. To better understand the molecular mechanism by which BCNU exerts its effect in glioma cell lines according MGMT expression, we used microarray technology to interrogate 3800 known genes and determine the gene expression profiles altered by BCNU treatment. Our results showed that treatment with BCNU alters the expression of a diverse group of genes in a time-dependent manner. A subset of gene changes was found common in both glioma cell lines and other subset is specific of each cell line. After 24 h of BCNU treatment, up-regulation of transcription factors involved in the nucleation of both RNA polymerase II and III transcription initiation complexes was reported. Interestingly, BCNU promoted the expression of actin-dependent regulators of chromatin. Similar effects were found with higher BCNU doses in MGMT+ cell line showing a similar mechanism that in MGMT-deficient cell with standard doses. Our data suggest that human glioma cell lines treated with BCNU, independently of MGMT expression, show changes in the expression of cell cycle and survival-related genes interfering the transcription mechanisms and the chromatin regulation.

Standard name | GENTILE_UV_RESPONSE_CLUSTER_D5
Systematic name | M13814
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Cluster d5: genes progressively down-regulated in WS1 cells (fibroblast) through 18 h after irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | BRACHAT_RESPONSE_TO_METHOTREXATE_UP
Systematic name | M1569
Organism | Mus musculus
PMID | 12447701
Authors | Brachat A,Pierrat B,Xynos A,Brecht K,Simonen M,Brüngger A,Heim J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in FL5.12 cells (pro-B lymphocyte) in response to methotrexate [PubChem=4112].
Full description | DNA microarrays are powerful tools for the analysis of gene expression on a genomic scale. The importance of individual regulatory events for the process under study can however not be deduced unequivocally without additional experiments. We devised a strategy to identify central regulators of cancer drug responses by combining the results of microarray experiments with efficient methods for phenotypic testing of candidate genes. We exposed murine FL5.12 pro-B cells to cisplatin, camptothecin, methotrexate or paclitaxel, respectively and analysed the patterns of gene expression with cDNA microarrays. Drug-specific regulatory events as well as intersections between different apoptotic pathways, including previously studied responses to staurosporine and interleukin-3 (IL-3) deprivation, were identified. Genes shared by at least three pathways were chosen for further analysis. Ectopic expression of three such genes, TEAP, GP49B, and Lipin1 was found to have an anti-proliferative effect on pro-B cells. Interestingly, we identified hemoglobin alpha as a strong pro-apoptotic regulator. While hemoglobin-expressing cells were growing normally in the presence of IL-3, they displayed accelerated apoptosis with similar kinetics as Bax overexpressing cells upon IL-3 removal. The pro-apoptotic effect of hemoglobin was suppressed by Bcl-2 and was characterized by enhanced stimulation of caspase activity.

Standard name | RHODES_UNDIFFERENTIATED_CANCER
Systematic name | M8365
Organism | Homo sapiens
PMID | 15184677
Authors | Rhodes DR,Yu J,Shanker K,Deshpande N,Varambally R,Ghosh D,Barrette T,Pandey A,Chinnaiyan AM
Category | C2
Sub-category | CGP
Brief description | Genes commonly up-regulated in undifferentiated cancer relative to well-differentiated cancer, based on the meta-analysis of the OncoMine gene expression database.
Full description | Many studies have used DNA microarrays to identify the gene expression signatures of human cancer, yet the critical features of these often unmanageably large signatures remain elusive. To address this, we developed a statistical method, comparative metaprofiling, which identifies and assesses the intersection of multiple gene expression signatures from a diverse collection of microarray data sets. We collected and analyzed 40 published cancer microarray data sets, comprising 38 million gene expression measurements from >3,700 cancer samples. From this, we characterized a common transcriptional profile that is universally activated in most cancer types relative to the normal tissues from which they arose, likely reflecting essential transcriptional features of neoplastic transformation. In addition, we characterized a transcriptional profile that is commonly activated in various types of undifferentiated cancer, suggesting common molecular mechanisms by which cancer cells progress and avoid differentiation. Finally, we validated these transcriptional profiles on independent data sets.

Standard name | BROWNE_HCMV_INFECTION_14HR_UP
Systematic name | M17225
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 14 h time point that were not up-regulated at the previous time point, 12 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | YAMAZAKI_TCEB3_TARGETS_DN
Systematic name | M1571
Organism | Mus musculus
PMID | 12604609
Authors | Yamazaki K,Aso T,Ohnishi Y,Ohno M,Tamura K,Shuin T,Kitajima S,Nakabeppu Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in embryonic stem cells from TCEB3 [GeneID=6924] knockout mice.
Full description | Elongin A is a transcription elongation factor that increases the overall rate of mRNA chain elongation by RNA polymerase II. To investigate the function of Elongin A in vivo, the two alleles of the Elongin A gene have been disrupted by homologous recombination in murine embryonic stem (ES) cells. The Elongin A-deficient ES cells are viable, but show a slow growth phenotype because they undergo a delayed mitosis. The cDNA microarray and RNase protection assay using the wild-type and Elongin A-deficient ES cells indicate that the expression of only a small subset of genes is affected in the mutant cells. Taken together, our results suggest that Elongin A regulates transcription of a subset but not all of genes and reveal a linkage between Elongin A function and cell cycle progression.

Standard name | LEE_CALORIE_RESTRICTION_MUSCLE_UP
Systematic name | M1572
Organism | Mus musculus
PMID | 10464095
Authors | Lee CK,Klopp RG,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Up-regulated in the gastrocnemius muscle of aged (30-month) mice subjected to caloric restriction diet since young adulthood.
Full description | The gene expression profile of the aging process was analyzed in skeletal muscle of mice. Use of high-density oligonucleotide arrays representing 6347 genes revealed that aging resulted in a differential gene expression pattern indicative of a marked stress response and lower expression of metabolic and biosynthetic genes. Most alterations were either completely or partially prevented by caloric restriction, the only intervention known to retard aging in mammals. Transcriptional patterns of calorie-restricted animals suggest that caloric restriction retards the aging process by causing a metabolic shift toward increased protein turnover and decreased macromolecular damage.

Standard name | MACLACHLAN_BRCA1_TARGETS_UP
Systematic name | M17772
Organism | Homo sapiens
PMID | 10644742
Authors | MacLachlan TK,Somasundaram K,Sgagias M,Shifman Y,Muschel RJ,Cowan KH,El-Deiry WS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SW480 cells (colon cancer with mutated p53 [GeneID=7157]) upon expression of BRCA1 [GeneID=672] off an adenovirus vector.
Full description | The breast and ovarian cancer susceptibility gene product BRCA1 has been reported to be expressed in a cell cycle-dependent manner; possess transcriptional activity; associate with several proteins, including the p53 tumor suppressor; and play an integral role in certain types of DNA repair. We show here that ectopic expression of BRCA1 using an adenovirus vector (Ad-BRCA1) leads to dephosphorylation of the retinoblastoma protein accompanied by a decrease in cyclin-dependent kinase activity. Flow cytometric analysis on Ad-BRCA1-infected cells revealed a G(1) or G(2) phase accumulation. High density cDNA array screening of colon, lung, and breast cancer cells identified several genes affected by BRCA1 expression in a p53-independent manner, including DNA damage response genes and genes involved in cell cycle control. Notable changes included induction of the GADD45 and GADD153 genes and a reduction in cyclin B1 expression. Therefore, BRCA1 has the potential to modulate the expression of genes and function of proteins involved in cell cycle control and DNA damage response pathways.

Standard name | VERRECCHIA_RESPONSE_TO_TGFB1_C1
Systematic name | M16026
Organism | Homo sapiens
PMID | 11279127
Authors | Verrecchia F,Chu ML,Mauviel A
Category | C2
Sub-category | CGP
Brief description | Cluster 1: ECM related genes up-regulated in dermal fibroblasts within 30 min after TGFB1 [GeneID=7040] addition, and which kept increasing with time.
Full description | Despite major advances in the understanding of the intimate mechanisms of transforming growth factor-beta (TGF-beta) signaling through the Smad pathway, little progress has been made in the identification of direct target genes. In this report, using cDNA microarrays, we have focussed our attention on the characterization of extracellular matrix-related genes rapidly induced by TGF-beta in human dermal fibroblasts and attempted to identify the ones whose up-regulation by TGF-beta is Smad-mediated. For a gene to qualify as a direct Smad target, we postulated that it had to meet the following criteria: (1) rapid (30 min) and significant (at least 2-fold) elevation of steady-state mRNA levels upon TGF-beta stimulation, (2) activation of the promoter by both exogenous TGF-beta and co-transfected Smad3 expression vector, (3) up-regulation of promoter activity by TGF-beta blocked by both dominant-negative Smad3 and inhibitory Smad7 expression vectors, and (4) promoter transactivation by TGF-beta not possible in Smad3(-/-) mouse embryo fibroblasts. Using this stringent approach, we have identified COL1A2, COL3A1, COL6A1, COL6A3, and tissue inhibitor of metalloproteases-1 as definite TGF-beta/Smad3 targets. Extrapolation of this approach to other extracellular matrix-related gene promoters also identified COL1A1 and COL5A2, but not COL6A2, as novel Smad targets. Together, these results represent a significant step toward the identification of novel, early-induced Smad-dependent TGF-beta target genes in fibroblasts.

Standard name | GAJATE_RESPONSE_TO_TRABECTEDIN_DN
Systematic name | M16617
Organism | Homo sapiens
PMID | 12198119
Authors | Gajate C,An F,Mollinedo F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HeLa cells (cervical carcinoma) by trabectedin [PubChem=3199].
Full description | We have found that ecteinascidin-743 (ET-743) inhibited cell proliferation at 1-10 ng/ml, leading to S and G(2)/M arrest and subsequent apoptosis, and induced early apoptosis without previous cell cycle arrest at 10-100 ng/ml in cancer cells. ET-743-mediated apoptosis, did not involve Fas/CD95. ET-743 induced c-Jun NH(2)-terminal kinase (JNK) and caspase-3 activation, and JNK and caspase inhibition prevented ET-743-induced apoptosis. ET-743 failed to promote apoptosis in caspase-3-deficient MCF-7 cells, further implicating caspase-3 in its proapoptotic action. Overexpression of bcl-2 by gene transfer abrogated ET-743-induced apoptosis, but cells underwent cell cycle arrest. ET-743 triggered cytochrome c release from mitochondria that was inhibited by Bcl-2 overexpression. Inhibition of transcription or protein synthesis did not prevent ET-743-induced apoptosis, but abrogated ET-743-induced cell cycle arrest. Microarray analyses revealed changes in the expression of a small number of cell cycle-related genes (p21, GADD45A, cyclin G2, MCM5, and histones) that suggested their putative involvement in ET-743-induced cell cycle arrest. These data indicate that ET-743 is a very potent anticancer drug showing dose-dependent cytostatic and proapoptotic effects through activation of two different signaling pathways, namely a transcription-dependent pathway leading to cell cycle arrest and a transcription-independent route leading to rapid apoptosis that involves mitochondria, JNK, and caspase-3.

Standard name | LEE_AGING_MUSCLE_DN
Systematic name | M1574
Organism | Mus musculus
PMID | 10464095
Authors | Lee CK,Klopp RG,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Downregulated in the gastrocnemius muscle of aged adult mice (30-month) vs young adult (5-month)
Full description | The gene expression profile of the aging process was analyzed in skeletal muscle of mice. Use of high-density oligonucleotide arrays representing 6347 genes revealed that aging resulted in a differential gene expression pattern indicative of a marked stress response and lower expression of metabolic and biosynthetic genes. Most alterations were either completely or partially prevented by caloric restriction, the only intervention known to retard aging in mammals. Transcriptional patterns of calorie-restricted animals suggest that caloric restriction retards the aging process by causing a metabolic shift toward increased protein turnover and decreased macromolecular damage.

Standard name | ZHANG_PROLIFERATING_VS_QUIESCENT
Systematic name | M16992
Organism | Homo sapiens
PMID | 14517420
Authors | Zhang HT,Gorn M,Smith K,Graham AP,Lau KK,Bicknell R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HDMEC cells (microvascular endothelium): proliferating vs quiescent cells.
Full description | Endothelial cells are known to be a rich source of transcriptional gene expression. Recent technological advances now permit the detailed profiling of mRNA expression using arrays of known cDNAs on blots. We have used such arrays to examine expression of mRNA by primary isolates of human foreskin microvascular endothelial cells in the proliferative and quiescent state. Cells were stimulated by a combination of known growth factors for these cells including epidermal growth factor (EGF), vascular endothelial growth factor (VEGF), and 'endothelial cell growth supplement (ECGS)' either alone or in combination. Analysis showed the expression of many mRNAs but of the 588 examined, only one, namely monocyte chemotactic protein-1 (MCP-1), showed a decrease on treatment with EGF. A combination of image grabbing followed by subtractive densitometry enabled identification of the mRNAs upregulated in proliferating endothelium. In consideration of the possibility of selective vascular targeting, of particular interest was the increase in expression of the mRNA for the cell surface proteins vascular endothelial (VE-) and neural (N-) cadherin and alpha5, alphav, beta1 and beta3 integrins. The alpha5 integrin offers a previously unrecognized opportunity for vascular targeting.

Standard name | GAJATE_RESPONSE_TO_TRABECTEDIN_UP
Systematic name | M4932
Organism | Homo sapiens
PMID | 12198119
Authors | Gajate C,An F,Mollinedo F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HeLa cells (cervical carcinoma) by trabectedin [PubChem=3199].
Full description | We have found that ecteinascidin-743 (ET-743) inhibited cell proliferation at 1-10 ng/ml, leading to S and G(2)/M arrest and subsequent apoptosis, and induced early apoptosis without previous cell cycle arrest at 10-100 ng/ml in cancer cells. ET-743-mediated apoptosis, did not involve Fas/CD95. ET-743 induced c-Jun NH(2)-terminal kinase (JNK) and caspase-3 activation, and JNK and caspase inhibition prevented ET-743-induced apoptosis. ET-743 failed to promote apoptosis in caspase-3-deficient MCF-7 cells, further implicating caspase-3 in its proapoptotic action. Overexpression of bcl-2 by gene transfer abrogated ET-743-induced apoptosis, but cells underwent cell cycle arrest. ET-743 triggered cytochrome c release from mitochondria that was inhibited by Bcl-2 overexpression. Inhibition of transcription or protein synthesis did not prevent ET-743-induced apoptosis, but abrogated ET-743-induced cell cycle arrest. Microarray analyses revealed changes in the expression of a small number of cell cycle-related genes (p21, GADD45A, cyclin G2, MCM5, and histones) that suggested their putative involvement in ET-743-induced cell cycle arrest. These data indicate that ET-743 is a very potent anticancer drug showing dose-dependent cytostatic and proapoptotic effects through activation of two different signaling pathways, namely a transcription-dependent pathway leading to cell cycle arrest and a transcription-independent route leading to rapid apoptosis that involves mitochondria, JNK, and caspase-3.

Standard name | VERRECCHIA_RESPONSE_TO_TGFB1_C5
Systematic name | M6470
Organism | Homo sapiens
PMID | 11279127
Authors | Verrecchia F,Chu ML,Mauviel A
Category | C2
Sub-category | CGP
Brief description | Cluster 5: ECM related genes up-regulated in dermal fibroblasts later than 30 min after TGFB1 [GeneID=7040] addition; decreased slowly after the peak at 120 min time point.
Full description | Despite major advances in the understanding of the intimate mechanisms of transforming growth factor-beta (TGF-beta) signaling through the Smad pathway, little progress has been made in the identification of direct target genes. In this report, using cDNA microarrays, we have focussed our attention on the characterization of extracellular matrix-related genes rapidly induced by TGF-beta in human dermal fibroblasts and attempted to identify the ones whose up-regulation by TGF-beta is Smad-mediated. For a gene to qualify as a direct Smad target, we postulated that it had to meet the following criteria: (1) rapid (30 min) and significant (at least 2-fold) elevation of steady-state mRNA levels upon TGF-beta stimulation, (2) activation of the promoter by both exogenous TGF-beta and co-transfected Smad3 expression vector, (3) up-regulation of promoter activity by TGF-beta blocked by both dominant-negative Smad3 and inhibitory Smad7 expression vectors, and (4) promoter transactivation by TGF-beta not possible in Smad3(-/-) mouse embryo fibroblasts. Using this stringent approach, we have identified COL1A2, COL3A1, COL6A1, COL6A3, and tissue inhibitor of metalloproteases-1 as definite TGF-beta/Smad3 targets. Extrapolation of this approach to other extracellular matrix-related gene promoters also identified COL1A1 and COL5A2, but not COL6A2, as novel Smad targets. Together, these results represent a significant step toward the identification of novel, early-induced Smad-dependent TGF-beta target genes in fibroblasts.

Standard name | GERHOLD_ADIPOGENESIS_DN
Systematic name | M1576
Organism | Mus musculus
PMID | 12021175
Authors | Gerhold DL,Liu F,Jiang G,Li Z,Xu J,Lu M,Sachs JR,Bagchi A,Fridman A,Holder DJ,Doebber TW,Berger J,Elbrecht A,Moller DE,Zhang BB
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated during differentiation of 3T3-L1 cells (fibroblast) into adipocytes in response to adipogenic hormones.
Full description | PPAR gamma is an adipocyte-specific nuclear hormone receptor. Agonists of PPAR gamma, such as thiazolidinediones (TZDs), promote adipocyte differentiation and have insulin-sensitizing effects in animals and diabetic patients. Affymetrix oligonucleotide arrays representing 6347 genes were employed to profile the gene expression responses of mature 3T3-L1 adipocytes and differentiating preadipocytes to a TZD PPAR gamma agonist in vitro. The expression of 579 genes was significantly up- or down-regulated by more than 1.5-fold during differentiation and/or by treatment with TZD, and these genes were organized into 32 clusters that demonstrated concerted changes in expression of genes controlling cell growth or lipid metabolism. Quantitative PCR was employed to further characterize gene expression and led to the identification of beta-catenin as a new PPAR gamma target gene. Both mRNA and protein levels for beta-catenin were down-regulated in 3T3-L1 adipocytes compared with fibroblasts and were further decreased by treatment of adipocytes with PPAR gamma agonists. Treatment of db/db mice with a PPAR gamma agonist also resulted in reduction of beta-catenin mRNA levels in adipose tissue. These results suggest that beta-catenin plays an important role in the regulation of adipogenesis. Thus, the transcriptional patterns revealed in this study further the understanding of adipogenesis process and the function of PPAR gamma activation.

Standard name | LU_AGING_BRAIN_UP
Systematic name | M5547
Organism | Homo sapiens
PMID | 15190254
Authors | Lu T,Pan Y,Kao SY,Li C,Kohane I,Chan J,Yankner BA
Category | C2
Sub-category | CGP
Brief description | Age up-regulated genes in the human frontal cortex.
Full description | The ageing of the human brain is a cause of cognitive decline in the elderly and the major risk factor for Alzheimer's disease. The time in life when brain ageing begins is undefined. Here we show that transcriptional profiling of the human frontal cortex from individuals ranging from 26 to 106 years of age defines a set of genes with reduced expression after age 40. These genes play central roles in synaptic plasticity, vesicular transport and mitochondrial function. This is followed by induction of stress response, antioxidant and DNA repair genes. DNA damage is markedly increased in the promoters of genes with reduced expression in the aged cortex. Moreover, these gene promoters are selectively damaged by oxidative stress in cultured human neurons, and show reduced base-excision DNA repair. Thus, DNA damage may reduce the expression of selectively vulnerable genes involved in learning, memory and neuronal survival, initiating a programme of brain ageing that starts early in adult life.

Standard name | BURTON_ADIPOGENESIS_3
Systematic name | M1577
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Strongly up-regulated at 16-24 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | DAZARD_RESPONSE_TO_UV_NHEK_UP
Systematic name | M19693
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NHEK cells (normal keratinocytes) by UV-B irradiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | LIAN_LIPA_TARGETS_3M
Systematic name | M16088
Organism | Mus musculus
PMID | 16127159
Authors | Lian X,Yan C,Qin Y,Knox L,Li T,Du H
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated at 3 months of age in lungs from LIPA [GeneID=3988] knockout mice, which display pulmonary pathology.
Full description | The functional roles of neutral lipids in the lung are poorly understood. However, blocking cholesteryl ester and triglyceride metabolism in lysosomal acid lipase gene knockout mice (lal-/-) results in severe pathogenic phenotypes in the lung, including massive neutrophil infiltration, foamy macrophage accumulation, unwanted cell growth, and emphysema. To elucidate the mechanism underlining these pathologies, we performed Affymetrix GeneChip microarray analysis of 1-, 3-, and 6-month-old mice and identified aberrant gene expression that progressed with age. Among changed genes, matrix metalloproteinase (MMP)-12, apoptosis inhibitor 6 (Api-6), erythroblast transformation-specific domain (Ets) transcription factor family member Spi-C, and oncogene MafB were increased 100-, 70-, 40-, and 10-fold, respectively, in lal-/- lungs versus the wild-type lungs. The pathogenic increases of these molecules occurred primarily in alveolar type II epithelial cells. Transcriptional activities of the MMP-12 and Api-6 promoters were stimulated by Spi-C or MafB in respiratory epithelial cells. Treatment with 9-hydroxyoctadecanoic acids and ciglitazone significantly rescued lal-/- pulmonary inflammation and aberrant gene expression. In addition, both compounds as well as peroxisome proliferator-activated receptor gamma inhibited MMP-12 and Api-6 promoter activities. These data suggest that inflammation-triggered cell growth and emphysema during lysosomal acid lipase deficiency are partially caused by peroxisome proliferator-activated receptor-gamma inactivation.

Standard name | ZHU_CMV_ALL_UP
Systematic name | M19630
Organism | Homo sapiens
PMID | 9826724
Authors | Zhu H,Cong JP,Mamtora G,Gingeras T,Shenk T
Category | C2
Sub-category | CGP
Brief description | Up-regulated at any timepoint following infection of primary human foreskin fibroblasts with CMV
Full description | Mechanistic insights to viral replication and pathogenesis generally have come from the analysis of viral gene products, either by studying their biochemical activities and interactions individually or by creating mutant viruses and analyzing their phenotype. Now it is possible to identify and catalog the host cell genes whose mRNA levels change in response to a pathogen. We have used DNA array technology to monitor the level of approximately 6,600 human mRNAs in uninfected as compared with human cytomegalovirus-infected cells. The level of 258 mRNAs changed by a factor of 4 or more before the onset of viral DNA replication. Several of these mRNAs encode gene products that might play key roles in virus-induced pathogenesis, identifying them as intriguing targets for further study.

Standard name | BURTON_ADIPOGENESIS_8
Systematic name | M1579
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Progressively down-regulated 8-96 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | DELLA_RESPONSE_TO_TSA_AND_BUTYRATE
Systematic name | M7912
Organism | Homo sapiens
PMID | 11423116
Authors | Della Ragione F,Criniti V,Della Pietra V,Borriello A,Oliva A,Indaco S,Yamamoto T,Zappia V
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HT-29 cells (colon cancer) by the combination of trichostatin A (TSA) and sodium butyrate [PubChem=5562;5222465].
Full description | A wealth of evidence correlates the chemopreventive activity of a fiber-rich diet with the production of butyrate. In order to identify the genes transcriptionally modulated by the molecule, we analyzed the expression profile of butyrate-treated colon cancer cells by means of cDNA expression arrays. Moreover, the effect of trichostatin A, a specific histone deacetylase inhibitor, was studied. A superimposable group of 23 genes out of 588 investigated is modulated by both butyrate and trichostatin A. Among them, a major target was tob-1, a gene involved in the control of cell cycle. tob-1 is also up-regulated by butyrate in a neuroblastoma-derived cell line, and its overexpression in the colon cells caused growth arrest. Our findings represent an extensive analysis of genes modulated by butyrate and identify completely new effectors of its biological activities.

Standard name | RUAN_RESPONSE_TO_TNF_TROGLITAZONE_UP
Systematic name | M1581
Organism | Mus musculus
PMID | 12732648
Authors | Ruan H,Pownall HJ,Lodish HF
Category | C2
Sub-category | CGP
Brief description | Adipocyte abundant genes up-regulated in 3T3-L1 cells (fibroblasts induced to differentiate to adipocytes) in response to troglitazone [PubChem=5591] and TNF [GeneID=7124].
Full description | Troglitazone (TGZ), a member of the thiazolidinedione class of anti-diabetic compounds and a peroxisome proliferator activator receptor-gamma (PPAR-gamma) agonist, restores systemic insulin sensitivity and improves the full insulin resistance syndrome in vivo. The mechanisms underlying its in vivo function are not understood. Here we investigated the potential functional interaction between PPAR-gamma and NF-kappaB in adipocytes. We show that TGZ selectively blocked tumor necrosis factor-alpha-induced and NF-kappaB-dependent repression of multiple adipocyte-specific genes and induction of growth phase and other genes. This occurs without interfering with NF-kappaB expression, activation, nuclear translocation, or DNA binding and without suppressing NF-kappaB-dependent survival signals. Notably, the expressions of some tumor necrosis factor-alpha-induced genes in adipocytes were unaffected by PPAR-gamma activation. In reporter gene assays in HeLa cells, ectopic expression of PPAR-gamma abolished induction of a NF-kappaB-responsive reporter gene by the p65 subunit (RelA) of NF-kappaB, and the inhibition was further enhanced in the presence of TGZ. Conversely, overexpression of p65 inhibited induction of a PPAR-gamma-responsive reporter gene by activated PPAR-gamma in a dose-dependent manner. The inhibitory effect was independent of the presence of NF-kappaB-binding sites in the promoter region. Other NF-kappaB family members, p50 and c-Rel as well as the S276A mutant of p65, blocked PPAR-gamma-mediated gene transcription less effectively. Thus, p65 antagonizes the transcriptional regulatory activity of PPAR-gamma in adipocytes, and PPAR-gamma activation can at least partially override the inhibitory effects of p65 on the expression of key adipocyte genes. Our data suggest that inhibition of NF-kappaB activity is a mechanism by which PPAR-gamma agonists improve insulin sensitivity in vivo and that adipocyte NF-kappaB is a potential therapeutic target for obesity-linked type 2 diabetes.

Standard name | BURTON_ADIPOGENESIS_2
Systematic name | M1582
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Strongly up-regulated at 8 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | VERRECCHIA_EARLY_RESPONSE_TO_TGFB1
Systematic name | M4737
Organism | Homo sapiens
PMID | 11279127
Authors | Verrecchia F,Chu ML,Mauviel A
Category | C2
Sub-category | CGP
Brief description | ECM related genes up-regulated early (within 30 min) in dermal fibroblasts after addition of TGFB1 [GeneID=7040].
Full description | Despite major advances in the understanding of the intimate mechanisms of transforming growth factor-beta (TGF-beta) signaling through the Smad pathway, little progress has been made in the identification of direct target genes. In this report, using cDNA microarrays, we have focussed our attention on the characterization of extracellular matrix-related genes rapidly induced by TGF-beta in human dermal fibroblasts and attempted to identify the ones whose up-regulation by TGF-beta is Smad-mediated. For a gene to qualify as a direct Smad target, we postulated that it had to meet the following criteria: (1) rapid (30 min) and significant (at least 2-fold) elevation of steady-state mRNA levels upon TGF-beta stimulation, (2) activation of the promoter by both exogenous TGF-beta and co-transfected Smad3 expression vector, (3) up-regulation of promoter activity by TGF-beta blocked by both dominant-negative Smad3 and inhibitory Smad7 expression vectors, and (4) promoter transactivation by TGF-beta not possible in Smad3(-/-) mouse embryo fibroblasts. Using this stringent approach, we have identified COL1A2, COL3A1, COL6A1, COL6A3, and tissue inhibitor of metalloproteases-1 as definite TGF-beta/Smad3 targets. Extrapolation of this approach to other extracellular matrix-related gene promoters also identified COL1A1 and COL5A2, but not COL6A2, as novel Smad targets. Together, these results represent a significant step toward the identification of novel, early-induced Smad-dependent TGF-beta target genes in fibroblasts.

Standard name | XU_GH1_EXOGENOUS_TARGETS_UP
Systematic name | M16128
Organism | Homo sapiens
PMID | 15845533
Authors | Xu XQ,Emerald BS,Goh EL,Kannan N,Miller LD,Gluckman PD,Liu ET,Lobie PE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MFCF-7 cells (breast cancer) by exogenous HG1 [GeneID=2688].
Full description | We have exploited a discrepancy in the oncogenic potential of autocrine and exogenous human growth hormone (hGH) in an attempt to identify molecules that could potentially be involved in oncogenic transformation of the human mammary epithelial cell. Microarray analysis of 19,000 human genes identified a subset of 305 genes in a human mammary carcinoma cell line that were remarkably different in their response to autocrine and exogenous hGH. Autocrine and exogenous hGH also regulated 167 common genes. Semiquantitative reverse transcription-PCR confirmed differential regulation of genes by either autocrine or exogenous hGH. Functional analysis of one of the identified autocrine hGH-regulated genes, TFF3, determined that its expression is sufficient to support anchorage-independent growth of human mammary carcinoma cells. Small interfering RNA-mediated knockdown of TFF3 concordantly abrogated anchorage-independent growth of mammary carcinoma cells and abrogated the ability of autocrine hGH to stimulate oncogenic transformation of immortalized human mammary epithelial cells. Further functional characterization of the identified subset of specifically autocrine hGH regulated genes will delineate additional novel oncogenes for the human mammary epithelial cell.

Standard name | ZHU_CMV_8_HR_DN
Systematic name | M9806
Organism | Homo sapiens
PMID | 9826724
Authors | Zhu H,Cong JP,Mamtora G,Gingeras T,Shenk T
Category | C2
Sub-category | CGP
Brief description | Down-regulated at 8 h following infection of primary human foreskin fibroblasts with CMV
Full description | Mechanistic insights to viral replication and pathogenesis generally have come from the analysis of viral gene products, either by studying their biochemical activities and interactions individually or by creating mutant viruses and analyzing their phenotype. Now it is possible to identify and catalog the host cell genes whose mRNA levels change in response to a pathogen. We have used DNA array technology to monitor the level of approximately 6,600 human mRNAs in uninfected as compared with human cytomegalovirus-infected cells. The level of 258 mRNAs changed by a factor of 4 or more before the onset of viral DNA replication. Several of these mRNAs encode gene products that might play key roles in virus-induced pathogenesis, identifying them as intriguing targets for further study.

Standard name | ZHU_CMV_24_HR_DN
Systematic name | M4065
Organism | Homo sapiens
PMID | 9826724
Authors | Zhu H,Cong JP,Mamtora G,Gingeras T,Shenk T
Category | C2
Sub-category | CGP
Brief description | Down-regulated at 24 h following infection of primary human foreskin fibroblasts with CMV
Full description | Mechanistic insights to viral replication and pathogenesis generally have come from the analysis of viral gene products, either by studying their biochemical activities and interactions individually or by creating mutant viruses and analyzing their phenotype. Now it is possible to identify and catalog the host cell genes whose mRNA levels change in response to a pathogen. We have used DNA array technology to monitor the level of approximately 6,600 human mRNAs in uninfected as compared with human cytomegalovirus-infected cells. The level of 258 mRNAs changed by a factor of 4 or more before the onset of viral DNA replication. Several of these mRNAs encode gene products that might play key roles in virus-induced pathogenesis, identifying them as intriguing targets for further study.

Standard name | WU_HBX_TARGETS_3_DN
Systematic name | M3518
Organism | Homo sapiens
PMID | 11439330
Authors | Wu CG,Salvay DM,Forgues M,Valerie K,Farnsworth J,Markin RS,Wang XW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by expression of HBV X protein (HBVgp3) [GeneID=944566] both in SK-Hep-1 cells (hepatocellular carcinoma) and normal primary hepatocytes.
Full description | Hepatitis B virus (HBV) is a major risk factor for the development of hepatocellular carcinoma (HCC). HBV encodes the potentially oncogenic HBx protein, which mainly functions as a transcriptional co-activator involving in multiple gene deregulations. However, mechanisms underlying HBx-mediated oncogenicity remain unclear. To determine the role(s) of HBx in the early genesis of HCC, we utilized the NCI Oncochip microarray that contains 2208 human cDNA clones to examine the gene expression profiles in either freshly isolated normal primary adult human hepatocytes (Hhep) or an HCC cell line (SK-Hep-1) ecotopically expressing HBx via an adenoviral system. The gene expression profiles also were determined in liver samples from HBV-infected chronic active hepatitis patients when compared with normal liver samples. The microarray results were validated through Northern blot analysis of the expression of selected genes. Using reciprocally labeling hybridizations, scatterplot analysis of gene expression ratios in human primary hepatocytes expressing HBx demonstrates that microarrays are highly reproducible. The comparison of gene expression profiles between HBx-expressing primary hepatocytes and HBV-infected liver samples shows a consistent alteration of many cellular genes including a subset of oncogenes (such as c-myc and c-myb) and tumor suppressor genes (such as APC, p53, WAF1 and WT1). Furthermore, clustering algorithm analysis showed distinctive gene expression profiles in Hhep and SK-Hep-1 cells. Our findings are consistent with the hypothesis that the deregulation of cellular genes by oncogenic HBx may be an early event that favors hepatocyte proliferation during liver carcinogenesis.

Standard name | SU_KIDNEY
Systematic name | M5672
Organism | Homo sapiens
PMID | 11904358
Authors | Su AI,Cooke MP,Ching KA,Hakak Y,Walker JR,Wiltshire T,Orth AP,Vega RG,Sapinoso LM,Moqrich A,Patapoutian A,Hampton GM,Schultz PG,Hogenesch JB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated specifically in human kidney tissue.
Full description | High-throughput gene expression profiling has become an important tool for investigating transcriptional activity in a variety of biological samples. To date, the vast majority of these experiments have focused on specific biological processes and perturbations. Here, we have generated and analyzed gene expression from a set of samples spanning a broad range of biological conditions. Specifically, we profiled gene expression from 91 human and mouse samples across a diverse array of tissues, organs, and cell lines. Because these samples predominantly come from the normal physiological state in the human and mouse, this dataset represents a preliminary, but substantial, description of the normal mammalian transcriptome. We have used this dataset to illustrate methods of mining these data, and to reveal insights into molecular and physiological gene function, mechanisms of transcriptional regulation, disease etiology, and comparative genomics. Finally, to allow the scientific community to use this resource, we have built a free and publicly accessible website (http://expression.gnf.org) that integrates data visualization and curation of current gene annotations.

Standard name | GENTILE_UV_RESPONSE_CLUSTER_D2
Systematic name | M12861
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Cluster d2: genes down-regulated consistently in WS1 cells (fibroblast) between 6 h and 24 h after irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | PAL_PRMT5_TARGETS_DN
Systematic name | M5519
Organism | Mus musculus
PMID | 15485929
Authors | Pal S,Vishwanath SN,Erdjument-Bromage H,Tempst P,Sif S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NIH-3T3 cells (fibroblast) after knockdown of PRMT5 [GeneID=10419] by RNAi.
Full description | Protein arginine methyltransferases (PRMTs) have been implicated in transcriptional activation and repression, but their role in controlling cell growth and proliferation remains obscure. We have recently shown that PRMT5 can interact with flag-tagged BRG1- and hBRM-based hSWI/SNF chromatin remodelers and that both complexes can specifically methylate histones H3 and H4. Here we report that PRMT5 can be found in association with endogenous hSWI/SNF complexes, which can methylate H3 and H4 N-terminal tails, and show that H3 arginine 8 and H4 arginine 3 are preferred sites of methylation by recombinant and hSWI/SNF-associated PRMT5. To elucidate the role played by PRMT5 in gene regulation, we have established a PRMT5 antisense cell line and determined by microarray analysis that more genes are derepressed when PRMT5 levels are reduced. Among the affected genes, we show that suppressor of tumorigenicity 7 (ST7) and nonmetastatic 23 (NM23) are direct targets of PRMT5-containing BRG1 and hBRM complexes. Furthermore, we demonstrate that expression of ST7 and NM23 is reduced in a cell line that overexpresses PRMT5 and that this decrease in expression correlates with H3R8 methylation, H3K9 deacetylation, and increased transformation of NIH 3T3 cells. These findings suggest that the BRG1- and hBRM-associated PRMT5 regulates cell growth and proliferation by controlling expression of genes involved in tumor suppression.

Standard name | VISALA_AGING_LYMPHOCYTE_DN
Systematic name | M1583
Organism | Homo sapiens
PMID | 12618007
Authors | Visala Rao D,Boyle GM,Parsons PG,Watson K,Jones GL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in peripheral lymphocytes from old individuals compared to those from young donors.
Full description | Ageing results in a progressive, intrinsic and generalised imbalance of the control of regulatory systems. A key manifestation of this complex biological process includes the attenuation of the universal stress response. Here we provide the first global assessment of the ageing process as it affects the heat shock response, utilising human peripheral lymphocytes and cDNA microarray analysis. The genomic approach employed in our preliminary study was supplemented with a proteomic approach. In addition, the current study correlates the in vivo total antioxidant status with the age-related differential gene expression as well as the translational kinetics of heat shock proteins (hsps). Most of the genes encoding stress response proteins on the 4224 element microarray used in this study were significantly elevated after heat shock treatment of lymphocytes obtained from both young and old individuals albeit to a greater extent in the young. Cell signaling and signal transduction genes as well as some oxidoreductases showed varied response. Results from translational kinetics of induction of major hsps, from 0 to 24 h recovery period were broadly consistent with the differential expression of HSC 70 and HSP 40 genes. Total antioxidant levels in plasma from old individuals were found to be significantly lower by comparison with young, in agreement with the widely acknowledged role of oxidant homeostasis in the ageing process.

Standard name | SATO_SILENCED_EPIGENETICALLY_IN_PANCREATIC_CANCER
Systematic name | M5542
Organism | Homo sapiens
PMID | 12839967
Authors | Sato N,Fukushima N,Maitra A,Matsubayashi H,Yeo CJ,Cameron JL,Hruban RH,Goggins M
Category | C2
Sub-category | CGP
Brief description | 50 genes up-regulated in the pancreatic cancer cell lines (AsPC1, Hs766T, MiaPaCa2, Panc1) but not in the non-neoplastic cells (HPDE) by the combination of decitabine and TSA [PubChem=451668;5562].
Full description | To identify potential targets for aberrant methylation in pancreatic cancer, we analyzed global changes in gene expression profiles of four pancreatic cancer cell lines after treatment with the demethylating agent 5-aza-2'-deoxycytidine (5Aza-dC) and/or the histone deacetylase inhibitor trichostatin A. A substantial number of genes were induced 5-fold or greater by 5Aza-dC alone (631 transcripts), trichostatin A alone (1196 transcripts), and by treatment with both agents (857 transcripts). Four hundred and seventy-five genes were markedly (>5-fold) induced after 5Aza-dC treatment in pancreatic cancer cell lines but not in a nonneoplastic pancreatic epithelial cell line. The methylation status of 11 of these 475 genes was examined in a panel of 42 pancreatic cancers, and all 11 of these genes were aberrantly methylated in pancreatic cancer but rarely, if any, methylated in 10 normal pancreatic ductal epithelia. These genes include UCHL1 (methylated in 100% of 42 pancreatic cancers), NPTX2 (98%), SARP2 (95%), CLDN5 (93%), reprimo (86%), LHX1 (76%), WNT7A (71%), FOXE1 (69%), TJP2 (64%), CDH3 (19%), and ST14 (10%). Three of these 11 genes (NPTX2, SARP2, and CLDN5) were selected for further analysis in a larger panel of specimens, and aberrant methylation of at least one of these three genes was detectable in 100% of 43 primary pancreatic cancers and in 18 of 24 (75%) pancreatic juice samples obtained from patients with pancreatic cancer. Thus, a substantial number of genes are induced by 5Aza-dC treatment of pancreatic cancer cells, and many of them may represent novel targets for aberrant methylation in pancreatic carcinoma.

Standard name | CHEN_ETV5_TARGETS_SERTOLI
Systematic name | M1586
Organism | Mus musculus
PMID | 16107850
Authors | Chen C,Ouyang W,Grigura V,Zhou Q,Carnes K,Lim H,Zhao GQ,Arber S,Kurpios N,Murphy TL,Cheng AM,Hassell JA,Chandrashekar V,Hofmann MC,Hess RA,Murphy KM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Sertoli cells from both 4 and 10 week old ETV5 [GeneID=2119] knockout mice.
Full description | Division of spermatogonial stem cells produces daughter cells that either maintain their stem cell identity or undergo differentiation to form mature sperm. The Sertoli cell, the only somatic cell within seminiferous tubules, provides the stem cell niche through physical support and expression of surface proteins and soluble factors. Here we show that the Ets related molecule (ERM) is expressed exclusively within Sertoli cells in the testis and is required for spermatogonial stem cell self-renewal. Mice with targeted disruption of ERM have a loss of maintenance of spermatogonial stem cell self-renewal without a block in normal spermatogenic differentiation and thus have progressive germ-cell depletion and a Sertoli-cell-only syndrome. Microarray analysis of primary Sertoli cells from ERM-deficient mice showed alterations in secreted factors known to regulate the haematopoietic stem cell niche. These results identify a new function for the Ets family transcription factors in spermatogenesis and provide an example of transcriptional control of a vertebrate stem cell niche.

Standard name | BROWNE_HCMV_INFECTION_18HR_DN
Systematic name | M6641
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 18 h time point that were not down-regulated at the previous time point, 16 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | MOREIRA_RESPONSE_TO_TSA_UP
Systematic name | M15501
Organism | Homo sapiens
PMID | 14606959
Authors | Moreira JM,Scheipers P,Sørensen P
Category | C2
Sub-category | CGP
Brief description | Up-regulated in CD4+ [GeneID=920] T lymphocytes after 4 h treatment with 100 nM TSA [PubChem=5562].
Full description | BACKGROUND: Histone deacetylase inhibitors (HDACIs) induce hyperacetylation of core histones modulating chromatin structure and affecting gene expression. These compounds are also able to induce growth arrest, cell differentiation, and apoptotic cell death of tumor cells in vitro as well as in vivo. Even though several genes modulated by HDAC inhibition have been identified, those genes clearly responsible for the biological effects of these drugs have remained elusive. We investigated the pharmacological effect of the HDACI and potential anti-cancer agent Trichostatin A (TSA) on primary T cells. METHODS: To ascertain the effect of TSA on resting and activated T cells we used a model system where an enriched cell population consisting of primary T-cells was stimulated in vitro with immobilized anti-CD3/anti-CD28 antibodies whilst exposed to pharmacological concentrations of Trichostatin A. RESULTS: We found that this drug causes a rapid decline in cytokine expression, accumulation of cells in the G1 phase of the cell cycle, and induces apoptotic cell death. The mitochondrial respiratory chain (MRC) plays a critical role in the apoptotic response to TSA, as dissipation of mitochondrial membrane potential and reactive oxygen species (ROS) scavengers block TSA-induced T-cell death. Treatment of T cells with TSA results in the altered expression of a subset of genes involved in T cell responses, as assessed by microarray gene expression profiling. We also observed up- as well as down-regulation of various costimulatory/adhesion molecules, such as CD28 and CD154, important for T-cell function. CONCLUSIONS: Taken together, our findings indicate that HDAC inhibitors have an immunomodulatory potential that may contribute to the potency and specificity of these antineoplastic compounds and might be useful in the treatment of autoimmune disorders.

Standard name | IVANOVA_HEMATOPOIESIS_STEM_CELL_SHORT_TERM
Systematic name | M14523
Organism | Mus musculus
PMID | 12228721
Authors | Ivanova NB,Dimos JT,Schaniel C,Hackney JA,Moore KA,Lemischka IR
Category | C2
Sub-category | CGP
Brief description | Genes in the expression cluster 'ST-HSC Shared': up-regulated in short term hematopoietic stem cells (ST-HSC) from adult bone marrow and fetal liver.
Full description | Mechanisms regulating self-renewal and cell fate decisions in mammalian stem cells are poorly understood. We determined global gene expression profiles for mouse and human hematopoietic stem cells and other stages of the hematopoietic hierarchy. Murine and human hematopoietic stem cells share a number of expressed gene products, which define key conserved regulatory pathways in this developmental system. Moreover, in the mouse, a portion of the genetic program of hematopoietic stem cells is shared with embryonic and neural stem cells. This overlapping set of gene products represents a molecular signature of stem cells.

Standard name | TAKAO_RESPONSE_TO_UVB_RADIATION_DN
Systematic name | M17860
Organism | Homo sapiens
PMID | 11982916
Authors | Takao J,Ariizumi K,Dougherty II,Cruz PD Jr
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary tissue culture of epidermal kerationcytes after UVB irradiation.
Full description | Ultraviolet B (UVB) radiation is an important inducer of many biologic changes in skin, of which keratinocytes are a key target. To gain better insight into changes in gene expression generated in the early phase after UVB exposure, we used complementary RNA (cRNA) microarray hybridization to compare differences in mRNA expression of UVB-irradiated (single dose of 100 J/m2 broad-band UVB) and sham-irradiated primary cultured human keratinocytes. Six hours after irradiation, total RNA was isolated from keratinocytes, and cRNA was synthesized and hybridized to a GeneChip expression array (Affymetrix) consisting of 6800 genes. Based on a threshold of > twofold change, 187 genes (2.8%) were designated to be the most UVB-responsive. Surprisingly, none of these genes had been shown previously to be modulated by UVB. Conversely, several genes in the microarray that had been reported previously to be UVB- responsive by other methods showed less (< twofold) or no change. Northern blotting of seven differentially modulated genes produced results similar to those derived from microarray technology, thereby validating the accuracy of screening. Clustering based on known or likely functions indicated that among 88 upregulated genes, nine encode for cytochrome c subunits, six for ribosomal proteins, and two for regulators of apoptosis. By contrast, many of the 99 downregulated genes are involved in transcription, differentiation and transport. These findings indicate that keratinocytes respond to a single low dose of broad-band UVB irradiation by enhancing processes involved in energy production and translation, while suppressing those related to transcription, differentiation and transport.

Standard name | YIH_RESPONSE_TO_ARSENITE_C4
Systematic name | M1587
Organism | Homo sapiens
PMID | 12016162
Authors | Yih LH,Peck K,Lee TC
Category | C2
Sub-category | CGP
Brief description | Genes in cluster 4: immediate down-regulation in HFW cells (fibroblast) by sodium arsenite [PubChem=26435].
Full description | Arsenic compounds are widely distributed and arsenic ingestion is associated with many human diseases, including blackfoot disease, atherosclerosis, and cancers. However, the underlying mechanism of arsenic toxicity is not understood. In human fibroblast cells (HFW), arsenite is known to induce oxidative damage, chromosome aberrations, cell cycle arrest, and aneuploidy, and the manifestation of these cellular responses is dependent on changes in gene expression which can be analyzed using the cDNA microarray technique. In this study, cDNA microarray membranes with 568 human genes were used to examine mRNA profile changes in HFW cells treated for 0 to 24 h with 5 microM sodium arsenite. On the basis of the mean value for three independent experiments, 133 target genes were selected for a 2 x 3 self-organizing map cluster analysis; 94 were found to be induced by arsenite treatment, whereas 39 were repressed. These genes were categorized as signal transduction, transcriptional regulation, cell cycle control, stress responses, proteolytic enzymes, and miscellaneous. Significant changes in the signaling-related and transcriptional regulation genes indicated that arsenite induces complex toxicopathological injury.

Standard name | ZHANG_ANTIVIRAL_RESPONSE_TO_RIBAVIRIN_UP
Systematic name | M15069
Organism | Homo sapiens
PMID | 12719586
Authors | Zhang Y,Jamaluddin M,Wang S,Tian B,Garofalo RP,Casola A,Brasier AR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A549 cells (lung carcinoma) upon infection with RSV (respiratory syncytial virus) and up-regulated by further treatment with ribavirin [PubChem=5064].
Full description | Respiratory syncytial virus (RSV) is a mucosa-restricted virus that is a leading cause of epidemic respiratory tract infections in children. RSV replication is a potent activator of the epithelial-cell genomic response, influencing the expression of a spectrum of cellular pathways, including proinflammatory chemokines of the CC, CXC, and CX(3)C subclasses. Ribavirin (1-beta-D-ribofuranosyl-1,2,4-triazole-3-carboxamide) is a nontoxic antiviral agent currently licensed for the treatment of severe RSV lower respiratory tract infections. Because ribavirin treatment reduces the cytopathic effect in infected cells, we used high-density microarrays to investigate the hypothesis that ribavirin modifies the virus-induced epithelial genomic response to replicating virus. Ribavirin treatment administered in concentrations of 10 to 100 micro g/ml potently inhibited RSV transcription, thereby reducing the level of RSV N transcripts to approximately 13% of levels in nontreated cells. We observed that in both the absence and the presence of ribavirin, RSV infection induced global alterations in the host epithelial cell, affecting approximately 49% of the approximately 6,650 expressed genes detectable by the microarray. Ribavirin influences the expression of only 7.5% of the RSV-inducible genes (total number of genes, 272), suggesting that the epithelial-cell genetic program initiated by viral infection is independent of high-level RSV replication. Hierarchical clustering of the ribavirin-regulated genes identified four expression patterns. In one group, ribavirin inhibited the expression of the RSV-inducible CC chemokines MIP-1 alpha and -1 beta, which are important in RSV-induced pulmonary pathology, and interferon (IFN), a cytokine important in the mucosal immune response. In a second group, ribavirin further up-regulated a set of RSV- and IFN-stimulated response genes (ISGs) encoding antiviral proteins (MxA and p56), complement products, acute-phase response factors, and the STAT and IRF transcription factors. Because IFN-beta expression itself was reduced in the ribavirin-treated cells, we further investigated the mechanism for up-regulation of the IFN-signaling pathway. Enhanced expression of IFI 6-16, IFI 9-27, MxA/p78, STAT-1 alpha, STAT-1 beta, IRF-7B, and TAP-1-LMP2 transcripts were independently reproduced by Northern blot analysis. Ribavirin-enhanced TAP-1-LMP2 expression was a transcriptional event where site mutations of the IFN-stimulated response element (ISRE) blocked RSV and ribavirin-inducible promoter activity. Furthermore, ribavirin up-regulated the transcriptional activity of a reporter gene selectively driven by the ISRE. In specific DNA pull-down assays, we observed that ribavirin enhanced RSV-induced STAT-1 binding to the ISRE. We conclude that ribavirin potentiates virus-induced ISRE signaling to enhance the expression of antiviral ISGs, suggesting a mechanism for the efficacy of combined treatment with ribavirin and IFN in other chronic viral diseases.

Standard name | MARIADASON_RESPONSE_TO_BUTYRATE_SULINDAC_4
Systematic name | M1588
Organism | Homo sapiens
PMID | 10969808
Authors | Mariadason JM,Corner GA,Augenlicht LH
Category | C2
Sub-category | CGP
Brief description | Cluster 4: genes down-regulated in SW260 cells (colon cancer) by sodium butyrate and sulindac [PubChem=5222465;5352].
Full description | The short-chain fatty acid butyrate, produced by microbial fermentation of dietary fiber in the large intestine, is a physiological regulator of major pathways of colonic epithelial cell maturation: cell cycle arrest, lineage-specific differentiation, and apoptosis. Microarray analysis of 8,063 sequences demonstrated a complex cascade of reprogramming of SW620 colonic epithelial cells upon treatment with butyrate characterized by the progressive recruitment of gene sets as a function of time. Comparison with the effects of trichostatin A, in conjunction with differences in the kinetics of alteration of histone acetylation induced by butyrate and trichostatin A, identified subsets of induced and repressed genes likely coordinately regulated by altered histone acetylation. The butyrate response was also compared in detail with that of sulindac, a nonsteroidal anti-inflammatory drug with significant chemopreventive activity for colon cancer, and curcumin, a component of mustard and curry structurally and functionally related to sulindac that also has chemopreventive activity. Although gene clusters were identified that showed similar responses to butyrate and sulindac, the data were characterized by the extensive differences in the effects of the two agents. This was striking for functional classes of genes involved in signaling pathways and in cell cycle progression, although butyrate and sulindac induce a similar G0-G1 arrest, elevation of beta-catenin-Tcf signaling, and apoptotic cascade. As regards cell cycle arrest, the underlying mechanism in response to butyrate was most similar to that of the Caco-2 cell line that had spontaneously undergone a G0-G1 arrest and least similar to the G2-M arrest stimulated by curcumin. Thus, high-throughput microarray analysis of gene expression profiles can be used to characterize and distinguish the mechanisms of response of colonic epithelial cells to physiological and pharmacological inducers of cell maturation. This has important implications for characterization of chemopreventive agents and recognition of potential toxicity and synergies. The data bases, gene clusters, and analyses are available at http:// sequence.aecom.yu.edu/genome/.

Standard name | ZHENG_RESPONSE_TO_ARSENITE_UP
Systematic name | M1589
Organism | Homo sapiens
PMID | 12679051
Authors | Zheng XH,Watts GS,Vaught S,Gandolfi AJ
Category | C2
Sub-category | CGP
Brief description | Up-regulated in HEK293 cells (kidney epithelium) by treatment with sodium arsenite [PubChem=26435].
Full description | Chronic, low-level exposure to arsenic frequently results in skin, lung, bladder, and kidney cancer. Since arsenic is primarily excreted via the kidney, this study focused on this target tissue. Gene array was used as a sensitive low-level monitor of the impact of arsenic on this target tissue. Arsenite [As(III)] was chosen as the chemical species of arsenic since As(III) species are touted as the cellular toxic form of arsenic. Human embryonic kidney cell line HEK293 cells were incubated with 1, 10, and 25 microM arsenite [As(III)] for 6 or 24 h. Total RNA from treated and control cells was isolated, reverse transcribed, and labeled with Cy3 or Cy5, and hybridized to a human cDNA microarray. Hybridizations were performed four times using independent total RNA preparations to ensure reproducibility. Raw data from 10 and 25 microM treated cells exposed for 6 h was normalized within, and between, hybridizations followed by identification of genes affected by arsenite exposure based on practical significance (2-fold change up or down) and reproducibility (affected in four of six measurements). In these studies, 20 genes (HMOX1, MT1E, or FOSL1, etc.) were up-regulated, and 19 genes (MYC, JAK1, or CENPE, etc.) were down-regulated. Genes identified at 10 and 25 microM arsenic exposure were then examined after 1 microM treatment for 6 or 24 h. Expression of affected genes showed a dose-dependent (1-25 microM) trend that was apparently not time-dependent (6 vs. 24 h). The affected genes indicate that even this realistic, low-level arsenite exposure was recognized by the HEK293 cells (e.g. metallothionein genes) and produced an oxidative stress (e.g. heme oxygenase gene). These affected genes were characterized as stress response genes, proto-oncogene, signaling molecules, transcription factors, chemokine receptors, proteolytic enzymes, ESTs, and unknown genes. These findings imply that arsenite induces complex cellular injury and the cellular adaptation to As(III) is associated with alterations in the expression of many genes.

Standard name | DAZARD_UV_RESPONSE_CLUSTER_G4
Systematic name | M10885
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Cluster G4: genes increasingly up-regulated in NHEK cells (normal keratinocyte) after 12 h time point after UV-B irradiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | GENTILE_UV_RESPONSE_CLUSTER_D7
Systematic name | M16093
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Cluster d7: genes progressively down-regulated in WS1 cells (fibroblast) through 18 h after irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | EHRLICH_ICF_SYNDROM_DN
Systematic name | M2375
Organism | Homo sapiens
PMID | 11741835
Authors | Ehrlich M,Buchanan KL,Tsien F,Jiang G,Sun B,Uicker W,Weemaes CM,Smeets D,Sperling K,Belohradsky BH,Tommerup N,Misek DE,Rouillard JM,Kuick R,Hanash SM
Category | C2
Sub-category | CGP
Brief description | Down-regulated in B lymphocytes from patients with ICF syndrom caused by mutations in DNMT3B [GeneID=1789] compared to normals.
Full description | ICF (immunodeficiency, centromeric region instability and facial anomalies) is a recessive disease caused by mutations in the DNA methyltransferase 3B gene (DNMT3B). Patients have immunodeficiency, chromosome 1 (Chr1) and Chr16 pericentromeric anomalies in mitogen-stimulated lymphocytes, a small decrease in overall genomic 5-methylcytosine levels and much hypomethylation of Chr1 and Chr16 juxtacentromeric heterochromatin. Microarray expression analysis was done on B-cell lymphoblastoid cell lines (LCLs) from ICF patients with diverse DNMT3B mutations and on control LCLs using oligonucleotide arrays for approximately 5600 different genes, 510 of which showed a lymphoid lineage-restricted expression pattern among several different lineages tested. A set of 32 genes had consistent and significant ICF-specific changes in RNA levels. Half of these genes play a role in immune function. ICF-specific increases in immunoglobulin (Ig) heavy constant mu and delta RNA and cell surface IgM and IgD and decreases in Ig(gamma) and Ig(alpha) RNA and surface IgG and IgA indicate inhibition of the later steps of lymphocyte maturation. ICF-specific increases were seen in RNA for RGS1, a B-cell specific inhibitor of G-protein signaling implicated in negative regulation of B-cell migration, and in RNA for the pro-apoptotic protein kinase C eta gene. ICF-associated decreases were observed in RNAs encoding proteins involved in activation, migration or survival of lymphoid cells, namely, transcription factor negative regulator ID3, the enhancer-binding MEF2C, the iron regulatory transferrin receptor, integrin beta7, the stress protein heme oxygenase and the lymphocyte-specific tumor necrosis factor receptor family members 7 and 17. No differences in promoter methylation were seen between ICF and normal LCLs for three ICF upregulated genes and one downregulated gene by a quantitative methylation assay [combined bisulfite restriction analysis (COBRA)]. Our data suggest that DNMT3B mutations in the ICF syndrome cause lymphogenesis-associated gene dysregulation by indirect effects on gene expression that interfere with normal lymphocyte signaling, maturation and migration.

Standard name | KAAB_HEART_ATRIUM_VS_VENTRICLE_DN
Systematic name | M2584
Organism | Homo sapiens
PMID | 15103417
Authors | Kääb S,Barth AS,Margerie D,Dugas M,Gebauer M,Zwermann L,Merk S,Pfeufer A,Steinmeyer K,Bleich M,Kreuzer E,Steinbeck G,Näbauer M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the ventricles of healthy hearts, compared to atria.
Full description | To obtain region- and disease-specific transcription profiles of human myocardial tissue, we explored mRNA expression from all four chambers of eight explanted failing [idiopathic dilated cardiomyopathy (DCM), n=5; ischemic cardiomyopathy (ICM), n=3], and five non-failing hearts using high-density oligonucleotide arrays (Affymetrix U95Av2). We performed pair-wise comparisons of gene expression in the categories (1) atria versus ventricles, (2) disease-regulated genes in atria and (3) disease-regulated genes in ventricles. In the 51 heart samples examined, 549 genes showed divergent distribution between atria and ventricles (272 genes with higher expression in atria, 277 genes with higher expression in ventricles). Two hundred and eighty-eight genes were differentially expressed in failing myocardium compared to non-failing hearts (19 genes regulated in atria and ventricles, 172 regulated in atria only, 97 genes regulated in ventricles only). For disease-regulated genes, down-regulation was 4.5-times more common than up-regulation. Functional classification according to Gene Ontology identified specific biological patterns for differentially expressed genes. Eleven genes were validated by RT-PCR showing a good correlation with the microarray data. Our goal was to determine a gene expression fingerprint of the heart, accounting for region- and disease-specific aspects. Recognizing common gene expression patterns in heart failure will significantly contribute to the understanding of heart failure and may eventually lead to the development of pathway-specific therapies.

Standard name | GENTILE_UV_RESPONSE_CLUSTER_D6
Systematic name | M15187
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Cluster d6: genes progressively down-regulated in WS1 cells (fibroblast) through 18 h after irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | VERRECCHIA_DELAYED_RESPONSE_TO_TGFB1
Systematic name | M16643
Organism | Homo sapiens
PMID | 11279127
Authors | Verrecchia F,Chu ML,Mauviel A
Category | C2
Sub-category | CGP
Brief description | ECM related genes up-regulated later than 30 min following addition of TGFB1 [GeneID=7040] in dermal fibroblasts.
Full description | Despite major advances in the understanding of the intimate mechanisms of transforming growth factor-beta (TGF-beta) signaling through the Smad pathway, little progress has been made in the identification of direct target genes. In this report, using cDNA microarrays, we have focussed our attention on the characterization of extracellular matrix-related genes rapidly induced by TGF-beta in human dermal fibroblasts and attempted to identify the ones whose up-regulation by TGF-beta is Smad-mediated. For a gene to qualify as a direct Smad target, we postulated that it had to meet the following criteria: (1) rapid (30 min) and significant (at least 2-fold) elevation of steady-state mRNA levels upon TGF-beta stimulation, (2) activation of the promoter by both exogenous TGF-beta and co-transfected Smad3 expression vector, (3) up-regulation of promoter activity by TGF-beta blocked by both dominant-negative Smad3 and inhibitory Smad7 expression vectors, and (4) promoter transactivation by TGF-beta not possible in Smad3(-/-) mouse embryo fibroblasts. Using this stringent approach, we have identified COL1A2, COL3A1, COL6A1, COL6A3, and tissue inhibitor of metalloproteases-1 as definite TGF-beta/Smad3 targets. Extrapolation of this approach to other extracellular matrix-related gene promoters also identified COL1A1 and COL5A2, but not COL6A2, as novel Smad targets. Together, these results represent a significant step toward the identification of novel, early-induced Smad-dependent TGF-beta target genes in fibroblasts.

Standard name | BROWNE_HCMV_INFECTION_18HR_UP
Systematic name | M5388
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 18 h time point that were not up-regulated at the previous time point, 16 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | LEE_AGING_NEOCORTEX_UP
Systematic name | M1590
Organism | Mus musculus
PMID | 10888876
Authors | Lee CK,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Upregulated in the neocortex of aged adult mice (30-month) vs young adult (5-month)
Full description | Ageing of the brain leads to impairments in cognitive and motor skills, and is the major risk factor for several common neurological disorders such as Alzheimer disease (AD) and Parkinson disease (PD). Recent studies suggest that normal brain ageing is associated with subtle morphological and functional alterations in specific neuronal circuits, as opposed to large-scale neuronal loss. In fact, ageing of the central nervous system in diverse mammalian species shares many features, such as atrophy of pyramidal neurons, synaptic atrophy, decrease of striatal dopamine receptors, accumulation of fluorescent pigments, cytoskeletal abnormalities, and reactive astrocytes and microglia. To provide the first global analysis of brain ageing at the molecular level, we used oligonucleotide arrays representing 6,347 genes to determine the gene-expression profile of the ageing neocortex and cerebellum in mice. Ageing resulted in a gene-expression profile indicative of an inflammatory response, oxidative stress and reduced neurotrophic support in both brain regions. At the transcriptional level, brain ageing in mice displays parallels with human neurodegenerative disorders. Caloric restriction, which retards the ageing process in mammals, selectively attenuated the age-associated induction of genes encoding inflammatory and stress responses.

Standard name | ZHANG_RESPONSE_TO_CANTHARIDIN_DN
Systematic name | M2510
Organism | Homo sapiens
PMID | 14639605
Authors | Zhang JP,Ying K,Xiao ZY,Zhou B,Huang QS,Wu HM,Yin M,Xie Y,Mao YM,Rui YC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HL-60 cells (promyeloid leukemia) by cantharidin [PubChem=6708701].
Full description | Cantharidin is a natural toxin that has antitumor properties and causes leukocytosis as well as increasing sensitivity of tumor cells resistant to other chemotherapeutic agents. There is limited information, however, on the molecular pharmacological mechanisms of cantharidin on human cancer cells. We have used cDNA microarrays to identify gene expression changes in HL-60 promyeloid leukemia cells exposed to cantharidin. Cantharidin-treated cells not only decreased expression of genes coding for proteins involved in DNA replication (e.g., DNA polymerase delta), DNA repair (e.g., FANCG, ERCC), energy metabolism (e.g., isocitrate dehydrogenase alpha, ADP/ATP translocase), but also decreased expression of genes coding for proteins that have oncogenic activity (e.g., c-myc, GTPase) or show tumor-specific expression (e.g., phosphatidylinositol 3-kinase). In contrast, these treated cells overexpressed several genes that encode intracellular and secreted growth-inhibitory proteins (e.g., BTG2, MCP-3) as well as proapoptotic genes (e.g., ATL-derived PMA-responsive peptide). Our findings suggest that alterations in specific genes functionally related to cell proliferation or apoptosis may be responsible for cantharidin-mediated cytotoxicity. We also found that exposure of HL-60 cells to cantharidin resulted in the decreased expression of multidrug resistance-associated protein genes (e.g., ABCA3, MOAT-B), suggesting that cantharidin may be used as an oncotherapy sensitizer, and the increased expression of genes in modulating cytokine production and inflammatory response (e.g., NFIL-3, N-formylpeptide receptor), which may partly explain the stimulating effects on leukocytosis. Our data provide new insight into the molecular mechanisms of cantharidin.

Standard name | BURTON_ADIPOGENESIS_PEAK_AT_24HR
Systematic name | M1591
Organism | Mus musculus
PMID | 12137940
Authors | Burton GR,Guan Y,Nagarajan R,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Cluster 5: genes progressively up-regulated (peak at 24 h time point) during differentiation of 3T3-L1 fibroblasts into adipocytes in response to adipogenic hormones.
Full description | The molecular mechanisms that regulate cellular differentiation during development and throughout life are complex. It is now recognized that precise patterns of differentially expressed genes ultimately direct a particular cell toward a given lineage and many of these are regulated during the earliest stages of differentiation. Using a microarray-based expression analysis, we have examined gene expression profiles during the first 24 h of 3T3-L1 adipocyte differentiation. RNA was isolated at times 0, 2, 8, 16, and 24 h following stimulation of differentiation and hybridized in duplicate to high density Affymetrix microarray gene chips containing a series of 13,179 cDNA/expressed sequence tag (EST) probe sets. Two hundred and eighty-five cDNA/ESTs were shown to have at least a fivefold change in expression levels during this time course and both hierarchical and self-organizing map clustering analysis was performed to categorize them by expression profiles. Several genes known to be regulated during this time period were confirmed and Western blot analysis of the proteins encoded by some of the identified genes revealed expression profiles similar to their mRNA counterparts. As expected, many of the genes identified have not been examined in such a critical time period during adipogenesis and may well represent novel adipogenic mediators.

Standard name | SARTIPY_NORMAL_AT_INSULIN_RESISTANCE_UP
Systematic name | M1592
Organism | Mus musculus
PMID | 14530283
Authors | Sartipy P,Loskutoff DJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 3T3-L1 cells (adipocyte) by insulin [GeneID=3630] which continued to respond normally to insulin in the insulin resistant cells.
Full description | We have employed microarray technology using RNA from normal 3T3-L1 adipocytes and from 3T3-L1 adipocytes made insulin-resistant by treatment with tumor necrosis factor-alpha to identify a new class of insulin-responsive genes. These genes continued to respond normally to insulin even though the adipocytes themselves were metabolically insulin-resistant, i.e. they displayed a significantly decreased rate of insulin-stimulated glucose uptake. Approximately 12,000 genes/expressed sequence tags (ESTs) were screened. Of these, 40 genes/ESTs were identified that became insulin-resistant as expected (e.g. Socs-3, junB, and matrix metalloproteinase-11). However, 61 genes/ESTs continued to respond normally to insulin. Although some of these genes were previously shown to be regulated by insulin (e.g. Glut-1 and beta3-adrenergic receptor), other novel insulin-sensitive genes were also identified (e.g. Egr-1, epiregulin, Fra-1, and ABCA1). Real-time reverse transcription-PCR analysis confirmed the expression patterns of several of the differentially expressed genes. One gene that remained insulin-sensitive in the insulin-resistant adipocytes is the transcription factor Egr-1. Using an antisense strategy, we show that tissue factor and macrophage colony-stimulating factor, two cardiovascular risk factors, are downstream EGR-1 target genes in the adipocyte. Taken together, these data support the hypothesis that some signaling pathways remain insulin-sensitive in metabolically insulin-resistant adipocytes. These pathways may promote abnormal gene expression in hyperinsulinemic states like obesity and type II diabetes and thus may contribute to pathologies associated with these conditions.

Standard name | MULLIGAN_NTF3_SIGNALING_VIA_INSR_AND_IGF1R_UP
Systematic name | M1593
Organism | Mus musculus
PMID | 12213819
Authors | Mulligan C,Rochford J,Denyer G,Stephens R,Yeo G,Freeman T,Siddle K,O'Rahilly S
Category | C2
Sub-category | CGP
Brief description | Genes similarly up-regulated in 3T3-L1 cells (fibroblasts able to differentiate to adipocytes) upon stimulation of INSR or IGFR1 by NTF3 [GeneID=3643;3480;4908].
Full description | Insulin and insulin-like growth factor-1 (IGF-1) act through highly homologous receptors that engage similar intracellular signaling pathways, yet these hormones serve largely distinct physiological roles in the control of metabolism and growth, respectively. In an attempt to uncover the molecular mechanisms underlying their divergent functions, we compared insulin receptor (IR) and IGF-1 receptor (IGF-1R) regulation of gene expression by microarray analysis, using 3T3-L1 cells expressing either TrkC/IR or TrkC/IGF-1R chimeric receptors to ensure the highly selective activation of each receptor tyrosine kinase. Following stimulation of the chimeric receptors for 4 h, we detected 11 genes to be differentially regulated, of which 10 were up-regulated to a greater extent by the IGF-1R. These included genes involved in adhesion, transcription, transport, and proliferation. The expression of mRNA encoding heparin-binding epidermal growth factor-like growth factor (HB-EGF), a potent mitogen, was markedly increased by IGF-1R but not IR activation. This effect was dependent on MAPK, but not phosphatidylinositol 3-kinase, and did not require an autocrine loop through the epidermal growth factor receptor. HB-EGF mitogenic activity was detectable in the medium of 3T3-L1 preadipocytes expressing activated IGF-1R but not IR, indicating that the transcriptional response is accompanied by a parallel increase in mature HB-EGF protein. The differential abilities of the IR and IGF-1R tyrosine kinases to stimulate the synthesis and release of a growth factor may provide, at least in part, an explanation for the greater role of the IGF-1R in the control of cellular proliferation.

Standard name | BRACHAT_RESPONSE_TO_CAMPTOTHECIN_UP
Systematic name | M1594
Organism | Mus musculus
PMID | 12447701
Authors | Brachat A,Pierrat B,Xynos A,Brecht K,Simonen M,Brüngger A,Heim J
Category | C2
Sub-category | CGP
Brief description | Genes specifically up-regulated in FL5.12 cells (pro-B lymphocyte) by camptothecin [PubChem=2538].
Full description | DNA microarrays are powerful tools for the analysis of gene expression on a genomic scale. The importance of individual regulatory events for the process under study can however not be deduced unequivocally without additional experiments. We devised a strategy to identify central regulators of cancer drug responses by combining the results of microarray experiments with efficient methods for phenotypic testing of candidate genes. We exposed murine FL5.12 pro-B cells to cisplatin, camptothecin, methotrexate or paclitaxel, respectively and analysed the patterns of gene expression with cDNA microarrays. Drug-specific regulatory events as well as intersections between different apoptotic pathways, including previously studied responses to staurosporine and interleukin-3 (IL-3) deprivation, were identified. Genes shared by at least three pathways were chosen for further analysis. Ectopic expression of three such genes, TEAP, GP49B, and Lipin1 was found to have an anti-proliferative effect on pro-B cells. Interestingly, we identified hemoglobin alpha as a strong pro-apoptotic regulator. While hemoglobin-expressing cells were growing normally in the presence of IL-3, they displayed accelerated apoptosis with similar kinetics as Bax overexpressing cells upon IL-3 removal. The pro-apoptotic effect of hemoglobin was suppressed by Bcl-2 and was characterized by enhanced stimulation of caspase activity.

Standard name | GENTILE_UV_HIGH_DOSE_DN
Systematic name | M13630
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated in WS1 (fibroblast) in response to irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | HENDRICKS_SMARCA4_TARGETS_DN
Systematic name | M7914
Organism | Homo sapiens
PMID | 14673169
Authors | Hendricks KB,Shanahan F,Lees E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ALAB cells (breast cancer) upon reintroduction of SMARCA4 [GeneID=6597] expressed off adenoviral vector.
Full description | Human BRG1, a subunit of the Swi/Snf chromatin remodeling apparatus, has been implicated in regulation of cellular proliferation and is a candidate tumor suppressor. Reintroduction of BRG1 into a breast tumor cell line, ALAB, carrying a defined mutation in the BRG1 gene, induced growth arrest. Gene expression data revealed that the arrest may in part be accounted for by down-regulation of select E2F target genes such as cyclin E, but more dramatically, by up-regulation of mRNAs for the cyclin-dependent kinase inhibitors p21 and p15. Protein levels of both p15 and p21 were induced, and p21 protein was recruited to a complex with cyclin-dependent kinase, CDK2, to inhibit its activity. BRG1 can associate with the p21 promoter in a p53-independent manner, suggesting that the induction of p21 by BRG1 may be direct. Further, using microarray and real-time PCR analysis we identified several novel BRG1-regulated genes. Our work provides further evidence for a role for BRG1 in the regulation of several genes involved in key steps in tumorigenesis and has revealed a potential mechanism for BRG1-induced growth arrest.

Standard name | HAN_JNK_SINGALING_UP
Systematic name | M1596
Organism | Mus musculus
PMID | 12354774
Authors | Han SY,Kim SH,Heasley LE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 3T3 cells (fibroblast) upon activation of JNK pathway.
Full description | The c-Jun N-terminal kinases (JNKs) are encoded by three genes that yield 10 isoforms through alternative mRNA splicing. The roles of each JNK isoform in the many putative biological responses where the JNK pathway is activated are still unclear. To examine the cellular responses mediated by different JNK isoforms, gain-of-function JNK1 polypeptides were generated by fusing the upstream mitogen-activated protein kinase kinase, MKK7, with p46JNK1alpha or p46JNK1beta. The MKK7-JNK fusion proteins, which exhibited constitutive activity in 293T cells, were stably expressed in Swiss 3T3 fibroblasts using retrovirus-mediated gene transfer. Swiss 3T3 cells expressing either of the MKK7-JNK polypeptides were equally sensitized to induction of cell death following serum withdrawal. To search for other cellular responses that may be selectively regulated by the JNK1 isoforms, the gene expression profiles of Swiss 3T3 cells expressing MKK7-JNK1alpha or MKK7-JNK1beta were compared with empty vector-transfected control cells. Affymetrix Genechips identified 46 genes for which expression was increased in MKK7-JNK-expressing cells relative to vector control cells. Twenty genes including those for c-Jun, MKP-7, interluekin-1 receptor family member ST2L/ST2, and c-Jun-binding protein were induced similarly by MKK7-JNK1alpha and MKK7-JNK1beta proteins, whereas 13 genes were selectively increased by MKK7-JNK1alpha and 13 genes were selectively increased by MKK7-JNK1beta. The set of genes selectively induced by MKK7-JNK1beta included a number of known interferon-stimulated genes (ISG12, ISG15, IGTP, and GTPI). Consistent with these gene expression changes, Swiss 3T3 cells expressing MKK7-JNK1beta exhibited increased resistance to vesicular stomatitis virus-induced cell death. These findings reveal evidence for JNK isoform-selective gene regulation and support a role for distinct JNK isoforms in specific cellular responses.

Standard name | KANG_DOXORUBICIN_RESISTANCE_DN
Systematic name | M3323
Organism | Homo sapiens
PMID | 14734480
Authors | Kang HC,Kim IJ,Park JH,Shin Y,Ku JL,Jung MS,Yoo BC,Kim HK,Park JG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in gastric cancer cell lines: doxorubicin [PubChem=31703] resistant vs sensitive.
Full description | PURPOSE: A major obstacle in chemotherapy is treatment failure due to anticancer drug resistance. The emergence of acquired resistance results from host factors and genetic or epigenetic changes in the cancer cells. The purpose of this study was to identify differentially expressed genes associated with acquisition of resistance in human gastric cancer cells. EXPERIMENTAL DESIGN: We performed global gene expression analysis in the acquired drug-resistant gastric cancer cell lines to the commonly used drugs 5-fluorouracil, doxorubicin, and cisplatin using Affymetrix HG-U133A microarray. The gene expression patterns of 10 chemoresistant gastric cancer cell lines were compared with those of four parent cell lines using fold-change and Wilcoxon's test for data analysis. RESULTS: We identified over 250 genes differentially expressed in 5-fluorouracil-, cisplatin-, or doxorubicin-resistant gastric cancer cell lines. Our expression analysis also identified eight multidrug resistance candidate genes that were associated with resistance to two or more of the tested chemotherapeutic agents. Among these, midkine (MDK), a heparin-binding growth factor, was overexpressed in all drug-resistant cell lines, strongly suggesting that MDK might contribute to multidrug resistance in gastric cancer cells. CONCLUSIONS: Our investigation provides comprehensive gene information associated with acquired resistance to anticancer drugs in gastric cancer cells and a basis for additional functional studies.

Standard name | SESTO_RESPONSE_TO_UV_C0
Systematic name | M459
Organism | Homo sapiens
PMID | 11867738
Authors | Sesto A,Navarro M,Burslem F,Jorcano JL
Category | C2
Sub-category | CGP
Brief description | Cluster 0: genes changed in primary keratinocytes by UVB irradiation.
Full description | UV radiation is the most important environmental skin aggressor, causing cancer and other problems. This paper reports the use of oligonucleotide microarray technology to determine changes in gene expression in human keratinocytes after UVB treatment. Examination of the effects of different doses at different times after irradiation gave a global picture of the keratinocyte response to this type of insult. Five hundred thirty-nine regulated transcripts were found and organized into nine different clusters depending on behavior patterns. Classification of these genes into 23 functional categories revealed that several biological processes are globally affected by UVB. In addition to confirming a majority up-regulation of the transcripts related to the UV-specific inflammatory and stress responses, significant increases were seen in the expression of genes involved in basal transcription, splicing, and translation as well as in the proteasome-mediated degradation category. On the other hand, those transcripts belonging to the metabolism and adhesion categories were strongly downregulated. These results demonstrate the complexity of the transcriptional profile of the UVB response, describe several cellular processes previously not known to be affected by UV irradiation, and serve as a basis for the global characterization of UV-regulated genes and pathways.

Standard name | MCLACHLAN_DENTAL_CARIES_DN
Systematic name | M1278
Organism | Homo sapiens
PMID | 15869869
Authors | McLachlan JL,Smith AJ,Bujalska IJ,Cooper PR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pulpal tissue extracted from carious teeth.
Full description | High-throughput characterisation of the molecular response of pulpal tissue under carious lesions may contribute to improved future diagnosis and treatment. To identify genes associated with this process, oligonucleotide microarrays containing approximately 15,000 human sequences were screened using pooled total RNA isolated from pulpal tissue from both healthy and carious teeth. Data analysis identified 445 genes with 2-fold or greater difference in expression level, with 85 more abundant in health and 360 more abundant in disease. Subsequent gene ontological grouping identified a variety of processes and functions potentially activated or down-modulated during caries. Validation of microarray results was obtained by a combination of real-time and semi-quantitative PCR for selected genes, confirming down-regulation of Dentin Matrix Protein-1 (DMP-1), SLIT 2, Period-2 (PER 2), Period-3 (PER 3), osteoadherin, Glypican-3, Midkine, activin receptor interacting protein-1 (AIP 1), osteoadherin and growth hormone receptor (GHR), and up-regulation of Adrenomedullin (ADM), Interleukin-11 (IL-11), Bone sialoprotein (BSP), matrix Gla protein (MGP), endothelial cell growth factor-1 (ECGF 1), inhibin beta A and orosomucoid-1 (ORM 1), in diseased pulp. Real-time PCR analyses of ADM and DMP-1 in a panel of healthy and carious pulpal tissue and also in immune system cells highlighted the heterogeneity of caries and indicated increased expression of ADM in neutrophils activated by bacterial products. In contrast, DMP-1 was predominantly expressed by cells native to healthy pulpal tissue. This study has greatly extended our molecular knowledge of dental tissue disease and identified involvement of genes previously unassociated with this process.

Standard name | BURTON_ADIPOGENESIS_PEAK_AT_2HR
Systematic name | M1597
Organism | Mus musculus
PMID | 12137940
Authors | Burton GR,Guan Y,Nagarajan R,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Cluster 2: genes maximally expressed at 2 h time point during differentiation of 3T3-L1 fibroblasts into adipocytes (cluster 2) in response to adipogenic hormones.
Full description | The molecular mechanisms that regulate cellular differentiation during development and throughout life are complex. It is now recognized that precise patterns of differentially expressed genes ultimately direct a particular cell toward a given lineage and many of these are regulated during the earliest stages of differentiation. Using a microarray-based expression analysis, we have examined gene expression profiles during the first 24 h of 3T3-L1 adipocyte differentiation. RNA was isolated at times 0, 2, 8, 16, and 24 h following stimulation of differentiation and hybridized in duplicate to high density Affymetrix microarray gene chips containing a series of 13,179 cDNA/expressed sequence tag (EST) probe sets. Two hundred and eighty-five cDNA/ESTs were shown to have at least a fivefold change in expression levels during this time course and both hierarchical and self-organizing map clustering analysis was performed to categorize them by expression profiles. Several genes known to be regulated during this time period were confirmed and Western blot analysis of the proteins encoded by some of the identified genes revealed expression profiles similar to their mRNA counterparts. As expected, many of the genes identified have not been examined in such a critical time period during adipogenesis and may well represent novel adipogenic mediators.

Standard name | CHEN_PDGF_TARGETS
Systematic name | M1598
Organism | Mus musculus
PMID | 14981515
Authors | Chen WV,Delrow J,Corrin PD,Frazier JP,Soriano P
Category | C2
Sub-category | CGP
Brief description | Up-regulated PDGF targets identified by a gene-trap screen.
Full description | We developed a versatile, high-throughput genetic screening strategy by coupling gene mutagenesis and expression profiling technologies. Using a retroviral gene-trap vector optimized for efficient mutagenesis and cloning, we randomly disrupted genes in mouse embryonic stem (ES) cells and amplified them to construct a cDNA microarray. With this gene-trap array, we show that transcriptional target genes of platelet-derived growth factor (PDGF) can be efficiently and reliably identified in physiologically relevant cells and are immediately accessible to genetic studies to determine their in vivo roles and relative contributions to PDGF-regulated developmental processes. The same platform can be used to search for genes of specific biological relevance in a broad array of experimental settings, providing a fast track from gene identification to functional validation.

Standard name | MCCLUNG_CREB1_TARGETS_UP
Systematic name | M6920
Organism | Mus musculus
PMID | 14566342
Authors | McClung CA,Nestler EJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the nucleus accumbens (a major reward center in the brain) 8 weeks after induction of CREB1 [GeneID=1385] expression in a transgenic Tet-Off system.
Full description | DeltaFosB (a truncated form of FosB) and CREB (cAMP response element binding protein) are transcription factors induced in the brain's reward pathways after chronic exposure to drugs of abuse. However, their mechanisms of action and the genes they regulate remain unclear. Using microarray analysis in the nucleus accumbens of inducible transgenic mice, we found that CREB and a dominant-negative CREB have opposite effects on gene expression, as do prolonged expression of DeltaFosB and the activator protein-1 (AP-1) antagonist DeltacJun. However, unlike CREB, short-term and prolonged DeltaFosB induction had opposing effects on gene expression. Gene expression induced by short-term DeltaFosB and by CREB was strikingly similar, and both reduced the rewarding effects of cocaine, whereas prolonged DeltaFosB expression increased drug reward. Gene expression after a short cocaine treatment was more dependent on CREB, whereas gene expression after a longer cocaine treatment became increasingly DeltaFosB dependent. These findings help define the molecular functions of CREB and DeltaFosB and identify clusters of genes that contribute to cocaine addiction.

Standard name | LEE_AGING_CEREBELLUM_UP
Systematic name | M1599
Organism | Mus musculus
PMID | 10888876
Authors | Lee CK,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Upregulated in the cerebellum of aged adult mice (30-month) vs young adult (5-month)
Full description | Ageing of the brain leads to impairments in cognitive and motor skills, and is the major risk factor for several common neurological disorders such as Alzheimer disease (AD) and Parkinson disease (PD). Recent studies suggest that normal brain ageing is associated with subtle morphological and functional alterations in specific neuronal circuits, as opposed to large-scale neuronal loss. In fact, ageing of the central nervous system in diverse mammalian species shares many features, such as atrophy of pyramidal neurons, synaptic atrophy, decrease of striatal dopamine receptors, accumulation of fluorescent pigments, cytoskeletal abnormalities, and reactive astrocytes and microglia. To provide the first global analysis of brain ageing at the molecular level, we used oligonucleotide arrays representing 6,347 genes to determine the gene-expression profile of the ageing neocortex and cerebellum in mice. Ageing resulted in a gene-expression profile indicative of an inflammatory response, oxidative stress and reduced neurotrophic support in both brain regions. At the transcriptional level, brain ageing in mice displays parallels with human neurodegenerative disorders. Caloric restriction, which retards the ageing process in mammals, selectively attenuated the age-associated induction of genes encoding inflammatory and stress responses.

Standard name | WEIGEL_OXIDATIVE_STRESS_BY_HNE_AND_TBH
Systematic name | M7899
Organism | Homo sapiens
PMID | 12419474
Authors | Weigel AL,Handa JT,Hjelmeland LM
Category | C2
Sub-category | CGP
Brief description | Oxidative stress genes down-regulated in ARPE-19 cells (retinal pigmented epithelium) in response to HNE and tBH [PubChem=5283344;6410].
Full description | Oxidative stress plays a key role in aging diseases of the posterior pole of the eye such as age-related macular degeneration. The oxidative stress response of in vitro RPE cells has been studied for a small number of genes. However, a comprehensive transcriptional response has yet to be elucidated. The purpose of this study was to determine if the transcription of a common set of genes is altered by exposure of ARPE-19 cells to three major generators of oxidative stress, hydrogen peroxide (H2O2), 4-hydroxynonenal (HNE), and tert-butylhydroperoxide (tBH). As expected, a common response was observed that included 35 genes differentially regulated by all three treatments. Of these, only one gene was upregulated, and only by one oxidant, while all other responses were downregulation. The majority of these genes fell into five functional categories: apoptosis, cell cycle regulation, cell-cell communication, signal transduction, and transcriptional regulation. Additionally, a large number of genes were differentially regulated by one oxidant only, including the majority of the conventional oxidative stress response genes present on the Clontech Human 1.2 microarray. This study raises questions regarding the generality of results that involve the use of a single oxidant and a single cell culture condition.

Standard name | TSENG_IRS1_TARGETS_DN
Systematic name | M13907
Organism | Mus musculus
PMID | 15895078
Authors | Tseng YH,Butte AJ,Kokkotou E,Yechoor VK,Taniguchi CM,Kriauciunas KM,Cypess AM,Niinobe M,Yoshikawa K,Patti ME,Kahn CR
Category | C2
Sub-category | CGP
Brief description | Down-regulated in brown preadipocytes with IRS1 [GeneID=3667] knockout vs wild type controls; the knockouts have severe defects in adipocyte differentiation.
Full description | The insulin/IGF-1 (insulin-like growth factor 1) signalling pathway promotes adipocyte differentiation via complex signalling networks. Here, using microarray analysis of brown preadipocytes that are derived from wild-type and insulin receptor substrate (Irs) knockout animals that exhibit progressively impaired differentiation, we define 374 genes/expressed-sequence tags whose expression in preadipocytes correlates with the ultimate ability of the cells to differentiate. Many of these genes, including preadipocyte factor-1 (Pref-1) and multiple members of the Wnt signalling pathway, are related to early adipogenic events. Necdin is also markedly increased in Irs knockout cells that cannot differentiate, and knockdown of necdin restores brown adipogenesis with downregulation of Pref-1 and Wnt10a expression. Insulin receptor substrate proteins regulate a necdin-E2F4 interaction that represses peroxisome-proliferator-activated receptor gamma (PPARgamma) transcription via a cyclic AMP response element binding protein (CREB)-dependent pathway. Together these define a key signalling network that is involved in brown preadipocyte determination.

Standard name | RODWELL_AGING_KIDNEY_NO_BLOOD_UP
Systematic name | M9893
Organism | Homo sapiens
PMID | 15562319
Authors | Rodwell GE,Sonu R,Zahn JM,Lund J,Wilhelmy J,Wang L,Xiao W,Mindrinos M,Crane E,Segal E,Myers BD,Brooks JD,Davis RW,Higgins J,Owen AB,Kim SK
Category | C2
Sub-category | CGP
Brief description | Genes whose expression increases with age in normal kidney, excluding those with higher expression in blood.
Full description | In this study, we found 985 genes that change expression in the cortex and the medulla of the kidney with age. Some of the genes whose transcripts increase in abundance with age are known to be specifically expressed in immune cells, suggesting that immune surveillance or inflammation increases with age. The age-regulated genes show a similar aging profile in the cortex and the medulla, suggesting a common underlying mechanism for aging. Expression profiles of these age-regulated genes mark not only age, but also the relative health and physiology of the kidney in older individuals. Finally, the set of aging-regulated kidney genes suggests specific mechanisms and pathways that may play a role in kidney degeneration with age.

Standard name | RODWELL_AGING_KIDNEY_UP
Systematic name | M5389
Organism | Homo sapiens
PMID | 15562319
Authors | Rodwell GE,Sonu R,Zahn JM,Lund J,Wilhelmy J,Wang L,Xiao W,Mindrinos M,Crane E,Segal E,Myers BD,Brooks JD,Davis RW,Higgins J,Owen AB,Kim SK
Category | C2
Sub-category | CGP
Brief description | Genes whose expression increases with age in normal kidney.
Full description | In this study, we found 985 genes that change expression in the cortex and the medulla of the kidney with age. Some of the genes whose transcripts increase in abundance with age are known to be specifically expressed in immune cells, suggesting that immune surveillance or inflammation increases with age. The age-regulated genes show a similar aging profile in the cortex and the medulla, suggesting a common underlying mechanism for aging. Expression profiles of these age-regulated genes mark not only age, but also the relative health and physiology of the kidney in older individuals. Finally, the set of aging-regulated kidney genes suggests specific mechanisms and pathways that may play a role in kidney degeneration with age.

Standard name | MCCLUNG_COCAIN_REWARD_4WK
Systematic name | M1600
Organism | Mus musculus
PMID | 14566342
Authors | McClung CA,Nestler EJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the nucleus accumbens (a major reward center in the brain) after 4 weeks of cocaine [PubChem=5760] treatment.
Full description | DeltaFosB (a truncated form of FosB) and CREB (cAMP response element binding protein) are transcription factors induced in the brain's reward pathways after chronic exposure to drugs of abuse. However, their mechanisms of action and the genes they regulate remain unclear. Using microarray analysis in the nucleus accumbens of inducible transgenic mice, we found that CREB and a dominant-negative CREB have opposite effects on gene expression, as do prolonged expression of DeltaFosB and the activator protein-1 (AP-1) antagonist DeltacJun. However, unlike CREB, short-term and prolonged DeltaFosB induction had opposing effects on gene expression. Gene expression induced by short-term DeltaFosB and by CREB was strikingly similar, and both reduced the rewarding effects of cocaine, whereas prolonged DeltaFosB expression increased drug reward. Gene expression after a short cocaine treatment was more dependent on CREB, whereas gene expression after a longer cocaine treatment became increasingly DeltaFosB dependent. These findings help define the molecular functions of CREB and DeltaFosB and identify clusters of genes that contribute to cocaine addiction.

Standard name | ZHOU_TNF_SIGNALING_30MIN
Systematic name | M1603
Organism | Homo sapiens
PMID | 12673210
Authors | Zhou A,Scoggin S,Gaynor RB,Williams NS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HeLa cells (cervical carcinoma) at 30 min after stimulation with TNF [GeneID=7124].
Full description | Tumor necrosis factor alpha (TNF alpha) is a proinflammatory cytokine with important roles in regulating inflammatory responses as well as cell cycle proliferation and apoptosis. Although TNFalpha stimulates apoptosis, it also activates the transcription factor NF-kappa B, and studies have shown that inhibition of NF-kappa B potentiates the cytotoxicity of TNFalpha. Since several chemotherapy agents act like TNFalpha to both promote apoptosis and activate NF-kappa B, understanding the role of NF-kappa B in suppressing apoptosis may have significant clinical applications. To understand the effects of stimulation with TNFalpha and the role of NF-kappa B in regulating this response, a 23k human cDNA microarray was used to screen TNFalpha-inducible genes in HeLa cells. Real-time PCR verified expression changes in 16 of these genes and revealed three distinct temporal patterns of expression after TNFalpha stimulation. Using RNA interference to disrupt expression of the p65 subunit of NF-kappa B, all but two of the genes were shown to depend on this transcription factor for their expression, which correlated well with the existence of NF-kappa B binding sites in most of their promoters. Inflammatory, proapoptotic, and antiapoptotic genes were all shown to be regulated by NF-kappa B, demonstrating the wide variety of targets activated by NF-kappa B signaling and the necessity of differentiating among these genes for therapeutic purposes.

Standard name | WELCSH_BRCA1_TARGETS_UP
Systematic name | M5490
Organism | Homo sapiens
PMID | 12032322
Authors | Welcsh PL,Lee MK,Gonzalez-Hernandez RM,Black DJ,Mahadevappa M,Swisher EM,Warrington JA,King MC
Category | C2
Sub-category | CGP
Brief description | Up-regulated by induction of exogenous BRCA1 in EcR-293 cells
Full description | Loss of function of BRCA1 caused by inherited mutation and tissue-specific somatic mutation leads to breast and ovarian cancer. Nearly all BRCA1 germ-line mutations involve truncation or loss of the C-terminal BRCT transcriptional activation domain, suggesting that transcriptional regulation is a critical function of the wild-type gene. The purpose of this project was to determine whether there is a link between the role of BRCA1 in transcriptional regulation and its role in tumor suppression. We developed a cell line (in which BRCA1 can be induced) and used microarray analysis to compare transcription profiles of epithelial cells with low endogenous levels of BRCA1 vs. transcription profiles of cells with 2-4-fold higher induced levels of expression of BRCA1. At these levels of expression, BRCA1 did not induce apoptosis. Undirected cluster analysis of six paired experiments revealed 373 genes, the expression of which was altered significantly and consistently by BRCA1 induction. Expression of 62 genes was altered more than 2-fold. BRCA1-regulated genes associated with breast tumorigenesis included the estrogen-responsive genes MYC and cyclin D1, which are overexpressed in many breast tumors; STAT1 and JAK1, key components of the cytokine signal transduction pathway; the extracellular matrix protein laminin 3A; ID4, an inhibitor of DNA-binding transcriptional activators, which in turn negatively regulates BRCA1 expression; and the prohormone stanniocalcin, expression of which is lost in breast tumor cells. Coordinated expression of BRCA1 with ID4 and with stanniocalcin was confirmed in primary breast and ovarian tumors.

Standard name | JACKSON_DNMT1_TARGETS_UP
Systematic name | M1604
Organism | Mus musculus
PMID | 11137995
Authors | Jackson-Grusby L,Beard C,Possemato R,Tudor M,Fambrough D,Csankovszki G,Dausman J,Lee P,Wilson C,Lander E,Jaenisch R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) upon Cre-lox knockout of DNMT1 [GeneID=1786].
Full description | Cytosine methylation of mammalian DNA is essential for the proper epigenetic regulation of gene expression and maintenance of genomic integrity. To define the mechanism through which demethylated cells die, and to establish a paradigm for identifying genes regulated by DNA methylation, we have generated mice with a conditional allele for the maintenance DNA methyltransferase gene Dnmt1. Cre-mediated deletion of Dnmt1 causes demethylation of cultured fibroblasts and a uniform p53-dependent cell death. Mutational inactivation of Trp53 partially rescues the demethylated fibroblasts for up to five population doublings in culture. Oligonucleotide microarray analysis showed that up to 10% of genes are aberrantly expressed in demethylated fibroblasts. Our results demonstrate that loss of Dnmt1 causes cell-type-specific changes in gene expression that impinge on several pathways, including expression of imprinted genes, cell-cycle control, growth factor/receptor signal transduction and mobilization of retroelements.

Standard name | CHANG_IMMORTALIZED_BY_HPV31_UP
Systematic name | M15837
Organism | Homo sapiens
PMID | 10756030
Authors | Chang YE,Laimins LA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in normal keratinocytes immortalized by infection with the high risk HPV31 (human papilloma virus) strain.
Full description | Human papillomaviruses (HPVs) infect keratinocytes and induce proliferative lesions. In infected cells, viral gene products alter the activities of cellular proteins, such as Rb and p53, resulting in altered cell cycle response. It is likely that HPV gene products also alter expression of cellular genes. In this study we used microarray analysis to examine the global changes in gene expression induced by high-risk HPV type 31 (HPV31). Among 7,075 known genes and ESTs (expressed sequence tags) tested, we found that 178 were upregulated and 150 were downregulated twofold or more in HPV31 cells compared to normal human keratinocytes. While no specific pattern could be deduced from the list of genes that were upregulated, downregulated genes could be classified to three groups: genes that are involved in the regulation of cell growth, genes that are specifically expressed in keratinocytes, and genes whose expression is increased in response to interferon stimulation. The basal level of expression of several interferon-responsive genes was found to be downregulated in HPV31 cells by both microarray analysis and Northern blot analysis in different HPV31 cell lines. When cells were treated with alpha or gamma interferon, expression of interferon-inducible genes was impaired. At high doses of interferon, the effects were less pronounced. Among the genes repressed by HPV31 was the signal transducer and activator of transcription (Stat-1), which plays a major role in mediating the interferon response. Suppression of Stat-1 expression may contribute to a suppressed response to interferon as well as immune evasion.

Standard name | MODY_HIPPOCAMPUS_PRENATAL
Systematic name | M5316
Organism | Mus musculus
PMID | 11438693
Authors | Mody M,Cao Y,Cui Z,Tay KY,Shyong A,Shimizu E,Pham K,Schultz P,Welsh D,Tsien JZ
Category | C2
Sub-category | CGP
Brief description | Genes highly expressed in prenatal hippocampus (cluster 1).
Full description | We have analyzed the developmental molecular programs of the mouse hippocampus, a cortical structure critical for learning and memory, by means of large-scale DNA microarray techniques. Of 11,000 genes and expressed sequence tags examined, 1,926 showed dynamic changes during hippocampal development from embryonic day 16 to postnatal day 30. Gene-cluster analysis was used to group these genes into 16 distinct clusters with striking patterns that appear to correlate with major developmental hallmarks and cellular events. These include genes involved in neuronal proliferation, differentiation, and synapse formation. A complete list of the transcriptional changes has been compiled into a comprehensive gene profile database (http://BrainGenomics.Princeton.edu), which should prove valuable in advancing our understanding of the molecular and genetic programs underlying both the development and the functions of the mammalian brain.

Standard name | BURTON_ADIPOGENESIS_4
Systematic name | M1605
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Progressively up-regulated from 8-48 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | ZHU_CMV_ALL_DN
Systematic name | M14555
Organism | Homo sapiens
PMID | 9826724
Authors | Zhu H,Cong JP,Mamtora G,Gingeras T,Shenk T
Category | C2
Sub-category | CGP
Brief description | Down-regulated at any timepoint following infection of primary human foreskin fibroblasts with CMV
Full description | Mechanistic insights to viral replication and pathogenesis generally have come from the analysis of viral gene products, either by studying their biochemical activities and interactions individually or by creating mutant viruses and analyzing their phenotype. Now it is possible to identify and catalog the host cell genes whose mRNA levels change in response to a pathogen. We have used DNA array technology to monitor the level of approximately 6,600 human mRNAs in uninfected as compared with human cytomegalovirus-infected cells. The level of 258 mRNAs changed by a factor of 4 or more before the onset of viral DNA replication. Several of these mRNAs encode gene products that might play key roles in virus-induced pathogenesis, identifying them as intriguing targets for further study.

Standard name | IVANOVA_HEMATOPOIESIS_INTERMEDIATE_PROGENITOR
Systematic name | M16005
Organism | Mus musculus
PMID | 12228721
Authors | Ivanova NB,Dimos JT,Schaniel C,Hackney JA,Moore KA,Lemischka IR
Category | C2
Sub-category | CGP
Brief description | Genes in the expression cluster 'Intermediate Progenitors Shared': up-regulated in hematopoietic intemediate progenitor cells from adult bone marrow and fetal liver.
Full description | Mechanisms regulating self-renewal and cell fate decisions in mammalian stem cells are poorly understood. We determined global gene expression profiles for mouse and human hematopoietic stem cells and other stages of the hematopoietic hierarchy. Murine and human hematopoietic stem cells share a number of expressed gene products, which define key conserved regulatory pathways in this developmental system. Moreover, in the mouse, a portion of the genetic program of hematopoietic stem cells is shared with embryonic and neural stem cells. This overlapping set of gene products represents a molecular signature of stem cells.

Standard name | GENTILE_UV_HIGH_DOSE_UP
Systematic name | M7048
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated in WS1 (fibroblast) in response to irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | SU_LIVER
Systematic name | M7054
Organism | Homo sapiens
PMID | 11904358
Authors | Su AI,Cooke MP,Ching KA,Hakak Y,Walker JR,Wiltshire T,Orth AP,Vega RG,Sapinoso LM,Moqrich A,Patapoutian A,Hampton GM,Schultz PG,Hogenesch JB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated specifically in human liver tissue.
Full description | High-throughput gene expression profiling has become an important tool for investigating transcriptional activity in a variety of biological samples. To date, the vast majority of these experiments have focused on specific biological processes and perturbations. Here, we have generated and analyzed gene expression from a set of samples spanning a broad range of biological conditions. Specifically, we profiled gene expression from 91 human and mouse samples across a diverse array of tissues, organs, and cell lines. Because these samples predominantly come from the normal physiological state in the human and mouse, this dataset represents a preliminary, but substantial, description of the normal mammalian transcriptome. We have used this dataset to illustrate methods of mining these data, and to reveal insights into molecular and physiological gene function, mechanisms of transcriptional regulation, disease etiology, and comparative genomics. Finally, to allow the scientific community to use this resource, we have built a free and publicly accessible website (http://expression.gnf.org) that integrates data visualization and curation of current gene annotations.

Standard name | CHIBA_RESPONSE_TO_TSA_DN
Systematic name | M12459
Organism | Homo sapiens
PMID | 15452378
Authors | Chiba T,Yokosuka O,Fukai K,Kojima H,Tada M,Arai M,Imazeki F,Saisho H
Category | C2
Sub-category | CGP
Brief description | Cancer related genes down-regulated in any of four hepatoma cell lines following 24 h treatment with TSA [PubChem=5562].
Full description | OBJECTIVE: Histone deacetylase (HDAC) inhibitors have been reported to induce cell growth arrest, apoptosis and differentiation in tumor cells. The effect of the HDAC inhibitor, trichostatin A (TSA), on hepatoma cells, however, has not been well studied. In this study, we examined cell viability and gene expression profile in hepatoma cell lines treated with TSA. METHODS: To study cell growth inhibition and induction of apoptosis by TSA on human hepatoma cell lines including HuH7, Hep3B, HepG2, and PLC/PRF/5, cells were treated with TSA at various concentrations and analyzed by the 3-(4, 5-dimethyl-2-thiazolyl)-2H-tetrazolium bromide (MTT) and TUNEL assays, respectively. Changes in gene expression profile after exposure to TSA were assessed using a cDNA microarray consisting of 557 distinct cDNA of cancer-related genes. The levels of acetylated histones were examined by the chromatin immunoprecipitation (ChIP) assay using anti-acetylated histone H3 or H4 antibody. RESULTS: The MTT assay demonstrated that TSA showed cell growth inhibition not only in a concentration-dependent but also a time-dependent manner on all cell lines studied. The TUNEL assay also revealed the potential of TSA to induce apoptosis. The microarray analysis revealed that 8 genes including collagen type 1, alpha2 (COL1A2), insulin-like growth factor binding protein 2 (IGFBP2), integrin, alpha7 (ITGA7), basigin (BSG), quiescin Q6 (QSCN6), superoxide dismutase 3, extracellular (SOD3), nerve growth factor receptor (NGFR), and p53-induced protein (PIG11) exhibited substantial induction (ratio >2.0) after TSA treatment in multiple cell lines. ChIP assay, in general, showed a good correlation between the expression level of mRNA and levels of acetylated histones in these upregulated genes. CONCLUSIONS: This study showed cell growth inhibition and the gene expression profile in hepatoma cell lines exposed to TSA. The alteration in levels of acetylated histones was closely associated with expression of specific cancer-related genes in hepatoma cells.

Standard name | KUNINGER_IGF1_VS_PDGFB_TARGETS_UP
Systematic name | M9065
Organism | Mus musculus
PMID | 15475267
Authors | Kuninger D,Kuzmickas R,Peng B,Pintar JE,Rotwein P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in C2AS12 cells (myoblast) by IGF1 [GeneID=3479] vs PDGFB [GeneID=5155].
Full description | Peptide growth factors regulate cell fate by activating distinct signal transduction pathways that ultimately influence gene expression. Insulin-like growth factors (IGFs) play central roles in controlling somatic growth and participate in skeletal muscle development and regeneration. In cultured muscle cells, IGF action is critical both for maintaining viability during the transition from proliferating to differentiating myoblasts and for facilitating differentiation. By contrast, platelet-derived growth factor (PDGF) can sustain cell survival but inhibits differentiation. Here we examine the genetic programs that accompany IGF and PDGF action in myoblasts. Through analysis of high-density oligonucleotide arrays containing approximately 36,000 mouse probe sets, we identify 90 transcripts differentially induced by IGF-I, including 28 muscle-specific genes and 33 previously unannotated mRNAs, and 55 transcripts specifically stimulated by PDGF, including 14 unknowns. Detailed study of one IGF-induced mRNA shows that it encodes a protein related to a recently characterized repulsive guidance molecule postulated to regulate neuronal targeting during development. Our results demonstrate the power of transcriptional profiling for gene discovery and provide opportunities for investigating new proteins potentially involved in different aspects of growth factor action in muscle.

Standard name | BLALOCK_ALZHEIMERS_DISEASE_INCIPIENT_DN
Systematic name | M6110
Organism | Homo sapiens
PMID | 14769913
Authors | Blalock EM,Geddes JW,Chen KC,Porter NM,Markesbery WR,Landfield PW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in patients at the incipient stage of Alzheimer's disease.
Full description | The pathogenesis of incipient Alzheimer's disease (AD) has been resistant to analysis because of the complexity of AD and the overlap of its early-stage markers with normal aging. Gene microarrays provide new tools for addressing complexity because they allow overviews of the simultaneous activity of multiple cellular pathways. However, microarray data interpretation is often hindered by low statistical power, high false positives or false negatives, and by uncertain relevance to functional endpoints. Here, we analyzed hippocampal gene expression of nine control and 22 AD subjects of varying severity on 31 separate microarrays. We then tested the correlation of each gene's expression with MiniMental Status Examination (MMSE) and neurofibrillary tangle (NFT) scores across all 31 subjects regardless of diagnosis. These well powered tests revealed a major transcriptional response comprising thousands of genes significantly correlated with AD markers. Several hundred of these genes were also correlated with AD markers across only control and incipient AD subjects (MMSE > 20). Biological process categories associated with incipient AD-correlated genes were identified statistically (ease program) and revealed up-regulation of many transcription factor/signaling genes regulating proliferation and differentiation, including tumor suppressors, oligodendrocyte growth factors, and protein kinase A modulators. In addition, up-regulation of adhesion, apoptosis, lipid metabolism, and initial inflammation processes occurred, and down-regulation of protein folding/metabolism/transport and some energy metabolism and signaling pathways took place. These findings suggest a new model of AD pathogenesis in which a genomically orchestrated up-regulation of tumor suppressor-mediated differentiation and involution processes induces the spread of pathology along myelinated axons.

Standard name | LIANG_SILENCED_BY_METHYLATION_UP
Systematic name | M14553
Organism | Homo sapiens
PMID | 11861364
Authors | Liang G,Gonzales FA,Jones PA,Orntoft TF,Thykjaer T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in LD419 cells (fibroblast) after treatment with decitabine (5-aza-2'-deoxycytidine) [PubChem=451668].
Full description | Hypermethylation of the promoters of cancer-related genes is often associated with their inactivation during tumorigenesis. Several preclinical and clinical trials have been developed to use DNA methylation inhibitors, such as 5-aza-2'-deoxycytidine (5-Aza-CdR) in attempts to reactivate silenced genes in human cancers. We used high-density oligonucleotide gene expression microarrays to examine the effects of 5-Aza-CdR treatment on human fibroblast cells (LD419) and a human bladder tumor cell line (T24). Data obtained 8 days after recovery from 5-Aza-CdR treatment showed that more genes were induced in tumorigenic cells (61 genes induced; >or=4-fold) than nontumorigenic cells (34 genes induced; >or= 4-fold). Approximately 60% of induced genes did not have CpG islands within their 5' regions, suggesting that some genes activated by 5-Aza-CdR may not result from the direct inhibition of promoter methylation. Interestingly, a high percentage of genes activated in both cell types belonged to the IFN signaling pathway, confirming data from other tumor cell types.

Standard name | SONG_TARGETS_OF_IE86_CMV_PROTEIN
Systematic name | M2257
Organism | Homo sapiens
PMID | 11867723
Authors | Song YJ,Stinski MF
Category | C2
Sub-category | CGP
Brief description | Cellular genes up-regulated in forskin fibroblasts by expression of CMV EI86 protein off an adenovirus vector.
Full description | We have previously reported that the immediate early (IE)-86 protein of human cytomegalovirus (HCMV) pushes the cell cycle toward S phase but inhibits cell division [Murphy, E. A., Streblow, D. N., Nelson, J. A. & Stinski, M. F. (2000) J. Virol. 74, 7108-7118]. We determined the cellular genes activated by the IE86 protein in permissive human fibroblast cells. A 4-fold or greater increase in the steady-state RNA from many cellular genes that regulate the cell cycle, the enzymes for DNA precursor synthesis, and the initiation of cellular DNA replication was detected by high-density DNA microarray analysis. Northern blot analysis confirmed the DNA microarray data. The viral IE86 protein induced a significant increase in the cellular steady-state RNA level from the B-myb, cyclin E, cdk-2, E2F-1, ribonucleotide reductase 1, ribonucleotide reductase 2, thymidylate synthetase, MCM3, and MCM7 genes, but actin RNA was not affected. Cellular genes regulated by the E2F transcription factors were strongly activated by the IE86 protein. In most cases, the cellular genes induced by the IE86 protein were also induced by HCMV infection. This study demonstrates the global array of cellular genes activated by the IE86 protein that pushes progression of the cell cycle from G0/G1 toward the G1/S transition point.

Standard name | LEE_CALORIE_RESTRICTION_NEOCORTEX_DN
Systematic name | M1609
Organism | Mus musculus
PMID | 10888876
Authors | Lee CK,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Down-regulated in the neocortex of aged (30-month) mice subjected to caloric restriction since young adulthood.
Full description | Ageing of the brain leads to impairments in cognitive and motor skills, and is the major risk factor for several common neurological disorders such as Alzheimer disease (AD) and Parkinson disease (PD). Recent studies suggest that normal brain ageing is associated with subtle morphological and functional alterations in specific neuronal circuits, as opposed to large-scale neuronal loss. In fact, ageing of the central nervous system in diverse mammalian species shares many features, such as atrophy of pyramidal neurons, synaptic atrophy, decrease of striatal dopamine receptors, accumulation of fluorescent pigments, cytoskeletal abnormalities, and reactive astrocytes and microglia. To provide the first global analysis of brain ageing at the molecular level, we used oligonucleotide arrays representing 6,347 genes to determine the gene-expression profile of the ageing neocortex and cerebellum in mice. Ageing resulted in a gene-expression profile indicative of an inflammatory response, oxidative stress and reduced neurotrophic support in both brain regions. At the transcriptional level, brain ageing in mice displays parallels with human neurodegenerative disorders. Caloric restriction, which retards the ageing process in mammals, selectively attenuated the age-associated induction of genes encoding inflammatory and stress responses.

Standard name | CUI_TCF21_TARGETS_2_UP
Systematic name | M1610
Organism | Mus musculus
PMID | 16207825
Authors | Cui S,Li C,Ema M,Weinstein J,Quaggin SE
Category | C2
Sub-category | CGP
Brief description | All significantly up-regulated genes in kidney glomeruli isolated from TCF21 [Gene ID=6943] knockout mice.
Full description | Mouse mutations have provided tremendous insights into the molecular basis of renal and glomerular development. However, genes often play important roles during multiple stages of nephrogenesis, making it difficult to determine the role of a gene in a specific cell lineage such as the podocyte. Conditional gene targeting and chimeric analysis are two possible approaches to dissect the function of genes in specific cell populations. However, these are labor-intensive and costly and require the generation, validation, and analysis of additional transgenic lines. For overcoming these shortcomings and, specifically, for studying the role of gene function in developing glomeruli, a technique to isolate and purify glomeruli from murine embryos was developed. Combined with gene expression profiling, this method was used to identify differentially expressed genes in glomeruli from Pod1 knockout (KO) mice that die in the perinatal period with multiple renal defects. Glomeruli from early developing stages (late S-shape/early capillary loop) onward can be isolated successfully from wild-type and KO kidneys at 18.5 d postcoitus, and RNA can readily be obtained and used for genome-wide microarray analysis. With this approach, 3986 genes that are differently expressed between glomeruli from Pod1 KO and wild-type mice were identified, including a four-fold reduction of alpha 8 integrin mRNA in glomeruli from Pod1 KO mice that was confirmed by immunostaining. This procedure may be adapted to any transgenic strain, providing a rapid and efficient method to dissect the function of specific genes in glomerular development.

Standard name | SESTO_RESPONSE_TO_UV_C1
Systematic name | M7933
Organism | Homo sapiens
PMID | 11867738
Authors | Sesto A,Navarro M,Burslem F,Jorcano JL
Category | C2
Sub-category | CGP
Brief description | Cluster 1: genes changed in primary keratinocytes by UVB irradiation.
Full description | UV radiation is the most important environmental skin aggressor, causing cancer and other problems. This paper reports the use of oligonucleotide microarray technology to determine changes in gene expression in human keratinocytes after UVB treatment. Examination of the effects of different doses at different times after irradiation gave a global picture of the keratinocyte response to this type of insult. Five hundred thirty-nine regulated transcripts were found and organized into nine different clusters depending on behavior patterns. Classification of these genes into 23 functional categories revealed that several biological processes are globally affected by UVB. In addition to confirming a majority up-regulation of the transcripts related to the UV-specific inflammatory and stress responses, significant increases were seen in the expression of genes involved in basal transcription, splicing, and translation as well as in the proteasome-mediated degradation category. On the other hand, those transcripts belonging to the metabolism and adhesion categories were strongly downregulated. These results demonstrate the complexity of the transcriptional profile of the UVB response, describe several cellular processes previously not known to be affected by UV irradiation, and serve as a basis for the global characterization of UV-regulated genes and pathways.

Standard name | LY_AGING_MIDDLE_UP
Systematic name | M19146
Organism | Homo sapiens
PMID | 10741968
Authors | Ly DH,Lockhart DJ,Lerner RA,Schultz PG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in fibroblasts from middle-age individuals, compared to those from the young donors.
Full description | Messenger RNA levels were measured in actively dividing fibroblasts isolated from young, middle-age, and old-age humans and humans with progeria, a rare genetic disorder characterized by accelerated aging. Genes whose expression is associated with age-related phenotypes and diseases were identified. The data also suggest that an underlying mechanism of the aging process involves increasing errors in the mitotic machinery of dividing cells in the postreproductive stage of life. We propose that this dysfunction leads to chromosomal pathologies that result in misregulation of genes involved in the aging process.

Standard name | WENG_POR_TARGETS_GLOBAL_UP
Systematic name | M1611
Organism | Mus musculus
PMID | 16006652
Authors | Weng Y,DiRusso CC,Reilly AA,Black PN,Ding X
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in liver from transgenic mice with reduced expression of POR [GeneID=5447] in all tissues.
Full description | NADPH-cytochrome P450 reductase (CPR) is an essential component for the function of many enzymes, including microsomal cytochrome P450 (P450) monooxygenases and heme oxygenases. In liver-Cpr-null (with liver-specific Cpr deletion) and Cpr-low (with reduced CPR expression in all organs examined) mouse models, a reduced serum cholesterol level and an induction of hepatic P450s were observed, whereas hepatomegaly and fatty liver were only observed in the liver-Cpr-null model. Our goal was to identify hepatic gene expression changes related to these phenotypes. Cpr-lox mice (with a floxed Cpr gene and normal CPR expression) were used as the control. Through microarray analysis, we identified many genes that were differentially expressed among the three groups of mice. We also recognized the 12 gene ontology terms that contained the most significantly changed gene expression in at least one of the two mouse models. We further uncovered potential mechanisms, such as an increased activation of constitutive androstane receptor and a decreased activation of peroxisomal proliferator-activated receptor-alpha by precursors of cholesterol biosynthesis, that underlie common changes (e.g. induction of multiple P450s and suppression of genes for fatty acid metabolism) in response to CPR loss in the two mouse models. Additionally, we observed model-specific gene expression changes, such as the induction of a fatty-acid translocase (Cd36 antigen) and the suppression of carnitine O-palmitoyltransferase 1 (Cpt1a) and acyl-CoA synthetase long chain family member 1 (Acsl1), that are potentially responsible for the severe hepatic lipidosis and an altered fatty acid profile observed in liver-Cpr-null mice.

Standard name | WU_HBX_TARGETS_1_UP
Systematic name | M3190
Organism | Homo sapiens
PMID | 11439330
Authors | Wu CG,Salvay DM,Forgues M,Valerie K,Farnsworth J,Markin RS,Wang XW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by expression of HBV X protein (HBVgp3) [GeneID=944566] in SK-Hep-1 cells (hepatocellular carcinoma).
Full description | Hepatitis B virus (HBV) is a major risk factor for the development of hepatocellular carcinoma (HCC). HBV encodes the potentially oncogenic HBx protein, which mainly functions as a transcriptional co-activator involving in multiple gene deregulations. However, mechanisms underlying HBx-mediated oncogenicity remain unclear. To determine the role(s) of HBx in the early genesis of HCC, we utilized the NCI Oncochip microarray that contains 2208 human cDNA clones to examine the gene expression profiles in either freshly isolated normal primary adult human hepatocytes (Hhep) or an HCC cell line (SK-Hep-1) ecotopically expressing HBx via an adenoviral system. The gene expression profiles also were determined in liver samples from HBV-infected chronic active hepatitis patients when compared with normal liver samples. The microarray results were validated through Northern blot analysis of the expression of selected genes. Using reciprocally labeling hybridizations, scatterplot analysis of gene expression ratios in human primary hepatocytes expressing HBx demonstrates that microarrays are highly reproducible. The comparison of gene expression profiles between HBx-expressing primary hepatocytes and HBV-infected liver samples shows a consistent alteration of many cellular genes including a subset of oncogenes (such as c-myc and c-myb) and tumor suppressor genes (such as APC, p53, WAF1 and WT1). Furthermore, clustering algorithm analysis showed distinctive gene expression profiles in Hhep and SK-Hep-1 cells. Our findings are consistent with the hypothesis that the deregulation of cellular genes by oncogenic HBx may be an early event that favors hepatocyte proliferation during liver carcinogenesis.

Standard name | GEISS_RESPONSE_TO_DSRNA_UP
Systematic name | M3911
Organism | Homo sapiens
PMID | 11487589
Authors | Geiss G,Jin G,Guo J,Bumgarner R,Katze MG,Sen GC
Category | C2
Sub-category | CGP
Brief description | Genes up-pregulated by dsRNA in GRE cells (glioma; no interferon system).
Full description | Double-stranded (ds) RNA, a common component of virus-infected cells, is a potent inducer of the type I interferon and other cellular genes. For identifying the full repertoire of human dsRNA-regulated genes, a cDNA microarray hybridization screening was conducted using mRNA from dsRNA-treated GRE cells. Because these cells lack all type I interferon genes, the possibility of gene induction by autocrine actions of interferon was eliminated. Our screen identified 175 dsRNA-stimulated genes (DSG) and 95 dsRNA-repressed genes. A subset of the DSGs was also induced by different inflammatory cytokines and viruses demonstrating interconnections among disparate signaling pathways. Functionally, the DSGs encode proteins involved in signaling, apoptosis, RNA synthesis, protein synthesis and processing, cell metabolism, transport, and structure. Induction of such a diverse family of genes by dsRNA has major implications in host-virus interactions and in the use of RNA(i) technology for functional ablation of specific genes.

Standard name | ABE_VEGFA_TARGETS
Systematic name | M19918
Organism | Homo sapiens
PMID | 12197474
Authors | Abe M,Sato Y
Category | C2
Sub-category | CGP
Brief description | Genes most profoundly induced in HUVEC cells (endothelium) by VEGFA [GeneID=7422].
Full description | Vascular endothelial growth factor (VEGF) is one of the most important factors that stimulate angiogenesis and vascular permeability. To clarify the role of VEGF, we analysed a human cDNA chip containing 7267 human genes to identify genes induced by VEGF in human umbilical vein endothelial cells (HUVECs). One hundred thirty-nine cDNAs, including ninety-nine previously known and forty poorly characterized or novel sequences, were increased more than two-fold by VEGF within twenty-four hours of stimulation. Among them, only five are known to regulate angiogenesis: cyclooxygenase 2 (COX2), heparin-binding epidermal growth factor-like growth factor, early growth response 1 (EGR 1), CYR61, and angiopoietin 2. Fifty-three genes induced within the first two hours were thought to be directly induced by VEGF. Of these, Down syndrome candidate region 1 (maximum induction = 6.1-fold) was the most profoundly induced, followed by Mifl (KIAA0025; 5.5-fold), COX2 (4.7-fold), EGR 3 (3.7-fold), EGR 2 (3.2-fold), bactericidal/permeability-increasing protein (3.1-fold), and CD1B antigen, b polypeptide (3.1-fold). In addition to the genes mentioned above, there were many poorly characterized or novel genes induced by VEGF. Further analysis of these genes may aid in the elucidation of the molecular mechanisms of angiogenesis or vascular permeability stimulated by VEGF.

Standard name | MMS_MOUSE_LYMPH_HIGH_4HRS_UP
Systematic name | M972
Organism | Mus musculus
PMID | 15515172
Authors | Islaih M,Li B,Kadura IA,Reid-Hubbard JL,Deahl JT,Altizer JL,Watson DE,Newton RK
Category | C2
Sub-category | CGP
Brief description | Up-regulated at 4 hours following treatment of mouse lymphocytes (TK 3.7.2C) with a high dose of methyl methanesulfonate (MMS)
Full description | Exposure to DNA-damaging agents can elicit a variety of stress-related responses that may alter the gene expression of numerous biological pathways. We used Affymetrix microarrays to detect gene expression changes in mouse lymphoma (L5178Y) and human lymphoblastoid (TK6) cells in response to methyl methanesulfonate (MMS; a prototypical alkylating agent) and bleomycin (a prototypical oxidative mutagen). Cells were treated for 4 hr, and RNA was isolated either at the end of the treatment or after a 20-hr recovery period. Two concentrations of each agent were used based on cytotoxicity levels and Tk mutant frequencies. Our microarray data analysis indicated that MMS and bleomycin gene expression responses were considerably different in mouse cells versus human cells. The results also suggested that more comprehensive cellular responses to MMS and bleomycin occurred in TK6 cells than in L5178Y cells. In contrast to L5178Y cells, the response of TK6 cells to MMS and bleomycin was characterized by the induction of p53-dependent genes that are involved in DNA repair, cell cycle regulation, and apoptosis. It appears that the induction of DNA damage by MMS in human TK6 cells mediated cytotoxicity and led to decreased cell survival. This may explain the greater sensitivity of TK6 cells to cytotoxic effects of MMS compared to L5178Y cells. Bleomycin exerted comparable cytotoxic effects in the two cell lines. Overall, these studies were unable to identify distinctive gene expression changes that differentiated bleomycin from MMS in either TK6 cells or mouse lymphoma cells.

Standard name | BURTON_ADIPOGENESIS_1
Systematic name | M1612
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Strongly up-regulated at 2 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | LIANG_SILENCED_BY_METHYLATION_DN
Systematic name | M6302
Organism | Homo sapiens
PMID | 11861364
Authors | Liang G,Gonzales FA,Jones PA,Orntoft TF,Thykjaer T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in LD419 cells (fibroblast) after treatment with decitabine (5-aza-2'-deoxycytidine) [PubChem=451668].
Full description | Hypermethylation of the promoters of cancer-related genes is often associated with their inactivation during tumorigenesis. Several preclinical and clinical trials have been developed to use DNA methylation inhibitors, such as 5-aza-2'-deoxycytidine (5-Aza-CdR) in attempts to reactivate silenced genes in human cancers. We used high-density oligonucleotide gene expression microarrays to examine the effects of 5-Aza-CdR treatment on human fibroblast cells (LD419) and a human bladder tumor cell line (T24). Data obtained 8 days after recovery from 5-Aza-CdR treatment showed that more genes were induced in tumorigenic cells (61 genes induced; >or=4-fold) than nontumorigenic cells (34 genes induced; >or= 4-fold). Approximately 60% of induced genes did not have CpG islands within their 5' regions, suggesting that some genes activated by 5-Aza-CdR may not result from the direct inhibition of promoter methylation. Interestingly, a high percentage of genes activated in both cell types belonged to the IFN signaling pathway, confirming data from other tumor cell types.

Standard name | MOREIRA_RESPONSE_TO_TSA_DN
Systematic name | M3506
Organism | Homo sapiens
PMID | 14606959
Authors | Moreira JM,Scheipers P,Sørensen P
Category | C2
Sub-category | CGP
Brief description | Down-regulated in CD4+ [GeneID=920] T lymphocytes after 4 h treatment with 100 nM TSA [PubChem=5562].
Full description | BACKGROUND: Histone deacetylase inhibitors (HDACIs) induce hyperacetylation of core histones modulating chromatin structure and affecting gene expression. These compounds are also able to induce growth arrest, cell differentiation, and apoptotic cell death of tumor cells in vitro as well as in vivo. Even though several genes modulated by HDAC inhibition have been identified, those genes clearly responsible for the biological effects of these drugs have remained elusive. We investigated the pharmacological effect of the HDACI and potential anti-cancer agent Trichostatin A (TSA) on primary T cells. METHODS: To ascertain the effect of TSA on resting and activated T cells we used a model system where an enriched cell population consisting of primary T-cells was stimulated in vitro with immobilized anti-CD3/anti-CD28 antibodies whilst exposed to pharmacological concentrations of Trichostatin A. RESULTS: We found that this drug causes a rapid decline in cytokine expression, accumulation of cells in the G1 phase of the cell cycle, and induces apoptotic cell death. The mitochondrial respiratory chain (MRC) plays a critical role in the apoptotic response to TSA, as dissipation of mitochondrial membrane potential and reactive oxygen species (ROS) scavengers block TSA-induced T-cell death. Treatment of T cells with TSA results in the altered expression of a subset of genes involved in T cell responses, as assessed by microarray gene expression profiling. We also observed up- as well as down-regulation of various costimulatory/adhesion molecules, such as CD28 and CD154, important for T-cell function. CONCLUSIONS: Taken together, our findings indicate that HDAC inhibitors have an immunomodulatory potential that may contribute to the potency and specificity of these antineoplastic compounds and might be useful in the treatment of autoimmune disorders.

Standard name | WENG_POR_TARGETS_GLOBAL_DN
Systematic name | M1615
Organism | Mus musculus
PMID | 16006652
Authors | Weng Y,DiRusso CC,Reilly AA,Black PN,Ding X
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in liver from transgenic mice with reduced expression of POR [GeneID=5447] in all tissues.
Full description | NADPH-cytochrome P450 reductase (CPR) is an essential component for the function of many enzymes, including microsomal cytochrome P450 (P450) monooxygenases and heme oxygenases. In liver-Cpr-null (with liver-specific Cpr deletion) and Cpr-low (with reduced CPR expression in all organs examined) mouse models, a reduced serum cholesterol level and an induction of hepatic P450s were observed, whereas hepatomegaly and fatty liver were only observed in the liver-Cpr-null model. Our goal was to identify hepatic gene expression changes related to these phenotypes. Cpr-lox mice (with a floxed Cpr gene and normal CPR expression) were used as the control. Through microarray analysis, we identified many genes that were differentially expressed among the three groups of mice. We also recognized the 12 gene ontology terms that contained the most significantly changed gene expression in at least one of the two mouse models. We further uncovered potential mechanisms, such as an increased activation of constitutive androstane receptor and a decreased activation of peroxisomal proliferator-activated receptor-alpha by precursors of cholesterol biosynthesis, that underlie common changes (e.g. induction of multiple P450s and suppression of genes for fatty acid metabolism) in response to CPR loss in the two mouse models. Additionally, we observed model-specific gene expression changes, such as the induction of a fatty-acid translocase (Cd36 antigen) and the suppression of carnitine O-palmitoyltransferase 1 (Cpt1a) and acyl-CoA synthetase long chain family member 1 (Acsl1), that are potentially responsible for the severe hepatic lipidosis and an altered fatty acid profile observed in liver-Cpr-null mice.

Standard name | BURTON_ADIPOGENESIS_7
Systematic name | M1616
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Down-regulated at 48-96 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | BROWNE_HCMV_INFECTION_10HR_UP
Systematic name | M15382
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 10 h time point that were not up-regulated at the previous time point, 8 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | LIU_SMARCA4_TARGETS
Systematic name | M1618
Organism | Homo sapiens
PMID | 11509180
Authors | Liu R,Liu H,Chen X,Kirby M,Brown PO,Zhao K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SW-13 cells (kidney cancer) by transient expression of SMARCA4 [GeneID=6597] at 24 h off a plasmid vector.
Full description | The mammalian BAF complex regulates gene expression by modifying chromatin structure. In this report, we identify 80 genes activated and 2 genes repressed by the BAF complex in SW-13 cells. We find that prior binding of NFI/CTF to the NFI/CTF binding site in CSF1 promoter is required for the recruitment of the BAF complex and the BAF-dependent activation of the promoter. Furthermore, the activation of the CSF1 promoter requires Z-DNA-forming sequences that are converted to Z-DNA structure upon activation by the BAF complex. The BAF complex facilitates Z-DNA formation in a nucleosomal template in vitro. We propose a model in which the BAF complex promotes Z-DNA formation which, in turn, stabilizes the open chromatin structure at the CSF1 promoter.

Standard name | GENTILE_UV_RESPONSE_CLUSTER_D1
Systematic name | M3990
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Cluster d1: genes down-regulated in WS1 cells (fibroblast) at 6 h after irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | DEBIASI_APOPTOSIS_BY_REOVIRUS_INFECTION_DN
Systematic name | M3063
Organism | Homo sapiens
PMID | 12885910
Authors | DeBiasi RL,Clarke P,Meintzer S,Jotte R,Kleinschmidt-Demasters BK,Johnson GL,Tyler KL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HEK293 cells (embryonic kidney) at 6 h, 12 h or 24 h after infection with reovirus strain T3A (known as a strong inducer of apoptosis).
Full description | Reoviruses are a leading model for understanding cellular mechanisms of virus-induced apoptosis. Reoviruses induce apoptosis in multiple cell lines in vitro, and apoptosis plays a key role in virus-induced tissue injury of the heart and brain in vivo. The activation of transcription factors NF-kappaB and c-Jun are key events in reovirus-induced apoptosis, indicating that new gene expression is critical to this process. We used high-density oligonucleotide microarrays to analyze cellular transcriptional alterations in HEK293 cells after infection with reovirus strain T3A (i.e., apoptosis inducing) compared to infection with reovirus strain T1L (i.e., minimally apoptosis inducing) and uninfected cells. These strains also differ dramatically in their potential to induce apoptotic injury in hearts of infected mice in vivo-T3A is myocarditic, whereas T1L is not. Using high-throughput microarray analysis of over 12,000 genes, we identified differential expression of a defined subset of genes involved in apoptosis and DNA repair after reovirus infection. This provides the first comparative analysis of altered gene expression after infection with viruses of differing apoptotic phenotypes and provides insight into pathogenic mechanisms of virus-induced disease.

Standard name | RAMPON_ENRICHED_LEARNING_ENVIRONMENT_EARLY_UP
Systematic name | M1619
Organism | Mus musculus
PMID | 11070096
Authors | Rampon C,Jiang CH,Dong H,Tang YP,Lockhart DJ,Schultz PG,Tsien JZ,Hu Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the brain cortex of mice that were exposed to an enriched learning environment for one day.
Full description | An enriched environment is known to promote structural changes in the brain and to enhance learning and memory performance in rodents [Hebb, D. O. (1947) Am. Psychol. 2, 306-307]. To better understand the molecular mechanisms underlying these experience-dependent cognitive changes, we have used high-density oligonucleotide microarrays to analyze gene expression in the brain. Expression of a large number of genes changes in response to enrichment training, many of which can be linked to neuronal structure, synaptic plasticity, and transmission. A number of these genes may play important roles in modulating learning and memory capacity.

Standard name | SARTIPY_BLUNTED_BY_INSULIN_RESISTANCE_DN
Systematic name | M1620
Organism | Mus musculus
PMID | 14530283
Authors | Sartipy P,Loskutoff DJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 3T3-L1 cells (adipocyte) by insulin [GeneID=3630] but displayed blunted response to insulin the insulin resistant cells.
Full description | We have employed microarray technology using RNA from normal 3T3-L1 adipocytes and from 3T3-L1 adipocytes made insulin-resistant by treatment with tumor necrosis factor-alpha to identify a new class of insulin-responsive genes. These genes continued to respond normally to insulin even though the adipocytes themselves were metabolically insulin-resistant, i.e. they displayed a significantly decreased rate of insulin-stimulated glucose uptake. Approximately 12,000 genes/expressed sequence tags (ESTs) were screened. Of these, 40 genes/ESTs were identified that became insulin-resistant as expected (e.g. Socs-3, junB, and matrix metalloproteinase-11). However, 61 genes/ESTs continued to respond normally to insulin. Although some of these genes were previously shown to be regulated by insulin (e.g. Glut-1 and beta3-adrenergic receptor), other novel insulin-sensitive genes were also identified (e.g. Egr-1, epiregulin, Fra-1, and ABCA1). Real-time reverse transcription-PCR analysis confirmed the expression patterns of several of the differentially expressed genes. One gene that remained insulin-sensitive in the insulin-resistant adipocytes is the transcription factor Egr-1. Using an antisense strategy, we show that tissue factor and macrophage colony-stimulating factor, two cardiovascular risk factors, are downstream EGR-1 target genes in the adipocyte. Taken together, these data support the hypothesis that some signaling pathways remain insulin-sensitive in metabolically insulin-resistant adipocytes. These pathways may promote abnormal gene expression in hyperinsulinemic states like obesity and type II diabetes and thus may contribute to pathologies associated with these conditions.

Standard name | ZHANG_ANTIVIRAL_RESPONSE_TO_RIBAVIRIN_DN
Systematic name | M950
Organism | Homo sapiens
PMID | 12719586
Authors | Zhang Y,Jamaluddin M,Wang S,Tian B,Garofalo RP,Casola A,Brasier AR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A549 cells (lung carcinoma) upon infection with RSV (respiratory syncytial virus) and down-regulated by further treatment with ribavirin [PubChem=5064].
Full description | Respiratory syncytial virus (RSV) is a mucosa-restricted virus that is a leading cause of epidemic respiratory tract infections in children. RSV replication is a potent activator of the epithelial-cell genomic response, influencing the expression of a spectrum of cellular pathways, including proinflammatory chemokines of the CC, CXC, and CX(3)C subclasses. Ribavirin (1-beta-D-ribofuranosyl-1,2,4-triazole-3-carboxamide) is a nontoxic antiviral agent currently licensed for the treatment of severe RSV lower respiratory tract infections. Because ribavirin treatment reduces the cytopathic effect in infected cells, we used high-density microarrays to investigate the hypothesis that ribavirin modifies the virus-induced epithelial genomic response to replicating virus. Ribavirin treatment administered in concentrations of 10 to 100 micro g/ml potently inhibited RSV transcription, thereby reducing the level of RSV N transcripts to approximately 13% of levels in nontreated cells. We observed that in both the absence and the presence of ribavirin, RSV infection induced global alterations in the host epithelial cell, affecting approximately 49% of the approximately 6,650 expressed genes detectable by the microarray. Ribavirin influences the expression of only 7.5% of the RSV-inducible genes (total number of genes, 272), suggesting that the epithelial-cell genetic program initiated by viral infection is independent of high-level RSV replication. Hierarchical clustering of the ribavirin-regulated genes identified four expression patterns. In one group, ribavirin inhibited the expression of the RSV-inducible CC chemokines MIP-1 alpha and -1 beta, which are important in RSV-induced pulmonary pathology, and interferon (IFN), a cytokine important in the mucosal immune response. In a second group, ribavirin further up-regulated a set of RSV- and IFN-stimulated response genes (ISGs) encoding antiviral proteins (MxA and p56), complement products, acute-phase response factors, and the STAT and IRF transcription factors. Because IFN-beta expression itself was reduced in the ribavirin-treated cells, we further investigated the mechanism for up-regulation of the IFN-signaling pathway. Enhanced expression of IFI 6-16, IFI 9-27, MxA/p78, STAT-1 alpha, STAT-1 beta, IRF-7B, and TAP-1-LMP2 transcripts were independently reproduced by Northern blot analysis. Ribavirin-enhanced TAP-1-LMP2 expression was a transcriptional event where site mutations of the IFN-stimulated response element (ISRE) blocked RSV and ribavirin-inducible promoter activity. Furthermore, ribavirin up-regulated the transcriptional activity of a reporter gene selectively driven by the ISRE. In specific DNA pull-down assays, we observed that ribavirin enhanced RSV-induced STAT-1 binding to the ISRE. We conclude that ribavirin potentiates virus-induced ISRE signaling to enhance the expression of antiviral ISGs, suggesting a mechanism for the efficacy of combined treatment with ribavirin and IFN in other chronic viral diseases.

Standard name | SCHLINGEMANN_SKIN_CARCINOGENESIS_TPA_DN
Systematic name | M1623
Organism | Mus musculus
PMID | 12640676
Authors | Schlingemann J,Hess J,Wrobel G,Breitenbach U,Gebhardt C,Steinlein P,Kramer H,Fürstenberger G,Hahn M,Angel P,Lichter P
Category | C2
Sub-category | CGP
Brief description | Down-regulated in murine dorsal skin cells at 6 h after treatment with the phorbol ester carcinogen TPA [PubChem=4792].
Full description | Malignant transformation of mouse skin by chemical carcinogens and tumour promoters, such as the phorbol ester 12-O-tetradecanoylphorbol-13-acetate (TPA), is a multistage process that leads to squamous cell carcinoma (SCC) formation. In an effort to identify tumour-associated genes, we studied the influence of short-term TPA-treatment on the gene expression profile of murine skin. A comprehensive microarray with some 5,000 murine gene specific cDNA fragments was established and hybridised with pooled RNA derived from control and TPA-treated dorsal skin samples. Of these genes, 54 were up- and 35 were down-regulated upon TPA application. Additionally, we performed suppression subtractive hybridisation (SSH) with respective RNA pools to generate and analyse a cDNA library enriched for TPA-inducible genes. Expression data of selected genes were confirmed by quantitative real-time PCR and Northern blot analysis. Comparison of microarray and SSH data revealed that 26% of up-regulated genes identified by expression profiling matched with those present in the SSH library. Besides numerous known genes, we identified a large set of unknown cDNAs that represent previously unrecognised TPA-regulated genes in murine skin with potential function in tumour promotion. Additionally, some TPA-induced genes, such as Sprr1A, Saa3, JunB, Il4ralpha, Gp38, RalGDS and Slpi exhibit high basal level in advanced stages of skin carcinogenesis, suggesting that at least a subgroup of the identified TPA-regulated genes may contribute to tumour progression and metastasis.

Standard name | DELASERNA_TARGETS_OF_MYOD_AND_SMARCA4
Systematic name | M1624
Organism | Mus musculus
PMID | 15870273
Authors | de la Serna IL,Ohkawa Y,Berkes CA,Bergstrom DA,Dacwag CS,Tapscott SJ,Imbalzano AN
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NIH 3T3 cells (fibroblasts) 24 h after inducing MYOD [GeneID=4654] which were down-regulated by dominant negative form of SMARCA4 [GeneID=6597].
Full description | The activation of muscle-specific gene expression requires the coordinated action of muscle regulatory proteins and chromatin-remodeling enzymes. Microarray analysis performed in the presence or absence of a dominant-negative BRG1 ATPase demonstrated that approximately one-third of MyoD-induced genes were highly dependent on SWI/SNF enzymes. To understand the mechanism of activation, we performed chromatin immunoprecipitations analyzing the myogenin promoter. We found that H4 hyperacetylation preceded Brg1 binding in a MyoD-dependent manner but that MyoD binding occurred subsequent to H4 modification and Brg1 interaction. In the absence of functional SWI/SNF enzymes, muscle regulatory proteins did not bind to the myogenin promoter, thereby providing evidence for SWI/SNF-dependent activator binding. We observed that the homeodomain factor Pbx1, which cooperates with MyoD to stimulate myogenin expression, is constitutively bound to the myogenin promoter in a SWI/SNF-independent manner, suggesting a two-step mechanism in which MyoD initially interacts indirectly with the myogenin promoter and attracts chromatin-remodeling enzymes, which then facilitate direct binding by MyoD and other regulatory proteins.

Standard name | BRACHAT_RESPONSE_TO_CAMPTOTHECIN_DN
Systematic name | M1625
Organism | Mus musculus
PMID | 12447701
Authors | Brachat A,Pierrat B,Xynos A,Brecht K,Simonen M,Brüngger A,Heim J
Category | C2
Sub-category | CGP
Brief description | Genes specifically down-regulated in FL5.12 cells (pro-B lymphocyte) by camptothecin [PubChem=2538].
Full description | DNA microarrays are powerful tools for the analysis of gene expression on a genomic scale. The importance of individual regulatory events for the process under study can however not be deduced unequivocally without additional experiments. We devised a strategy to identify central regulators of cancer drug responses by combining the results of microarray experiments with efficient methods for phenotypic testing of candidate genes. We exposed murine FL5.12 pro-B cells to cisplatin, camptothecin, methotrexate or paclitaxel, respectively and analysed the patterns of gene expression with cDNA microarrays. Drug-specific regulatory events as well as intersections between different apoptotic pathways, including previously studied responses to staurosporine and interleukin-3 (IL-3) deprivation, were identified. Genes shared by at least three pathways were chosen for further analysis. Ectopic expression of three such genes, TEAP, GP49B, and Lipin1 was found to have an anti-proliferative effect on pro-B cells. Interestingly, we identified hemoglobin alpha as a strong pro-apoptotic regulator. While hemoglobin-expressing cells were growing normally in the presence of IL-3, they displayed accelerated apoptosis with similar kinetics as Bax overexpressing cells upon IL-3 removal. The pro-apoptotic effect of hemoglobin was suppressed by Bcl-2 and was characterized by enhanced stimulation of caspase activity.

Standard name | WHITESIDE_CISPLATIN_RESISTANCE_DN
Systematic name | M8834
Organism | Homo sapiens
PMID | 14737109
Authors | Whiteside MA,Chen DT,Desmond RA,Abdulkadir SA,Johanning GL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NCI-H2170 cells (lung cancer) upon induction of resistance to cisplatin [PubChem=2767].
Full description | In recent years, most cDNA microarray studies of chemotherapeutic drug resistance have not considered the temporal pattern of gene expression. The objective of this study was to examine systematically changes in gene expression of NCI-H226 and NCI-H2170 lung cancer cells treated weekly with IC10 doses of cisplatin. NCI-H226 lung cancer cells were treated weekly with an IC10 dose of cisplatin. Candidate genes with a fold change of 2.0 or more were identified from this study. A second experiment was conducted by exposing NCI-H2170 cells to cisplatin doses that were increased in week 4 and decreased in week 5. Overall, 44 genes were differentially expressed in both the NCI-H226 and NCI-H2170 cell lines. In the NCI-H2170 cell line, 24 genes had a twofold gene expression change from weeks 3 to 4. Real-time PCR found a significant correlation of the gene expression changes for seven genes of interest. This small time-ordered series identified novel genes associated with cisplatin resistance. This kind of analysis should be viewed as a first step towards building gene-regulatory networks.

Standard name | BURTON_ADIPOGENESIS_PEAK_AT_0HR
Systematic name | M1626
Organism | Mus musculus
PMID | 12137940
Authors | Burton GR,Guan Y,Nagarajan R,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Cluster 1: genes progressively down-regulated over 24 h (peak at 0 h timepoint) during differentiation of 3T3-L1 fibroblasts into adipocytes in response to adipogenic hormones.
Full description | The molecular mechanisms that regulate cellular differentiation during development and throughout life are complex. It is now recognized that precise patterns of differentially expressed genes ultimately direct a particular cell toward a given lineage and many of these are regulated during the earliest stages of differentiation. Using a microarray-based expression analysis, we have examined gene expression profiles during the first 24 h of 3T3-L1 adipocyte differentiation. RNA was isolated at times 0, 2, 8, 16, and 24 h following stimulation of differentiation and hybridized in duplicate to high density Affymetrix microarray gene chips containing a series of 13,179 cDNA/expressed sequence tag (EST) probe sets. Two hundred and eighty-five cDNA/ESTs were shown to have at least a fivefold change in expression levels during this time course and both hierarchical and self-organizing map clustering analysis was performed to categorize them by expression profiles. Several genes known to be regulated during this time period were confirmed and Western blot analysis of the proteins encoded by some of the identified genes revealed expression profiles similar to their mRNA counterparts. As expected, many of the genes identified have not been examined in such a critical time period during adipogenesis and may well represent novel adipogenic mediators.

Standard name | JAZAERI_BREAST_CANCER_BRCA1_VS_BRCA2_UP
Systematic name | M2202
Organism | Homo sapiens
PMID | 12096084
Authors | Jazaeri AA,Yee CJ,Sotiriou C,Brantley KR,Boyd J,Liu ET
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes distinguishing between breast cancer tumors with mutated BRCA1 [GeneID=672] from those with mutated BRCA2 [GeneID=675].
Full description | BACKGROUND: Germline mutations in BRCA1 and BRCA2 are responsible for 5%-10% of epithelial ovarian cancers, but the molecular pathways affected by these mutations are unknown. We used complementary DNA (cDNA) microarrays to compare gene expression patterns in ovarian cancers associated with BRCA1 or BRCA2 mutations with gene expression patterns in sporadic epithelial ovarian cancers and to identify patterns common to both hereditary and sporadic tumors. METHODS: Tumor samples from 61 patients with pathologically confirmed epithelial ovarian adenocarcinoma with matched clinicopathologic features were studied, including 18 with BRCA1 founder mutations, 16 with BRCA2 founder mutations, and 27 without either founder mutation (termed sporadic cancers). The cDNA microarrays contained 7651 sequence-verified features. Gene expression data were analyzed with a modified two-sided F test, with P<.0001 considered statistically significant. The expression level of six genes was also studied with reverse transcription-polymerase chain reaction. RESULTS: The greatest contrast in gene expression was observed between tumors with BRCA1 mutations and those with BRCA2 mutations; 110 genes showed statistically significantly different expression levels (P<.0001). This group of genes could segregate sporadic tumors into two subgroups, BRCA1-like and BRCA2-like, suggesting that BRCA1-related and BRCA2-related pathways are also involved in sporadic ovarian cancers. Fifty-three genes were differentially expressed between tumors with BRCA1 mutations and sporadic tumors; six of the 53 mapped to Xp11.23 and were expressed at higher levels in tumors with BRCA1 mutations than in sporadic tumors. Compared with the immortalized ovarian surface epithelial cells used as reference, several interferon-inducible genes were overexpressed in the majority of tumors with a BRCA mutation and in sporadic tumors. CONCLUSIONS: Mutations in BRCA1 and BRCA2 may lead to carcinogenesis through distinct molecular pathways that also appear to be involved in sporadic cancers. Sporadic carcinogenic pathways may result from epigenetic aberrations of BRCA1 and BRCA2 or their downstream effectors.

Standard name | JACKSON_DNMT1_TARGETS_DN
Systematic name | M1627
Organism | Mus musculus
PMID | 11137995
Authors | Jackson-Grusby L,Beard C,Possemato R,Tudor M,Fambrough D,Csankovszki G,Dausman J,Lee P,Wilson C,Lander E,Jaenisch R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblast) upon Cre-lox knockout of DNMT1 [GeneID=1786].
Full description | Cytosine methylation of mammalian DNA is essential for the proper epigenetic regulation of gene expression and maintenance of genomic integrity. To define the mechanism through which demethylated cells die, and to establish a paradigm for identifying genes regulated by DNA methylation, we have generated mice with a conditional allele for the maintenance DNA methyltransferase gene Dnmt1. Cre-mediated deletion of Dnmt1 causes demethylation of cultured fibroblasts and a uniform p53-dependent cell death. Mutational inactivation of Trp53 partially rescues the demethylated fibroblasts for up to five population doublings in culture. Oligonucleotide microarray analysis showed that up to 10% of genes are aberrantly expressed in demethylated fibroblasts. Our results demonstrate that loss of Dnmt1 causes cell-type-specific changes in gene expression that impinge on several pathways, including expression of imprinted genes, cell-cycle control, growth factor/receptor signal transduction and mobilization of retroelements.

Standard name | DAZARD_RESPONSE_TO_UV_NHEK_DN
Systematic name | M8702
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NHEK cells (normal keratinocytes) by UV-B irradiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | BANDRES_RESPONSE_TO_CARMUSTIN_WITHOUT_MGMT_48HR_UP
Systematic name | M17700
Organism | Homo sapiens
PMID | 15980968
Authors | Bandres E,Andion E,Escalada A,Honorato B,Catalan V,Cubedo E,Cordeu L,Garcia F,Zarate R,Zabalegui N,Garcia-Foncillas J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A172 cells (glioma, does not express MGMT [GeneID=4255]) by carmustine [PubChem=2578] at 48 h.
Full description | Chemotherapy with the alkylating agent BCNU (1,3-bis (2-chloroethyl)-1-nitrosourea) is the most commonly used chemotherapeutic agent for gliomas. However, the usefulness of this agent is limited because tumor cell resistance to BCNU is frequently found in clinical brain tumor therapy. The O6-methylguanine-DNA methyltransferase protein (MGMT) reverses alkylation at the O6 position of guanine and we have reported the role of MGMT in the response of brain tumors to alkylating agents. However, the different mechanisms underlying the patterns related to MGMT remain unclear. To better understand the molecular mechanism by which BCNU exerts its effect in glioma cell lines according MGMT expression, we used microarray technology to interrogate 3800 known genes and determine the gene expression profiles altered by BCNU treatment. Our results showed that treatment with BCNU alters the expression of a diverse group of genes in a time-dependent manner. A subset of gene changes was found common in both glioma cell lines and other subset is specific of each cell line. After 24 h of BCNU treatment, up-regulation of transcription factors involved in the nucleation of both RNA polymerase II and III transcription initiation complexes was reported. Interestingly, BCNU promoted the expression of actin-dependent regulators of chromatin. Similar effects were found with higher BCNU doses in MGMT+ cell line showing a similar mechanism that in MGMT-deficient cell with standard doses. Our data suggest that human glioma cell lines treated with BCNU, independently of MGMT expression, show changes in the expression of cell cycle and survival-related genes interfering the transcription mechanisms and the chromatin regulation.

Standard name | KYNG_RESPONSE_TO_H2O2_VIA_ERCC6
Systematic name | M1629
Organism | Homo sapiens
PMID | 12606941
Authors | Kyng KJ,May A,Brosh RM Jr,Cheng WH,Chen C,Becker KG,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CS-B cells (Cockayne syndrome fibroblast, CS) with defficient ERCC6 [GeneID=2074] in response to hydrogen peroxide [PubChem=784].
Full description | Cockayne syndrome (CS) is a human hereditary disease belonging to the group of segmental progerias, and the clinical phenotype is characterized by postnatal growth failure, neurological dysfunction, cachetic dwarfism, photosensitivity, sensorineural hearing loss, and retinal degradation. CS-B cells are defective in transcription-coupled DNA repair, base excision repair, transcription, and chromatin structural organization. Using array analysis, we have examined the expression profile in CS complementation group B (CS-B) fibroblasts after exposure to oxidative stress (H2O2) before and after complete complementation with the CSB gene. The following isogenic cell lines were compared: CS-B cells (CS-B null), CS-B cells complemented with wild-type CSB (CS-B wt), and a stably transformed cell line with a point mutation in the ATPase domain of CSB (CS-B ATPase mutant). In the wt rescued cells, we detected significant induction (two-fold) of 112 genes out of the 6912 analysed. The patterns suggested an induction or upregulation of genes involved in several DNA metabolic processes including DNA repair, transcription, and signal transduction. In both CS-B mutant cell lines, we found a general deficiency in transcription after oxidative stress, suggesting that the CSB protein influenced the regulation of transcription of certain genes. Of the 6912 genes, 122 were differentially regulated by more than two-fold. Evidently, the ATPase function of CSB is biologically important as the deficiencies seen in the ATPase mutant cells are very similar to those observed in the CS-B-null cells. Some major defects are in the transcription of genes involved in DNA repair, signal transduction, and ribosomal functions.

Standard name | KALMA_E2F1_TARGETS
Systematic name | M10142
Organism | Rattus norvegicus
PMID | 11313881
Authors | Kalma Y,Marash L,Lamed Y,Ginsberg D
Category | C2
Sub-category | CGP
Brief description | DNA replication genes up-regulated in a Rat-1a cell line (fibroblast) by expression of E2F1 [GeneID=1869].
Full description | The transcription factor E2F-1 plays a pivotal role in the regulation of G1/S transition in higher eukaryotes cell cycle. We used a cell line containing an inducible E2F-1 and oligonucleotide microarray analysis to identify novel E2F target genes. We show that E2F-1 up-regulates the expression of a number of genes coding for components of the DNA replication machinery. Among them is the gene coding for the 32 Kd subunit of replication protein A (RPA2). Replication protein A is the most abundant single strand DNA binding complex and it is essential for DNA replication. We demonstrate that RPA2 is a novel E2F target gene whose expression can be directly regulated by E2F-1 via E2F binding sites in its promoter. In addition, expression of Topoisomerase IIalpha and subunit IV of DNA polymerase alpha is also up-regulated upon E2F-1 induction. Taken together, these results provide novel links between components of the DNA replication machinery and the cell growth regulatory pathway involving the Rb tumor suppressor and E2F.

Standard name | VERRECCHIA_RESPONSE_TO_TGFB1_C4
Systematic name | M566
Organism | Homo sapiens
PMID | 11279127
Authors | Verrecchia F,Chu ML,Mauviel A
Category | C2
Sub-category | CGP
Brief description | Cluster 4: ECM related genes up-regulated in dermal fibroblasts later than 30 min after TGFB1 [GeneID=7040] addition; kept increasing with time.
Full description | Despite major advances in the understanding of the intimate mechanisms of transforming growth factor-beta (TGF-beta) signaling through the Smad pathway, little progress has been made in the identification of direct target genes. In this report, using cDNA microarrays, we have focussed our attention on the characterization of extracellular matrix-related genes rapidly induced by TGF-beta in human dermal fibroblasts and attempted to identify the ones whose up-regulation by TGF-beta is Smad-mediated. For a gene to qualify as a direct Smad target, we postulated that it had to meet the following criteria: (1) rapid (30 min) and significant (at least 2-fold) elevation of steady-state mRNA levels upon TGF-beta stimulation, (2) activation of the promoter by both exogenous TGF-beta and co-transfected Smad3 expression vector, (3) up-regulation of promoter activity by TGF-beta blocked by both dominant-negative Smad3 and inhibitory Smad7 expression vectors, and (4) promoter transactivation by TGF-beta not possible in Smad3(-/-) mouse embryo fibroblasts. Using this stringent approach, we have identified COL1A2, COL3A1, COL6A1, COL6A3, and tissue inhibitor of metalloproteases-1 as definite TGF-beta/Smad3 targets. Extrapolation of this approach to other extracellular matrix-related gene promoters also identified COL1A1 and COL5A2, but not COL6A2, as novel Smad targets. Together, these results represent a significant step toward the identification of novel, early-induced Smad-dependent TGF-beta target genes in fibroblasts.

Standard name | ZHU_CMV_24_HR_UP
Systematic name | M15565
Organism | Homo sapiens
PMID | 9826724
Authors | Zhu H,Cong JP,Mamtora G,Gingeras T,Shenk T
Category | C2
Sub-category | CGP
Brief description | Up-regulated at 24 h following infection of primary human foreskin fibroblasts with CMV
Full description | Mechanistic insights to viral replication and pathogenesis generally have come from the analysis of viral gene products, either by studying their biochemical activities and interactions individually or by creating mutant viruses and analyzing their phenotype. Now it is possible to identify and catalog the host cell genes whose mRNA levels change in response to a pathogen. We have used DNA array technology to monitor the level of approximately 6,600 human mRNAs in uninfected as compared with human cytomegalovirus-infected cells. The level of 258 mRNAs changed by a factor of 4 or more before the onset of viral DNA replication. Several of these mRNAs encode gene products that might play key roles in virus-induced pathogenesis, identifying them as intriguing targets for further study.

Standard name | BURTON_ADIPOGENESIS_11
Systematic name | M1632
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Strongly down-regulated at 2-96 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | BROWNE_HCMV_INFECTION_12HR_UP
Systematic name | M11572
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 12 h time point that were not up-regulated at the previous time point, 10 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | IVANOVA_HEMATOPOIESIS_STEM_CELL_AND_PROGENITOR
Systematic name | M8215
Organism | Mus musculus
PMID | 12228721
Authors | Ivanova NB,Dimos JT,Schaniel C,Hackney JA,Moore KA,Lemischka IR
Category | C2
Sub-category | CGP
Brief description | Genes in the expression cluster 'HSC and Progenitors Shared': up-regulated in hematopoietic stem cells (HSC) and progenitors from adult bone marrow and fetal liver.
Full description | Mechanisms regulating self-renewal and cell fate decisions in mammalian stem cells are poorly understood. We determined global gene expression profiles for mouse and human hematopoietic stem cells and other stages of the hematopoietic hierarchy. Murine and human hematopoietic stem cells share a number of expressed gene products, which define key conserved regulatory pathways in this developmental system. Moreover, in the mouse, a portion of the genetic program of hematopoietic stem cells is shared with embryonic and neural stem cells. This overlapping set of gene products represents a molecular signature of stem cells.

Standard name | RAMASWAMY_METASTASIS_UP
Systematic name | M6698
Organism | Homo sapiens
PMID | 12469122
Authors | Ramaswamy S,Ross KN,Lander ES,Golub TR
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in metastatic vs primary solid tumors.
Full description | Metastasis is the principal event leading to death in individuals with cancer, yet its molecular basis is poorly understood. To explore the molecular differences between human primary tumors and metastases, we compared the gene-expression profiles of adenocarcinoma metastases of multiple tumor types to unmatched primary adenocarcinomas. We found a gene-expression signature that distinguished primary from metastatic adenocarcinomas. More notably, we found that a subset of primary tumors resembled metastatic tumors with respect to this gene-expression signature. We confirmed this finding by applying the expression signature to data on 279 primary solid tumors of diverse types. We found that solid tumors carrying the gene-expression signature were most likely to be associated with metastasis and poor clinical outcome (P < 0.03). These results suggest that the metastatic potential of human tumors is encoded in the bulk of a primary tumor, thus challenging the notion that metastases arise from rare cells within a primary tumor that have the ability to metastasize.

Standard name | DAZARD_RESPONSE_TO_UV_SCC_UP
Systematic name | M1361
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SCC12B2 cells (squamous cell carcinoma) by UV-B irradiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | KAYO_CALORIE_RESTRICTION_MUSCLE_UP
Systematic name | M7013
Organism | Macaca mulatta
PMID | 11309484
Authors | Kayo T,Allison DB,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Upregulated in the vastus lateralis muscle of middle aged rhesus monkeys subjected to caloric restriction since young adulthood vs age matched controls
Full description | In laboratory rodents, caloric restriction (CR) retards several age-dependent physiological and biochemical changes in skeletal muscle, including increased steady-state levels of oxidative damage to lipids, DNA, and proteins. We have previously used high-density oligonucleotide arrays to show that CR can prevent or delay most of the major age-related transcriptional alterations in the gastrocnemius muscle of C57BL/6 mice. Here we report the effects of aging and adult-onset CR on the gene expression profile of 7,070 genes in the vastus lateralis muscle from rhesus monkeys. Gene expression analysis of aged rhesus monkeys (mean age of 26 years) was compared with that of young animals (mean age of 8 years). Aging resulted in a selective up-regulation of transcripts involved in inflammation and oxidative stress, and a down-regulation of genes involved in mitochondrial electron transport and oxidative phosphorylation. Middle-aged monkeys (mean age of 20 years) subjected to CR since early adulthood (mean age of 11 years) were studied to determine the gene expression profile induced by CR. CR resulted in an up-regulation of cytoskeletal protein-encoding genes, and also a decrease in the expression of genes involved in mitochondrial bioenergetics. Surprisingly, we did not observe any evidence for an inhibitory effect of adult-onset CR on age-related changes in gene expression. These results indicate that the induction of an oxidative stress-induced transcriptional response may be a common feature of aging in skeletal muscle of rodents and primates, but the extent to which CR modifies these responses may be species-specific.

Standard name | JIANG_HYPOXIA_NORMAL
Systematic name | M3996
Organism | Homo sapiens
PMID | 12692265
Authors | Jiang Y,Zhang W,Kondo K,Klco JM,St Martin TB,Dufault MR,Madden SL,Kaelin WG Jr,Nacht M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RPTEC cells (normal kidney) by hypoxia.
Full description | The von Hippel-Lindau tumor suppressor, pVHL, is a key player in one of the best characterized hypoxia signaling pathways, the VHL-hypoxia-inducible factor (VHL-HIF) pathway. To better understand the role of VHL in the hypoxia signaling pathways of tumor cells, we used serial analysis of gene expression (SAGE) to investigate hypoxia-regulated gene expression in renal carcinoma cells (786-0), with and without VHL. The gene expression profiles of the cancer cells were compared to SAGE profiles from normal renal proximal tubule cells grown under both normoxia and hypoxia. The data suggest that the role of VHL as a tumor suppressor may be more complex than previously thought. Further, the data reveal that renal carcinoma cells have evolved an alternative hypoxia signaling pathway(s) compared with normal renal cells. These alternative hypoxia pathways demonstrate VHL-dependent and VHL-independent regulation. The genes involved in such pathways include those with potential importance in the physiological and pathological regulation of tumor growth and angiogenesis. Some of the genes identified as showing overexpression in the cancer cells, particularly those encoding secreted or membrane-bound proteins, could be potential biomarkers for tumors or targets for rational therapeutics that are dependent on VHL status.

Standard name | BANDRES_RESPONSE_TO_CARMUSTIN_WITHOUT_MGMT_48HR_DN
Systematic name | M9066
Organism | Homo sapiens
PMID | 15980968
Authors | Bandres E,Andion E,Escalada A,Honorato B,Catalan V,Cubedo E,Cordeu L,Garcia F,Zarate R,Zabalegui N,Garcia-Foncillas J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A172 cells (glioma, does not express MGMT [GeneID=4255]) by carmustine [PubChem=2578] at 48 h.
Full description | Chemotherapy with the alkylating agent BCNU (1,3-bis (2-chloroethyl)-1-nitrosourea) is the most commonly used chemotherapeutic agent for gliomas. However, the usefulness of this agent is limited because tumor cell resistance to BCNU is frequently found in clinical brain tumor therapy. The O6-methylguanine-DNA methyltransferase protein (MGMT) reverses alkylation at the O6 position of guanine and we have reported the role of MGMT in the response of brain tumors to alkylating agents. However, the different mechanisms underlying the patterns related to MGMT remain unclear. To better understand the molecular mechanism by which BCNU exerts its effect in glioma cell lines according MGMT expression, we used microarray technology to interrogate 3800 known genes and determine the gene expression profiles altered by BCNU treatment. Our results showed that treatment with BCNU alters the expression of a diverse group of genes in a time-dependent manner. A subset of gene changes was found common in both glioma cell lines and other subset is specific of each cell line. After 24 h of BCNU treatment, up-regulation of transcription factors involved in the nucleation of both RNA polymerase II and III transcription initiation complexes was reported. Interestingly, BCNU promoted the expression of actin-dependent regulators of chromatin. Similar effects were found with higher BCNU doses in MGMT+ cell line showing a similar mechanism that in MGMT-deficient cell with standard doses. Our data suggest that human glioma cell lines treated with BCNU, independently of MGMT expression, show changes in the expression of cell cycle and survival-related genes interfering the transcription mechanisms and the chromatin regulation.

Standard name | ABE_INNER_EAR
Systematic name | M260
Organism | Homo sapiens
PMID | 12471561
Authors | Abe S,Katagiri T,Saito-Hisaminato A,Usami S,Inoue Y,Tsunoda T,Nakamura Y
Category | C2
Sub-category | CGP
Brief description | Genes prefentially expressed in human inner ear tissue (cochlea and vestibule), at least 10-fold higher from a mixture of 29 other tissues.
Full description | Through cDNA microarray analysis of gene expression in human cochlea and vestibule, we detected strong expression of mu-crystallin (CRYM; also known as NADP-regulated thyroid hormone-binding protein) only in these inner-ear tissues. In a subsequent search for mutations of CRYM, among 192 patients with nonsyndromic deafness, we identified two mutations at the C-terminus; one was a de novo change (X315Y) in a patient with unaffected parents, and the other was a missense mutation (K314T) that segregated dominantly in the proband's family. When the mutated proteins were expressed in COS-7 cells, their subcellular localizations were different from that of the normal protein: the X315Y mutant showed vacuolated distribution in the cytoplasm, and the K314T mutant localized in perinuclear areas, whereas normal protein was distributed homogeneously in the cytoplasm. Aberrant intracellular localization of the mutated proteins might cause dysfunction of the CRYM product and result in hearing impairment. In situ hybridization analysis using mouse tissues indicated its expression in the lateral region of the spiral ligament and the fibrocytes of the spiral limbus, implying its possible involvement in the potassium-ion recycling system. Our results strongly implicate CRYM in normal auditory function and identify it as one of the genes that can be responsible for nonsyndromic deafness.

Standard name | MARIADASON_RESPONSE_TO_CURCUMIN_SULINDAC_5
Systematic name | M8382
Organism | Homo sapiens
PMID | 10969808
Authors | Mariadason JM,Corner GA,Augenlicht LH
Category | C2
Sub-category | CGP
Brief description | Cluster 5: genes up-regulated in SW260 cells (colon cancer) by curcumin and sulindac [PubChem=969516;5352].
Full description | The short-chain fatty acid butyrate, produced by microbial fermentation of dietary fiber in the large intestine, is a physiological regulator of major pathways of colonic epithelial cell maturation: cell cycle arrest, lineage-specific differentiation, and apoptosis. Microarray analysis of 8,063 sequences demonstrated a complex cascade of reprogramming of SW620 colonic epithelial cells upon treatment with butyrate characterized by the progressive recruitment of gene sets as a function of time. Comparison with the effects of trichostatin A, in conjunction with differences in the kinetics of alteration of histone acetylation induced by butyrate and trichostatin A, identified subsets of induced and repressed genes likely coordinately regulated by altered histone acetylation. The butyrate response was also compared in detail with that of sulindac, a nonsteroidal anti-inflammatory drug with significant chemopreventive activity for colon cancer, and curcumin, a component of mustard and curry structurally and functionally related to sulindac that also has chemopreventive activity. Although gene clusters were identified that showed similar responses to butyrate and sulindac, the data were characterized by the extensive differences in the effects of the two agents. This was striking for functional classes of genes involved in signaling pathways and in cell cycle progression, although butyrate and sulindac induce a similar G0-G1 arrest, elevation of beta-catenin-Tcf signaling, and apoptotic cascade. As regards cell cycle arrest, the underlying mechanism in response to butyrate was most similar to that of the Caco-2 cell line that had spontaneously undergone a G0-G1 arrest and least similar to the G2-M arrest stimulated by curcumin. Thus, high-throughput microarray analysis of gene expression profiles can be used to characterize and distinguish the mechanisms of response of colonic epithelial cells to physiological and pharmacological inducers of cell maturation. This has important implications for characterization of chemopreventive agents and recognition of potential toxicity and synergies. The data bases, gene clusters, and analyses are available at http:// sequence.aecom.yu.edu/genome/.

Standard name | TSENG_IRS1_TARGETS_UP
Systematic name | M10427
Organism | Mus musculus
PMID | 15895078
Authors | Tseng YH,Butte AJ,Kokkotou E,Yechoor VK,Taniguchi CM,Kriauciunas KM,Cypess AM,Niinobe M,Yoshikawa K,Patti ME,Kahn CR
Category | C2
Sub-category | CGP
Brief description | Up-regulated in brown preadipocytes with IRS1 [GeneID=3667] knockout vs wild type controls; the knockouts have severe defects in adipocyte differentiation.
Full description | The insulin/IGF-1 (insulin-like growth factor 1) signalling pathway promotes adipocyte differentiation via complex signalling networks. Here, using microarray analysis of brown preadipocytes that are derived from wild-type and insulin receptor substrate (Irs) knockout animals that exhibit progressively impaired differentiation, we define 374 genes/expressed-sequence tags whose expression in preadipocytes correlates with the ultimate ability of the cells to differentiate. Many of these genes, including preadipocyte factor-1 (Pref-1) and multiple members of the Wnt signalling pathway, are related to early adipogenic events. Necdin is also markedly increased in Irs knockout cells that cannot differentiate, and knockdown of necdin restores brown adipogenesis with downregulation of Pref-1 and Wnt10a expression. Insulin receptor substrate proteins regulate a necdin-E2F4 interaction that represses peroxisome-proliferator-activated receptor gamma (PPARgamma) transcription via a cyclic AMP response element binding protein (CREB)-dependent pathway. Together these define a key signalling network that is involved in brown preadipocyte determination.

Standard name | SARTIPY_BLUNTED_BY_INSULIN_RESISTANCE_UP
Systematic name | M1633
Organism | Mus musculus
PMID | 14530283
Authors | Sartipy P,Loskutoff DJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 3T3-L1 cells (adipocyte) by insulin [GeneID=3630] but displayed blunted response to insulin the insulin resistant cells.
Full description | We have employed microarray technology using RNA from normal 3T3-L1 adipocytes and from 3T3-L1 adipocytes made insulin-resistant by treatment with tumor necrosis factor-alpha to identify a new class of insulin-responsive genes. These genes continued to respond normally to insulin even though the adipocytes themselves were metabolically insulin-resistant, i.e. they displayed a significantly decreased rate of insulin-stimulated glucose uptake. Approximately 12,000 genes/expressed sequence tags (ESTs) were screened. Of these, 40 genes/ESTs were identified that became insulin-resistant as expected (e.g. Socs-3, junB, and matrix metalloproteinase-11). However, 61 genes/ESTs continued to respond normally to insulin. Although some of these genes were previously shown to be regulated by insulin (e.g. Glut-1 and beta3-adrenergic receptor), other novel insulin-sensitive genes were also identified (e.g. Egr-1, epiregulin, Fra-1, and ABCA1). Real-time reverse transcription-PCR analysis confirmed the expression patterns of several of the differentially expressed genes. One gene that remained insulin-sensitive in the insulin-resistant adipocytes is the transcription factor Egr-1. Using an antisense strategy, we show that tissue factor and macrophage colony-stimulating factor, two cardiovascular risk factors, are downstream EGR-1 target genes in the adipocyte. Taken together, these data support the hypothesis that some signaling pathways remain insulin-sensitive in metabolically insulin-resistant adipocytes. These pathways may promote abnormal gene expression in hyperinsulinemic states like obesity and type II diabetes and thus may contribute to pathologies associated with these conditions.

Standard name | XU_GH1_AUTOCRINE_TARGETS_UP
Systematic name | M10664
Organism | Homo sapiens
PMID | 15845533
Authors | Xu XQ,Emerald BS,Goh EL,Kannan N,Miller LD,Gluckman PD,Liu ET,Lobie PE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MFCF-7 cells (breast cancer) upon stable autocrine expression of HG1 [GeneID=2688].
Full description | We have exploited a discrepancy in the oncogenic potential of autocrine and exogenous human growth hormone (hGH) in an attempt to identify molecules that could potentially be involved in oncogenic transformation of the human mammary epithelial cell. Microarray analysis of 19,000 human genes identified a subset of 305 genes in a human mammary carcinoma cell line that were remarkably different in their response to autocrine and exogenous hGH. Autocrine and exogenous hGH also regulated 167 common genes. Semiquantitative reverse transcription-PCR confirmed differential regulation of genes by either autocrine or exogenous hGH. Functional analysis of one of the identified autocrine hGH-regulated genes, TFF3, determined that its expression is sufficient to support anchorage-independent growth of human mammary carcinoma cells. Small interfering RNA-mediated knockdown of TFF3 concordantly abrogated anchorage-independent growth of mammary carcinoma cells and abrogated the ability of autocrine hGH to stimulate oncogenic transformation of immortalized human mammary epithelial cells. Further functional characterization of the identified subset of specifically autocrine hGH regulated genes will delineate additional novel oncogenes for the human mammary epithelial cell.

Standard name | XU_GH1_EXOGENOUS_TARGETS_DN
Systematic name | M17387
Organism | Homo sapiens
PMID | 15845533
Authors | Xu XQ,Emerald BS,Goh EL,Kannan N,Miller LD,Gluckman PD,Liu ET,Lobie PE
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MFCF-7 cells (breast cancer) by exogenous HG1 [GeneID=2688].
Full description | We have exploited a discrepancy in the oncogenic potential of autocrine and exogenous human growth hormone (hGH) in an attempt to identify molecules that could potentially be involved in oncogenic transformation of the human mammary epithelial cell. Microarray analysis of 19,000 human genes identified a subset of 305 genes in a human mammary carcinoma cell line that were remarkably different in their response to autocrine and exogenous hGH. Autocrine and exogenous hGH also regulated 167 common genes. Semiquantitative reverse transcription-PCR confirmed differential regulation of genes by either autocrine or exogenous hGH. Functional analysis of one of the identified autocrine hGH-regulated genes, TFF3, determined that its expression is sufficient to support anchorage-independent growth of human mammary carcinoma cells. Small interfering RNA-mediated knockdown of TFF3 concordantly abrogated anchorage-independent growth of mammary carcinoma cells and abrogated the ability of autocrine hGH to stimulate oncogenic transformation of immortalized human mammary epithelial cells. Further functional characterization of the identified subset of specifically autocrine hGH regulated genes will delineate additional novel oncogenes for the human mammary epithelial cell.

Standard name | BAELDE_DIABETIC_NEPHROPATHY_DN
Systematic name | M4665
Organism | Homo sapiens
PMID | 15042541
Authors | Baelde HJ,Eikmans M,Doran PP,Lappin DW,de Heer E,Bruijn JA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in glomeruli of kidneys from patients with diabetic nephropathy (type 2 diabetes mellitus).
Full description | BACKGROUND: Diabetic nephropathy (DN) is a frequent complication in patients with diabetes mellitus. To find improved intervention strategies in this disease, it is necessary to investigate the molecular mechanisms involved. To obtain more insight into processes that lead to DN, messenger RNA expression profiles of diabetic glomeruli and glomeruli from healthy individuals were compared. METHODS: Two morphologically normal kidneys and 2 kidneys from patients with DN were used for the study. Glomerular RNA was hybridized in duplicate on Human Genome U95Av2 Arrays (Affymetrix, Santa Clara, CA). Several transcripts were tested further in independent patient groups and at the protein level by immunohistochemistry. RESULTS: Ninety-six genes were upregulated in diabetic glomeruli, whereas 519 genes were downregulated. The list of overexpressed genes in DN includes aquaporin 1, calpain 3, hyaluronoglucosidase, and platelet/endothelial cell adhesion molecule. The list of downregulated genes includes bone morphogenetic protein 2, vascular endothelial growth factor (VEGF), fibroblast growth factor 1, insulin-like growth factor binding protein 2, and nephrin. A decrease in VEGF and nephrin could be validated at the protein level and also at the RNA level in renal biopsy specimens from 5 additional patients with diabetes. CONCLUSION: Results of oligonucleotide microarray analyses on control and diabetic glomeruli are presented and discussed in their relation to vascular damage, mesangial matrix expansion, proliferation, and proteinuria. Our findings suggest that progression of DN might result from diminished tissue repair capability.

Standard name | BROWNE_HCMV_INFECTION_6HR_UP
Systematic name | M14728
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 6 h time point that were not up-regulated at the previous time point, 4 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | DAZARD_UV_RESPONSE_CLUSTER_G1
Systematic name | M9375
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Cluster G1: genes most highly up-regulated in NHEK cells (normal keratinocyte) between 6 h and 12 h after UV-B irradiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | LY_AGING_OLD_DN
Systematic name | M18789
Organism | Homo sapiens
PMID | 10741968
Authors | Ly DH,Lockhart DJ,Lerner RA,Schultz PG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in fibroblasts from old individuals, compared to those from young donors.
Full description | Messenger RNA levels were measured in actively dividing fibroblasts isolated from young, middle-age, and old-age humans and humans with progeria, a rare genetic disorder characterized by accelerated aging. Genes whose expression is associated with age-related phenotypes and diseases were identified. The data also suggest that an underlying mechanism of the aging process involves increasing errors in the mitotic machinery of dividing cells in the postreproductive stage of life. We propose that this dysfunction leads to chromosomal pathologies that result in misregulation of genes involved in the aging process.

Standard name | WENG_POR_DOSAGE
Systematic name | M1634
Organism | Mus musculus
PMID | 16006652
Authors | Weng Y,DiRusso CC,Reilly AA,Black PN,Ding X
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in liver from mice with liver specific knockout of POR [GeneID=5447] vs mice with reduced expression of POR in all tissues.
Full description | NADPH-cytochrome P450 reductase (CPR) is an essential component for the function of many enzymes, including microsomal cytochrome P450 (P450) monooxygenases and heme oxygenases. In liver-Cpr-null (with liver-specific Cpr deletion) and Cpr-low (with reduced CPR expression in all organs examined) mouse models, a reduced serum cholesterol level and an induction of hepatic P450s were observed, whereas hepatomegaly and fatty liver were only observed in the liver-Cpr-null model. Our goal was to identify hepatic gene expression changes related to these phenotypes. Cpr-lox mice (with a floxed Cpr gene and normal CPR expression) were used as the control. Through microarray analysis, we identified many genes that were differentially expressed among the three groups of mice. We also recognized the 12 gene ontology terms that contained the most significantly changed gene expression in at least one of the two mouse models. We further uncovered potential mechanisms, such as an increased activation of constitutive androstane receptor and a decreased activation of peroxisomal proliferator-activated receptor-alpha by precursors of cholesterol biosynthesis, that underlie common changes (e.g. induction of multiple P450s and suppression of genes for fatty acid metabolism) in response to CPR loss in the two mouse models. Additionally, we observed model-specific gene expression changes, such as the induction of a fatty-acid translocase (Cd36 antigen) and the suppression of carnitine O-palmitoyltransferase 1 (Cpt1a) and acyl-CoA synthetase long chain family member 1 (Acsl1), that are potentially responsible for the severe hepatic lipidosis and an altered fatty acid profile observed in liver-Cpr-null mice.

Standard name | MURAKAMI_UV_RESPONSE_24HR
Systematic name | M17175
Organism | Homo sapiens
PMID | 11532376
Authors | Murakami T,Fujimoto M,Ohtsuki M,Nakagawa H
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary keratinocytes at 24 h after UVB irradiation.
Full description | Ultraviolet B irradiation initiates and promotes skin cancers, photo-aging, and immune suppression. In order to elucidate the effect of these processes at the level of gene expression, we used cDNA microarray technology to examine the effect of ultraviolet B irradiation on 588 cancer-related genes in human keratinocytes at 1, 6, and 24 h post-irradiation with a mildly cytotoxic dose of ultraviolet B (170 mJ/cm(2)). The viability of the irradiated keratinocytes was 75% at 24 h post-irradiation. Various cytokeratins and transcription factors were up-regulated within 1 h post-irradiation. After 6 h, expression of a variety of genes related to growth regulation (e.g. p21(WAF1), notch 4, and smoothened), apoptosis (e.g. caspase 10, hTRIP, and CRAF1), DNA repair (ERCC1, XRCC1), cytokines (e.g. IL-6, IL-13, TGF-beta, and endothelin 2), and cell adhesion (e.g. RhoE, and RhoGDI) were altered in human keratinocytes. These data suggest the changes in a cascade of gene expression in human keratinocytes occurring within 24 h after UVB exposure. Although the roles of these cellular genes after UVB-irradiation remain to be elucidated, microarray analysis may provide a new view of gene expression in epidermal keratinocytes following UVB exposure.

Standard name | SEMENZA_HIF1_TARGETS
Systematic name | M12299
Organism | Homo sapiens
PMID | 11516994
Authors | Semenza GL
Category | C2
Sub-category | CGP
Brief description | Genes that are transcriptionally regulated by HIF1A [GeneID=3091].
Full description | Hypoxia-inducible factor 1 (HIF-1) activates transcription of genes encoding proteins that mediate adaptive responses to reduced oxygen availability. The HIF-1beta subunit is constitutively expressed, whereas the HIF-1alpha subunit is subject to ubiquitination and proteasomal degradation, a process that is inhibited under hypoxic conditions. Recent data indicate that HIF-1 plays major roles in the prevention of myocardial and cerebral ischemia and in the pathogenesis of pulmonary hypertension and cancer. Modulation of HIF-1 activity by genetic or pharmacological means could provide a novel therapeutic approach to these common causes of mortality.

Standard name | BACOLOD_RESISTANCE_TO_ALKYLATING_AGENTS_DN
Systematic name | M12518
Organism | Homo sapiens
PMID | 12479369
Authors | Bacolod MD,Johnson SP,Ali-Osman F,Modrich P,Bullock NS,Colvin OM,Bigner DD,Friedman HS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in D-341 MED (OBR) cells (medulloblastoma) resistant to both carmustine and O6-BG [PubChem=2578;4578].
Full description | Medulloblastoma (D-341 MED) and rhabdomyosarcoma (TE-671) cell lines, which are resistant to either 1,3-bis(2-chloroethyl)-1-nitrosourea (BCNU) or the combination of BCNU and O6-benzylguanine (O6-BG), were generated by serial escalation of BCNU. The activities of O6-alkylguanine-DNA alkyltransferase (AGT), glutathione-S-transferase (GST), and total glutathione (GSH) of the parental, BCNU-resistant (BR), and BCNU + O6-BG-resistant (OBR) cells were measured. No significant differences in GST activity or total GSH were seen between the parental, BR, and OBR cells of both TE-671 and D-341 MED. The AGT activities of D-341 MED (BR) and TE-671 (BR) were twice those of D-341 MED and TE-671, respectively, confirming the importance of this enzyme for BCNU resistance. The D-341 MED (OBR) cells did not exhibit any AGT activity, suggesting that another mechanism must play a role in the drug resistance. Fewer DNA interstrand cross-links (ICLs) were observed in D-341 MED (OBR) than in D-341 MED after 8 h BCNU (100-400 microM) treatment. However, the amounts of DNA ICLs observed in D-341 MED and D-341 MED (OBR) were stable after 24 h. Microarray analysis showed the increased expressions of several metallothionein genes and down-regulation of several proapoptotic genes. The AGT activity of TE-671 (OBR) was 223 fmol/mg when the cells were grown in 10 microM O6-BG and decreased to about half this value when the O6-BG concentration was increased 60 microM. The AGT cDNA of TE-671 (OBR) cells was cloned and found to contain a G-to-T transversion at codon 156, resulting in conversion of glycine to cysteine (G156C). In vitro mutagenesis has shown that the G156C AGT mutant is resistant to inactivation by O6-BG. Thus, the selection of a mutant AGT with decreased sensitivity to O6-BG is a significant contributing factor to BCNU + O6-BG resistance.

Standard name | WANG_CISPLATIN_RESPONSE_AND_XPC_UP
Systematic name | M19511
Organism | Homo sapiens
PMID | 15107491
Authors | Wang G,Chuang L,Zhang X,Colton S,Dombkowski A,Reiners J,Diakiw A,Xu XS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in fibroblasts with defective XPC [GeneID=7508] in response to cisplatin [PubChem=2767].
Full description | XPC is an important DNA damage recognition protein involved in DNA nucleotide excision repair. We have studied the role of the XPC protein in cisplatin treatment-mediated cell cycle regulation. Through the comparison of microarray data obtained from human normal fibroblasts and two individual XPC-defective cell lines, 486 genes were identified as XPC-responsive genes in the cisplatin treatment (with a minimal 1.5-fold change) and 297 of these genes were further mapped to biological pathways and gene ontologies. The cell cycle and cell proliferation-related genes were the most affected genes by the XPC defect in the cisplatin treatment. Many other cellular function genes were also affected by the XPC defect in the treatment. Western blot hybridization results revealed that the XPC defect reduced the p53 responses to the cisplatin treatment. The ability to activate caspase-3 was also attenuated in the XPC cells with the treatment. These results suggest that the XPC protein plays a critical role in initiating the cisplatin DNA damaging treatment-mediated signal transduction process, resulting in activation of the p53 pathway and cell cycle arrest that allow DNA repair and apoptosis to take place. These results reveal an important role of the XPC protein in the cancer prevention.

Standard name | VARELA_ZMPSTE24_TARGETS_UP
Systematic name | M2085
Organism | Mus musculus
PMID | 16079796
Authors | Varela I,Cadiñanos J,Pendás AM,Gutiérrez-Fernández A,Folgueras AR,Sánchez LM,Zhou Z,Rodríguez FJ,Stewart CL,Vega JA,Tryggvason K,Freije JM,López-Otín C
Category | C2
Sub-category | CGP
Brief description | Top genes up-regulated in liver tissue from mice with knockout of ZMPSTE24 [GeneID=10269].
Full description | Zmpste24 (also called FACE-1) is a metalloproteinase involved in the maturation of lamin A (Lmna), an essential component of the nuclear envelope. Both Zmpste24- and Lmna-deficient mice exhibit profound nuclear architecture abnormalities and multiple histopathological defects that phenocopy an accelerated ageing process. Similarly, diverse human progeroid syndromes are caused by mutations in ZMPSTE24 or LMNA genes. To elucidate the molecular mechanisms underlying these devastating diseases, we have analysed the transcriptional alterations occurring in tissues from Zmpste24-deficient mice. We demonstrate that Zmpste24 deficiency elicits a stress signalling pathway that is evidenced by a marked upregulation of p53 target genes, and accompanied by a senescence phenotype at the cellular level and accelerated ageing at the organismal level. These phenotypes are largely rescued in Zmpste24-/-Lmna+/- mice and partially reversed in Zmpste24-/-p53-/- mice. These findings provide evidence for the existence of a checkpoint response activated by the nuclear abnormalities caused by prelamin A accumulation, and support the concept that hyperactivation of the tumour suppressor p53 may cause accelerated ageing.

Standard name | YIH_RESPONSE_TO_ARSENITE_C3
Systematic name | M1636
Organism | Homo sapiens
PMID | 12016162
Authors | Yih LH,Peck K,Lee TC
Category | C2
Sub-category | CGP
Brief description | Genes in cluster 3: delayed up-regulation in HFW cells (fibroblast) by sodium arsenite [PubChem=26435].
Full description | Arsenic compounds are widely distributed and arsenic ingestion is associated with many human diseases, including blackfoot disease, atherosclerosis, and cancers. However, the underlying mechanism of arsenic toxicity is not understood. In human fibroblast cells (HFW), arsenite is known to induce oxidative damage, chromosome aberrations, cell cycle arrest, and aneuploidy, and the manifestation of these cellular responses is dependent on changes in gene expression which can be analyzed using the cDNA microarray technique. In this study, cDNA microarray membranes with 568 human genes were used to examine mRNA profile changes in HFW cells treated for 0 to 24 h with 5 microM sodium arsenite. On the basis of the mean value for three independent experiments, 133 target genes were selected for a 2 x 3 self-organizing map cluster analysis; 94 were found to be induced by arsenite treatment, whereas 39 were repressed. These genes were categorized as signal transduction, transcriptional regulation, cell cycle control, stress responses, proteolytic enzymes, and miscellaneous. Significant changes in the signaling-related and transcriptional regulation genes indicated that arsenite induces complex toxicopathological injury.

Standard name | SATO_SILENCED_BY_DEACETYLATION_IN_PANCREATIC_CANCER
Systematic name | M11213
Organism | Homo sapiens
PMID | 12839967
Authors | Sato N,Fukushima N,Maitra A,Matsubayashi H,Yeo CJ,Cameron JL,Hruban RH,Goggins M
Category | C2
Sub-category | CGP
Brief description | 50 most interesting genes up-regulated in pancreatic cancer cell lines (AsPC1, Hs766T, MiaPaCa2, Panc1) but not in the non-neoplastic cells (HPDE) by TSA [PubChem=5562].
Full description | To identify potential targets for aberrant methylation in pancreatic cancer, we analyzed global changes in gene expression profiles of four pancreatic cancer cell lines after treatment with the demethylating agent 5-aza-2'-deoxycytidine (5Aza-dC) and/or the histone deacetylase inhibitor trichostatin A. A substantial number of genes were induced 5-fold or greater by 5Aza-dC alone (631 transcripts), trichostatin A alone (1196 transcripts), and by treatment with both agents (857 transcripts). Four hundred and seventy-five genes were markedly (>5-fold) induced after 5Aza-dC treatment in pancreatic cancer cell lines but not in a nonneoplastic pancreatic epithelial cell line. The methylation status of 11 of these 475 genes was examined in a panel of 42 pancreatic cancers, and all 11 of these genes were aberrantly methylated in pancreatic cancer but rarely, if any, methylated in 10 normal pancreatic ductal epithelia. These genes include UCHL1 (methylated in 100% of 42 pancreatic cancers), NPTX2 (98%), SARP2 (95%), CLDN5 (93%), reprimo (86%), LHX1 (76%), WNT7A (71%), FOXE1 (69%), TJP2 (64%), CDH3 (19%), and ST14 (10%). Three of these 11 genes (NPTX2, SARP2, and CLDN5) were selected for further analysis in a larger panel of specimens, and aberrant methylation of at least one of these three genes was detectable in 100% of 43 primary pancreatic cancers and in 18 of 24 (75%) pancreatic juice samples obtained from patients with pancreatic cancer. Thus, a substantial number of genes are induced by 5Aza-dC treatment of pancreatic cancer cells, and many of them may represent novel targets for aberrant methylation in pancreatic carcinoma.

Standard name | CHENG_RESPONSE_TO_NICKEL_ACETATE
Systematic name | M19667
Organism | Homo sapiens
PMID | 12915101
Authors | Cheng RY,Zhao A,Alvord WG,Powell DA,Bare RM,Masuda A,Takahashi T,Anderson LM,Kasprzak KS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HPL1D cells (lung epithelium) upon exposure to nickel acetate [PubChem=9756].
Full description | Occupational exposure to nickel compounds is associated with lung cancer risk; both genotoxic and epigenetic mechanisms have been proposed. For comprehensive examination of the acute effects of nickel(II) acetate on gene expression in cultured human peripheral lung epithelial HPL1D cells, microarray analyses were carried out with cDNA chips (approximately 8000 cDNAs). Cells were exposed for 24 h to nontoxic (50, 100, and 200 microM) or toxic (400, 800, and 1600 microM) nickel(II) concentrations. Cluster analysis was applied to the 868 genes with > or = 2-fold change at any concentration. Two main clusters showed marked up- or down-regulation at the highest, toxic concentrations. The data further subdivided into 10 highly cohesive clusters with high probability, and of these only 2 had the same response trend at low nontoxic as at high concentrations, an observation of clear relevance to the process of high- to low-dose extrapolation in risk assessment. There were 113 genes showing > or = 2-fold change at the three lower nontoxic concentrations, those most relevant to in vivo carcinogenesis. In addition to expected responses of metallothionein, ferritin, and heat-shock proteins, the results revealed for the first time changed expression of some potential cancer-related genes in response to low-dose Ni(II): RhoA, dyskerin, interferon regulatory factor 1, RAD21 homologue, and tumor protein, translationally controlled. Overall, most of the genes impacted by nontoxic concentrations of nickel(II) acetate related to gene transcription, protein synthesis and stability, cytoskeleton, signaling, metabolism, cell membrane, and extracellular matrix.

Standard name | TSENG_ADIPOGENIC_POTENTIAL_DN
Systematic name | M8364
Organism | Mus musculus
PMID | 15895078
Authors | Tseng YH,Butte AJ,Kokkotou E,Yechoor VK,Taniguchi CM,Kriauciunas KM,Cypess AM,Niinobe M,Yoshikawa K,Patti ME,Kahn CR
Category | C2
Sub-category | CGP
Brief description | Genes showing decreasing expression in brown preadipocytes with increasing ability of the cells to differentiate.
Full description | The insulin/IGF-1 (insulin-like growth factor 1) signalling pathway promotes adipocyte differentiation via complex signalling networks. Here, using microarray analysis of brown preadipocytes that are derived from wild-type and insulin receptor substrate (Irs) knockout animals that exhibit progressively impaired differentiation, we define 374 genes/expressed-sequence tags whose expression in preadipocytes correlates with the ultimate ability of the cells to differentiate. Many of these genes, including preadipocyte factor-1 (Pref-1) and multiple members of the Wnt signalling pathway, are related to early adipogenic events. Necdin is also markedly increased in Irs knockout cells that cannot differentiate, and knockdown of necdin restores brown adipogenesis with downregulation of Pref-1 and Wnt10a expression. Insulin receptor substrate proteins regulate a necdin-E2F4 interaction that represses peroxisome-proliferator-activated receptor gamma (PPARgamma) transcription via a cyclic AMP response element binding protein (CREB)-dependent pathway. Together these define a key signalling network that is involved in brown preadipocyte determination.

Standard name | DAZARD_UV_RESPONSE_CLUSTER_G6
Systematic name | M1810
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Cluster G6: genes increasingly down-regulated in NHEK cells (normal keratinocyte) after UV-B irradiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | XU_GH1_AUTOCRINE_TARGETS_DN
Systematic name | M16384
Organism | Homo sapiens
PMID | 15845533
Authors | Xu XQ,Emerald BS,Goh EL,Kannan N,Miller LD,Gluckman PD,Liu ET,Lobie PE
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MFCF-7 cells (breast cancer) upon stable autocrine expression of HG1 [GeneID=2688].
Full description | We have exploited a discrepancy in the oncogenic potential of autocrine and exogenous human growth hormone (hGH) in an attempt to identify molecules that could potentially be involved in oncogenic transformation of the human mammary epithelial cell. Microarray analysis of 19,000 human genes identified a subset of 305 genes in a human mammary carcinoma cell line that were remarkably different in their response to autocrine and exogenous hGH. Autocrine and exogenous hGH also regulated 167 common genes. Semiquantitative reverse transcription-PCR confirmed differential regulation of genes by either autocrine or exogenous hGH. Functional analysis of one of the identified autocrine hGH-regulated genes, TFF3, determined that its expression is sufficient to support anchorage-independent growth of human mammary carcinoma cells. Small interfering RNA-mediated knockdown of TFF3 concordantly abrogated anchorage-independent growth of mammary carcinoma cells and abrogated the ability of autocrine hGH to stimulate oncogenic transformation of immortalized human mammary epithelial cells. Further functional characterization of the identified subset of specifically autocrine hGH regulated genes will delineate additional novel oncogenes for the human mammary epithelial cell.

Standard name | SESTO_RESPONSE_TO_UV_C7
Systematic name | M14808
Organism | Homo sapiens
PMID | 11867738
Authors | Sesto A,Navarro M,Burslem F,Jorcano JL
Category | C2
Sub-category | CGP
Brief description | Cluster 7: genes changed in primary keratinocytes by UVB irradiation.
Full description | UV radiation is the most important environmental skin aggressor, causing cancer and other problems. This paper reports the use of oligonucleotide microarray technology to determine changes in gene expression in human keratinocytes after UVB treatment. Examination of the effects of different doses at different times after irradiation gave a global picture of the keratinocyte response to this type of insult. Five hundred thirty-nine regulated transcripts were found and organized into nine different clusters depending on behavior patterns. Classification of these genes into 23 functional categories revealed that several biological processes are globally affected by UVB. In addition to confirming a majority up-regulation of the transcripts related to the UV-specific inflammatory and stress responses, significant increases were seen in the expression of genes involved in basal transcription, splicing, and translation as well as in the proteasome-mediated degradation category. On the other hand, those transcripts belonging to the metabolism and adhesion categories were strongly downregulated. These results demonstrate the complexity of the transcriptional profile of the UVB response, describe several cellular processes previously not known to be affected by UV irradiation, and serve as a basis for the global characterization of UV-regulated genes and pathways.

Standard name | KAAB_FAILED_HEART_VENTRICLE_DN
Systematic name | M15188
Organism | Homo sapiens
PMID | 15103417
Authors | Kääb S,Barth AS,Margerie D,Dugas M,Gebauer M,Zwermann L,Merk S,Pfeufer A,Steinmeyer K,Bleich M,Kreuzer E,Steinbeck G,Näbauer M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the ventricles of failing hearts (DCM and ICM) compared to the healthy controls.
Full description | To obtain region- and disease-specific transcription profiles of human myocardial tissue, we explored mRNA expression from all four chambers of eight explanted failing [idiopathic dilated cardiomyopathy (DCM), n=5; ischemic cardiomyopathy (ICM), n=3], and five non-failing hearts using high-density oligonucleotide arrays (Affymetrix U95Av2). We performed pair-wise comparisons of gene expression in the categories (1) atria versus ventricles, (2) disease-regulated genes in atria and (3) disease-regulated genes in ventricles. In the 51 heart samples examined, 549 genes showed divergent distribution between atria and ventricles (272 genes with higher expression in atria, 277 genes with higher expression in ventricles). Two hundred and eighty-eight genes were differentially expressed in failing myocardium compared to non-failing hearts (19 genes regulated in atria and ventricles, 172 regulated in atria only, 97 genes regulated in ventricles only). For disease-regulated genes, down-regulation was 4.5-times more common than up-regulation. Functional classification according to Gene Ontology identified specific biological patterns for differentially expressed genes. Eleven genes were validated by RT-PCR showing a good correlation with the microarray data. Our goal was to determine a gene expression fingerprint of the heart, accounting for region- and disease-specific aspects. Recognizing common gene expression patterns in heart failure will significantly contribute to the understanding of heart failure and may eventually lead to the development of pathway-specific therapies.

Standard name | JIANG_HYPOXIA_CANCER
Systematic name | M7547
Organism | Homo sapiens
PMID | 12692265
Authors | Jiang Y,Zhang W,Kondo K,Klco JM,St Martin TB,Dufault MR,Madden SL,Kaelin WG Jr,Nacht M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 786-0 cells (renal carcinoma, RCC) by hypoxia and in the absensce of VHL [GeneID=7428].
Full description | The von Hippel-Lindau tumor suppressor, pVHL, is a key player in one of the best characterized hypoxia signaling pathways, the VHL-hypoxia-inducible factor (VHL-HIF) pathway. To better understand the role of VHL in the hypoxia signaling pathways of tumor cells, we used serial analysis of gene expression (SAGE) to investigate hypoxia-regulated gene expression in renal carcinoma cells (786-0), with and without VHL. The gene expression profiles of the cancer cells were compared to SAGE profiles from normal renal proximal tubule cells grown under both normoxia and hypoxia. The data suggest that the role of VHL as a tumor suppressor may be more complex than previously thought. Further, the data reveal that renal carcinoma cells have evolved an alternative hypoxia signaling pathway(s) compared with normal renal cells. These alternative hypoxia pathways demonstrate VHL-dependent and VHL-independent regulation. The genes involved in such pathways include those with potential importance in the physiological and pathological regulation of tumor growth and angiogenesis. Some of the genes identified as showing overexpression in the cancer cells, particularly those encoding secreted or membrane-bound proteins, could be potential biomarkers for tumors or targets for rational therapeutics that are dependent on VHL status.

Standard name | ZAMORA_NOS2_TARGETS_DN
Systematic name | M1638
Organism | Mus musculus
PMID | 12381414
Authors | Zamora R,Vodovotz Y,Aulak KS,Kim PK,Kane JM 3rd,Alarcon L,Stuehr DJ,Billiar TR
Category | C2
Sub-category | CGP
Brief description | Down-regulated in hepatocytes upon expression of NOS2 [GeneID=4843].
Full description | Nitric oxide (NO) can modulate numerous genes directly; however, some genes may be modulated only in the presence of the inflammatory stimuli that increase the expression of the inducible nitric oxide synthase (iNOS). One method by which to examine changes in NO-mediated gene expression is to carry out a gene array analysis on NO-nai;ve cells. Herein, we report a gene array analysis on mRNA from iNOS-null (iNOS(-/-)) mouse hepatocytes harvested from mice exposed to NO by infection with an adenovirus expressing human iNOS (Ad-iNOS). Of the 6500 genes on this array, only approximately 200 were modulated either up or down by the increased iNOS activity according to our criteria for significance. Several clearly defined families of genes were modulated, including genes coding for proinflammatory transcription factors, cytokines, cytokine receptors, proteins associated with cell proliferation and cellular energetics, as well as proteins involved in apoptosis. Our results suggest that iNOS has a generally anti-inflammatory and anti-apoptotic role in hepatocytes but also acts to suppress proliferation and protein synthesis. The expression of iNOS results in increased expression of stress-related proteins, including heme oxygenase-1 (HO-1). We used HO-1 to confirm that a significant change identified by an analysis could be demonstrated as significant in cells and tissues. The elevation of HO-1 was confirmed at the protein level in hepatocytes in vitro. Furthermore, iNOS(-/-) mice experienced greatly increased liver injury subsequent to intestinal ischemia/reperfusion injury, associated with an inability to upregulate HO-1. This is the first study to address the global gene changes induced by iNOS in any cell type, and the findings presented herein may have clinical relevance for conditions such as septic or hemorrhagic shock in which hepatocytes, NO, and HO-1 play a crucial role.

Standard name | YIH_RESPONSE_TO_ARSENITE_C1
Systematic name | M1640
Organism | Homo sapiens
PMID | 12016162
Authors | Yih LH,Peck K,Lee TC
Category | C2
Sub-category | CGP
Brief description | Genes in cluster 1: strongly up-regulated in HFW cells (fibroblast) upon treatment with sodium arsenite [PubChem=26435] at all time points.
Full description | Arsenic compounds are widely distributed and arsenic ingestion is associated with many human diseases, including blackfoot disease, atherosclerosis, and cancers. However, the underlying mechanism of arsenic toxicity is not understood. In human fibroblast cells (HFW), arsenite is known to induce oxidative damage, chromosome aberrations, cell cycle arrest, and aneuploidy, and the manifestation of these cellular responses is dependent on changes in gene expression which can be analyzed using the cDNA microarray technique. In this study, cDNA microarray membranes with 568 human genes were used to examine mRNA profile changes in HFW cells treated for 0 to 24 h with 5 microM sodium arsenite. On the basis of the mean value for three independent experiments, 133 target genes were selected for a 2 x 3 self-organizing map cluster analysis; 94 were found to be induced by arsenite treatment, whereas 39 were repressed. These genes were categorized as signal transduction, transcriptional regulation, cell cycle control, stress responses, proteolytic enzymes, and miscellaneous. Significant changes in the signaling-related and transcriptional regulation genes indicated that arsenite induces complex toxicopathological injury.

Standard name | BANDRES_RESPONSE_TO_CARMUSTIN_MGMT_48HR_DN
Systematic name | M9556
Organism | Homo sapiens
PMID | 15980968
Authors | Bandres E,Andion E,Escalada A,Honorato B,Catalan V,Cubedo E,Cordeu L,Garcia F,Zarate R,Zabalegui N,Garcia-Foncillas J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T98G cells (glioma, express MGMT [GeneID=4255]) by carmustine [PubChem=2578] at 48 h.
Full description | Chemotherapy with the alkylating agent BCNU (1,3-bis (2-chloroethyl)-1-nitrosourea) is the most commonly used chemotherapeutic agent for gliomas. However, the usefulness of this agent is limited because tumor cell resistance to BCNU is frequently found in clinical brain tumor therapy. The O6-methylguanine-DNA methyltransferase protein (MGMT) reverses alkylation at the O6 position of guanine and we have reported the role of MGMT in the response of brain tumors to alkylating agents. However, the different mechanisms underlying the patterns related to MGMT remain unclear. To better understand the molecular mechanism by which BCNU exerts its effect in glioma cell lines according MGMT expression, we used microarray technology to interrogate 3800 known genes and determine the gene expression profiles altered by BCNU treatment. Our results showed that treatment with BCNU alters the expression of a diverse group of genes in a time-dependent manner. A subset of gene changes was found common in both glioma cell lines and other subset is specific of each cell line. After 24 h of BCNU treatment, up-regulation of transcription factors involved in the nucleation of both RNA polymerase II and III transcription initiation complexes was reported. Interestingly, BCNU promoted the expression of actin-dependent regulators of chromatin. Similar effects were found with higher BCNU doses in MGMT+ cell line showing a similar mechanism that in MGMT-deficient cell with standard doses. Our data suggest that human glioma cell lines treated with BCNU, independently of MGMT expression, show changes in the expression of cell cycle and survival-related genes interfering the transcription mechanisms and the chromatin regulation.

Standard name | BURTON_ADIPOGENESIS_PEAK_AT_8HR
Systematic name | M1641
Organism | Mus musculus
PMID | 12137940
Authors | Burton GR,Guan Y,Nagarajan R,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Cluster 3: genes maximally expressed at 8 hr time point during differentiation of 3T3-L1 fibroblasts into adipocytes in response to adipogenic hormones.
Full description | The molecular mechanisms that regulate cellular differentiation during development and throughout life are complex. It is now recognized that precise patterns of differentially expressed genes ultimately direct a particular cell toward a given lineage and many of these are regulated during the earliest stages of differentiation. Using a microarray-based expression analysis, we have examined gene expression profiles during the first 24 h of 3T3-L1 adipocyte differentiation. RNA was isolated at times 0, 2, 8, 16, and 24 h following stimulation of differentiation and hybridized in duplicate to high density Affymetrix microarray gene chips containing a series of 13,179 cDNA/expressed sequence tag (EST) probe sets. Two hundred and eighty-five cDNA/ESTs were shown to have at least a fivefold change in expression levels during this time course and both hierarchical and self-organizing map clustering analysis was performed to categorize them by expression profiles. Several genes known to be regulated during this time period were confirmed and Western blot analysis of the proteins encoded by some of the identified genes revealed expression profiles similar to their mRNA counterparts. As expected, many of the genes identified have not been examined in such a critical time period during adipogenesis and may well represent novel adipogenic mediators.

Standard name | SIMBULAN_PARP1_TARGETS_DN
Systematic name | M1642
Organism | Mus musculus
PMID | 11016956
Authors | Simbulan-Rosenthal CM,Ly DH,Rosenthal DS,Konopka G,Luo R,Wang ZQ,Schultz PG,Smulson ME
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblasts) from PARP1 [GeneID=142] knockout mice.
Full description | Poly(ADP-ribose) polymerase (PARP) is implicated in the maintenance of genomic integrity, given that inhibition or depletion of this enzyme increases genomic instability in cells exposed to genotoxic agents. We previously showed that immortalized fibroblasts derived from PARP(-/-) mice exhibit an unstable tetraploid population, and partial chromosomal gains and losses in PARP(-/-) mice and immortalized fibroblasts are accompanied by changes in the expression of p53, Rb, and c-Jun, as well as other proteins. A tetraploid population has also now been detected in primary fibroblasts derived from PARP(-/-) mice. Oligonucleotide microarray analysis was applied to characterize more comprehensively the differences in gene expression between asynchronously dividing primary fibroblasts derived from PARP(-/-) mice and their wild-type littermates. Of the 11,000 genes monitored, 91 differentially expressed genes were identified. The loss of PARP results in down-regulation of the expression of several genes involved in regulation of cell cycle progression or mitosis, DNA replication, or chromosomal processing or assembly. PARP deficiency also up-regulates genes that encode extracellular matrix or cytoskeletal proteins that are implicated in cancer initiation or progression or in normal or premature aging. These results provide insight into the mechanism by which PARP deficiency impairs mitotic function, thereby resulting in the genomic alterations and chromosomal abnormalities as well as in altered expression of genes that may contribute to genomic instability, cancer, and aging.

Standard name | SAFFORD_T_LYMPHOCYTE_ANERGY
Systematic name | M1644
Organism | Mus musculus
PMID | 15834410
Authors | Safford M,Collins S,Lutz MA,Allen A,Huang CT,Kowalski J,Blackford A,Horton MR,Drake C,Schwartz RH,Powell JD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in anergic mouse T helper cells (A.E7), versus non-anergic stimulated controls
Full description | T cell receptor engagement in the absence of proper accessory signals leads to T cell anergy. E3 ligases are involved in maintaining the anergic state. However, the specific molecules responsible for the induction of anergy have yet to be elucidated. Using microarray analysis we have identified here early growth response gene 2 (Egr-2) and Egr-3 as key negative regulators of T cell activation. Overexpression of Egr2 and Egr3 was associated with an increase in the E3 ubiquitin ligase Cbl-b and inhibition of T cell activation. Conversely, T cells from Egr3(-/-) mice had lower expression of Cbl-b and were resistant to in vivo peptide-induced tolerance. These data support the idea that Egr-2 and Egr-3 are involved in promoting a T cell receptor-induced negative regulatory genetic program.

Standard name | WU_HBX_TARGETS_2_UP
Systematic name | M17316
Organism | Homo sapiens
PMID | 11439330
Authors | Wu CG,Salvay DM,Forgues M,Valerie K,Farnsworth J,Markin RS,Wang XW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by expression of HBV X protein (HBVgp3) [GeneID=944566] in primary hepatocytes.
Full description | Hepatitis B virus (HBV) is a major risk factor for the development of hepatocellular carcinoma (HCC). HBV encodes the potentially oncogenic HBx protein, which mainly functions as a transcriptional co-activator involving in multiple gene deregulations. However, mechanisms underlying HBx-mediated oncogenicity remain unclear. To determine the role(s) of HBx in the early genesis of HCC, we utilized the NCI Oncochip microarray that contains 2208 human cDNA clones to examine the gene expression profiles in either freshly isolated normal primary adult human hepatocytes (Hhep) or an HCC cell line (SK-Hep-1) ecotopically expressing HBx via an adenoviral system. The gene expression profiles also were determined in liver samples from HBV-infected chronic active hepatitis patients when compared with normal liver samples. The microarray results were validated through Northern blot analysis of the expression of selected genes. Using reciprocally labeling hybridizations, scatterplot analysis of gene expression ratios in human primary hepatocytes expressing HBx demonstrates that microarrays are highly reproducible. The comparison of gene expression profiles between HBx-expressing primary hepatocytes and HBV-infected liver samples shows a consistent alteration of many cellular genes including a subset of oncogenes (such as c-myc and c-myb) and tumor suppressor genes (such as APC, p53, WAF1 and WT1). Furthermore, clustering algorithm analysis showed distinctive gene expression profiles in Hhep and SK-Hep-1 cells. Our findings are consistent with the hypothesis that the deregulation of cellular genes by oncogenic HBx may be an early event that favors hepatocyte proliferation during liver carcinogenesis.

Standard name | SESTO_RESPONSE_TO_UV_C5
Systematic name | M1470
Organism | Homo sapiens
PMID | 11867738
Authors | Sesto A,Navarro M,Burslem F,Jorcano JL
Category | C2
Sub-category | CGP
Brief description | Cluster 5: genes changed in primary keratinocytes by UVB irradiation.
Full description | UV radiation is the most important environmental skin aggressor, causing cancer and other problems. This paper reports the use of oligonucleotide microarray technology to determine changes in gene expression in human keratinocytes after UVB treatment. Examination of the effects of different doses at different times after irradiation gave a global picture of the keratinocyte response to this type of insult. Five hundred thirty-nine regulated transcripts were found and organized into nine different clusters depending on behavior patterns. Classification of these genes into 23 functional categories revealed that several biological processes are globally affected by UVB. In addition to confirming a majority up-regulation of the transcripts related to the UV-specific inflammatory and stress responses, significant increases were seen in the expression of genes involved in basal transcription, splicing, and translation as well as in the proteasome-mediated degradation category. On the other hand, those transcripts belonging to the metabolism and adhesion categories were strongly downregulated. These results demonstrate the complexity of the transcriptional profile of the UVB response, describe several cellular processes previously not known to be affected by UV irradiation, and serve as a basis for the global characterization of UV-regulated genes and pathways.

Standard name | LI_ADIPOGENESIS_BY_ACTIVATED_PPARG
Systematic name | M1645
Organism | Mus musculus
PMID | 11981038
Authors | Li Y,Lazar MA
Category | C2
Sub-category | CGP
Brief description | Adipocyte genes induced in 3T3-L1 cells (adipocyte) by constitutively active PPARG [GeneID=5468] or its agonist, TZD [PubChem=5437].
Full description | The PPARgamma is a key adipogenic determination factor. Ligands for PPARgamma such as antidiabetic thiazolidinedione (TZD) compounds are adipogenic, and many adipocyte genes that are activated by TZDs contain binding sites for PPARgamma. Like ligands for other nuclear receptors, TZDs can regulate genes positively or negatively. Here, we sought to understand the importance of positive regulation of gene expression by PPARgamma in adipogenesis. Fusion of the potent viral transcriptional activator VP16 to PPARgamma2 (VP16-PPARgamma) created a transcription factor that constitutively and dramatically activated transcription of PPARgamma-responsive genes in the absence of ligand. Forced expression of VP16-PPARgamma in 3T3-L1 preadipocytes using retroviral vectors led to adipogenesis in the absence of standard differentiating medium or any exogenous PPARgamma ligand. Gene microarray analysis revealed that VP16-PPARgamma induced many of the genes associated with adipogenesis and adipocyte function. Thus, direct up-regulation of gene expression by PPARgamma is sufficient for adipogenesis. TZD-induced adipogenesis up-regulated many of the same genes, although some were divergently regulated, including resistin, whose gene expression was reduced inVP16-PPARgamma adipocytes treated with TZDs. These results show that, although activation of PPARgamma by a heterologous activation domain is sufficient for adipogenesis, it is not equivalent to TZD treatment. This conclusion has important implications for understanding biological effects of the TZDs on adipogenesis and insulin sensitization.

Standard name | LY_AGING_MIDDLE_DN
Systematic name | M12457
Organism | Homo sapiens
PMID | 10741968
Authors | Ly DH,Lockhart DJ,Lerner RA,Schultz PG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in fibroblasts from middle-age individuals, compared to those from the young donors.
Full description | Messenger RNA levels were measured in actively dividing fibroblasts isolated from young, middle-age, and old-age humans and humans with progeria, a rare genetic disorder characterized by accelerated aging. Genes whose expression is associated with age-related phenotypes and diseases were identified. The data also suggest that an underlying mechanism of the aging process involves increasing errors in the mitotic machinery of dividing cells in the postreproductive stage of life. We propose that this dysfunction leads to chromosomal pathologies that result in misregulation of genes involved in the aging process.

Standard name | BACOLOD_RESISTANCE_TO_ALKYLATING_AGENTS_UP
Systematic name | M15908
Organism | Homo sapiens
PMID | 12479369
Authors | Bacolod MD,Johnson SP,Ali-Osman F,Modrich P,Bullock NS,Colvin OM,Bigner DD,Friedman HS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in D-341 MED (OBR) cells (medulloblastoma) resistant to both carmustine and O6-BG [PubChem=2578;4578].
Full description | Medulloblastoma (D-341 MED) and rhabdomyosarcoma (TE-671) cell lines, which are resistant to either 1,3-bis(2-chloroethyl)-1-nitrosourea (BCNU) or the combination of BCNU and O6-benzylguanine (O6-BG), were generated by serial escalation of BCNU. The activities of O6-alkylguanine-DNA alkyltransferase (AGT), glutathione-S-transferase (GST), and total glutathione (GSH) of the parental, BCNU-resistant (BR), and BCNU + O6-BG-resistant (OBR) cells were measured. No significant differences in GST activity or total GSH were seen between the parental, BR, and OBR cells of both TE-671 and D-341 MED. The AGT activities of D-341 MED (BR) and TE-671 (BR) were twice those of D-341 MED and TE-671, respectively, confirming the importance of this enzyme for BCNU resistance. The D-341 MED (OBR) cells did not exhibit any AGT activity, suggesting that another mechanism must play a role in the drug resistance. Fewer DNA interstrand cross-links (ICLs) were observed in D-341 MED (OBR) than in D-341 MED after 8 h BCNU (100-400 microM) treatment. However, the amounts of DNA ICLs observed in D-341 MED and D-341 MED (OBR) were stable after 24 h. Microarray analysis showed the increased expressions of several metallothionein genes and down-regulation of several proapoptotic genes. The AGT activity of TE-671 (OBR) was 223 fmol/mg when the cells were grown in 10 microM O6-BG and decreased to about half this value when the O6-BG concentration was increased 60 microM. The AGT cDNA of TE-671 (OBR) cells was cloned and found to contain a G-to-T transversion at codon 156, resulting in conversion of glycine to cysteine (G156C). In vitro mutagenesis has shown that the G156C AGT mutant is resistant to inactivation by O6-BG. Thus, the selection of a mutant AGT with decreased sensitivity to O6-BG is a significant contributing factor to BCNU + O6-BG resistance.

Standard name | SATO_SILENCED_BY_METHYLATION_IN_PANCREATIC_CANCER_1
Systematic name | M4308
Organism | Homo sapiens
PMID | 12839967
Authors | Sato N,Fukushima N,Maitra A,Matsubayashi H,Yeo CJ,Cameron JL,Hruban RH,Goggins M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the pancreatic cancer cell lines (AsPC1, Hs766T, MiaPaCa2, Panc1) but not in the non-neoplastic cells (HPDE) by decitabine (5-aza-2'-deoxycytidine) [PubChem=451668].
Full description | To identify potential targets for aberrant methylation in pancreatic cancer, we analyzed global changes in gene expression profiles of four pancreatic cancer cell lines after treatment with the demethylating agent 5-aza-2'-deoxycytidine (5Aza-dC) and/or the histone deacetylase inhibitor trichostatin A. A substantial number of genes were induced 5-fold or greater by 5Aza-dC alone (631 transcripts), trichostatin A alone (1196 transcripts), and by treatment with both agents (857 transcripts). Four hundred and seventy-five genes were markedly (>5-fold) induced after 5Aza-dC treatment in pancreatic cancer cell lines but not in a nonneoplastic pancreatic epithelial cell line. The methylation status of 11 of these 475 genes was examined in a panel of 42 pancreatic cancers, and all 11 of these genes were aberrantly methylated in pancreatic cancer but rarely, if any, methylated in 10 normal pancreatic ductal epithelia. These genes include UCHL1 (methylated in 100% of 42 pancreatic cancers), NPTX2 (98%), SARP2 (95%), CLDN5 (93%), reprimo (86%), LHX1 (76%), WNT7A (71%), FOXE1 (69%), TJP2 (64%), CDH3 (19%), and ST14 (10%). Three of these 11 genes (NPTX2, SARP2, and CLDN5) were selected for further analysis in a larger panel of specimens, and aberrant methylation of at least one of these three genes was detectable in 100% of 43 primary pancreatic cancers and in 18 of 24 (75%) pancreatic juice samples obtained from patients with pancreatic cancer. Thus, a substantial number of genes are induced by 5Aza-dC treatment of pancreatic cancer cells, and many of them may represent novel targets for aberrant methylation in pancreatic carcinoma.

Standard name | WENG_POR_TARGETS_LIVER_UP
Systematic name | M1647
Organism | Mus musculus
PMID | 16006652
Authors | Weng Y,DiRusso CC,Reilly AA,Black PN,Ding X
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in liver from mice with liver specific knockout of POR [GeneID=5447].
Full description | NADPH-cytochrome P450 reductase (CPR) is an essential component for the function of many enzymes, including microsomal cytochrome P450 (P450) monooxygenases and heme oxygenases. In liver-Cpr-null (with liver-specific Cpr deletion) and Cpr-low (with reduced CPR expression in all organs examined) mouse models, a reduced serum cholesterol level and an induction of hepatic P450s were observed, whereas hepatomegaly and fatty liver were only observed in the liver-Cpr-null model. Our goal was to identify hepatic gene expression changes related to these phenotypes. Cpr-lox mice (with a floxed Cpr gene and normal CPR expression) were used as the control. Through microarray analysis, we identified many genes that were differentially expressed among the three groups of mice. We also recognized the 12 gene ontology terms that contained the most significantly changed gene expression in at least one of the two mouse models. We further uncovered potential mechanisms, such as an increased activation of constitutive androstane receptor and a decreased activation of peroxisomal proliferator-activated receptor-alpha by precursors of cholesterol biosynthesis, that underlie common changes (e.g. induction of multiple P450s and suppression of genes for fatty acid metabolism) in response to CPR loss in the two mouse models. Additionally, we observed model-specific gene expression changes, such as the induction of a fatty-acid translocase (Cd36 antigen) and the suppression of carnitine O-palmitoyltransferase 1 (Cpt1a) and acyl-CoA synthetase long chain family member 1 (Acsl1), that are potentially responsible for the severe hepatic lipidosis and an altered fatty acid profile observed in liver-Cpr-null mice.

Standard name | HU_GENOTOXIC_DAMAGE_4HR
Systematic name | M1648
Organism | Mus musculus
PMID | 15120960
Authors | Hu T,Gibson DP,Carr GJ,Torontali SM,Tiesman JP,Chaney JG,Aardema MJ
Category | C2
Sub-category | CGP
Brief description | Genes most consistently regulated at 4 h by all six genotoxins tested: cisplatin, methyl methanesulfonate, mitomycin C, taxol, hydroxyurea and etoposide [PubChem=2767;4156;5746;4666;3657;36462].
Full description | During the safety evaluation process of new drugs and chemicals, a battery of genotoxicity tests is conducted starting with in vitro genotoxicity assays. Obtaining positive results in in vitro genotoxicity tests is not uncommon. Follow-up studies to determine the biological relevance of positive genotoxicity results are costly, time consuming, and utilize animals. More efficient methods, especially for identifying a putative mode of action like an indirect mechanism of genotoxicity (where DNA molecules are not the initial primary targets), would greatly improve the risk assessment for genotoxins. To this end, we are participating in an International Life Sciences Institute (ILSI) project involving studies of gene expression changes caused by model genotoxins. The purpose of the work is to evaluate gene expression tools in general, and specifically for discriminating genotoxins that are direct-acting from indirect-acting. Our lab has evaluated gene expression changes as well as micronuclei (MN) in L5178Y TK(+/-) mouse lymphoma cells treated with six compounds. Direct-acting genotoxins (where DNA is the initial primary target) that were evaluated included the DNA crosslinking agents, mitomycin C (MMC) and cisplatin (CIS), and an alkylating agent, methyl methanesulfonate (MMS). Indirect-acting genotoxins included hydroxyurea (HU), a ribonucleotide reductase inhibitor, taxol (TXL), a microtubule inhibitor, and etoposide (ETOP), a DNA topoisomerase II inhibitor. Microarray gene expression analysis was conducted using Affymetrix mouse oligonucleotide arrays on RNA samples derived from cells which were harvested immediately after the 4 h chemical treatment, and 20 h after the 4 h chemical treatment. The evaluation of these experimental results yields evidence of differentially regulated genes at both 4 and 24 h time points that appear to have discriminating power for direct versus indirect genotoxins, and therefore may serve as a fingerprint for classifying chemicals when their mechanism of action is unknown.

Standard name | MCDOWELL_ACUTE_LUNG_INJURY_DN
Systematic name | M1650
Organism | Mus musculus
PMID | 12540486
Authors | McDowell SA,Gammon K,Zingarelli B,Bachurski CJ,Aronow BJ,Prows DR,Leikauf GD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the mouse model of acute lung injury induced by inhaling nickel sulfate [PubChem=24586].
Full description | The role of nitric oxide (NO) in acute lung injury remains controversial. Although inhaled NO increases oxygenation in clinical trials, inhibiting NO-synthase (NOS) can be protective. To examine the latter, nickel-exposed mice were treated with saline or NOS inhibitor, N(G)-nitro-L-arginine methyl ester (L-NAME). Initial microarray analysis of nickel-induced gene expression of saline-treated mice revealed increased inflammatory mediator, matrix injury-repair, and hypoxia-induced factor-mediated sequences and decreased lung-specific (e.g., surfactant-associated protein B and C) sequences. Compared with saline control, L-NAME-treated mice had enhanced survival with attenuated serum nitrate/nitrite, endothelial NOS activity, and lavage neutrophils and protein. Although initial cytokine (i.e., interferon-gamma, interleukins-1beta and -6, macrophage inflammatory protein-2, monocyte chemotactic protein-1, and tumor necrosis factor-alpha) gene expression was similar between groups, subsequent larger cytokine increases only occurred in saline-treated mice. Similarly, surfactant protein gene expression decreased initially in both groups yet was restored subsequently with L-NAME treatment. Interestingly, the role of inducible NOS (iNOS) in these responses seems minimal. iNOS gene expression was unaltered, iNOS activity and nitrotyrosine residues were undetectable, and an iNOS antagonist, aminoguanidine, failed to increase survival. Rather, systemic L-NAME treatment appears to attenuate pulmonary endothelial NOS activity, subsequent cytokine expression, inflammation, and protein permeability, and thereby restores surfactant gene expression and increases survival.

Standard name | RAMPON_ENRICHED_LEARNING_ENVIRONMENT_LATE_UP
Systematic name | M1651
Organism | Mus musculus
PMID | 11070096
Authors | Rampon C,Jiang CH,Dong H,Tang YP,Lockhart DJ,Schultz PG,Tsien JZ,Hu Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the brain cortex of mice that were exposed to an enriched learning environment for 2 or 14 days.
Full description | An enriched environment is known to promote structural changes in the brain and to enhance learning and memory performance in rodents [Hebb, D. O. (1947) Am. Psychol. 2, 306-307]. To better understand the molecular mechanisms underlying these experience-dependent cognitive changes, we have used high-density oligonucleotide microarrays to analyze gene expression in the brain. Expression of a large number of genes changes in response to enrichment training, many of which can be linked to neuronal structure, synaptic plasticity, and transmission. A number of these genes may play important roles in modulating learning and memory capacity.

Standard name | MARIADASON_RESPONSE_TO_BUTYRATE_SULINDAC_6
Systematic name | M1652
Organism | Homo sapiens
PMID | 10969808
Authors | Mariadason JM,Corner GA,Augenlicht LH
Category | C2
Sub-category | CGP
Brief description | Cluster 6: genes down-regulated in SW260 cells (colon cancer) by sodium butyrate and sulindac [PubChem=5222465;5352].
Full description | The short-chain fatty acid butyrate, produced by microbial fermentation of dietary fiber in the large intestine, is a physiological regulator of major pathways of colonic epithelial cell maturation: cell cycle arrest, lineage-specific differentiation, and apoptosis. Microarray analysis of 8,063 sequences demonstrated a complex cascade of reprogramming of SW620 colonic epithelial cells upon treatment with butyrate characterized by the progressive recruitment of gene sets as a function of time. Comparison with the effects of trichostatin A, in conjunction with differences in the kinetics of alteration of histone acetylation induced by butyrate and trichostatin A, identified subsets of induced and repressed genes likely coordinately regulated by altered histone acetylation. The butyrate response was also compared in detail with that of sulindac, a nonsteroidal anti-inflammatory drug with significant chemopreventive activity for colon cancer, and curcumin, a component of mustard and curry structurally and functionally related to sulindac that also has chemopreventive activity. Although gene clusters were identified that showed similar responses to butyrate and sulindac, the data were characterized by the extensive differences in the effects of the two agents. This was striking for functional classes of genes involved in signaling pathways and in cell cycle progression, although butyrate and sulindac induce a similar G0-G1 arrest, elevation of beta-catenin-Tcf signaling, and apoptotic cascade. As regards cell cycle arrest, the underlying mechanism in response to butyrate was most similar to that of the Caco-2 cell line that had spontaneously undergone a G0-G1 arrest and least similar to the G2-M arrest stimulated by curcumin. Thus, high-throughput microarray analysis of gene expression profiles can be used to characterize and distinguish the mechanisms of response of colonic epithelial cells to physiological and pharmacological inducers of cell maturation. This has important implications for characterization of chemopreventive agents and recognition of potential toxicity and synergies. The data bases, gene clusters, and analyses are available at http:// sequence.aecom.yu.edu/genome/.

Standard name | GENTILE_UV_LOW_DOSE_DN
Systematic name | M4594
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated in WS1 (fibroblast) in response to irradiation with low dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | SARTIPY_NORMAL_AT_INSULIN_RESISTANCE_DN
Systematic name | M1654
Organism | Mus musculus
PMID | 14530283
Authors | Sartipy P,Loskutoff DJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 3T3-L1 cells (adipocyte) by insulin [GeneID=3630] which continued to respond normally to insulin in the insulin resistant cells.
Full description | We have employed microarray technology using RNA from normal 3T3-L1 adipocytes and from 3T3-L1 adipocytes made insulin-resistant by treatment with tumor necrosis factor-alpha to identify a new class of insulin-responsive genes. These genes continued to respond normally to insulin even though the adipocytes themselves were metabolically insulin-resistant, i.e. they displayed a significantly decreased rate of insulin-stimulated glucose uptake. Approximately 12,000 genes/expressed sequence tags (ESTs) were screened. Of these, 40 genes/ESTs were identified that became insulin-resistant as expected (e.g. Socs-3, junB, and matrix metalloproteinase-11). However, 61 genes/ESTs continued to respond normally to insulin. Although some of these genes were previously shown to be regulated by insulin (e.g. Glut-1 and beta3-adrenergic receptor), other novel insulin-sensitive genes were also identified (e.g. Egr-1, epiregulin, Fra-1, and ABCA1). Real-time reverse transcription-PCR analysis confirmed the expression patterns of several of the differentially expressed genes. One gene that remained insulin-sensitive in the insulin-resistant adipocytes is the transcription factor Egr-1. Using an antisense strategy, we show that tissue factor and macrophage colony-stimulating factor, two cardiovascular risk factors, are downstream EGR-1 target genes in the adipocyte. Taken together, these data support the hypothesis that some signaling pathways remain insulin-sensitive in metabolically insulin-resistant adipocytes. These pathways may promote abnormal gene expression in hyperinsulinemic states like obesity and type II diabetes and thus may contribute to pathologies associated with these conditions.

Standard name | BANDRES_RESPONSE_TO_CARMUSTIN_MGMT_48HR_UP
Systematic name | M2042
Organism | Homo sapiens
PMID | 15980968
Authors | Bandres E,Andion E,Escalada A,Honorato B,Catalan V,Cubedo E,Cordeu L,Garcia F,Zarate R,Zabalegui N,Garcia-Foncillas J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T98G cells (glioma, express MGMT [GeneID=4255]) by carmustine [PubChem=2578] at 48 h.
Full description | Chemotherapy with the alkylating agent BCNU (1,3-bis (2-chloroethyl)-1-nitrosourea) is the most commonly used chemotherapeutic agent for gliomas. However, the usefulness of this agent is limited because tumor cell resistance to BCNU is frequently found in clinical brain tumor therapy. The O6-methylguanine-DNA methyltransferase protein (MGMT) reverses alkylation at the O6 position of guanine and we have reported the role of MGMT in the response of brain tumors to alkylating agents. However, the different mechanisms underlying the patterns related to MGMT remain unclear. To better understand the molecular mechanism by which BCNU exerts its effect in glioma cell lines according MGMT expression, we used microarray technology to interrogate 3800 known genes and determine the gene expression profiles altered by BCNU treatment. Our results showed that treatment with BCNU alters the expression of a diverse group of genes in a time-dependent manner. A subset of gene changes was found common in both glioma cell lines and other subset is specific of each cell line. After 24 h of BCNU treatment, up-regulation of transcription factors involved in the nucleation of both RNA polymerase II and III transcription initiation complexes was reported. Interestingly, BCNU promoted the expression of actin-dependent regulators of chromatin. Similar effects were found with higher BCNU doses in MGMT+ cell line showing a similar mechanism that in MGMT-deficient cell with standard doses. Our data suggest that human glioma cell lines treated with BCNU, independently of MGMT expression, show changes in the expression of cell cycle and survival-related genes interfering the transcription mechanisms and the chromatin regulation.

Standard name | GENTILE_UV_RESPONSE_CLUSTER_D8
Systematic name | M15693
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Cluster d8: genes progressively down-regulated in WS1 cells (fibroblast) through 18 h after irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | BROWNE_HCMV_INFECTION_24HR_UP
Systematic name | M12275
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 24 h time point that were not up-regulated at the previous time point, 20 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | WANG_SMARCE1_TARGETS_UP
Systematic name | M1804
Organism | Homo sapiens
PMID | 16135788
Authors | Wang L,Baiocchi RA,Pal S,Mosialos G,Caligiuri M,Sif S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in BT549 cells (breast cancer) by expression of SMARCE1 [GeneID=6605] off a retroviral vector.
Full description | Mutation of BRG1, hBRM, and their associated factors, INI1 and BAF57, in primary human tumors has suggested that inactivation of human SWI/SNF (hSWI/SNF) complexes may be involved in neoplastic transformation. BT549 is an invasive human breast carcinoma cell line that lacks expression of BAF57, a key hSWI/SNF subunit that mediates interaction with transcriptional activators and corepressors. In this study we investigated the role of BAF57 in suppressing tumorigenesis by establishing BT549 stable cell lines that expresses full-length BAF57 protein. BT549 clones expressing BAF57 demonstrated marked phenotypic changes, slow growth kinetics, and restoration of contact inhibition. Altered growth was found to be due in part to cell cycle arrest and induction of apoptosis. Furthermore, microarray analysis revealed that BAF57-mediated cell death was associated with up-regulation of proapoptotic genes including the tumor suppressor familial cylindromatosis (CYLD), which was found to be a direct target of BAF57 as determined by chromatin immunoprecipitation analysis. Increased expression of CYLD in BT549 cells induced apoptosis, while its suppression by small interfering RNA inhibited cell death in BAF57 expressing BT549 cells. These findings demonstrate the importance of BAF57 in cell growth regulation and provide a novel link between hSWI/SNF chromatin remodelers and apoptosis.

Standard name | SESTO_RESPONSE_TO_UV_C3
Systematic name | M12664
Organism | Homo sapiens
PMID | 11867738
Authors | Sesto A,Navarro M,Burslem F,Jorcano JL
Category | C2
Sub-category | CGP
Brief description | Cluster 3: genes changed in primary keratinocytes by UVB irradiation.
Full description | UV radiation is the most important environmental skin aggressor, causing cancer and other problems. This paper reports the use of oligonucleotide microarray technology to determine changes in gene expression in human keratinocytes after UVB treatment. Examination of the effects of different doses at different times after irradiation gave a global picture of the keratinocyte response to this type of insult. Five hundred thirty-nine regulated transcripts were found and organized into nine different clusters depending on behavior patterns. Classification of these genes into 23 functional categories revealed that several biological processes are globally affected by UVB. In addition to confirming a majority up-regulation of the transcripts related to the UV-specific inflammatory and stress responses, significant increases were seen in the expression of genes involved in basal transcription, splicing, and translation as well as in the proteasome-mediated degradation category. On the other hand, those transcripts belonging to the metabolism and adhesion categories were strongly downregulated. These results demonstrate the complexity of the transcriptional profile of the UVB response, describe several cellular processes previously not known to be affected by UV irradiation, and serve as a basis for the global characterization of UV-regulated genes and pathways.

Standard name | HAN_JNK_SINGALING_DN
Systematic name | M1655
Organism | Mus musculus
PMID | 12354774
Authors | Han SY,Kim SH,Heasley LE
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 3T3 cells (fibroblast) upon activation of JNK pathway.
Full description | The c-Jun N-terminal kinases (JNKs) are encoded by three genes that yield 10 isoforms through alternative mRNA splicing. The roles of each JNK isoform in the many putative biological responses where the JNK pathway is activated are still unclear. To examine the cellular responses mediated by different JNK isoforms, gain-of-function JNK1 polypeptides were generated by fusing the upstream mitogen-activated protein kinase kinase, MKK7, with p46JNK1alpha or p46JNK1beta. The MKK7-JNK fusion proteins, which exhibited constitutive activity in 293T cells, were stably expressed in Swiss 3T3 fibroblasts using retrovirus-mediated gene transfer. Swiss 3T3 cells expressing either of the MKK7-JNK polypeptides were equally sensitized to induction of cell death following serum withdrawal. To search for other cellular responses that may be selectively regulated by the JNK1 isoforms, the gene expression profiles of Swiss 3T3 cells expressing MKK7-JNK1alpha or MKK7-JNK1beta were compared with empty vector-transfected control cells. Affymetrix Genechips identified 46 genes for which expression was increased in MKK7-JNK-expressing cells relative to vector control cells. Twenty genes including those for c-Jun, MKP-7, interluekin-1 receptor family member ST2L/ST2, and c-Jun-binding protein were induced similarly by MKK7-JNK1alpha and MKK7-JNK1beta proteins, whereas 13 genes were selectively increased by MKK7-JNK1alpha and 13 genes were selectively increased by MKK7-JNK1beta. The set of genes selectively induced by MKK7-JNK1beta included a number of known interferon-stimulated genes (ISG12, ISG15, IGTP, and GTPI). Consistent with these gene expression changes, Swiss 3T3 cells expressing MKK7-JNK1beta exhibited increased resistance to vesicular stomatitis virus-induced cell death. These findings reveal evidence for JNK isoform-selective gene regulation and support a role for distinct JNK isoforms in specific cellular responses.

Standard name | KRASNOSELSKAYA_ILF3_TARGETS_DN
Systematic name | M12166
Organism | Homo sapiens
PMID | 12036489
Authors | Krasnoselskaya-Riz I,Spruill A,Chen YW,Schuster D,Teslovich T,Baker C,Kumar A,Stephan DA
Category | C2
Sub-category | CGP
Brief description | Down-regulated in GHOST(3)CXCR4 cells (osteosarcoma) upon ectopic expression of ILF3 [GeneID=3609].
Full description | Viral infection triggers a cascade of interferon response genes, but the mechanisms that prime such innate antiviral defenses are poorly understood. Among candidate cellular mediators of the antiviral response are the double-stranded RNA (dsRNA)-binding proteins. Here we show that a C-terminal variant of the ubiquitous dsRNA-binding protein, nuclear factor 90 (NF90ctv), can activate the interferon response genes in the absence of viral infection. NF90ctv-expressing cells were infected with the syncytium-inducing HIV-1 strain NL4-3 and were shown to inhibit viral replication. To gain insight into this mechanism of protection, we analyzed the expression profiles of NF90ctv-positive cells as compared with parental cells transduced with the empty vector. Of the 5600 genes represented on the expression arrays, 90 displayed significant (4-fold or more) changes in mRNA levels in NF90-expressing cells. About 50% are known interferon alpha/beta-stimulated genes. The microarray expression data were confirmed by quantitative reverse transcriptase-polymerase chain reaction analysis of six representative interferon-inducible genes. Electrophoretic mobility shift assays showed that the biological response is mediated by the activation of transcription factors in NF90ctv-expressing cells. Functional significance of the activated transcription complex was evaluated by transfection assays with luciferase reporter constructs driven by the interferon-inducible promoter from the 2'-5'-oligoadenylate synthetase (p69) gene. Resistance to HIV-1, caused by the expression of NF90ctv in the cell culture system, appears to be mediated in part by the induction of interferon response genes. This leads to a hypothesis as to the mechanism of action of NF90 in mediating endogenous antiviral responses.

Standard name | GENTILE_RESPONSE_CLUSTER_D3
Systematic name | M11338
Organism | Homo sapiens
PMID | 12907719
Authors | Gentile M,Latonen L,Laiho M
Category | C2
Sub-category | CGP
Brief description | Cluster d3: genes progressively down-regulated in WS1 cells (fibroblast) through 12 h irradiation with high dose UV-C.
Full description | DNA damage caused by UV radiation initiates cellular recovery mechanisms, which involve activation of DNA damage response pathways, cell cycle arrest and apoptosis. To assess cellular transcriptional responses to UVC-induced DNA damage we compared time course responses of human skin fibroblasts to low and high doses of UVC radiation known to induce a transient cellular replicative arrest or apoptosis, respectively. UVC radiation elicited >3-fold changes in 460 out of 12,000 transcripts and 89% of these represented downregulated transcripts. Only 5% of the regulated genes were common to both low and high doses of radiation. Cells inflicted with a low dose of UVC exhibited transcription profiles demonstrating transient regulation followed by recovery, whereas the responses were persistent after the high dose. A detailed clustering analysis and functional classification of the targets implied regulation of biologically divergent responses and suggested involvement of transcriptional and translational machinery, inflammatory, anti-proliferative and anti-angiogenic responses. The data support the notion that UVC radiation induces prominent, dose-dependent downregulation of transcription. However, the data strongly suggest that transcriptional repression is also target gene selective. Furthermore, the results demonstrate that dose-dependent induction of cell cycle arrest and apoptosis by UVC radiation are transcriptionally highly distinct responses.

Standard name | JI_RESPONSE_TO_FSH_UP
Systematic name | M10355
Organism | Homo sapiens
PMID | 15386376
Authors | Ji Q,Liu PI,Chen PK,Aoyama C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCV152 cells (ovarian cancer) treated with follicle stimulating hormone (FSH).
Full description | Epidemiologic data have implicated reproductive follicle-stimulating hormone (FSH) as a probable risk factor for ovarian cancer (OC) development. Although pituitary and sex hormones have been reported to regulate OC cell growth, no information is available on the influence of FSH on gene expression profiles during ovarian surface epithelial (OSE) cell proliferation. This study evaluated the effect of FSH treatment on cell proliferation of various OSE cell lines and gene expression profiles with FSH treatment. Follicle-stimulating hormone receptor (FSHR) was found at higher expression at both transcriptional and protein levels in ovarian cancerous tissues compared to normal tissues, and FSH was shown to promote cell growth in 3 OSE cell lines. Furthermore, it was also found that overexpression of FSHR in Chinese hamster ovary (CHO) cells leads to cell proliferation. Using cDNA MicroArray analysis on MCV152 cells with FSH treatment, 91 genes were found upregulated and 68 genes downregulated for more than 2-fold after FSH treatment. Most of the genes were related to metabolism, cell proliferation and oncogenes. Downregulated genes included tumor suppressor genes (RB1, BRCA1, BS69) and the genes related to cell proliferation control. Pathway analysis found that FSH activates certain important enzymes in sterol biosynthesis pathways. FSH-induced gene expression profiles on MCV152 cells support the standing hypothesis that FSH is a probable risk factor for ovarian cancerous development.

Standard name | LEE_CALORIE_RESTRICTION_MUSCLE_DN
Systematic name | M1657
Organism | Mus musculus
PMID | 10464095
Authors | Lee CK,Klopp RG,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Down-regulated in the gastrocnemius muscle of aged (30-month) mice subjected to caloric restriction diet since young adulthood.
Full description | The gene expression profile of the aging process was analyzed in skeletal muscle of mice. Use of high-density oligonucleotide arrays representing 6347 genes revealed that aging resulted in a differential gene expression pattern indicative of a marked stress response and lower expression of metabolic and biosynthetic genes. Most alterations were either completely or partially prevented by caloric restriction, the only intervention known to retard aging in mammals. Transcriptional patterns of calorie-restricted animals suggest that caloric restriction retards the aging process by causing a metabolic shift toward increased protein turnover and decreased macromolecular damage.

Standard name | ABE_VEGFA_TARGETS_30MIN
Systematic name | M4078
Organism | Homo sapiens
PMID | 12197474
Authors | Abe M,Sato Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HUVEC cells (endothelium) at 30 min after VEGFA [GeneID=7422] stimulation.
Full description | Vascular endothelial growth factor (VEGF) is one of the most important factors that stimulate angiogenesis and vascular permeability. To clarify the role of VEGF, we analysed a human cDNA chip containing 7267 human genes to identify genes induced by VEGF in human umbilical vein endothelial cells (HUVECs). One hundred thirty-nine cDNAs, including ninety-nine previously known and forty poorly characterized or novel sequences, were increased more than two-fold by VEGF within twenty-four hours of stimulation. Among them, only five are known to regulate angiogenesis: cyclooxygenase 2 (COX2), heparin-binding epidermal growth factor-like growth factor, early growth response 1 (EGR 1), CYR61, and angiopoietin 2. Fifty-three genes induced within the first two hours were thought to be directly induced by VEGF. Of these, Down syndrome candidate region 1 (maximum induction = 6.1-fold) was the most profoundly induced, followed by Mifl (KIAA0025; 5.5-fold), COX2 (4.7-fold), EGR 3 (3.7-fold), EGR 2 (3.2-fold), bactericidal/permeability-increasing protein (3.1-fold), and CD1B antigen, b polypeptide (3.1-fold). In addition to the genes mentioned above, there were many poorly characterized or novel genes induced by VEGF. Further analysis of these genes may aid in the elucidation of the molecular mechanisms of angiogenesis or vascular permeability stimulated by VEGF.

Standard name | BROWNE_HCMV_INFECTION_6HR_DN
Systematic name | M10311
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 6 h time point that were not down-regulated at the previous time point, 4 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | LEE_AGING_MUSCLE_UP
Systematic name | M1658
Organism | Mus musculus
PMID | 10464095
Authors | Lee CK,Klopp RG,Weindruch R,Prolla TA
Category | C2
Sub-category | CGP
Brief description | Upregulated in the gastrocnemius muscle of aged adult mice (30-month) vs young adult (5-month)
Full description | The gene expression profile of the aging process was analyzed in skeletal muscle of mice. Use of high-density oligonucleotide arrays representing 6347 genes revealed that aging resulted in a differential gene expression pattern indicative of a marked stress response and lower expression of metabolic and biosynthetic genes. Most alterations were either completely or partially prevented by caloric restriction, the only intervention known to retard aging in mammals. Transcriptional patterns of calorie-restricted animals suggest that caloric restriction retards the aging process by causing a metabolic shift toward increased protein turnover and decreased macromolecular damage.

Standard name | CARDOSO_RESPONSE_TO_GAMMA_RADIATION_AND_3AB
Systematic name | M1659
Organism | Mus musculus
PMID | 12379459
Authors | Cardoso RS,Espanhol AR,Passos GA,Sakamoto-Hojo ET
Category | C2
Sub-category | CGP
Brief description | Down-regulated synergystically by gamma-irradiation and 3-aminobenzamine [PubChem=1645], an inhibitor of PARP1 [GeneID=142].
Full description | 3-Aminobenzamide (3AB) is an inhibitor of poly (ADP-ribose) polymerase (PARP), an enzyme implicated in the maintenance of genomic integrity, which is activated in response to radiation-induced DNA strand breaks. cDNA macroarray membranes containing 1536 clones were used to characterize the gene expression profiles displayed by mouse BALB/3T3 fibroblasts (A31 cell line) in response to ionizing irradiation alone or in combination with 3AB. A31 cells in exponential growth were pre-treated with 3AB 4mM 1h before gamma-irradiation (4Gy), remaining in culture during 6h until harvesting time. A31 cells treated with 3AB alone presented a down-regulation in genes involved in protein processing and cell cycle control, while an up-regulation of genes involved in apoptosis and related to DNA/RNA synthesis and repair was verified. A31 cells irradiated with 4Gy displayed 41 genes differentially expressed, being detected a down-regulation of genes involved in protein processing and apoptosis, and genes controlling the cell cycle. Concomitantly, another set of genes for protein processing and related to DNA/RNA synthesis and repair were found to be up-regulated. A positive or negative interaction effect between 3AB and radiation was verified for 29 known genes. While the combined treatment induced a synergistic effect on the expression of LCK proto-oncogene and several genes related to protein synthesis/processing, a negative interaction effect was found for the expression of genes related to cytoskeleton and extracellular matrix assembly (SATB1 and Anexin III), cell cycle control (tyrosine kinase), and genes participating in DNA/RNA synthesis and repair (RNA helicase, FLAP endonuclease-1, DNA-3 glycosylase methyladenine, splicing factor SC35 and Soh1). The present data open the possibility to investigate the direct participation of specific genes, or gene products acting in concert in the mechanism underlying the cell response to radiation-induced DNA damage under the influence of PARP inhibitor.

Standard name | MULLIGAN_NTF3_SIGNALING_VIA_INSR_AND_IGF1R_DN
Systematic name | M1660
Organism | Mus musculus
PMID | 12213819
Authors | Mulligan C,Rochford J,Denyer G,Stephens R,Yeo G,Freeman T,Siddle K,O'Rahilly S
Category | C2
Sub-category | CGP
Brief description | Genes similarly down-regulated in 3T3-L1 cells (fibroblasts able to differentiate to adipocytes) upon stimulation of INSR or IGFR1 by NTF3 [GeneID=3643;3480;4908].
Full description | Insulin and insulin-like growth factor-1 (IGF-1) act through highly homologous receptors that engage similar intracellular signaling pathways, yet these hormones serve largely distinct physiological roles in the control of metabolism and growth, respectively. In an attempt to uncover the molecular mechanisms underlying their divergent functions, we compared insulin receptor (IR) and IGF-1 receptor (IGF-1R) regulation of gene expression by microarray analysis, using 3T3-L1 cells expressing either TrkC/IR or TrkC/IGF-1R chimeric receptors to ensure the highly selective activation of each receptor tyrosine kinase. Following stimulation of the chimeric receptors for 4 h, we detected 11 genes to be differentially regulated, of which 10 were up-regulated to a greater extent by the IGF-1R. These included genes involved in adhesion, transcription, transport, and proliferation. The expression of mRNA encoding heparin-binding epidermal growth factor-like growth factor (HB-EGF), a potent mitogen, was markedly increased by IGF-1R but not IR activation. This effect was dependent on MAPK, but not phosphatidylinositol 3-kinase, and did not require an autocrine loop through the epidermal growth factor receptor. HB-EGF mitogenic activity was detectable in the medium of 3T3-L1 preadipocytes expressing activated IGF-1R but not IR, indicating that the transcriptional response is accompanied by a parallel increase in mature HB-EGF protein. The differential abilities of the IR and IGF-1R tyrosine kinases to stimulate the synthesis and release of a growth factor may provide, at least in part, an explanation for the greater role of the IGF-1R in the control of cellular proliferation.

Standard name | SASSON_FSH_RESPONSE
Systematic name | M1663
Organism | Rattus norvegicus
PMID | 12832290
Authors | Sasson R,Dantes A,Tajima K,Amsterdam A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in rFSH-17 cells (primary granulosa) after stimulation with FSH.
Full description | Follicle-stimulating hormone (FSH) controls the development of follicle-enclosed oocytes in the mammalian ovary by interacting with specific receptors located exclusively on granulosa cells. Its biological activity involves stimulation of intercellular communication, intracellular signaling, and up-regulation of steroidogenesis; the entire spectrum of genes regulated by FSH is not yet fully characterized. We have established monoclonal rat FSH-responsive granulosa cell lines that express FSH receptors at 20-fold higher rates than with primary cells, and thus increased the probability of yielding a distinct spectrum of genes modulated by FSH. Using Affymetrix DNA microarrays, we discovered 11 genes not reported earlier to be up-regulated by FSH and 9 genes not reported earlier to be down-regulated by FSH. Modulation of signal transduction associated with G-protein signaling, phosphorylation of proteins, and intracellular-extracellular ion balance was suggested by up-regulation of decay accelerating factor GPI-form precursor (DAF), membrane interacting protein RGS16, protein tyrosine phosphatase (PTPase), oxidative stress-inducible protein tyrosine phosphatase (OSIPTPase), and down-regulation of rat prostatic acid phosphatase (rPAP), Na+, K+-ATPase, and protein phosphatase 1beta. Elevation in granzyme-like proteins 1 and 3, and natural killer (NK) cell protease 1 (NKP-1) along with reduction in carboxypeptidase E indicates possible FSH-mediated preparation of the cells for apoptosis. Up-regulation of vascular endothelial growth factors indicates the ability of FSH to produce angiogenic factors upon their maturation; whereas, reduction in insulin-like growth factor binding protein (IGFBP3) indicates its increased potential to promote p53-induced apoptosis. Striking similarities in FSH modulation of gene expression were found in primary cultures of human granulosa cells obtained from IVF patients although these cells expressed only 1% of FSH receptor compared with immortalized rat cells, as indicated by microarray technique, which probably is in the normal range of expression of this receptor in nontransformed cells. These findings should increase our understanding of the mechanism of FSH action in stimulating development of the ovarian follicular cells, of intracellular and intercellular communication, and of increasing the potential of ovarian follicular cells to undergo apoptosis during the process of selection of the dominant follicle.

Standard name | CHEN_ETV5_TARGETS_TESTIS
Systematic name | M1664
Organism | Mus musculus
PMID | 16107850
Authors | Chen C,Ouyang W,Grigura V,Zhou Q,Carnes K,Lim H,Zhao GQ,Arber S,Kurpios N,Murphy TL,Cheng AM,Hassell JA,Chandrashekar V,Hofmann MC,Hess RA,Murphy KM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in testis from 4 week old ETV5 [GeneID=2119] knockout mice.
Full description | Division of spermatogonial stem cells produces daughter cells that either maintain their stem cell identity or undergo differentiation to form mature sperm. The Sertoli cell, the only somatic cell within seminiferous tubules, provides the stem cell niche through physical support and expression of surface proteins and soluble factors. Here we show that the Ets related molecule (ERM) is expressed exclusively within Sertoli cells in the testis and is required for spermatogonial stem cell self-renewal. Mice with targeted disruption of ERM have a loss of maintenance of spermatogonial stem cell self-renewal without a block in normal spermatogenic differentiation and thus have progressive germ-cell depletion and a Sertoli-cell-only syndrome. Microarray analysis of primary Sertoli cells from ERM-deficient mice showed alterations in secreted factors known to regulate the haematopoietic stem cell niche. These results identify a new function for the Ets family transcription factors in spermatogenesis and provide an example of transcriptional control of a vertebrate stem cell niche.

Standard name | ZHU_CMV_8_HR_UP
Systematic name | M4710
Organism | Homo sapiens
PMID | 9826724
Authors | Zhu H,Cong JP,Mamtora G,Gingeras T,Shenk T
Category | C2
Sub-category | CGP
Brief description | Up-regulated at 8 h following infection of primary human foreskin fibroblasts with CMV
Full description | Mechanistic insights to viral replication and pathogenesis generally have come from the analysis of viral gene products, either by studying their biochemical activities and interactions individually or by creating mutant viruses and analyzing their phenotype. Now it is possible to identify and catalog the host cell genes whose mRNA levels change in response to a pathogen. We have used DNA array technology to monitor the level of approximately 6,600 human mRNAs in uninfected as compared with human cytomegalovirus-infected cells. The level of 258 mRNAs changed by a factor of 4 or more before the onset of viral DNA replication. Several of these mRNAs encode gene products that might play key roles in virus-induced pathogenesis, identifying them as intriguing targets for further study.

Standard name | WELCSH_BRCA1_TARGETS_DN
Systematic name | M2428
Organism | Homo sapiens
PMID | 12032322
Authors | Welcsh PL,Lee MK,Gonzalez-Hernandez RM,Black DJ,Mahadevappa M,Swisher EM,Warrington JA,King MC
Category | C2
Sub-category | CGP
Brief description | Down-regulated by induction of exogenous BRCA1 in EcR-293 cells
Full description | Loss of function of BRCA1 caused by inherited mutation and tissue-specific somatic mutation leads to breast and ovarian cancer. Nearly all BRCA1 germ-line mutations involve truncation or loss of the C-terminal BRCT transcriptional activation domain, suggesting that transcriptional regulation is a critical function of the wild-type gene. The purpose of this project was to determine whether there is a link between the role of BRCA1 in transcriptional regulation and its role in tumor suppression. We developed a cell line (in which BRCA1 can be induced) and used microarray analysis to compare transcription profiles of epithelial cells with low endogenous levels of BRCA1 vs. transcription profiles of cells with 2-4-fold higher induced levels of expression of BRCA1. At these levels of expression, BRCA1 did not induce apoptosis. Undirected cluster analysis of six paired experiments revealed 373 genes, the expression of which was altered significantly and consistently by BRCA1 induction. Expression of 62 genes was altered more than 2-fold. BRCA1-regulated genes associated with breast tumorigenesis included the estrogen-responsive genes MYC and cyclin D1, which are overexpressed in many breast tumors; STAT1 and JAK1, key components of the cytokine signal transduction pathway; the extracellular matrix protein laminin 3A; ID4, an inhibitor of DNA-binding transcriptional activators, which in turn negatively regulates BRCA1 expression; and the prohormone stanniocalcin, expression of which is lost in breast tumor cells. Coordinated expression of BRCA1 with ID4 and with stanniocalcin was confirmed in primary breast and ovarian tumors.

Standard name | DASU_IL6_SIGNALING_SCAR_DN
Systematic name | M1711
Organism | Homo sapiens
PMID | 15095275
Authors | Dasu MR,Hawkins HK,Barrow RE,Xue H,Herndon DN
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hypertrophic scar fibroblasts in response to IL6 [GeneID=3569].
Full description | The structural rearrangement of collagen fibres in hypertrophic scar causes abnormal contracture, low tensile strength, and raised scars, which cause functional impairment and disfigurement. It is hypothesized that changes in the genes of cytokines, extracellular matrix proteins, and proteins regulating programmed cell death are related to hypertrophic scar formation. To test this hypothesis, fibroblasts were cultured from hypertrophic scars and their response to interleukin-6 (IL-6) stimulation was studied by defining their gene expression profiles. Affymetrix gene chip analysis was used to identify up- or down-regulation in the 12 625 genes present in the affymetrix array. RT-PCR and ELISA assays were used to validate microarray expression profiles further. Comparison of gene profiles showed an increase of 12 genes in hypertrophic scar fibroblasts compared with normal skin fibroblasts, while the expression of 14 genes decreased. Thirty-three genes were affected by IL-6 treatment in the hypertrophic scar fibroblasts, while 57 genes were affected in normal skin fibroblasts. Messenger RNA to beta-actin ratios for matrix metalloproteinase-1 (MMP-1) and MMP-3 were increased with IL-6 in normal skin fibroblasts from 2.43 +/- 0.06 to 5.50 +/- 0.45 and from 0.75 +/- 0.09 to 1.98 +/- 0.01, respectively. No change in these matrix metalloproteinases could be shown with IL-6 stimulation in hypertrophic scar fibroblasts. Secreted protein levels of pro-MMP-1 and MMP-3 were elevated in the supernatants from normal skin fibroblasts from 2.00 +/- 0.09 and 1.72 +/- 0.10 ng/ml to 4.60 +/- 0.12 and 3.41 +/- 0.20 ng/ml, respectively, after treatment with IL-6 (p < 0.05). No changes were observed in hypertrophic scar fibroblasts treated with IL-6. Values are means +/- SEM. The absence of any up-regulation of MMP-1 and MMP-3 in hypertrophic scar fibroblasts, in response to IL-6, suggests that suppression of matrix metalloproteinases may play a role in the excessive accumulation of collagen formed in hypertrophic scars. While the pathogenesis of abnormal hypertrophic scars remains poorly understood, the use of gene expression arrays may prove helpful in identifying the mechanisms responsible for this type of abnormal scar formation and in formulating an effective therapeutic protocol.

Standard name | JIANG_AGING_CEREBRAL_CORTEX_DN
Systematic name | M1665
Organism | Mus musculus
PMID | 11172053
Authors | Jiang CH,Tsien JZ,Schultz PG,Hu Y
Category | C2
Sub-category | CGP
Brief description | Down-regulated in the cerebral cortex of aged (22 months) BALB/c mice, compared to young (2 months) controls
Full description | A better understanding of the molecular effects of aging in the brain may help to reveal important aspects of organismal aging, as well as processes that lead to age-related brain dysfunction. In this study, we have examined differences in gene expression in the hypothalamus and cortex of young and aged mice by using high-density oligonucleotide arrays. A number of key genes involved in neuronal structure and signaling are differentially expressed in both the aged hypothalamus and cortex, including synaptotagmin I, cAMP-dependent protein kinase C beta, apolipoprotein E, protein phosphatase 2A, and prostaglandin D. Misregulation of these proteins may contribute to age-related memory deficits and neurodegenerative diseases. In addition, many proteases that play essential roles in regulating neuropeptide metabolism, amyloid precursor protein processing, and neuronal apoptosis are up-regulated in the aged brain and likely contribute significantly to brain aging. Finally, a subset of these genes whose expression is affected by aging are oppositely affected by exposure of mice to an enriched environment, suggesting that these genes may play important roles in learning and memory.

Standard name | MARTINEZ_RESPONSE_TO_TRABECTEDIN_DN
Systematic name | M15123
Organism | Homo sapiens
PMID | 15897246
Authors | Martínez N,Sánchez-Beato M,Carnero A,Moneo V,Tercero JC,Fernández I,Navarrete M,Jimeno J,Piris MA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in at least 8 of 11 sarcoma cell lines by trabectedin [PubChem=3199].
Full description | Ecteinascidin 743 (ET-743; Yondelis, Trabectedin) is a marine anticancer agent that induces long-lasting objective remissions and tumor control in a subset of patients with pretreated/resistant soft-tissue sarcoma. Drug-induced tumor control is achievable in 22% of such patients, but there is no clear indication of the molecular features correlated with clinical sensitivity/resistance to ET-743. Nine low-passage, soft-tissue sarcoma cell lines, explanted from chemo-naive patients with different patterns of sensitivity, have been profiled with a cDNA microarray containing 6,700 cancer-related genes. The molecular signature of these cell lines was analyzed at baseline and at four different times after ET-743 exposure. The association of levels of TP53 mutation and TP73 expression with ET-743 sensitivity and cell cycle kinetics after treatment was also analyzed. Gene expression profile analysis revealed up-regulation of 86 genes and down-regulation of 244 genes in response to ET-743. The ET-743 gene expression signature identified a group of genes related with cell cycle control, stress, and DNA-damage response (JUNB, ATF3, CS-1, SAT, GADD45B, and ID2) that were up-regulated in all the cell lines studied. The transcriptional signature 72 hours after ET-743 administration, associated with ET-743 sensitivity, showed a more efficient induction of genes involved in DNA-damage response and apoptosis, such as RAD17, BRCA1, PAR4, CDKN1A, and P53DINP1, in the sensitive cell line group. The transcriptional signature described here may lead to the identification of ET-743 downstream mediators and transcription regulators and the proposal of strategies by which ET-743-sensitive tumors may be identified.

Standard name | BURTON_ADIPOGENESIS_9
Systematic name | M1666
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Strongly down-regulated at 8-96 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | URS_ADIPOCYTE_DIFFERENTIATION_DN
Systematic name | M18395
Organism | Homo sapiens
PMID | 15051823
Authors | Urs S,Smith C,Campbell B,Saxton AM,Taylor J,Zhang B,Snoddy J,Jones Voy B,Moustaid-Moussa N
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary adipocytes compared to preadipocytes.
Full description | Uncontrolled expansion of adipose tissue leads to obesity, a public health epidemic affecting >30% of adult Americans. Adipose mass increases in part through the recruitment and differentiation of an existing pool of preadipocytes (PA) into adipocytes (AD). Most studies investigating adipogenesis used primarily murine cell lines; much less is known about the relevant processes that occur in humans. Therefore, characterization of genes associated with adipocyte development is key to understanding the pathogenesis of obesity and developing treatments for this disorder. To address this issue, we performed large-scale analyses of human adipose gene expression using microarray technology. Differential gene expression between PA and AD was analyzed in 6 female patients using human cDNA microarray slides and data analyzed using the Stanford Microarray Database. Statistical analysis for the gene expression was performed using the SAS mixed models. Compared with PA, several genes involved in lipid metabolism were overexpressed in AD, including fatty acid binding protein, adipose differentiation-related protein, lipoprotein lipase, perilipin, and adipose most abundant transcript 1. Novel genes expressed in adipocytes included E2F5 transcriptional factor and SMARC (SWI/SNF-related, matrix associated, actin-dependent regulator of chromatin). PA predominantly expressed genes encoding extracellular matrix components such as fibronectin, matrix metalloprotein, and novel proteins such as lysyl oxidase. Despite the high differential expression of some of these genes, many did not differ significantly likely due to high variability and limited statistical power. A comprehensive list of differential gene expression is presented according to cellular function. In conclusion, these studies offer an overview of the gene expression profiles in PA and AD and identify new genes with potentially important functions in adipose tissue development and obesity that merit further investigation.

Standard name | VISALA_RESPONSE_TO_HEAT_SHOCK_AND_AGING_DN
Systematic name | M1667
Organism | Homo sapiens
PMID | 12618007
Authors | Visala Rao D,Boyle GM,Parsons PG,Watson K,Jones GL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated after heat shock in peripheral lympocytes from old donors, compared to those from the young ones.
Full description | Ageing results in a progressive, intrinsic and generalised imbalance of the control of regulatory systems. A key manifestation of this complex biological process includes the attenuation of the universal stress response. Here we provide the first global assessment of the ageing process as it affects the heat shock response, utilising human peripheral lymphocytes and cDNA microarray analysis. The genomic approach employed in our preliminary study was supplemented with a proteomic approach. In addition, the current study correlates the in vivo total antioxidant status with the age-related differential gene expression as well as the translational kinetics of heat shock proteins (hsps). Most of the genes encoding stress response proteins on the 4224 element microarray used in this study were significantly elevated after heat shock treatment of lymphocytes obtained from both young and old individuals albeit to a greater extent in the young. Cell signaling and signal transduction genes as well as some oxidoreductases showed varied response. Results from translational kinetics of induction of major hsps, from 0 to 24 h recovery period were broadly consistent with the differential expression of HSC 70 and HSP 40 genes. Total antioxidant levels in plasma from old individuals were found to be significantly lower by comparison with young, in agreement with the widely acknowledged role of oxidant homeostasis in the ageing process.

Standard name | BROWNE_HCMV_INFECTION_12HR_DN
Systematic name | M5775
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 12 h time point that were not down-regulated at the previous time point, 10 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | MAHAJAN_RESPONSE_TO_IL1A_UP
Systematic name | M6154
Organism | Homo sapiens
PMID | 12091409
Authors | Mahajan VB,Wei C,McDonnell PJ 3rd
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in corneal fibroblasts after treatment with IL1A [GeneID=3552].
Full description | PURPOSE: To identify changes in gene expression in human corneal fibroblasts after exposure to interleukin-1alpha. METHODS: RNA was isolated from cultured human corneal fibroblasts after treatment with interleukin-1alpha and subjected to DNA microarray analysis. Changes in gene expression were determined by comparison with untreated cells in three independent experiments after a Bayesian statistical analysis of variance. RESULTS: Changes in gene expression were reproducibly observed in 165 genes representing previously identified and novel chemokines, matrix molecules, membrane receptors, angiogenic mediators, and transcription factors that correlated with pathophysiological responses to inflammation. Dramatic increases in gene expression were observed with exodus-1 (CCL20), MMP-12, and RhoA. CONCLUSIONS: DNA microarray analysis of the corneal fibroblast response to interleukin-1alpha provides important insight into modeling changes in gene expression and suggests novel therapeutic targets for the control of corneal inflammation.

Standard name | JIANG_AGING_HYPOTHALAMUS_UP
Systematic name | M1668
Organism | Mus musculus
PMID | 11172053
Authors | Jiang CH,Tsien JZ,Schultz PG,Hu Y
Category | C2
Sub-category | CGP
Brief description | Up-regulated in the hypothalamus of aged (22 months) BALB/c mice, compared to young (2 months) controls
Full description | A better understanding of the molecular effects of aging in the brain may help to reveal important aspects of organismal aging, as well as processes that lead to age-related brain dysfunction. In this study, we have examined differences in gene expression in the hypothalamus and cortex of young and aged mice by using high-density oligonucleotide arrays. A number of key genes involved in neuronal structure and signaling are differentially expressed in both the aged hypothalamus and cortex, including synaptotagmin I, cAMP-dependent protein kinase C beta, apolipoprotein E, protein phosphatase 2A, and prostaglandin D. Misregulation of these proteins may contribute to age-related memory deficits and neurodegenerative diseases. In addition, many proteases that play essential roles in regulating neuropeptide metabolism, amyloid precursor protein processing, and neuronal apoptosis are up-regulated in the aged brain and likely contribute significantly to brain aging. Finally, a subset of these genes whose expression is affected by aging are oppositely affected by exposure of mice to an enriched environment, suggesting that these genes may play important roles in learning and memory.

Standard name | KYNG_RESPONSE_TO_H2O2
Systematic name | M1671
Organism | Homo sapiens
PMID | 12606941
Authors | Kyng KJ,May A,Brosh RM Jr,Cheng WH,Chen C,Becker KG,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in response to hydrogen peroxide [PubChem=784] in CS-B cells (Cockayne syndrome fibroblast, CS) expressing ERCC6 [GeneID=2074] off a plasmid vector.
Full description | Cockayne syndrome (CS) is a human hereditary disease belonging to the group of segmental progerias, and the clinical phenotype is characterized by postnatal growth failure, neurological dysfunction, cachetic dwarfism, photosensitivity, sensorineural hearing loss, and retinal degradation. CS-B cells are defective in transcription-coupled DNA repair, base excision repair, transcription, and chromatin structural organization. Using array analysis, we have examined the expression profile in CS complementation group B (CS-B) fibroblasts after exposure to oxidative stress (H2O2) before and after complete complementation with the CSB gene. The following isogenic cell lines were compared: CS-B cells (CS-B null), CS-B cells complemented with wild-type CSB (CS-B wt), and a stably transformed cell line with a point mutation in the ATPase domain of CSB (CS-B ATPase mutant). In the wt rescued cells, we detected significant induction (two-fold) of 112 genes out of the 6912 analysed. The patterns suggested an induction or upregulation of genes involved in several DNA metabolic processes including DNA repair, transcription, and signal transduction. In both CS-B mutant cell lines, we found a general deficiency in transcription after oxidative stress, suggesting that the CSB protein influenced the regulation of transcription of certain genes. Of the 6912 genes, 122 were differentially regulated by more than two-fold. Evidently, the ATPase function of CSB is biologically important as the deficiencies seen in the ATPase mutant cells are very similar to those observed in the CS-B-null cells. Some major defects are in the transcription of genes involved in DNA repair, signal transduction, and ribosomal functions.

Standard name | DAZARD_UV_RESPONSE_CLUSTER_G2
Systematic name | M5622
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Cluster G2: genes increasingly up-regulated in NHEK cells (normal keratinocyte) and reaching maximum levels at 12 h and 24 h after UV-B irradiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | VERRECCHIA_RESPONSE_TO_TGFB1_C3
Systematic name | M5321
Organism | Homo sapiens
PMID | 11279127
Authors | Verrecchia F,Chu ML,Mauviel A
Category | C2
Sub-category | CGP
Brief description | Cluster 3: ECM related genes up-regulated in dermal fibroblasts within 30 min after TGFB1 [GeneID=7040] addition; returned rapidly to basal level after that.
Full description | Despite major advances in the understanding of the intimate mechanisms of transforming growth factor-beta (TGF-beta) signaling through the Smad pathway, little progress has been made in the identification of direct target genes. In this report, using cDNA microarrays, we have focussed our attention on the characterization of extracellular matrix-related genes rapidly induced by TGF-beta in human dermal fibroblasts and attempted to identify the ones whose up-regulation by TGF-beta is Smad-mediated. For a gene to qualify as a direct Smad target, we postulated that it had to meet the following criteria: (1) rapid (30 min) and significant (at least 2-fold) elevation of steady-state mRNA levels upon TGF-beta stimulation, (2) activation of the promoter by both exogenous TGF-beta and co-transfected Smad3 expression vector, (3) up-regulation of promoter activity by TGF-beta blocked by both dominant-negative Smad3 and inhibitory Smad7 expression vectors, and (4) promoter transactivation by TGF-beta not possible in Smad3(-/-) mouse embryo fibroblasts. Using this stringent approach, we have identified COL1A2, COL3A1, COL6A1, COL6A3, and tissue inhibitor of metalloproteases-1 as definite TGF-beta/Smad3 targets. Extrapolation of this approach to other extracellular matrix-related gene promoters also identified COL1A1 and COL5A2, but not COL6A2, as novel Smad targets. Together, these results represent a significant step toward the identification of novel, early-induced Smad-dependent TGF-beta target genes in fibroblasts.

Standard name | WESTON_VEGFA_TARGETS_3HR
Systematic name | M1673
Organism | Homo sapiens
PMID | 12200464
Authors | Weston GC,Haviv I,Rogers PA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MMEC cells (myometrial endothelium) at 3 h after VEGFA [GeneID=7422] stimulation.
Full description | There is evidence that the vasculature of different organs display different functional characteristics in response to cytokines and growth factors. The aim of this study was to use cDNA gene expression microarray to analyse changes in gene expression following stimulation of myometrial microvascular endothelial cells (MMECs) with vascular endothelial growth factor (VEGF). Primary isolates of MMECs were obtained from fresh hysterectomy specimens and purified with magnetic beads. Cells were stimulated with 15 ng/ml VEGF for 3, 6 and 12 h, and two unstimulated experiments served as controls. A total of six arrays was performed over these time-points. A total of 110 genes were identified as up-regulated by VEGF, 19% of which (21 genes) have previously been reported as up-regulated by VEGF or by angiogenesis. Among the novel genes to be up-regulated by VEGF were brain-derived growth factor, oxytocin receptor and estrogen sulphotransferase. The significance of the genes identified in the physiological and pathological functioning of the myometrial vasculature is discussed.

Standard name | TSENG_ADIPOGENIC_POTENTIAL_UP
Systematic name | M75
Organism | Mus musculus
PMID | 15895078
Authors | Tseng YH,Butte AJ,Kokkotou E,Yechoor VK,Taniguchi CM,Kriauciunas KM,Cypess AM,Niinobe M,Yoshikawa K,Patti ME,Kahn CR
Category | C2
Sub-category | CGP
Brief description | Genes showing increasing expression in brown preadipocytes with decreasing ability of the cells to differentiate.
Full description | The insulin/IGF-1 (insulin-like growth factor 1) signalling pathway promotes adipocyte differentiation via complex signalling networks. Here, using microarray analysis of brown preadipocytes that are derived from wild-type and insulin receptor substrate (Irs) knockout animals that exhibit progressively impaired differentiation, we define 374 genes/expressed-sequence tags whose expression in preadipocytes correlates with the ultimate ability of the cells to differentiate. Many of these genes, including preadipocyte factor-1 (Pref-1) and multiple members of the Wnt signalling pathway, are related to early adipogenic events. Necdin is also markedly increased in Irs knockout cells that cannot differentiate, and knockdown of necdin restores brown adipogenesis with downregulation of Pref-1 and Wnt10a expression. Insulin receptor substrate proteins regulate a necdin-E2F4 interaction that represses peroxisome-proliferator-activated receptor gamma (PPARgamma) transcription via a cyclic AMP response element binding protein (CREB)-dependent pathway. Together these define a key signalling network that is involved in brown preadipocyte determination.

Standard name | JOSEPH_RESPONSE_TO_SODIUM_BUTYRATE_UP
Systematic name | M1674
Organism | Homo sapiens
PMID | 15318170
Authors | Joseph J,Mudduluru G,Antony S,Vashistha S,Ajitkumar P,Somasundaram K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in H460 cells (non-small cell lung carcinoma, NSCLC) after treatment with sodium butyrate [PubChem=5222465].
Full description | Histone deacetylase (HDAC) inhibitors induce growth arrest and apoptosis in a variety of human cancer cells. Sodium butyrate (NaB), a short chain fatty acid, is a HDAC inhibitor and is produced in the colonic lumen as a consequence of microbial degradation of dietary fibers. In order to dissect out the mechanism of NaB-induced growth inhibition of cancer cells, we carried out expression profiling of a human lung carcinoma cell line (H460) treated with NaB using a cDNA microarray. Of the total 1728 genes analysed, there were 32 genes with a mean expression value of 2.0-fold and higher and 66 genes with a mean expression value 3.0-fold and lower in NaB-treated cells. For a few selected genes, we demonstrate that their expression pattern by semiquantitative reverse transcription-polymerase chain reaction (RT-PCR) analysis is matching with the results obtained by microarray analysis. Closer view at the expression profile of NaB-treated cells revealed the downregulation of a total of 16 genes associated with cytokine signaling, in particular, interferon gamma (IFNgamma) pathway. In good correlation, NaB-pretreated cells failed to induce interferon regulatory factor 1, an INFgamma target gene, efficiently upon IFNgamma addition. These results suggest that NaB inhibits proinflammatory cytokine signaling pathway, thus providing proof of mechanism for its anti-inflammatory activity. We also found that NaB induced three genes, which are known metastatic suppressors, and downregulated 11 genes, which have been shown to promote metastasis. Upregulation of metastatic suppressor Kangai 1 (KAI1) by NaB in a time-dependent manner was confirmed by RT-PCR analysis. The differential regulation of metastasis-associated genes by NaB provides explanation for the anti-invasive properties of NaB. Therefore, our study presents new evidence for pathways regulated by NaB, thus providing evidence for the mechanism behind anti-inflammatory and antimetastatic activities of NaB.

Standard name | MCLACHLAN_DENTAL_CARIES_UP
Systematic name | M10454
Organism | Homo sapiens
PMID | 15869869
Authors | McLachlan JL,Smith AJ,Bujalska IJ,Cooper PR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pulpal tissue extracted from carious teeth.
Full description | High-throughput characterisation of the molecular response of pulpal tissue under carious lesions may contribute to improved future diagnosis and treatment. To identify genes associated with this process, oligonucleotide microarrays containing approximately 15,000 human sequences were screened using pooled total RNA isolated from pulpal tissue from both healthy and carious teeth. Data analysis identified 445 genes with 2-fold or greater difference in expression level, with 85 more abundant in health and 360 more abundant in disease. Subsequent gene ontological grouping identified a variety of processes and functions potentially activated or down-modulated during caries. Validation of microarray results was obtained by a combination of real-time and semi-quantitative PCR for selected genes, confirming down-regulation of Dentin Matrix Protein-1 (DMP-1), SLIT 2, Period-2 (PER 2), Period-3 (PER 3), osteoadherin, Glypican-3, Midkine, activin receptor interacting protein-1 (AIP 1), osteoadherin and growth hormone receptor (GHR), and up-regulation of Adrenomedullin (ADM), Interleukin-11 (IL-11), Bone sialoprotein (BSP), matrix Gla protein (MGP), endothelial cell growth factor-1 (ECGF 1), inhibin beta A and orosomucoid-1 (ORM 1), in diseased pulp. Real-time PCR analyses of ADM and DMP-1 in a panel of healthy and carious pulpal tissue and also in immune system cells highlighted the heterogeneity of caries and indicated increased expression of ADM in neutrophils activated by bacterial products. In contrast, DMP-1 was predominantly expressed by cells native to healthy pulpal tissue. This study has greatly extended our molecular knowledge of dental tissue disease and identified involvement of genes previously unassociated with this process.

Standard name | GERHOLD_ADIPOGENESIS_UP
Systematic name | M1675
Organism | Mus musculus
PMID | 12021175
Authors | Gerhold DL,Liu F,Jiang G,Li Z,Xu J,Lu M,Sachs JR,Bagchi A,Fridman A,Holder DJ,Doebber TW,Berger J,Elbrecht A,Moller DE,Zhang BB
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated during differentiation of 3T3-L1 cells (fibroblast) into adipocytes in response to adipogenic hormones.
Full description | PPAR gamma is an adipocyte-specific nuclear hormone receptor. Agonists of PPAR gamma, such as thiazolidinediones (TZDs), promote adipocyte differentiation and have insulin-sensitizing effects in animals and diabetic patients. Affymetrix oligonucleotide arrays representing 6347 genes were employed to profile the gene expression responses of mature 3T3-L1 adipocytes and differentiating preadipocytes to a TZD PPAR gamma agonist in vitro. The expression of 579 genes was significantly up- or down-regulated by more than 1.5-fold during differentiation and/or by treatment with TZD, and these genes were organized into 32 clusters that demonstrated concerted changes in expression of genes controlling cell growth or lipid metabolism. Quantitative PCR was employed to further characterize gene expression and led to the identification of beta-catenin as a new PPAR gamma target gene. Both mRNA and protein levels for beta-catenin were down-regulated in 3T3-L1 adipocytes compared with fibroblasts and were further decreased by treatment of adipocytes with PPAR gamma agonists. Treatment of db/db mice with a PPAR gamma agonist also resulted in reduction of beta-catenin mRNA levels in adipose tissue. These results suggest that beta-catenin plays an important role in the regulation of adipogenesis. Thus, the transcriptional patterns revealed in this study further the understanding of adipogenesis process and the function of PPAR gamma activation.

Standard name | WENG_POR_TARGETS_LIVER_DN
Systematic name | M1677
Organism | Mus musculus
PMID | 16006652
Authors | Weng Y,DiRusso CC,Reilly AA,Black PN,Ding X
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in liver from mice with liver specific knockout of POR [GeneID=5447].
Full description | NADPH-cytochrome P450 reductase (CPR) is an essential component for the function of many enzymes, including microsomal cytochrome P450 (P450) monooxygenases and heme oxygenases. In liver-Cpr-null (with liver-specific Cpr deletion) and Cpr-low (with reduced CPR expression in all organs examined) mouse models, a reduced serum cholesterol level and an induction of hepatic P450s were observed, whereas hepatomegaly and fatty liver were only observed in the liver-Cpr-null model. Our goal was to identify hepatic gene expression changes related to these phenotypes. Cpr-lox mice (with a floxed Cpr gene and normal CPR expression) were used as the control. Through microarray analysis, we identified many genes that were differentially expressed among the three groups of mice. We also recognized the 12 gene ontology terms that contained the most significantly changed gene expression in at least one of the two mouse models. We further uncovered potential mechanisms, such as an increased activation of constitutive androstane receptor and a decreased activation of peroxisomal proliferator-activated receptor-alpha by precursors of cholesterol biosynthesis, that underlie common changes (e.g. induction of multiple P450s and suppression of genes for fatty acid metabolism) in response to CPR loss in the two mouse models. Additionally, we observed model-specific gene expression changes, such as the induction of a fatty-acid translocase (Cd36 antigen) and the suppression of carnitine O-palmitoyltransferase 1 (Cpt1a) and acyl-CoA synthetase long chain family member 1 (Acsl1), that are potentially responsible for the severe hepatic lipidosis and an altered fatty acid profile observed in liver-Cpr-null mice.

Standard name | SU_PLACENTA
Systematic name | M6349
Organism | Homo sapiens
PMID | 11904358
Authors | Su AI,Cooke MP,Ching KA,Hakak Y,Walker JR,Wiltshire T,Orth AP,Vega RG,Sapinoso LM,Moqrich A,Patapoutian A,Hampton GM,Schultz PG,Hogenesch JB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated specifically in human placenta.
Full description | High-throughput gene expression profiling has become an important tool for investigating transcriptional activity in a variety of biological samples. To date, the vast majority of these experiments have focused on specific biological processes and perturbations. Here, we have generated and analyzed gene expression from a set of samples spanning a broad range of biological conditions. Specifically, we profiled gene expression from 91 human and mouse samples across a diverse array of tissues, organs, and cell lines. Because these samples predominantly come from the normal physiological state in the human and mouse, this dataset represents a preliminary, but substantial, description of the normal mammalian transcriptome. We have used this dataset to illustrate methods of mining these data, and to reveal insights into molecular and physiological gene function, mechanisms of transcriptional regulation, disease etiology, and comparative genomics. Finally, to allow the scientific community to use this resource, we have built a free and publicly accessible website (http://expression.gnf.org) that integrates data visualization and curation of current gene annotations.

Standard name | BURTON_ADIPOGENESIS_6
Systematic name | M1678
Organism | Mus musculus
PMID | 15033539
Authors | Burton GR,Nagarajan R,Peterson CA,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Strongly up-regulated at 96 h during differentiation of 3T3-L1 cells (fibroblast) into adipocytes.
Full description | During cellular differentiation and development, it is recognized that many complex molecular mechanisms as well as precise patterns of differentially expressed genes occur in directing precursor cells toward a given lineage. Using microarray-based technology, we examined gene expression across the course of 3T3-L1 adipocyte differentiation. Total cellular RNA was isolated at times 0, 2, 8, 16, 24, 48, and 96 h following treatment with either standard hormonal inducers of differentiation; insulin, dexamethasone, isobutylmethylxanthine (IDX), or IDX plus trichostatin A (TsA), a histone deacetylase inhibitor and potent adipogenic inhibitor. cRNA was synthesized from cellular RNA and hybridized to high density Affymetrix MG_U74Av2 microarray gene chips containing 12,488 cDNA/Expressed Sequence Tags (ESTs) probe sets. From the IDX-only treated cells, all probe sets that were either unchanged or differentially expressed less than 2-fold throughout differentiation with respect to time 0 preadipocytes were excluded from further analyses. This selection resulted in a net of 1686 transcripts, 859 were increased in expression, and 827 were decreased in expression at least 2-fold across differentiation. To focus in on genes that were more specific to differentiation, the same analysis was performed on IDX plus TsA-treated non-differentiating cells and all probe sets from the IDX-only group that exhibited similar expression profiles in the non-differentiating TsA-treated group were excluded leaving a total of 1016 transcripts that were regulated only under differentiating conditions. Six hundred and thirty-six of these transcripts were elevated at least 2-fold and 380 exhibited a decrease in expression relative to time 0 preadipocytes. This group of genes was further analyzed using hierarchical clustering and self-organizing maps and resulted in the identification of numerous genes not previously known to be regulated during adipocyte differentiation. Many of these genes may well represent novel adipogenic mediators and markers of adipogenesis.

Standard name | SUZUKI_RESPONSE_TO_TSA
Systematic name | M1680
Organism | Homo sapiens
PMID | 11992124
Authors | Suzuki H,Gabrielson E,Chen W,Anbazhagan R,van Engeland M,Weijenberg MP,Herman JG,Baylin SB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by TSA alone [PubChem=5562], with non-hypermethylated promoters, in RKO cells (colorectal cancer).
Full description | Aberrant hypermethylation of gene promoters is a major mechanism associated with inactivation of tumor-suppressor genes in cancer. We previously showed this transcriptional silencing to be mediated by both methylation and histone deacetylase activity, with methylation being dominant. Here, we have used cDNA microarray analysis to screen for genes that are epigenetically silenced in human colorectal cancer. By screening over 10,000 genes, we show that our approach can identify a substantial number of genes with promoter hypermethylation in a given cancer; these are distinct from genes with unmethylated promoters, for which increased expression is produced by histone deacetylase inhibition alone. Many of the hypermethylated genes we identified have high potential for roles in tumorigenesis by virtue of their predicted function and chromosome position. We also identified a group of genes that are preferentially hypermethylated in colorectal cancer and gastric cancer. One of these genes, SFRP1, belongs to a gene family; we show that hypermethylation of four genes in this family occurs very frequently in colorectal cancer, providing for (i) a unique potential mechanism for loss of tumor-suppressor gene function and (ii) construction of a molecular marker panel that could detect virtually all colorectal cancer.

Standard name | BURTON_ADIPOGENESIS_PEAK_AT_16HR
Systematic name | M1681
Organism | Mus musculus
PMID | 12137940
Authors | Burton GR,Guan Y,Nagarajan R,McGehee RE Jr
Category | C2
Sub-category | CGP
Brief description | Cluster 4: genes maximally expressed at 16 h time point during differentiation of 3T3-L1 fibroblasts into adipocytes in response to adipogenic hormones.
Full description | The molecular mechanisms that regulate cellular differentiation during development and throughout life are complex. It is now recognized that precise patterns of differentially expressed genes ultimately direct a particular cell toward a given lineage and many of these are regulated during the earliest stages of differentiation. Using a microarray-based expression analysis, we have examined gene expression profiles during the first 24 h of 3T3-L1 adipocyte differentiation. RNA was isolated at times 0, 2, 8, 16, and 24 h following stimulation of differentiation and hybridized in duplicate to high density Affymetrix microarray gene chips containing a series of 13,179 cDNA/expressed sequence tag (EST) probe sets. Two hundred and eighty-five cDNA/ESTs were shown to have at least a fivefold change in expression levels during this time course and both hierarchical and self-organizing map clustering analysis was performed to categorize them by expression profiles. Several genes known to be regulated during this time period were confirmed and Western blot analysis of the proteins encoded by some of the identified genes revealed expression profiles similar to their mRNA counterparts. As expected, many of the genes identified have not been examined in such a critical time period during adipogenesis and may well represent novel adipogenic mediators.

Standard name | MARCHINI_TRABECTEDIN_RESISTANCE_DN
Systematic name | M8349
Organism | Homo sapiens
PMID | 15661559
Authors | Marchini S,Marrazzo E,Bonomi R,Chiorino G,Zaffaroni M,Weissbach L,Hornicek FJ,Broggini M,Faircloth GT,D'Incalci M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in chondrosarcoma and ovarian carcinoma cell lines which developed resistance to trabectedin [PubChem=3199].
Full description | ET-743 (Yondelis(TM), Trabectedin) isolated from the tunicate Ecteinascidia turbinata, is being tested in phase II clinical trials in Europe and the United States of America (USA). Studies with different solid tumours have shown antitumour activity in advanced, pre-treated sarcomas as well as in drug-resistant breast and ovarian cancer. The primary mechanism of action for ET-743 has not been fully elucidated and different models have been suggested to explain its molecular mechanism of action. ET-743 binds tightly to the minor groove of DNA and previous data have suggested that ET-743 acts by interfering with RNA transcription. To further investigate the mechanism of in vitro drug resistance, we evaluated the gene expression profile in ovarian and chondrosarcoma cell lines selected for resistance to ET-743. We found 70 genes whose expression was modulated in both drug-resistant cell lines when compared with their respective parental drug-sensitive cell lines. This pattern of gene expression seems to be selective for ET-743-resistant cells, since ovarian cancer cells resistant to paclitaxel did not share the same gene expression changes. Data presented in this study reveal different molecular pathways that could be involved in the cellular mechanism of ET-743 resistance.

Standard name | BILD_MYC_ONCOGENIC_SIGNATURE
Systematic name | M2069
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Genes selected in supervised analyses to discriminate cells expressing c-Myc [GeneID=4609] from control cells expressing GFP.
Full description | The development of an oncogenic state is a complex process involving the accumulation of multiple independent mutations that lead to deregulation of cell signalling pathways central to the control of cell growth and cell fate. The ability to define cancer subtypes, recurrence of disease and response to specific therapies using DNA microarray-based gene expression signatures has been demonstrated in multiple studies. Various studies have also demonstrated the potential for using gene expression profiles for the analysis of oncogenic pathways. Here we show that gene expression signatures can be identified that reflect the activation status of several oncogenic pathways. When evaluated in several large collections of human cancers, these gene expression signatures identify patterns of pathway deregulation in tumours and clinically relevant associations with disease outcomes. Combining signature-based predictions across several pathways identifies coordinated patterns of pathway deregulation that distinguish between specific cancers and tumour subtypes. Clustering tumours based on pathway signatures further defines prognosis in respective patient subsets, demonstrating that patterns of oncogenic pathway deregulation underlie the development of the oncogenic phenotype and reflect the biology and outcome of specific cancers. Predictions of pathway deregulation in cancer cell lines are also shown to predict the sensitivity to therapeutic agents that target components of the pathway. Linking pathway deregulation with sensitivity to therapeutics that target components of the pathway provides an opportunity to make use of these oncogenic pathway signatures to guide the use of targeted therapeutics.

Standard name | BILD_E2F3_ONCOGENIC_SIGNATURE
Systematic name | M13061
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Genes selected in supervised analyses to discriminate cells expressing E2F3 [GeneID=1871] from control cells expressing GFP.
Full description | The development of an oncogenic state is a complex process involving the accumulation of multiple independent mutations that lead to deregulation of cell signalling pathways central to the control of cell growth and cell fate. The ability to define cancer subtypes, recurrence of disease and response to specific therapies using DNA microarray-based gene expression signatures has been demonstrated in multiple studies. Various studies have also demonstrated the potential for using gene expression profiles for the analysis of oncogenic pathways. Here we show that gene expression signatures can be identified that reflect the activation status of several oncogenic pathways. When evaluated in several large collections of human cancers, these gene expression signatures identify patterns of pathway deregulation in tumours and clinically relevant associations with disease outcomes. Combining signature-based predictions across several pathways identifies coordinated patterns of pathway deregulation that distinguish between specific cancers and tumour subtypes. Clustering tumours based on pathway signatures further defines prognosis in respective patient subsets, demonstrating that patterns of oncogenic pathway deregulation underlie the development of the oncogenic phenotype and reflect the biology and outcome of specific cancers. Predictions of pathway deregulation in cancer cell lines are also shown to predict the sensitivity to therapeutic agents that target components of the pathway. Linking pathway deregulation with sensitivity to therapeutics that target components of the pathway provides an opportunity to make use of these oncogenic pathway signatures to guide the use of targeted therapeutics.

Standard name | BILD_HRAS_ONCOGENIC_SIGNATURE
Systematic name | M12029
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Genes selected in supervised analyses to discriminate cells expressing activated HRAS [GeneID=3265] oncogene from control cells expressing GFP.
Full description | The development of an oncogenic state is a complex process involving the accumulation of multiple independent mutations that lead to deregulation of cell signalling pathways central to the control of cell growth and cell fate. The ability to define cancer subtypes, recurrence of disease and response to specific therapies using DNA microarray-based gene expression signatures has been demonstrated in multiple studies. Various studies have also demonstrated the potential for using gene expression profiles for the analysis of oncogenic pathways. Here we show that gene expression signatures can be identified that reflect the activation status of several oncogenic pathways. When evaluated in several large collections of human cancers, these gene expression signatures identify patterns of pathway deregulation in tumours and clinically relevant associations with disease outcomes. Combining signature-based predictions across several pathways identifies coordinated patterns of pathway deregulation that distinguish between specific cancers and tumour subtypes. Clustering tumours based on pathway signatures further defines prognosis in respective patient subsets, demonstrating that patterns of oncogenic pathway deregulation underlie the development of the oncogenic phenotype and reflect the biology and outcome of specific cancers. Predictions of pathway deregulation in cancer cell lines are also shown to predict the sensitivity to therapeutic agents that target components of the pathway. Linking pathway deregulation with sensitivity to therapeutics that target components of the pathway provides an opportunity to make use of these oncogenic pathway signatures to guide the use of targeted therapeutics.

Standard name | BILD_SRC_ONCOGENIC_SIGNATURE
Systematic name | M116
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Genes selected in supervised analyses to discriminate cells expressing c-Src (CSK) [GeneID=1445] from control cells expressing GFP.
Full description | The development of an oncogenic state is a complex process involving the accumulation of multiple independent mutations that lead to deregulation of cell signalling pathways central to the control of cell growth and cell fate. The ability to define cancer subtypes, recurrence of disease and response to specific therapies using DNA microarray-based gene expression signatures has been demonstrated in multiple studies. Various studies have also demonstrated the potential for using gene expression profiles for the analysis of oncogenic pathways. Here we show that gene expression signatures can be identified that reflect the activation status of several oncogenic pathways. When evaluated in several large collections of human cancers, these gene expression signatures identify patterns of pathway deregulation in tumours and clinically relevant associations with disease outcomes. Combining signature-based predictions across several pathways identifies coordinated patterns of pathway deregulation that distinguish between specific cancers and tumour subtypes. Clustering tumours based on pathway signatures further defines prognosis in respective patient subsets, demonstrating that patterns of oncogenic pathway deregulation underlie the development of the oncogenic phenotype and reflect the biology and outcome of specific cancers. Predictions of pathway deregulation in cancer cell lines are also shown to predict the sensitivity to therapeutic agents that target components of the pathway. Linking pathway deregulation with sensitivity to therapeutics that target components of the pathway provides an opportunity to make use of these oncogenic pathway signatures to guide the use of targeted therapeutics.

Standard name | BILD_CTNNB1_ONCOGENIC_SIGNATURE
Systematic name | M7102
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Genes selected in supervised analyses to discriminate cells expressing activated beta-catenin (CTNNB1) [GeneID=1499] oncogene from control cells expressing GFP.
Full description | The development of an oncogenic state is a complex process involving the accumulation of multiple independent mutations that lead to deregulation of cell signalling pathways central to the control of cell growth and cell fate. The ability to define cancer subtypes, recurrence of disease and response to specific therapies using DNA microarray-based gene expression signatures has been demonstrated in multiple studies. Various studies have also demonstrated the potential for using gene expression profiles for the analysis of oncogenic pathways. Here we show that gene expression signatures can be identified that reflect the activation status of several oncogenic pathways. When evaluated in several large collections of human cancers, these gene expression signatures identify patterns of pathway deregulation in tumours and clinically relevant associations with disease outcomes. Combining signature-based predictions across several pathways identifies coordinated patterns of pathway deregulation that distinguish between specific cancers and tumour subtypes. Clustering tumours based on pathway signatures further defines prognosis in respective patient subsets, demonstrating that patterns of oncogenic pathway deregulation underlie the development of the oncogenic phenotype and reflect the biology and outcome of specific cancers. Predictions of pathway deregulation in cancer cell lines are also shown to predict the sensitivity to therapeutic agents that target components of the pathway. Linking pathway deregulation with sensitivity to therapeutics that target components of the pathway provides an opportunity to make use of these oncogenic pathway signatures to guide the use of targeted therapeutics.

Standard name | DOUGLAS_BMI1_TARGETS_UP
Systematic name | M15103
Organism | Homo sapiens
PMID | 18701473
Authors | Douglas D,Hsu JH,Hung L,Cooper A,Abdueva D,van Doorninck J,Peng G,Shimada H,Triche TJ,Lawlor ER
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A4573 cells (Ewing's sarcoma, ESFT) after knockdown of BMI1 [GeneID=648] by RNAi.
Full description | Deregulation of the polycomb group gene BMI-1 is implicated in the pathogenesis of many human cancers. In this study, we have investigated if the Ewing sarcoma family of tumors (ESFT) expresses BMI-1 and whether it functions as an oncogene in this highly aggressive group of bone and soft tissue tumors. Our data show that BMI-1 is highly expressed by ESFT cells and that, although it does not significantly affect proliferation or survival, BMI-1 actively promotes anchorage-independent growth in vitro and tumorigenicity in vivo. Moreover, we find that BMI-1 promotes the tumorigenicity of both p16 wild-type and p16-null cell lines, demonstrating that the mechanism of BMI-1 oncogenic function in ESFT is, at least in part, independent of CDKN2A repression. Expression profiling studies of ESFT cells following BMI-1 knockdown reveal that BMI-1 regulates the expression of hundreds of downstream target genes including, in particular, genes involved in both differentiation and development as well as cell-cell and cell-matrix adhesion. Gain and loss of function assays confirm that BMI-1 represses the expression of the adhesion-associated basement membrane protein nidogen 1. In addition, although BMI-1 promotes ESFT adhesion, nidogen 1 inhibits cellular adhesion in vitro. Together, these data support a pivotal role for BMI-1 ESFT pathogenesis and suggest that its oncogenic function in these tumors is in part mediated through modulation of adhesion pathways.

Standard name | DOUGLAS_BMI1_TARGETS_DN
Systematic name | M14279
Organism | Homo sapiens
PMID | 18701473
Authors | Douglas D,Hsu JH,Hung L,Cooper A,Abdueva D,van Doorninck J,Peng G,Shimada H,Triche TJ,Lawlor ER
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A4573 cells (Ewing's sarcoma, ESFT) after knockdown of BMI1 [GeneID=648] by RNAi.
Full description | Deregulation of the polycomb group gene BMI-1 is implicated in the pathogenesis of many human cancers. In this study, we have investigated if the Ewing sarcoma family of tumors (ESFT) expresses BMI-1 and whether it functions as an oncogene in this highly aggressive group of bone and soft tissue tumors. Our data show that BMI-1 is highly expressed by ESFT cells and that, although it does not significantly affect proliferation or survival, BMI-1 actively promotes anchorage-independent growth in vitro and tumorigenicity in vivo. Moreover, we find that BMI-1 promotes the tumorigenicity of both p16 wild-type and p16-null cell lines, demonstrating that the mechanism of BMI-1 oncogenic function in ESFT is, at least in part, independent of CDKN2A repression. Expression profiling studies of ESFT cells following BMI-1 knockdown reveal that BMI-1 regulates the expression of hundreds of downstream target genes including, in particular, genes involved in both differentiation and development as well as cell-cell and cell-matrix adhesion. Gain and loss of function assays confirm that BMI-1 represses the expression of the adhesion-associated basement membrane protein nidogen 1. In addition, although BMI-1 promotes ESFT adhesion, nidogen 1 inhibits cellular adhesion in vitro. Together, these data support a pivotal role for BMI-1 ESFT pathogenesis and suggest that its oncogenic function in these tumors is in part mediated through modulation of adhesion pathways.

Standard name | KRIGE_AMINO_ACID_DEPRIVATION
Systematic name | M19341
Organism | Homo sapiens
PMID | 18701491
Authors | Krige D,Needham LA,Bawden LJ,Flores N,Farmer H,Miles LE,Stone E,Callaghan J,Chandler S,Clark VL,Kirwin-Jones P,Legris V,Owen J,Patel T,Wood S,Box G,Laber D,Odedra R,Wright A,Wood LM,Eccles SA,Bone EA,Ayscough A,Drummond AH
Category | C2
Sub-category | CGP
Brief description | The 'amino acid deprivation response' (AADR): genes up-regulated in HL-60 cells (acute promyelocytic leukemia, APL) after amino acid deprivation or treatment with the aminopeptidase inhibitor tosedostat (CHR-2797) [PubChem=15547703].
Full description | CHR-2797 is a novel metalloenzyme inhibitor that is converted into a pharmacologically active acid product (CHR-79888) inside cells. CHR-79888 is a potent inhibitor of a number of intracellular aminopeptidases, including leucine aminopeptidase. CHR-2797 exerts antiproliferative effects against a range of tumor cell lines in vitro and in vivo and shows selectivity for transformed over nontransformed cells. Its antiproliferative effects are at least 300 times more potent than the prototypical aminopeptidase inhibitor, bestatin. However, the mechanism by which inhibition of these enzymes leads to proliferative changes is not understood. Gene expression microarrays were used to profile changes in mRNA expression levels in the human promyelocytic leukemia cell line HL-60 treated with CHR-2797. This analysis showed that CHR-2797 treatment induced a transcriptional response indicative of amino acid depletion, the amino acid deprivation response, which involves up-regulation of amino acid synthetic genes, transporters, and tRNA synthetases. These changes were confirmed in other leukemic cell lines sensitive to the antiproliferative effects of CHR-2797. Furthermore, CHR-2797 treatment inhibited phosphorylation of mTOR substrates and reduced protein synthesis in HL-60 cells, both also indicative of amino acid depletion. Treatment with CHR-2797 led to an increase in the concentration of intracellular small peptides, the substrates of aminopeptidases. It is suggested that aminopeptidase inhibitors, such as CHR-2797 and bestatin, deplete sensitive tumor cells of amino acids by blocking protein recycling, and this generates an antiproliferative effect. CHR-2797 is orally bioavailable and currently undergoing phase II clinical investigation in the treatment of myeloid leukemia.

Standard name | KRIGE_RESPONSE_TO_TOSEDOSTAT_6HR_UP
Systematic name | M8144
Organism | Homo sapiens
PMID | 18701491
Authors | Krige D,Needham LA,Bawden LJ,Flores N,Farmer H,Miles LE,Stone E,Callaghan J,Chandler S,Clark VL,Kirwin-Jones P,Legris V,Owen J,Patel T,Wood S,Box G,Laber D,Odedra R,Wright A,Wood LM,Eccles SA,Bone EA,Ayscough A,Drummond AH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HL-60 cells (acute promyelocytic leukemia, APL) after treatment with the aminopeptidase inhibitor tosedostat (CHR-2797) [PubChem=15547703] for 6 h.
Full description | CHR-2797 is a novel metalloenzyme inhibitor that is converted into a pharmacologically active acid product (CHR-79888) inside cells. CHR-79888 is a potent inhibitor of a number of intracellular aminopeptidases, including leucine aminopeptidase. CHR-2797 exerts antiproliferative effects against a range of tumor cell lines in vitro and in vivo and shows selectivity for transformed over nontransformed cells. Its antiproliferative effects are at least 300 times more potent than the prototypical aminopeptidase inhibitor, bestatin. However, the mechanism by which inhibition of these enzymes leads to proliferative changes is not understood. Gene expression microarrays were used to profile changes in mRNA expression levels in the human promyelocytic leukemia cell line HL-60 treated with CHR-2797. This analysis showed that CHR-2797 treatment induced a transcriptional response indicative of amino acid depletion, the amino acid deprivation response, which involves up-regulation of amino acid synthetic genes, transporters, and tRNA synthetases. These changes were confirmed in other leukemic cell lines sensitive to the antiproliferative effects of CHR-2797. Furthermore, CHR-2797 treatment inhibited phosphorylation of mTOR substrates and reduced protein synthesis in HL-60 cells, both also indicative of amino acid depletion. Treatment with CHR-2797 led to an increase in the concentration of intracellular small peptides, the substrates of aminopeptidases. It is suggested that aminopeptidase inhibitors, such as CHR-2797 and bestatin, deplete sensitive tumor cells of amino acids by blocking protein recycling, and this generates an antiproliferative effect. CHR-2797 is orally bioavailable and currently undergoing phase II clinical investigation in the treatment of myeloid leukemia.

Standard name | KRIGE_RESPONSE_TO_TOSEDOSTAT_6HR_DN
Systematic name | M19907
Organism | Homo sapiens
PMID | 18701491
Authors | Krige D,Needham LA,Bawden LJ,Flores N,Farmer H,Miles LE,Stone E,Callaghan J,Chandler S,Clark VL,Kirwin-Jones P,Legris V,Owen J,Patel T,Wood S,Box G,Laber D,Odedra R,Wright A,Wood LM,Eccles SA,Bone EA,Ayscough A,Drummond AH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HL-60 cells (acute promyelocytic leukemia, APL) after treatment with the aminopeptidase inhibitor tosedostat (CHR-2797) [PubChem=15547703] for 6 h.
Full description | CHR-2797 is a novel metalloenzyme inhibitor that is converted into a pharmacologically active acid product (CHR-79888) inside cells. CHR-79888 is a potent inhibitor of a number of intracellular aminopeptidases, including leucine aminopeptidase. CHR-2797 exerts antiproliferative effects against a range of tumor cell lines in vitro and in vivo and shows selectivity for transformed over nontransformed cells. Its antiproliferative effects are at least 300 times more potent than the prototypical aminopeptidase inhibitor, bestatin. However, the mechanism by which inhibition of these enzymes leads to proliferative changes is not understood. Gene expression microarrays were used to profile changes in mRNA expression levels in the human promyelocytic leukemia cell line HL-60 treated with CHR-2797. This analysis showed that CHR-2797 treatment induced a transcriptional response indicative of amino acid depletion, the amino acid deprivation response, which involves up-regulation of amino acid synthetic genes, transporters, and tRNA synthetases. These changes were confirmed in other leukemic cell lines sensitive to the antiproliferative effects of CHR-2797. Furthermore, CHR-2797 treatment inhibited phosphorylation of mTOR substrates and reduced protein synthesis in HL-60 cells, both also indicative of amino acid depletion. Treatment with CHR-2797 led to an increase in the concentration of intracellular small peptides, the substrates of aminopeptidases. It is suggested that aminopeptidase inhibitors, such as CHR-2797 and bestatin, deplete sensitive tumor cells of amino acids by blocking protein recycling, and this generates an antiproliferative effect. CHR-2797 is orally bioavailable and currently undergoing phase II clinical investigation in the treatment of myeloid leukemia.

Standard name | KRIGE_RESPONSE_TO_TOSEDOSTAT_24HR_UP
Systematic name | M17915
Organism | Homo sapiens
PMID | 18701491
Authors | Krige D,Needham LA,Bawden LJ,Flores N,Farmer H,Miles LE,Stone E,Callaghan J,Chandler S,Clark VL,Kirwin-Jones P,Legris V,Owen J,Patel T,Wood S,Box G,Laber D,Odedra R,Wright A,Wood LM,Eccles SA,Bone EA,Ayscough A,Drummond AH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HL-60 cells (acute promyelocytic leukemia, APL) after treatment with the aminopeptidase inhibitor tosedostat (CHR-2797) [PubChem=15547703] for 24 h.
Full description | CHR-2797 is a novel metalloenzyme inhibitor that is converted into a pharmacologically active acid product (CHR-79888) inside cells. CHR-79888 is a potent inhibitor of a number of intracellular aminopeptidases, including leucine aminopeptidase. CHR-2797 exerts antiproliferative effects against a range of tumor cell lines in vitro and in vivo and shows selectivity for transformed over nontransformed cells. Its antiproliferative effects are at least 300 times more potent than the prototypical aminopeptidase inhibitor, bestatin. However, the mechanism by which inhibition of these enzymes leads to proliferative changes is not understood. Gene expression microarrays were used to profile changes in mRNA expression levels in the human promyelocytic leukemia cell line HL-60 treated with CHR-2797. This analysis showed that CHR-2797 treatment induced a transcriptional response indicative of amino acid depletion, the amino acid deprivation response, which involves up-regulation of amino acid synthetic genes, transporters, and tRNA synthetases. These changes were confirmed in other leukemic cell lines sensitive to the antiproliferative effects of CHR-2797. Furthermore, CHR-2797 treatment inhibited phosphorylation of mTOR substrates and reduced protein synthesis in HL-60 cells, both also indicative of amino acid depletion. Treatment with CHR-2797 led to an increase in the concentration of intracellular small peptides, the substrates of aminopeptidases. It is suggested that aminopeptidase inhibitors, such as CHR-2797 and bestatin, deplete sensitive tumor cells of amino acids by blocking protein recycling, and this generates an antiproliferative effect. CHR-2797 is orally bioavailable and currently undergoing phase II clinical investigation in the treatment of myeloid leukemia.

Standard name | KRIGE_RESPONSE_TO_TOSEDOSTAT_24HR_DN
Systematic name | M8525
Organism | Homo sapiens
PMID | 18701491
Authors | Krige D,Needham LA,Bawden LJ,Flores N,Farmer H,Miles LE,Stone E,Callaghan J,Chandler S,Clark VL,Kirwin-Jones P,Legris V,Owen J,Patel T,Wood S,Box G,Laber D,Odedra R,Wright A,Wood LM,Eccles SA,Bone EA,Ayscough A,Drummond AH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HL-60 cells (acute promyelocytic leukemia, APL) after treatment with the aminopeptidase inhibitor tosedostat (CHR-2797) [PubChem=15547703] for 24 h.
Full description | CHR-2797 is a novel metalloenzyme inhibitor that is converted into a pharmacologically active acid product (CHR-79888) inside cells. CHR-79888 is a potent inhibitor of a number of intracellular aminopeptidases, including leucine aminopeptidase. CHR-2797 exerts antiproliferative effects against a range of tumor cell lines in vitro and in vivo and shows selectivity for transformed over nontransformed cells. Its antiproliferative effects are at least 300 times more potent than the prototypical aminopeptidase inhibitor, bestatin. However, the mechanism by which inhibition of these enzymes leads to proliferative changes is not understood. Gene expression microarrays were used to profile changes in mRNA expression levels in the human promyelocytic leukemia cell line HL-60 treated with CHR-2797. This analysis showed that CHR-2797 treatment induced a transcriptional response indicative of amino acid depletion, the amino acid deprivation response, which involves up-regulation of amino acid synthetic genes, transporters, and tRNA synthetases. These changes were confirmed in other leukemic cell lines sensitive to the antiproliferative effects of CHR-2797. Furthermore, CHR-2797 treatment inhibited phosphorylation of mTOR substrates and reduced protein synthesis in HL-60 cells, both also indicative of amino acid depletion. Treatment with CHR-2797 led to an increase in the concentration of intracellular small peptides, the substrates of aminopeptidases. It is suggested that aminopeptidase inhibitors, such as CHR-2797 and bestatin, deplete sensitive tumor cells of amino acids by blocking protein recycling, and this generates an antiproliferative effect. CHR-2797 is orally bioavailable and currently undergoing phase II clinical investigation in the treatment of myeloid leukemia.

Standard name | GHO_ATF5_TARGETS_UP
Systematic name | M12008
Organism | Homo sapiens
PMID | 18701499
Authors | Gho JW,Ip WK,Chan KY,Law PT,Lai PB,Wong N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HEP3B cells (liver cancer) overexpressing ATF5 [GeneID=22809] off a plasmid vector.
Full description | Transcription factors represent an important class of genes that play key roles in controlling cellular proliferation, cell cycle modulation, and attractive targets for cancer therapy. Here, we report on the novel finding of common ATF5 down-regulations in hepatocellular carcinoma (HCC), a highly malignant tumor with a dismal clinical course. Array-based mapping in HCC highlighted a high and consistent incidence of transcription factor ATF5 repressions on regional chr.19q13. By quantitative reverse transcription-PCR, profound down-regulations of ATF5 were further suggested in 78% of HCC tumors (60 of 77 cases) compared to their adjacent nontumoral liver (P = 0.0004). Restoration of ATF5 expression in 3 nonexpressing HCC cell lines demonstrated a consistent growth inhibitory effect (P < 0.029) but minimal induction on cellular apoptosis. Subsequent flow cytometric investigations revealed a G(2)-M cell cycle arrest in HCC cells that were ectopically transfected with ATF5 (P < 0.002). The differential expressed genes from the functional effects of ATF5 were examined by array profiling. Over a hundred genes were identified, among which ID1 contains the ATF/CREB target binding sequences within its promoter region. An inverse relationship between ATF5 expressions with ID1 transcriptions was verified in HCC (P = 0.019), and a direct interaction of ATF5 on the promoter of ID1 was further demonstrated from electromobility shift assay. Examination of causal events underlying the silencing of ATF5 in HCC suggested copy number losses, promoter hypermethylation, histone deacetylation, and DNA mutations to be the likely inactivating mechanisms. In conclusion, our finding supports a tumor suppressive role for ATF5 in HCC, and highlighted ID1 as a potential downstream target.

Standard name | GHO_ATF5_TARGETS_DN
Systematic name | M11457
Organism | Homo sapiens
PMID | 18701499
Authors | Gho JW,Ip WK,Chan KY,Law PT,Lai PB,Wong N
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HEP3B cells (liver cancer) overexpressing ATF5 [GeneID=22809] off a plasmid vector.
Full description | Transcription factors represent an important class of genes that play key roles in controlling cellular proliferation, cell cycle modulation, and attractive targets for cancer therapy. Here, we report on the novel finding of common ATF5 down-regulations in hepatocellular carcinoma (HCC), a highly malignant tumor with a dismal clinical course. Array-based mapping in HCC highlighted a high and consistent incidence of transcription factor ATF5 repressions on regional chr.19q13. By quantitative reverse transcription-PCR, profound down-regulations of ATF5 were further suggested in 78% of HCC tumors (60 of 77 cases) compared to their adjacent nontumoral liver (P = 0.0004). Restoration of ATF5 expression in 3 nonexpressing HCC cell lines demonstrated a consistent growth inhibitory effect (P < 0.029) but minimal induction on cellular apoptosis. Subsequent flow cytometric investigations revealed a G(2)-M cell cycle arrest in HCC cells that were ectopically transfected with ATF5 (P < 0.002). The differential expressed genes from the functional effects of ATF5 were examined by array profiling. Over a hundred genes were identified, among which ID1 contains the ATF/CREB target binding sequences within its promoter region. An inverse relationship between ATF5 expressions with ID1 transcriptions was verified in HCC (P = 0.019), and a direct interaction of ATF5 on the promoter of ID1 was further demonstrated from electromobility shift assay. Examination of causal events underlying the silencing of ATF5 in HCC suggested copy number losses, promoter hypermethylation, histone deacetylation, and DNA mutations to be the likely inactivating mechanisms. In conclusion, our finding supports a tumor suppressive role for ATF5 in HCC, and highlighted ID1 as a potential downstream target.

Standard name | DURCHDEWALD_SKIN_CARCINOGENESIS_UP
Systematic name | M1683
Organism | Mus musculus
PMID | 18757399
Authors | Durchdewald M,Guinea-Viniegra J,Haag D,Riehl A,Lichter P,Hahn M,Wagner EF,Angel P,Hess J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated upon skin specific knockout of FOS [GeneID=2353] by cre-lox in the K5-SOS-F mice (express a constitutively active form of SOS1 [GeneID=6654] in the skin).
Full description | Expression and function of the oncogenic transcription factor activator protein (AP-1; mainly composed of Jun and Fos proteins) is required for neoplastic transformation of keratinocytes in vitro and tumor promotion as well as malignant progression in vivo. Here, we describe the identification of 372 differentially expressed genes comparing skin tumor samples of K5-SOS-F transgenic mice (Fos(f/f) SOS(+)) with samples derived from animals with a specific deletion of c-Fos in keratinocytes (Fos(Deltaep) SOS(+)). Fos-dependent transcription of selected genes was confirmed by quantitative real-time PCR analysis using tumor samples and mouse back skin treated with the tumor promoter 12-O-tetradecanoylphorbol-13-acetate (TPA). One of the most differentially expressed genes encodes the small mucin-like glycoprotein Podoplanin (Pdpn), whose expression correlates with malignant progression in mouse tumor model systems and human cancer. We found Pdpn and Fos expression in chemically induced mouse skin tumors, and detailed analysis of the Pdpn gene promoter revealed impaired activity in Fos-deficient mouse embryonic fibroblasts, which could be restored by ectopic Fos expression. Direct Fos protein binding to the Pdpn promoter was shown by chromatin immunoprecipitation and a TPA-induced complex at a TPA-responsive element-like motif in the proximal promoter was identified by electrophoretic mobility shift assays. In summary, we could define a Fos-dependent genetic program in a well-established model of skin tumors. Systematic analysis of these novel target genes will guide us in elucidating the molecular mechanisms of AP-1-regulated pathways that are critically implicated in neoplastic transformation and/or malignant progression.

Standard name | DURCHDEWALD_SKIN_CARCINOGENESIS_DN
Systematic name | M1684
Organism | Mus musculus
PMID | 18757399
Authors | Durchdewald M,Guinea-Viniegra J,Haag D,Riehl A,Lichter P,Hahn M,Wagner EF,Angel P,Hess J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated upon skin specific knockout of FOS [GeneID=2353] by cre-lox in the K5-SOS-F mice (express a constitutively active form of SOS1 [GeneID=6654] in the skin).
Full description | Expression and function of the oncogenic transcription factor activator protein (AP-1; mainly composed of Jun and Fos proteins) is required for neoplastic transformation of keratinocytes in vitro and tumor promotion as well as malignant progression in vivo. Here, we describe the identification of 372 differentially expressed genes comparing skin tumor samples of K5-SOS-F transgenic mice (Fos(f/f) SOS(+)) with samples derived from animals with a specific deletion of c-Fos in keratinocytes (Fos(Deltaep) SOS(+)). Fos-dependent transcription of selected genes was confirmed by quantitative real-time PCR analysis using tumor samples and mouse back skin treated with the tumor promoter 12-O-tetradecanoylphorbol-13-acetate (TPA). One of the most differentially expressed genes encodes the small mucin-like glycoprotein Podoplanin (Pdpn), whose expression correlates with malignant progression in mouse tumor model systems and human cancer. We found Pdpn and Fos expression in chemically induced mouse skin tumors, and detailed analysis of the Pdpn gene promoter revealed impaired activity in Fos-deficient mouse embryonic fibroblasts, which could be restored by ectopic Fos expression. Direct Fos protein binding to the Pdpn promoter was shown by chromatin immunoprecipitation and a TPA-induced complex at a TPA-responsive element-like motif in the proximal promoter was identified by electrophoretic mobility shift assays. In summary, we could define a Fos-dependent genetic program in a well-established model of skin tumors. Systematic analysis of these novel target genes will guide us in elucidating the molecular mechanisms of AP-1-regulated pathways that are critically implicated in neoplastic transformation and/or malignant progression.

Standard name | LI_CYTIDINE_ANALOGS_CYCTOTOXICITY
Systematic name | M19805
Organism | Homo sapiens
PMID | 18757419
Authors | Li L,Fridley B,Kalari K,Jenkins G,Batzler A,Safgren S,Hildebrandt M,Ames M,Schaid D,Wang L
Category | C2
Sub-category | CGP
Brief description | Genes whose expression in a panel of lymphoblastoid cell lines was associated with cytotoxicity of the anti-cancer analogs of cytidine, gemcitabine and cytarabine [PubChem=596;3461;6253].
Full description | Two cytidine analogues, gemcitabine (dFdC) and 1-beta-d-arabinofuranosylcytosine (AraC), show significant therapeutic effect in a variety of cancers. However, response to these drugs varies widely. Evidence from tumor biopsy samples shows that expression levels for genes involved in the cytidine transport, metabolism, and bioactivation pathway contribute to this variation in response. In the present study, we set out to test the hypothesis that variation in gene expression both within and outside of this pathway might influence sensitivity to gemcitabine and AraC. Specifically, Affymetrix U133 Plus 2.0 GeneChip and cytotoxicity assays were performed to obtain basal mRNA expression and IC(50) values for both drugs in 197 ethnically defined Human Variation Panel lymphoblastoid cell lines. Genes with a high degree of association with IC(50) values were involved mainly in cell death, cancer, cell cycle, and nucleic acid metabolism pathways. We validated selected significant genes by performing real-time quantitative reverse transcription-PCR and selected two representative candidates, NT5C3 (within the pathway) and FKBP5 (outside of the pathway), for functional validation. Those studies showed that down-regulation of NT5C3 and FKBP5 altered tumor cell sensitivity to both drugs. Our results suggest that cell-based model system studies, when combined with complementary functional characterization, may help to identify biomarkers for response to chemotherapy with these cytidine analogues.

Standard name | LI_CYTIDINE_ANALOG_PATHWAY
Systematic name | M19946
Organism | Homo sapiens
PMID | 18757419
Authors | Li L,Fridley B,Kalari K,Jenkins G,Batzler A,Safgren S,Hildebrandt M,Ames M,Schaid D,Wang L
Category | C2
Sub-category | CGP
Brief description | The 'cytidine analog pathway': genes involved in transport and metabolism of the anti-cancer analogs of cytidine: gemcitabine and cytarabine [PubChem=596;3461;6253].
Full description | Two cytidine analogues, gemcitabine (dFdC) and 1-beta-d-arabinofuranosylcytosine (AraC), show significant therapeutic effect in a variety of cancers. However, response to these drugs varies widely. Evidence from tumor biopsy samples shows that expression levels for genes involved in the cytidine transport, metabolism, and bioactivation pathway contribute to this variation in response. In the present study, we set out to test the hypothesis that variation in gene expression both within and outside of this pathway might influence sensitivity to gemcitabine and AraC. Specifically, Affymetrix U133 Plus 2.0 GeneChip and cytotoxicity assays were performed to obtain basal mRNA expression and IC(50) values for both drugs in 197 ethnically defined Human Variation Panel lymphoblastoid cell lines. Genes with a high degree of association with IC(50) values were involved mainly in cell death, cancer, cell cycle, and nucleic acid metabolism pathways. We validated selected significant genes by performing real-time quantitative reverse transcription-PCR and selected two representative candidates, NT5C3 (within the pathway) and FKBP5 (outside of the pathway), for functional validation. Those studies showed that down-regulation of NT5C3 and FKBP5 altered tumor cell sensitivity to both drugs. Our results suggest that cell-based model system studies, when combined with complementary functional characterization, may help to identify biomarkers for response to chemotherapy with these cytidine analogues.

Standard name | KIM_LRRC3B_TARGETS
Systematic name | M17363
Organism | Homo sapiens
PMID | 18757430
Authors | Kim M,Kim JH,Jang HR,Kim HM,Lee CW,Noh SM,Song KS,Cho JS,Jeong HY,Hahn Y,Yeom YI,Yoo HS,Kim YS
Category | C2
Sub-category | CGP
Brief description | Immune response genes up-regulated in zenograft tumors formed by SNU-601 cells (gastric cancer) made to express LRRC3B [GeneID=116135].
Full description | Leucine-rich repeat-containing 3B (LRRC3B) is an evolutionarily highly conserved leucine-rich repeat-containing protein, but its biological significance is unknown. Using restriction landmark genomic scanning and pyrosequencing, we found that the promoter region of LRRC3B was aberrantly methylated in gastric cancer. Gastric cancer cell lines displayed epigenetic silencing of LRRC3B, but treatment with the DNA methylation inhibitor 5-aza-2'-deoxycytidine and/or the histone deacetylase inhibitor trichostatin A increased LRRC3B expression in gastric cancer cell lines. Real-time reverse transcription-PCR analysis of 96 paired primary gastric tumors and normal adjacent tissues showed that LRRC3B expression was reduced in 88.5% of gastric tumors compared with normal adjacent tissues. Pyrosequencing analysis of the promoter region revealed that LRRC3B was significantly hypermethylated in gastric tumors. Stable transfection of LRRC3B in SNU-601 cells, a gastric cancer cell line, inhibited anchorage-dependent and anchorage-independent colony formation, and LRRC3B expression suppressed tumorigenesis in nude mice. Microarray analysis of LRRC3B-expressing xenograft tumors showed induction of immune response-related genes and IFN signaling genes. H&E-stained sections of LRRC3B-expressing xenograft tumors showed lymphocyte infiltration in the region. We suggest that LRRC3B is a putative tumor suppressor gene that is silenced in gastric cancers by epigenetic mechanisms and that LRRC3B silencing in cancer may play an important role in tumor escape from immune surveillance.

Standard name | ZHONG_SECRETOME_OF_LUNG_CANCER_AND_MACROPHAGE
Systematic name | M1685
Organism | Mus musculus
PMID | 18757440
Authors | Zhong L,Roybal J,Chaerkady R,Zhang W,Choi K,Alvarez CA,Tran H,Creighton CJ,Yan S,Strieter RM,Pandey A,Kurie JM
Category | C2
Sub-category | CGP
Brief description | Proteins secreted in co-culture of LKR-13 tumor cells (non-small cell lung cancer, NSCLC) and MHS stroma cells (macrophages).
Full description | Non-small cell lung cancer (NSCLC) cells with somatic mutations in K-ras recruit to the tumor a variety of cell types (hereafter collectively termed stromal cells) that can promote or inhibit tumorigenesis by mechanisms that have not been fully elucidated. Here, we postulated that stromal cells in the tumor microenvironment alter the tumor cell secretome, including those proteins required for tumor growth and dissemination, and we developed an in vitro model to test this hypothesis. Coculturing a murine K-ras mutant lung adenocarcinoma cell line (LKR-13) with a murine lung stromal cell (macrophage, endothelial cell, or fibroblast) enhanced stromal cell migration, induced endothelial tube formation, increased LKR-13 cell proliferation, and regulated the secretion of proteins involved in angiogenesis, inflammation, cell proliferation, and epithelial-to-mesenchymal transition. Among these proteins, CXCL1 has been reported to promote NSCLC development, whereas interleukin-18 (IL-18) has an undefined role. Genetic and pharmacologic strategies to inhibit CXCL1 and IL-18 revealed that stromal cell migration, LKR-13 cell proliferation, and LKR-13 cell tumorigenicity required one or both of these proteins. We conclude that stromal cells enhanced LKR-13 cell tumorigenicity partly through their effects on the secretome of LKR-13 cells. Strategies to inhibit tumor/stromal cell interactions may be useful as therapeutic approaches in NSCLC patients.

Standard name | ZHONG_SECRETOME_OF_LUNG_CANCER_AND_ENDOTHELIUM
Systematic name | M1686
Organism | Mus musculus
PMID | 18757440
Authors | Zhong L,Roybal J,Chaerkady R,Zhang W,Choi K,Alvarez CA,Tran H,Creighton CJ,Yan S,Strieter RM,Pandey A,Kurie JM
Category | C2
Sub-category | CGP
Brief description | Proteins secreted in co-culture of LKR-13 tumor cells (non-small cell lung cancer, NSCLC) and MEC stroma cells (endothelium).
Full description | Non-small cell lung cancer (NSCLC) cells with somatic mutations in K-ras recruit to the tumor a variety of cell types (hereafter collectively termed stromal cells) that can promote or inhibit tumorigenesis by mechanisms that have not been fully elucidated. Here, we postulated that stromal cells in the tumor microenvironment alter the tumor cell secretome, including those proteins required for tumor growth and dissemination, and we developed an in vitro model to test this hypothesis. Coculturing a murine K-ras mutant lung adenocarcinoma cell line (LKR-13) with a murine lung stromal cell (macrophage, endothelial cell, or fibroblast) enhanced stromal cell migration, induced endothelial tube formation, increased LKR-13 cell proliferation, and regulated the secretion of proteins involved in angiogenesis, inflammation, cell proliferation, and epithelial-to-mesenchymal transition. Among these proteins, CXCL1 has been reported to promote NSCLC development, whereas interleukin-18 (IL-18) has an undefined role. Genetic and pharmacologic strategies to inhibit CXCL1 and IL-18 revealed that stromal cell migration, LKR-13 cell proliferation, and LKR-13 cell tumorigenicity required one or both of these proteins. We conclude that stromal cells enhanced LKR-13 cell tumorigenicity partly through their effects on the secretome of LKR-13 cells. Strategies to inhibit tumor/stromal cell interactions may be useful as therapeutic approaches in NSCLC patients.

Standard name | ZHONG_SECRETOME_OF_LUNG_CANCER_AND_FIBROBLAST
Systematic name | M1687
Organism | Mus musculus
PMID | 18757440
Authors | Zhong L,Roybal J,Chaerkady R,Zhang W,Choi K,Alvarez CA,Tran H,Creighton CJ,Yan S,Strieter RM,Pandey A,Kurie JM
Category | C2
Sub-category | CGP
Brief description | Proteins secreted in co-culture of LKR-13 tumor cells (non-small cell lung cancer, NSCLC) and MLg stroma cells (fibroblasts).
Full description | Non-small cell lung cancer (NSCLC) cells with somatic mutations in K-ras recruit to the tumor a variety of cell types (hereafter collectively termed stromal cells) that can promote or inhibit tumorigenesis by mechanisms that have not been fully elucidated. Here, we postulated that stromal cells in the tumor microenvironment alter the tumor cell secretome, including those proteins required for tumor growth and dissemination, and we developed an in vitro model to test this hypothesis. Coculturing a murine K-ras mutant lung adenocarcinoma cell line (LKR-13) with a murine lung stromal cell (macrophage, endothelial cell, or fibroblast) enhanced stromal cell migration, induced endothelial tube formation, increased LKR-13 cell proliferation, and regulated the secretion of proteins involved in angiogenesis, inflammation, cell proliferation, and epithelial-to-mesenchymal transition. Among these proteins, CXCL1 has been reported to promote NSCLC development, whereas interleukin-18 (IL-18) has an undefined role. Genetic and pharmacologic strategies to inhibit CXCL1 and IL-18 revealed that stromal cell migration, LKR-13 cell proliferation, and LKR-13 cell tumorigenicity required one or both of these proteins. We conclude that stromal cells enhanced LKR-13 cell tumorigenicity partly through their effects on the secretome of LKR-13 cells. Strategies to inhibit tumor/stromal cell interactions may be useful as therapeutic approaches in NSCLC patients.

Standard name | CLASPER_LYMPHATIC_VESSELS_DURING_METASTASIS_UP
Systematic name | M11701
Organism | Mus musculus
PMID | 18794116
Authors | Clasper S,Royston D,Baban D,Cao Y,Ewers S,Butz S,Vestweber D,Jackson DG
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated during invasion of lymphatic vessels during metastasis.
Full description | Invasion of lymphatic vessels is a key step in the metastasis of primary tumors to draining lymph nodes. Although the process is enhanced by tumor lymphangiogenesis, it is unclear whether this is a consequence of increased lymphatic vessel number, altered lymphatic vessel properties, or both. Here we have addressed the question by comparing the RNA profiles of primary lymphatic endothelial cells (LEC) isolated from the vasculature of normal tissue and from highly metastatic T-241/vascular endothelial growth factor (VEGF)-C fibrosarcomas implanted in C57BL/6 mice. Our findings reveal significant differences in expression of some 792 genes (i.e., >or=2-fold up- or down-regulated, P <or= 0.05) that code for a variety of proteins including components of endothelial junctions, subendothelial matrix, and vessel growth/patterning. The tumor LEC profile, validated by immunohistochemical staining, is distinct from that of normal, inflammatory cytokine, or mitogen-activated LEC, characterized by elevated expression of such functionally significant molecules as the tight junction regulatory protein endothelial specific adhesion molecule (ESAM), the transforming growth factor-beta coreceptor Endoglin (CD105), the angiogenesis-associated leptin receptor, and the immunoinhibitory receptor CD200, and reduced expression of subendothelial matrix proteins including collagens, fibrillin, and biglycan. Moreover, we show similar induction of ESAM, Endoglin, and leptin receptor within tumor lymphatics in a series of human head and neck and colorectal carcinomas, and uncover a dramatic correlation between ESAM expression and nodal metastasis that identifies this marker as a possible prognostic indicator. These findings reveal a remarkable degree of phenotypic plasticity in cancer lymphatics and provide new insight into the processes of lymphatic invasion and lymph node metastasis.

Standard name | CLASPER_LYMPHATIC_VESSELS_DURING_METASTASIS_DN
Systematic name | M11788
Organism | Mus musculus
PMID | 18794116
Authors | Clasper S,Royston D,Baban D,Cao Y,Ewers S,Butz S,Vestweber D,Jackson DG
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated during invasion of lymphatic vessels during metastasis.
Full description | Invasion of lymphatic vessels is a key step in the metastasis of primary tumors to draining lymph nodes. Although the process is enhanced by tumor lymphangiogenesis, it is unclear whether this is a consequence of increased lymphatic vessel number, altered lymphatic vessel properties, or both. Here we have addressed the question by comparing the RNA profiles of primary lymphatic endothelial cells (LEC) isolated from the vasculature of normal tissue and from highly metastatic T-241/vascular endothelial growth factor (VEGF)-C fibrosarcomas implanted in C57BL/6 mice. Our findings reveal significant differences in expression of some 792 genes (i.e., >or=2-fold up- or down-regulated, P <or= 0.05) that code for a variety of proteins including components of endothelial junctions, subendothelial matrix, and vessel growth/patterning. The tumor LEC profile, validated by immunohistochemical staining, is distinct from that of normal, inflammatory cytokine, or mitogen-activated LEC, characterized by elevated expression of such functionally significant molecules as the tight junction regulatory protein endothelial specific adhesion molecule (ESAM), the transforming growth factor-beta coreceptor Endoglin (CD105), the angiogenesis-associated leptin receptor, and the immunoinhibitory receptor CD200, and reduced expression of subendothelial matrix proteins including collagens, fibrillin, and biglycan. Moreover, we show similar induction of ESAM, Endoglin, and leptin receptor within tumor lymphatics in a series of human head and neck and colorectal carcinomas, and uncover a dramatic correlation between ESAM expression and nodal metastasis that identifies this marker as a possible prognostic indicator. These findings reveal a remarkable degree of phenotypic plasticity in cancer lymphatics and provide new insight into the processes of lymphatic invasion and lymph node metastasis.

Standard name | MONNIER_POSTRADIATION_TUMOR_ESCAPE_UP
Systematic name | M11891
Organism | Mus musculus
PMID | 18794119
Authors | Monnier Y,Farmer P,Bieler G,Imaizumi N,Sengstag T,Alghisi GC,Stehle JC,Ciarloni L,Andrejevic-Blant S,Moeckli R,Mirimanoff RO,Goodman SL,Delorenzi M,Rüegg C
Category | C2
Sub-category | CGP
Brief description | The postradiation tumor escape signature: genes up-regulated in tumors from irradiated stroma vs those from non-irradiated stroma.
Full description | Radiotherapy is widely used to treat human cancer. Patients locally recurring after radiotherapy, however, have increased risk of metastatic progression and poor prognosis. The clinical management of postradiation recurrences remains an unresolved issue. Tumors growing in preirradiated tissues have an increased fraction of hypoxic cells and are more metastatic, a condition known as tumor bed effect. The transcription factor hypoxia inducible factor (HIF)-1 promotes invasion and metastasis of hypoxic tumors, but its role in the tumor bed effect has not been reported. Here, we show that tumor cells derived from SCCVII and HCT116 tumors growing in a preirradiated bed, or selected in vitro through repeated cycles of severe hypoxia, retain invasive and metastatic capacities when returned to normoxia. HIF activity, although facilitating metastatic spreading of tumors growing in a preirradiated bed, is not essential. Through gene expression profiling and gain- and loss-of-function experiments, we identified the matricellular protein CYR61 and alphaVbeta5 integrin as proteins cooperating to mediate these effects. The anti-alphaV integrin monoclonal antibody 17E6 and the small molecular alphaVbeta3/alphaVbeta5 integrin inhibitor EMD121974 suppressed invasion and metastasis induced by CYR61 and attenuated metastasis of tumors growing within a preirradiated field. These results represent a conceptual advance to the understanding of the tumor bed effect and identify CYR61 and alphaVbeta5 integrin as proteins that cooperate to mediate metastasis. They also identify alphaV integrin inhibition as a potential therapeutic approach for preventing metastasis in patients at risk for postradiation recurrences.

Standard name | MONNIER_POSTRADIATION_TUMOR_ESCAPE_DN
Systematic name | M3485
Organism | Mus musculus
PMID | 18794119
Authors | Monnier Y,Farmer P,Bieler G,Imaizumi N,Sengstag T,Alghisi GC,Stehle JC,Ciarloni L,Andrejevic-Blant S,Moeckli R,Mirimanoff RO,Goodman SL,Delorenzi M,Rüegg C
Category | C2
Sub-category | CGP
Brief description | The postradiation tumor escape signature: genes down-regulated in tumors from irradiated stroma vs those from non-irradiated stroma.
Full description | Radiotherapy is widely used to treat human cancer. Patients locally recurring after radiotherapy, however, have increased risk of metastatic progression and poor prognosis. The clinical management of postradiation recurrences remains an unresolved issue. Tumors growing in preirradiated tissues have an increased fraction of hypoxic cells and are more metastatic, a condition known as tumor bed effect. The transcription factor hypoxia inducible factor (HIF)-1 promotes invasion and metastasis of hypoxic tumors, but its role in the tumor bed effect has not been reported. Here, we show that tumor cells derived from SCCVII and HCT116 tumors growing in a preirradiated bed, or selected in vitro through repeated cycles of severe hypoxia, retain invasive and metastatic capacities when returned to normoxia. HIF activity, although facilitating metastatic spreading of tumors growing in a preirradiated bed, is not essential. Through gene expression profiling and gain- and loss-of-function experiments, we identified the matricellular protein CYR61 and alphaVbeta5 integrin as proteins cooperating to mediate these effects. The anti-alphaV integrin monoclonal antibody 17E6 and the small molecular alphaVbeta3/alphaVbeta5 integrin inhibitor EMD121974 suppressed invasion and metastasis induced by CYR61 and attenuated metastasis of tumors growing within a preirradiated field. These results represent a conceptual advance to the understanding of the tumor bed effect and identify CYR61 and alphaVbeta5 integrin as proteins that cooperate to mediate metastasis. They also identify alphaV integrin inhibition as a potential therapeutic approach for preventing metastasis in patients at risk for postradiation recurrences.

Standard name | MCCOLLUM_GELDANAMYCIN_RESISTANCE_UP
Systematic name | M7047
Organism | Homo sapiens
PMID | 18794130
Authors | McCollum AK,TenEyck CJ,Stensgard B,Morlan BW,Ballman KV,Jenkins RB,Toft DO,Erlichman C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A549GARS cells (lung cancer) resistant to the geldanamycin and 17-AAG [PubChem=5476289;6440175].
Full description | Despite studies that show the antitumor activity of Hsp90 inhibitors, such as geldanamycin (GA) and its derivative 17-allylamino-demethoxygeldanamycin (17-AAG), recent reports indicate that these inhibitors lack significant single-agent clinical activity. Resistance to Hsp90 inhibitors has been previously linked to expression of P-glycoprotein (P-gp) and the multidrug resistant (MDR) phenotype. However, the stress response induced by GA treatment can also cause resistance to Hsp90-targeted therapy. Therefore, we chose to further investigate the relative importance of P-gp and the stress response in 17-AAG resistance. Colony-forming assays revealed that high expression of P-gp could increase the 17-AAG IC(50) 6-fold in cells transfected with P-gp compared with parent cells. A549 cells selected for resistance to GA overexpressed P-gp, but verapamil did not reverse the resistance. These cells also overexpressed Hsp27, and Hsp70 was induced with 17-AAG treatment. When the GA and 17-AAG resistant cells were transfected with Hsp27 and/or Hsp70 small interfering RNA (siRNA), the 17-AAG IC(50) decreased 10-fold compared with control transfected cells. Transfection with siRNA directed against Hsp27, Hsp70, or Hsp27 and Hsp70 also increased sensitivity to EC78, a purine scaffold-based Hsp90 inhibitor that is not a P-gp substrate. We conclude that P-gp may contribute, in part, to resistance to 17-AAG, but induction of stress response proteins, such as Hsp27 and Hsp70, by Hsp90-targeted therapy plays a larger role. Taken together, our results indicate that targeting of Hsp27 and Hsp70 should be exploited to increase the clinical efficacy of Hsp90-directed therapy.

Standard name | MCCOLLUM_GELDANAMYCIN_RESISTANCE_DN
Systematic name | M14386
Organism | Homo sapiens
PMID | 18794130
Authors | McCollum AK,TenEyck CJ,Stensgard B,Morlan BW,Ballman KV,Jenkins RB,Toft DO,Erlichman C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A549GARS cells (lung cancer) resistant to the geldanamycin and 17-AAG [PubChem=5476289;6440175].
Full description | Despite studies that show the antitumor activity of Hsp90 inhibitors, such as geldanamycin (GA) and its derivative 17-allylamino-demethoxygeldanamycin (17-AAG), recent reports indicate that these inhibitors lack significant single-agent clinical activity. Resistance to Hsp90 inhibitors has been previously linked to expression of P-glycoprotein (P-gp) and the multidrug resistant (MDR) phenotype. However, the stress response induced by GA treatment can also cause resistance to Hsp90-targeted therapy. Therefore, we chose to further investigate the relative importance of P-gp and the stress response in 17-AAG resistance. Colony-forming assays revealed that high expression of P-gp could increase the 17-AAG IC(50) 6-fold in cells transfected with P-gp compared with parent cells. A549 cells selected for resistance to GA overexpressed P-gp, but verapamil did not reverse the resistance. These cells also overexpressed Hsp27, and Hsp70 was induced with 17-AAG treatment. When the GA and 17-AAG resistant cells were transfected with Hsp27 and/or Hsp70 small interfering RNA (siRNA), the 17-AAG IC(50) decreased 10-fold compared with control transfected cells. Transfection with siRNA directed against Hsp27, Hsp70, or Hsp27 and Hsp70 also increased sensitivity to EC78, a purine scaffold-based Hsp90 inhibitor that is not a P-gp substrate. We conclude that P-gp may contribute, in part, to resistance to 17-AAG, but induction of stress response proteins, such as Hsp27 and Hsp70, by Hsp90-targeted therapy plays a larger role. Taken together, our results indicate that targeting of Hsp27 and Hsp70 should be exploited to increase the clinical efficacy of Hsp90-directed therapy.

Standard name | CREIGHTON_ENDOCRINE_THERAPY_RESISTANCE_1
Systematic name | M12522
Organism | Homo sapiens
PMID | 18794137
Authors | Creighton CJ,Massarweh S,Huang S,Tsimelzon A,Hilsenbeck SG,Osborne CK,Shou J,Malorni L,Schiff R
Category | C2
Sub-category | CGP
Brief description | The 'group 1 set' of genes associated with acquired endocrine therapy resistance in breast tumors expressing ESR1 and ERBB2 [GeneID=2099;2064].
Full description | The effectiveness of therapies targeting specific pathways in breast cancer, such as the estrogen receptor or HER2, is limited because many tumors manifest resistance, either de novo or acquired, during the course of treatment. To investigate molecular mechanisms of resistance, we used two xenograft models of estrogen receptor-positive (ER+) breast cancer, one with and one without HER2 overexpression (MCF7/HER2-18 and MCF7 wt, respectively). Mice with established tumors were assigned to the following treatment groups: estrogen supplementation (E2), estrogen deprivation (ED), ED plus tamoxifen (Tam), all with or without the epidermal growth factor receptor tyrosine kinase inhibitor gefitinib (G). Another group received ED plus the antiestrogen fulvestrant (MCF7 wt only). Tumors with acquired or de novo resistance to these endocrine therapies were profiled for gene expression and compared with tumors in the E2 control group. One class of genes underexpressed in endocrine-resistant tumors (relative to E2-treated tumors) were estrogen inducible in vitro and associated with ER+ human breast cancers (luminal subtype). Another class of genes overexpressed in tumors with acquired resistance in both models represented transcriptional targets of HER2 signaling and was associated with ER-/HER2+ human cancers (ERBB2+ subtype). A third class of genes overexpressed in MCF7/HER2-18 tumors exhibiting de novo resistance to tamoxifen was associated with ER+ human cancers but not with estrogen-regulated genes. Thus, in response to various endocrine therapy regimens, these xenograft breast tumors shut down classic estrogen signaling and activate alternative pathways such as HER2 that contribute to treatment resistance. Over time, the molecular phenotype of breast cancer can change.

Standard name | CREIGHTON_ENDOCRINE_THERAPY_RESISTANCE_2
Systematic name | M3062
Organism | Homo sapiens
PMID | 18794137
Authors | Creighton CJ,Massarweh S,Huang S,Tsimelzon A,Hilsenbeck SG,Osborne CK,Shou J,Malorni L,Schiff R
Category | C2
Sub-category | CGP
Brief description | The 'group 2 set' of genes associated with acquired endocrine therapy resistance in breast tumors expressing ESR1 and ERBB2 [GeneID=2099;2064].
Full description | The effectiveness of therapies targeting specific pathways in breast cancer, such as the estrogen receptor or HER2, is limited because many tumors manifest resistance, either de novo or acquired, during the course of treatment. To investigate molecular mechanisms of resistance, we used two xenograft models of estrogen receptor-positive (ER+) breast cancer, one with and one without HER2 overexpression (MCF7/HER2-18 and MCF7 wt, respectively). Mice with established tumors were assigned to the following treatment groups: estrogen supplementation (E2), estrogen deprivation (ED), ED plus tamoxifen (Tam), all with or without the epidermal growth factor receptor tyrosine kinase inhibitor gefitinib (G). Another group received ED plus the antiestrogen fulvestrant (MCF7 wt only). Tumors with acquired or de novo resistance to these endocrine therapies were profiled for gene expression and compared with tumors in the E2 control group. One class of genes underexpressed in endocrine-resistant tumors (relative to E2-treated tumors) were estrogen inducible in vitro and associated with ER+ human breast cancers (luminal subtype). Another class of genes overexpressed in tumors with acquired resistance in both models represented transcriptional targets of HER2 signaling and was associated with ER-/HER2+ human cancers (ERBB2+ subtype). A third class of genes overexpressed in MCF7/HER2-18 tumors exhibiting de novo resistance to tamoxifen was associated with ER+ human cancers but not with estrogen-regulated genes. Thus, in response to various endocrine therapy regimens, these xenograft breast tumors shut down classic estrogen signaling and activate alternative pathways such as HER2 that contribute to treatment resistance. Over time, the molecular phenotype of breast cancer can change.

Standard name | CREIGHTON_ENDOCRINE_THERAPY_RESISTANCE_3
Systematic name | M4210
Organism | Homo sapiens
PMID | 18794137
Authors | Creighton CJ,Massarweh S,Huang S,Tsimelzon A,Hilsenbeck SG,Osborne CK,Shou J,Malorni L,Schiff R
Category | C2
Sub-category | CGP
Brief description | The 'group 3 set' of genes associated with acquired endocrine therapy resistance in breast tumors expressing ESR1 and ERBB2 [GeneID=2099;2064].
Full description | The effectiveness of therapies targeting specific pathways in breast cancer, such as the estrogen receptor or HER2, is limited because many tumors manifest resistance, either de novo or acquired, during the course of treatment. To investigate molecular mechanisms of resistance, we used two xenograft models of estrogen receptor-positive (ER+) breast cancer, one with and one without HER2 overexpression (MCF7/HER2-18 and MCF7 wt, respectively). Mice with established tumors were assigned to the following treatment groups: estrogen supplementation (E2), estrogen deprivation (ED), ED plus tamoxifen (Tam), all with or without the epidermal growth factor receptor tyrosine kinase inhibitor gefitinib (G). Another group received ED plus the antiestrogen fulvestrant (MCF7 wt only). Tumors with acquired or de novo resistance to these endocrine therapies were profiled for gene expression and compared with tumors in the E2 control group. One class of genes underexpressed in endocrine-resistant tumors (relative to E2-treated tumors) were estrogen inducible in vitro and associated with ER+ human breast cancers (luminal subtype). Another class of genes overexpressed in tumors with acquired resistance in both models represented transcriptional targets of HER2 signaling and was associated with ER-/HER2+ human cancers (ERBB2+ subtype). A third class of genes overexpressed in MCF7/HER2-18 tumors exhibiting de novo resistance to tamoxifen was associated with ER+ human cancers but not with estrogen-regulated genes. Thus, in response to various endocrine therapy regimens, these xenograft breast tumors shut down classic estrogen signaling and activate alternative pathways such as HER2 that contribute to treatment resistance. Over time, the molecular phenotype of breast cancer can change.

Standard name | CREIGHTON_ENDOCRINE_THERAPY_RESISTANCE_4
Systematic name | M6386
Organism | Homo sapiens
PMID | 18794137
Authors | Creighton CJ,Massarweh S,Huang S,Tsimelzon A,Hilsenbeck SG,Osborne CK,Shou J,Malorni L,Schiff R
Category | C2
Sub-category | CGP
Brief description | The 'group 4 set' of genes associated with acquired endocrine therapy resistance in breast tumors expressing ESR1 but not ERBB2 [GeneID=2099;2064].
Full description | The effectiveness of therapies targeting specific pathways in breast cancer, such as the estrogen receptor or HER2, is limited because many tumors manifest resistance, either de novo or acquired, during the course of treatment. To investigate molecular mechanisms of resistance, we used two xenograft models of estrogen receptor-positive (ER+) breast cancer, one with and one without HER2 overexpression (MCF7/HER2-18 and MCF7 wt, respectively). Mice with established tumors were assigned to the following treatment groups: estrogen supplementation (E2), estrogen deprivation (ED), ED plus tamoxifen (Tam), all with or without the epidermal growth factor receptor tyrosine kinase inhibitor gefitinib (G). Another group received ED plus the antiestrogen fulvestrant (MCF7 wt only). Tumors with acquired or de novo resistance to these endocrine therapies were profiled for gene expression and compared with tumors in the E2 control group. One class of genes underexpressed in endocrine-resistant tumors (relative to E2-treated tumors) were estrogen inducible in vitro and associated with ER+ human breast cancers (luminal subtype). Another class of genes overexpressed in tumors with acquired resistance in both models represented transcriptional targets of HER2 signaling and was associated with ER-/HER2+ human cancers (ERBB2+ subtype). A third class of genes overexpressed in MCF7/HER2-18 tumors exhibiting de novo resistance to tamoxifen was associated with ER+ human cancers but not with estrogen-regulated genes. Thus, in response to various endocrine therapy regimens, these xenograft breast tumors shut down classic estrogen signaling and activate alternative pathways such as HER2 that contribute to treatment resistance. Over time, the molecular phenotype of breast cancer can change.

Standard name | CREIGHTON_ENDOCRINE_THERAPY_RESISTANCE_5
Systematic name | M13661
Organism | Homo sapiens
PMID | 18794137
Authors | Creighton CJ,Massarweh S,Huang S,Tsimelzon A,Hilsenbeck SG,Osborne CK,Shou J,Malorni L,Schiff R
Category | C2
Sub-category | CGP
Brief description | The 'group 5 set' of genes associated with acquired endocrine therapy resistance in breast tumors expressing ESR1 but not ERBB2 [GeneID=2099;2064].
Full description | The effectiveness of therapies targeting specific pathways in breast cancer, such as the estrogen receptor or HER2, is limited because many tumors manifest resistance, either de novo or acquired, during the course of treatment. To investigate molecular mechanisms of resistance, we used two xenograft models of estrogen receptor-positive (ER+) breast cancer, one with and one without HER2 overexpression (MCF7/HER2-18 and MCF7 wt, respectively). Mice with established tumors were assigned to the following treatment groups: estrogen supplementation (E2), estrogen deprivation (ED), ED plus tamoxifen (Tam), all with or without the epidermal growth factor receptor tyrosine kinase inhibitor gefitinib (G). Another group received ED plus the antiestrogen fulvestrant (MCF7 wt only). Tumors with acquired or de novo resistance to these endocrine therapies were profiled for gene expression and compared with tumors in the E2 control group. One class of genes underexpressed in endocrine-resistant tumors (relative to E2-treated tumors) were estrogen inducible in vitro and associated with ER+ human breast cancers (luminal subtype). Another class of genes overexpressed in tumors with acquired resistance in both models represented transcriptional targets of HER2 signaling and was associated with ER-/HER2+ human cancers (ERBB2+ subtype). A third class of genes overexpressed in MCF7/HER2-18 tumors exhibiting de novo resistance to tamoxifen was associated with ER+ human cancers but not with estrogen-regulated genes. Thus, in response to various endocrine therapy regimens, these xenograft breast tumors shut down classic estrogen signaling and activate alternative pathways such as HER2 that contribute to treatment resistance. Over time, the molecular phenotype of breast cancer can change.

Standard name | MILICIC_FAMILIAL_ADENOMATOUS_POLYPOSIS_UP
Systematic name | M9371
Organism | Homo sapiens
PMID | 18829530
Authors | Milicic A,Harrison LA,Goodlad RA,Hardy RG,Nicholson AM,Presz M,Sieber O,Santander S,Pringle JH,Mandir N,East P,Obszynska J,Sanders S,Piazuelo E,Shaw J,Harrison R,Tomlinson IP,McDonald SA,Wright NA,Jankowski JA
Category | C2
Sub-category | CGP
Brief description | Top genes up-regulated in colon epithelium biopsies from FAP (familial adenomatous polyposis) patients with mutated APC [GeneID=324].
Full description | P-cadherin is normally expressed in the basal layer of squamous epithelia and absent from the healthy intestine and colon. We have previously shown it to be expressed in all inflamed, hyperplastic, and dysplastic intestinal and colonic mucosa. This study aimed to better understand the mechanisms controlling the expression of P-cadherin and the biological effects of its ectopic presence in the intestine and colon. We investigated the CpG methylation status of the P-cadherin (CDH3) promoter and P-cadherin mRNA and protein expression in cases of familial and sporadic colorectal cancer (CRC). The CDH3 promoter was hypomethylated in colonic aberrant crypt foci, in CRC, and, occasionally, in the normal epithelium adjacent to cancer, demonstrating a potential field effect of cancerization. The hypomethylation was also associated with induction of P-cadherin expression in the neoplastic colon (P < 0.0001). We then created transgenic mice that overexpressed P-cadherin specifically in the intestinal and colonic epithelium under the liver fatty acid binding protein promoter. Forced ectopic expression of P-cadherin accompanied by indomethacin-induced inflammation resulted in a 3-fold higher crypt fission rate within the small and large intestines in the homozygous mice compared with the wild-type animals (P < 0.02). We conclude that epigenetic demethylation of the P-cadherin promoter in the human intestine permits its ectopic expression very early in the colorectal adenoma-carcinoma sequence and persists during invasive cancer. Induced P-cadherin expression, especially in mucosal damage, leads to an increased rate of crypt fission, a common feature of clonal expansion in gastrointestinal dysplasia.

Standard name | MILICIC_FAMILIAL_ADENOMATOUS_POLYPOSIS_DN
Systematic name | M6706
Organism | Homo sapiens
PMID | 18829530
Authors | Milicic A,Harrison LA,Goodlad RA,Hardy RG,Nicholson AM,Presz M,Sieber O,Santander S,Pringle JH,Mandir N,East P,Obszynska J,Sanders S,Piazuelo E,Shaw J,Harrison R,Tomlinson IP,McDonald SA,Wright NA,Jankowski JA
Category | C2
Sub-category | CGP
Brief description | Top genes down-regulated in colon epithelium biopsies from FAP (familial adenomatous polyposis) patients with mutated APC [GeneID=324].
Full description | P-cadherin is normally expressed in the basal layer of squamous epithelia and absent from the healthy intestine and colon. We have previously shown it to be expressed in all inflamed, hyperplastic, and dysplastic intestinal and colonic mucosa. This study aimed to better understand the mechanisms controlling the expression of P-cadherin and the biological effects of its ectopic presence in the intestine and colon. We investigated the CpG methylation status of the P-cadherin (CDH3) promoter and P-cadherin mRNA and protein expression in cases of familial and sporadic colorectal cancer (CRC). The CDH3 promoter was hypomethylated in colonic aberrant crypt foci, in CRC, and, occasionally, in the normal epithelium adjacent to cancer, demonstrating a potential field effect of cancerization. The hypomethylation was also associated with induction of P-cadherin expression in the neoplastic colon (P < 0.0001). We then created transgenic mice that overexpressed P-cadherin specifically in the intestinal and colonic epithelium under the liver fatty acid binding protein promoter. Forced ectopic expression of P-cadherin accompanied by indomethacin-induced inflammation resulted in a 3-fold higher crypt fission rate within the small and large intestines in the homozygous mice compared with the wild-type animals (P < 0.02). We conclude that epigenetic demethylation of the P-cadherin promoter in the human intestine permits its ectopic expression very early in the colorectal adenoma-carcinoma sequence and persists during invasive cancer. Induced P-cadherin expression, especially in mucosal damage, leads to an increased rate of crypt fission, a common feature of clonal expansion in gastrointestinal dysplasia.

Standard name | SINGH_NFE2L2_TARGETS
Systematic name | M2662
Organism | Homo sapiens
PMID | 18829555
Authors | Singh A,Boldin-Adamsky S,Thimmulappa RK,Rath SK,Ashush H,Coulter J,Blackford A,Goodman SN,Bunz F,Watson WH,Gabrielson E,Feinstein E,Biswal S
Category | C2
Sub-category | CGP
Brief description | Selected electrophile and drug detoxication genes down-regulated in A549 and H460 cells (lung cancer) upon knockdown of NFE2L2 [GeneID=4780] by RNAi.
Full description | Nuclear factor erythroid-2-related factor 2 (Nrf2) is a redox-sensitive transcription factor that regulates the expression of electrophile and xenobiotic detoxification enzymes and efflux proteins, which confer cytoprotection against oxidative stress and apoptosis in normal cells. Loss of function mutations in the Nrf2 inhibitor, Kelch-like ECH-associated protein (Keap1), results in constitutive activation of Nrf2 function in non-small cell lung cancer. In this study, we show that constitutive activation of Nrf2 in lung cancer cells promotes tumorigenicity and contributes to chemoresistance by up-regulation of glutathione, thioredoxin, and the drug efflux pathways involved in detoxification of electrophiles and broad spectrum of drugs. RNAi-mediated reduction of Nrf2 expression in lung cancer cells induces generation of reactive oxygen species, suppresses tumor growth, and results in increased sensitivity to chemotherapeutic drug-induced cell death in vitro and in vivo. Inhibiting Nrf2 expression using naked siRNA duplexes in combination with carboplatin significantly inhibits tumor growth in a subcutaneous model of lung cancer. Thus, targeting Nrf2 activity in lung cancers, particularly those with Keap1 mutations, could be a promising strategy to inhibit tumor growth and circumvent chemoresistance.

Standard name | PELLICCIOTTA_HDAC_IN_ANTIGEN_PRESENTATION_UP
Systematic name | M7488
Organism | Homo sapiens
PMID | 18829567
Authors | Pellicciotta I,Cortez-Gonzalez X,Sasik R,Reiter Y,Hardiman G,Langlade-Demoyen P,Zanetti M
Category | C2
Sub-category | CGP
Brief description | Antigen processing and presentation genes up-regulated in JY cells (B lymphocytes) treated with TSA [PubChem=5562].
Full description | Histone deacetylases (HDAC) modify the architecture of chromatin, leading to decreased gene expression, an effect that is reversed by HDAC inhibition. The balance between deacetylation and acetylation is central to many biological events including the regulation of cell proliferation and cancer but also the differentiation of immune T cells. The effects of HDAC inhibition on the interaction between antitumor effector T cells and tumor cells are not known. Here, we studied presentation of a universal self-tumor antigen, telomerase reverse transcriptase, in human tumor cells during HDAC inhibition. We found that HDAC inhibition with trichostatin A was associated with a decreased presentation and diminished killing of tumor cells by CTLs. Using gene array analysis, we found that HDAC inhibition resulted in a decrease of genes coding for proteasome catalytic proteins and for tapasin, an endoplasmic reticulum resident protein involved in the MHC class I pathway of endogenous antigen presentation. Our findings indicate that epigenetic changes in tumor cells decrease self-tumor antigen presentation and contribute to reduced recognition and killing of tumor cells by cytotoxic T lymphocytes. This mechanism could contribute to tumor escape from immune surveillance.

Standard name | PELLICCIOTTA_HDAC_IN_ANTIGEN_PRESENTATION_DN
Systematic name | M8341
Organism | Homo sapiens
PMID | 18829567
Authors | Pellicciotta I,Cortez-Gonzalez X,Sasik R,Reiter Y,Hardiman G,Langlade-Demoyen P,Zanetti M
Category | C2
Sub-category | CGP
Brief description | Antigen processing and presentation genes down-regulated in JY cells (B lymphocytes) treated with trichostatin A (TSA) [PubChem=5562].
Full description | Histone deacetylases (HDAC) modify the architecture of chromatin, leading to decreased gene expression, an effect that is reversed by HDAC inhibition. The balance between deacetylation and acetylation is central to many biological events including the regulation of cell proliferation and cancer but also the differentiation of immune T cells. The effects of HDAC inhibition on the interaction between antitumor effector T cells and tumor cells are not known. Here, we studied presentation of a universal self-tumor antigen, telomerase reverse transcriptase, in human tumor cells during HDAC inhibition. We found that HDAC inhibition with trichostatin A was associated with a decreased presentation and diminished killing of tumor cells by CTLs. Using gene array analysis, we found that HDAC inhibition resulted in a decrease of genes coding for proteasome catalytic proteins and for tapasin, an endoplasmic reticulum resident protein involved in the MHC class I pathway of endogenous antigen presentation. Our findings indicate that epigenetic changes in tumor cells decrease self-tumor antigen presentation and contribute to reduced recognition and killing of tumor cells by cytotoxic T lymphocytes. This mechanism could contribute to tumor escape from immune surveillance.

Standard name | LOPES_METHYLATED_IN_COLON_CANCER_UP
Systematic name | M7371
Organism | Homo sapiens
PMID | 18794111
Authors | Lopes EC,Valls E,Figueroa ME,Mazur A,Meng FG,Chiosis G,Laird PW,Schreiber-Agus N,Greally JM,Prokhortchouk E,Melnick A
Category | C2
Sub-category | CGP
Brief description | Genes methylated aberrantly in HCT116 and Colo320 (colon cancer) cells.
Full description | Aberrant CpG methylation of tumor suppressor gene regulatory elements is associated with transcriptional silencing and contributes to malignant transformation of different tissues. It is presumed that methylated DNA sequences recruit repressor machinery to actively shutdown gene expression. The Kaiso protein is a transcriptional repressor expressed in human and murine colorectal tumors that can bind to methylated clusters of CpG dinucleotides. We show here that Kaiso represses methylated tumor suppressor genes and can bind in a methylation-dependent manner to the CDKN2A in human colon cancer cell lines. The contribution of Kaiso to epigenetic silencing was underlined by the fact that Kaiso depletion induced tumor suppressor gene expression without affecting DNA methylation levels. As a consequence, colon cancer cells became susceptible to cell cycle arrest and cell death mediated by chemotherapy. The data suggest that Kaiso is a methylation-dependent opportunistic oncogene that silences tumor suppressor genes when they become hypermethylated. Because Kaiso inactivation sensitized colon cancer cell lines to chemotherapy, it is possible that therapeutic targeting of Kaiso could improve the efficacy of current treatment regimens.

Standard name | LOPES_METHYLATED_IN_COLON_CANCER_DN
Systematic name | M12717
Organism | Homo sapiens
PMID | 18794111
Authors | Lopes EC,Valls E,Figueroa ME,Mazur A,Meng FG,Chiosis G,Laird PW,Schreiber-Agus N,Greally JM,Prokhortchouk E,Melnick A
Category | C2
Sub-category | CGP
Brief description | Genes un-methylated aberrantly in HCT116 and Colo320 (colon cancer) cells.
Full description | Aberrant CpG methylation of tumor suppressor gene regulatory elements is associated with transcriptional silencing and contributes to malignant transformation of different tissues. It is presumed that methylated DNA sequences recruit repressor machinery to actively shutdown gene expression. The Kaiso protein is a transcriptional repressor expressed in human and murine colorectal tumors that can bind to methylated clusters of CpG dinucleotides. We show here that Kaiso represses methylated tumor suppressor genes and can bind in a methylation-dependent manner to the CDKN2A in human colon cancer cell lines. The contribution of Kaiso to epigenetic silencing was underlined by the fact that Kaiso depletion induced tumor suppressor gene expression without affecting DNA methylation levels. As a consequence, colon cancer cells became susceptible to cell cycle arrest and cell death mediated by chemotherapy. The data suggest that Kaiso is a methylation-dependent opportunistic oncogene that silences tumor suppressor genes when they become hypermethylated. Because Kaiso inactivation sensitized colon cancer cell lines to chemotherapy, it is possible that therapeutic targeting of Kaiso could improve the efficacy of current treatment regimens.

Standard name | HARRIS_BRAIN_CANCER_PROGENITORS
Systematic name | M1694
Organism | Mus musculus
PMID | 19074870
Authors | Harris MA,Yang H,Low BE,Mukherje J,Guha A,Bronson RT,Shultz LD,Israel MA,Yun K
Category | C2
Sub-category | CGP
Brief description | Genes from the brain cancer stem (cancer stem cell, CSC) signature.
Full description | The recent identification of cancer stem cells (CSCs) in multiple human cancers provides a new inroad to understanding tumorigenesis at the cellular level. CSCs are defined by their characteristics of self-renewal, multipotentiality, and tumor initiation upon transplantation. By testing for these defining characteristics, we provide evidence for the existence of CSCs in a transgenic mouse model of glioma, S100beta-verbB;Trp53. In this glioma model, CSCs are enriched in the side population (SP) cells. These SP cells have enhanced tumor-initiating capacity, self-renewal, and multipotentiality compared with non-SP cells from the same tumors. Furthermore, gene expression analysis comparing fluorescence-activated cell sorting-sorted cancer SP cells to non-SP cancer cells and normal neural SP cells identified 45 candidate genes that are differentially expressed in glioma stem cells. We validated the expression of two genes from this list (S100a4 and S100a6) in primary mouse gliomas and human glioma samples. Analyses of xenografted human glioblastoma multiforme cell lines and primary human glioma tissues show that S100A4 and S100A6 are expressed in a small subset of cancer cells and that their abundance is positively correlated to tumor grade. In conclusion, this study shows that CSCs exist in a mouse glioma model, suggesting that this model can be used to study the molecular and cellular characteristics of CSCs in vivo and to further test the CSC hypothesis.

Standard name | TUOMISTO_TUMOR_SUPPRESSION_BY_COL13A1_UP
Systematic name | M1695
Organism | Mus musculus
PMID | 19074901
Authors | Tuomisto A,Sund M,Tahkola J,Latvanlehto A,Savolainen ER,Autio-Harmainen H,Liakka A,Sormunen R,Vuoristo J,West A,Lahesmaa R,Morse HC 3rd,Pihlajaniemi T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in small intestine tissue from transgenic mice expressing a mutant form of COL13A1 [GeneID=1305], compared to normal controls.
Full description | Epithelial cells of mucosal surfaces are critical for maintaining immune homeostasis by aiding in the discrimination of pathogenic and commensal microorganisms and modulating the activities of antigen-presenting cells and lymphocytes. Functional breakdowns resulting in chronic infection and inflammation are associated with the development of hematologic and solid neoplasms for which detailed pathogenetic mechanisms are poorly understood. Mice heterozygous for a transgene Col13a1(del) expressing a mutant collagen XIII developed clonal mature B-cell lineage lymphomas originating in mesenteric lymph nodes (MLN). The tumors were associated with T cells and macrophages. The incidence of disease was reduced 2-fold in transgenic mice raised under specific pathogen-free conditions, suggesting a role for infectious agents. The lymphomas did not express the mutant collagen XIII, indicating that its influence on tumorigenesis was B-cell extrinsic and likely to be associated with collagen XIII-positive tissues drained by the MLN. Studies of the small intestines of transgenic mice showed that the subepithelial basement membranes (BM) were highly abnormal and that they exhibited heightened expression of genes involved in immune responses. These results define collagen XIII-dependent maintenance of the intestinal BM as a previously unappreciated component of immune responses and a critical determinant of cancer susceptibility.

Standard name | TUOMISTO_TUMOR_SUPPRESSION_BY_COL13A1_DN
Systematic name | M1697
Organism | Mus musculus
PMID | 19074901
Authors | Tuomisto A,Sund M,Tahkola J,Latvanlehto A,Savolainen ER,Autio-Harmainen H,Liakka A,Sormunen R,Vuoristo J,West A,Lahesmaa R,Morse HC 3rd,Pihlajaniemi T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in small intestine tissue from transgenic mice expressing a mutant form of COL13A1 [GeneID=1305], compared to normal controls.
Full description | Epithelial cells of mucosal surfaces are critical for maintaining immune homeostasis by aiding in the discrimination of pathogenic and commensal microorganisms and modulating the activities of antigen-presenting cells and lymphocytes. Functional breakdowns resulting in chronic infection and inflammation are associated with the development of hematologic and solid neoplasms for which detailed pathogenetic mechanisms are poorly understood. Mice heterozygous for a transgene Col13a1(del) expressing a mutant collagen XIII developed clonal mature B-cell lineage lymphomas originating in mesenteric lymph nodes (MLN). The tumors were associated with T cells and macrophages. The incidence of disease was reduced 2-fold in transgenic mice raised under specific pathogen-free conditions, suggesting a role for infectious agents. The lymphomas did not express the mutant collagen XIII, indicating that its influence on tumorigenesis was B-cell extrinsic and likely to be associated with collagen XIII-positive tissues drained by the MLN. Studies of the small intestines of transgenic mice showed that the subepithelial basement membranes (BM) were highly abnormal and that they exhibited heightened expression of genes involved in immune responses. These results define collagen XIII-dependent maintenance of the intestinal BM as a previously unappreciated component of immune responses and a critical determinant of cancer susceptibility.

Standard name | BAFNA_MUC4_TARGETS_UP
Systematic name | M1699
Organism | Mus musculus
PMID | 19010895
Authors | Bafna S,Singh AP,Moniaux N,Eudy JD,Meza JL,Batra SK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NIH3T3 cells (fibroblast) engineered to stably express MUC4 [GeneID=4585].
Full description | Numerous studies have established the association of MUC4 with the progression of cancer and metastasis. An aberrant expression of MUC4 is reported in precancerous lesions, indicating its early involvement in the disease process; however, its precise role in cellular transformation has not been explored. MUC4 contains many unique domains and is proposed to affect cell signaling pathways and behavior of the tumor cells. In the present study, to decipher the oncogenic potential of MUC4, we stably expressed the MUC4 mucin in NIH3T3 mouse fibroblast cells. Stable ectopic expression of MUC4 resulted in increased growth, colony formation, and motility of NIH3T3 cells in vitro and tumor formation in nude mice when cells were injected s.c. Microarray analysis showed increased expression of several growth-associated and mitochondrial energy production-associated genes in MUC4-expressing NIH3T3 cells. In addition, expression of MUC4 in NIH3T3 cells resulted in enhanced levels of oncoprotein ErbB2 and its phosphorylated form (pY(1248)-ErbB2). In conclusion, our studies provide the first evidence that MUC4 alone induces cellular transformation and indicates a novel role of MUC4 in cancer biology.

Standard name | HOWLIN_CITED1_TARGETS_1_UP
Systematic name | M1701
Organism | Mus musculus
PMID | 16278680
Authors | Howlin J,McBryan J,Napoletano S,Lambe T,McArdle E,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mammary glands from the CITED1 [GeneID=4435] knockout mice: homozygotic vs. heterozygotic animals.
Full description | Expression microarray analysis identified CITED1 among a group of genes specifically upregulated in the pubertal mouse mammary gland. At puberty, CITED1 localizes to the luminal epithelial cell population of the mammary ducts and the body cells of the terminal end buds. Generation of CITED1 gene knockout mice showed that homozygous null mutants exhibit retarded mammary ductal growth at puberty and, in addition, dilated ductal structures with a lack of spatial restriction of the subtending branches. Analysis of CITED1 homozygous null and heterozygous null mammary gland gene expression using microarrays suggested that the mammary-specific phenotype seen in the homozygous null females is due to a disturbance in the transcription of a number of key mediators of pubertal ductal morphogenesis. These include estrogen and TGFbeta responsive genes, such as the EGFR/ErbB2 ligand, amphiregulin, whose transcription we suggest is directly or indirectly regulated by CITED1.

Standard name | HOWLIN_CITED1_TARGETS_1_DN
Systematic name | M1703
Organism | Mus musculus
PMID | 16278680
Authors | Howlin J,McBryan J,Napoletano S,Lambe T,McArdle E,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mammary glands from the CITED1 [GeneID=4435] knockout mice: homozygotic vs. heterozygotic animals.
Full description | Expression microarray analysis identified CITED1 among a group of genes specifically upregulated in the pubertal mouse mammary gland. At puberty, CITED1 localizes to the luminal epithelial cell population of the mammary ducts and the body cells of the terminal end buds. Generation of CITED1 gene knockout mice showed that homozygous null mutants exhibit retarded mammary ductal growth at puberty and, in addition, dilated ductal structures with a lack of spatial restriction of the subtending branches. Analysis of CITED1 homozygous null and heterozygous null mammary gland gene expression using microarrays suggested that the mammary-specific phenotype seen in the homozygous null females is due to a disturbance in the transcription of a number of key mediators of pubertal ductal morphogenesis. These include estrogen and TGFbeta responsive genes, such as the EGFR/ErbB2 ligand, amphiregulin, whose transcription we suggest is directly or indirectly regulated by CITED1.

Standard name | HOWLIN_CITED1_TARGETS_2_UP
Systematic name | M1704
Organism | Mus musculus
PMID | 16278680
Authors | Howlin J,McBryan J,Napoletano S,Lambe T,McArdle E,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mammary glands from the CITED1 [GeneID=4435] knockout mice: homozygotic vs wild type (WT) animals.
Full description | Expression microarray analysis identified CITED1 among a group of genes specifically upregulated in the pubertal mouse mammary gland. At puberty, CITED1 localizes to the luminal epithelial cell population of the mammary ducts and the body cells of the terminal end buds. Generation of CITED1 gene knockout mice showed that homozygous null mutants exhibit retarded mammary ductal growth at puberty and, in addition, dilated ductal structures with a lack of spatial restriction of the subtending branches. Analysis of CITED1 homozygous null and heterozygous null mammary gland gene expression using microarrays suggested that the mammary-specific phenotype seen in the homozygous null females is due to a disturbance in the transcription of a number of key mediators of pubertal ductal morphogenesis. These include estrogen and TGFbeta responsive genes, such as the EGFR/ErbB2 ligand, amphiregulin, whose transcription we suggest is directly or indirectly regulated by CITED1.

Standard name | HOWLIN_CITED1_TARGETS_2_DN
Systematic name | M1708
Organism | Mus musculus
PMID | 16278680
Authors | Howlin J,McBryan J,Napoletano S,Lambe T,McArdle E,Shioda T,Martin F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mammary glands from the CITED1 [GeneID=4435] knockout mice: homozygotic vs wild type (WT) animals.
Full description | Expression microarray analysis identified CITED1 among a group of genes specifically upregulated in the pubertal mouse mammary gland. At puberty, CITED1 localizes to the luminal epithelial cell population of the mammary ducts and the body cells of the terminal end buds. Generation of CITED1 gene knockout mice showed that homozygous null mutants exhibit retarded mammary ductal growth at puberty and, in addition, dilated ductal structures with a lack of spatial restriction of the subtending branches. Analysis of CITED1 homozygous null and heterozygous null mammary gland gene expression using microarrays suggested that the mammary-specific phenotype seen in the homozygous null females is due to a disturbance in the transcription of a number of key mediators of pubertal ductal morphogenesis. These include estrogen and TGFbeta responsive genes, such as the EGFR/ErbB2 ligand, amphiregulin, whose transcription we suggest is directly or indirectly regulated by CITED1.

Standard name | HILLION_HMGA1_TARGETS
Systematic name | M1709
Organism | Rattus norvegicus
PMID | 19074878
Authors | Hillion J,Dhara S,Sumter TF,Mukherjee M,Di Cello F,Belton A,Turkson J,Jaganathan S,Cheng L,Ye Z,Jove R,Aplan P,Lin YW,Wertzler K,Reeves R,Elbahlouh O,Kowalski J,Bhattacharya R,Resar LM
Category | C2
Sub-category | CGP
Brief description | Genes changed in Rat1a cells (fibroblasts) by overexpression of HMGA1 isoform a [GeneID=3159] off a plasmid vector.
Full description | Although HMGA1 (high-mobility group A1; formerly HMG-I/Y) is an oncogene that is widely overexpressed in aggressive cancers, the molecular mechanisms underlying transformation by HMGA1 are only beginning to emerge. HMGA1 encodes the HMGA1a and HMGA1b protein isoforms, which function in regulating gene expression. To determine how HMGA1 leads to neoplastic transformation, we looked for genes regulated by HMGA1 using gene expression profile analysis. Here, we show that the STAT3 gene, which encodes the signaling molecule signal transducer and activator of transcription 3 (STAT3), is a critical downstream target of HMGA1a. STAT3 mRNA and protein are up-regulated in fibroblasts overexpressing HMGA1a and activated STAT3 recapitulates the transforming activity of HMGA1a in fibroblasts. HMGA1a also binds directly to a conserved region of the STAT3 promoter in vivo in human leukemia cells by chromatin immunoprecipitation and activates transcription of the STAT3 promoter in transfection experiments. To determine if this pathway contributes to HMGA1-mediated transformation, we investigated STAT3 expression in our HMGA1a transgenic mice, all of which developed aggressive lymphoid malignancy. STAT3 expression was increased in the leukemia cells from our transgenics but not in control cells. Blocking STAT3 function induced apoptosis in the transgenic leukemia cells but not in controls. In primary human leukemia samples, there was a positive correlation between HMGA1a and STAT3 mRNA. Moreover, blocking STAT3 function in human leukemia or lymphoma cells led to decreased cellular motility and foci formation. Our results show that the HMGA1a-STAT3 axis is a potential Achilles heel that could be exploited therapeutically in hematopoietic and other malignancies overexpressing HMGA1a.

Standard name | HILLION_HMGA1B_TARGETS
Systematic name | M1710
Organism | Rattus norvegicus
PMID | 19074878
Authors | Hillion J,Dhara S,Sumter TF,Mukherjee M,Di Cello F,Belton A,Turkson J,Jaganathan S,Cheng L,Ye Z,Jove R,Aplan P,Lin YW,Wertzler K,Reeves R,Elbahlouh O,Kowalski J,Bhattacharya R,Resar LM
Category | C2
Sub-category | CGP
Brief description | Genes changed in Rat1a cells (fibroblasts) by overexpression of HMGA1 isoform b [GeneID=3159] off a plasmid vector.
Full description | Although HMGA1 (high-mobility group A1; formerly HMG-I/Y) is an oncogene that is widely overexpressed in aggressive cancers, the molecular mechanisms underlying transformation by HMGA1 are only beginning to emerge. HMGA1 encodes the HMGA1a and HMGA1b protein isoforms, which function in regulating gene expression. To determine how HMGA1 leads to neoplastic transformation, we looked for genes regulated by HMGA1 using gene expression profile analysis. Here, we show that the STAT3 gene, which encodes the signaling molecule signal transducer and activator of transcription 3 (STAT3), is a critical downstream target of HMGA1a. STAT3 mRNA and protein are up-regulated in fibroblasts overexpressing HMGA1a and activated STAT3 recapitulates the transforming activity of HMGA1a in fibroblasts. HMGA1a also binds directly to a conserved region of the STAT3 promoter in vivo in human leukemia cells by chromatin immunoprecipitation and activates transcription of the STAT3 promoter in transfection experiments. To determine if this pathway contributes to HMGA1-mediated transformation, we investigated STAT3 expression in our HMGA1a transgenic mice, all of which developed aggressive lymphoid malignancy. STAT3 expression was increased in the leukemia cells from our transgenics but not in control cells. Blocking STAT3 function induced apoptosis in the transgenic leukemia cells but not in controls. In primary human leukemia samples, there was a positive correlation between HMGA1a and STAT3 mRNA. Moreover, blocking STAT3 function in human leukemia or lymphoma cells led to decreased cellular motility and foci formation. Our results show that the HMGA1a-STAT3 axis is a potential Achilles heel that could be exploited therapeutically in hematopoietic and other malignancies overexpressing HMGA1a.

Standard name | DACOSTA_UV_RESPONSE_VIA_ERCC3_COMMON_UP
Systematic name | M14046
Organism | Homo sapiens
PMID | 15608684
Authors | da Costa RM,Riou L,Paquola A,Menck CF,Sarasin A
Category | C2
Sub-category | CGP
Brief description | Common up-regulated transcripts in fibroblasts expressing either XP/CS or TDD mutant forms of ERCC3 [GeneID=2071], after UVC irradiation.
Full description | Xeroderma pigmentosum (XP) and trichothiodystrophy (TTD) syndromes are characterized by deficiency in nucleotide excision repair pathway, but with distinguished clinical manifestations. While XP patients exhibit a high frequency of skin cancer, TTD patients are not cancer prone. The relation between lack of DNA repair and their clinical manifestations was investigated through analysis of the transcriptional profile of 12,600 transcripts in two isogenic cell lines with different capabilities of DNA repair. These cell lines result from a stable transfection of the XPB-TTD allele into XP complementation group B fibroblasts, from an XP patient who also have clinical abnormalities corresponding to Cockayne's syndrome (CS). The microarray assays performed under normal growth conditions showed the expression of distinct groups of genes in each cell line. The UVC-transcription modulation of these cells revealed the changes in 869 transcripts. Some of these transcripts had similar modulation pattern in both cells, although with eventually different time patterns for induction or repression. However, some different 'UVC signature' for each cell line was also found, that is, transcripts that were specifically UV regulated depending on the DNA repair status of the cell. These results provide a detailed portrait of expression profiles that may potentially unravel the causes of the different phenotypes of XP/CS and TTD patients.

Standard name | LEIN_NEURON_MARKERS
Systematic name | M1712
Organism | Mus musculus
PMID | 17151600
Authors | Lein ES,Hawrylycz MJ,Ao N,Ayres M,Bensinger A,Bernard A,Boe AF,Boguski MS,Brockway KS,Byrnes EJ,Chen L,Chen TM,Chin MC,Chong J,Crook BE,Czaplinska A,Dang CN,Datta S,Dee NR,Desaki AL,Desta T,Diep E,Dolbeare TA,Donelan MJ,Dong HW,Dougherty JG,Duncan BJ,Ebbert AJ,Eichele G,Estin LK,Faber C,Facer BA,Fields R,Fischer SR,Fliss TP,Frensley C,Gates SN,Glattfelder KJ,Halverson KR,Hart MR,Hohmann JG,Howell MP,Jeung DP,Johnson RA,Karr PT,Kawal R,Kidney JM,Knapik RH,Kuan CL,Lake JH,Laramee AR,Larsen KD,Lau C,Lemon TA,Liang AJ,Liu Y,Luong LT,Michaels J,Morgan JJ,Morgan RJ,Mortrud MT,Mosqueda NF,Ng LL,Ng R,Orta GJ,Overly CC,Pak TH,Parry SE,Pathak SD,Pearson OC,Puchalski RB,Riley ZL,Rockett HR,Rowland SA,Royall JJ,Ruiz MJ,Sarno NR,Schaffnit K,Shapovalova NV,Sivisay T,Slaughterbeck CR,Smith SC,Smith KA,Smith BI,Sodt AJ,Stewart NN,Stumpf KR,Sunkin SM,Sutram M,Tam A,Teemer CD,Thaller C,Thompson CL,Varnam LR,Visel A,Whitlock RM,Wohnoutka PE,Wolkey CK,Wong VY,Wood M,Yaylaoglu MB,Young RC,Youngstrom BL,Yuan XF,Zhang B,Zwingman TA,Jones AR
Category | C2
Sub-category | CGP
Brief description | Genes enriched in neurons in the adult mouse brain identified through correlation-based searches seeded with neuron cell-type specific gene expression patterns.
Full description | Molecular approaches to understanding the functional circuitry of the nervous system promise new insights into the relationship between genes, brain and behaviour. The cellular diversity of the brain necessitates a cellular resolution approach towards understanding the functional genomics of the nervous system. We describe here an anatomically comprehensive digital atlas containing the expression patterns of approximately 20,000 genes in the adult mouse brain. Data were generated using automated high-throughput procedures for in situ hybridization and data acquisition, and are publicly accessible online. Newly developed image-based informatics tools allow global genome-scale structural analysis and cross-correlation, as well as identification of regionally enriched genes. Unbiased fine-resolution analysis has identified highly specific cellular markers as well as extensive evidence of cellular heterogeneity not evident in classical neuroanatomical atlases. This highly standardized atlas provides an open, primary data resource for a wide variety of further studies concerning brain organization and function.

Standard name | LEIN_ASTROCYTE_MARKERS
Systematic name | M1713
Organism | Mus musculus
PMID | 17151600
Authors | Lein ES,Hawrylycz MJ,Ao N,Ayres M,Bensinger A,Bernard A,Boe AF,Boguski MS,Brockway KS,Byrnes EJ,Chen L,Chen TM,Chin MC,Chong J,Crook BE,Czaplinska A,Dang CN,Datta S,Dee NR,Desaki AL,Desta T,Diep E,Dolbeare TA,Donelan MJ,Dong HW,Dougherty JG,Duncan BJ,Ebbert AJ,Eichele G,Estin LK,Faber C,Facer BA,Fields R,Fischer SR,Fliss TP,Frensley C,Gates SN,Glattfelder KJ,Halverson KR,Hart MR,Hohmann JG,Howell MP,Jeung DP,Johnson RA,Karr PT,Kawal R,Kidney JM,Knapik RH,Kuan CL,Lake JH,Laramee AR,Larsen KD,Lau C,Lemon TA,Liang AJ,Liu Y,Luong LT,Michaels J,Morgan JJ,Morgan RJ,Mortrud MT,Mosqueda NF,Ng LL,Ng R,Orta GJ,Overly CC,Pak TH,Parry SE,Pathak SD,Pearson OC,Puchalski RB,Riley ZL,Rockett HR,Rowland SA,Royall JJ,Ruiz MJ,Sarno NR,Schaffnit K,Shapovalova NV,Sivisay T,Slaughterbeck CR,Smith SC,Smith KA,Smith BI,Sodt AJ,Stewart NN,Stumpf KR,Sunkin SM,Sutram M,Tam A,Teemer CD,Thaller C,Thompson CL,Varnam LR,Visel A,Whitlock RM,Wohnoutka PE,Wolkey CK,Wong VY,Wood M,Yaylaoglu MB,Young RC,Youngstrom BL,Yuan XF,Zhang B,Zwingman TA,Jones AR
Category | C2
Sub-category | CGP
Brief description | Genes enriched in astrocytes in the adult mouse brain identified through correlation-based searches seeded with the astrocyte cell-type specific gene expression patterns.
Full description | Molecular approaches to understanding the functional circuitry of the nervous system promise new insights into the relationship between genes, brain and behaviour. The cellular diversity of the brain necessitates a cellular resolution approach towards understanding the functional genomics of the nervous system. We describe here an anatomically comprehensive digital atlas containing the expression patterns of approximately 20,000 genes in the adult mouse brain. Data were generated using automated high-throughput procedures for in situ hybridization and data acquisition, and are publicly accessible online. Newly developed image-based informatics tools allow global genome-scale structural analysis and cross-correlation, as well as identification of regionally enriched genes. Unbiased fine-resolution analysis has identified highly specific cellular markers as well as extensive evidence of cellular heterogeneity not evident in classical neuroanatomical atlases. This highly standardized atlas provides an open, primary data resource for a wide variety of further studies concerning brain organization and function.

Standard name | LEIN_OLIGODENDROCYTE_MARKERS
Systematic name | M1714
Organism | Mus musculus
PMID | 17151600
Authors | Lein ES,Hawrylycz MJ,Ao N,Ayres M,Bensinger A,Bernard A,Boe AF,Boguski MS,Brockway KS,Byrnes EJ,Chen L,Chen TM,Chin MC,Chong J,Crook BE,Czaplinska A,Dang CN,Datta S,Dee NR,Desaki AL,Desta T,Diep E,Dolbeare TA,Donelan MJ,Dong HW,Dougherty JG,Duncan BJ,Ebbert AJ,Eichele G,Estin LK,Faber C,Facer BA,Fields R,Fischer SR,Fliss TP,Frensley C,Gates SN,Glattfelder KJ,Halverson KR,Hart MR,Hohmann JG,Howell MP,Jeung DP,Johnson RA,Karr PT,Kawal R,Kidney JM,Knapik RH,Kuan CL,Lake JH,Laramee AR,Larsen KD,Lau C,Lemon TA,Liang AJ,Liu Y,Luong LT,Michaels J,Morgan JJ,Morgan RJ,Mortrud MT,Mosqueda NF,Ng LL,Ng R,Orta GJ,Overly CC,Pak TH,Parry SE,Pathak SD,Pearson OC,Puchalski RB,Riley ZL,Rockett HR,Rowland SA,Royall JJ,Ruiz MJ,Sarno NR,Schaffnit K,Shapovalova NV,Sivisay T,Slaughterbeck CR,Smith SC,Smith KA,Smith BI,Sodt AJ,Stewart NN,Stumpf KR,Sunkin SM,Sutram M,Tam A,Teemer CD,Thaller C,Thompson CL,Varnam LR,Visel A,Whitlock RM,Wohnoutka PE,Wolkey CK,Wong VY,Wood M,Yaylaoglu MB,Young RC,Youngstrom BL,Yuan XF,Zhang B,Zwingman TA,Jones AR
Category | C2
Sub-category | CGP
Brief description | Genes enriched in oligodendrocytes in the adult mouse brain identified through correlation-based searches seeded with the oligodendrocyte cell-type specific gene expression patterns.
Full description | Molecular approaches to understanding the functional circuitry of the nervous system promise new insights into the relationship between genes, brain and behaviour. The cellular diversity of the brain necessitates a cellular resolution approach towards understanding the functional genomics of the nervous system. We describe here an anatomically comprehensive digital atlas containing the expression patterns of approximately 20,000 genes in the adult mouse brain. Data were generated using automated high-throughput procedures for in situ hybridization and data acquisition, and are publicly accessible online. Newly developed image-based informatics tools allow global genome-scale structural analysis and cross-correlation, as well as identification of regionally enriched genes. Unbiased fine-resolution analysis has identified highly specific cellular markers as well as extensive evidence of cellular heterogeneity not evident in classical neuroanatomical atlases. This highly standardized atlas provides an open, primary data resource for a wide variety of further studies concerning brain organization and function.

Standard name | LEIN_CHOROID_PLEXUS_MARKERS
Systematic name | M1719
Organism | Mus musculus
PMID | 17151600
Authors | Lein ES,Hawrylycz MJ,Ao N,Ayres M,Bensinger A,Bernard A,Boe AF,Boguski MS,Brockway KS,Byrnes EJ,Chen L,Chen TM,Chin MC,Chong J,Crook BE,Czaplinska A,Dang CN,Datta S,Dee NR,Desaki AL,Desta T,Diep E,Dolbeare TA,Donelan MJ,Dong HW,Dougherty JG,Duncan BJ,Ebbert AJ,Eichele G,Estin LK,Faber C,Facer BA,Fields R,Fischer SR,Fliss TP,Frensley C,Gates SN,Glattfelder KJ,Halverson KR,Hart MR,Hohmann JG,Howell MP,Jeung DP,Johnson RA,Karr PT,Kawal R,Kidney JM,Knapik RH,Kuan CL,Lake JH,Laramee AR,Larsen KD,Lau C,Lemon TA,Liang AJ,Liu Y,Luong LT,Michaels J,Morgan JJ,Morgan RJ,Mortrud MT,Mosqueda NF,Ng LL,Ng R,Orta GJ,Overly CC,Pak TH,Parry SE,Pathak SD,Pearson OC,Puchalski RB,Riley ZL,Rockett HR,Rowland SA,Royall JJ,Ruiz MJ,Sarno NR,Schaffnit K,Shapovalova NV,Sivisay T,Slaughterbeck CR,Smith SC,Smith KA,Smith BI,Sodt AJ,Stewart NN,Stumpf KR,Sunkin SM,Sutram M,Tam A,Teemer CD,Thaller C,Thompson CL,Varnam LR,Visel A,Whitlock RM,Wohnoutka PE,Wolkey CK,Wong VY,Wood M,Yaylaoglu MB,Young RC,Youngstrom BL,Yuan XF,Zhang B,Zwingman TA,Jones AR
Category | C2
Sub-category | CGP
Brief description | Genes enriched in choroid plexus cells in the brain identified through correlation-based searches seeded with the choroid plexus cell-type specific gene expression patterns.
Full description | Molecular approaches to understanding the functional circuitry of the nervous system promise new insights into the relationship between genes, brain and behaviour. The cellular diversity of the brain necessitates a cellular resolution approach towards understanding the functional genomics of the nervous system. We describe here an anatomically comprehensive digital atlas containing the expression patterns of approximately 20,000 genes in the adult mouse brain. Data were generated using automated high-throughput procedures for in situ hybridization and data acquisition, and are publicly accessible online. Newly developed image-based informatics tools allow global genome-scale structural analysis and cross-correlation, as well as identification of regionally enriched genes. Unbiased fine-resolution analysis has identified highly specific cellular markers as well as extensive evidence of cellular heterogeneity not evident in classical neuroanatomical atlases. This highly standardized atlas provides an open, primary data resource for a wide variety of further studies concerning brain organization and function.

Standard name | LEIN_MIDBRAIN_MARKERS
Systematic name | M1720
Organism | Mus musculus
PMID | 17151600
Authors | Lein ES,Hawrylycz MJ,Ao N,Ayres M,Bensinger A,Bernard A,Boe AF,Boguski MS,Brockway KS,Byrnes EJ,Chen L,Chen TM,Chin MC,Chong J,Crook BE,Czaplinska A,Dang CN,Datta S,Dee NR,Desaki AL,Desta T,Diep E,Dolbeare TA,Donelan MJ,Dong HW,Dougherty JG,Duncan BJ,Ebbert AJ,Eichele G,Estin LK,Faber C,Facer BA,Fields R,Fischer SR,Fliss TP,Frensley C,Gates SN,Glattfelder KJ,Halverson KR,Hart MR,Hohmann JG,Howell MP,Jeung DP,Johnson RA,Karr PT,Kawal R,Kidney JM,Knapik RH,Kuan CL,Lake JH,Laramee AR,Larsen KD,Lau C,Lemon TA,Liang AJ,Liu Y,Luong LT,Michaels J,Morgan JJ,Morgan RJ,Mortrud MT,Mosqueda NF,Ng LL,Ng R,Orta GJ,Overly CC,Pak TH,Parry SE,Pathak SD,Pearson OC,Puchalski RB,Riley ZL,Rockett HR,Rowland SA,Royall JJ,Ruiz MJ,Sarno NR,Schaffnit K,Shapovalova NV,Sivisay T,Slaughterbeck CR,Smith SC,Smith KA,Smith BI,Sodt AJ,Stewart NN,Stumpf KR,Sunkin SM,Sutram M,Tam A,Teemer CD,Thaller C,Thompson CL,Varnam LR,Visel A,Whitlock RM,Wohnoutka PE,Wolkey CK,Wong VY,Wood M,Yaylaoglu MB,Young RC,Youngstrom BL,Yuan XF,Zhang B,Zwingman TA,Jones AR
Category | C2
Sub-category | CGP
Brief description | Top 100 ranked genes most specific to midbrain region of adult mouse brain.
Full description | Molecular approaches to understanding the functional circuitry of the nervous system promise new insights into the relationship between genes, brain and behaviour. The cellular diversity of the brain necessitates a cellular resolution approach towards understanding the functional genomics of the nervous system. We describe here an anatomically comprehensive digital atlas containing the expression patterns of approximately 20,000 genes in the adult mouse brain. Data were generated using automated high-throughput procedures for in situ hybridization and data acquisition, and are publicly accessible online. Newly developed image-based informatics tools allow global genome-scale structural analysis and cross-correlation, as well as identification of regionally enriched genes. Unbiased fine-resolution analysis has identified highly specific cellular markers as well as extensive evidence of cellular heterogeneity not evident in classical neuroanatomical atlases. This highly standardized atlas provides an open, primary data resource for a wide variety of further studies concerning brain organization and function.

Standard name | LEIN_PONS_MARKERS
Systematic name | M1721
Organism | Mus musculus
PMID | 17151600
Authors | Lein ES,Hawrylycz MJ,Ao N,Ayres M,Bensinger A,Bernard A,Boe AF,Boguski MS,Brockway KS,Byrnes EJ,Chen L,Chen TM,Chin MC,Chong J,Crook BE,Czaplinska A,Dang CN,Datta S,Dee NR,Desaki AL,Desta T,Diep E,Dolbeare TA,Donelan MJ,Dong HW,Dougherty JG,Duncan BJ,Ebbert AJ,Eichele G,Estin LK,Faber C,Facer BA,Fields R,Fischer SR,Fliss TP,Frensley C,Gates SN,Glattfelder KJ,Halverson KR,Hart MR,Hohmann JG,Howell MP,Jeung DP,Johnson RA,Karr PT,Kawal R,Kidney JM,Knapik RH,Kuan CL,Lake JH,Laramee AR,Larsen KD,Lau C,Lemon TA,Liang AJ,Liu Y,Luong LT,Michaels J,Morgan JJ,Morgan RJ,Mortrud MT,Mosqueda NF,Ng LL,Ng R,Orta GJ,Overly CC,Pak TH,Parry SE,Pathak SD,Pearson OC,Puchalski RB,Riley ZL,Rockett HR,Rowland SA,Royall JJ,Ruiz MJ,Sarno NR,Schaffnit K,Shapovalova NV,Sivisay T,Slaughterbeck CR,Smith SC,Smith KA,Smith BI,Sodt AJ,Stewart NN,Stumpf KR,Sunkin SM,Sutram M,Tam A,Teemer CD,Thaller C,Thompson CL,Varnam LR,Visel A,Whitlock RM,Wohnoutka PE,Wolkey CK,Wong VY,Wood M,Yaylaoglu MB,Young RC,Youngstrom BL,Yuan XF,Zhang B,Zwingman TA,Jones AR
Category | C2
Sub-category | CGP
Brief description | Top 100 ranked genes most specific to pons region (P) of the adult mouse brain.
Full description | Molecular approaches to understanding the functional circuitry of the nervous system promise new insights into the relationship between genes, brain and behaviour. The cellular diversity of the brain necessitates a cellular resolution approach towards understanding the functional genomics of the nervous system. We describe here an anatomically comprehensive digital atlas containing the expression patterns of approximately 20,000 genes in the adult mouse brain. Data were generated using automated high-throughput procedures for in situ hybridization and data acquisition, and are publicly accessible online. Newly developed image-based informatics tools allow global genome-scale structural analysis and cross-correlation, as well as identification of regionally enriched genes. Unbiased fine-resolution analysis has identified highly specific cellular markers as well as extensive evidence of cellular heterogeneity not evident in classical neuroanatomical atlases. This highly standardized atlas provides an open, primary data resource for a wide variety of further studies concerning brain organization and function.

Standard name | LEIN_MEDULLA_MARKERS
Systematic name | M1722
Organism | Mus musculus
PMID | 17151600
Authors | Lein ES,Hawrylycz MJ,Ao N,Ayres M,Bensinger A,Bernard A,Boe AF,Boguski MS,Brockway KS,Byrnes EJ,Chen L,Chen TM,Chin MC,Chong J,Crook BE,Czaplinska A,Dang CN,Datta S,Dee NR,Desaki AL,Desta T,Diep E,Dolbeare TA,Donelan MJ,Dong HW,Dougherty JG,Duncan BJ,Ebbert AJ,Eichele G,Estin LK,Faber C,Facer BA,Fields R,Fischer SR,Fliss TP,Frensley C,Gates SN,Glattfelder KJ,Halverson KR,Hart MR,Hohmann JG,Howell MP,Jeung DP,Johnson RA,Karr PT,Kawal R,Kidney JM,Knapik RH,Kuan CL,Lake JH,Laramee AR,Larsen KD,Lau C,Lemon TA,Liang AJ,Liu Y,Luong LT,Michaels J,Morgan JJ,Morgan RJ,Mortrud MT,Mosqueda NF,Ng LL,Ng R,Orta GJ,Overly CC,Pak TH,Parry SE,Pathak SD,Pearson OC,Puchalski RB,Riley ZL,Rockett HR,Rowland SA,Royall JJ,Ruiz MJ,Sarno NR,Schaffnit K,Shapovalova NV,Sivisay T,Slaughterbeck CR,Smith SC,Smith KA,Smith BI,Sodt AJ,Stewart NN,Stumpf KR,Sunkin SM,Sutram M,Tam A,Teemer CD,Thaller C,Thompson CL,Varnam LR,Visel A,Whitlock RM,Wohnoutka PE,Wolkey CK,Wong VY,Wood M,Yaylaoglu MB,Young RC,Youngstrom BL,Yuan XF,Zhang B,Zwingman TA,Jones AR
Category | C2
Sub-category | CGP
Brief description | Top 100 ranked genes most specific to medulla (myelencephalon) hindbrain region of adult mouse brain.
Full description | Molecular approaches to understanding the functional circuitry of the nervous system promise new insights into the relationship between genes, brain and behaviour. The cellular diversity of the brain necessitates a cellular resolution approach towards understanding the functional genomics of the nervous system. We describe here an anatomically comprehensive digital atlas containing the expression patterns of approximately 20,000 genes in the adult mouse brain. Data were generated using automated high-throughput procedures for in situ hybridization and data acquisition, and are publicly accessible online. Newly developed image-based informatics tools allow global genome-scale structural analysis and cross-correlation, as well as identification of regionally enriched genes. Unbiased fine-resolution analysis has identified highly specific cellular markers as well as extensive evidence of cellular heterogeneity not evident in classical neuroanatomical atlases. This highly standardized atlas provides an open, primary data resource for a wide variety of further studies concerning brain organization and function.

Standard name | LEIN_CEREBELLUM_MARKERS
Systematic name | M1723
Organism | Mus musculus
PMID | 17151600
Authors | Lein ES,Hawrylycz MJ,Ao N,Ayres M,Bensinger A,Bernard A,Boe AF,Boguski MS,Brockway KS,Byrnes EJ,Chen L,Chen TM,Chin MC,Chong J,Crook BE,Czaplinska A,Dang CN,Datta S,Dee NR,Desaki AL,Desta T,Diep E,Dolbeare TA,Donelan MJ,Dong HW,Dougherty JG,Duncan BJ,Ebbert AJ,Eichele G,Estin LK,Faber C,Facer BA,Fields R,Fischer SR,Fliss TP,Frensley C,Gates SN,Glattfelder KJ,Halverson KR,Hart MR,Hohmann JG,Howell MP,Jeung DP,Johnson RA,Karr PT,Kawal R,Kidney JM,Knapik RH,Kuan CL,Lake JH,Laramee AR,Larsen KD,Lau C,Lemon TA,Liang AJ,Liu Y,Luong LT,Michaels J,Morgan JJ,Morgan RJ,Mortrud MT,Mosqueda NF,Ng LL,Ng R,Orta GJ,Overly CC,Pak TH,Parry SE,Pathak SD,Pearson OC,Puchalski RB,Riley ZL,Rockett HR,Rowland SA,Royall JJ,Ruiz MJ,Sarno NR,Schaffnit K,Shapovalova NV,Sivisay T,Slaughterbeck CR,Smith SC,Smith KA,Smith BI,Sodt AJ,Stewart NN,Stumpf KR,Sunkin SM,Sutram M,Tam A,Teemer CD,Thaller C,Thompson CL,Varnam LR,Visel A,Whitlock RM,Wohnoutka PE,Wolkey CK,Wong VY,Wood M,Yaylaoglu MB,Young RC,Youngstrom BL,Yuan XF,Zhang B,Zwingman TA,Jones AR
Category | C2
Sub-category | CGP
Brief description | Top 100 ranked genes most specific to the cerebellum region of adult mouse brain.
Full description | Molecular approaches to understanding the functional circuitry of the nervous system promise new insights into the relationship between genes, brain and behaviour. The cellular diversity of the brain necessitates a cellular resolution approach towards understanding the functional genomics of the nervous system. We describe here an anatomically comprehensive digital atlas containing the expression patterns of approximately 20,000 genes in the adult mouse brain. Data were generated using automated high-throughput procedures for in situ hybridization and data acquisition, and are publicly accessible online. Newly developed image-based informatics tools allow global genome-scale structural analysis and cross-correlation, as well as identification of regionally enriched genes. Unbiased fine-resolution analysis has identified highly specific cellular markers as well as extensive evidence of cellular heterogeneity not evident in classical neuroanatomical atlases. This highly standardized atlas provides an open, primary data resource for a wide variety of further studies concerning brain organization and function.

Standard name | LEIN_LOCALIZED_TO_DISTAL_AND_PROXIMAL_DENDRITES
Systematic name | M1725
Organism | Mus musculus
PMID | 17151600
Authors | Lein ES,Hawrylycz MJ,Ao N,Ayres M,Bensinger A,Bernard A,Boe AF,Boguski MS,Brockway KS,Byrnes EJ,Chen L,Chen TM,Chin MC,Chong J,Crook BE,Czaplinska A,Dang CN,Datta S,Dee NR,Desaki AL,Desta T,Diep E,Dolbeare TA,Donelan MJ,Dong HW,Dougherty JG,Duncan BJ,Ebbert AJ,Eichele G,Estin LK,Faber C,Facer BA,Fields R,Fischer SR,Fliss TP,Frensley C,Gates SN,Glattfelder KJ,Halverson KR,Hart MR,Hohmann JG,Howell MP,Jeung DP,Johnson RA,Karr PT,Kawal R,Kidney JM,Knapik RH,Kuan CL,Lake JH,Laramee AR,Larsen KD,Lau C,Lemon TA,Liang AJ,Liu Y,Luong LT,Michaels J,Morgan JJ,Morgan RJ,Mortrud MT,Mosqueda NF,Ng LL,Ng R,Orta GJ,Overly CC,Pak TH,Parry SE,Pathak SD,Pearson OC,Puchalski RB,Riley ZL,Rockett HR,Rowland SA,Royall JJ,Ruiz MJ,Sarno NR,Schaffnit K,Shapovalova NV,Sivisay T,Slaughterbeck CR,Smith SC,Smith KA,Smith BI,Sodt AJ,Stewart NN,Stumpf KR,Sunkin SM,Sutram M,Tam A,Teemer CD,Thaller C,Thompson CL,Varnam LR,Visel A,Whitlock RM,Wohnoutka PE,Wolkey CK,Wong VY,Wood M,Yaylaoglu MB,Young RC,Youngstrom BL,Yuan XF,Zhang B,Zwingman TA,Jones AR
Category | C2
Sub-category | CGP
Brief description | Transcripts showing subcellular localization to both distal and proximal dendrites in the adult mouse brain.
Full description | Molecular approaches to understanding the functional circuitry of the nervous system promise new insights into the relationship between genes, brain and behaviour. The cellular diversity of the brain necessitates a cellular resolution approach towards understanding the functional genomics of the nervous system. We describe here an anatomically comprehensive digital atlas containing the expression patterns of approximately 20,000 genes in the adult mouse brain. Data were generated using automated high-throughput procedures for in situ hybridization and data acquisition, and are publicly accessible online. Newly developed image-based informatics tools allow global genome-scale structural analysis and cross-correlation, as well as identification of regionally enriched genes. Unbiased fine-resolution analysis has identified highly specific cellular markers as well as extensive evidence of cellular heterogeneity not evident in classical neuroanatomical atlases. This highly standardized atlas provides an open, primary data resource for a wide variety of further studies concerning brain organization and function.

Standard name | LEIN_LOCALIZED_TO_PROXIMAL_DENDRITES
Systematic name | M1726
Organism | Mus musculus
PMID | 17151600
Authors | Lein ES,Hawrylycz MJ,Ao N,Ayres M,Bensinger A,Bernard A,Boe AF,Boguski MS,Brockway KS,Byrnes EJ,Chen L,Chen TM,Chin MC,Chong J,Crook BE,Czaplinska A,Dang CN,Datta S,Dee NR,Desaki AL,Desta T,Diep E,Dolbeare TA,Donelan MJ,Dong HW,Dougherty JG,Duncan BJ,Ebbert AJ,Eichele G,Estin LK,Faber C,Facer BA,Fields R,Fischer SR,Fliss TP,Frensley C,Gates SN,Glattfelder KJ,Halverson KR,Hart MR,Hohmann JG,Howell MP,Jeung DP,Johnson RA,Karr PT,Kawal R,Kidney JM,Knapik RH,Kuan CL,Lake JH,Laramee AR,Larsen KD,Lau C,Lemon TA,Liang AJ,Liu Y,Luong LT,Michaels J,Morgan JJ,Morgan RJ,Mortrud MT,Mosqueda NF,Ng LL,Ng R,Orta GJ,Overly CC,Pak TH,Parry SE,Pathak SD,Pearson OC,Puchalski RB,Riley ZL,Rockett HR,Rowland SA,Royall JJ,Ruiz MJ,Sarno NR,Schaffnit K,Shapovalova NV,Sivisay T,Slaughterbeck CR,Smith SC,Smith KA,Smith BI,Sodt AJ,Stewart NN,Stumpf KR,Sunkin SM,Sutram M,Tam A,Teemer CD,Thaller C,Thompson CL,Varnam LR,Visel A,Whitlock RM,Wohnoutka PE,Wolkey CK,Wong VY,Wood M,Yaylaoglu MB,Young RC,Youngstrom BL,Yuan XF,Zhang B,Zwingman TA,Jones AR
Category | C2
Sub-category | CGP
Brief description | Transcripts showing subcellular localization only to proximal dendrites in the adult mouse brain.
Full description | Molecular approaches to understanding the functional circuitry of the nervous system promise new insights into the relationship between genes, brain and behaviour. The cellular diversity of the brain necessitates a cellular resolution approach towards understanding the functional genomics of the nervous system. We describe here an anatomically comprehensive digital atlas containing the expression patterns of approximately 20,000 genes in the adult mouse brain. Data were generated using automated high-throughput procedures for in situ hybridization and data acquisition, and are publicly accessible online. Newly developed image-based informatics tools allow global genome-scale structural analysis and cross-correlation, as well as identification of regionally enriched genes. Unbiased fine-resolution analysis has identified highly specific cellular markers as well as extensive evidence of cellular heterogeneity not evident in classical neuroanatomical atlases. This highly standardized atlas provides an open, primary data resource for a wide variety of further studies concerning brain organization and function.

Standard name | GAVIN_FOXP3_TARGETS_CLUSTER_T4
Systematic name | M1729
Organism | Mus musculus
PMID | 17220874
Authors | Gavin MA,Rasmussen JP,Fontenot JD,Vasta V,Manganiello VC,Beavo JA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Cluster T4 of genes with similar expression profiles in thymic T lymphocytes after FOXP3 [GeneID=50943] loss of function (LOF).
Full description | Regulatory CD4+ T cells (Tr cells), the development of which is critically dependent on X-linked transcription factor Foxp3 (forkhead box P3), prevent self-destructive immune responses. Despite its important role, molecular and functional features conferred by Foxp3 to Tr precursor cells remain unknown. It has been suggested that Foxp3 expression is required for both survival of Tr precursors as well as their inability to produce interleukin (IL)-2 and independently proliferate after T-cell-receptor engagement, raising the possibility that such 'anergy' and Tr suppressive capacity are intimately linked. Here we show, by dissociating Foxp3-dependent features from those induced by the signals preceding and promoting its expression in mice, that the latter signals include several functional and transcriptional hallmarks of Tr cells. Although its function is required for Tr cell suppressor activity, Foxp3 to a large extent amplifies and fixes pre-established molecular features of Tr cells, including anergy and dependence on paracrine IL-2. Furthermore, Foxp3 solidifies Tr cell lineage stability through modification of cell surface and signalling molecules, resulting in adaptation to the signals required to induce and maintain Tr cells. This adaptation includes Foxp3-dependent repression of cyclic nucleotide phosphodiesterase 3B, affecting genes responsible for Tr cell homeostasis.

Standard name | GAVIN_FOXP3_TARGETS_CLUSTER_T7
Systematic name | M1731
Organism | Mus musculus
PMID | 17220874
Authors | Gavin MA,Rasmussen JP,Fontenot JD,Vasta V,Manganiello VC,Beavo JA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Cluster T7 of genes with similar expression profiles in thymic T lymphocytes after FOXP3 [GeneID=50943] loss of function (LOF).
Full description | Regulatory CD4+ T cells (Tr cells), the development of which is critically dependent on X-linked transcription factor Foxp3 (forkhead box P3), prevent self-destructive immune responses. Despite its important role, molecular and functional features conferred by Foxp3 to Tr precursor cells remain unknown. It has been suggested that Foxp3 expression is required for both survival of Tr precursors as well as their inability to produce interleukin (IL)-2 and independently proliferate after T-cell-receptor engagement, raising the possibility that such 'anergy' and Tr suppressive capacity are intimately linked. Here we show, by dissociating Foxp3-dependent features from those induced by the signals preceding and promoting its expression in mice, that the latter signals include several functional and transcriptional hallmarks of Tr cells. Although its function is required for Tr cell suppressor activity, Foxp3 to a large extent amplifies and fixes pre-established molecular features of Tr cells, including anergy and dependence on paracrine IL-2. Furthermore, Foxp3 solidifies Tr cell lineage stability through modification of cell surface and signalling molecules, resulting in adaptation to the signals required to induce and maintain Tr cells. This adaptation includes Foxp3-dependent repression of cyclic nucleotide phosphodiesterase 3B, affecting genes responsible for Tr cell homeostasis.

Standard name | GAVIN_FOXP3_TARGETS_CLUSTER_P2
Systematic name | M1732
Organism | Mus musculus
PMID | 17220874
Authors | Gavin MA,Rasmussen JP,Fontenot JD,Vasta V,Manganiello VC,Beavo JA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Cluster P2 of genes with similar expression profiles in peripheral T ymphocytes after FOXP3 [GeneID=50943] loss of function (LOF).
Full description | Regulatory CD4+ T cells (Tr cells), the development of which is critically dependent on X-linked transcription factor Foxp3 (forkhead box P3), prevent self-destructive immune responses. Despite its important role, molecular and functional features conferred by Foxp3 to Tr precursor cells remain unknown. It has been suggested that Foxp3 expression is required for both survival of Tr precursors as well as their inability to produce interleukin (IL)-2 and independently proliferate after T-cell-receptor engagement, raising the possibility that such 'anergy' and Tr suppressive capacity are intimately linked. Here we show, by dissociating Foxp3-dependent features from those induced by the signals preceding and promoting its expression in mice, that the latter signals include several functional and transcriptional hallmarks of Tr cells. Although its function is required for Tr cell suppressor activity, Foxp3 to a large extent amplifies and fixes pre-established molecular features of Tr cells, including anergy and dependence on paracrine IL-2. Furthermore, Foxp3 solidifies Tr cell lineage stability through modification of cell surface and signalling molecules, resulting in adaptation to the signals required to induce and maintain Tr cells. This adaptation includes Foxp3-dependent repression of cyclic nucleotide phosphodiesterase 3B, affecting genes responsible for Tr cell homeostasis.

Standard name | GAVIN_FOXP3_TARGETS_CLUSTER_P3
Systematic name | M1733
Organism | Mus musculus
PMID | 17220874
Authors | Gavin MA,Rasmussen JP,Fontenot JD,Vasta V,Manganiello VC,Beavo JA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Cluster P3 of genes with similar expression profiles in peripheral T lymphocytes after FOXP3 [GeneID=50943] loss of function (LOF).
Full description | Regulatory CD4+ T cells (Tr cells), the development of which is critically dependent on X-linked transcription factor Foxp3 (forkhead box P3), prevent self-destructive immune responses. Despite its important role, molecular and functional features conferred by Foxp3 to Tr precursor cells remain unknown. It has been suggested that Foxp3 expression is required for both survival of Tr precursors as well as their inability to produce interleukin (IL)-2 and independently proliferate after T-cell-receptor engagement, raising the possibility that such 'anergy' and Tr suppressive capacity are intimately linked. Here we show, by dissociating Foxp3-dependent features from those induced by the signals preceding and promoting its expression in mice, that the latter signals include several functional and transcriptional hallmarks of Tr cells. Although its function is required for Tr cell suppressor activity, Foxp3 to a large extent amplifies and fixes pre-established molecular features of Tr cells, including anergy and dependence on paracrine IL-2. Furthermore, Foxp3 solidifies Tr cell lineage stability through modification of cell surface and signalling molecules, resulting in adaptation to the signals required to induce and maintain Tr cells. This adaptation includes Foxp3-dependent repression of cyclic nucleotide phosphodiesterase 3B, affecting genes responsible for Tr cell homeostasis.

Standard name | GAVIN_FOXP3_TARGETS_CLUSTER_P4
Systematic name | M1734
Organism | Mus musculus
PMID | 17220874
Authors | Gavin MA,Rasmussen JP,Fontenot JD,Vasta V,Manganiello VC,Beavo JA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Cluster P4 of genes with similar expression profiles in peripheral T lymphocytes after FOXP3 [GeneID=50943] loss of function (LOF).
Full description | Regulatory CD4+ T cells (Tr cells), the development of which is critically dependent on X-linked transcription factor Foxp3 (forkhead box P3), prevent self-destructive immune responses. Despite its important role, molecular and functional features conferred by Foxp3 to Tr precursor cells remain unknown. It has been suggested that Foxp3 expression is required for both survival of Tr precursors as well as their inability to produce interleukin (IL)-2 and independently proliferate after T-cell-receptor engagement, raising the possibility that such 'anergy' and Tr suppressive capacity are intimately linked. Here we show, by dissociating Foxp3-dependent features from those induced by the signals preceding and promoting its expression in mice, that the latter signals include several functional and transcriptional hallmarks of Tr cells. Although its function is required for Tr cell suppressor activity, Foxp3 to a large extent amplifies and fixes pre-established molecular features of Tr cells, including anergy and dependence on paracrine IL-2. Furthermore, Foxp3 solidifies Tr cell lineage stability through modification of cell surface and signalling molecules, resulting in adaptation to the signals required to induce and maintain Tr cells. This adaptation includes Foxp3-dependent repression of cyclic nucleotide phosphodiesterase 3B, affecting genes responsible for Tr cell homeostasis.

Standard name | GAVIN_FOXP3_TARGETS_CLUSTER_P6
Systematic name | M1735
Organism | Mus musculus
PMID | 17220874
Authors | Gavin MA,Rasmussen JP,Fontenot JD,Vasta V,Manganiello VC,Beavo JA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Cluster P6 of genes with similar expression profiles in peripheral T lymphocytes after FOXP3 [GeneID=50943] loss of function (LOF).
Full description | Regulatory CD4+ T cells (Tr cells), the development of which is critically dependent on X-linked transcription factor Foxp3 (forkhead box P3), prevent self-destructive immune responses. Despite its important role, molecular and functional features conferred by Foxp3 to Tr precursor cells remain unknown. It has been suggested that Foxp3 expression is required for both survival of Tr precursors as well as their inability to produce interleukin (IL)-2 and independently proliferate after T-cell-receptor engagement, raising the possibility that such 'anergy' and Tr suppressive capacity are intimately linked. Here we show, by dissociating Foxp3-dependent features from those induced by the signals preceding and promoting its expression in mice, that the latter signals include several functional and transcriptional hallmarks of Tr cells. Although its function is required for Tr cell suppressor activity, Foxp3 to a large extent amplifies and fixes pre-established molecular features of Tr cells, including anergy and dependence on paracrine IL-2. Furthermore, Foxp3 solidifies Tr cell lineage stability through modification of cell surface and signalling molecules, resulting in adaptation to the signals required to induce and maintain Tr cells. This adaptation includes Foxp3-dependent repression of cyclic nucleotide phosphodiesterase 3B, affecting genes responsible for Tr cell homeostasis.

Standard name | GAVIN_FOXP3_TARGETS_CLUSTER_P7
Systematic name | M1736
Organism | Mus musculus
PMID | 17220874
Authors | Gavin MA,Rasmussen JP,Fontenot JD,Vasta V,Manganiello VC,Beavo JA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Cluster P7 of genes with similar expression profiles in peripheral T lymphocytes after FOXP3 [GeneID=50943] loss of function (LOF).
Full description | Regulatory CD4+ T cells (Tr cells), the development of which is critically dependent on X-linked transcription factor Foxp3 (forkhead box P3), prevent self-destructive immune responses. Despite its important role, molecular and functional features conferred by Foxp3 to Tr precursor cells remain unknown. It has been suggested that Foxp3 expression is required for both survival of Tr precursors as well as their inability to produce interleukin (IL)-2 and independently proliferate after T-cell-receptor engagement, raising the possibility that such 'anergy' and Tr suppressive capacity are intimately linked. Here we show, by dissociating Foxp3-dependent features from those induced by the signals preceding and promoting its expression in mice, that the latter signals include several functional and transcriptional hallmarks of Tr cells. Although its function is required for Tr cell suppressor activity, Foxp3 to a large extent amplifies and fixes pre-established molecular features of Tr cells, including anergy and dependence on paracrine IL-2. Furthermore, Foxp3 solidifies Tr cell lineage stability through modification of cell surface and signalling molecules, resulting in adaptation to the signals required to induce and maintain Tr cells. This adaptation includes Foxp3-dependent repression of cyclic nucleotide phosphodiesterase 3B, affecting genes responsible for Tr cell homeostasis.

Standard name | GAVIN_PDE3B_TARGETS
Systematic name | M1737
Organism | Mus musculus
PMID | 17220874
Authors | Gavin MA,Rasmussen JP,Fontenot JD,Vasta V,Manganiello VC,Beavo JA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Genes changed in peripheral regulatory T lymphocytes that depend on PDE3B [GeneID=5140].
Full description | Regulatory CD4+ T cells (Tr cells), the development of which is critically dependent on X-linked transcription factor Foxp3 (forkhead box P3), prevent self-destructive immune responses. Despite its important role, molecular and functional features conferred by Foxp3 to Tr precursor cells remain unknown. It has been suggested that Foxp3 expression is required for both survival of Tr precursors as well as their inability to produce interleukin (IL)-2 and independently proliferate after T-cell-receptor engagement, raising the possibility that such 'anergy' and Tr suppressive capacity are intimately linked. Here we show, by dissociating Foxp3-dependent features from those induced by the signals preceding and promoting its expression in mice, that the latter signals include several functional and transcriptional hallmarks of Tr cells. Although its function is required for Tr cell suppressor activity, Foxp3 to a large extent amplifies and fixes pre-established molecular features of Tr cells, including anergy and dependence on paracrine IL-2. Furthermore, Foxp3 solidifies Tr cell lineage stability through modification of cell surface and signalling molecules, resulting in adaptation to the signals required to induce and maintain Tr cells. This adaptation includes Foxp3-dependent repression of cyclic nucleotide phosphodiesterase 3B, affecting genes responsible for Tr cell homeostasis.

Standard name | GAVIN_IL2_RESPONSIVE_FOXP3_TARGETS_UP
Systematic name | M1739
Organism | Mus musculus
PMID | 17220874
Authors | Gavin MA,Rasmussen JP,Fontenot JD,Vasta V,Manganiello VC,Beavo JA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | FOXP3 [GeneID=50943] target genes up-regulated in T lymphocytes after stimulation with IL2 [GeneID=3558].
Full description | Regulatory CD4+ T cells (Tr cells), the development of which is critically dependent on X-linked transcription factor Foxp3 (forkhead box P3), prevent self-destructive immune responses. Despite its important role, molecular and functional features conferred by Foxp3 to Tr precursor cells remain unknown. It has been suggested that Foxp3 expression is required for both survival of Tr precursors as well as their inability to produce interleukin (IL)-2 and independently proliferate after T-cell-receptor engagement, raising the possibility that such 'anergy' and Tr suppressive capacity are intimately linked. Here we show, by dissociating Foxp3-dependent features from those induced by the signals preceding and promoting its expression in mice, that the latter signals include several functional and transcriptional hallmarks of Tr cells. Although its function is required for Tr cell suppressor activity, Foxp3 to a large extent amplifies and fixes pre-established molecular features of Tr cells, including anergy and dependence on paracrine IL-2. Furthermore, Foxp3 solidifies Tr cell lineage stability through modification of cell surface and signalling molecules, resulting in adaptation to the signals required to induce and maintain Tr cells. This adaptation includes Foxp3-dependent repression of cyclic nucleotide phosphodiesterase 3B, affecting genes responsible for Tr cell homeostasis.

Standard name | GAVIN_IL2_RESPONSIVE_FOXP3_TARGETS_DN
Systematic name | M1740
Organism | Mus musculus
PMID | 17220874
Authors | Gavin MA,Rasmussen JP,Fontenot JD,Vasta V,Manganiello VC,Beavo JA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | FOXP3 [GeneID=50943] target genes down-regulated in T lymphocytes after stimulation with IL2 [GeneID=3558].
Full description | Regulatory CD4+ T cells (Tr cells), the development of which is critically dependent on X-linked transcription factor Foxp3 (forkhead box P3), prevent self-destructive immune responses. Despite its important role, molecular and functional features conferred by Foxp3 to Tr precursor cells remain unknown. It has been suggested that Foxp3 expression is required for both survival of Tr precursors as well as their inability to produce interleukin (IL)-2 and independently proliferate after T-cell-receptor engagement, raising the possibility that such 'anergy' and Tr suppressive capacity are intimately linked. Here we show, by dissociating Foxp3-dependent features from those induced by the signals preceding and promoting its expression in mice, that the latter signals include several functional and transcriptional hallmarks of Tr cells. Although its function is required for Tr cell suppressor activity, Foxp3 to a large extent amplifies and fixes pre-established molecular features of Tr cells, including anergy and dependence on paracrine IL-2. Furthermore, Foxp3 solidifies Tr cell lineage stability through modification of cell surface and signalling molecules, resulting in adaptation to the signals required to induce and maintain Tr cells. This adaptation includes Foxp3-dependent repression of cyclic nucleotide phosphodiesterase 3B, affecting genes responsible for Tr cell homeostasis.

Standard name | ZHENG_BOUND_BY_FOXP3
Systematic name | M1741
Organism | Mus musculus
PMID | 17237761
Authors | Zheng Y,Josefowicz SZ,Kas A,Chu TT,Gavin MA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters are bound by FOXP3 [GeneID=50943] based an a ChIP-chip analysis.
Full description | Transcription factor Foxp3 (forkhead box P3), restricted in its expression to a specialized regulatory CD4+ T-cell subset (T(R)) with a dedicated suppressor function, controls T(R) lineage development. In humans and mice, Foxp3 deficiency results in a paucity of T(R) cells and a fatal breach in immunological tolerance, causing highly aggressive multi-organ autoimmune pathology. Here, through genome-wide analysis combining chromatin immunoprecipitation with mouse genome tiling array profiling, we identify Foxp3 binding regions for approximately 700 genes and for an intergenically encoded microRNA. We find that a large number of Foxp3-bound genes are up- or downregulated in Foxp3+ T cells, suggesting that Foxp3 acts as both a transcriptional activator and repressor. Foxp3-mediated regulation unique to the thymus affects, among others, genes encoding nuclear factors that control gene expression and chromatin remodelling. In contrast, Foxp3 target genes shared by the thymic and peripheral T(R) cells encode primarily plasma membrane proteins, as well as cell signalling proteins. Together, our studies suggest that distinct transcriptional sub-programmes implemented by Foxp3 establish T(R) lineage during differentiation and its proliferative and functional competence in the periphery.

Standard name | MARSON_BOUND_BY_FOXP3_STIMULATED
Systematic name | M1742
Organism | Mus musculus
PMID | 17237765
Authors | Marson A,Kretschmer K,Frampton GM,Jacobsen ES,Polansky JK,MacIsaac KD,Levine SS,Fraenkel E,von Boehmer H,Young RA
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by FOXP3 [GeneID=50943] in hybridoma cells stimulated by PMA [PubChem=4792] and ionomycin [PubChem=3733].
Full description | Foxp3+CD4+CD25+ regulatory T (T(reg)) cells are essential for the prevention of autoimmunity. T(reg) cells have an attenuated cytokine response to T-cell receptor stimulation, and can suppress the proliferation and effector function of neighbouring T cells. The forkhead transcription factor Foxp3 (forkhead box P3) is selectively expressed in T(reg) cells, is required for T(reg) development and function, and is sufficient to induce a T(reg) phenotype in conventional CD4+CD25- T cells. Mutations in Foxp3 cause severe, multi-organ autoimmunity in both human and mouse. FOXP3 can cooperate in a DNA-binding complex with NFAT (nuclear factor of activated T cells) to regulate the transcription of several known target genes. However, the global set of genes regulated directly by Foxp3 is not known and consequently, how this transcription factor controls the gene expression programme for T(reg) function is not understood. Here we identify Foxp3 target genes and report that many of these are key modulators of T-cell activation and function. Remarkably, the predominant, although not exclusive, effect of Foxp3 occupancy is to suppress the activation of target genes on T-cell stimulation. Foxp3 suppression of its targets appears to be crucial for the normal function of T(reg) cells, because overactive variants of some target genes are known to be associated with autoimmune disease.

Standard name | MARSON_BOUND_BY_FOXP3_UNSTIMULATED
Systematic name | M1743
Organism | Mus musculus
PMID | 17237765
Authors | Marson A,Kretschmer K,Frampton GM,Jacobsen ES,Polansky JK,MacIsaac KD,Levine SS,Fraenkel E,von Boehmer H,Young RA
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by FOXP3 [GeneID=50943] in unstimulated hybridoma cells.
Full description | Foxp3+CD4+CD25+ regulatory T (T(reg)) cells are essential for the prevention of autoimmunity. T(reg) cells have an attenuated cytokine response to T-cell receptor stimulation, and can suppress the proliferation and effector function of neighbouring T cells. The forkhead transcription factor Foxp3 (forkhead box P3) is selectively expressed in T(reg) cells, is required for T(reg) development and function, and is sufficient to induce a T(reg) phenotype in conventional CD4+CD25- T cells. Mutations in Foxp3 cause severe, multi-organ autoimmunity in both human and mouse. FOXP3 can cooperate in a DNA-binding complex with NFAT (nuclear factor of activated T cells) to regulate the transcription of several known target genes. However, the global set of genes regulated directly by Foxp3 is not known and consequently, how this transcription factor controls the gene expression programme for T(reg) function is not understood. Here we identify Foxp3 target genes and report that many of these are key modulators of T-cell activation and function. Remarkably, the predominant, although not exclusive, effect of Foxp3 occupancy is to suppress the activation of target genes on T-cell stimulation. Foxp3 suppression of its targets appears to be crucial for the normal function of T(reg) cells, because overactive variants of some target genes are known to be associated with autoimmune disease.

Standard name | MARSON_BOUND_BY_E2F4_UNSTIMULATED
Systematic name | M1744
Organism | Mus musculus
PMID | 17237765
Authors | Marson A,Kretschmer K,Frampton GM,Jacobsen ES,Polansky JK,MacIsaac KD,Levine SS,Fraenkel E,von Boehmer H,Young RA
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by E2F4 [GeneID=1874] in unstimulated hybridoma cells.
Full description | Foxp3+CD4+CD25+ regulatory T (T(reg)) cells are essential for the prevention of autoimmunity. T(reg) cells have an attenuated cytokine response to T-cell receptor stimulation, and can suppress the proliferation and effector function of neighbouring T cells. The forkhead transcription factor Foxp3 (forkhead box P3) is selectively expressed in T(reg) cells, is required for T(reg) development and function, and is sufficient to induce a T(reg) phenotype in conventional CD4+CD25- T cells. Mutations in Foxp3 cause severe, multi-organ autoimmunity in both human and mouse. FOXP3 can cooperate in a DNA-binding complex with NFAT (nuclear factor of activated T cells) to regulate the transcription of several known target genes. However, the global set of genes regulated directly by Foxp3 is not known and consequently, how this transcription factor controls the gene expression programme for T(reg) function is not understood. Here we identify Foxp3 target genes and report that many of these are key modulators of T-cell activation and function. Remarkably, the predominant, although not exclusive, effect of Foxp3 occupancy is to suppress the activation of target genes on T-cell stimulation. Foxp3 suppression of its targets appears to be crucial for the normal function of T(reg) cells, because overactive variants of some target genes are known to be associated with autoimmune disease.

Standard name | MARSON_FOXP3_TARGETS_STIMULATED_UP
Systematic name | M3146
Organism | Mus musculus
PMID | 17237765
Authors | Marson A,Kretschmer K,Frampton GM,Jacobsen ES,Polansky JK,MacIsaac KD,Levine SS,Fraenkel E,von Boehmer H,Young RA
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by FOXP3 [GeneID=50943], dependent on it, and up-regulated in hybridoma cells stimulated by PMA [PubChem=4792] and ionomycin [PubChem=3733].
Full description | Foxp3+CD4+CD25+ regulatory T (T(reg)) cells are essential for the prevention of autoimmunity. T(reg) cells have an attenuated cytokine response to T-cell receptor stimulation, and can suppress the proliferation and effector function of neighbouring T cells. The forkhead transcription factor Foxp3 (forkhead box P3) is selectively expressed in T(reg) cells, is required for T(reg) development and function, and is sufficient to induce a T(reg) phenotype in conventional CD4+CD25- T cells. Mutations in Foxp3 cause severe, multi-organ autoimmunity in both human and mouse. FOXP3 can cooperate in a DNA-binding complex with NFAT (nuclear factor of activated T cells) to regulate the transcription of several known target genes. However, the global set of genes regulated directly by Foxp3 is not known and consequently, how this transcription factor controls the gene expression programme for T(reg) function is not understood. Here we identify Foxp3 target genes and report that many of these are key modulators of T-cell activation and function. Remarkably, the predominant, although not exclusive, effect of Foxp3 occupancy is to suppress the activation of target genes on T-cell stimulation. Foxp3 suppression of its targets appears to be crucial for the normal function of T(reg) cells, because overactive variants of some target genes are known to be associated with autoimmune disease.

Standard name | MARSON_FOXP3_TARGETS_STIMULATED_DN
Systematic name | M18702
Organism | Mus musculus
PMID | 17237765
Authors | Marson A,Kretschmer K,Frampton GM,Jacobsen ES,Polansky JK,MacIsaac KD,Levine SS,Fraenkel E,von Boehmer H,Young RA
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by FOXP3 [GeneID=50943], dependent on it, and down-regulated in hybridoma cells stimulated by PMA [PubChem=4792] and ionomycin [PubChem=3733].
Full description | Foxp3+CD4+CD25+ regulatory T (T(reg)) cells are essential for the prevention of autoimmunity. T(reg) cells have an attenuated cytokine response to T-cell receptor stimulation, and can suppress the proliferation and effector function of neighbouring T cells. The forkhead transcription factor Foxp3 (forkhead box P3) is selectively expressed in T(reg) cells, is required for T(reg) development and function, and is sufficient to induce a T(reg) phenotype in conventional CD4+CD25- T cells. Mutations in Foxp3 cause severe, multi-organ autoimmunity in both human and mouse. FOXP3 can cooperate in a DNA-binding complex with NFAT (nuclear factor of activated T cells) to regulate the transcription of several known target genes. However, the global set of genes regulated directly by Foxp3 is not known and consequently, how this transcription factor controls the gene expression programme for T(reg) function is not understood. Here we identify Foxp3 target genes and report that many of these are key modulators of T-cell activation and function. Remarkably, the predominant, although not exclusive, effect of Foxp3 occupancy is to suppress the activation of target genes on T-cell stimulation. Foxp3 suppression of its targets appears to be crucial for the normal function of T(reg) cells, because overactive variants of some target genes are known to be associated with autoimmune disease.

Standard name | MARSON_FOXP3_CORE_DIRECT_TARGETS
Systematic name | M1745
Organism | Mus musculus
PMID | 17237765
Authors | Marson A,Kretschmer K,Frampton GM,Jacobsen ES,Polansky JK,MacIsaac KD,Levine SS,Fraenkel E,von Boehmer H,Young RA
Category | C2
Sub-category | CGP
Brief description | Direct FOXP3 [GeneID=50943] targets that exhibit consistent transcriptional behavior in hybridoma and in ex vivo T lymphocytes.
Full description | Foxp3+CD4+CD25+ regulatory T (T(reg)) cells are essential for the prevention of autoimmunity. T(reg) cells have an attenuated cytokine response to T-cell receptor stimulation, and can suppress the proliferation and effector function of neighbouring T cells. The forkhead transcription factor Foxp3 (forkhead box P3) is selectively expressed in T(reg) cells, is required for T(reg) development and function, and is sufficient to induce a T(reg) phenotype in conventional CD4+CD25- T cells. Mutations in Foxp3 cause severe, multi-organ autoimmunity in both human and mouse. FOXP3 can cooperate in a DNA-binding complex with NFAT (nuclear factor of activated T cells) to regulate the transcription of several known target genes. However, the global set of genes regulated directly by Foxp3 is not known and consequently, how this transcription factor controls the gene expression programme for T(reg) function is not understood. Here we identify Foxp3 target genes and report that many of these are key modulators of T-cell activation and function. Remarkably, the predominant, although not exclusive, effect of Foxp3 occupancy is to suppress the activation of target genes on T-cell stimulation. Foxp3 suppression of its targets appears to be crucial for the normal function of T(reg) cells, because overactive variants of some target genes are known to be associated with autoimmune disease.

Standard name | ZHENG_FOXP3_TARGETS_IN_THYMUS_UP
Systematic name | M1746
Organism | Mus musculus
PMID | 17237761
Authors | Zheng Y,Josefowicz SZ,Kas A,Chu TT,Gavin MA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by FOXP3 [GeneID=50943] and which are up-regulated only in developing (located in the thymus) regulatory CD4+ [GeneID=920] T lymphocytes.
Full description | Transcription factor Foxp3 (forkhead box P3), restricted in its expression to a specialized regulatory CD4+ T-cell subset (T(R)) with a dedicated suppressor function, controls T(R) lineage development. In humans and mice, Foxp3 deficiency results in a paucity of T(R) cells and a fatal breach in immunological tolerance, causing highly aggressive multi-organ autoimmune pathology. Here, through genome-wide analysis combining chromatin immunoprecipitation with mouse genome tiling array profiling, we identify Foxp3 binding regions for approximately 700 genes and for an intergenically encoded microRNA. We find that a large number of Foxp3-bound genes are up- or downregulated in Foxp3+ T cells, suggesting that Foxp3 acts as both a transcriptional activator and repressor. Foxp3-mediated regulation unique to the thymus affects, among others, genes encoding nuclear factors that control gene expression and chromatin remodelling. In contrast, Foxp3 target genes shared by the thymic and peripheral T(R) cells encode primarily plasma membrane proteins, as well as cell signalling proteins. Together, our studies suggest that distinct transcriptional sub-programmes implemented by Foxp3 establish T(R) lineage during differentiation and its proliferative and functional competence in the periphery.

Standard name | ZHENG_FOXP3_TARGETS_IN_THYMUS_DN
Systematic name | M1747
Organism | Mus musculus
PMID | 17237761
Authors | Zheng Y,Josefowicz SZ,Kas A,Chu TT,Gavin MA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by FOXP3 [GeneID=50943] and which are down-regulated only in developing (located in the thymus) regulatory CD4+ [GeneID=920] T lymphocytes.
Full description | Transcription factor Foxp3 (forkhead box P3), restricted in its expression to a specialized regulatory CD4+ T-cell subset (T(R)) with a dedicated suppressor function, controls T(R) lineage development. In humans and mice, Foxp3 deficiency results in a paucity of T(R) cells and a fatal breach in immunological tolerance, causing highly aggressive multi-organ autoimmune pathology. Here, through genome-wide analysis combining chromatin immunoprecipitation with mouse genome tiling array profiling, we identify Foxp3 binding regions for approximately 700 genes and for an intergenically encoded microRNA. We find that a large number of Foxp3-bound genes are up- or downregulated in Foxp3+ T cells, suggesting that Foxp3 acts as both a transcriptional activator and repressor. Foxp3-mediated regulation unique to the thymus affects, among others, genes encoding nuclear factors that control gene expression and chromatin remodelling. In contrast, Foxp3 target genes shared by the thymic and peripheral T(R) cells encode primarily plasma membrane proteins, as well as cell signalling proteins. Together, our studies suggest that distinct transcriptional sub-programmes implemented by Foxp3 establish T(R) lineage during differentiation and its proliferative and functional competence in the periphery.

Standard name | ZHENG_FOXP3_TARGETS_IN_T_LYMPHOCYTE_UP
Systematic name | M1748
Organism | Mus musculus
PMID | 17237761
Authors | Zheng Y,Josefowicz SZ,Kas A,Chu TT,Gavin MA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by FOXP3 [GeneID=50943] and which are up-regulated only in mature (peripheral blood) regulatory CD4+ [GeneID=920] T lymphocytes.
Full description | Transcription factor Foxp3 (forkhead box P3), restricted in its expression to a specialized regulatory CD4+ T-cell subset (T(R)) with a dedicated suppressor function, controls T(R) lineage development. In humans and mice, Foxp3 deficiency results in a paucity of T(R) cells and a fatal breach in immunological tolerance, causing highly aggressive multi-organ autoimmune pathology. Here, through genome-wide analysis combining chromatin immunoprecipitation with mouse genome tiling array profiling, we identify Foxp3 binding regions for approximately 700 genes and for an intergenically encoded microRNA. We find that a large number of Foxp3-bound genes are up- or downregulated in Foxp3+ T cells, suggesting that Foxp3 acts as both a transcriptional activator and repressor. Foxp3-mediated regulation unique to the thymus affects, among others, genes encoding nuclear factors that control gene expression and chromatin remodelling. In contrast, Foxp3 target genes shared by the thymic and peripheral T(R) cells encode primarily plasma membrane proteins, as well as cell signalling proteins. Together, our studies suggest that distinct transcriptional sub-programmes implemented by Foxp3 establish T(R) lineage during differentiation and its proliferative and functional competence in the periphery.

Standard name | ZHENG_FOXP3_TARGETS_IN_T_LYMPHOCYTE_DN
Systematic name | M1751
Organism | Mus musculus
PMID | 17237761
Authors | Zheng Y,Josefowicz SZ,Kas A,Chu TT,Gavin MA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by FOXP3 [GeneID=50943] and which are down-regulated only in mature (peripheral blood) regulatory CD4+ [GeneID=920] T lymphocytes.
Full description | Transcription factor Foxp3 (forkhead box P3), restricted in its expression to a specialized regulatory CD4+ T-cell subset (T(R)) with a dedicated suppressor function, controls T(R) lineage development. In humans and mice, Foxp3 deficiency results in a paucity of T(R) cells and a fatal breach in immunological tolerance, causing highly aggressive multi-organ autoimmune pathology. Here, through genome-wide analysis combining chromatin immunoprecipitation with mouse genome tiling array profiling, we identify Foxp3 binding regions for approximately 700 genes and for an intergenically encoded microRNA. We find that a large number of Foxp3-bound genes are up- or downregulated in Foxp3+ T cells, suggesting that Foxp3 acts as both a transcriptional activator and repressor. Foxp3-mediated regulation unique to the thymus affects, among others, genes encoding nuclear factors that control gene expression and chromatin remodelling. In contrast, Foxp3 target genes shared by the thymic and peripheral T(R) cells encode primarily plasma membrane proteins, as well as cell signalling proteins. Together, our studies suggest that distinct transcriptional sub-programmes implemented by Foxp3 establish T(R) lineage during differentiation and its proliferative and functional competence in the periphery.

Standard name | ZHENG_FOXP3_TARGETS_UP
Systematic name | M1753
Organism | Mus musculus
PMID | 17237761
Authors | Zheng Y,Josefowicz SZ,Kas A,Chu TT,Gavin MA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by FOXP3 [GeneID=50943] and which are up-regulated both in developing (located in the thymus) and mature (from peripheral blood) regulatory CD4+ [GeneID=920] T lymphocytes.
Full description | Transcription factor Foxp3 (forkhead box P3), restricted in its expression to a specialized regulatory CD4+ T-cell subset (T(R)) with a dedicated suppressor function, controls T(R) lineage development. In humans and mice, Foxp3 deficiency results in a paucity of T(R) cells and a fatal breach in immunological tolerance, causing highly aggressive multi-organ autoimmune pathology. Here, through genome-wide analysis combining chromatin immunoprecipitation with mouse genome tiling array profiling, we identify Foxp3 binding regions for approximately 700 genes and for an intergenically encoded microRNA. We find that a large number of Foxp3-bound genes are up- or downregulated in Foxp3+ T cells, suggesting that Foxp3 acts as both a transcriptional activator and repressor. Foxp3-mediated regulation unique to the thymus affects, among others, genes encoding nuclear factors that control gene expression and chromatin remodelling. In contrast, Foxp3 target genes shared by the thymic and peripheral T(R) cells encode primarily plasma membrane proteins, as well as cell signalling proteins. Together, our studies suggest that distinct transcriptional sub-programmes implemented by Foxp3 establish T(R) lineage during differentiation and its proliferative and functional competence in the periphery.

Standard name | ZHENG_FOXP3_TARGETS_DN
Systematic name | M1754
Organism | Mus musculus
PMID | 17237761
Authors | Zheng Y,Josefowicz SZ,Kas A,Chu TT,Gavin MA,Rudensky AY
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by FOXP3 [GeneID=50943] and which are down-regulated both in developing (located in the thymus) and mature (from peripheral blood) regulatory CD4+ [GeneID=920] T lymphocytes.
Full description | Transcription factor Foxp3 (forkhead box P3), restricted in its expression to a specialized regulatory CD4+ T-cell subset (T(R)) with a dedicated suppressor function, controls T(R) lineage development. In humans and mice, Foxp3 deficiency results in a paucity of T(R) cells and a fatal breach in immunological tolerance, causing highly aggressive multi-organ autoimmune pathology. Here, through genome-wide analysis combining chromatin immunoprecipitation with mouse genome tiling array profiling, we identify Foxp3 binding regions for approximately 700 genes and for an intergenically encoded microRNA. We find that a large number of Foxp3-bound genes are up- or downregulated in Foxp3+ T cells, suggesting that Foxp3 acts as both a transcriptional activator and repressor. Foxp3-mediated regulation unique to the thymus affects, among others, genes encoding nuclear factors that control gene expression and chromatin remodelling. In contrast, Foxp3 target genes shared by the thymic and peripheral T(R) cells encode primarily plasma membrane proteins, as well as cell signalling proteins. Together, our studies suggest that distinct transcriptional sub-programmes implemented by Foxp3 establish T(R) lineage during differentiation and its proliferative and functional competence in the periphery.

Standard name | SANSOM_APC_TARGETS
Systematic name | M1755
Organism | Mus musculus
PMID | 17377531
Authors | Sansom OJ,Meniel VS,Muncan V,Phesse TJ,Wilkins JA,Reed KR,Vass JK,Athineos D,Clevers H,Clarke AR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated after Cre-lox knockout of APC [GeneID=324] in the small intestine.
Full description | The APC gene encodes the adenomatous polyposis coli tumour suppressor protein, germline mutation of which characterizes familial adenomatous polyposis (FAP), an autosomal intestinal cancer syndrome. Inactivation of APC is also recognized as the key early event in the development of sporadic colorectal cancers, and its loss results in constitutive activity of the beta-catenin-Tcf4 transcription complex. The proto-oncogene c-MYC has been identified as a target of the Wnt pathway in colorectal cancer cells in vitro, in normal crypts in vivo and in intestinal epithelial cells acutely transformed on in vivo deletion of the APC gene; however, the significance of this is unclear. Therefore, to elucidate the role Myc has in the intestine after Apc loss, we have simultaneously deleted both Apc and Myc in the adult murine small intestine. Here we show that loss of Myc rescued the phenotypes of perturbed differentiation, migration, proliferation and apoptosis, which occur on deletion of Apc. Remarkably, this rescue occurred in the presence of high levels of nuclear beta-catenin. Array analysis revealed that Myc is required for the majority of Wnt target gene activation following Apc loss. These data establish Myc as the critical mediator of the early stages of neoplasia following Apc loss.

Standard name | SANSOM_APC_MYC_TARGETS
Systematic name | M1756
Organism | Mus musculus
PMID | 17377531
Authors | Sansom OJ,Meniel VS,Muncan V,Phesse TJ,Wilkins JA,Reed KR,Vass JK,Athineos D,Clevers H,Clarke AR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated after double Cre-lox knockout of both APC and MYC [GeneID=324;4609] in small intestine.
Full description | The APC gene encodes the adenomatous polyposis coli tumour suppressor protein, germline mutation of which characterizes familial adenomatous polyposis (FAP), an autosomal intestinal cancer syndrome. Inactivation of APC is also recognized as the key early event in the development of sporadic colorectal cancers, and its loss results in constitutive activity of the beta-catenin-Tcf4 transcription complex. The proto-oncogene c-MYC has been identified as a target of the Wnt pathway in colorectal cancer cells in vitro, in normal crypts in vivo and in intestinal epithelial cells acutely transformed on in vivo deletion of the APC gene; however, the significance of this is unclear. Therefore, to elucidate the role Myc has in the intestine after Apc loss, we have simultaneously deleted both Apc and Myc in the adult murine small intestine. Here we show that loss of Myc rescued the phenotypes of perturbed differentiation, migration, proliferation and apoptosis, which occur on deletion of Apc. Remarkably, this rescue occurred in the presence of high levels of nuclear beta-catenin. Array analysis revealed that Myc is required for the majority of Wnt target gene activation following Apc loss. These data establish Myc as the critical mediator of the early stages of neoplasia following Apc loss.

Standard name | SANSOM_APC_TARGETS_REQUIRE_MYC
Systematic name | M1757
Organism | Mus musculus
PMID | 17377531
Authors | Sansom OJ,Meniel VS,Muncan V,Phesse TJ,Wilkins JA,Reed KR,Vass JK,Athineos D,Clevers H,Clarke AR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated after Cre-lox knockout of APC [GeneID=324] in the small intestine that require functional MYC [GeneID=4609].
Full description | The APC gene encodes the adenomatous polyposis coli tumour suppressor protein, germline mutation of which characterizes familial adenomatous polyposis (FAP), an autosomal intestinal cancer syndrome. Inactivation of APC is also recognized as the key early event in the development of sporadic colorectal cancers, and its loss results in constitutive activity of the beta-catenin-Tcf4 transcription complex. The proto-oncogene c-MYC has been identified as a target of the Wnt pathway in colorectal cancer cells in vitro, in normal crypts in vivo and in intestinal epithelial cells acutely transformed on in vivo deletion of the APC gene; however, the significance of this is unclear. Therefore, to elucidate the role Myc has in the intestine after Apc loss, we have simultaneously deleted both Apc and Myc in the adult murine small intestine. Here we show that loss of Myc rescued the phenotypes of perturbed differentiation, migration, proliferation and apoptosis, which occur on deletion of Apc. Remarkably, this rescue occurred in the presence of high levels of nuclear beta-catenin. Array analysis revealed that Myc is required for the majority of Wnt target gene activation following Apc loss. These data establish Myc as the critical mediator of the early stages of neoplasia following Apc loss.

Standard name | SANSOM_WNT_PATHWAY_REQUIRE_MYC
Systematic name | M1758
Organism | Mus musculus
PMID | 17377531
Authors | Sansom OJ,Meniel VS,Muncan V,Phesse TJ,Wilkins JA,Reed KR,Vass JK,Athineos D,Clevers H,Clarke AR
Category | C2
Sub-category | CGP
Brief description | Wnt target genes up-regulated after Cre-lox knockout of APC [GeneID=324] in the small intestine that require functional MYC [GeneID=4609].
Full description | The APC gene encodes the adenomatous polyposis coli tumour suppressor protein, germline mutation of which characterizes familial adenomatous polyposis (FAP), an autosomal intestinal cancer syndrome. Inactivation of APC is also recognized as the key early event in the development of sporadic colorectal cancers, and its loss results in constitutive activity of the beta-catenin-Tcf4 transcription complex. The proto-oncogene c-MYC has been identified as a target of the Wnt pathway in colorectal cancer cells in vitro, in normal crypts in vivo and in intestinal epithelial cells acutely transformed on in vivo deletion of the APC gene; however, the significance of this is unclear. Therefore, to elucidate the role Myc has in the intestine after Apc loss, we have simultaneously deleted both Apc and Myc in the adult murine small intestine. Here we show that loss of Myc rescued the phenotypes of perturbed differentiation, migration, proliferation and apoptosis, which occur on deletion of Apc. Remarkably, this rescue occurred in the presence of high levels of nuclear beta-catenin. Array analysis revealed that Myc is required for the majority of Wnt target gene activation following Apc loss. These data establish Myc as the critical mediator of the early stages of neoplasia following Apc loss.

Standard name | YEGNASUBRAMANIAN_PROSTATE_CANCER
Systematic name | M4034
Organism | Homo sapiens
PMID | 18974140
Authors | Yegnasubramanian S,Haffner MC,Zhang Y,Gurel B,Cornish TC,Wu Z,Irizarry RA,Morgan J,Hicks J,DeWeese TL,Isaacs WB,Bova GS,De Marzo AM,Nelson WG
Category | C2
Sub-category | CGP
Brief description | Genes expressed in at least one prostate cancer cell line but not in normal prostate epithelial cells or stromal cells
Full description | Hypomethylation of CpG dinucleotides in genomic DNA was one of the first somatic epigenetic alterations discovered in human cancers. DNA hypomethylation is postulated to occur very early in almost all human cancers, perhaps facilitating genetic instability and cancer initiation and progression. We therefore examined the nature, extent, and timing of DNA hypomethylation changes in human prostate cancer. Contrary to the prevailing view that global DNA hypomethylation changes occur extremely early in all human cancers, we show that reductions in (5me)C content in the genome occur very late in prostate cancer progression, appearing at a significant extent only at the stage of metastatic disease. Furthermore, we found that, whereas some LINE1 promoter hypomethylation does occur in primary prostate cancers compared with normal tissues, this LINE1 hypomethylation is significantly more pronounced in metastatic prostate cancer. Next, we carried out a tiered gene expression microarray and bisulfite genomic sequencing-based approach to identify genes that are silenced by CpG island methylation in normal prostate cells but become overexpressed in prostate cancer cells as a result of CpG island hypomethylation. Through this analysis, we show that a class of cancer testis antigen genes undergoes CpG island hypomethylation and overexpression in primary prostate cancers, but more so in metastatic prostate cancers. Finally, we show that DNA hypomethylation patterns are quite heterogeneous across different metastatic sites within the same patients. These findings provide evidence that DNA hypomethylation changes occur later in prostate carcinogenesis than the CpG island hypermethylation changes and occur heterogeneously during prostate cancer progression and metastatic dissemination.

Standard name | RIGGINS_TAMOXIFEN_RESISTANCE_UP
Systematic name | M17487
Organism | Homo sapiens
PMID | 18974135
Authors | Riggins RB,Lan JP,Klimach U,Zwart A,Cavalli LR,Haddad BR,Chen L,Gong T,Xuan J,Ethier SP,Clarke R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated SUM44/LCCTam cells (breast cancer) resistant to 4-hydroxytamoxifen [PubChem=63062] relative to the parental SUM44 cells sensitive to the drug.
Full description | One-third of all estrogen receptor (ER)-positive breast tumors treated with endocrine therapy fail to respond, and the remainder is likely to relapse in the future. Almost all data on endocrine resistance has been obtained in models of invasive ductal carcinoma (IDC). However, invasive lobular carcinomas (ILC) comprise up to 15% of newly diagnosed invasive breast cancers each year and, whereas the incidence of IDC has remained relatively constant during the last 20 years, the prevalence of ILC continues to increase among postmenopausal women. We report a new model of Tamoxifen (TAM)-resistant invasive lobular breast carcinoma cells that provides novel insights into the molecular mechanisms of endocrine resistance. SUM44 cells express ER and are sensitive to the growth inhibitory effects of antiestrogens. Selection for resistance to 4-hydroxytamoxifen led to the development of the SUM44/LCCTam cell line, which exhibits decreased expression of ERalpha and increased expression of the estrogen-related receptor gamma (ERRgamma). Knockdown of ERRgamma in SUM44/LCCTam cells by siRNA restores TAM sensitivity, and overexpression of ERRgamma blocks the growth-inhibitory effects of TAM in SUM44 and MDA-MB-134 VI lobular breast cancer cells. ERRgamma-driven transcription is also increased in SUM44/LCCTam, and inhibition of activator protein 1 (AP1) can restore or enhance TAM sensitivity. These data support a role for ERRgamma/AP1 signaling in the development of TAM resistance and suggest that expression of ERRgamma may be a marker of poor TAM response.

Standard name | RIGGINS_TAMOXIFEN_RESISTANCE_DN
Systematic name | M15835
Organism | Homo sapiens
PMID | 18974135
Authors | Riggins RB,Lan JP,Klimach U,Zwart A,Cavalli LR,Haddad BR,Chen L,Gong T,Xuan J,Ethier SP,Clarke R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated SUM44/LCCTam cells (breast cancer) resistant to 4-hydroxytamoxifen [PubChem=63062] relative to the parental SUM44 cells sensitive to the drug.
Full description | One-third of all estrogen receptor (ER)-positive breast tumors treated with endocrine therapy fail to respond, and the remainder is likely to relapse in the future. Almost all data on endocrine resistance has been obtained in models of invasive ductal carcinoma (IDC). However, invasive lobular carcinomas (ILC) comprise up to 15% of newly diagnosed invasive breast cancers each year and, whereas the incidence of IDC has remained relatively constant during the last 20 years, the prevalence of ILC continues to increase among postmenopausal women. We report a new model of Tamoxifen (TAM)-resistant invasive lobular breast carcinoma cells that provides novel insights into the molecular mechanisms of endocrine resistance. SUM44 cells express ER and are sensitive to the growth inhibitory effects of antiestrogens. Selection for resistance to 4-hydroxytamoxifen led to the development of the SUM44/LCCTam cell line, which exhibits decreased expression of ERalpha and increased expression of the estrogen-related receptor gamma (ERRgamma). Knockdown of ERRgamma in SUM44/LCCTam cells by siRNA restores TAM sensitivity, and overexpression of ERRgamma blocks the growth-inhibitory effects of TAM in SUM44 and MDA-MB-134 VI lobular breast cancer cells. ERRgamma-driven transcription is also increased in SUM44/LCCTam, and inhibition of activator protein 1 (AP1) can restore or enhance TAM sensitivity. These data support a role for ERRgamma/AP1 signaling in the development of TAM resistance and suggest that expression of ERRgamma may be a marker of poor TAM response.

Standard name | NIKOLSKY_OVERCONNECTED_IN_BREAST_CANCER
Systematic name | M10991
Organism | Homo sapiens
PMID | 19010930
Authors | Nikolsky Y,Sviridov E,Yao J,Dosymbekov D,Ustyansky V,Kaznacheev V,Dezso Z,Mulvey L,Macconaill LE,Winckler W,Serebryiskaya T,Nikolskaya T,Polyak K
Category | C2
Sub-category | CGP
Brief description | Overconnected mutated transcription factors regulating genes within the breast cancer amplicome.
Full description | A single cancer cell contains large numbers of genetic alterations that in combination create the malignant phenotype. However, whether amplified and mutated genes form functional and physical interaction networks that could explain the selection for cells with combined alterations is unknown. To investigate this issue, we characterized copy number alterations in 191 breast tumors using dense single nucleotide polymorphism arrays and identified 1,747 genes with copy number gain organized into 30 amplicons. Amplicons were distributed unequally throughout the genome. Each amplicon had distinct enrichment pattern in pathways, networks, and molecular functions, but genes within individual amplicons did not form coherent functional units. Genes in amplicons included all major tumorigenic pathways and were highly enriched in breast cancer-causative genes. In contrast, 1,188 genes with somatic mutations in breast cancer were distributed randomly over the genome, did not represent a functionally cohesive gene set, and were relatively less enriched in breast cancer marker genes. Mutated and gained genes did not show statistically significant overlap but were highly synergistic in populating key tumorigenic pathways including transforming growth factor beta, WNT, fibroblast growth factor, and PIP3 signaling. In general, mutated genes were more frequently upstream of gained genes in transcription regulation signaling than vice versa, suggesting that mutated genes are mainly regulators, whereas gained genes are mostly regulated. ESR1 was the major transcription factor regulating amplified but not mutated genes. Our results support the hypothesis that multiple genetic events, including copy number gains and somatic mutations, are necessary for establishing the malignant cell phenotype.

Standard name | STEIN_ESRRA_TARGETS_RESPONSIVE_TO_ESTROGEN_UP
Systematic name | M19548
Organism | Homo sapiens
PMID | 18974123
Authors | Stein RA,Chang CY,Kazmin DA,Way J,Schroeder T,Wergin M,Dewhirst MW,McDonnell DP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by estradiol [PubChem=5757] and up-regulated by ESRRA [GeneID=2101] in MCF-7 cells (breast cancer).
Full description | Expression of estrogen-related receptor alpha (ERRalpha) has recently been shown to carry negative prognostic significance in breast and ovarian cancers. The specific role of this orphan nuclear receptor in tumor growth and progression, however, is yet to be fully understood. The significant homology between estrogen receptor alpha (ERalpha) and ERRalpha initially suggested that these receptors may have similar transcriptional targets. Using the well-characterized ERalpha-positive MCF-7 breast cancer cell line, we sought to gain a genome-wide picture of ERalpha-ERRalpha cross-talk using an unbiased microarray approach. In addition to generating a host of novel ERRalpha target genes, this study yielded the surprising result that most ERRalpha-regulated genes are unrelated to estrogen signaling. The relatively small number of genes regulated by both ERalpha and ERRalpha led us to expand our study to the more aggressive and less clinically treatable ERalpha-negative class of breast cancers. In this setting, we found that ERRalpha expression is required for the basal level of expression of many known and novel ERRalpha target genes. Introduction of a small interfering RNA directed to ERRalpha into the highly aggressive breast carcinoma MDA-MB-231 cell line dramatically reduced the migratory potential of these cells. Although stable knockdown of ERRalpha expression in MDA-MB-231 cells had no effect on in vitro cell proliferation, a significant reduction of tumor growth rate was observed when these cells were implanted as xenografts. Our results confirm a role for ERRalpha in breast cancer growth and highlight it as a potential therapeutic target for estrogen receptor-negative breast cancer.

Standard name | STEIN_ESRRA_TARGETS_RESPONSIVE_TO_ESTROGEN_DN
Systematic name | M19002
Organism | Homo sapiens
PMID | 18974123
Authors | Stein RA,Chang CY,Kazmin DA,Way J,Schroeder T,Wergin M,Dewhirst MW,McDonnell DP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by estradiol [PubChem=5757] and down-regulated by ESRRA [GeneID=2101] in MCF-7 cells (breast cancer).
Full description | Expression of estrogen-related receptor alpha (ERRalpha) has recently been shown to carry negative prognostic significance in breast and ovarian cancers. The specific role of this orphan nuclear receptor in tumor growth and progression, however, is yet to be fully understood. The significant homology between estrogen receptor alpha (ERalpha) and ERRalpha initially suggested that these receptors may have similar transcriptional targets. Using the well-characterized ERalpha-positive MCF-7 breast cancer cell line, we sought to gain a genome-wide picture of ERalpha-ERRalpha cross-talk using an unbiased microarray approach. In addition to generating a host of novel ERRalpha target genes, this study yielded the surprising result that most ERRalpha-regulated genes are unrelated to estrogen signaling. The relatively small number of genes regulated by both ERalpha and ERRalpha led us to expand our study to the more aggressive and less clinically treatable ERalpha-negative class of breast cancers. In this setting, we found that ERRalpha expression is required for the basal level of expression of many known and novel ERRalpha target genes. Introduction of a small interfering RNA directed to ERRalpha into the highly aggressive breast carcinoma MDA-MB-231 cell line dramatically reduced the migratory potential of these cells. Although stable knockdown of ERRalpha expression in MDA-MB-231 cells had no effect on in vitro cell proliferation, a significant reduction of tumor growth rate was observed when these cells were implanted as xenografts. Our results confirm a role for ERRalpha in breast cancer growth and highlight it as a potential therapeutic target for estrogen receptor-negative breast cancer.

Standard name | STEIN_ESRRA_TARGETS_UP
Systematic name | M18491
Organism | Homo sapiens
PMID | 18974123
Authors | Stein RA,Chang CY,Kazmin DA,Way J,Schroeder T,Wergin M,Dewhirst MW,McDonnell DP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by ESRRA [GeneID=2101] only.
Full description | Expression of estrogen-related receptor alpha (ERRalpha) has recently been shown to carry negative prognostic significance in breast and ovarian cancers. The specific role of this orphan nuclear receptor in tumor growth and progression, however, is yet to be fully understood. The significant homology between estrogen receptor alpha (ERalpha) and ERRalpha initially suggested that these receptors may have similar transcriptional targets. Using the well-characterized ERalpha-positive MCF-7 breast cancer cell line, we sought to gain a genome-wide picture of ERalpha-ERRalpha cross-talk using an unbiased microarray approach. In addition to generating a host of novel ERRalpha target genes, this study yielded the surprising result that most ERRalpha-regulated genes are unrelated to estrogen signaling. The relatively small number of genes regulated by both ERalpha and ERRalpha led us to expand our study to the more aggressive and less clinically treatable ERalpha-negative class of breast cancers. In this setting, we found that ERRalpha expression is required for the basal level of expression of many known and novel ERRalpha target genes. Introduction of a small interfering RNA directed to ERRalpha into the highly aggressive breast carcinoma MDA-MB-231 cell line dramatically reduced the migratory potential of these cells. Although stable knockdown of ERRalpha expression in MDA-MB-231 cells had no effect on in vitro cell proliferation, a significant reduction of tumor growth rate was observed when these cells were implanted as xenografts. Our results confirm a role for ERRalpha in breast cancer growth and highlight it as a potential therapeutic target for estrogen receptor-negative breast cancer.

Standard name | STEIN_ESRRA_TARGETS_DN
Systematic name | M18160
Organism | Homo sapiens
PMID | 18974123
Authors | Stein RA,Chang CY,Kazmin DA,Way J,Schroeder T,Wergin M,Dewhirst MW,McDonnell DP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by ESRRA [GeneID=2101] only.
Full description | Expression of estrogen-related receptor alpha (ERRalpha) has recently been shown to carry negative prognostic significance in breast and ovarian cancers. The specific role of this orphan nuclear receptor in tumor growth and progression, however, is yet to be fully understood. The significant homology between estrogen receptor alpha (ERalpha) and ERRalpha initially suggested that these receptors may have similar transcriptional targets. Using the well-characterized ERalpha-positive MCF-7 breast cancer cell line, we sought to gain a genome-wide picture of ERalpha-ERRalpha cross-talk using an unbiased microarray approach. In addition to generating a host of novel ERRalpha target genes, this study yielded the surprising result that most ERRalpha-regulated genes are unrelated to estrogen signaling. The relatively small number of genes regulated by both ERalpha and ERRalpha led us to expand our study to the more aggressive and less clinically treatable ERalpha-negative class of breast cancers. In this setting, we found that ERRalpha expression is required for the basal level of expression of many known and novel ERRalpha target genes. Introduction of a small interfering RNA directed to ERRalpha into the highly aggressive breast carcinoma MDA-MB-231 cell line dramatically reduced the migratory potential of these cells. Although stable knockdown of ERRalpha expression in MDA-MB-231 cells had no effect on in vitro cell proliferation, a significant reduction of tumor growth rate was observed when these cells were implanted as xenografts. Our results confirm a role for ERRalpha in breast cancer growth and highlight it as a potential therapeutic target for estrogen receptor-negative breast cancer.

Standard name | WANG_LSD1_TARGETS_UP
Systematic name | M1759
Organism | Mus musculus
PMID | 17392792
Authors | Wang J,Scully K,Zhu X,Cai L,Zhang J,Prefontaine GG,Krones A,Ohgi KA,Zhu P,Garcia-Bassets I,Liu F,Taylor H,Lozach J,Jayes FL,Korach KS,Glass CK,Fu XD,Rosenfeld MG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated after Cre-lox knockout of LSD1 [GeneID=23028] in pituitary.
Full description | Precise control of transcriptional programmes underlying metazoan development is modulated by enzymatically active co-regulatory complexes, coupled with epigenetic strategies. One thing that remains unclear is how specific members of histone modification enzyme families, such as histone methyltransferases and demethylases, are used in vivo to simultaneously orchestrate distinct developmental gene activation and repression programmes. Here, we report that the histone lysine demethylase, LSD1--a component of the CoREST-CtBP co-repressor complex--is required for late cell-lineage determination and differentiation during pituitary organogenesis. LSD1 seems to act primarily on target gene activation programmes, as well as in gene repression programmes, on the basis of recruitment of distinct LSD1-containing co-activator or co-repressor complexes. LSD1-dependent gene repression programmes can be extended late in development with the induced expression of ZEB1, a Krüppel-like repressor that can act as a molecular beacon for recruitment of the LSD1-containing CoREST-CtBP co-repressor complex, causing repression of an additional cohort of genes, such as Gh, which previously required LSD1 for activation. These findings suggest that temporal patterns of expression of specific components of LSD1 complexes modulate gene regulatory programmes in many mammalian organs.

Standard name | WANG_LSD1_TARGETS_DN
Systematic name | M1760
Organism | Mus musculus
PMID | 17392792
Authors | Wang J,Scully K,Zhu X,Cai L,Zhang J,Prefontaine GG,Krones A,Ohgi KA,Zhu P,Garcia-Bassets I,Liu F,Taylor H,Lozach J,Jayes FL,Korach KS,Glass CK,Fu XD,Rosenfeld MG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated after Cre-lox knockout of LSD1 [GeneID=23028] in pituitary.
Full description | Precise control of transcriptional programmes underlying metazoan development is modulated by enzymatically active co-regulatory complexes, coupled with epigenetic strategies. One thing that remains unclear is how specific members of histone modification enzyme families, such as histone methyltransferases and demethylases, are used in vivo to simultaneously orchestrate distinct developmental gene activation and repression programmes. Here, we report that the histone lysine demethylase, LSD1--a component of the CoREST-CtBP co-repressor complex--is required for late cell-lineage determination and differentiation during pituitary organogenesis. LSD1 seems to act primarily on target gene activation programmes, as well as in gene repression programmes, on the basis of recruitment of distinct LSD1-containing co-activator or co-repressor complexes. LSD1-dependent gene repression programmes can be extended late in development with the induced expression of ZEB1, a Krüppel-like repressor that can act as a molecular beacon for recruitment of the LSD1-containing CoREST-CtBP co-repressor complex, causing repression of an additional cohort of genes, such as Gh, which previously required LSD1 for activation. These findings suggest that temporal patterns of expression of specific components of LSD1 complexes modulate gene regulatory programmes in many mammalian organs.

Standard name | FOSTER_TOLERANT_MACROPHAGE_UP
Systematic name | M12595
Organism | Mus musculus
PMID | 17538624
Authors | Foster SL,Hargreaves DC,Medzhitov R
Category | C2
Sub-category | CGP
Brief description | Class T (tolerizeable) genes: induced during the first LPS stimulation and either not re-induced or induced to a much lesser degree in tolerant macrophages.
Full description | Toll-like receptors (TLRs) induce a multi-component inflammatory response that must be tightly regulated to avoid tissue damage. Most known regulatory mechanisms target TLR signalling pathways and thus broadly inhibit multiple aspects of the inflammatory response. Given the functional diversity of TLR-induced genes, we proposed that additional, gene-specific regulatory mechanisms exist to allow individual aspects of the TLR-induced response to be differentially regulated. Using an in vitro system of lipopolysaccharide tolerance in murine macrophages, we show that TLR-induced genes fall into two categories on the basis of their functions and regulatory requirements. We demonstrate that representatives from the two classes acquire distinct patterns of TLR-induced chromatin modifications. These gene-specific chromatin modifications are associated with transient silencing of one class of genes, which includes pro-inflammatory mediators, and priming of the second class, which includes antimicrobial effectors. These findings illustrate an adaptive response in macrophages and reveal component-specific regulation of inflammation.

Standard name | FOSTER_TOLERANT_MACROPHAGE_DN
Systematic name | M12676
Organism | Mus musculus
PMID | 17538624
Authors | Foster SL,Hargreaves DC,Medzhitov R
Category | C2
Sub-category | CGP
Brief description | Class NT (non-tolerizeable) genes: induced during the first LPS stimulation and induced at equal or greater degree in tolerant macrophages.
Full description | Toll-like receptors (TLRs) induce a multi-component inflammatory response that must be tightly regulated to avoid tissue damage. Most known regulatory mechanisms target TLR signalling pathways and thus broadly inhibit multiple aspects of the inflammatory response. Given the functional diversity of TLR-induced genes, we proposed that additional, gene-specific regulatory mechanisms exist to allow individual aspects of the TLR-induced response to be differentially regulated. Using an in vitro system of lipopolysaccharide tolerance in murine macrophages, we show that TLR-induced genes fall into two categories on the basis of their functions and regulatory requirements. We demonstrate that representatives from the two classes acquire distinct patterns of TLR-induced chromatin modifications. These gene-specific chromatin modifications are associated with transient silencing of one class of genes, which includes pro-inflammatory mediators, and priming of the second class, which includes antimicrobial effectors. These findings illustrate an adaptive response in macrophages and reveal component-specific regulation of inflammation.

Standard name | TESAR_ALK_TARGETS_EPISC_3D_UP
Systematic name | M1761
Organism | Mus musculus
PMID | 17597760
Authors | Tesar PJ,Chenoweth JG,Brook FA,Davies TJ,Evans EP,Mack DL,Gardner RL,McKay RD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in EpiSC cells (mouse epiblast embryonic stem cells) after treatment with the ALK [GeneID=238] inhibitor SB-431542 [PubChem=4521392].
Full description | The application of human embryonic stem (ES) cells in medicine and biology has an inherent reliance on understanding the starting cell population. Human ES cells differ from mouse ES cells and the specific embryonic origin of both cell types is unclear. Previous work suggested that mouse ES cells could only be obtained from the embryo before implantation in the uterus. Here we show that cell lines can be derived from the epiblast, a tissue of the post-implantation embryo that generates the embryo proper. These cells, which we refer to as EpiSCs (post-implantation epiblast-derived stem cells), express transcription factors known to regulate pluripotency, maintain their genomic integrity, and robustly differentiate into the major somatic cell types as well as primordial germ cells. The EpiSC lines are distinct from mouse ES cells in their epigenetic state and the signals controlling their differentiation. Furthermore, EpiSC and human ES cells share patterns of gene expression and signalling responses that normally function in the epiblast. These results show that epiblast cells can be maintained as stable cell lines and interrogated to understand how pluripotent cells generate distinct fates during early development.

Standard name | TESAR_ALK_TARGETS_EPISC_4D_UP
Systematic name | M1762
Organism | Mus musculus
PMID | 17597760
Authors | Tesar PJ,Chenoweth JG,Brook FA,Davies TJ,Evans EP,Mack DL,Gardner RL,McKay RD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in EpiSC cells (epiblast stem cells) after treatment with the ALK [GeneID=238] inhibitor SB-431542 [PubChem=4521392].
Full description | The application of human embryonic stem (ES) cells in medicine and biology has an inherent reliance on understanding the starting cell population. Human ES cells differ from mouse ES cells and the specific embryonic origin of both cell types is unclear. Previous work suggested that mouse ES cells could only be obtained from the embryo before implantation in the uterus. Here we show that cell lines can be derived from the epiblast, a tissue of the post-implantation embryo that generates the embryo proper. These cells, which we refer to as EpiSCs (post-implantation epiblast-derived stem cells), express transcription factors known to regulate pluripotency, maintain their genomic integrity, and robustly differentiate into the major somatic cell types as well as primordial germ cells. The EpiSC lines are distinct from mouse ES cells in their epigenetic state and the signals controlling their differentiation. Furthermore, EpiSC and human ES cells share patterns of gene expression and signalling responses that normally function in the epiblast. These results show that epiblast cells can be maintained as stable cell lines and interrogated to understand how pluripotent cells generate distinct fates during early development.

Standard name | TESAR_ALK_AND_JAK_TARGETS_MOUSE_ES_D4_UP
Systematic name | M1763
Organism | Mus musculus
PMID | 17597760
Authors | Tesar PJ,Chenoweth JG,Brook FA,Davies TJ,Evans EP,Mack DL,Gardner RL,McKay RD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mES cells (mouse embryonic stem cells) after tratment with the ALK [GeneID=238] inhibitor SB-431542 and JAK inhibitor I [PubChem=4521392;5494425].
Full description | The application of human embryonic stem (ES) cells in medicine and biology has an inherent reliance on understanding the starting cell population. Human ES cells differ from mouse ES cells and the specific embryonic origin of both cell types is unclear. Previous work suggested that mouse ES cells could only be obtained from the embryo before implantation in the uterus. Here we show that cell lines can be derived from the epiblast, a tissue of the post-implantation embryo that generates the embryo proper. These cells, which we refer to as EpiSCs (post-implantation epiblast-derived stem cells), express transcription factors known to regulate pluripotency, maintain their genomic integrity, and robustly differentiate into the major somatic cell types as well as primordial germ cells. The EpiSC lines are distinct from mouse ES cells in their epigenetic state and the signals controlling their differentiation. Furthermore, EpiSC and human ES cells share patterns of gene expression and signalling responses that normally function in the epiblast. These results show that epiblast cells can be maintained as stable cell lines and interrogated to understand how pluripotent cells generate distinct fates during early development.

Standard name | TESAR_ALK_AND_JAK_TARGETS_MOUSE_ES_D4_DN
Systematic name | M1764
Organism | Mus musculus
PMID | 17597760
Authors | Tesar PJ,Chenoweth JG,Brook FA,Davies TJ,Evans EP,Mack DL,Gardner RL,McKay RD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mES cells (mouse embryonic stem cells) after tratment with the ALK [GeneID=238] inhibitor SB-431542 and JAK inhibitor I [PubChem=4521392;5494425].
Full description | The application of human embryonic stem (ES) cells in medicine and biology has an inherent reliance on understanding the starting cell population. Human ES cells differ from mouse ES cells and the specific embryonic origin of both cell types is unclear. Previous work suggested that mouse ES cells could only be obtained from the embryo before implantation in the uterus. Here we show that cell lines can be derived from the epiblast, a tissue of the post-implantation embryo that generates the embryo proper. These cells, which we refer to as EpiSCs (post-implantation epiblast-derived stem cells), express transcription factors known to regulate pluripotency, maintain their genomic integrity, and robustly differentiate into the major somatic cell types as well as primordial germ cells. The EpiSC lines are distinct from mouse ES cells in their epigenetic state and the signals controlling their differentiation. Furthermore, EpiSC and human ES cells share patterns of gene expression and signalling responses that normally function in the epiblast. These results show that epiblast cells can be maintained as stable cell lines and interrogated to understand how pluripotent cells generate distinct fates during early development.

Standard name | TESAR_JAK_TARGETS_MOUSE_ES_D3_DN
Systematic name | M1766
Organism | Mus musculus
PMID | 17597760
Authors | Tesar PJ,Chenoweth JG,Brook FA,Davies TJ,Evans EP,Mack DL,Gardner RL,McKay RD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mES cells (mouse embryonic stem cells) after tratment with JAK inhibitor I [PubChem=5494425].
Full description | The application of human embryonic stem (ES) cells in medicine and biology has an inherent reliance on understanding the starting cell population. Human ES cells differ from mouse ES cells and the specific embryonic origin of both cell types is unclear. Previous work suggested that mouse ES cells could only be obtained from the embryo before implantation in the uterus. Here we show that cell lines can be derived from the epiblast, a tissue of the post-implantation embryo that generates the embryo proper. These cells, which we refer to as EpiSCs (post-implantation epiblast-derived stem cells), express transcription factors known to regulate pluripotency, maintain their genomic integrity, and robustly differentiate into the major somatic cell types as well as primordial germ cells. The EpiSC lines are distinct from mouse ES cells in their epigenetic state and the signals controlling their differentiation. Furthermore, EpiSC and human ES cells share patterns of gene expression and signalling responses that normally function in the epiblast. These results show that epiblast cells can be maintained as stable cell lines and interrogated to understand how pluripotent cells generate distinct fates during early development.

Standard name | JI_CARCINOGENESIS_BY_KRAS_AND_STK11_DN
Systematic name | M1767
Organism | Mus musculus
PMID | 17676035
Authors | Ji H,Ramsey MR,Hayes DN,Fan C,McNamara K,Kozlowski P,Torrice C,Wu MC,Shimamura T,Perera SA,Liang MC,Cai D,Naumov GN,Bao L,Contreras CM,Li D,Chen L,Krishnamurthy J,Koivunen J,Chirieac LR,Padera RF,Bronson RT,Lindeman NI,Christiani DC,Lin X,Shapiro GI,Jänne PA,Johnson BE,Meyerson M,Kwiatkowski DJ,Castrillon DH,Bardeesy N,Sharpless NE,Wong KK
Category | C2
Sub-category | CGP
Brief description | Cluster B: genes down-regulated in primary lung tumors driven by KRAS [GeneID=3845] activation and loss of STK11 [GeneID=6794]; also up-regulated in human squamous cell carcinoma (SCC) vs adenocarcinoma subtype of NSCLC (non-small cell lung cancer).
Full description | Germline mutation in serine/threonine kinase 11 (STK11, also called LKB1) results in Peutz-Jeghers syndrome, characterized by intestinal hamartomas and increased incidence of epithelial cancers. Although uncommon in most sporadic cancers, inactivating somatic mutations of LKB1 have been reported in primary human lung adenocarcinomas and derivative cell lines. Here we used a somatically activatable mutant Kras-driven model of mouse lung cancer to compare the role of Lkb1 to other tumour suppressors in lung cancer. Although Kras mutation cooperated with loss of p53 or Ink4a/Arf (also known as Cdkn2a) in this system, the strongest cooperation was seen with homozygous inactivation of Lkb1. Lkb1-deficient tumours demonstrated shorter latency, an expanded histological spectrum (adeno-, squamous and large-cell carcinoma) and more frequent metastasis compared to tumours lacking p53 or Ink4a/Arf. Pulmonary tumorigenesis was also accelerated by hemizygous inactivation of Lkb1. Consistent with these findings, inactivation of LKB1 was found in 34% and 19% of 144 analysed human lung adenocarcinomas and squamous cell carcinomas, respectively. Expression profiling in human lung cancer cell lines and mouse lung tumours identified a variety of metastasis-promoting genes, such as NEDD9, VEGFC and CD24, as targets of LKB1 repression in lung cancer. These studies establish LKB1 as a critical barrier to pulmonary tumorigenesis, controlling initiation, differentiation and metastasis.

Standard name | JI_CARCINOGENESIS_BY_KRAS_AND_STK11_UP
Systematic name | M1769
Organism | Mus musculus
PMID | 17676035
Authors | Ji H,Ramsey MR,Hayes DN,Fan C,McNamara K,Kozlowski P,Torrice C,Wu MC,Shimamura T,Perera SA,Liang MC,Cai D,Naumov GN,Bao L,Contreras CM,Li D,Chen L,Krishnamurthy J,Koivunen J,Chirieac LR,Padera RF,Bronson RT,Lindeman NI,Christiani DC,Lin X,Shapiro GI,Jänne PA,Johnson BE,Meyerson M,Kwiatkowski DJ,Castrillon DH,Bardeesy N,Sharpless NE,Wong KK
Category | C2
Sub-category | CGP
Brief description | Cluster A: genes up-regulated in primary lung tumors driven by KRAS [GeneID=3845] activation and loss of STK11 [GeneID=6794]; also up-regulated in human squamous cell carcinoma (SCC) vs adenocarcinoma subtype of NSCLC (non-small cell lung cancer).
Full description | Germline mutation in serine/threonine kinase 11 (STK11, also called LKB1) results in Peutz-Jeghers syndrome, characterized by intestinal hamartomas and increased incidence of epithelial cancers. Although uncommon in most sporadic cancers, inactivating somatic mutations of LKB1 have been reported in primary human lung adenocarcinomas and derivative cell lines. Here we used a somatically activatable mutant Kras-driven model of mouse lung cancer to compare the role of Lkb1 to other tumour suppressors in lung cancer. Although Kras mutation cooperated with loss of p53 or Ink4a/Arf (also known as Cdkn2a) in this system, the strongest cooperation was seen with homozygous inactivation of Lkb1. Lkb1-deficient tumours demonstrated shorter latency, an expanded histological spectrum (adeno-, squamous and large-cell carcinoma) and more frequent metastasis compared to tumours lacking p53 or Ink4a/Arf. Pulmonary tumorigenesis was also accelerated by hemizygous inactivation of Lkb1. Consistent with these findings, inactivation of LKB1 was found in 34% and 19% of 144 analysed human lung adenocarcinomas and squamous cell carcinomas, respectively. Expression profiling in human lung cancer cell lines and mouse lung tumours identified a variety of metastasis-promoting genes, such as NEDD9, VEGFC and CD24, as targets of LKB1 repression in lung cancer. These studies establish LKB1 as a critical barrier to pulmonary tumorigenesis, controlling initiation, differentiation and metastasis.

Standard name | GAZIN_EPIGENETIC_SILENCING_BY_KRAS
Systematic name | M1770
Organism | Mus musculus
PMID | 17960246
Authors | Gazin C,Wajapeyee N,Gobeil S,Virbasius CM,Green MR
Category | C2
Sub-category | CGP
Brief description | Genes required for epigenetic silencing of FAS [GeneID=355] by activated KRAS [GeneID=3845] in NIH 3T3 cells, based on RNAi screen.
Full description | The conversion of a normal cell to a cancer cell occurs in several steps and typically involves the activation of oncogenes and the inactivation of tumour suppressor and pro-apoptotic genes. In many instances, inactivation of genes critical for cancer development occurs by epigenetic silencing, often involving hypermethylation of CpG-rich promoter regions. It remains to be determined whether silencing occurs by random acquisition of epigenetic marks that confer a selective growth advantage or through a specific pathway initiated by an oncogene. Here we perform a genome-wide RNA interference (RNAi) screen in K-ras-transformed NIH 3T3 cells and identify 28 genes required for Ras-mediated epigenetic silencing of the pro-apoptotic Fas gene. At least nine of these RESEs (Ras epigenetic silencing effectors), including the DNA methyltransferase DNMT1, are directly associated with specific regions of the Fas promoter in K-ras-transformed NIH 3T3 cells but not in untransformed NIH 3T3 cells. RNAi-mediated knockdown of any of the 28 RESEs results in failure to recruit DNMT1 to the Fas promoter, loss of Fas promoter hypermethylation, and derepression of Fas expression. Analysis of five other epigenetically repressed genes indicates that Ras directs the silencing of multiple unrelated genes through a largely common pathway. Last, we show that nine RESEs are required for anchorage-independent growth and tumorigenicity of K-ras-transformed NIH 3T3 cells; these nine genes have not previously been implicated in transformation by Ras. Our results show that Ras-mediated epigenetic silencing occurs through a specific, complex, pathway involving components that are required for maintenance of a fully transformed phenotype.

Standard name | JEPSEN_SMRT_TARGETS
Systematic name | M1773
Organism | Mus musculus
PMID | 17928865
Authors | Jepsen K,Solum D,Zhou T,McEvilly RJ,Kim HJ,Glass CK,Hermanson O,Rosenfeld MG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in neural progenitor cells (NPC) isolated from E13 cortical tissue of SMRT [GeneID=9612] knockout mice.
Full description | A series of transcription factors critical for maintenance of the neural stem cell state have been identified, but the role of functionally important corepressors in maintenance of the neural stem cell state and early neurogenesis remains unclear. Previous studies have characterized the expression of both SMRT (also known as NCoR2, nuclear receptor co-repressor 2) and NCoR in a variety of developmental systems; however, the specific role of the SMRT corepressor in neurogenesis is still to be determined. Here we report a critical role for SMRT in forebrain development and in maintenance of the neural stem cell state. Analysis of a series of markers in SMRT-gene-deleted mice revealed the functional requirement of SMRT in the actions of both retinoic-acid-dependent and Notch-dependent forebrain development. In isolated cortical progenitor cells, SMRT was critical for preventing retinoic-acid-receptor-dependent induction of differentiation along a neuronal pathway in the absence of any ligand. Our data reveal that SMRT represses expression of the jumonji-domain containing gene JMJD3, a direct retinoic-acid-receptor target that functions as a histone H3 trimethyl K27 demethylase and which is capable of activating specific components of the neurogenic program.

Standard name | KYNG_DNA_DAMAGE_BY_4NQO
Systematic name | M11361
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes specifically responding to 4NQO treatment of primary fibroblasts.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_DNA_DAMAGE_BY_GAMMA_RADIATION
Systematic name | M12971
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes specifically responding to gamma radiation.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_DNA_DAMAGE_BY_UV
Systematic name | M17866
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | UV only responding genes in primary fibroblasts from young donors.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_DNA_DAMAGE_BY_4NQO_OR_GAMMA_RADIATION
Systematic name | M19053
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes responding to 4NQO treatment and gamma irradiation.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS

Standard name | KYNG_DNA_DAMAGE_BY_4NQO_OR_UV
Systematic name | M1816
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | 4NQO treatment and UV irradiation responding genes.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS

Standard name | KYNG_DNA_DAMAGE_BY_GAMMA_AND_UV_RADIATION
Systematic name | M2540
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Gamma and UV responding genes.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS

Standard name | KYNG_ENVIRONMENTAL_STRESS_RESPONSE_NOT_BY_4NQO_IN_OLD
Systematic name | M1895
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Human environmental etress response genes not changed in primary fibroblasts from old donors in response to 4NQO treatment.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_ENVIRONMENTAL_STRESS_RESPONSE_NOT_BY_4NQO_IN_WS
Systematic name | M5040
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Human environmental stress response genes not changed in primary fibroblasts from Wilmor syndrom (WS) patients in response to 4NQO treatment.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_ENVIRONMENTAL_STRESS_RESPONSE_NOT_BY_GAMMA_IN_OLD
Systematic name | M2503
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Human environmental stress response (H-ESR) genes not changed in primary fibroblasts from old donors in response to gamma radiation.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_ENVIRONMENTAL_STRESS_RESPONSE_NOT_BY_GAMMA_IN_WS
Systematic name | M12458
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Human environmental stress response genes not changed in primary fibroblasts from Werner syndrom (WS) patients in response to gamma radiation.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_ENVIRONMENTAL_STRESS_RESPONSE_NOT_BY_UV_IN_OLD
Systematic name | M16409
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Human environmental stress response genes not changed in primary fibroblasts from old donors in response to UV radiation.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_ENVIRONMENTAL_STRESS_RESPONSE_NOT_BY_UV_IN_WS
Systematic name | M19703
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Human environmental stress response genes not changed in primary fibroblasts from patients with Warner syndrom (WS) .
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_DNA_DAMAGE_DN
Systematic name | M11350
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes with GO annotation and down-regulated after DNA damage in cell lines from young donors.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_DNA_DAMAGE_UP
Systematic name | M3961
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes with GO annotation and up-regulated after DNA damage in cell lines from young donors.
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_ENVIRONMENTAL_STRESS_RESPONSE_UP
Systematic name | M14365
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | All common up-regulated stress response genes (Human Environmental Stress Response, H-ESR).
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KYNG_ENVIRONMENTAL_STRESS_RESPONSE_DN
Systematic name | M1776
Organism | Homo sapiens
PMID | 15897889
Authors | Kyng KJ,May A,Stevnsner T,Becker KG,Kølvrå S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | All common down-regulated stress response genes (Human Environmental Stress Response, H-ESR).
Full description | The accumulation of DNA damage and mutations is considered a major cause of cancer and aging. While it is known that DNA damage can affect changes in gene expression, transcriptional regulation after DNA damage is poorly understood. We characterized the expression of 6912 genes in human primary fibroblasts after exposure to three different kinds of cellular stress that introduces DNA damage: 4-nitroquinoline-1-oxide (4NQO), gamma-irradiation, or UV-irradiation. Each type of stress elicited damage specific gene expression changes of up to 10-fold. A total of 85 genes had similar changes in expression of 3-40-fold after all three kinds of stress. We examined transcription in cells from young and old individuals and from patients with Werner syndrome (WS), a segmental progeroid condition with a high incidence of cancer, and found various age-associated transcriptional changes depending upon the type of cellular stress. Compared to young individuals, both WS and old individuals had similarly aberrant transcriptional responses to gamma- and UV-irradiation, suggesting a role for Werner protein in stress-induced gene expression. Our results suggest that aberrant DNA damage-induced gene regulation may contribute to the aging process and the premature aging in WS.

Standard name | KONDO_PROSTATE_CANCER_HCP_WITH_H3K27ME3
Systematic name | M16734
Organism | Homo sapiens
PMID | 18488029
Authors | Kondo Y,Shen L,Cheng AS,Ahmed S,Boumber Y,Charo C,Yamochi T,Urano T,Furukawa K,Kwabi-Addo B,Gold DL,Sekido Y,Huang TH,Issa JP
Category | C2
Sub-category | CGP
Brief description | Genes with high histone H3 trimethylation mark at K27 (H3K27me3) in PC3 cells (prostate cancer) by ChIP-chip assay on a 12K CpG array (high-CpG-density promoters, HCP).
Full description | Epigenetic silencing in cancer cells is mediated by at least two distinct histone modifications, polycomb-based histone H3 lysine 27 trimethylation (H3K27triM) and H3K9 dimethylation. The relationship between DNA hypermethylation and these histone modifications is not completely understood. Using chromatin immunoprecipitation microarrays (ChIP-chip) in prostate cancer cells compared to normal prostate, we found that up to 5% of promoters (16% CpG islands and 84% non-CpG islands) were enriched with H3K27triM. These genes were silenced specifically in prostate cancer, and those CpG islands affected showed low levels of DNA methylation. Downregulation of the EZH2 histone methyltransferase restored expression of the H3K27triM target genes alone or in synergy with histone deacetylase inhibition, without affecting promoter DNA methylation, and with no effect on the expression of genes silenced by DNA hypermethylation. These data establish EZH2-mediated H3K27triM as a mechanism of tumor-suppressor gene silencing in cancer that is potentially independent of promoter DNA methylation.

Standard name | KONDO_PROSTATE_CANCER_WITH_H3K27ME3
Systematic name | M7281
Organism | Homo sapiens
PMID | 18488029
Authors | Kondo Y,Shen L,Cheng AS,Ahmed S,Boumber Y,Charo C,Yamochi T,Urano T,Furukawa K,Kwabi-Addo B,Gold DL,Sekido Y,Huang TH,Issa JP
Category | C2
Sub-category | CGP
Brief description | Top 200 genes with high histone H3 trimethylation mark at K27 (H3K27me3) in PC3 cells (prostate cancer), by ChIP-chip assay on an 88K microarray (all promoters).
Full description | Epigenetic silencing in cancer cells is mediated by at least two distinct histone modifications, polycomb-based histone H3 lysine 27 trimethylation (H3K27triM) and H3K9 dimethylation. The relationship between DNA hypermethylation and these histone modifications is not completely understood. Using chromatin immunoprecipitation microarrays (ChIP-chip) in prostate cancer cells compared to normal prostate, we found that up to 5% of promoters (16% CpG islands and 84% non-CpG islands) were enriched with H3K27triM. These genes were silenced specifically in prostate cancer, and those CpG islands affected showed low levels of DNA methylation. Downregulation of the EZH2 histone methyltransferase restored expression of the H3K27triM target genes alone or in synergy with histone deacetylase inhibition, without affecting promoter DNA methylation, and with no effect on the expression of genes silenced by DNA hypermethylation. These data establish EZH2-mediated H3K27triM as a mechanism of tumor-suppressor gene silencing in cancer that is potentially independent of promoter DNA methylation.

Standard name | KONDO_COLON_CANCER_HCP_WITH_H3K27ME1
Systematic name | M13354
Organism | Homo sapiens
PMID | 18488029
Authors | Kondo Y,Shen L,Cheng AS,Ahmed S,Boumber Y,Charo C,Yamochi T,Urano T,Furukawa K,Kwabi-Addo B,Gold DL,Sekido Y,Huang TH,Issa JP
Category | C2
Sub-category | CGP
Brief description | Genes with high levels of histone H3 monomethylation mark at K27 (H3K27me1) in SW48 cells (colon cancer) by ChIP-chip assay on a 12K CpG array (CpG promoters only, HCP=high-CpG-density promoters).
Full description | Epigenetic silencing in cancer cells is mediated by at least two distinct histone modifications, polycomb-based histone H3 lysine 27 trimethylation (H3K27triM) and H3K9 dimethylation. The relationship between DNA hypermethylation and these histone modifications is not completely understood. Using chromatin immunoprecipitation microarrays (ChIP-chip) in prostate cancer cells compared to normal prostate, we found that up to 5% of promoters (16% CpG islands and 84% non-CpG islands) were enriched with H3K27triM. These genes were silenced specifically in prostate cancer, and those CpG islands affected showed low levels of DNA methylation. Downregulation of the EZH2 histone methyltransferase restored expression of the H3K27triM target genes alone or in synergy with histone deacetylase inhibition, without affecting promoter DNA methylation, and with no effect on the expression of genes silenced by DNA hypermethylation. These data establish EZH2-mediated H3K27triM as a mechanism of tumor-suppressor gene silencing in cancer that is potentially independent of promoter DNA methylation.

Standard name | KONDO_COLON_CANCER_HCP_WITH_H3K27ME3
Systematic name | M697
Organism | Homo sapiens
PMID | 18488029
Authors | Kondo Y,Shen L,Cheng AS,Ahmed S,Boumber Y,Charo C,Yamochi T,Urano T,Furukawa K,Kwabi-Addo B,Gold DL,Sekido Y,Huang TH,Issa JP
Category | C2
Sub-category | CGP
Brief description | Genes with high histone H3 tri-methylation mark at K27 (H3K27me3) in SW48 cells (colon cancer), by ChIP-chip assay on a 12K CpG array (high-CpG-density promoters, HCP).
Full description | Epigenetic silencing in cancer cells is mediated by at least two distinct histone modifications, polycomb-based histone H3 lysine 27 trimethylation (H3K27triM) and H3K9 dimethylation. The relationship between DNA hypermethylation and these histone modifications is not completely understood. Using chromatin immunoprecipitation microarrays (ChIP-chip) in prostate cancer cells compared to normal prostate, we found that up to 5% of promoters (16% CpG islands and 84% non-CpG islands) were enriched with H3K27triM. These genes were silenced specifically in prostate cancer, and those CpG islands affected showed low levels of DNA methylation. Downregulation of the EZH2 histone methyltransferase restored expression of the H3K27triM target genes alone or in synergy with histone deacetylase inhibition, without affecting promoter DNA methylation, and with no effect on the expression of genes silenced by DNA hypermethylation. These data establish EZH2-mediated H3K27triM as a mechanism of tumor-suppressor gene silencing in cancer that is potentially independent of promoter DNA methylation.

Standard name | KONDO_EZH2_TARGETS
Systematic name | M5301
Organism | Homo sapiens
PMID | 18488029
Authors | Kondo Y,Shen L,Cheng AS,Ahmed S,Boumber Y,Charo C,Yamochi T,Urano T,Furukawa K,Kwabi-Addo B,Gold DL,Sekido Y,Huang TH,Issa JP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in PC3 cells (prostate cancer) after EZH2 [GeneID=2146] knockdown by RNAi.
Full description | Epigenetic silencing in cancer cells is mediated by at least two distinct histone modifications, polycomb-based histone H3 lysine 27 trimethylation (H3K27triM) and H3K9 dimethylation. The relationship between DNA hypermethylation and these histone modifications is not completely understood. Using chromatin immunoprecipitation microarrays (ChIP-chip) in prostate cancer cells compared to normal prostate, we found that up to 5% of promoters (16% CpG islands and 84% non-CpG islands) were enriched with H3K27triM. These genes were silenced specifically in prostate cancer, and those CpG islands affected showed low levels of DNA methylation. Downregulation of the EZH2 histone methyltransferase restored expression of the H3K27triM target genes alone or in synergy with histone deacetylase inhibition, without affecting promoter DNA methylation, and with no effect on the expression of genes silenced by DNA hypermethylation. These data establish EZH2-mediated H3K27triM as a mechanism of tumor-suppressor gene silencing in cancer that is potentially independent of promoter DNA methylation.

Standard name | ZHANG_GATA6_TARGETS_UP
Systematic name | M1777
Organism | Mus musculus
PMID | 18536717
Authors | Zhang Y,Goss AM,Cohen ED,Kadzik R,Lepore JJ,Muthukumaraswamy K,Yang J,DeMayo FJ,Whitsett JA,Parmacek MS,Morrisey EE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated after cre-lox knockout of GATA6 [GeneID=2627] in airway epithelium.
Full description | Epithelial organs, including the lung, are known to possess regenerative abilities through activation of endogenous stem cell populations, but the molecular pathways regulating stem cell expansion and regeneration are not well understood. Here we show that Gata6 regulates the temporal appearance and number of bronchioalveolar stem cells (BASCs) in the lung, its absence in Gata6-null lung epithelium leading to the precocious appearance of BASCs and concurrent loss in epithelial differentiation. This expansion of BASCs was the result of a pronounced increase in canonical Wnt signaling in lung epithelium upon loss of Gata6. Expression of the noncanonical Wnt receptor Fzd2 was downregulated in Gata6 mutants and increased Fzd2 or decreased beta-catenin expression rescued, in part, the lung epithelial defects in Gata6 mutants. During lung epithelial regeneration, canonical Wnt signaling was activated in the niche containing BASCs and forced activation of Wnt signaling led to a large increase in BASC numbers. Moreover, Gata6 was required for proper lung epithelial regeneration, and postnatal loss of Gata6 led to increased BASC expansion and decreased differentiation. Together, these data demonstrate that Gata6-regulated Wnt signaling controls the balance between progenitor expansion and epithelial differentiation required for both lung development and regeneration.

Standard name | ZHANG_GATA6_TARGETS_DN
Systematic name | M1778
Organism | Mus musculus
PMID | 18536717
Authors | Zhang Y,Goss AM,Cohen ED,Kadzik R,Lepore JJ,Muthukumaraswamy K,Yang J,DeMayo FJ,Whitsett JA,Parmacek MS,Morrisey EE
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated after cre-lox knockout of GATA6 [GeneID=2627] in airway epithelium.
Full description | Epithelial organs, including the lung, are known to possess regenerative abilities through activation of endogenous stem cell populations, but the molecular pathways regulating stem cell expansion and regeneration are not well understood. Here we show that Gata6 regulates the temporal appearance and number of bronchioalveolar stem cells (BASCs) in the lung, its absence in Gata6-null lung epithelium leading to the precocious appearance of BASCs and concurrent loss in epithelial differentiation. This expansion of BASCs was the result of a pronounced increase in canonical Wnt signaling in lung epithelium upon loss of Gata6. Expression of the noncanonical Wnt receptor Fzd2 was downregulated in Gata6 mutants and increased Fzd2 or decreased beta-catenin expression rescued, in part, the lung epithelial defects in Gata6 mutants. During lung epithelial regeneration, canonical Wnt signaling was activated in the niche containing BASCs and forced activation of Wnt signaling led to a large increase in BASC numbers. Moreover, Gata6 was required for proper lung epithelial regeneration, and postnatal loss of Gata6 led to increased BASC expansion and decreased differentiation. Together, these data demonstrate that Gata6-regulated Wnt signaling controls the balance between progenitor expansion and epithelial differentiation required for both lung development and regeneration.

Standard name | MCGOWAN_RSP6_TARGETS_UP
Systematic name | M1780
Organism | Mus musculus
PMID | 18641651
Authors | McGowan KA,Li JZ,Park CY,Beaudry V,Tabor HK,Sabnis AJ,Zhang W,Fuchs H,de Angelis MH,Myers RM,Attardi LD,Barsh GS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by hemizygotic cre-lox knockout of RSP6 [GeneID=81492] in keratinocytes.
Full description | Mutations in genes encoding ribosomal proteins cause the Minute phenotype in Drosophila and mice, and Diamond-Blackfan syndrome in humans. Here we report two mouse dark skin (Dsk) loci caused by mutations in Rps19 (ribosomal protein S19) and Rps20 (ribosomal protein S20). We identify a common pathophysiologic program in which p53 stabilization stimulates Kit ligand expression, and, consequently, epidermal melanocytosis via a paracrine mechanism. Accumulation of p53 also causes reduced body size and erythrocyte count. These results provide a mechanistic explanation for the diverse collection of phenotypes that accompany reduced dosage of genes encoding ribosomal proteins, and have implications for understanding normal human variation and human disease.

Standard name | KANG_CISPLATIN_RESISTANCE_UP
Systematic name | M2767
Organism | Homo sapiens
PMID | 14734480
Authors | Kang HC,Kim IJ,Park JH,Shin Y,Ku JL,Jung MS,Yoo BC,Kim HK,Park JG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in gastric cancer cell lines resistant to cisplatin [PubChem=2767].
Full description | PURPOSE: A major obstacle in chemotherapy is treatment failure due to anticancer drug resistance. The emergence of acquired resistance results from host factors and genetic or epigenetic changes in the cancer cells. The purpose of this study was to identify differentially expressed genes associated with acquisition of resistance in human gastric cancer cells. EXPERIMENTAL DESIGN: We performed global gene expression analysis in the acquired drug-resistant gastric cancer cell lines to the commonly used drugs 5-fluorouracil, doxorubicin, and cisplatin using Affymetrix HG-U133A microarray. The gene expression patterns of 10 chemoresistant gastric cancer cell lines were compared with those of four parent cell lines using fold-change and Wilcoxon's test for data analysis. RESULTS: We identified over 250 genes differentially expressed in 5-fluorouracil-, cisplatin-, or doxorubicin-resistant gastric cancer cell lines. Our expression analysis also identified eight multidrug resistance candidate genes that were associated with resistance to two or more of the tested chemotherapeutic agents. Among these, midkine (MDK), a heparin-binding growth factor, was overexpressed in all drug-resistant cell lines, strongly suggesting that MDK might contribute to multidrug resistance in gastric cancer cells. CONCLUSIONS: Our investigation provides comprehensive gene information associated with acquired resistance to anticancer drugs in gastric cancer cells and a basis for additional functional studies.

Standard name | KANG_CISPLATIN_RESISTANCE_DN
Systematic name | M8236
Organism | Homo sapiens
PMID | 14734480
Authors | Kang HC,Kim IJ,Park JH,Shin Y,Ku JL,Jung MS,Yoo BC,Kim HK,Park JG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in gastric cancer cell lines resistant to cisplatin [PubChem=2767].
Full description | PURPOSE: A major obstacle in chemotherapy is treatment failure due to anticancer drug resistance. The emergence of acquired resistance results from host factors and genetic or epigenetic changes in the cancer cells. The purpose of this study was to identify differentially expressed genes associated with acquisition of resistance in human gastric cancer cells. EXPERIMENTAL DESIGN: We performed global gene expression analysis in the acquired drug-resistant gastric cancer cell lines to the commonly used drugs 5-fluorouracil, doxorubicin, and cisplatin using Affymetrix HG-U133A microarray. The gene expression patterns of 10 chemoresistant gastric cancer cell lines were compared with those of four parent cell lines using fold-change and Wilcoxon's test for data analysis. RESULTS: We identified over 250 genes differentially expressed in 5-fluorouracil-, cisplatin-, or doxorubicin-resistant gastric cancer cell lines. Our expression analysis also identified eight multidrug resistance candidate genes that were associated with resistance to two or more of the tested chemotherapeutic agents. Among these, midkine (MDK), a heparin-binding growth factor, was overexpressed in all drug-resistant cell lines, strongly suggesting that MDK might contribute to multidrug resistance in gastric cancer cells. CONCLUSIONS: Our investigation provides comprehensive gene information associated with acquired resistance to anticancer drugs in gastric cancer cells and a basis for additional functional studies.

Standard name | STEARMAN_TUMOR_FIELD_EFFECT_UP
Systematic name | M13438
Organism | Mus musculus
PMID | 18172294
Authors | Stearman RS,Dwyer-Nield L,Grady MC,Malkinson AM,Geraci MW
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the 'Field Effect' signature of normal lung tissue adjacent to the tumor.
Full description | One area of intensive investigation is to understand complex cellular and signaling interactions in the tumor microenvironment. Using a novel, although straightforward, microarray approach, we defined a gene expression signature from the lung tumor microenvironment in the murine A/J-urethane model of human lung adenocarcinoma. The tumor microenvironment is reflected by the composition of the cell types present and alterations in mRNA levels, resulting in a Field Effect around the tumor. The genes composing the Field Effect expression signature include proteases and their inhibitors, inflammation markers, and immune signaling molecules. By several criteria, the Field Effect expression signature can be attributed to the macrophage lineage, suggesting a qualitative change in the expression pattern of tumor-associated macrophages (TAM) observed in lung tumors. The protein expression levels for a number of Field Effect genes were verified by Western blot analysis of lung homogenates, and for their expression in macrophages and parenchymal cells outside of the tumors by immunohistochemistry. In addition, the Field Effect expression signature was used to classify bronchoalveolar lavage (BAL) cells from tumor-bearing or age-matched control mice. Using a variety of statistical measures, the Field Effect expression signature correctly classified the BAL cells >94% of the time. Finally, the protein levels for several Field Effect genes were higher in cell-free BAL fluid, indicating they may be secreted by the TAMs. This work suggests that TAMs generate a unique gene expression signature within the tumor microenvironment, and this signature could potentially be used for identifying lung cancer from BAL cells and/or fluid.

Standard name | STEARMAN_LUNG_CANCER_EARLY_VS_LATE_UP
Systematic name | M4925
Organism | Mus musculus
PMID | 18172294
Authors | Stearman RS,Dwyer-Nield L,Grady MC,Malkinson AM,Geraci MW
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes classifying non-tumor lung tissues by age after incution of lung cancer by urethane injection [PubChem=5641]: early (24-26 weeks) vs late (46 weeks).
Full description | One area of intensive investigation is to understand complex cellular and signaling interactions in the tumor microenvironment. Using a novel, although straightforward, microarray approach, we defined a gene expression signature from the lung tumor microenvironment in the murine A/J-urethane model of human lung adenocarcinoma. The tumor microenvironment is reflected by the composition of the cell types present and alterations in mRNA levels, resulting in a Field Effect around the tumor. The genes composing the Field Effect expression signature include proteases and their inhibitors, inflammation markers, and immune signaling molecules. By several criteria, the Field Effect expression signature can be attributed to the macrophage lineage, suggesting a qualitative change in the expression pattern of tumor-associated macrophages (TAM) observed in lung tumors. The protein expression levels for a number of Field Effect genes were verified by Western blot analysis of lung homogenates, and for their expression in macrophages and parenchymal cells outside of the tumors by immunohistochemistry. In addition, the Field Effect expression signature was used to classify bronchoalveolar lavage (BAL) cells from tumor-bearing or age-matched control mice. Using a variety of statistical measures, the Field Effect expression signature correctly classified the BAL cells >94% of the time. Finally, the protein levels for several Field Effect genes were higher in cell-free BAL fluid, indicating they may be secreted by the TAMs. This work suggests that TAMs generate a unique gene expression signature within the tumor microenvironment, and this signature could potentially be used for identifying lung cancer from BAL cells and/or fluid.

Standard name | STEARMAN_LUNG_CANCER_EARLY_VS_LATE_DN
Systematic name | M10880
Organism | Mus musculus
PMID | 18172294
Authors | Stearman RS,Dwyer-Nield L,Grady MC,Malkinson AM,Geraci MW
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes classifying non-tumor lung tissues by age after incution of lung cancer by urethane injection [PubChem=5641]: early (24-26 weeks) vs late (46 weeks).
Full description | One area of intensive investigation is to understand complex cellular and signaling interactions in the tumor microenvironment. Using a novel, although straightforward, microarray approach, we defined a gene expression signature from the lung tumor microenvironment in the murine A/J-urethane model of human lung adenocarcinoma. The tumor microenvironment is reflected by the composition of the cell types present and alterations in mRNA levels, resulting in a Field Effect around the tumor. The genes composing the Field Effect expression signature include proteases and their inhibitors, inflammation markers, and immune signaling molecules. By several criteria, the Field Effect expression signature can be attributed to the macrophage lineage, suggesting a qualitative change in the expression pattern of tumor-associated macrophages (TAM) observed in lung tumors. The protein expression levels for a number of Field Effect genes were verified by Western blot analysis of lung homogenates, and for their expression in macrophages and parenchymal cells outside of the tumors by immunohistochemistry. In addition, the Field Effect expression signature was used to classify bronchoalveolar lavage (BAL) cells from tumor-bearing or age-matched control mice. Using a variety of statistical measures, the Field Effect expression signature correctly classified the BAL cells >94% of the time. Finally, the protein levels for several Field Effect genes were higher in cell-free BAL fluid, indicating they may be secreted by the TAMs. This work suggests that TAMs generate a unique gene expression signature within the tumor microenvironment, and this signature could potentially be used for identifying lung cancer from BAL cells and/or fluid.

Standard name | HELLER_SILENCED_BY_METHYLATION_UP
Systematic name | M8776
Organism | Homo sapiens
PMID | 18172295
Authors | Heller G,Schmidt WM,Ziegler B,Holzer S,Müllauer L,Bilban M,Zielinski CC,Drach J,Zöchbauer-Müller S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in at least one of three multiple myeloma (MM) cell lines treated with the DNA hypomethylating agent decitabine (5-aza-2'-deoxycytidine) [PubChem=451668].
Full description | To identify epigenetically silenced cancer-related genes and to determine molecular effects of 5-aza-2'-deoxycytidine (Aza-dC) and/or trichostatin A (TSA) in multiple myeloma (MM), we analyzed global changes in gene expression profiles of three MM cell lines by microarray analysis. We identified up-regulation of several genes whose epigenetic silencing in MM is well known. However, much more importantly, we identified a large number of epigenetically inactivated cancer-related genes that are involved in various physiologic processes and whose epigenetic regulation in MM was unknown thus far. In addition, drug treatment of MM cell lines resulted in down-regulation of several MM proliferation-associated factors (i.e., MAF, CCND1/2, MYC, FGFR3, MMSET). Ten Aza-dC and/or TSA up-regulated genes (CPEB1, CD9, GJA1, BCL7c, GADD45G, AKAP12, TFPI2, CCNA1, SPARC, and BNIP3) were selected for methylation analysis in six MM cell lines, 24 samples from patients with monoclonal gammopathy of undetermined significance (MGUS), and 111 samples from patients with MM. Methylation frequencies of these genes ranged between 0% and 17% in MGUS samples and between 5% and 50% in MM samples. Interestingly, methylation of SPARC and BNIP3 was statistically significantly associated with a poor overall survival of MM patients (P = 0.003 and P = 0.017, respectively). Moreover, SPARC methylation was associated with loss of SPARC protein expression by immunostaining in a subset of MM patients. In conclusion, we identified new targets for aberrant methylation in monoclonal gammopathies, and our results suggest that DNA methyltransferase and histone deacetylase inhibition might play an important role in the future treatment of patients with MM.

Standard name | HELLER_SILENCED_BY_METHYLATION_DN
Systematic name | M3185
Organism | Homo sapiens
PMID | 18172295
Authors | Heller G,Schmidt WM,Ziegler B,Holzer S,Müllauer L,Bilban M,Zielinski CC,Drach J,Zöchbauer-Müller S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in at least one of three multiple myeloma (MM) cell lines treated with the DNA hypomethylating agent decitabine (5-aza-2'-deoxycytidine) [PubChem=451668].
Full description | To identify epigenetically silenced cancer-related genes and to determine molecular effects of 5-aza-2'-deoxycytidine (Aza-dC) and/or trichostatin A (TSA) in multiple myeloma (MM), we analyzed global changes in gene expression profiles of three MM cell lines by microarray analysis. We identified up-regulation of several genes whose epigenetic silencing in MM is well known. However, much more importantly, we identified a large number of epigenetically inactivated cancer-related genes that are involved in various physiologic processes and whose epigenetic regulation in MM was unknown thus far. In addition, drug treatment of MM cell lines resulted in down-regulation of several MM proliferation-associated factors (i.e., MAF, CCND1/2, MYC, FGFR3, MMSET). Ten Aza-dC and/or TSA up-regulated genes (CPEB1, CD9, GJA1, BCL7c, GADD45G, AKAP12, TFPI2, CCNA1, SPARC, and BNIP3) were selected for methylation analysis in six MM cell lines, 24 samples from patients with monoclonal gammopathy of undetermined significance (MGUS), and 111 samples from patients with MM. Methylation frequencies of these genes ranged between 0% and 17% in MGUS samples and between 5% and 50% in MM samples. Interestingly, methylation of SPARC and BNIP3 was statistically significantly associated with a poor overall survival of MM patients (P = 0.003 and P = 0.017, respectively). Moreover, SPARC methylation was associated with loss of SPARC protein expression by immunostaining in a subset of MM patients. In conclusion, we identified new targets for aberrant methylation in monoclonal gammopathies, and our results suggest that DNA methyltransferase and histone deacetylase inhibition might play an important role in the future treatment of patients with MM.

Standard name | HELLER_HDAC_TARGETS_UP
Systematic name | M3335
Organism | Homo sapiens
PMID | 18172295
Authors | Heller G,Schmidt WM,Ziegler B,Holzer S,Müllauer L,Bilban M,Zielinski CC,Drach J,Zöchbauer-Müller S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in at least one of three multiple myeloma (MM) cell lines by TSA [PubChem=5562].
Full description | To identify epigenetically silenced cancer-related genes and to determine molecular effects of 5-aza-2'-deoxycytidine (Aza-dC) and/or trichostatin A (TSA) in multiple myeloma (MM), we analyzed global changes in gene expression profiles of three MM cell lines by microarray analysis. We identified up-regulation of several genes whose epigenetic silencing in MM is well known. However, much more importantly, we identified a large number of epigenetically inactivated cancer-related genes that are involved in various physiologic processes and whose epigenetic regulation in MM was unknown thus far. In addition, drug treatment of MM cell lines resulted in down-regulation of several MM proliferation-associated factors (i.e., MAF, CCND1/2, MYC, FGFR3, MMSET). Ten Aza-dC and/or TSA up-regulated genes (CPEB1, CD9, GJA1, BCL7c, GADD45G, AKAP12, TFPI2, CCNA1, SPARC, and BNIP3) were selected for methylation analysis in six MM cell lines, 24 samples from patients with monoclonal gammopathy of undetermined significance (MGUS), and 111 samples from patients with MM. Methylation frequencies of these genes ranged between 0% and 17% in MGUS samples and between 5% and 50% in MM samples. Interestingly, methylation of SPARC and BNIP3 was statistically significantly associated with a poor overall survival of MM patients (P = 0.003 and P = 0.017, respectively). Moreover, SPARC methylation was associated with loss of SPARC protein expression by immunostaining in a subset of MM patients. In conclusion, we identified new targets for aberrant methylation in monoclonal gammopathies, and our results suggest that DNA methyltransferase and histone deacetylase inhibition might play an important role in the future treatment of patients with MM.

Standard name | HELLER_HDAC_TARGETS_DN
Systematic name | M6890
Organism | Homo sapiens
PMID | 18172295
Authors | Heller G,Schmidt WM,Ziegler B,Holzer S,Müllauer L,Bilban M,Zielinski CC,Drach J,Zöchbauer-Müller S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in at least one of three multiple myeloma (MM) cell lines by TSA [PubChem=5562].
Full description | To identify epigenetically silenced cancer-related genes and to determine molecular effects of 5-aza-2'-deoxycytidine (Aza-dC) and/or trichostatin A (TSA) in multiple myeloma (MM), we analyzed global changes in gene expression profiles of three MM cell lines by microarray analysis. We identified up-regulation of several genes whose epigenetic silencing in MM is well known. However, much more importantly, we identified a large number of epigenetically inactivated cancer-related genes that are involved in various physiologic processes and whose epigenetic regulation in MM was unknown thus far. In addition, drug treatment of MM cell lines resulted in down-regulation of several MM proliferation-associated factors (i.e., MAF, CCND1/2, MYC, FGFR3, MMSET). Ten Aza-dC and/or TSA up-regulated genes (CPEB1, CD9, GJA1, BCL7c, GADD45G, AKAP12, TFPI2, CCNA1, SPARC, and BNIP3) were selected for methylation analysis in six MM cell lines, 24 samples from patients with monoclonal gammopathy of undetermined significance (MGUS), and 111 samples from patients with MM. Methylation frequencies of these genes ranged between 0% and 17% in MGUS samples and between 5% and 50% in MM samples. Interestingly, methylation of SPARC and BNIP3 was statistically significantly associated with a poor overall survival of MM patients (P = 0.003 and P = 0.017, respectively). Moreover, SPARC methylation was associated with loss of SPARC protein expression by immunostaining in a subset of MM patients. In conclusion, we identified new targets for aberrant methylation in monoclonal gammopathies, and our results suggest that DNA methyltransferase and histone deacetylase inhibition might play an important role in the future treatment of patients with MM.

Standard name | HELLER_HDAC_TARGETS_SILENCED_BY_METHYLATION_UP
Systematic name | M14127
Organism | Homo sapiens
PMID | 18172295
Authors | Heller G,Schmidt WM,Ziegler B,Holzer S,Müllauer L,Bilban M,Zielinski CC,Drach J,Zöchbauer-Müller S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in multiple myeloma (MM) cell lines treated with both decitabine [PubChem=451668] TSA [PubChem=5562].
Full description | To identify epigenetically silenced cancer-related genes and to determine molecular effects of 5-aza-2'-deoxycytidine (Aza-dC) and/or trichostatin A (TSA) in multiple myeloma (MM), we analyzed global changes in gene expression profiles of three MM cell lines by microarray analysis. We identified up-regulation of several genes whose epigenetic silencing in MM is well known. However, much more importantly, we identified a large number of epigenetically inactivated cancer-related genes that are involved in various physiologic processes and whose epigenetic regulation in MM was unknown thus far. In addition, drug treatment of MM cell lines resulted in down-regulation of several MM proliferation-associated factors (i.e., MAF, CCND1/2, MYC, FGFR3, MMSET). Ten Aza-dC and/or TSA up-regulated genes (CPEB1, CD9, GJA1, BCL7c, GADD45G, AKAP12, TFPI2, CCNA1, SPARC, and BNIP3) were selected for methylation analysis in six MM cell lines, 24 samples from patients with monoclonal gammopathy of undetermined significance (MGUS), and 111 samples from patients with MM. Methylation frequencies of these genes ranged between 0% and 17% in MGUS samples and between 5% and 50% in MM samples. Interestingly, methylation of SPARC and BNIP3 was statistically significantly associated with a poor overall survival of MM patients (P = 0.003 and P = 0.017, respectively). Moreover, SPARC methylation was associated with loss of SPARC protein expression by immunostaining in a subset of MM patients. In conclusion, we identified new targets for aberrant methylation in monoclonal gammopathies, and our results suggest that DNA methyltransferase and histone deacetylase inhibition might play an important role in the future treatment of patients with MM.

Standard name | HELLER_HDAC_TARGETS_SILENCED_BY_METHYLATION_DN
Systematic name | M7623
Organism | Homo sapiens
PMID | 18172295
Authors | Heller G,Schmidt WM,Ziegler B,Holzer S,Müllauer L,Bilban M,Zielinski CC,Drach J,Zöchbauer-Müller S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in multiple myeloma (MM) cell lines treated with both decitabine [PubChem=451668] TSA [PubChem=5562].
Full description | To identify epigenetically silenced cancer-related genes and to determine molecular effects of 5-aza-2'-deoxycytidine (Aza-dC) and/or trichostatin A (TSA) in multiple myeloma (MM), we analyzed global changes in gene expression profiles of three MM cell lines by microarray analysis. We identified up-regulation of several genes whose epigenetic silencing in MM is well known. However, much more importantly, we identified a large number of epigenetically inactivated cancer-related genes that are involved in various physiologic processes and whose epigenetic regulation in MM was unknown thus far. In addition, drug treatment of MM cell lines resulted in down-regulation of several MM proliferation-associated factors (i.e., MAF, CCND1/2, MYC, FGFR3, MMSET). Ten Aza-dC and/or TSA up-regulated genes (CPEB1, CD9, GJA1, BCL7c, GADD45G, AKAP12, TFPI2, CCNA1, SPARC, and BNIP3) were selected for methylation analysis in six MM cell lines, 24 samples from patients with monoclonal gammopathy of undetermined significance (MGUS), and 111 samples from patients with MM. Methylation frequencies of these genes ranged between 0% and 17% in MGUS samples and between 5% and 50% in MM samples. Interestingly, methylation of SPARC and BNIP3 was statistically significantly associated with a poor overall survival of MM patients (P = 0.003 and P = 0.017, respectively). Moreover, SPARC methylation was associated with loss of SPARC protein expression by immunostaining in a subset of MM patients. In conclusion, we identified new targets for aberrant methylation in monoclonal gammopathies, and our results suggest that DNA methyltransferase and histone deacetylase inhibition might play an important role in the future treatment of patients with MM.

Standard name | CLAUS_PGR_POSITIVE_MENINGIOMA_UP
Systematic name | M10153
Organism | Homo sapiens
PMID | 18172325
Authors | Claus EB,Park PJ,Carroll R,Chan J,Black PM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in meningioma samples positive for PGR [GeneID=5241] compared to those without the receptor.
Full description | An association between hormones and meningioma has been postulated. No data exist that examine gene expression in meningioma by hormone receptor status. The data are surgical specimens from 31 meningioma patients undergoing neurosurgical resection at Brigham and Women's Hospital from March 15, 2004 to May 10, 2005. Progesterone and estrogen hormone receptors (PR and ER, respectively) were measured via immunohistochemistry and compared with gene expression profiling results. The sample is 77% female with a mean age of 55.7 years. Eighty percent were grade 1 and the mean MIB was 6.2, whereas 33% and 84% were ER+ and PR+, respectively. Gene expression seemed more strongly associated with PR status than with ER status. Genes on the long arm of chromosome 22 and near the neurofibromatosis type 2 (NF2) gene (22q12) were most frequently noted to have expression variation, with significant up-regulation in PR+ versus PR- lesions, suggesting a higher rate of 22q loss in PR- lesions. Pathway analyses indicated that genes in collagen and extracellular matrix pathways were most likely to be differentially expressed by PR status. These data, although preliminary, are the first to examine gene expression for meningioma cases by hormone receptor status and indicate a stronger association with PR than with ER status. PR status is related to the expression of genes near the NF2 gene, mutations in which have been identified as the initial event in many meningiomas. These findings suggest that PR status may be a clinical marker for genetic subgroups of meningioma and warrant further examination in a larger data set.

Standard name | CLAUS_PGR_POSITIVE_MENINGIOMA_DN
Systematic name | M14787
Organism | Homo sapiens
PMID | 18172325
Authors | Claus EB,Park PJ,Carroll R,Chan J,Black PM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in meningioma samples positive for PGR [GeneID=5241] compared to those without the receptor.
Full description | An association between hormones and meningioma has been postulated. No data exist that examine gene expression in meningioma by hormone receptor status. The data are surgical specimens from 31 meningioma patients undergoing neurosurgical resection at Brigham and Women's Hospital from March 15, 2004 to May 10, 2005. Progesterone and estrogen hormone receptors (PR and ER, respectively) were measured via immunohistochemistry and compared with gene expression profiling results. The sample is 77% female with a mean age of 55.7 years. Eighty percent were grade 1 and the mean MIB was 6.2, whereas 33% and 84% were ER+ and PR+, respectively. Gene expression seemed more strongly associated with PR status than with ER status. Genes on the long arm of chromosome 22 and near the neurofibromatosis type 2 (NF2) gene (22q12) were most frequently noted to have expression variation, with significant up-regulation in PR+ versus PR- lesions, suggesting a higher rate of 22q loss in PR- lesions. Pathway analyses indicated that genes in collagen and extracellular matrix pathways were most likely to be differentially expressed by PR status. These data, although preliminary, are the first to examine gene expression for meningioma cases by hormone receptor status and indicate a stronger association with PR than with ER status. PR status is related to the expression of genes near the NF2 gene, mutations in which have been identified as the initial event in many meningiomas. These findings suggest that PR status may be a clinical marker for genetic subgroups of meningioma and warrant further examination in a larger data set.

Standard name | WONG_MITOCHONDRIA_GENE_MODULE
Systematic name | M15112
Organism | Homo sapiens
PMID | 18199530
Authors | Wong DJ,Nuyten DS,Regev A,Lin M,Adler AS,Segal E,van de Vijver MJ,Chang HY
Category | C2
Sub-category | CGP
Brief description | Genes that comprise the mitochondria gene module
Full description | A major goal of cancer research is to match specific therapies to molecular targets in cancer. Genome-scale expression profiling has identified new subtypes of cancer based on consistent patterns of variation in gene expression, leading to improved prognostic predictions. However, how these new genetic subtypes of cancers should be treated is unknown. Here, we show that a gene module map can guide the prospective identification of targeted therapies for genetic subtypes of cancer. By visualizing genome-scale gene expression in cancer as combinations of activated and deactivated functional modules, gene module maps can reveal specific functional pathways associated with each subtype that might be susceptible to targeted therapies. We show that in human breast cancers, activation of a poor-prognosis wound signature is strongly associated with induction of both a mitochondria gene module and a proteasome gene module. We found that 3-bromopyruvic acid, which inhibits glycolysis, selectively killed breast cells expressing the mitochondria and wound signatures. In addition, inhibition of proteasome activity by bortezomib, a drug approved for human use in multiple myeloma, abrogated wound signature expression and selectively killed breast cells expressing the wound signature. Thus, gene module maps may enable rapid translation of complex genomic signatures in human disease to targeted therapeutic strategies.

Standard name | WONG_PROTEASOME_GENE_MODULE
Systematic name | M11458
Organism | Homo sapiens
PMID | 18199530
Authors | Wong DJ,Nuyten DS,Regev A,Lin M,Adler AS,Segal E,van de Vijver MJ,Chang HY
Category | C2
Sub-category | CGP
Brief description | Genes that comprise the proteasome gene module
Full description | A major goal of cancer research is to match specific therapies to molecular targets in cancer. Genome-scale expression profiling has identified new subtypes of cancer based on consistent patterns of variation in gene expression, leading to improved prognostic predictions. However, how these new genetic subtypes of cancers should be treated is unknown. Here, we show that a gene module map can guide the prospective identification of targeted therapies for genetic subtypes of cancer. By visualizing genome-scale gene expression in cancer as combinations of activated and deactivated functional modules, gene module maps can reveal specific functional pathways associated with each subtype that might be susceptible to targeted therapies. We show that in human breast cancers, activation of a poor-prognosis wound signature is strongly associated with induction of both a mitochondria gene module and a proteasome gene module. We found that 3-bromopyruvic acid, which inhibits glycolysis, selectively killed breast cells expressing the mitochondria and wound signatures. In addition, inhibition of proteasome activity by bortezomib, a drug approved for human use in multiple myeloma, abrogated wound signature expression and selectively killed breast cells expressing the wound signature. Thus, gene module maps may enable rapid translation of complex genomic signatures in human disease to targeted therapeutic strategies.

Standard name | COATES_MACROPHAGE_M1_VS_M2_UP
Systematic name | M13671
Organism | Mus musculus
PMID | 18199539
Authors | Coates PJ,Rundle JK,Lorimore SA,Wright EG
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes distinguishing between M1 (pro-inflammatory) and M2 (anti-inflammatory) macrophage subtypes.
Full description | In addition to the directly mutagenic effects of energy deposition in DNA, ionizing radiation is associated with a variety of untargeted and delayed effects that result in ongoing bone marrow damage. Delayed effects are genotype dependent with CBA/Ca mice, but not C57BL/6 mice, susceptible to the induction of damage and also radiation-induced acute myeloid leukemia. Because macrophages are a potential source of ongoing damaging signals, we have determined their gene expression profiles and we show that bone marrow-derived macrophages show widely different intrinsic expression patterns. The profiles classify macrophages derived from CBA/Ca mice as M1-like (pro-inflammatory) and those from C57BL/6 mice as M2-like (anti-inflammatory); measurements of NOS2 and arginase activity in normal bone marrow macrophages confirm these findings. After irradiation in vivo, but not in vitro, C57BL/6 macrophages show a reduction in NOS2 and an increase in arginase activities, indicating a further M2 response, whereas CBA/Ca macrophages retain an M1 phenotype. Activation of specific signal transducer and activator of transcription signaling pathways in irradiated hemopoietic tissues supports these observations. The data indicate that macrophage activation is not a direct effect of radiation but a tissue response, secondary to the initial radiation exposure, and have important implications for understanding genotype-dependent responses and the mechanisms of the hemotoxic and leukemogenic consequences of radiation exposure.

Standard name | COATES_MACROPHAGE_M1_VS_M2_DN
Systematic name | M14515
Organism | Mus musculus
PMID | 18199539
Authors | Coates PJ,Rundle JK,Lorimore SA,Wright EG
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes distinguishing between M1 (pro-inflammatory) and M2 (anti-inflammatory) macrophage subtypes.
Full description | In addition to the directly mutagenic effects of energy deposition in DNA, ionizing radiation is associated with a variety of untargeted and delayed effects that result in ongoing bone marrow damage. Delayed effects are genotype dependent with CBA/Ca mice, but not C57BL/6 mice, susceptible to the induction of damage and also radiation-induced acute myeloid leukemia. Because macrophages are a potential source of ongoing damaging signals, we have determined their gene expression profiles and we show that bone marrow-derived macrophages show widely different intrinsic expression patterns. The profiles classify macrophages derived from CBA/Ca mice as M1-like (pro-inflammatory) and those from C57BL/6 mice as M2-like (anti-inflammatory); measurements of NOS2 and arginase activity in normal bone marrow macrophages confirm these findings. After irradiation in vivo, but not in vitro, C57BL/6 macrophages show a reduction in NOS2 and an increase in arginase activities, indicating a further M2 response, whereas CBA/Ca macrophages retain an M1 phenotype. Activation of specific signal transducer and activator of transcription signaling pathways in irradiated hemopoietic tissues supports these observations. The data indicate that macrophage activation is not a direct effect of radiation but a tissue response, secondary to the initial radiation exposure, and have important implications for understanding genotype-dependent responses and the mechanisms of the hemotoxic and leukemogenic consequences of radiation exposure.

Standard name | LEE_METASTASIS_AND_RNA_PROCESSING_UP
Systematic name | M8887
Organism | Homo sapiens
PMID | 18245461
Authors | Lee JH,Horak CE,Khanna C,Meng Z,Yu LR,Veenstra TD,Steeg PS
Category | C2
Sub-category | CGP
Brief description | Components of RNA post-transcriptional modification machinery up-regulated in MDA-MB-435 cells (breast cancer) whose metastatic potential has been reduced by expression of NME1 [GeneID=4830].
Full description | The role of Gemin5 in alternative mRNA splicing, tumor cell motility, and proteomic instability was investigated. Isotope Capture Affinity Tag proteomic analysis was conducted on MDA-MB-435 tumor cells transfected with either a control vector (C-100) or the Nm23-H1 metastasis suppressor (H1-177). Ingenuity pathway analysis revealed that RNA posttranscriptional processing was the most prominent class of differentially expressed proteins. Within this category, overexpression of Acinus1, Poly(a) binding protein, HNRPA2B1, Bop1, and Gemin5 was confirmed in less metastatic H1-177 cells. Overexpression of the latter four proteins was also observed in the lower metastatic antisense Ezrin transfectant of a murine osteosarcoma model system, confirming the general relevance of the trends. Gemin5, a component of the spliceosomal complex, was chosen for further study. Analysis of global mRNA splicing by SpliceArray chips revealed that 16 genes were differentially spliced in C-100 compared with H1-177 cells; transient transfection of gemin5 into C-100 cells restored the splice pattern to that of H1-177 cells. Alternative splicing patterns for the engulfment and cell motility 1 and thrombospondin 4 genes were confirmed by semiquantitative reverse transcription-PCR. Gemin5 overexpression coordinately reduced C-100 cell motility by 50%, and siRNA-mediated reduction of Gemin5 expression increased the motility of H1-177 cells by 2-fold (P < 0.004). The data provide the first demonstration that alterations in the expression of a spliceosome protein can effect both specific splicing events and tumor cell motility. The data also show that changes in mRNA splicing patterns accompany metastatic progression, which may contribute to proteome instability.

Standard name | LEE_METASTASIS_AND_ALTERNATIVE_SPLICING_UP
Systematic name | M515
Organism | Homo sapiens
PMID | 18245461
Authors | Lee JH,Horak CE,Khanna C,Meng Z,Yu LR,Veenstra TD,Steeg PS
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes displaying alternative splicing in MDA-MB-435 cells (breast cancer) whose metastatic potential has been reduced by expression of NME1 [GeneID=4830].
Full description | The role of Gemin5 in alternative mRNA splicing, tumor cell motility, and proteomic instability was investigated. Isotope Capture Affinity Tag proteomic analysis was conducted on MDA-MB-435 tumor cells transfected with either a control vector (C-100) or the Nm23-H1 metastasis suppressor (H1-177). Ingenuity pathway analysis revealed that RNA posttranscriptional processing was the most prominent class of differentially expressed proteins. Within this category, overexpression of Acinus1, Poly(a) binding protein, HNRPA2B1, Bop1, and Gemin5 was confirmed in less metastatic H1-177 cells. Overexpression of the latter four proteins was also observed in the lower metastatic antisense Ezrin transfectant of a murine osteosarcoma model system, confirming the general relevance of the trends. Gemin5, a component of the spliceosomal complex, was chosen for further study. Analysis of global mRNA splicing by SpliceArray chips revealed that 16 genes were differentially spliced in C-100 compared with H1-177 cells; transient transfection of gemin5 into C-100 cells restored the splice pattern to that of H1-177 cells. Alternative splicing patterns for the engulfment and cell motility 1 and thrombospondin 4 genes were confirmed by semiquantitative reverse transcription-PCR. Gemin5 overexpression coordinately reduced C-100 cell motility by 50%, and siRNA-mediated reduction of Gemin5 expression increased the motility of H1-177 cells by 2-fold (P < 0.004). The data provide the first demonstration that alterations in the expression of a spliceosome protein can effect both specific splicing events and tumor cell motility. The data also show that changes in mRNA splicing patterns accompany metastatic progression, which may contribute to proteome instability.

Standard name | LEE_METASTASIS_AND_ALTERNATIVE_SPLICING_DN
Systematic name | M13714
Organism | Homo sapiens
PMID | 18245461
Authors | Lee JH,Horak CE,Khanna C,Meng Z,Yu LR,Veenstra TD,Steeg PS
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes displaying alternative splicing in MDA-MB-435 cells (breast cancer) whose metastatic potential has been reduced by expression of NME1 [GeneID=4830].
Full description | The role of Gemin5 in alternative mRNA splicing, tumor cell motility, and proteomic instability was investigated. Isotope Capture Affinity Tag proteomic analysis was conducted on MDA-MB-435 tumor cells transfected with either a control vector (C-100) or the Nm23-H1 metastasis suppressor (H1-177). Ingenuity pathway analysis revealed that RNA posttranscriptional processing was the most prominent class of differentially expressed proteins. Within this category, overexpression of Acinus1, Poly(a) binding protein, HNRPA2B1, Bop1, and Gemin5 was confirmed in less metastatic H1-177 cells. Overexpression of the latter four proteins was also observed in the lower metastatic antisense Ezrin transfectant of a murine osteosarcoma model system, confirming the general relevance of the trends. Gemin5, a component of the spliceosomal complex, was chosen for further study. Analysis of global mRNA splicing by SpliceArray chips revealed that 16 genes were differentially spliced in C-100 compared with H1-177 cells; transient transfection of gemin5 into C-100 cells restored the splice pattern to that of H1-177 cells. Alternative splicing patterns for the engulfment and cell motility 1 and thrombospondin 4 genes were confirmed by semiquantitative reverse transcription-PCR. Gemin5 overexpression coordinately reduced C-100 cell motility by 50%, and siRNA-mediated reduction of Gemin5 expression increased the motility of H1-177 cells by 2-fold (P < 0.004). The data provide the first demonstration that alterations in the expression of a spliceosome protein can effect both specific splicing events and tumor cell motility. The data also show that changes in mRNA splicing patterns accompany metastatic progression, which may contribute to proteome instability.

Standard name | LIN_MELANOMA_COPY_NUMBER_UP
Systematic name | M346
Organism | Homo sapiens
PMID | 18245465
Authors | Lin WM,Baker AC,Beroukhim R,Winckler W,Feng W,Marmion JM,Laine E,Greulich H,Tseng H,Gates C,Hodi FS,Dranoff G,Sellers WR,Thomas RK,Meyerson M,Golub TR,Dummer R,Herlyn M,Getz G,Garraway LA
Category | C2
Sub-category | CGP
Brief description | Candidate genes in significant regions of chromosomal copy number gains in a panel of melanoma samples.
Full description | The classification of human tumors based on molecular criteria offers tremendous clinical potential; however, discerning critical and druggable effectors on a large scale will also require robust experimental models reflective of tumor genomic diversity. Here, we describe a comprehensive genomic analysis of 101 melanoma short-term cultures and cell lines. Using an analytic approach designed to enrich for putative driver events, we show that cultured melanoma cells encompass the spectrum of significant genomic alterations present in primary tumors. When annotated according to these lesions, melanomas cluster into subgroups suggestive of distinct oncogenic mechanisms. Integrating gene expression data suggests novel candidate effector genes linked to recurrent copy gains and losses, including both phosphatase and tensin homologue (PTEN)-dependent and PTEN-independent tumor suppressor mechanisms associated with chromosome 10 deletions. Finally, sample-matched pharmacologic data show that FGFR1 mutations and extracellular signal-regulated kinase (ERK) activation may modulate sensitivity to mitogen-activated protein kinase/ERK kinase inhibitors. Genetically defined cell culture collections therefore offer a rich framework for systematic functional studies in melanoma and other tumors.

Standard name | LIN_MELANOMA_COPY_NUMBER_DN
Systematic name | M3694
Organism | Homo sapiens
PMID | 18245465
Authors | Lin WM,Baker AC,Beroukhim R,Winckler W,Feng W,Marmion JM,Laine E,Greulich H,Tseng H,Gates C,Hodi FS,Dranoff G,Sellers WR,Thomas RK,Meyerson M,Golub TR,Dummer R,Herlyn M,Getz G,Garraway LA
Category | C2
Sub-category | CGP
Brief description | Candidate genes in significant regions of chromosomal copy number losses in a panel of melanoma samples.
Full description | The classification of human tumors based on molecular criteria offers tremendous clinical potential; however, discerning critical and druggable effectors on a large scale will also require robust experimental models reflective of tumor genomic diversity. Here, we describe a comprehensive genomic analysis of 101 melanoma short-term cultures and cell lines. Using an analytic approach designed to enrich for putative driver events, we show that cultured melanoma cells encompass the spectrum of significant genomic alterations present in primary tumors. When annotated according to these lesions, melanomas cluster into subgroups suggestive of distinct oncogenic mechanisms. Integrating gene expression data suggests novel candidate effector genes linked to recurrent copy gains and losses, including both phosphatase and tensin homologue (PTEN)-dependent and PTEN-independent tumor suppressor mechanisms associated with chromosome 10 deletions. Finally, sample-matched pharmacologic data show that FGFR1 mutations and extracellular signal-regulated kinase (ERK) activation may modulate sensitivity to mitogen-activated protein kinase/ERK kinase inhibitors. Genetically defined cell culture collections therefore offer a rich framework for systematic functional studies in melanoma and other tumors.

Standard name | MARTINEZ_RB1_TARGETS_UP
Systematic name | M12224
Organism | Mus musculus
PMID | 18245467
Authors | Martínez-Cruz AB,Santos M,Lara MF,Segrelles C,Ruiz S,Moral M,Lorz C,García-Escudero R,Paramio JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mice with skin specific knockout of RB1 [GeneID=5925] by Cre-lox.
Full description | Squamous cell carcinomas (SCC) represent the most aggressive type of nonmelanoma skin cancer. Although little is known about the causal alterations of SCCs, in organ-transplanted patients the E7 and E6 oncogenes of human papillomavirus, targeting the p53- and pRb-dependent pathways, have been widely involved. Here, we report the functional consequences of the simultaneous elimination of Trp53 and retinoblastoma (Rb) genes in epidermis using Cre-loxP system. Loss of p53, but not pRb, produces spontaneous tumor development, indicating that p53 is the predominant tumor suppressor acting in mouse epidermis. Although the simultaneous inactivation of pRb and p53 does not aggravate the phenotype observed in Rb-deficient epidermis in terms of proliferation and/or differentiation, spontaneous SCC development is severely accelerated in doubly deficient mice. The tumors are aggressive and undifferentiated and display a hair follicle origin. Detailed analysis indicates that the acceleration is mediated by premature activation of the epidermal growth factor receptor/Akt pathway, resulting in increased proliferation in normal and dysplastic hair follicles and augmented tumor angiogenesis. The molecular characteristics of this model provide valuable tools to understand epidermal tumor formation and may ultimately contribute to the development of therapies for the treatment of aggressive squamous cancer.

Standard name | MARTINEZ_RB1_TARGETS_DN
Systematic name | M12701
Organism | Mus musculus
PMID | 18245467
Authors | Martínez-Cruz AB,Santos M,Lara MF,Segrelles C,Ruiz S,Moral M,Lorz C,García-Escudero R,Paramio JM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mice with skin specific knockout of RB1 [GeneID=5925] by Cre-lox.
Full description | Squamous cell carcinomas (SCC) represent the most aggressive type of nonmelanoma skin cancer. Although little is known about the causal alterations of SCCs, in organ-transplanted patients the E7 and E6 oncogenes of human papillomavirus, targeting the p53- and pRb-dependent pathways, have been widely involved. Here, we report the functional consequences of the simultaneous elimination of Trp53 and retinoblastoma (Rb) genes in epidermis using Cre-loxP system. Loss of p53, but not pRb, produces spontaneous tumor development, indicating that p53 is the predominant tumor suppressor acting in mouse epidermis. Although the simultaneous inactivation of pRb and p53 does not aggravate the phenotype observed in Rb-deficient epidermis in terms of proliferation and/or differentiation, spontaneous SCC development is severely accelerated in doubly deficient mice. The tumors are aggressive and undifferentiated and display a hair follicle origin. Detailed analysis indicates that the acceleration is mediated by premature activation of the epidermal growth factor receptor/Akt pathway, resulting in increased proliferation in normal and dysplastic hair follicles and augmented tumor angiogenesis. The molecular characteristics of this model provide valuable tools to understand epidermal tumor formation and may ultimately contribute to the development of therapies for the treatment of aggressive squamous cancer.

Standard name | MARTINEZ_TP53_TARGETS_UP
Systematic name | M4371
Organism | Mus musculus
PMID | 18245467
Authors | Martínez-Cruz AB,Santos M,Lara MF,Segrelles C,Ruiz S,Moral M,Lorz C,García-Escudero R,Paramio JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mice with skin specific knockout of TP53 [GeneID=7157].
Full description | Squamous cell carcinomas (SCC) represent the most aggressive type of nonmelanoma skin cancer. Although little is known about the causal alterations of SCCs, in organ-transplanted patients the E7 and E6 oncogenes of human papillomavirus, targeting the p53- and pRb-dependent pathways, have been widely involved. Here, we report the functional consequences of the simultaneous elimination of Trp53 and retinoblastoma (Rb) genes in epidermis using Cre-loxP system. Loss of p53, but not pRb, produces spontaneous tumor development, indicating that p53 is the predominant tumor suppressor acting in mouse epidermis. Although the simultaneous inactivation of pRb and p53 does not aggravate the phenotype observed in Rb-deficient epidermis in terms of proliferation and/or differentiation, spontaneous SCC development is severely accelerated in doubly deficient mice. The tumors are aggressive and undifferentiated and display a hair follicle origin. Detailed analysis indicates that the acceleration is mediated by premature activation of the epidermal growth factor receptor/Akt pathway, resulting in increased proliferation in normal and dysplastic hair follicles and augmented tumor angiogenesis. The molecular characteristics of this model provide valuable tools to understand epidermal tumor formation and may ultimately contribute to the development of therapies for the treatment of aggressive squamous cancer.

Standard name | MARTINEZ_TP53_TARGETS_DN
Systematic name | M8673
Organism | Mus musculus
PMID | 18245467
Authors | Martínez-Cruz AB,Santos M,Lara MF,Segrelles C,Ruiz S,Moral M,Lorz C,García-Escudero R,Paramio JM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mice with skin specific knockout of TP53 [GeneID=7157].
Full description | Squamous cell carcinomas (SCC) represent the most aggressive type of nonmelanoma skin cancer. Although little is known about the causal alterations of SCCs, in organ-transplanted patients the E7 and E6 oncogenes of human papillomavirus, targeting the p53- and pRb-dependent pathways, have been widely involved. Here, we report the functional consequences of the simultaneous elimination of Trp53 and retinoblastoma (Rb) genes in epidermis using Cre-loxP system. Loss of p53, but not pRb, produces spontaneous tumor development, indicating that p53 is the predominant tumor suppressor acting in mouse epidermis. Although the simultaneous inactivation of pRb and p53 does not aggravate the phenotype observed in Rb-deficient epidermis in terms of proliferation and/or differentiation, spontaneous SCC development is severely accelerated in doubly deficient mice. The tumors are aggressive and undifferentiated and display a hair follicle origin. Detailed analysis indicates that the acceleration is mediated by premature activation of the epidermal growth factor receptor/Akt pathway, resulting in increased proliferation in normal and dysplastic hair follicles and augmented tumor angiogenesis. The molecular characteristics of this model provide valuable tools to understand epidermal tumor formation and may ultimately contribute to the development of therapies for the treatment of aggressive squamous cancer.

Standard name | MARTINEZ_RB1_AND_TP53_TARGETS_UP
Systematic name | M15896
Organism | Mus musculus
PMID | 18245467
Authors | Martínez-Cruz AB,Santos M,Lara MF,Segrelles C,Ruiz S,Moral M,Lorz C,García-Escudero R,Paramio JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mice with skin specific double knockout of both RB1 and TP53 [GeneID=5925;7157] by Cre-lox.
Full description | Squamous cell carcinomas (SCC) represent the most aggressive type of nonmelanoma skin cancer. Although little is known about the causal alterations of SCCs, in organ-transplanted patients the E7 and E6 oncogenes of human papillomavirus, targeting the p53- and pRb-dependent pathways, have been widely involved. Here, we report the functional consequences of the simultaneous elimination of Trp53 and retinoblastoma (Rb) genes in epidermis using Cre-loxP system. Loss of p53, but not pRb, produces spontaneous tumor development, indicating that p53 is the predominant tumor suppressor acting in mouse epidermis. Although the simultaneous inactivation of pRb and p53 does not aggravate the phenotype observed in Rb-deficient epidermis in terms of proliferation and/or differentiation, spontaneous SCC development is severely accelerated in doubly deficient mice. The tumors are aggressive and undifferentiated and display a hair follicle origin. Detailed analysis indicates that the acceleration is mediated by premature activation of the epidermal growth factor receptor/Akt pathway, resulting in increased proliferation in normal and dysplastic hair follicles and augmented tumor angiogenesis. The molecular characteristics of this model provide valuable tools to understand epidermal tumor formation and may ultimately contribute to the development of therapies for the treatment of aggressive squamous cancer.

Standard name | MARTINEZ_RB1_AND_TP53_TARGETS_DN
Systematic name | M3854
Organism | Mus musculus
PMID | 18245467
Authors | Martínez-Cruz AB,Santos M,Lara MF,Segrelles C,Ruiz S,Moral M,Lorz C,García-Escudero R,Paramio JM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mice with skin specific double knockout of both RB1 and TP53 [GeneID=5925;7157] by Cre-lox.
Full description | Squamous cell carcinomas (SCC) represent the most aggressive type of nonmelanoma skin cancer. Although little is known about the causal alterations of SCCs, in organ-transplanted patients the E7 and E6 oncogenes of human papillomavirus, targeting the p53- and pRb-dependent pathways, have been widely involved. Here, we report the functional consequences of the simultaneous elimination of Trp53 and retinoblastoma (Rb) genes in epidermis using Cre-loxP system. Loss of p53, but not pRb, produces spontaneous tumor development, indicating that p53 is the predominant tumor suppressor acting in mouse epidermis. Although the simultaneous inactivation of pRb and p53 does not aggravate the phenotype observed in Rb-deficient epidermis in terms of proliferation and/or differentiation, spontaneous SCC development is severely accelerated in doubly deficient mice. The tumors are aggressive and undifferentiated and display a hair follicle origin. Detailed analysis indicates that the acceleration is mediated by premature activation of the epidermal growth factor receptor/Akt pathway, resulting in increased proliferation in normal and dysplastic hair follicles and augmented tumor angiogenesis. The molecular characteristics of this model provide valuable tools to understand epidermal tumor formation and may ultimately contribute to the development of therapies for the treatment of aggressive squamous cancer.

Standard name | FINETTI_BREAST_CANCER_KINOME_RED
Systematic name | M9389
Organism | Homo sapiens
PMID | 18245477
Authors | Finetti P,Cervera N,Charafe-Jauffret E,Chabannon C,Charpin C,Chaffanet M,Jacquemier J,Viens P,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes in the red cluster of protein kinases distinguishing between luminal A and basal breast cancer subtypes.
Full description | Breast cancer is a heterogeneous disease made of various molecular subtypes with different prognosis. However, evolution remains difficult to predict within some subtypes, such as luminal A, and treatment is not as adapted as it should be. Refinement of prognostic classification and identification of new therapeutic targets are needed. Using oligonucleotide microarrays, we profiled 227 breast cancers. We focused our analysis on two major breast cancer subtypes with opposite prognosis, luminal A (n = 80) and basal (n = 58), and on genes encoding protein kinases. Whole-kinome expression separated luminal A and basal tumors. The expression (measured by a kinase score) of 16 genes encoding serine/threonine kinases involved in mitosis distinguished two subgroups of luminal A tumors: Aa, of good prognosis and Ab, of poor prognosis. This classification and its prognostic effect were validated in 276 luminal A cases from three independent series profiled across different microarray platforms. The classification outperformed the current prognostic factors in univariate and multivariate analyses in both training and validation sets. The luminal Ab subgroup, characterized by high mitotic activity compared with luminal Aa tumors, displayed clinical characteristics and a kinase score intermediate between the luminal Aa subgroup and the luminal B subtype, suggesting a continuum in luminal tumors. Some of the mitotic kinases of the signature represent therapeutic targets under investigation. The identification of luminal A cases of poor prognosis should help select appropriate treatment, whereas the identification of a relevant kinase set provides potential targets.

Standard name | FINETTI_BREAST_CANCER_KINOME_GREEN
Systematic name | M12692
Organism | Homo sapiens
PMID | 18245477
Authors | Finetti P,Cervera N,Charafe-Jauffret E,Chabannon C,Charpin C,Chaffanet M,Jacquemier J,Viens P,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes in the green cluster of protein kinases distinguishing between luminal A and basal breast cancer subtypes.
Full description | Breast cancer is a heterogeneous disease made of various molecular subtypes with different prognosis. However, evolution remains difficult to predict within some subtypes, such as luminal A, and treatment is not as adapted as it should be. Refinement of prognostic classification and identification of new therapeutic targets are needed. Using oligonucleotide microarrays, we profiled 227 breast cancers. We focused our analysis on two major breast cancer subtypes with opposite prognosis, luminal A (n = 80) and basal (n = 58), and on genes encoding protein kinases. Whole-kinome expression separated luminal A and basal tumors. The expression (measured by a kinase score) of 16 genes encoding serine/threonine kinases involved in mitosis distinguished two subgroups of luminal A tumors: Aa, of good prognosis and Ab, of poor prognosis. This classification and its prognostic effect were validated in 276 luminal A cases from three independent series profiled across different microarray platforms. The classification outperformed the current prognostic factors in univariate and multivariate analyses in both training and validation sets. The luminal Ab subgroup, characterized by high mitotic activity compared with luminal Aa tumors, displayed clinical characteristics and a kinase score intermediate between the luminal Aa subgroup and the luminal B subtype, suggesting a continuum in luminal tumors. Some of the mitotic kinases of the signature represent therapeutic targets under investigation. The identification of luminal A cases of poor prognosis should help select appropriate treatment, whereas the identification of a relevant kinase set provides potential targets.

Standard name | FINETTI_BREAST_CANCERS_KINOME_BLUE
Systematic name | M2862
Organism | Homo sapiens
PMID | 18245477
Authors | Finetti P,Cervera N,Charafe-Jauffret E,Chabannon C,Charpin C,Chaffanet M,Jacquemier J,Viens P,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes in the blue cluster of protein kinases distinguishing between luminal A and basal breast cancer subtypes.
Full description | Breast cancer is a heterogeneous disease made of various molecular subtypes with different prognosis. However, evolution remains difficult to predict within some subtypes, such as luminal A, and treatment is not as adapted as it should be. Refinement of prognostic classification and identification of new therapeutic targets are needed. Using oligonucleotide microarrays, we profiled 227 breast cancers. We focused our analysis on two major breast cancer subtypes with opposite prognosis, luminal A (n = 80) and basal (n = 58), and on genes encoding protein kinases. Whole-kinome expression separated luminal A and basal tumors. The expression (measured by a kinase score) of 16 genes encoding serine/threonine kinases involved in mitosis distinguished two subgroups of luminal A tumors: Aa, of good prognosis and Ab, of poor prognosis. This classification and its prognostic effect were validated in 276 luminal A cases from three independent series profiled across different microarray platforms. The classification outperformed the current prognostic factors in univariate and multivariate analyses in both training and validation sets. The luminal Ab subgroup, characterized by high mitotic activity compared with luminal Aa tumors, displayed clinical characteristics and a kinase score intermediate between the luminal Aa subgroup and the luminal B subtype, suggesting a continuum in luminal tumors. Some of the mitotic kinases of the signature represent therapeutic targets under investigation. The identification of luminal A cases of poor prognosis should help select appropriate treatment, whereas the identification of a relevant kinase set provides potential targets.

Standard name | FINETTI_BREAST_CANCERS_KINOME_GRAY
Systematic name | M9693
Organism | Homo sapiens
PMID | 18245477
Authors | Finetti P,Cervera N,Charafe-Jauffret E,Chabannon C,Charpin C,Chaffanet M,Jacquemier J,Viens P,Birnbaum D,Bertucci F
Category | C2
Sub-category | CGP
Brief description | Genes in the gray cluster of protein kinases distinguishing between luminal A and basal breast cancer subtypes.
Full description | Breast cancer is a heterogeneous disease made of various molecular subtypes with different prognosis. However, evolution remains difficult to predict within some subtypes, such as luminal A, and treatment is not as adapted as it should be. Refinement of prognostic classification and identification of new therapeutic targets are needed. Using oligonucleotide microarrays, we profiled 227 breast cancers. We focused our analysis on two major breast cancer subtypes with opposite prognosis, luminal A (n = 80) and basal (n = 58), and on genes encoding protein kinases. Whole-kinome expression separated luminal A and basal tumors. The expression (measured by a kinase score) of 16 genes encoding serine/threonine kinases involved in mitosis distinguished two subgroups of luminal A tumors: Aa, of good prognosis and Ab, of poor prognosis. This classification and its prognostic effect were validated in 276 luminal A cases from three independent series profiled across different microarray platforms. The classification outperformed the current prognostic factors in univariate and multivariate analyses in both training and validation sets. The luminal Ab subgroup, characterized by high mitotic activity compared with luminal Aa tumors, displayed clinical characteristics and a kinase score intermediate between the luminal Aa subgroup and the luminal B subtype, suggesting a continuum in luminal tumors. Some of the mitotic kinases of the signature represent therapeutic targets under investigation. The identification of luminal A cases of poor prognosis should help select appropriate treatment, whereas the identification of a relevant kinase set provides potential targets.

Standard name | MASSARWEH_TAMOXIFEN_RESISTANCE_UP
Systematic name | M17454
Organism | Homo sapiens
PMID | 18245484
Authors | Massarweh S,Osborne CK,Creighton CJ,Qin L,Tsimelzon A,Huang S,Weiss H,Rimawi M,Schiff R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in breast cancer tumors (formed by MCF-7 xenografts) resistant to tamoxifen [PubChem=5376].
Full description | Not all breast cancers respond to tamoxifen, and many develop resistance despite initial benefit. We used an in vivo model of estrogen receptor (ER)-positive breast cancer (MCF-7 xenografts) to investigate mechanisms of this resistance and develop strategies to circumvent it. Epidermal growth factor receptor (EGFR) and HER2, which were barely detected in control estrogen-treated tumors, increased slightly with tamoxifen and were markedly increased when tumors became resistant. Gefitinib, which inhibits EGFR/HER2, improved the antitumor effect of tamoxifen and delayed acquired resistance, but had no effect on estrogen-stimulated growth. Phosphorylated levels of p42/44 and p38 mitogen-activated protein kinases (both downstream of EGFR/HER2) were increased in the tamoxifen-resistant tumors and were suppressed by gefitinib. There was no apparent increase in phosphorylated AKT (also downstream of EGFR/HER2) in resistant tumors, but it was nonetheless suppressed by gefitinib. Phosphorylated insulin-like growth factor-IR (IGF-IR), which can interact with both EGFR and membrane ER, was elevated in the tamoxifen-resistant tumors compared with the sensitive group. However, ER-regulated gene products, including total IGF-IR itself and progesterone receptor, remained suppressed even at the time of acquired resistance. Tamoxifen's antagonism of classic ER genomic function was retained in these resistant tumors and even in tumors that overexpress HER2 (MCF-7 HER2/18) and are de novo tamoxifen-resistant. In conclusion, EGFR/HER2 may mediate tamoxifen resistance in ER-positive breast cancer despite continued suppression of ER genomic function by tamoxifen. IGF-IR expression remains dependent on ER but is activated in the tamoxifen-resistant tumors. This study provides a rationale to combine HER inhibitors with tamoxifen in clinical studies, even in tumors that do not initially overexpress EGFR/HER2.

Standard name | MASSARWEH_TAMOXIFEN_RESISTANCE_DN
Systematic name | M828
Organism | Homo sapiens
PMID | 18245484
Authors | Massarweh S,Osborne CK,Creighton CJ,Qin L,Tsimelzon A,Huang S,Weiss H,Rimawi M,Schiff R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in breast cancer tumors (formed by MCF-7 xenografts) resistant to tamoxifen [PubChem=5376].
Full description | Not all breast cancers respond to tamoxifen, and many develop resistance despite initial benefit. We used an in vivo model of estrogen receptor (ER)-positive breast cancer (MCF-7 xenografts) to investigate mechanisms of this resistance and develop strategies to circumvent it. Epidermal growth factor receptor (EGFR) and HER2, which were barely detected in control estrogen-treated tumors, increased slightly with tamoxifen and were markedly increased when tumors became resistant. Gefitinib, which inhibits EGFR/HER2, improved the antitumor effect of tamoxifen and delayed acquired resistance, but had no effect on estrogen-stimulated growth. Phosphorylated levels of p42/44 and p38 mitogen-activated protein kinases (both downstream of EGFR/HER2) were increased in the tamoxifen-resistant tumors and were suppressed by gefitinib. There was no apparent increase in phosphorylated AKT (also downstream of EGFR/HER2) in resistant tumors, but it was nonetheless suppressed by gefitinib. Phosphorylated insulin-like growth factor-IR (IGF-IR), which can interact with both EGFR and membrane ER, was elevated in the tamoxifen-resistant tumors compared with the sensitive group. However, ER-regulated gene products, including total IGF-IR itself and progesterone receptor, remained suppressed even at the time of acquired resistance. Tamoxifen's antagonism of classic ER genomic function was retained in these resistant tumors and even in tumors that overexpress HER2 (MCF-7 HER2/18) and are de novo tamoxifen-resistant. In conclusion, EGFR/HER2 may mediate tamoxifen resistance in ER-positive breast cancer despite continued suppression of ER genomic function by tamoxifen. IGF-IR expression remains dependent on ER but is activated in the tamoxifen-resistant tumors. This study provides a rationale to combine HER inhibitors with tamoxifen in clinical studies, even in tumors that do not initially overexpress EGFR/HER2.

Standard name | MASSARWEH_RESPONSE_TO_ESTRADIOL
Systematic name | M14447
Organism | Homo sapiens
PMID | 18245484
Authors | Massarweh S,Osborne CK,Creighton CJ,Qin L,Tsimelzon A,Huang S,Weiss H,Rimawi M,Schiff R
Category | C2
Sub-category | CGP
Brief description | Genes rapidly up-regulated in breast cancer cell cultures by estradiol [PubChem=5757].
Full description | Not all breast cancers respond to tamoxifen, and many develop resistance despite initial benefit. We used an in vivo model of estrogen receptor (ER)-positive breast cancer (MCF-7 xenografts) to investigate mechanisms of this resistance and develop strategies to circumvent it. Epidermal growth factor receptor (EGFR) and HER2, which were barely detected in control estrogen-treated tumors, increased slightly with tamoxifen and were markedly increased when tumors became resistant. Gefitinib, which inhibits EGFR/HER2, improved the antitumor effect of tamoxifen and delayed acquired resistance, but had no effect on estrogen-stimulated growth. Phosphorylated levels of p42/44 and p38 mitogen-activated protein kinases (both downstream of EGFR/HER2) were increased in the tamoxifen-resistant tumors and were suppressed by gefitinib. There was no apparent increase in phosphorylated AKT (also downstream of EGFR/HER2) in resistant tumors, but it was nonetheless suppressed by gefitinib. Phosphorylated insulin-like growth factor-IR (IGF-IR), which can interact with both EGFR and membrane ER, was elevated in the tamoxifen-resistant tumors compared with the sensitive group. However, ER-regulated gene products, including total IGF-IR itself and progesterone receptor, remained suppressed even at the time of acquired resistance. Tamoxifen's antagonism of classic ER genomic function was retained in these resistant tumors and even in tumors that overexpress HER2 (MCF-7 HER2/18) and are de novo tamoxifen-resistant. In conclusion, EGFR/HER2 may mediate tamoxifen resistance in ER-positive breast cancer despite continued suppression of ER genomic function by tamoxifen. IGF-IR expression remains dependent on ER but is activated in the tamoxifen-resistant tumors. This study provides a rationale to combine HER inhibitors with tamoxifen in clinical studies, even in tumors that do not initially overexpress EGFR/HER2.

Standard name | WALLACE_PROSTATE_CANCER_UP
Systematic name | M3710
Organism | Homo sapiens
PMID | 18245496
Authors | Wallace TA,Prueitt RL,Yi M,Howe TM,Gillespie JW,Yfantis HG,Stephens RM,Caporaso NE,Loffredo CA,Ambs S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in prostate tumor vs normal tissue samples.
Full description | The incidence and mortality rates of prostate cancer are significantly higher in African-American men when compared with European-American men. We tested the hypothesis that differences in tumor biology contribute to this survival health disparity. Using microarray technology, we obtained gene expression profiles of primary prostate tumors resected from 33 African-American and 36 European-American patients. These tumors were matched on clinical variables. We also evaluated 18 nontumor prostate tissues from seven African-American and 11 European-American patients. The resulting datasets were analyzed for expression differences on the gene and pathway level comparing African-American with European-American patients. Our analysis revealed a significant number of genes, e.g., 162 transcripts at a false-discovery rate of <or=5% to be differently expressed between African-American and European-American patients. Using a disease association analysis, we identified a common relationship of these transcripts with autoimmunity and inflammation. These findings were corroborated on the pathway level with numerous differently expressed genes clustering in immune response, stress response, cytokine signaling, and chemotaxis pathways. Several known metastasis-promoting genes, including autocrine mobility factor receptor, chemokine (C-X-C motif) receptor 4, and matrix metalloproteinase 9, were more highly expressed in tumors from African-Americans than European-Americans. Furthermore, a two-gene tumor signature that accurately differentiated between African-American and European-American patients was identified. This finding was confirmed in a blinded analysis of a second sample set. In conclusion, the gene expression profiles of prostate tumors indicate prominent differences in tumor immunobiology between African-American and European-American men. The profiles portray the existence of a distinct tumor microenvironment in these two patient groups.

Standard name | WALLACE_PROSTATE_CANCER_DN
Systematic name | M12533
Organism | Homo sapiens
PMID | 18245496
Authors | Wallace TA,Prueitt RL,Yi M,Howe TM,Gillespie JW,Yfantis HG,Stephens RM,Caporaso NE,Loffredo CA,Ambs S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in prostate tumor vs normal tissue samples.
Full description | The incidence and mortality rates of prostate cancer are significantly higher in African-American men when compared with European-American men. We tested the hypothesis that differences in tumor biology contribute to this survival health disparity. Using microarray technology, we obtained gene expression profiles of primary prostate tumors resected from 33 African-American and 36 European-American patients. These tumors were matched on clinical variables. We also evaluated 18 nontumor prostate tissues from seven African-American and 11 European-American patients. The resulting datasets were analyzed for expression differences on the gene and pathway level comparing African-American with European-American patients. Our analysis revealed a significant number of genes, e.g., 162 transcripts at a false-discovery rate of <or=5% to be differently expressed between African-American and European-American patients. Using a disease association analysis, we identified a common relationship of these transcripts with autoimmunity and inflammation. These findings were corroborated on the pathway level with numerous differently expressed genes clustering in immune response, stress response, cytokine signaling, and chemotaxis pathways. Several known metastasis-promoting genes, including autocrine mobility factor receptor, chemokine (C-X-C motif) receptor 4, and matrix metalloproteinase 9, were more highly expressed in tumors from African-Americans than European-Americans. Furthermore, a two-gene tumor signature that accurately differentiated between African-American and European-American patients was identified. This finding was confirmed in a blinded analysis of a second sample set. In conclusion, the gene expression profiles of prostate tumors indicate prominent differences in tumor immunobiology between African-American and European-American men. The profiles portray the existence of a distinct tumor microenvironment in these two patient groups.

Standard name | WALLACE_PROSTATE_CANCER_RACE_UP
Systematic name | M10319
Organism | Homo sapiens
PMID | 18245496
Authors | Wallace TA,Prueitt RL,Yi M,Howe TM,Gillespie JW,Yfantis HG,Stephens RM,Caporaso NE,Loffredo CA,Ambs S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in prostate cancer samples from African-American patients compared to those from the European-American patients.
Full description | The incidence and mortality rates of prostate cancer are significantly higher in African-American men when compared with European-American men. We tested the hypothesis that differences in tumor biology contribute to this survival health disparity. Using microarray technology, we obtained gene expression profiles of primary prostate tumors resected from 33 African-American and 36 European-American patients. These tumors were matched on clinical variables. We also evaluated 18 nontumor prostate tissues from seven African-American and 11 European-American patients. The resulting datasets were analyzed for expression differences on the gene and pathway level comparing African-American with European-American patients. Our analysis revealed a significant number of genes, e.g., 162 transcripts at a false-discovery rate of <or=5% to be differently expressed between African-American and European-American patients. Using a disease association analysis, we identified a common relationship of these transcripts with autoimmunity and inflammation. These findings were corroborated on the pathway level with numerous differently expressed genes clustering in immune response, stress response, cytokine signaling, and chemotaxis pathways. Several known metastasis-promoting genes, including autocrine mobility factor receptor, chemokine (C-X-C motif) receptor 4, and matrix metalloproteinase 9, were more highly expressed in tumors from African-Americans than European-Americans. Furthermore, a two-gene tumor signature that accurately differentiated between African-American and European-American patients was identified. This finding was confirmed in a blinded analysis of a second sample set. In conclusion, the gene expression profiles of prostate tumors indicate prominent differences in tumor immunobiology between African-American and European-American men. The profiles portray the existence of a distinct tumor microenvironment in these two patient groups.

Standard name | WALLACE_PROSTATE_CANCER_RACE_DN
Systematic name | M15671
Organism | Homo sapiens
PMID | 18245496
Authors | Wallace TA,Prueitt RL,Yi M,Howe TM,Gillespie JW,Yfantis HG,Stephens RM,Caporaso NE,Loffredo CA,Ambs S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in prostate cancer samples from African-American patients compared to those from the European-American patients.
Full description | The incidence and mortality rates of prostate cancer are significantly higher in African-American men when compared with European-American men. We tested the hypothesis that differences in tumor biology contribute to this survival health disparity. Using microarray technology, we obtained gene expression profiles of primary prostate tumors resected from 33 African-American and 36 European-American patients. These tumors were matched on clinical variables. We also evaluated 18 nontumor prostate tissues from seven African-American and 11 European-American patients. The resulting datasets were analyzed for expression differences on the gene and pathway level comparing African-American with European-American patients. Our analysis revealed a significant number of genes, e.g., 162 transcripts at a false-discovery rate of <or=5% to be differently expressed between African-American and European-American patients. Using a disease association analysis, we identified a common relationship of these transcripts with autoimmunity and inflammation. These findings were corroborated on the pathway level with numerous differently expressed genes clustering in immune response, stress response, cytokine signaling, and chemotaxis pathways. Several known metastasis-promoting genes, including autocrine mobility factor receptor, chemokine (C-X-C motif) receptor 4, and matrix metalloproteinase 9, were more highly expressed in tumors from African-Americans than European-Americans. Furthermore, a two-gene tumor signature that accurately differentiated between African-American and European-American patients was identified. This finding was confirmed in a blinded analysis of a second sample set. In conclusion, the gene expression profiles of prostate tumors indicate prominent differences in tumor immunobiology between African-American and European-American men. The profiles portray the existence of a distinct tumor microenvironment in these two patient groups.

Standard name | SARRIO_EPITHELIAL_MESENCHYMAL_TRANSITION_UP
Systematic name | M4288
Organism | Homo sapiens
PMID | 18281472
Authors | Sarrió D,Rodriguez-Pinilla SM,Hardisson D,Cano A,Moreno-Bueno G,Palacios J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF10A cells (breast cancer) grown at low (mesenchymal phenotype) compared to those grown at high (epithelial, basal-like phenotype) confluency.
Full description | Epithelial-mesenchymal transition (EMT) is defined by the loss of epithelial characteristics and the acquisition of a mesenchymal phenotype. In carcinoma cells, EMT can be associated with increased aggressiveness, and invasive and metastatic potential. To assess the occurrence of EMT in human breast tumors, we conducted a tissue microarray-based immunohistochemical study in 479 invasive breast carcinomas and 12 carcinosarcomas using 28 different markers. Unsupervised hierarchical clustering of the tumors and statistical analysis showed that up-regulation of EMT markers (vimentin, smooth-muscle-actin, N-cadherin, and cadherin-11) and overexpression of proteins involved in extracellular matrix remodeling and invasion (SPARC, laminin, and fascin), together with reduction of characteristic epithelial markers (E-cadherin and cytokeratins), preferentially occur in breast tumors with the basal-like phenotype. Moreover, most breast carcinosarcomas also had a basal-like phenotype and showed expression of mesenchymal markers in their sarcomatous and epithelial components. To assess whether basal-like cells have intrinsic phenotypic plasticity for mesenchymal transition, we performed in vitro studies with the MCF10A cell line. In response to low cell density, MCF10A cells suffer spontaneous morphologic and phenotypic EMT-like changes, including cytoskeleton reorganization, vimentin and Slug up-regulation, cadherin switching, and diffuse cytosolic relocalization of the catenins. Moreover, these phenotypic changes are associated with modifications in the global genetic differentiation program characteristic of the EMT process. In summary, our data indicate that in breast tumors, EMT likely occurs within a specific genetic context, the basal phenotype, and suggests that this proclivity to mesenchymal transition may be related to the high aggressiveness and the characteristic metastatic spread of these tumors.

Standard name | SARRIO_EPITHELIAL_MESENCHYMAL_TRANSITION_DN
Systematic name | M11513
Organism | Homo sapiens
PMID | 18281472
Authors | Sarrió D,Rodriguez-Pinilla SM,Hardisson D,Cano A,Moreno-Bueno G,Palacios J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF10A cells (breast cancer) grown at low (mesenchymal phenotype) compared to those grown at high (epithelial, basal-like phenotype) confluency.
Full description | Epithelial-mesenchymal transition (EMT) is defined by the loss of epithelial characteristics and the acquisition of a mesenchymal phenotype. In carcinoma cells, EMT can be associated with increased aggressiveness, and invasive and metastatic potential. To assess the occurrence of EMT in human breast tumors, we conducted a tissue microarray-based immunohistochemical study in 479 invasive breast carcinomas and 12 carcinosarcomas using 28 different markers. Unsupervised hierarchical clustering of the tumors and statistical analysis showed that up-regulation of EMT markers (vimentin, smooth-muscle-actin, N-cadherin, and cadherin-11) and overexpression of proteins involved in extracellular matrix remodeling and invasion (SPARC, laminin, and fascin), together with reduction of characteristic epithelial markers (E-cadherin and cytokeratins), preferentially occur in breast tumors with the basal-like phenotype. Moreover, most breast carcinosarcomas also had a basal-like phenotype and showed expression of mesenchymal markers in their sarcomatous and epithelial components. To assess whether basal-like cells have intrinsic phenotypic plasticity for mesenchymal transition, we performed in vitro studies with the MCF10A cell line. In response to low cell density, MCF10A cells suffer spontaneous morphologic and phenotypic EMT-like changes, including cytoskeleton reorganization, vimentin and Slug up-regulation, cadherin switching, and diffuse cytosolic relocalization of the catenins. Moreover, these phenotypic changes are associated with modifications in the global genetic differentiation program characteristic of the EMT process. In summary, our data indicate that in breast tumors, EMT likely occurs within a specific genetic context, the basal phenotype, and suggests that this proclivity to mesenchymal transition may be related to the high aggressiveness and the characteristic metastatic spread of these tumors.

Standard name | OUILLETTE_CLL_13Q14_DELETION_UP
Systematic name | M9025
Organism | Homo sapiens
PMID | 18281475
Authors | Ouillette P,Erba H,Kujawski L,Kaminski M,Shedden K,Malek SN
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in chronic lymphocytic leukemia (CLL) samples bearing deletions in the 13q14 region.
Full description | Chronic lymphocytic leukemia (CLL) is a biologically heterogeneous illness with a variable clinical course. Loss of chromosomal material on chromosome 13 at cytoband 13q14 is the most frequent genetic abnormality in CLL, but the molecular aberrations underlying del13q14 in CLL remain incompletely characterized. We analyzed 171 CLL cases for loss of heterozygosity and subchromosomal copy loss on chromosome 13 in DNA from fluorescence-activated cell sorting-sorted CD19(+) cells and paired buccal cells using the Affymetrix XbaI 50k SNP array platform. The resulting high-resolution genomic maps, together with array-based measurements of expression levels of RNA in CLL cases with and without del13q14 and quantitative PCR-based expression analysis of selected genes, support the following conclusions: (a) del13q14 is heterogeneous and composed of multiple subtypes, with deletion of Rb or the miR15a/miR16 loci serving as anatomic landmarks, respectively; (b) del13q14 type Ia deletions are relatively uniform in length and extend from breakpoints close to the miR15a/miR16 cluster to a newly identified telomeric breakpoint cluster at the approximately 50.2 to 50.5 Mb physical position; (c) LATS2 RNA levels are approximately 2.6-fold to 2.8-fold lower in cases with del13q14 type I that do not delete Rb, as opposed to del13q14 type II or all other CLL cases; (d) PHLPP RNA is absent in approximately 50% of CLL cases with del13q14; and (e) approximately 15% of CLL cases display marked reductions in miR15a/miR16 expression that are often but not invariably associated with bi-allelic miR15a/miR16 loss. These data should aid future investigations into biological differences imparted on CLL by different del13q14 subtypes.

Standard name | OUILLETTE_CLL_13Q14_DELETION_DN
Systematic name | M3603
Organism | Homo sapiens
PMID | 18281475
Authors | Ouillette P,Erba H,Kujawski L,Kaminski M,Shedden K,Malek SN
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in chronic lymphocytic leukemia (CLL) samples bearing deletions in the 13q14 region.
Full description | Chronic lymphocytic leukemia (CLL) is a biologically heterogeneous illness with a variable clinical course. Loss of chromosomal material on chromosome 13 at cytoband 13q14 is the most frequent genetic abnormality in CLL, but the molecular aberrations underlying del13q14 in CLL remain incompletely characterized. We analyzed 171 CLL cases for loss of heterozygosity and subchromosomal copy loss on chromosome 13 in DNA from fluorescence-activated cell sorting-sorted CD19(+) cells and paired buccal cells using the Affymetrix XbaI 50k SNP array platform. The resulting high-resolution genomic maps, together with array-based measurements of expression levels of RNA in CLL cases with and without del13q14 and quantitative PCR-based expression analysis of selected genes, support the following conclusions: (a) del13q14 is heterogeneous and composed of multiple subtypes, with deletion of Rb or the miR15a/miR16 loci serving as anatomic landmarks, respectively; (b) del13q14 type Ia deletions are relatively uniform in length and extend from breakpoints close to the miR15a/miR16 cluster to a newly identified telomeric breakpoint cluster at the approximately 50.2 to 50.5 Mb physical position; (c) LATS2 RNA levels are approximately 2.6-fold to 2.8-fold lower in cases with del13q14 type I that do not delete Rb, as opposed to del13q14 type II or all other CLL cases; (d) PHLPP RNA is absent in approximately 50% of CLL cases with del13q14; and (e) approximately 15% of CLL cases display marked reductions in miR15a/miR16 expression that are often but not invariably associated with bi-allelic miR15a/miR16 loss. These data should aid future investigations into biological differences imparted on CLL by different del13q14 subtypes.

Standard name | YOKOE_CANCER_TESTIS_ANTIGENS
Systematic name | M12210
Organism | Homo sapiens
PMID | 18281482
Authors | Yokoe T,Tanaka F,Mimori K,Inoue H,Ohmachi T,Kusunoki M,Mori M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in both colorectal cancer cells and normal testis relative to normal colon epithelium.
Full description | Advanced technology in molecular biology has provided us powerful tools for the diagnosis and treatment for cancer. We herein adopted a new methodology to identify a novel cancer/testis (CT) antigen with high frequency of expression in colorectal cancer as follows: (a) combining laser microdissection and cDNA microarray was used to analyze the gene expression profile of colorectal cancer cells; (b) genes overexpressed in testis and underexpressed in normal colon epithelium were analyzed using cDNA microarray; and (c) the gene expression profile of colorectal cancer cells was compared with that of normal testis. Using this methodology, we selected 38 candidates for CT antigen. Among these genes, we identified a novel CT antigen, serine/threonine kinase 31 (STK31), which was previously reported as a gene expressed in spermatogonia. Reverse transcription-PCR analysis showed that STK31 gene expression levels in cancer samples were significantly higher (P < 0.0001) than those in normal samples. The STK31 gene was frequently expressed not only in colorectal cancer but also in gastric and esophageal cancer. Moreover, STK31 peptide was able to elicit specific CTLs and induced CTLs lysed either peptide-loading or endogenously STK31-expressing target cells. These results showed that the new methodology in this study facilitated identification of CT antigens and that STK31 may be a candidate for cancer immunotherapy against gastrointestinal cancer.

Standard name | MARZEC_IL2_SIGNALING_UP
Systematic name | M13984
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by IL2 [GeneID=3558] in cells derived from CD4+ [GeneID=920] cutaneous T-cell lymphoma (CTCL).
Full description | In this study, we compared the effects of interleukin-2 (IL-2), IL-15, and IL-21 on gene expression, activation of cell signaling pathways, and functional properties of cells derived from CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 modulated, in a CTCL cell line, the expression of >1,000 gene transcripts by at least 2-fold, IL-21 up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3 in CTCL cell lines and native leukemic (Sezary) cells. However, only IL-2 and IL-15 strongly activated signal transducers and activators of transcription 5, phosphoinositide 3-kinase/Akt, and mitogen-activated protein/extracellular signal-regulated kinase (ERK) kinase/ERK signaling pathways in the cell lines and mitogen-primed native cells. In contrast, IL-21 selectively activated signal transducers and activators of transcription 3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3 kinase- and Jak1 kinase- dependent. These findings document the vastly different effect of IL-2 and IL-15 versus IL-21 on CTCL cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T-cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, natural killer, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | MARZEC_IL2_SIGNALING_DN
Systematic name | M13276
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by IL2 [GeneID=3558] in cells derived from CD4+ [GeneID=920] cutaneous T-cell lymphoma (CTCL).
Full description | In this study, we compared the effects of interleukin-2 (IL-2), IL-15, and IL-21 on gene expression, activation of cell signaling pathways, and functional properties of cells derived from CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 modulated, in a CTCL cell line, the expression of >1,000 gene transcripts by at least 2-fold, IL-21 up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3 in CTCL cell lines and native leukemic (Sezary) cells. However, only IL-2 and IL-15 strongly activated signal transducers and activators of transcription 5, phosphoinositide 3-kinase/Akt, and mitogen-activated protein/extracellular signal-regulated kinase (ERK) kinase/ERK signaling pathways in the cell lines and mitogen-primed native cells. In contrast, IL-21 selectively activated signal transducers and activators of transcription 3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3 kinase- and Jak1 kinase- dependent. These findings document the vastly different effect of IL-2 and IL-15 versus IL-21 on CTCL cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T-cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, natural killer, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | IWANAGA_CARCINOGENESIS_BY_KRAS_PTEN_UP
Systematic name | M2776
Organism | Mus musculus
PMID | 18281487
Authors | Iwanaga K,Yang Y,Raso MG,Ma L,Hanna AE,Thilaganathan N,Moghaddam S,Evans CM,Li H,Cai WW,Sato M,Minna JD,Wu H,Creighton CJ,Demayo FJ,Wistuba II,Kurie JM
Category | C2
Sub-category | CGP
Brief description | Cluster 1: genes up-regulated in lung tissue samples from mice with oncogenic form of KRAS [GeneID=3845] and inactivated PTEN [GeneID=5728].
Full description | Phosphatase and tensin homologue deleted from chromosome 10 (Pten) is expressed aberrantly in non-small cell lung cancer cells, but the role of Pten in lung neoplasia has not been fully elucidated. In this study, we used a genetic approach to inactivate Pten in the bronchial epithelium of mice. Although, by itself, Pten inactivation had no discernible effect on bronchial epithelial histology, it accelerated lung tumorigenesis initiated by oncogenic K-ras, causing more rapid lethality than that induced by oncogenic K-ras alone (8 weeks versus 24 weeks of median duration of survival, respectively). Lung tumors arose in K-ras mutant, Pten-deficient mice that rapidly obstructed bronchial lumina and replaced alveolar spaces. Relative to K-ras mutant tumors, the K-ras mutant, Pten-deficient tumors exhibited more advanced histologic severity and more prominent inflammation and vascularity. Thus, Pten inactivation cooperated with oncogenic K-ras in promoting lung tumorigenesis.

Standard name | IWANAGA_CARCINOGENESIS_BY_KRAS_PTEN_DN
Systematic name | M6315
Organism | Mus musculus
PMID | 18281487
Authors | Iwanaga K,Yang Y,Raso MG,Ma L,Hanna AE,Thilaganathan N,Moghaddam S,Evans CM,Li H,Cai WW,Sato M,Minna JD,Wu H,Creighton CJ,Demayo FJ,Wistuba II,Kurie JM
Category | C2
Sub-category | CGP
Brief description | Cluster 2: genes down-regulated in lung tissue samples from mice with oncogenic form of KRAS [GeneID=3845] and inactivated PTEN [GeneID=5728].
Full description | Phosphatase and tensin homologue deleted from chromosome 10 (Pten) is expressed aberrantly in non-small cell lung cancer cells, but the role of Pten in lung neoplasia has not been fully elucidated. In this study, we used a genetic approach to inactivate Pten in the bronchial epithelium of mice. Although, by itself, Pten inactivation had no discernible effect on bronchial epithelial histology, it accelerated lung tumorigenesis initiated by oncogenic K-ras, causing more rapid lethality than that induced by oncogenic K-ras alone (8 weeks versus 24 weeks of median duration of survival, respectively). Lung tumors arose in K-ras mutant, Pten-deficient mice that rapidly obstructed bronchial lumina and replaced alveolar spaces. Relative to K-ras mutant tumors, the K-ras mutant, Pten-deficient tumors exhibited more advanced histologic severity and more prominent inflammation and vascularity. Thus, Pten inactivation cooperated with oncogenic K-ras in promoting lung tumorigenesis.

Standard name | IWANAGA_CARCINOGENESIS_BY_KRAS_UP
Systematic name | M9118
Organism | Mus musculus
PMID | 18281487
Authors | Iwanaga K,Yang Y,Raso MG,Ma L,Hanna AE,Thilaganathan N,Moghaddam S,Evans CM,Li H,Cai WW,Sato M,Minna JD,Wu H,Creighton CJ,Demayo FJ,Wistuba II,Kurie JM
Category | C2
Sub-category | CGP
Brief description | Cluster 3: genes up-regulated in lung tissue samples from mice with tumor-bearing genotypes (activated KRAS [GeneID=3845] alone or together with inactivated PTEN [GeneID=5728]).
Full description | Phosphatase and tensin homologue deleted from chromosome 10 (Pten) is expressed aberrantly in non-small cell lung cancer cells, but the role of Pten in lung neoplasia has not been fully elucidated. In this study, we used a genetic approach to inactivate Pten in the bronchial epithelium of mice. Although, by itself, Pten inactivation had no discernible effect on bronchial epithelial histology, it accelerated lung tumorigenesis initiated by oncogenic K-ras, causing more rapid lethality than that induced by oncogenic K-ras alone (8 weeks versus 24 weeks of median duration of survival, respectively). Lung tumors arose in K-ras mutant, Pten-deficient mice that rapidly obstructed bronchial lumina and replaced alveolar spaces. Relative to K-ras mutant tumors, the K-ras mutant, Pten-deficient tumors exhibited more advanced histologic severity and more prominent inflammation and vascularity. Thus, Pten inactivation cooperated with oncogenic K-ras in promoting lung tumorigenesis.

Standard name | IWANAGA_CARCINOGENESIS_BY_KRAS_DN
Systematic name | M9362
Organism | Mus musculus
PMID | 18281487
Authors | Iwanaga K,Yang Y,Raso MG,Ma L,Hanna AE,Thilaganathan N,Moghaddam S,Evans CM,Li H,Cai WW,Sato M,Minna JD,Wu H,Creighton CJ,Demayo FJ,Wistuba II,Kurie JM
Category | C2
Sub-category | CGP
Brief description | Cluster 4: genes down-regulated in lung tissue samples from mice with tumor-bearing genotypes (activated KRAS [GeneID=3845] alone or together with inactivated PTEN [GeneID=5728]).
Full description | Phosphatase and tensin homologue deleted from chromosome 10 (Pten) is expressed aberrantly in non-small cell lung cancer cells, but the role of Pten in lung neoplasia has not been fully elucidated. In this study, we used a genetic approach to inactivate Pten in the bronchial epithelium of mice. Although, by itself, Pten inactivation had no discernible effect on bronchial epithelial histology, it accelerated lung tumorigenesis initiated by oncogenic K-ras, causing more rapid lethality than that induced by oncogenic K-ras alone (8 weeks versus 24 weeks of median duration of survival, respectively). Lung tumors arose in K-ras mutant, Pten-deficient mice that rapidly obstructed bronchial lumina and replaced alveolar spaces. Relative to K-ras mutant tumors, the K-ras mutant, Pten-deficient tumors exhibited more advanced histologic severity and more prominent inflammation and vascularity. Thus, Pten inactivation cooperated with oncogenic K-ras in promoting lung tumorigenesis.

Standard name | DER_IFN_ALPHA_RESPONSE_DN
Systematic name | M5032
Organism | Homo sapiens
PMID | 9861020
Authors | Der SD,Zhou A,Williams BR,Silverman RH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HT1080 cells (fibrosarcoma) by treatment with interferon alpha for 6 h.
Full description | The pleiotropic activities of interferons (IFNs) are mediated primarily through the transcriptional regulation of many downstream effector genes. The mRNA profiles from IFN-alpha, -beta, or -gamma treatments of the human fibrosarcoma cell line, HT1080, were determined by using oligonucleotide arrays with probe sets corresponding to more than 6,800 human genes. Among these were transcripts for known IFN-stimulated genes (ISGs), the expression of which were consistent with previous studies in which the particular ISG was characterized as responsive to either Type I (alpha, beta) or Type II (gamma) IFNs, or both. Importantly, many novel IFN-stimulated genes were identified that were diverse in their known biological functions. For instance, several novel ISGs were identified that are implicated in apoptosis (including RAP46/Bag-1, phospholipid scramblase, and hypoxia inducible factor-1alpha). Furthermore, several IFN-repressed genes also were identified. These results demonstrate the usefulness of oligonucleotide arrays in monitoring mammalian gene expression on a broad and unprecedented scale. In particular, these findings provide insights into the basic mechanisms of IFN actions and ultimately may contribute to better therapeutic uses for IFNs.

Standard name | CAMPS_COLON_CANCER_COPY_NUMBER_UP
Systematic name | M18750
Organism | Homo sapiens
PMID | 18316590
Authors | Camps J,Grade M,Nguyen QT,Hörmann P,Becker S,Hummon AB,Rodriguez V,Chandrasekharappa S,Chen Y,Difilippantonio MJ,Becker H,Ghadimi BM,Ried T
Category | C2
Sub-category | CGP
Brief description | Genes from chromosomal copy number gains in a panel of 51 primary colon carcinoma samples.
Full description | Genomic aberrations on chromosome 8 are common in colon cancer, and are associated with lymph node and distant metastases as well as with disease susceptibility. This prompted us to generate a high-resolution map of genomic imbalances of chromosome 8 in 51 primary colon carcinomas using a custom-designed genomic array consisting of a tiling path of BAC clones. This analysis confirmed the dominant role of this chromosome. Unexpectedly, the position of the breakpoints suggested colocalization with structural variants in the human genome. In order to map these sites with increased resolution and to extend the analysis to the entire genome, we analyzed a subset of these tumors (n = 32) by comparative genomic hybridization on a 185K oligonucleotide array platform. Our comprehensive map of the colon cancer genome confirmed recurrent and specific low-level copy number changes of chromosomes 7, 8, 13, 18, and 20, and unveiled additional, novel sites of genomic imbalances including amplification of a histone gene cluster on chromosome 6p21.1-21.33 and deletions on chromosome 4q34-35. The systematic comparison of segments of copy number change with gene expression profiles showed that genomic imbalances directly affect average expression levels. Strikingly, we observed a significant association of chromosomal breakpoints with structural variants in the human genome: 41% of all copy number changes occurred at sites of such copy number variants (P < 2.2e(-16)). Such an association has not been previously described and reveals a yet underappreciated plasticity of the colon cancer genome; it also points to potential mechanisms for the induction of chromosomal breakage in cancer cells.

Standard name | CAMPS_COLON_CANCER_COPY_NUMBER_DN
Systematic name | M17535
Organism | Homo sapiens
PMID | 18316590
Authors | Camps J,Grade M,Nguyen QT,Hörmann P,Becker S,Hummon AB,Rodriguez V,Chandrasekharappa S,Chen Y,Difilippantonio MJ,Becker H,Ghadimi BM,Ried T
Category | C2
Sub-category | CGP
Brief description | Genes from chromosomal copy number losses in a panel of 51 primary colon carcinoma samples.
Full description | Genomic aberrations on chromosome 8 are common in colon cancer, and are associated with lymph node and distant metastases as well as with disease susceptibility. This prompted us to generate a high-resolution map of genomic imbalances of chromosome 8 in 51 primary colon carcinomas using a custom-designed genomic array consisting of a tiling path of BAC clones. This analysis confirmed the dominant role of this chromosome. Unexpectedly, the position of the breakpoints suggested colocalization with structural variants in the human genome. In order to map these sites with increased resolution and to extend the analysis to the entire genome, we analyzed a subset of these tumors (n = 32) by comparative genomic hybridization on a 185K oligonucleotide array platform. Our comprehensive map of the colon cancer genome confirmed recurrent and specific low-level copy number changes of chromosomes 7, 8, 13, 18, and 20, and unveiled additional, novel sites of genomic imbalances including amplification of a histone gene cluster on chromosome 6p21.1-21.33 and deletions on chromosome 4q34-35. The systematic comparison of segments of copy number change with gene expression profiles showed that genomic imbalances directly affect average expression levels. Strikingly, we observed a significant association of chromosomal breakpoints with structural variants in the human genome: 41% of all copy number changes occurred at sites of such copy number variants (P < 2.2e(-16)). Such an association has not been previously described and reveals a yet underappreciated plasticity of the colon cancer genome; it also points to potential mechanisms for the induction of chromosomal breakage in cancer cells.

Standard name | RIZKI_TUMOR_INVASIVENESS_3D_UP
Systematic name | M17026
Organism | Homo sapiens
PMID | 18316601
Authors | Rizki A,Weaver VM,Lee SY,Rozenberg GI,Chin K,Myers CA,Bascom JL,Mott JD,Semeiks JR,Grate LR,Mian IS,Borowsky AD,Jensen RA,Idowu MO,Chen F,Chen DJ,Petersen OW,Gray JW,Bissell MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in three-dimentional (3D) cultures of preinvasive (S3-C) vs invasive (T4-2) breast cancer cells.
Full description | A crucial step in human breast cancer progression is the acquisition of invasiveness. There is a distinct lack of human cell culture models to study the transition from preinvasive to invasive phenotype as it may occur spontaneously in vivo. To delineate molecular alterations important for this transition, we isolated human breast epithelial cell lines that showed partial loss of tissue polarity in three-dimensional reconstituted basement membrane cultures. These cells remained noninvasive; however, unlike their nonmalignant counterparts, they exhibited a high propensity to acquire invasiveness through basement membrane in culture. The genomic aberrations and gene expression profiles of the cells in this model showed a high degree of similarity to primary breast tumor profiles. The xenograft tumors formed by the cell lines in three different microenvironments in nude mice displayed metaplastic phenotypes, including squamous and basal characteristics, with invasive cells exhibiting features of higher-grade tumors. To find functionally significant changes in transition from preinvasive to invasive phenotype, we performed attribute profile clustering analysis on the list of genes differentially expressed between preinvasive and invasive cells. We found integral membrane proteins, transcription factors, kinases, transport molecules, and chemokines to be highly represented. In addition, expression of matrix metalloproteinases MMP9, MMP13, MMP15, and MMP17 was up-regulated in the invasive cells. Using small interfering RNA-based approaches, we found these MMPs to be required for the invasive phenotype. This model provides a new tool for dissection of mechanisms by which preinvasive breast cells could acquire invasiveness in a metaplastic context.

Standard name | RIZKI_TUMOR_INVASIVENESS_3D_DN
Systematic name | M11472
Organism | Homo sapiens
PMID | 18316601
Authors | Rizki A,Weaver VM,Lee SY,Rozenberg GI,Chin K,Myers CA,Bascom JL,Mott JD,Semeiks JR,Grate LR,Mian IS,Borowsky AD,Jensen RA,Idowu MO,Chen F,Chen DJ,Petersen OW,Gray JW,Bissell MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in three-dimentional (3D) cultures of preinvasive (S3-C) vs invasive (T4-2) breast cancer cells.
Full description | A crucial step in human breast cancer progression is the acquisition of invasiveness. There is a distinct lack of human cell culture models to study the transition from preinvasive to invasive phenotype as it may occur spontaneously in vivo. To delineate molecular alterations important for this transition, we isolated human breast epithelial cell lines that showed partial loss of tissue polarity in three-dimensional reconstituted basement membrane cultures. These cells remained noninvasive; however, unlike their nonmalignant counterparts, they exhibited a high propensity to acquire invasiveness through basement membrane in culture. The genomic aberrations and gene expression profiles of the cells in this model showed a high degree of similarity to primary breast tumor profiles. The xenograft tumors formed by the cell lines in three different microenvironments in nude mice displayed metaplastic phenotypes, including squamous and basal characteristics, with invasive cells exhibiting features of higher-grade tumors. To find functionally significant changes in transition from preinvasive to invasive phenotype, we performed attribute profile clustering analysis on the list of genes differentially expressed between preinvasive and invasive cells. We found integral membrane proteins, transcription factors, kinases, transport molecules, and chemokines to be highly represented. In addition, expression of matrix metalloproteinases MMP9, MMP13, MMP15, and MMP17 was up-regulated in the invasive cells. Using small interfering RNA-based approaches, we found these MMPs to be required for the invasive phenotype. This model provides a new tool for dissection of mechanisms by which preinvasive breast cells could acquire invasiveness in a metaplastic context.

Standard name | RIZKI_TUMOR_INVASIVENESS_2D_UP
Systematic name | M4242
Organism | Homo sapiens
PMID | 18316601
Authors | Rizki A,Weaver VM,Lee SY,Rozenberg GI,Chin K,Myers CA,Bascom JL,Mott JD,Semeiks JR,Grate LR,Mian IS,Borowsky AD,Jensen RA,Idowu MO,Chen F,Chen DJ,Petersen OW,Gray JW,Bissell MJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in monolayer (2D) cultures of preinvasive (S3-C) vs invasive (T4-2) breast cancer cells.
Full description | A crucial step in human breast cancer progression is the acquisition of invasiveness. There is a distinct lack of human cell culture models to study the transition from preinvasive to invasive phenotype as it may occur spontaneously in vivo. To delineate molecular alterations important for this transition, we isolated human breast epithelial cell lines that showed partial loss of tissue polarity in three-dimensional reconstituted basement membrane cultures. These cells remained noninvasive; however, unlike their nonmalignant counterparts, they exhibited a high propensity to acquire invasiveness through basement membrane in culture. The genomic aberrations and gene expression profiles of the cells in this model showed a high degree of similarity to primary breast tumor profiles. The xenograft tumors formed by the cell lines in three different microenvironments in nude mice displayed metaplastic phenotypes, including squamous and basal characteristics, with invasive cells exhibiting features of higher-grade tumors. To find functionally significant changes in transition from preinvasive to invasive phenotype, we performed attribute profile clustering analysis on the list of genes differentially expressed between preinvasive and invasive cells. We found integral membrane proteins, transcription factors, kinases, transport molecules, and chemokines to be highly represented. In addition, expression of matrix metalloproteinases MMP9, MMP13, MMP15, and MMP17 was up-regulated in the invasive cells. Using small interfering RNA-based approaches, we found these MMPs to be required for the invasive phenotype. This model provides a new tool for dissection of mechanisms by which preinvasive breast cells could acquire invasiveness in a metaplastic context.

Standard name | RIZKI_TUMOR_INVASIVENESS_2D_DN
Systematic name | M7615
Organism | Homo sapiens
PMID | 18316601
Authors | Rizki A,Weaver VM,Lee SY,Rozenberg GI,Chin K,Myers CA,Bascom JL,Mott JD,Semeiks JR,Grate LR,Mian IS,Borowsky AD,Jensen RA,Idowu MO,Chen F,Chen DJ,Petersen OW,Gray JW,Bissell MJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in monolayer (2D) cultures of preinvasive (S3-C) vs invasive (T4-2) breast cancer cells.
Full description | A crucial step in human breast cancer progression is the acquisition of invasiveness. There is a distinct lack of human cell culture models to study the transition from preinvasive to invasive phenotype as it may occur spontaneously in vivo. To delineate molecular alterations important for this transition, we isolated human breast epithelial cell lines that showed partial loss of tissue polarity in three-dimensional reconstituted basement membrane cultures. These cells remained noninvasive; however, unlike their nonmalignant counterparts, they exhibited a high propensity to acquire invasiveness through basement membrane in culture. The genomic aberrations and gene expression profiles of the cells in this model showed a high degree of similarity to primary breast tumor profiles. The xenograft tumors formed by the cell lines in three different microenvironments in nude mice displayed metaplastic phenotypes, including squamous and basal characteristics, with invasive cells exhibiting features of higher-grade tumors. To find functionally significant changes in transition from preinvasive to invasive phenotype, we performed attribute profile clustering analysis on the list of genes differentially expressed between preinvasive and invasive cells. We found integral membrane proteins, transcription factors, kinases, transport molecules, and chemokines to be highly represented. In addition, expression of matrix metalloproteinases MMP9, MMP13, MMP15, and MMP17 was up-regulated in the invasive cells. Using small interfering RNA-based approaches, we found these MMPs to be required for the invasive phenotype. This model provides a new tool for dissection of mechanisms by which preinvasive breast cells could acquire invasiveness in a metaplastic context.

Standard name | FUJII_YBX1_TARGETS_UP
Systematic name | M15267
Organism | Homo sapiens
PMID | 18316615
Authors | Fujii T,Kawahara A,Basaki Y,Hattori S,Nakashima K,Nakano K,Shirouzu K,Kohno K,Yanagawa T,Yamana H,Nishio K,Ono M,Kuwano M,Kage M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) after knockdown of YBX1 [GeneID=4904] by RNAi.
Full description | In our present study, we examined whether nuclear localization of Y-box binding protein-1 (YB-1) is associated with the expression of epidermal growth factor receptors (EGFR), hormone receptors, and other molecules affecting breast cancer prognosis. The expression of nuclear YB-1, clinicopathologic findings, and molecular markers [EGFR, HER2, estrogen receptor (ER)alpha, ER beta, progesterone receptor, chemokine (C-X-C motif) receptor 4 (CXCR4), phosphorylated Akt, and major vault protein/lung resistance protein] were immunohistochemically analyzed. The association of the expression of nuclear YB-1 and the molecular markers was examined in breast cancer cell lines using microarrays, quantitative real-time PCR, and Western blot analyses. Knockdown of YB-1 with siRNA significantly reduced EGFR, HER2, and ER alpha expression in ER alpha-positive, but not ER alpha-negative, breast cancer cell lines. Nuclear YB-1 expression was positively correlated with HER2 (P = 0.0153) and negatively correlated with ER alpha (P = 0.0122) and CXCR4 (P = 0.0166) in human breast cancer clinical specimens but was not correlated with EGFR expression. Nuclear YB-1 expression was an independent prognostic factor for overall (P = 0.0139) and progression-free (P = 0.0280) survival. In conclusion, nuclear YB-1 expression might be essential for the acquisition of malignant characteristics via HER2-Akt-dependent pathways in breast cancer patients. The nuclear localization of YB-1 could be an important therapeutic target against not only multidrug resistance but also tumor growth dependent on HER2 and ER alpha.

Standard name | FUJII_YBX1_TARGETS_DN
Systematic name | M14340
Organism | Homo sapiens
PMID | 18316615
Authors | Fujii T,Kawahara A,Basaki Y,Hattori S,Nakashima K,Nakano K,Shirouzu K,Kohno K,Yanagawa T,Yamana H,Nishio K,Ono M,Kuwano M,Kage M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) after knockdown of YBX1 [GeneID=4904] by RNAi.
Full description | In our present study, we examined whether nuclear localization of Y-box binding protein-1 (YB-1) is associated with the expression of epidermal growth factor receptors (EGFR), hormone receptors, and other molecules affecting breast cancer prognosis. The expression of nuclear YB-1, clinicopathologic findings, and molecular markers [EGFR, HER2, estrogen receptor (ER)alpha, ER beta, progesterone receptor, chemokine (C-X-C motif) receptor 4 (CXCR4), phosphorylated Akt, and major vault protein/lung resistance protein] were immunohistochemically analyzed. The association of the expression of nuclear YB-1 and the molecular markers was examined in breast cancer cell lines using microarrays, quantitative real-time PCR, and Western blot analyses. Knockdown of YB-1 with siRNA significantly reduced EGFR, HER2, and ER alpha expression in ER alpha-positive, but not ER alpha-negative, breast cancer cell lines. Nuclear YB-1 expression was positively correlated with HER2 (P = 0.0153) and negatively correlated with ER alpha (P = 0.0122) and CXCR4 (P = 0.0166) in human breast cancer clinical specimens but was not correlated with EGFR expression. Nuclear YB-1 expression was an independent prognostic factor for overall (P = 0.0139) and progression-free (P = 0.0280) survival. In conclusion, nuclear YB-1 expression might be essential for the acquisition of malignant characteristics via HER2-Akt-dependent pathways in breast cancer patients. The nuclear localization of YB-1 could be an important therapeutic target against not only multidrug resistance but also tumor growth dependent on HER2 and ER alpha.

Standard name | OSADA_ASCL1_TARGETS_UP
Systematic name | M8556
Organism | Homo sapiens
PMID | 18339843
Authors | Osada H,Tomida S,Yatabe Y,Tatematsu Y,Takeuchi T,Murakami H,Kondo Y,Sekido Y,Takahashi T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A549 cells (lung cancer) upon expression of ASCL1 [GeneID=429] off a viral vector.
Full description | The proneural basic-helix-loop-helix protein achaete-scute homologue 1 (ASH1) is expressed in a very limited spectrum of normal and cancerous cells in a lineage-specific manner, including normal pulmonary neuroendocrine cells and lung cancer cells with neuroendocrine features. Our previous results indicated that ASH1 may play a crucial role in the growth and survival of lung cancers with neuroendocrine features, which prompted us to investigate the molecular function of ASH1 in relation to its involvement in carcinogenic processes. Herein, we report for the first time that ASH1 functions as a dual transcription factor by activating neuroendocrine differentiation markers and also repressing putative tumor suppressors. This protein was found to inactivate DKK1 and DKK3, negative regulators of Wnt/beta-catenin signaling, E-cadherin, and integrin beta1 through ASH1-mediated deacetylation and repressive trimethylation of lysine 27 (H3K27me3) of histone H3 in the promoter regions of DKK1 and E-cadherin. In addition, ASH1-transduced A549 adenocarcinoma cells exhibited markedly altered morphology characteristics compared with lung cancer cells with neuroendocrine features both in vitro and in vivo and also grew faster in vivo. Our results provide important clues for a better understanding of the molecular and cellular biological roles of ASH1 in the process of carcinogenesis of lung cancers with neuroendocrine features and warrant future investigations to shed light on the lineage-specific dependency of this transcription factor with dual functions.

Standard name | OSADA_ASCL1_TARGETS_DN
Systematic name | M4336
Organism | Homo sapiens
PMID | 18339843
Authors | Osada H,Tomida S,Yatabe Y,Tatematsu Y,Takeuchi T,Murakami H,Kondo Y,Sekido Y,Takahashi T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A549 cells (lung cancer) upon expression of ASCL1 [GeneID=429] off a viral vector.
Full description | The proneural basic-helix-loop-helix protein achaete-scute homologue 1 (ASH1) is expressed in a very limited spectrum of normal and cancerous cells in a lineage-specific manner, including normal pulmonary neuroendocrine cells and lung cancer cells with neuroendocrine features. Our previous results indicated that ASH1 may play a crucial role in the growth and survival of lung cancers with neuroendocrine features, which prompted us to investigate the molecular function of ASH1 in relation to its involvement in carcinogenic processes. Herein, we report for the first time that ASH1 functions as a dual transcription factor by activating neuroendocrine differentiation markers and also repressing putative tumor suppressors. This protein was found to inactivate DKK1 and DKK3, negative regulators of Wnt/beta-catenin signaling, E-cadherin, and integrin beta1 through ASH1-mediated deacetylation and repressive trimethylation of lysine 27 (H3K27me3) of histone H3 in the promoter regions of DKK1 and E-cadherin. In addition, ASH1-transduced A549 adenocarcinoma cells exhibited markedly altered morphology characteristics compared with lung cancer cells with neuroendocrine features both in vitro and in vivo and also grew faster in vivo. Our results provide important clues for a better understanding of the molecular and cellular biological roles of ASH1 in the process of carcinogenesis of lung cancers with neuroendocrine features and warrant future investigations to shed light on the lineage-specific dependency of this transcription factor with dual functions.

Standard name | CHENG_IMPRINTED_BY_ESTRADIOL
Systematic name | M19202
Organism | Homo sapiens
PMID | 18339859
Authors | Cheng AS,Culhane AC,Chan MW,Venkataramu CR,Ehrich M,Nasir A,Rodriguez BA,Liu J,Yan PS,Quackenbush J,Nephew KP,Yeatman TJ,Huang TH
Category | C2
Sub-category | CGP
Brief description | Genes whose CpG islands became hypermethylated in breast progenitor cells pre-exposed to estradiol [PubChem=5757].
Full description | Estrogen imprinting is used to describe a phenomenon in which early developmental exposure to endocrine disruptors increases breast cancer risk later in adult life. We propose that long-lived, self-regenerating stem and progenitor cells are more susceptible to the exposure injury than terminally differentiated epithelial cells in the breast duct. Mammospheres, containing enriched breast progenitors, were used as an exposure system to simulate this imprinting phenomenon in vitro. Using MeDIP-chip, a methylation microarray screening method, we found that 0.5% (120 loci) of human CpG islands were hypermethylated in epithelial cells derived from estrogen-exposed progenitors compared with the non-estrogen-exposed control cells. This epigenetic event may lead to progressive silencing of tumor suppressor genes, including RUNX3, in these epithelial cells, which also occurred in primary breast tumors. Furthermore, normal tissue in close proximity to the tumor site also displayed RUNX3 hypermethylation, suggesting that this aberrant event occurs in early breast carcinogenesis. The high prevalence of estrogen-induced epigenetic changes in primary tumors and the surrounding histologically normal tissues provides the first empirical link between estrogen injury of breast stem/progenitor cells and carcinogenesis. This finding also offers a mechanistic explanation as to why a tumor suppressor gene, such as RUNX3, can be heritably silenced by epigenetic mechanisms in breast cancer.

Standard name | DE_YY1_TARGETS_UP
Systematic name | M2462
Organism | Homo sapiens
PMID | 18339860
Authors | de Nigris F,Rossiello R,Schiano C,Arra C,Williams-Ignarro S,Barbieri A,Lanza A,Balestrieri A,Giuliano MT,Ignarro LJ,Napoli C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SaOS-2 cells (osteosarcoma) upon knockdown of YY1 [GeneID=7528] by RNAi.
Full description | We know that the Yin Yang 1 protein (YY1) overexpression is positively and strongly correlated with the degree of malignancy of bone tumors. Therefore, we questioned whether we could influence cell invasiveness by deleting YY1 in human osteosarcoma cells (SaOs-2), as tested in Matrigel-coated filters and metastasis implantation of such osteosarcoma cells in vivo, by serial analysis with nuclear magnetic resonance. Moreover, we focused our work on the chemokine receptor CXCR4 and its inhibition by T22 antibody, as well as on systemic (direct in vivo assay) and computer-assisted imaging of angiogenesis-related metastasis. Results showed that cell invasiveness and metastasis implantation by wild-type SaOs-2 cells, as evaluated by histology and immunohistochemistry, are associated with up-regulation of CXCR4 expression, which in turn was significantly reduced by T22. In addition, deletion of YY1 (siRNAYY1-SaOs-2) induced a significant decrease of cell invasion and metastasis growth. This phenomenon was associated with decreased vascular endothelial growth factor (VEGF)/angiogenesis and a complex rearrangement of the gene expression profile as evaluated by microarray analysis. In conclusion, YY1 and VEGF/CXCR4 seem to intervene in the pathogenesis of the malignant phenotype of osteosarcoma by acting on cell invasiveness and metastasis growth.

Standard name | DE_YY1_TARGETS_DN
Systematic name | M3278
Organism | Homo sapiens
PMID | 18339860
Authors | de Nigris F,Rossiello R,Schiano C,Arra C,Williams-Ignarro S,Barbieri A,Lanza A,Balestrieri A,Giuliano MT,Ignarro LJ,Napoli C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SaOS-2 cells (osteosarcoma) upon knockdown of YY1 [GeneID=7528] by RNAi.
Full description | We know that the Yin Yang 1 protein (YY1) overexpression is positively and strongly correlated with the degree of malignancy of bone tumors. Therefore, we questioned whether we could influence cell invasiveness by deleting YY1 in human osteosarcoma cells (SaOs-2), as tested in Matrigel-coated filters and metastasis implantation of such osteosarcoma cells in vivo, by serial analysis with nuclear magnetic resonance. Moreover, we focused our work on the chemokine receptor CXCR4 and its inhibition by T22 antibody, as well as on systemic (direct in vivo assay) and computer-assisted imaging of angiogenesis-related metastasis. Results showed that cell invasiveness and metastasis implantation by wild-type SaOs-2 cells, as evaluated by histology and immunohistochemistry, are associated with up-regulation of CXCR4 expression, which in turn was significantly reduced by T22. In addition, deletion of YY1 (siRNAYY1-SaOs-2) induced a significant decrease of cell invasion and metastasis growth. This phenomenon was associated with decreased vascular endothelial growth factor (VEGF)/angiogenesis and a complex rearrangement of the gene expression profile as evaluated by microarray analysis. In conclusion, YY1 and VEGF/CXCR4 seem to intervene in the pathogenesis of the malignant phenotype of osteosarcoma by acting on cell invasiveness and metastasis growth.

Standard name | MCCABE_BOUND_BY_HOXC6
Systematic name | M6376
Organism | Homo sapiens
PMID | 18339881
Authors | McCabe CD,Spyropoulos DD,Martin D,Moreno CS
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters where bound by HOXC6 [GeneID=3223] in LNCaP cells (prostate cancer), according to a ChIP-chip analysis.
Full description | Homeobox transcription factors are developmentally regulated genes that play crucial roles in tissue patterning. Homeobox C6 (HOXC6) is overexpressed in prostate cancers and correlated with cancer progression, but the downstream targets of HOXC6 are largely unknown. We have performed genome-wide localization analysis to identify promoters bound by HOXC6 in prostate cancer cells. This analysis identified 468 reproducibly bound promoters whose associated genes are involved in functions such as cell proliferation and apoptosis. We have complemented these data with expression profiling of prostates from mice with homozygous disruption of the Hoxc6 gene to identify 31 direct regulatory target genes of HOXC6. We show that HOXC6 directly regulates expression of bone morphogenic protein 7, fibroblast growth factor receptor 2, insulin-like growth factor binding protein 3, and platelet-derived growth factor receptor alpha (PDGFRA) in prostate cells and indirectly influences the Notch and Wnt signaling pathways in vivo. We further show that inhibition of PDGFRA reduces proliferation of prostate cancer cells, and that overexpression of HOXC6 can overcome the effects of PDGFRA inhibition. HOXC6 regulates genes with both oncogenic and tumor suppressor activities as well as several genes such as CD44 that are important for prostate branching morphogenesis and metastasis to the bone microenvironment.

Standard name | POS_RESPONSE_TO_HISTAMINE_UP
Systematic name | M1782
Organism | Mus musculus
PMID | 18339882
Authors | Pos Z,Wiener Z,Pocza P,Racz M,Toth S,Darvas Z,Molnar V,Hegyesi H,Falus A
Category | C2
Sub-category | CGP
Brief description | Genes gradually up-regulated by histamine [PubChem=774] in B16-F10 melanoma tumors.
Full description | We previously showed that transgenic enhancement of histamine production in B16-F10 melanomas strongly supports tumor growth in C57BL/6 mice. In the present study, gene expression profiles of transgenic mouse melanomas, secreting different amounts of histamine, were compared by whole genome microarrays. Array results were validated by real-time PCR, and genes showing histamine-affected behavior were further analyzed by immunohistochemistry. Regulation of histamine-coupled genes was investigated by checking the presence and functional integrity of all four known histamine receptors in experimental melanomas and by administering histamine H1 receptor (H1R) and H2 receptor (H2R) antagonists to tumor-bearing mice. Finally, an attempt was made to integrate histamine-affected genes in known gene regulatory circuits by in silico pathway analysis. Our results show that histamine enhances melanoma growth via H1R rather than through H2R. We show that H1R activation suppresses RNA-level expression of the tumor suppressor insulin-like growth factor II receptor (IGF-IIR) and the antiangiogenic matrix protein fibulin-5 (FBLN5), decreases their intracellular protein levels, and also reduces their availability in the plasma membrane and extracellular matrix, respectively. Pathway analysis suggests that because plasma membrane-bound IGF-IIR is required to activate matrix-bound, latent transforming growth factor-beta1, a factor suggested to sustain FBLN5 expression, the data can be integrated in a known antineoplastic regulatory pathway that is suppressed by H1R. On the other hand, we show that engagement of H2R also reduces intracellular protein pools of IGF-IIR and FBLN5, but being a downstream acting posttranslational effect with minimal consequences on exported IGF-IIR and FBLN5 protein levels, H2R is rather irrelevant compared with H1R in melanoma.

Standard name | POS_RESPONSE_TO_HISTAMINE_DN
Systematic name | M1783
Organism | Mus musculus
PMID | 18339882
Authors | Pos Z,Wiener Z,Pocza P,Racz M,Toth S,Darvas Z,Molnar V,Hegyesi H,Falus A
Category | C2
Sub-category | CGP
Brief description | Genes gradually down-regulated by histamine [PubChem=774] in B16-F10 melanoma tumors.
Full description | We previously showed that transgenic enhancement of histamine production in B16-F10 melanomas strongly supports tumor growth in C57BL/6 mice. In the present study, gene expression profiles of transgenic mouse melanomas, secreting different amounts of histamine, were compared by whole genome microarrays. Array results were validated by real-time PCR, and genes showing histamine-affected behavior were further analyzed by immunohistochemistry. Regulation of histamine-coupled genes was investigated by checking the presence and functional integrity of all four known histamine receptors in experimental melanomas and by administering histamine H1 receptor (H1R) and H2 receptor (H2R) antagonists to tumor-bearing mice. Finally, an attempt was made to integrate histamine-affected genes in known gene regulatory circuits by in silico pathway analysis. Our results show that histamine enhances melanoma growth via H1R rather than through H2R. We show that H1R activation suppresses RNA-level expression of the tumor suppressor insulin-like growth factor II receptor (IGF-IIR) and the antiangiogenic matrix protein fibulin-5 (FBLN5), decreases their intracellular protein levels, and also reduces their availability in the plasma membrane and extracellular matrix, respectively. Pathway analysis suggests that because plasma membrane-bound IGF-IIR is required to activate matrix-bound, latent transforming growth factor-beta1, a factor suggested to sustain FBLN5 expression, the data can be integrated in a known antineoplastic regulatory pathway that is suppressed by H1R. On the other hand, we show that engagement of H2R also reduces intracellular protein pools of IGF-IIR and FBLN5, but being a downstream acting posttranslational effect with minimal consequences on exported IGF-IIR and FBLN5 protein levels, H2R is rather irrelevant compared with H1R in melanoma.

Standard name | POS_HISTAMINE_RESPONSE_NETWORK
Systematic name | M1785
Organism | Mus musculus
PMID | 18339882
Authors | Pos Z,Wiener Z,Pocza P,Racz M,Toth S,Darvas Z,Molnar V,Hegyesi H,Falus A
Category | C2
Sub-category | CGP
Brief description | Genes corresponding to the histamine [PubChem=774] response network.
Full description | We previously showed that transgenic enhancement of histamine production in B16-F10 melanomas strongly supports tumor growth in C57BL/6 mice. In the present study, gene expression profiles of transgenic mouse melanomas, secreting different amounts of histamine, were compared by whole genome microarrays. Array results were validated by real-time PCR, and genes showing histamine-affected behavior were further analyzed by immunohistochemistry. Regulation of histamine-coupled genes was investigated by checking the presence and functional integrity of all four known histamine receptors in experimental melanomas and by administering histamine H1 receptor (H1R) and H2 receptor (H2R) antagonists to tumor-bearing mice. Finally, an attempt was made to integrate histamine-affected genes in known gene regulatory circuits by in silico pathway analysis. Our results show that histamine enhances melanoma growth via H1R rather than through H2R. We show that H1R activation suppresses RNA-level expression of the tumor suppressor insulin-like growth factor II receptor (IGF-IIR) and the antiangiogenic matrix protein fibulin-5 (FBLN5), decreases their intracellular protein levels, and also reduces their availability in the plasma membrane and extracellular matrix, respectively. Pathway analysis suggests that because plasma membrane-bound IGF-IIR is required to activate matrix-bound, latent transforming growth factor-beta1, a factor suggested to sustain FBLN5 expression, the data can be integrated in a known antineoplastic regulatory pathway that is suppressed by H1R. On the other hand, we show that engagement of H2R also reduces intracellular protein pools of IGF-IIR and FBLN5, but being a downstream acting posttranslational effect with minimal consequences on exported IGF-IIR and FBLN5 protein levels, H2R is rather irrelevant compared with H1R in melanoma.

Standard name | DAIRKEE_CANCER_PRONE_RESPONSE_E2
Systematic name | M6041
Organism | Homo sapiens
PMID | 18381411
Authors | Dairkee SH,Seok J,Champion S,Sayeed A,Mindrinos M,Xiao W,Davis RW,Goodson WH
Category | C2
Sub-category | CGP
Brief description | 'Cancer prone response profile' (CPRP): genes changed in response to estradiol [PubChem=5757] in epithelial cell cultures from patients at high risk of breast cancer.
Full description | Breast cancer outcome is highly variable. Whether inadvertent exposure to environmental xenobiotics evokes a biological response promoting cancer aggressiveness and a higher probability of tumor recurrence remains unknown. To determine specific molecular alterations which arise in high-risk breast tissue in the presence of the ubiquitous xenoestrogen, bisphenol A (BPA), we used nonmalignant random periareolar fine-needle aspirates in a novel functional assay. Early events induced by BPA in epithelial-stromal cocultures derived from the contralateral tissue of patients with breast cancer included gene expression patterns which facilitate apoptosis evasion, endurance of microenvironmental stress, and cell cycle deregulation without a detectable increase in cell numbers. This BPA response profile was significantly associated with breast tumors characterized by high histologic grade (P < 0.001) and large tumor size (P = 0.002), resulting in decreased recurrence-free patient survival (P < 0.001). Our assays show a biological fingerprint of probable prior exposure to endocrine-disrupting agents, and suggest a scenario in which their presence in the microenvironmental milieu of high-risk breast tissue could play a deterministic role in establishing and maintaining tumor aggressiveness and poor patient outcome.

Standard name | DAIRKEE_CANCER_PRONE_RESPONSE_BPA
Systematic name | M8655
Organism | Homo sapiens
PMID | 18381411
Authors | Dairkee SH,Seok J,Champion S,Sayeed A,Mindrinos M,Xiao W,Davis RW,Goodson WH
Category | C2
Sub-category | CGP
Brief description | 'Cancer prone response profile' (CPRP): genes changed in response to bisphenol A [PubChem=6623] in epithelial cell cultures from patients at high risk of breast cancer.
Full description | Breast cancer outcome is highly variable. Whether inadvertent exposure to environmental xenobiotics evokes a biological response promoting cancer aggressiveness and a higher probability of tumor recurrence remains unknown. To determine specific molecular alterations which arise in high-risk breast tissue in the presence of the ubiquitous xenoestrogen, bisphenol A (BPA), we used nonmalignant random periareolar fine-needle aspirates in a novel functional assay. Early events induced by BPA in epithelial-stromal cocultures derived from the contralateral tissue of patients with breast cancer included gene expression patterns which facilitate apoptosis evasion, endurance of microenvironmental stress, and cell cycle deregulation without a detectable increase in cell numbers. This BPA response profile was significantly associated with breast tumors characterized by high histologic grade (P < 0.001) and large tumor size (P = 0.002), resulting in decreased recurrence-free patient survival (P < 0.001). Our assays show a biological fingerprint of probable prior exposure to endocrine-disrupting agents, and suggest a scenario in which their presence in the microenvironmental milieu of high-risk breast tissue could play a deterministic role in establishing and maintaining tumor aggressiveness and poor patient outcome.

Standard name | DAIRKEE_CANCER_PRONE_RESPONSE_BPA_E2
Systematic name | M18086
Organism | Homo sapiens
PMID | 18381411
Authors | Dairkee SH,Seok J,Champion S,Sayeed A,Mindrinos M,Xiao W,Davis RW,Goodson WH
Category | C2
Sub-category | CGP
Brief description | 'Cancer prone response profile' (CPRP): genes common to estradiol and bisphenol A [PubChem=5757;6623] response of epithelial cell cultures from patients at high risk of breast cancer.
Full description | Breast cancer outcome is highly variable. Whether inadvertent exposure to environmental xenobiotics evokes a biological response promoting cancer aggressiveness and a higher probability of tumor recurrence remains unknown. To determine specific molecular alterations which arise in high-risk breast tissue in the presence of the ubiquitous xenoestrogen, bisphenol A (BPA), we used nonmalignant random periareolar fine-needle aspirates in a novel functional assay. Early events induced by BPA in epithelial-stromal cocultures derived from the contralateral tissue of patients with breast cancer included gene expression patterns which facilitate apoptosis evasion, endurance of microenvironmental stress, and cell cycle deregulation without a detectable increase in cell numbers. This BPA response profile was significantly associated with breast tumors characterized by high histologic grade (P < 0.001) and large tumor size (P = 0.002), resulting in decreased recurrence-free patient survival (P < 0.001). Our assays show a biological fingerprint of probable prior exposure to endocrine-disrupting agents, and suggest a scenario in which their presence in the microenvironmental milieu of high-risk breast tissue could play a deterministic role in establishing and maintaining tumor aggressiveness and poor patient outcome.

Standard name | YAMASHITA_SILENCED_BY_METHYLATION
Systematic name | M1786
Organism | Rattus norvegicus
PMID | 18381416
Authors | Yamashita S,Takahashi S,McDonell N,Watanabe N,Niwa T,Hosoya K,Tsujino Y,Shirai T,Ushijima T
Category | C2
Sub-category | CGP
Brief description | Genes silenced by DNA methylation in prostate cancer cell lines.
Full description | To identify methylation-silenced genes in prostate cancers, a microarray analysis for genes up-regulated by treatment with a demethylating agent, 5-aza-2'-deoxycytidine, was performed using three rat prostate cancer cell lines. Eight genes (Aebp1, Dysf, Gas6, LOC361288, Nnat, Ocm, RGD1308119, and Tgfbr2) were re-expressed at 16-fold or more, and their promoter CpG islands were shown to be densely methylated in the cancer cell lines. From the eight genes, Tgfbr2, a key mediator of transforming growth factor-beta (TGF-beta) signaling that has been strongly implicated in human and rat prostate carcinogenesis, was selected, and its silencing in primary samples was analyzed further. Tgfbr2 was methylated and markedly down-regulated in three of seven 3,2'-dimethyl-4-aminobiphenyl-induced invasive adenocarcinomas in the dorsolateral lobe of the rat prostate. In humans, marked down-regulation of TGFBR2 protein was observed in 12 of 20 high-grade prostatic intraepithelial neoplasia and 36 of 60 prostate cancers. DNA methylation of the human TGFBR2 promoter CpG islands repressed transcription, if present, but neither methylation nor mutation were detected in 27 human prostate cancers analyzed. Methylation silencing of rat Tgfbr2 was associated with histone H3 lysine 9 trimethylation, whereas decreased expression of human TGFBR2 was mainly due to decreased transcription activity, sometimes in concert with histone deacetylation and H3 lysine 27 trimethylation. The identification of methylation silencing of Tgfbr2 in rat prostate cancers, in accordance with TGFBR2 down-regulation in human prostate cancers, will enable us to analyze how aberrant methylation is induced in vivo and identify factors that promote and suppress the induction of aberrant methylation.

Standard name | YAMASHITA_METHYLATED_IN_PROSTATE_CANCER
Systematic name | M14181
Organism | Rattus norvegicus
PMID | 18381416
Authors | Yamashita S,Takahashi S,McDonell N,Watanabe N,Niwa T,Hosoya K,Tsujino Y,Shirai T,Ushijima T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in prostate cancer cell lines after treatment with 5-aza-2'-deoxycytidine (decitabine) [PubChem=451668].
Full description | To identify methylation-silenced genes in prostate cancers, a microarray analysis for genes up-regulated by treatment with a demethylating agent, 5-aza-2'-deoxycytidine, was performed using three rat prostate cancer cell lines. Eight genes (Aebp1, Dysf, Gas6, LOC361288, Nnat, Ocm, RGD1308119, and Tgfbr2) were re-expressed at 16-fold or more, and their promoter CpG islands were shown to be densely methylated in the cancer cell lines. From the eight genes, Tgfbr2, a key mediator of transforming growth factor-beta (TGF-beta) signaling that has been strongly implicated in human and rat prostate carcinogenesis, was selected, and its silencing in primary samples was analyzed further. Tgfbr2 was methylated and markedly down-regulated in three of seven 3,2'-dimethyl-4-aminobiphenyl-induced invasive adenocarcinomas in the dorsolateral lobe of the rat prostate. In humans, marked down-regulation of TGFBR2 protein was observed in 12 of 20 high-grade prostatic intraepithelial neoplasia and 36 of 60 prostate cancers. DNA methylation of the human TGFBR2 promoter CpG islands repressed transcription, if present, but neither methylation nor mutation were detected in 27 human prostate cancers analyzed. Methylation silencing of rat Tgfbr2 was associated with histone H3 lysine 9 trimethylation, whereas decreased expression of human TGFBR2 was mainly due to decreased transcription activity, sometimes in concert with histone deacetylation and H3 lysine 27 trimethylation. The identification of methylation silencing of Tgfbr2 in rat prostate cancers, in accordance with TGFBR2 down-regulation in human prostate cancers, will enable us to analyze how aberrant methylation is induced in vivo and identify factors that promote and suppress the induction of aberrant methylation.

Standard name | OUYANG_PROSTATE_CANCER_PROGRESSION_UP
Systematic name | M15626
Organism | Mus musculus
PMID | 18381418
Authors | Ouyang X,Jessen WJ,Al-Ahmadie H,Serio AM,Lin Y,Shih WJ,Reuter VE,Scardino PT,Shen MM,Aronow BJ,Vickers AJ,Gerald WL,Abate-Shen C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during prostate cancer progression in mice heterozygotic for both NKX3.1 and PTEN [GeneID=4824;5728].
Full description | To identify biomarkers that discriminate the aggressive forms of prostate cancer, we performed gene expression profiling of prostate tumors using a genetically engineered mouse model that recapitulates the stages of human prostate cancer, namely Nkx3.1; Pten mutant mice. We observed a significant deregulation of the epidermal growth factor and mitogen-activated protein kinase (MAPK) signaling pathways, as well as their major downstream effectors--the activator protein-1 transcription factors c-Fos and c-Jun. Forced expression of c-Fos and c-Jun in prostate cancer cells promotes tumorigenicity and results in activation of extracellular signal-regulated kinase (Erk) MAPK signaling. In human prostate cancer, up-regulation of c-Fos and c-Jun proteins occurs in advanced disease and is correlated with Erk MAPK pathway activation, whereas high levels of c-Jun expression are associated with disease recurrence. Our analyses reveal a hitherto unappreciated role for AP-1 transcription factors in prostate cancer progression and identify c-Jun as a marker of high-risk prostate cancer. This study provides a striking example of how accurate mouse models can provide insights on molecular processes involved in progression and recurrence of human cancer.

Standard name | OUYANG_PROSTATE_CANCER_PROGRESSION_DN
Systematic name | M14636
Organism | Mus musculus
PMID | 18381418
Authors | Ouyang X,Jessen WJ,Al-Ahmadie H,Serio AM,Lin Y,Shih WJ,Reuter VE,Scardino PT,Shen MM,Aronow BJ,Vickers AJ,Gerald WL,Abate-Shen C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during prostate cancer progression in mice heterozygotic for both NKX3.1 and PTEN [GeneID=4824;5728].
Full description | To identify biomarkers that discriminate the aggressive forms of prostate cancer, we performed gene expression profiling of prostate tumors using a genetically engineered mouse model that recapitulates the stages of human prostate cancer, namely Nkx3.1; Pten mutant mice. We observed a significant deregulation of the epidermal growth factor and mitogen-activated protein kinase (MAPK) signaling pathways, as well as their major downstream effectors--the activator protein-1 transcription factors c-Fos and c-Jun. Forced expression of c-Fos and c-Jun in prostate cancer cells promotes tumorigenicity and results in activation of extracellular signal-regulated kinase (Erk) MAPK signaling. In human prostate cancer, up-regulation of c-Fos and c-Jun proteins occurs in advanced disease and is correlated with Erk MAPK pathway activation, whereas high levels of c-Jun expression are associated with disease recurrence. Our analyses reveal a hitherto unappreciated role for AP-1 transcription factors in prostate cancer progression and identify c-Jun as a marker of high-risk prostate cancer. This study provides a striking example of how accurate mouse models can provide insights on molecular processes involved in progression and recurrence of human cancer.

Standard name | OUYANG_PROSTATE_CANCER_MARKERS
Systematic name | M9874
Organism | Mus musculus
PMID | 18381418
Authors | Ouyang X,Jessen WJ,Al-Ahmadie H,Serio AM,Lin Y,Shih WJ,Reuter VE,Scardino PT,Shen MM,Aronow BJ,Vickers AJ,Gerald WL,Abate-Shen C
Category | C2
Sub-category | CGP
Brief description | Mouse orthologs of human prostate cancer tumor markers which were deregulated in mice heterozygotic for both NKX3.1 and PTEN [GeneID=4824;5728].
Full description | To identify biomarkers that discriminate the aggressive forms of prostate cancer, we performed gene expression profiling of prostate tumors using a genetically engineered mouse model that recapitulates the stages of human prostate cancer, namely Nkx3.1; Pten mutant mice. We observed a significant deregulation of the epidermal growth factor and mitogen-activated protein kinase (MAPK) signaling pathways, as well as their major downstream effectors--the activator protein-1 transcription factors c-Fos and c-Jun. Forced expression of c-Fos and c-Jun in prostate cancer cells promotes tumorigenicity and results in activation of extracellular signal-regulated kinase (Erk) MAPK signaling. In human prostate cancer, up-regulation of c-Fos and c-Jun proteins occurs in advanced disease and is correlated with Erk MAPK pathway activation, whereas high levels of c-Jun expression are associated with disease recurrence. Our analyses reveal a hitherto unappreciated role for AP-1 transcription factors in prostate cancer progression and identify c-Jun as a marker of high-risk prostate cancer. This study provides a striking example of how accurate mouse models can provide insights on molecular processes involved in progression and recurrence of human cancer.

Standard name | RIGGI_EWING_SARCOMA_PROGENITOR_UP
Systematic name | M15981
Organism | Homo sapiens
PMID | 18381423
Authors | Riggi N,Suvà ML,Suvà D,Cironi L,Provero P,Tercier S,Joseph JM,Stehle JC,Baumer K,Kindler V,Stamenkovic I
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mesenchymal stem cells (MSC) engineered to express EWS-FLI1 [GeneID=2130;2321] fusion protein.
Full description | Ewing's sarcoma family tumors (ESFT) express the EWS-FLI-1 fusion gene generated by the chromosomal translocation t(11;22)(q24;q12). Expression of the EWS-FLI-1 fusion protein in a permissive cellular environment is believed to play a key role in ESFT pathogenesis. However, EWS-FLI-1 induces growth arrest or apoptosis in differentiated primary cells, and the identity of permissive primary human cells that can support its expression and function has until now remained elusive. Here we show that expression of EWS-FLI-1 in human mesenchymal stem cells (hMSC) is not only stably maintained without inhibiting proliferation but also induces a gene expression profile bearing striking similarity to that of ESFT, including genes that are among the highest ESFT discriminators. Expression of EWS-FLI-1 in hMSCs may recapitulate the initial steps of Ewing's sarcoma development, allowing identification of genes that play an important role early in its pathogenesis. Among relevant candidate transcripts induced by EWS-FLI-1 in hMSCs, we found the polycomb group gene EZH2, which we show to play a critical role in Ewing's sarcoma growth. These observations are consistent with our recent findings using mouse mesenchymal progenitor cells and provide compelling evidence that hMSCs are candidate cells of origin of ESFT.

Standard name | RIGGI_EWING_SARCOMA_PROGENITOR_DN
Systematic name | M13256
Organism | Homo sapiens
PMID | 18381423
Authors | Riggi N,Suvà ML,Suvà D,Cironi L,Provero P,Tercier S,Joseph JM,Stehle JC,Baumer K,Kindler V,Stamenkovic I
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mesenchymal stem cells (MSC) engineered to express EWS-FLI1 [GeneID=2130;2321] fusion protein.
Full description | Ewing's sarcoma family tumors (ESFT) express the EWS-FLI-1 fusion gene generated by the chromosomal translocation t(11;22)(q24;q12). Expression of the EWS-FLI-1 fusion protein in a permissive cellular environment is believed to play a key role in ESFT pathogenesis. However, EWS-FLI-1 induces growth arrest or apoptosis in differentiated primary cells, and the identity of permissive primary human cells that can support its expression and function has until now remained elusive. Here we show that expression of EWS-FLI-1 in human mesenchymal stem cells (hMSC) is not only stably maintained without inhibiting proliferation but also induces a gene expression profile bearing striking similarity to that of ESFT, including genes that are among the highest ESFT discriminators. Expression of EWS-FLI-1 in hMSCs may recapitulate the initial steps of Ewing's sarcoma development, allowing identification of genes that play an important role early in its pathogenesis. Among relevant candidate transcripts induced by EWS-FLI-1 in hMSCs, we found the polycomb group gene EZH2, which we show to play a critical role in Ewing's sarcoma growth. These observations are consistent with our recent findings using mouse mesenchymal progenitor cells and provide compelling evidence that hMSCs are candidate cells of origin of ESFT.

Standard name | GAUTSCHI_SRC_SIGNALING
Systematic name | M14722
Organism | Homo sapiens
PMID | 18381431
Authors | Gautschi O,Tepper CG,Purnell PR,Izumiya Y,Evans CP,Green TP,Desprez PY,Lara PN,Gandara DR,Mack PC,Kung HJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A549 cells (lung cancer) after treatment with AZD0530 [PubChem=10302451], a SRC [GeneID=6714] kinase inhibitor.
Full description | Deregulated activation of the Src tyrosine kinase and heightened Id1 expression are independent mediators of aggressive tumor biology. The present report implicates Src signaling as a critical regulator of Id1 gene expression. Microarray analyses showed that Id family genes were among the most highly down-regulated by incubation of A549 lung carcinoma cells with the small-molecule Src inhibitor AZD0530. Id1 transcript and protein levels were potently reduced in a dose-dependent manner concomitantly with the reduction of activated Src levels. These effects were conserved across a panel of lung, breast, prostate, and colon cancer cell lines and confirmed by the ability of PP2, Src siRNA, and Src-blocking peptides to suppress Id1 expression. PP2, AZD0530, and dominant-negative Src abrogated Id1 promoter activity, which was induced by constitutively active Src. The Src-responsive region of the Id1 promoter was mapped to a region 1,199 to 1,360 bps upstream of the translation start site and contained a Smad-binding element. Src was also required for bone morphogenetic protein-2 (BMP-2)-induced Id1 expression and promoter activity, was moderately activated by BMP-2, and complexed with Smad1/5. Conversely, Src inhibitors blocked Smad1/5 nuclear translocation and binding to the Src-responsive region of the Id1 promoter. Consistent with a role for Src and Id1 in cancer cell invasion, Src inhibitors and Id1 siRNA decreased cancer cell invasion, which was increased by Id1 overexpression. Taken together, these results reveal that Src positively interacts with the BMP-Smad-Id pathway and provide new ways for targeted inhibition of Id1.

Standard name | VICENT_METASTASIS_UP
Systematic name | M10967
Organism | Homo sapiens
PMID | 18381434
Authors | Vicent S,Luis-Ravelo D,Antón I,García-Tuñón I,Borrás-Cuesta F,Dotor J,Rivas Las De J,Lecanda F
Category | C2
Sub-category | CGP
Brief description | The metastasis gene signature: genes up-regulated during metastasis of NSCLC (non-small cell lung carcinoma) tumors to bone.
Full description | Bone is a frequent target of lung cancer metastasis, which is associated with significant morbidity and a dismal prognosis. To identify and functionally characterize genes involved in the mechanisms of osseous metastasis, we developed a murine lung cancer model. Comparative transcriptomic analysis identified genes encoding signaling molecules (such as TCF4 and PRKD3) and cell anchorage-related proteins (MCAM and SUSD5), some of which were basally modulated by transforming growth factor-beta (TGF-beta) in tumor cells and in conditions mimicking tumor-stromal interactions. Triple gene combinations induced not only high osteoclastogenic activity but also a marked enhancement of global metalloproteolytic activities in vitro. These effects were strongly associated with robust bone colonization in vivo, whereas this gene subset was ineffective in promoting local tumor growth and cell homing activity to bone. Interestingly, global inhibition of metalloproteolytic activities and simultaneous TGF-beta blockade in vivo led to increased survival and a remarkable attenuation of bone tumor burden and osteolytic metastasis. Thus, this metastatic gene signature mediates bone matrix degradation by a dual mechanism of induction of TGF-beta-dependent osteoclastogenic bone resorption and enhancement of stroma-dependent metalloproteolytic activities. Our findings suggest the cooperative contribution of host-derived and cell autonomous effects directed by a small subset of genes in mediating aggressive osseous colonization.

Standard name | AMBROSINI_FLAVOPIRIDOL_TREATMENT_TP53
Systematic name | M8268
Organism | Homo sapiens
PMID | 18381438
Authors | Ambrosini G,Seelman SL,Qin LX,Schwartz GK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by flavopiridol [PubChem=5287969] in the HCT116 cells (colon cancer) depending on their TP53 [GeneID=7157] status: wild-type vs loss of the gene's function (LOF).
Full description | The results of a phase I clinical trial of the topoisomerase I (Topo I) poison CPT-11 followed by the cyclin-dependent kinase inhibitor flavopiridol in patients with advanced solid tumors indicate that patients whose tumors were wild-type, but not mutant, for p53 obtained the most clinical benefit from this combination therapy. We elected to elucidate the mechanistic basis for this effect in isogenic-paired HCT116 colon cancer cells that were either wild-type (+/+) or null (-/-) for p53. With the combination therapy of SN-38 (the active metabolite of CPT-11) followed by flavopiridol, the induction of apoptosis was 5-fold greater in the p53+/+ cells compared with the p53-/- cells. This sequential treatment induced phosphorylation of p53 at Ser(15), which interacted with Rad51, a DNA repair protein involved in homologous recombination. Rad51 bound to p53-Ser(15) within the first 5 hours of combination therapy, and then was transcriptionally suppressed at 24 hours by flavopiridol only in p53+/+ cells. Microarray analysis also revealed suppression of Rad51 in a p53-dependent manner. Depletion of Rad51 by small interfering RNA (siRNA) sensitized both p53+/+ and p53-/- cells to SN-38-induced apoptosis with increase of gamma H2AX, a marker of DNA damage. Conversely, overexpression of Rad51 rescued p53+/+ cells from SN-->F-induced apoptosis. Because flavopiridol inhibits Cdk9, we found that inhibition of Cdk9 by DRB or by siRNA could recapitulate the flavopiridol effects, with suppression of Rad51 and induction of apoptosis only in p53+/+ cells. In conclusion, after DNA damage by Topo I poisons, flavopiridol targets homologous recombination through a p53-dependent down-regulation of Rad51, resulting in enhancement of apoptosis.

Standard name | HANN_RESISTANCE_TO_BCL2_INHIBITOR_UP
Systematic name | M11749
Organism | Homo sapiens
PMID | 18381439
Authors | Hann CL,Daniel VC,Sugar EA,Dobromilskaya I,Murphy SC,Cope L,Lin X,Hierman JS,Wilburn DL,Watkins DN,Rudin CM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SCLC (small cell lung cancer) cells with acquired resistance to ABT-737 [PubChem=11228183], an inhibitor of the BCL2 [GeneID=596] family proteins.
Full description | Bcl-2 is a central regulator of cell survival that is overexpressed in the majority of small cell lung cancers (SCLC) and contributes to both malignant transformation and therapeutic resistance. We compared primary SCLC xenografts prepared from de novo human tumors with standard cell line-based xenografts in the evaluation of a novel and highly potent small molecule inhibitor of Bcl-2, ABT-737. ABT-737 induced dramatic regressions in tumors derived from some SCLC cell lines. In contrast, only one of three primary xenograft SCLC tumors showed significant growth inhibition with ABT-737. Explanations for this apparent dichotomy may include relatively low expression of Bcl-2 in the primary xenografts or inherent differences in the model systems. The addition of etoposide to ABT-737 in the primary xenografts resulted in significant decreases in tumor growth, underscoring the clinical potential of ABT-737 in combination therapy. To identify factors that may contribute to resistance to ABT-737 and related inhibitors, we isolated resistant derivatives of an initially sensitive cell line-based xenograft. Acquired resistance in this model was associated with decreases in the expression of the primary target Bcl-2, of proapoptotic partners of Bcl-2 (Bax and Bim), and of Bcl-2:Bim heterodimers. Expression profiling reveals 85 candidate genes demonstrating consistent changes in gene expression with acquired resistance. Taken together, these data have specific implications for the clinical development of Bcl-2 inhibitors for SCLC and broader implications for the testing of novel anticancer strategies in relevant preclinical models.

Standard name | HANN_RESISTANCE_TO_BCL2_INHIBITOR_DN
Systematic name | M4339
Organism | Homo sapiens
PMID | 18381439
Authors | Hann CL,Daniel VC,Sugar EA,Dobromilskaya I,Murphy SC,Cope L,Lin X,Hierman JS,Wilburn DL,Watkins DN,Rudin CM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SCLC (small cell lung cancer) cells with acquired resistance to ABT-737 [PubChem=11228183], an inhibitor of the BCL2 [GeneID=596] family proteins.
Full description | Bcl-2 is a central regulator of cell survival that is overexpressed in the majority of small cell lung cancers (SCLC) and contributes to both malignant transformation and therapeutic resistance. We compared primary SCLC xenografts prepared from de novo human tumors with standard cell line-based xenografts in the evaluation of a novel and highly potent small molecule inhibitor of Bcl-2, ABT-737. ABT-737 induced dramatic regressions in tumors derived from some SCLC cell lines. In contrast, only one of three primary xenograft SCLC tumors showed significant growth inhibition with ABT-737. Explanations for this apparent dichotomy may include relatively low expression of Bcl-2 in the primary xenografts or inherent differences in the model systems. The addition of etoposide to ABT-737 in the primary xenografts resulted in significant decreases in tumor growth, underscoring the clinical potential of ABT-737 in combination therapy. To identify factors that may contribute to resistance to ABT-737 and related inhibitors, we isolated resistant derivatives of an initially sensitive cell line-based xenograft. Acquired resistance in this model was associated with decreases in the expression of the primary target Bcl-2, of proapoptotic partners of Bcl-2 (Bax and Bim), and of Bcl-2:Bim heterodimers. Expression profiling reveals 85 candidate genes demonstrating consistent changes in gene expression with acquired resistance. Taken together, these data have specific implications for the clinical development of Bcl-2 inhibitors for SCLC and broader implications for the testing of novel anticancer strategies in relevant preclinical models.

Standard name | ENGELMANN_CANCER_PROGENITORS_UP
Systematic name | M13135
Organism | Homo sapiens
PMID | 18381450
Authors | Engelmann K,Shen H,Finn OJ
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the cancer progenitor (stem) cells corresponding to side population (SP) MCF7 cells (breast cancer) positive for MUC1 [GeneID=4582].
Full description | Chemotherapy, radiation, and growth inhibitory drugs preferentially eliminate actively growing cancer cells. Cancer recurrence is currently thought to be due to nondividing cancer stem/progenitor cells that are resistant to these therapies. Different therapeutic approaches need to be considered for the elimination of the cancer stem cell population. Immunotherapy is one such approach. In addition to specificity and lack of toxicity, immunotherapy targets cancer cells irrespective of their state of proliferation, as long as they express particular tumor antigens. For that reason, it is important to examine if the tumor antigens that are currently being tested as immunotherapeutic agents are also present on cancer stem cells. This study aimed to determine if one well-known tumor antigen, MUC1, which is being tested as an immunotherapy target on tumor cells, is also expressed on the quiescent cancer stem/progenitor cells. We used the so-called side population (SP) cells found in the MCF7 breast cancer cell line, which we first confirmed by cell surface markers and gene profiling to be highly enriched in cells that fulfill specific functional, phenotypic, and molecular criteria for being tumor stem/progenitor cells. We show that these cells express MUC1 and give rise to MUC1(+) tumors in vivo, which maintain the MUC1(+) SP population. MUC1 on SP cells is hypoglycosylated and heavily sialylated; the characteristics of the tumor-specific form were expressed on mature cancer cells and recognized by tumor-specific T cells and antibodies. This suggests that stem/progenitor cells, like mature tumor cells, would be targets of MUC1-directed immunotherapy.

Standard name | ENGELMANN_CANCER_PROGENITORS_DN
Systematic name | M9246
Organism | Homo sapiens
PMID | 18381450
Authors | Engelmann K,Shen H,Finn OJ
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the cancer progenitor (stem) cells corresponding to side population (SP) MCF7 cells (breast cancer) positive for MUC1 [GeneID=4582].
Full description | Chemotherapy, radiation, and growth inhibitory drugs preferentially eliminate actively growing cancer cells. Cancer recurrence is currently thought to be due to nondividing cancer stem/progenitor cells that are resistant to these therapies. Different therapeutic approaches need to be considered for the elimination of the cancer stem cell population. Immunotherapy is one such approach. In addition to specificity and lack of toxicity, immunotherapy targets cancer cells irrespective of their state of proliferation, as long as they express particular tumor antigens. For that reason, it is important to examine if the tumor antigens that are currently being tested as immunotherapeutic agents are also present on cancer stem cells. This study aimed to determine if one well-known tumor antigen, MUC1, which is being tested as an immunotherapy target on tumor cells, is also expressed on the quiescent cancer stem/progenitor cells. We used the so-called side population (SP) cells found in the MCF7 breast cancer cell line, which we first confirmed by cell surface markers and gene profiling to be highly enriched in cells that fulfill specific functional, phenotypic, and molecular criteria for being tumor stem/progenitor cells. We show that these cells express MUC1 and give rise to MUC1(+) tumors in vivo, which maintain the MUC1(+) SP population. MUC1 on SP cells is hypoglycosylated and heavily sialylated; the characteristics of the tumor-specific form were expressed on mature cancer cells and recognized by tumor-specific T cells and antibodies. This suggests that stem/progenitor cells, like mature tumor cells, would be targets of MUC1-directed immunotherapy.

Standard name | WORSCHECH_TUMOR_REJECTION_UP
Systematic name | M1787
Organism | Mus musculus
PMID | 18381452
Authors | Worschech A,Kmieciak M,Knutson KL,Bear HD,Szalay AA,Wang E,Marincola FM,Manjili MH
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes defining rejection of mammary carcinoma (MMC) tumors.
Full description | We have previously shown T-cell-mediated rejection of the neu-overexpressing mammary carcinoma cells (MMC) in wild-type FVB mice. However, following rejection of primary tumors, a fraction of animals experienced a recurrence of a neu antigen-negative variant (ANV) of MMC (tumor evasion model) after a long latency period. In the present study, we determined that T cells derived from wild-type FVB mice can specifically recognize MMC by secreting IFN-gamma and can induce apoptosis of MMC in vitro. Neu transgenic (FVBN202) mice develop spontaneous tumors and cannot reject it (tumor tolerance model). To dissect the mechanisms associated with rejection or tolerance of MMC tumors, we compared transcriptional patterns within the tumor microenvironment of MMC undergoing rejection with those that resisted it either because of tumor evasion/antigen loss recurrence (ANV tumors) or because of intrinsic tolerance mechanisms displayed by the transgenic mice. Gene profiling confirmed that immune rejection is primarily mediated through activation of IFN-stimulated genes and T-cell effector mechanisms. The tumor evasion model showed combined activation of Th1 and Th2 with a deviation toward Th2 and humoral immune responses that failed to achieve rejection likely because of lack of target antigen. Interestingly, the tumor tolerance model instead displayed immune suppression pathways through activation of regulatory mechanisms that included in particular the overexpression of interleukin-10 (IL-10), IL-10 receptor, and suppressor of cytokine signaling (SOCS)-1 and SOCS-3. These data provide a road map for the identification of novel biomarkers of immune responsiveness in clinical trials.

Standard name | WORSCHECH_TUMOR_REJECTION_DN
Systematic name | M1789
Organism | Mus musculus
PMID | 18381452
Authors | Worschech A,Kmieciak M,Knutson KL,Bear HD,Szalay AA,Wang E,Marincola FM,Manjili MH
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes defining rejection of mammary carcinoma (MMC) tumors.
Full description | We have previously shown T-cell-mediated rejection of the neu-overexpressing mammary carcinoma cells (MMC) in wild-type FVB mice. However, following rejection of primary tumors, a fraction of animals experienced a recurrence of a neu antigen-negative variant (ANV) of MMC (tumor evasion model) after a long latency period. In the present study, we determined that T cells derived from wild-type FVB mice can specifically recognize MMC by secreting IFN-gamma and can induce apoptosis of MMC in vitro. Neu transgenic (FVBN202) mice develop spontaneous tumors and cannot reject it (tumor tolerance model). To dissect the mechanisms associated with rejection or tolerance of MMC tumors, we compared transcriptional patterns within the tumor microenvironment of MMC undergoing rejection with those that resisted it either because of tumor evasion/antigen loss recurrence (ANV tumors) or because of intrinsic tolerance mechanisms displayed by the transgenic mice. Gene profiling confirmed that immune rejection is primarily mediated through activation of IFN-stimulated genes and T-cell effector mechanisms. The tumor evasion model showed combined activation of Th1 and Th2 with a deviation toward Th2 and humoral immune responses that failed to achieve rejection likely because of lack of target antigen. Interestingly, the tumor tolerance model instead displayed immune suppression pathways through activation of regulatory mechanisms that included in particular the overexpression of interleukin-10 (IL-10), IL-10 receptor, and suppressor of cytokine signaling (SOCS)-1 and SOCS-3. These data provide a road map for the identification of novel biomarkers of immune responsiveness in clinical trials.

Standard name | HUANG_FOXA2_TARGETS_UP
Systematic name | M15326
Organism | Homo sapiens
PMID | 18593902
Authors | Huang G,Eisenberg R,Yan M,Monti S,Lawrence E,Fu P,Walbroehl J,Löwenberg E,Golub T,Merchan J,Tenen DG,Markowitz SD,Halmos B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in H358 cells (lung cancer) by inducible expression of FOXA2 [GeneID=3170] in a Tet-off system.
Full description | The forkhead transcription factor hepatocyte nuclear factor 3beta (HNF3beta) is essential in foregut development and the regulation of lung-specific genes. HNF3beta expression leads to growth arrest and apoptosis in lung cancer cells and HNF3beta is a candidate tumor suppressor in lung cancer. In a transcriptional profiling study using a conditional cell line system, we now identify 15-PGDH as one of the major genes induced by HNF3beta expression. 15-PGDH is a critical metabolic enzyme of proliferative prostaglandins, an antagonist to cyclooxygenase-2 and a tumor suppressor in colon cancer. We confirmed the regulation of 15-PGDH expression by HNF3beta in a number of systems and showed direct binding of HNF3beta to 15-PGDH promoter elements. Western blotting of lung cancer cell lines and immunohistochemical examination of human lung cancer tissues found loss of 15-PGDH expression in approximately 65% of lung cancers. Further studies using in vitro cell-based assays and in vivo xenograft tumorigenesis assays showed a lack of in vitro but significant in vivo tumor suppressor activity of 15-PGDH via an antiangiogenic mechanism analogous to its role in colon cancer. In summary, we identify 15-PGDH as a direct downstream effector of HNF3beta and show that 15-PGDH acts as a tumor suppressor in lung cancer.

Standard name | HUANG_FOXA2_TARGETS_DN
Systematic name | M16701
Organism | Homo sapiens
PMID | 18593902
Authors | Huang G,Eisenberg R,Yan M,Monti S,Lawrence E,Fu P,Walbroehl J,Löwenberg E,Golub T,Merchan J,Tenen DG,Markowitz SD,Halmos B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in H358 cells (lung cancer) by inducible expression of FOXA2 [GeneID=3170] in a Tet-off system.
Full description | The forkhead transcription factor hepatocyte nuclear factor 3beta (HNF3beta) is essential in foregut development and the regulation of lung-specific genes. HNF3beta expression leads to growth arrest and apoptosis in lung cancer cells and HNF3beta is a candidate tumor suppressor in lung cancer. In a transcriptional profiling study using a conditional cell line system, we now identify 15-PGDH as one of the major genes induced by HNF3beta expression. 15-PGDH is a critical metabolic enzyme of proliferative prostaglandins, an antagonist to cyclooxygenase-2 and a tumor suppressor in colon cancer. We confirmed the regulation of 15-PGDH expression by HNF3beta in a number of systems and showed direct binding of HNF3beta to 15-PGDH promoter elements. Western blotting of lung cancer cell lines and immunohistochemical examination of human lung cancer tissues found loss of 15-PGDH expression in approximately 65% of lung cancers. Further studies using in vitro cell-based assays and in vivo xenograft tumorigenesis assays showed a lack of in vitro but significant in vivo tumor suppressor activity of 15-PGDH via an antiangiogenic mechanism analogous to its role in colon cancer. In summary, we identify 15-PGDH as a direct downstream effector of HNF3beta and show that 15-PGDH acts as a tumor suppressor in lung cancer.

Standard name | MASRI_RESISTANCE_TO_TAMOXIFEN_AND_AROMATASE_INHIBITORS_UP
Systematic name | M9611
Organism | Homo sapiens
PMID | 18559539
Authors | Masri S,Phung S,Wang X,Wu X,Yuan YC,Wagman L,Chen S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in derivatives of MCF-7aro cells (breast cancer) that developed resistance to tamoxifen [PubChem=5376] or inhibitors of aromatase (CYP19A1) [GeneID=1588].
Full description | Acquired resistance to either tamoxifen or aromatase inhibitors (AI) develops after prolonged treatment in a majority of hormone-responsive breast cancers. In an attempt to further elucidate mechanisms of acquired resistance to AIs, MCF-7aro cells resistant to letrozole (T+LET R), anastrozole (T+ANA R), and exemestane (T+EXE R), as well as long-term estrogen deprived (LTEDaro) and tamoxifen-resistant (T+TAM R) lines were generated. This is the first complete panel of endocrine therapy-resistant cell lines, which were generated as multiple independent biological replicates for unbiased genome-wide analysis using affymetrix microarrays. Although similarities are apparent, microarray results clearly show gene signatures unique to AI-resistance were inherently different from LTEDaro and T+TAM R gene expression profiles. Based on hierarchical clustering, unique estrogen-responsive gene signatures vary depending on cell line, with some genes up-regulated in all lines versus other genes up-regulated only in the AI-resistant lines. Characterization of these resistant lines showed that LTEDaro, T+LET R, and T+ANA R cells contained a constitutively active estrogen receptor (ER)alpha that does not require estrogen for activation. This ligand-independent activation of ER was not observed in the parental cells, as well as T+EXE R and T+TAM R cells. Further characterization of these resistant lines was performed using cell cycle analysis, immunofluorescence experiments to visualize ER subcellular localization, as well as cross-resistance studies to determine second-line inhibitor response. Using this well-defined model system, our studies provide important information regarding differences in resistance mechanisms to AIs, TAM, and LTEDaro, which are critical in overcoming resistance when treating hormone-responsive breast cancers.

Standard name | MASRI_RESISTANCE_TO_TAMOXIFEN_AND_AROMATASE_INHIBITORS_DN
Systematic name | M1991
Organism | Homo sapiens
PMID | 18559539
Authors | Masri S,Phung S,Wang X,Wu X,Yuan YC,Wagman L,Chen S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in derivatives of MCF-7aro cells (breast cancer) that developed resistance to tamoxifen [PubChem=5376] or inhibitors of aromatase (CYP19A1) [GeneID=1588].
Full description | Acquired resistance to either tamoxifen or aromatase inhibitors (AI) develops after prolonged treatment in a majority of hormone-responsive breast cancers. In an attempt to further elucidate mechanisms of acquired resistance to AIs, MCF-7aro cells resistant to letrozole (T+LET R), anastrozole (T+ANA R), and exemestane (T+EXE R), as well as long-term estrogen deprived (LTEDaro) and tamoxifen-resistant (T+TAM R) lines were generated. This is the first complete panel of endocrine therapy-resistant cell lines, which were generated as multiple independent biological replicates for unbiased genome-wide analysis using affymetrix microarrays. Although similarities are apparent, microarray results clearly show gene signatures unique to AI-resistance were inherently different from LTEDaro and T+TAM R gene expression profiles. Based on hierarchical clustering, unique estrogen-responsive gene signatures vary depending on cell line, with some genes up-regulated in all lines versus other genes up-regulated only in the AI-resistant lines. Characterization of these resistant lines showed that LTEDaro, T+LET R, and T+ANA R cells contained a constitutively active estrogen receptor (ER)alpha that does not require estrogen for activation. This ligand-independent activation of ER was not observed in the parental cells, as well as T+EXE R and T+TAM R cells. Further characterization of these resistant lines was performed using cell cycle analysis, immunofluorescence experiments to visualize ER subcellular localization, as well as cross-resistance studies to determine second-line inhibitor response. Using this well-defined model system, our studies provide important information regarding differences in resistance mechanisms to AIs, TAM, and LTEDaro, which are critical in overcoming resistance when treating hormone-responsive breast cancers.

Standard name | MISHRA_CARCINOMA_ASSOCIATED_FIBROBLAST_UP
Systematic name | M18292
Organism | Homo sapiens
PMID | 18519693
Authors | Mishra PJ,Humeniuk R,Medina DJ,Alexe G,Mesirov JP,Ganesan S,Glod JW,Banerjee D
Category | C2
Sub-category | CGP
Brief description | Top genes up-regulated in mesenchyme stem cells (MSC) grown in a tumor conditioned medium, which leads to carcinoma-associated fibroblast phenotype.
Full description | Carcinoma-associated fibroblasts (CAF) have recently been implicated in important aspects of epithelial solid tumor biology, such as neoplastic progression, tumor growth, angiogenesis, and metastasis. However, neither the source of CAFs nor the differences between CAFs and fibroblasts from nonneoplastic tissue have been well defined. In this study, we show that human bone marrow-derived mesenchymal stem cells (hMSCs) exposed to tumor-conditioned medium (TCM) over a prolonged period of time assume a CAF-like myofibroblastic phenotype. More importantly, these cells exhibit functional properties of CAFs, including sustained expression of stromal-derived factor-1 (SDF-1) and the ability to promote tumor cell growth both in vitro and in an in vivo coimplantation model, and expression of myofibroblast markers, including alpha-smooth muscle actin and fibroblast surface protein. hMSCs induced to differentiate to a myofibroblast-like phenotype using 5-azacytidine do not promote tumor cell growth as efficiently as hMSCs cultured in TCM nor do they show increased SDF-1 expression. Furthermore, gene expression profiling revealed similarities between TCM-exposed hMSCs and CAFs. Taken together, these data suggest that hMSCs are a source of CAFs and can be used in the modeling of tumor-stroma interactions. To our knowledge, this is the first report showing that hMSCs become activated and resemble carcinoma-associated myofibroblasts on prolonged exposure to conditioned medium from MDAMB231 human breast cancer cells.

Standard name | MCCABE_HOXC6_TARGETS_UP
Systematic name | M16591
Organism | Mus musculus
PMID | 18339881
Authors | McCabe CD,Spyropoulos DD,Martin D,Moreno CS
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by HOXC6 [GeneID=3223] in LNCaP cells (prostate cancer) and up-regulated upon loss of function (LOF) of HOXC6.
Full description | Homeobox transcription factors are developmentally regulated genes that play crucial roles in tissue patterning. Homeobox C6 (HOXC6) is overexpressed in prostate cancers and correlated with cancer progression, but the downstream targets of HOXC6 are largely unknown. We have performed genome-wide localization analysis to identify promoters bound by HOXC6 in prostate cancer cells. This analysis identified 468 reproducibly bound promoters whose associated genes are involved in functions such as cell proliferation and apoptosis. We have complemented these data with expression profiling of prostates from mice with homozygous disruption of the Hoxc6 gene to identify 31 direct regulatory target genes of HOXC6. We show that HOXC6 directly regulates expression of bone morphogenic protein 7, fibroblast growth factor receptor 2, insulin-like growth factor binding protein 3, and platelet-derived growth factor receptor alpha (PDGFRA) in prostate cells and indirectly influences the Notch and Wnt signaling pathways in vivo. We further show that inhibition of PDGFRA reduces proliferation of prostate cancer cells, and that overexpression of HOXC6 can overcome the effects of PDGFRA inhibition. HOXC6 regulates genes with both oncogenic and tumor suppressor activities as well as several genes such as CD44 that are important for prostate branching morphogenesis and metastasis to the bone microenvironment.

Standard name | MCCABE_HOXC6_TARGETS_DN
Systematic name | M5465
Organism | Mus musculus
PMID | 18339881
Authors | McCabe CD,Spyropoulos DD,Martin D,Moreno CS
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by HOXC6 [GeneID=3223] in LNCaP cells (prostate cancer) and down-regulated upon loss of function (LOF) of HOXC6.
Full description | Homeobox transcription factors are developmentally regulated genes that play crucial roles in tissue patterning. Homeobox C6 (HOXC6) is overexpressed in prostate cancers and correlated with cancer progression, but the downstream targets of HOXC6 are largely unknown. We have performed genome-wide localization analysis to identify promoters bound by HOXC6 in prostate cancer cells. This analysis identified 468 reproducibly bound promoters whose associated genes are involved in functions such as cell proliferation and apoptosis. We have complemented these data with expression profiling of prostates from mice with homozygous disruption of the Hoxc6 gene to identify 31 direct regulatory target genes of HOXC6. We show that HOXC6 directly regulates expression of bone morphogenic protein 7, fibroblast growth factor receptor 2, insulin-like growth factor binding protein 3, and platelet-derived growth factor receptor alpha (PDGFRA) in prostate cells and indirectly influences the Notch and Wnt signaling pathways in vivo. We further show that inhibition of PDGFRA reduces proliferation of prostate cancer cells, and that overexpression of HOXC6 can overcome the effects of PDGFRA inhibition. HOXC6 regulates genes with both oncogenic and tumor suppressor activities as well as several genes such as CD44 that are important for prostate branching morphogenesis and metastasis to the bone microenvironment.

Standard name | TING_SILENCED_BY_DICER
Systematic name | M8943
Organism | Homo sapiens
PMID | 18413723
Authors | Ting AH,Suzuki H,Cope L,Schuebel KE,Lee BH,Toyota M,Imai K,Shinomura Y,Tokino T,Baylin SB
Category | C2
Sub-category | CGP
Brief description | Epigenetically silenced genes up-regulated in HCT116 cells (colon cancer) hypomorphic for DICER1 [GeneID=23405].
Full description | Promoter hypermethylation is a prevalent phenomenon, found in virtually all cancer types studied thus far, and accounts for tumor suppressor gene silencing in the absence of genetic mutations. The mechanism behind the establishment and maintenance of such aberrant hypermethylation has been under intense study. Here, we have uncovered a link between aberrant gene silencing associated with promoter CpG island DNA methylation and the siRNA/miRNA processing enzyme, DICER, in human cancer cells. By comparing demethylated HCT116 colon cancer cells with HCT116 cells genetically rendered hypomorphic for DICER, we identified a group of epigenetically silenced genes that became reactivated in the absence of functional DICER. This reactivation is associated with a dramatic loss of localized promoter DNA hypermethylation. Thus, intact DICER is required to maintain full promoter DNA hypermethylation of select epigenetically silenced loci in human cancer cells.

Standard name | BOYERINAS_ONCOFETAL_TARGETS_OF_LET7A1
Systematic name | M9626
Organism | Homo sapiens
PMID | 18413726
Authors | Boyerinas B,Park SM,Shomron N,Hedegaard MM,Vinther J,Andersen JS,Feig C,Xu J,Burge CB,Peter ME
Category | C2
Sub-category | CGP
Brief description | Embryonic genes targeted by LET7A1 [GeneID=406881] and which are up-regulated in many human cancers.
Full description | MicroRNAs (miRNA) are small RNA molecules of approximately 20 to 22 nucleotides that reduce expression of proteins through mRNA degradation and/or translational silencing. Each known miRNA has a large number of predicted targets. Members of the let-7/miR-98 family of miRNAs are up-regulated at the end of embryonic development. Let-7 is often down-regulated early during cancer development, suggesting that let-7-regulated oncofetal genes (LOG) may become reexpressed in cancer cells. Using comparative bioinformatics, we have identified 12 conserved LOGs that include HMGA2 and IMP-1/CRD-BP. IMP-1 has growth-promoting activities through stabilization of c-myc mRNA. We experimentally confirmed that IMP-1 is a direct let-7 target that promotes cell growth and motility of tumor cells, and we confirmed by proteomics analysis that IMP-1 and HMGA2 are major miRNA targets. Our data suggest that a substantial part of the growth inhibitory activities of let-7 comes from suppressing the expression of IMP-1. LOGs could be novel therapeutic targets and potential biomarkers for cancer treatment.

Standard name | MCCABE_HOXC6_TARGETS_CANCER_UP
Systematic name | M15456
Organism | Homo sapiens
PMID | 18339881
Authors | McCabe CD,Spyropoulos DD,Martin D,Moreno CS
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters were bound by HOXC6 [GeneID=3223] in LNCaP cells (prostate cancer) and which were up-regulated in comparison of tumor vs normal prostate tissue samples.
Full description | Homeobox transcription factors are developmentally regulated genes that play crucial roles in tissue patterning. Homeobox C6 (HOXC6) is overexpressed in prostate cancers and correlated with cancer progression, but the downstream targets of HOXC6 are largely unknown. We have performed genome-wide localization analysis to identify promoters bound by HOXC6 in prostate cancer cells. This analysis identified 468 reproducibly bound promoters whose associated genes are involved in functions such as cell proliferation and apoptosis. We have complemented these data with expression profiling of prostates from mice with homozygous disruption of the Hoxc6 gene to identify 31 direct regulatory target genes of HOXC6. We show that HOXC6 directly regulates expression of bone morphogenic protein 7, fibroblast growth factor receptor 2, insulin-like growth factor binding protein 3, and platelet-derived growth factor receptor alpha (PDGFRA) in prostate cells and indirectly influences the Notch and Wnt signaling pathways in vivo. We further show that inhibition of PDGFRA reduces proliferation of prostate cancer cells, and that overexpression of HOXC6 can overcome the effects of PDGFRA inhibition. HOXC6 regulates genes with both oncogenic and tumor suppressor activities as well as several genes such as CD44 that are important for prostate branching morphogenesis and metastasis to the bone microenvironment.

Standard name | MCCABE_HOXC6_TARGETS_CANCER_DN
Systematic name | M13626
Organism | Homo sapiens
PMID | 18339881
Authors | McCabe CD,Spyropoulos DD,Martin D,Moreno CS
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters were bound by HOXC6 [GeneID=3223] in LNCaP cells (prostate cancer) and which were down-regulated in comparison of tumor vs normal prostate tissue samples.
Full description | Homeobox transcription factors are developmentally regulated genes that play crucial roles in tissue patterning. Homeobox C6 (HOXC6) is overexpressed in prostate cancers and correlated with cancer progression, but the downstream targets of HOXC6 are largely unknown. We have performed genome-wide localization analysis to identify promoters bound by HOXC6 in prostate cancer cells. This analysis identified 468 reproducibly bound promoters whose associated genes are involved in functions such as cell proliferation and apoptosis. We have complemented these data with expression profiling of prostates from mice with homozygous disruption of the Hoxc6 gene to identify 31 direct regulatory target genes of HOXC6. We show that HOXC6 directly regulates expression of bone morphogenic protein 7, fibroblast growth factor receptor 2, insulin-like growth factor binding protein 3, and platelet-derived growth factor receptor alpha (PDGFRA) in prostate cells and indirectly influences the Notch and Wnt signaling pathways in vivo. We further show that inhibition of PDGFRA reduces proliferation of prostate cancer cells, and that overexpression of HOXC6 can overcome the effects of PDGFRA inhibition. HOXC6 regulates genes with both oncogenic and tumor suppressor activities as well as several genes such as CD44 that are important for prostate branching morphogenesis and metastasis to the bone microenvironment.

Standard name | MOLENAAR_TARGETS_OF_CCND1_AND_CDK4_UP
Systematic name | M11763
Organism | Homo sapiens
PMID | 18413728
Authors | Molenaar JJ,Ebus ME,Koster J,van Sluis P,van Noesel CJ,Versteeg R,Caron HN
Category | C2
Sub-category | CGP
Brief description | Genes commonly up-regulated in SK-N-BE cells (neuroblastoma) after RNAi knockdown of CCND1 and CDK4 [GeneID=595;1019].
Full description | Genomic aberrations of Cyclin D1 (CCND1), CDK4, and CDK6 in neuroblastoma indicate that dysregulation of the G(1) entry checkpoint is an important cell cycle aberration in this pediatric tumor. Here, we report that analysis of Affymetrix expression data of primary neuroblastic tumors shows an extensive overexpression of Cyclin D1, which correlates with histologic subgroups. Immunohistochemical analysis showed overexpression of Cyclin D1 in neuroblasts and low Cyclin D1 expression in all cell types in ganglioneuroma. This suggests an involvement of G(1)-regulating genes in neuronal differentiation processes which we further evaluated using RNA interference against Cyclin D1 and its kinase partners CDK4 and CDK6 in several neuroblastoma cell lines. The Cyclin D1 and CDK4 knockdown resulted in pRb pathway inhibition as shown by an almost complete disappearance of CDK4/CDK6-specific pRb phosphorylation, reduction of E2F transcriptional activity, and a decrease of Cyclin A protein levels. Phenotype analysis showed a significant reduction in cell proliferation, a G(1)-specific cell cycle arrest, and, moreover, an extensive neuronal differentiation. Affymetrix microarray profiling of small interfering RNA-treated cells revealed a shift in expression profile toward a neuronal phenotype. Several new potential downstream players are identified. We conclude that neuroblastoma functionally depend on overexpression of G(1)-regulating genes to maintain their undifferentiated phenotype.

Standard name | MOLENAAR_TARGETS_OF_CCND1_AND_CDK4_DN
Systematic name | M12661
Organism | Homo sapiens
PMID | 18413728
Authors | Molenaar JJ,Ebus ME,Koster J,van Sluis P,van Noesel CJ,Versteeg R,Caron HN
Category | C2
Sub-category | CGP
Brief description | Genes commonly down-regulated in SK-N-BE cells (neuroblastoma) after RNAi knockdown of CCND1 and CDK4 [GeneID=595;1019].
Full description | Genomic aberrations of Cyclin D1 (CCND1), CDK4, and CDK6 in neuroblastoma indicate that dysregulation of the G(1) entry checkpoint is an important cell cycle aberration in this pediatric tumor. Here, we report that analysis of Affymetrix expression data of primary neuroblastic tumors shows an extensive overexpression of Cyclin D1, which correlates with histologic subgroups. Immunohistochemical analysis showed overexpression of Cyclin D1 in neuroblasts and low Cyclin D1 expression in all cell types in ganglioneuroma. This suggests an involvement of G(1)-regulating genes in neuronal differentiation processes which we further evaluated using RNA interference against Cyclin D1 and its kinase partners CDK4 and CDK6 in several neuroblastoma cell lines. The Cyclin D1 and CDK4 knockdown resulted in pRb pathway inhibition as shown by an almost complete disappearance of CDK4/CDK6-specific pRb phosphorylation, reduction of E2F transcriptional activity, and a decrease of Cyclin A protein levels. Phenotype analysis showed a significant reduction in cell proliferation, a G(1)-specific cell cycle arrest, and, moreover, an extensive neuronal differentiation. Affymetrix microarray profiling of small interfering RNA-treated cells revealed a shift in expression profile toward a neuronal phenotype. Several new potential downstream players are identified. We conclude that neuroblastoma functionally depend on overexpression of G(1)-regulating genes to maintain their undifferentiated phenotype.

Standard name | ACEVEDO_NORMAL_TISSUE_ADJACENT_TO_LIVER_TUMOR_UP
Systematic name | M2480
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in normal tissue adjacent to liver tumor, compared to the normal liver samples.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | ACEVEDO_NORMAL_TISSUE_ADJACENT_TO_LIVER_TUMOR_DN
Systematic name | M11156
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in normal tissue adjacent to liver tumor, compared to the normal liver samples.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | ACEVEDO_LIVER_CANCER_UP
Systematic name | M15709
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) compared to normal liver samples.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | ACEVEDO_LIVER_CANCER_DN
Systematic name | M7577
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma (HCC) compared to normal liver samples.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_UP
Systematic name | M4950
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in liver tumor compared to the normal adjacent tissue.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_DN
Systematic name | M13014
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in liver tumor compared to the normal adjacent tissue.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | ACEVEDO_LIVER_CANCER_WITH_H3K27ME3_UP
Systematic name | M11616
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters display higher levels of histone H3 trimethylation mark at K27 (H3K27me3) in hepatocellular carcinoma (HCC) compared to normal liver.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | ACEVEDO_LIVER_CANCER_WITH_H3K27ME3_DN
Systematic name | M16955
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters display lower levels of histone H3 trimethylation mark at K27 (H3K27me3) in hepatocellular carcinoma (HCC) compared to normal liver.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | ACEVEDO_LIVER_CANCER_WITH_H3K9ME3_UP
Systematic name | M6754
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters display higher histone H3 trimethylation mark at K9 (H3K9me3) in hepatocellular carcinoma (HCC) compared to normal liver.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | ACEVEDO_LIVER_CANCER_WITH_H3K9ME3_DN
Systematic name | M8817
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters display lower histone H3 trimethylation mark at K9 (H3K9me3) in hepatocellular carcinoma (HCC) compared to normal liver.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | ACEVEDO_METHYLATED_IN_LIVER_CANCER_DN
Systematic name | M16009
Organism | Homo sapiens
PMID | 18413731
Authors | Acevedo LG,Bieda M,Green R,Farnham PJ
Category | C2
Sub-category | CGP
Brief description | Genes whose DNA is hypo-methylated in hepatocellular carcinoma (HCC) compared to normal liver.
Full description | There is widespread interest in efficient characterization of differences between tumor and normal samples. Here, we show an effective methodology for genome-scale characterization of tumors. Using matched normal and tumor samples from liver cancer patients, as well as non-cancer-related normal liver tissue, we first determined changes in gene expression as monitored on RNA expression arrays. We identified several hundred mRNAs that were consistently changed in the tumor samples. To characterize the mechanisms responsible for creation of the tumor-specific transcriptome, we performed chromatin immunoprecipitation on microarray experiments to assay binding of RNA polymerase II, H3me3K27, and H3me3K9 and DNA methylation in 25,000 promoter regions. These experiments identified changes in active and silenced regions of the genome in the tumor cells. Finally, we used a virtual comparative genomic hybridization method to identify copy number alterations in the tumor samples. Through comparison of RNA polymerase II binding, chromatin structure, DNA methylation, and copy number changes, we suggest that the major contributor to creation of the liver tumor transcriptome was changes in gene copy number.

Standard name | MITSIADES_RESPONSE_TO_APLIDIN_UP
Systematic name | M7928
Organism | Homo sapiens
PMID | 18593922
Authors | Mitsiades CS,Ocio EM,Pandiella A,Maiso P,Gajate C,Garayoa M,Vilanova D,Montero JC,Mitsiades N,McMullan CJ,Munshi NC,Hideshima T,Chauhan D,Aviles P,Otero G,Faircloth G,Mateos MV,Richardson PG,Mollinedo F,San-Miguel JF,Anderson KC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the MM1S cells (multiple myeloma) after treatment with aplidin [PubChem=44152164], a marine-derived compound with potential anti-cancer properties.
Full description | Despite recent progress in its treatment, multiple myeloma (MM) remains incurable, thus necessitating identification of novel anti-MM agents. We report that the marine-derived cyclodepsipeptide Aplidin exhibits, at clinically achievable concentrations, potent in vitro activity against primary MM tumor cells and a broad spectrum of human MM cell lines, including cells resistant to conventional (e.g., dexamethasone, alkylating agents, and anthracyclines) or novel (e.g., thalidomide and bortezomib) anti-MM agents. Aplidin is active against MM cells in the presence of proliferative/antiapoptotic cytokines or bone marrow stromal cells and has additive or synergistic effects with some of the established anti-MM agents. Mechanistically, a short in vitro exposure to Aplidin induces MM cell death, which involves activation of p38 and c-jun NH(2)-terminal kinase signaling, Fas/CD95 translocation to lipid rafts, and caspase activation. The anti-MM effect of Aplidin is associated with suppression of a constellation of proliferative/antiapoptotic genes (e.g., MYC, MYBL2, BUB1, MCM2, MCM4, MCM5, and survivin) and up-regulation of several potential regulators of apoptosis (including c-JUN, TRAIL, CASP9, and Smac). Aplidin exhibited in vivo anti-MM activity in a mouse xenograft model. The profile of the anti-MM activity of Aplidin in our preclinical models provided the framework for its clinical testing in MM, which has already provided favorable preliminary results.

Standard name | MITSIADES_RESPONSE_TO_APLIDIN_DN
Systematic name | M11318
Organism | Homo sapiens
PMID | 18593922
Authors | Mitsiades CS,Ocio EM,Pandiella A,Maiso P,Gajate C,Garayoa M,Vilanova D,Montero JC,Mitsiades N,McMullan CJ,Munshi NC,Hideshima T,Chauhan D,Aviles P,Otero G,Faircloth G,Mateos MV,Richardson PG,Mollinedo F,San-Miguel JF,Anderson KC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the MM1S cells (multiple myeloma) after treatment with aplidin [PubChem=44152164], a marine-derived compound with potential anti-cancer properties.
Full description | Despite recent progress in its treatment, multiple myeloma (MM) remains incurable, thus necessitating identification of novel anti-MM agents. We report that the marine-derived cyclodepsipeptide Aplidin exhibits, at clinically achievable concentrations, potent in vitro activity against primary MM tumor cells and a broad spectrum of human MM cell lines, including cells resistant to conventional (e.g., dexamethasone, alkylating agents, and anthracyclines) or novel (e.g., thalidomide and bortezomib) anti-MM agents. Aplidin is active against MM cells in the presence of proliferative/antiapoptotic cytokines or bone marrow stromal cells and has additive or synergistic effects with some of the established anti-MM agents. Mechanistically, a short in vitro exposure to Aplidin induces MM cell death, which involves activation of p38 and c-jun NH(2)-terminal kinase signaling, Fas/CD95 translocation to lipid rafts, and caspase activation. The anti-MM effect of Aplidin is associated with suppression of a constellation of proliferative/antiapoptotic genes (e.g., MYC, MYBL2, BUB1, MCM2, MCM4, MCM5, and survivin) and up-regulation of several potential regulators of apoptosis (including c-JUN, TRAIL, CASP9, and Smac). Aplidin exhibited in vivo anti-MM activity in a mouse xenograft model. The profile of the anti-MM activity of Aplidin in our preclinical models provided the framework for its clinical testing in MM, which has already provided favorable preliminary results.

Standard name | HOQUE_METHYLATED_IN_CANCER
Systematic name | M19948
Organism | Homo sapiens
PMID | 18413733
Authors | Hoque MO,Kim MS,Ostrow KL,Liu J,Wisman GB,Park HL,Poeta ML,Jeronimo C,Henrique R,Lendvai A,Schuuring E,Begum S,Rosenbaum E,Ongenaert M,Yamashita K,Califano J,Westra W,van der Zee AG,Van Criekinge W,Sidransky D
Category | C2
Sub-category | CGP
Brief description | Genes whose DNA was methylated both in primary tumors and across a panel of cancer cell lines.
Full description | DNA methylation has a role in mediating epigenetic silencing of CpG island genes in cancer and other diseases. Identification of all gene promoters methylated in cancer cells the cancer methylome would greatly advance our understanding of gene regulatory networks in tumorigenesis. We previously described a new method of identifying methylated tumor suppressor genes based on pharmacologic unmasking of the promoter region and detection of re-expression on microarray analysis. In this study, we modified and greatly improved the selection of candidates based on new promoter structure algorithm and microarray data generated from 20 cancer cell lines of 5 major cancer types. We identified a set of 200 candidate genes that cluster throughout the genome of which 25 were previously reported as harboring cancer-specific promoter methylation. The remaining 175 genes were tested for promoter methylation by bisulfite sequencing or methylation-specific PCR (MSP). Eighty-two of 175 (47%) genes were found to be methylated in cell lines, and 53 of these 82 genes (65%) were methylated in primary tumor tissues. From these 53 genes, cancer-specific methylation was identified in 28 genes (28 of 53; 53%). Furthermore, we tested 8 of the 28 newly identified cancer-specific methylated genes with quantitative MSP in a panel of 300 primary tumors representing 13 types of cancer. We found cancer-specific methylation of at least one gene with high frequency in all cancer types. Identification of a large number of genes with cancer-specific methylation provides new targets for diagnostic and therapeutic intervention, and opens fertile avenues for basic research in tumor biology.

Standard name | NADELLA_PRKAR1A_TARGETS_UP
Systematic name | M1790
Organism | Mus musculus
PMID | 18413734
Authors | Nadella KS,Jones GN,Trimboli A,Stratakis CA,Leone G,Kirschner LS
Category | C2
Sub-category | CGP
Brief description | Epithelial and mesenchymal markers up-regulated in MEF cells (embryonic fibroblasts) after knockout of PRKAR1A [GeneID=5573].
Full description | Dysregulation of protein kinase A (PKA) activity, caused by loss of function mutations in PRKAR1A, is known to induce tumor formation in the inherited tumor syndrome Carney complex (CNC) and is also associated with sporadic tumors of the thyroid and adrenal. We have previously shown that Prkar1a(+/-) mice develop schwannomas reminiscent of those seen in CNC and that similar tumors are observed in tissue-specific knockouts (KO) of Prkar1a targeted to the neural crest. Within these tumors, we have previously described the presence of epithelial islands, although the nature of these structures was unclear. In this article, we report that these epithelial structures are derived from KO cells originating in the neural crest. Analysis of the mesenchymal marker vimentin revealed that this protein was markedly down-regulated not only from the epithelial islands, but also from the tumor as a whole, consistent with mesenchymal-to-epithelial transition (MET). In vitro, Prkar1a null primary mouse embryonic fibroblasts, which display constitutive PKA signaling, also showed evidence for MET, with a loss of vimentin and up-regulation of the epithelial marker E-cadherin. Reduction of vimentin protein occurred at the posttranslational level and was rescued by proteasomal inhibition. Finally, this down-regulation of vimentin was recapitulated in the adrenal nodules of CNC patients, confirming an unexpected and previously unrecognized role for PKA in MET.

Standard name | NADELLA_PRKAR1A_TARGETS_DN
Systematic name | M1791
Organism | Mus musculus
PMID | 18413734
Authors | Nadella KS,Jones GN,Trimboli A,Stratakis CA,Leone G,Kirschner LS
Category | C2
Sub-category | CGP
Brief description | Epithelial and mesenchymal markers down-regulated in MEF cells (embryonic fibroblasts) after knockout of PRKAR1A [GeneID=5573].
Full description | Dysregulation of protein kinase A (PKA) activity, caused by loss of function mutations in PRKAR1A, is known to induce tumor formation in the inherited tumor syndrome Carney complex (CNC) and is also associated with sporadic tumors of the thyroid and adrenal. We have previously shown that Prkar1a(+/-) mice develop schwannomas reminiscent of those seen in CNC and that similar tumors are observed in tissue-specific knockouts (KO) of Prkar1a targeted to the neural crest. Within these tumors, we have previously described the presence of epithelial islands, although the nature of these structures was unclear. In this article, we report that these epithelial structures are derived from KO cells originating in the neural crest. Analysis of the mesenchymal marker vimentin revealed that this protein was markedly down-regulated not only from the epithelial islands, but also from the tumor as a whole, consistent with mesenchymal-to-epithelial transition (MET). In vitro, Prkar1a null primary mouse embryonic fibroblasts, which display constitutive PKA signaling, also showed evidence for MET, with a loss of vimentin and up-regulation of the epithelial marker E-cadherin. Reduction of vimentin protein occurred at the posttranslational level and was rescued by proteasomal inhibition. Finally, this down-regulation of vimentin was recapitulated in the adrenal nodules of CNC patients, confirming an unexpected and previously unrecognized role for PKA in MET.

Standard name | SAGIV_CD24_TARGETS_UP
Systematic name | M4144
Organism | Homo sapiens
PMID | 18413748
Authors | Sagiv E,Starr A,Rozovski U,Khosravi R,Altevogt P,Wang T,Arber N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HT29 cells (colon cancer) after knockdown of CD24 [GeneID=100133941] by both RNAi and monoclonal antibodies.
Full description | CD24 is a potential oncogene reported to be overexpressed in a large variety of human malignancies. We have shown that CD24 is overexpressed in 90% of colorectal tumors at a fairly early stage in the multistep process of carcinogenesis. Anti-CD24 monoclonal antibodies (mAb) induce a significant growth inhibition in colorectal and pancreatic cancer cell lines that express the protein. This study is designed to investigate further the effects of CD24 down-regulation using mAb or small interfering RNA in vitro and in vivo. Western blot analysis showed that anti-CD24 mAb induced CD24 protein down-regulation through lysosomal degradation. mAb augmented growth inhibition in combination with five classic chemotherapies. Xenograft models in vivo showed that tumor growth was significantly reduced in mAb-treated mice. Similarly, stable growth inhibition of cancer cell lines was achieved by down-regulation of CD24 expression using short hairpin RNA (shRNA). The produced clones proliferated more slowly, reached lower saturation densities, and showed impaired motility. Most importantly, down-regulation of CD24 retarded tumorigenicity of human cancer cell lines in nude mice. Microarray analysis revealed a similar pattern of gene expression alterations when cells were subjected to anti-CD24 mAb or shRNA. Genes in the Ras pathway, mitogen-activated protein kinase, or BCL-2 family and others of oncogenic association were frequently down-regulated. As a putative new oncogene that is overexpressed in gastrointestinal malignancies early in the carcinogenesis process, CD24 is a potential target for early intervention in the prevention and treatment of cancer.

Standard name | SAGIV_CD24_TARGETS_DN
Systematic name | M15657
Organism | Homo sapiens
PMID | 18413748
Authors | Sagiv E,Starr A,Rozovski U,Khosravi R,Altevogt P,Wang T,Arber N
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HT29 cells (colon cancer) after knockdown of CD24 [GeneID=100133941] by both RNAi and monoclonal antibodies.
Full description | CD24 is a potential oncogene reported to be overexpressed in a large variety of human malignancies. We have shown that CD24 is overexpressed in 90% of colorectal tumors at a fairly early stage in the multistep process of carcinogenesis. Anti-CD24 monoclonal antibodies (mAb) induce a significant growth inhibition in colorectal and pancreatic cancer cell lines that express the protein. This study is designed to investigate further the effects of CD24 down-regulation using mAb or small interfering RNA in vitro and in vivo. Western blot analysis showed that anti-CD24 mAb induced CD24 protein down-regulation through lysosomal degradation. mAb augmented growth inhibition in combination with five classic chemotherapies. Xenograft models in vivo showed that tumor growth was significantly reduced in mAb-treated mice. Similarly, stable growth inhibition of cancer cell lines was achieved by down-regulation of CD24 expression using short hairpin RNA (shRNA). The produced clones proliferated more slowly, reached lower saturation densities, and showed impaired motility. Most importantly, down-regulation of CD24 retarded tumorigenicity of human cancer cell lines in nude mice. Microarray analysis revealed a similar pattern of gene expression alterations when cells were subjected to anti-CD24 mAb or shRNA. Genes in the Ras pathway, mitogen-activated protein kinase, or BCL-2 family and others of oncogenic association were frequently down-regulated. As a putative new oncogene that is overexpressed in gastrointestinal malignancies early in the carcinogenesis process, CD24 is a potential target for early intervention in the prevention and treatment of cancer.

Standard name | SMID_BREAST_CANCER_RELAPSE_IN_BRAIN_UP
Systematic name | M14383
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in brain relapse of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_RELAPSE_IN_BRAIN_DN
Systematic name | M244
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in brain relapse of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_RELAPSE_IN_BONE_UP
Systematic name | M3238
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in bone relapse of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_RELAPSE_IN_BONE_DN
Systematic name | M2700
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in bone relapse of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_RELAPSE_IN_LUNG_UP
Systematic name | M5840
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in lung relapse of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_RELAPSE_IN_LUNG_DN
Systematic name | M11302
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in lung relapse of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_RELAPSE_IN_LIVER_UP
Systematic name | M11159
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in liver relapse of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_RELAPSE_IN_LIVER_DN
Systematic name | M11782
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in liver relapse of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_RELAPSE_IN_PLEURA_UP
Systematic name | M19256
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pleura relapse of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_RELAPSE_IN_PLEURA_DN
Systematic name | M2118
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pleura relapse of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_LUMINAL_B_UP
Systematic name | M12892
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the luminal B subtype of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_LUMINAL_B_DN
Systematic name | M17572
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the luminal B subtype of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_LUMINAL_A_UP
Systematic name | M7517
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the luminal A subtype of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_LUMINAL_A_DN
Systematic name | M13072
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the luminal A subtype of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_ERBB2_UP
Systematic name | M3102
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the erbb2 subype of breast cancer samples, characterized by higher expression of ERBB2 [GeneID=2064].
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_ERBB2_DN
Systematic name | M1219
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the erbb2 subype of breast cancer samples, characterized by higher expression of ERBB2 [GeneID=2064].
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_NORMAL_LIKE_UP
Systematic name | M8513
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the normal-like subtype of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_NORMAL_LIKE_DN
Systematic name | M9564
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the normal-like subtype of breast cancer.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_BASAL_UP
Systematic name | M8124
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in basal subtype of breast cancer samles.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | SMID_BREAST_CANCER_BASAL_DN
Systematic name | M4960
Organism | Homo sapiens
PMID | 18451135
Authors | Smid M,Wang Y,Zhang Y,Sieuwerts AM,Yu J,Klijn JG,Foekens JA,Martens JW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in basal subtype of breast cancer samles.
Full description | We explored whether the five previously reported molecular subtypes in breast cancer show a preference for organ-specific relapse and searched for molecular pathways involved. The intrinsic gene list describing the subtypes was used to classify 344 primary breast tumors of lymph node-negative patients. Fisher exact tests were used to determine the association between a tumor subtype and a particular site of distant relapse in these patients who only received local treatment. Modulated genes and pathways were identified in the various groups using Significance Analysis of Microarrays and Global Testing. Bone relapse patients were most abundant in the luminal subtypes but were found less than expected in the basal subtype. The reverse was true for lung and brain relapse patients with the remark that absence of lung relapse was luminal A specific. Finally, a pleura relapse, although rare, was found almost exclusively in both luminal subtypes. Many differentially expressed genes were identified, of which several were in common in a subtype and the site to which the subtype preferentially relapsed. WNT signaling was up-regulated in the basal subtype and in brain-specific relapse, and down-modulated in the luminal B subtype and in bone-specific relapse. Focal adhesion was found up-regulated in the luminal A subtype but down-regulated in lung relapse. The five major molecular subtypes in breast cancer are evidently different with regard to their ability to metastasize to distant organ(s), and share biological features and pathways with their preferred distant metastatic site.

Standard name | KUMAMOTO_RESPONSE_TO_NUTLIN_3A_UP
Systematic name | M1518
Organism | Homo sapiens
PMID | 18451145
Authors | Kumamoto K,Spillare EA,Fujita K,Horikawa I,Yamashita T,Appella E,Nagashima M,Takenoshita S,Yokota J,Harris CC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in response to nutlin-3a [PubChem=216345], an inhibitor of MDM2 [GeneID=4193], in skin fibroblast cultures after knockdown of TP53 [GeneID=7157] by RNAi.
Full description | Nutlin-3, an MDM2 inhibitor, activates p53, resulting in several types of cancer cells undergoing apoptosis. Although p53 is mutated or deleted in approximately 50% of all cancers, p53 is still functionally active in the other 50%. Consequently, nutlin-3 and similar drugs could be candidates for neoadjuvant therapy in cancers with a functional p53. Cellular senescence is also a phenotype induced by p53 activation and plays a critical role in protecting against tumor development. In this report, we found that nutlin-3a can induce senescence in normal human fibroblasts. Nutlin-3a activated and repressed a large number of p53-dependent genes, including those encoding microRNAs. mir-34a, mir-34b, and mir-34c, which have recently been shown to be downstream effectors of p53-mediated senescence, were up-regulated, and inhibitor of growth 2 (ING2) expression was suppressed by nutlin-3a treatment. Two candidates for a p53-DNA binding consensus sequence were found in the ING2 promoter regulatory region; thus, we performed chromatin immunoprecipitation and electrophoretic mobility shift assays and confirmed p53 binding directly to those sites. In addition, the luciferase activity of a construct containing the ING2 regulatory region was repressed after p53 activation. Antisense knockdown of ING2 induces p53-independent senescence, whereas overexpression of ING2 induces p53-dependent senescence. Taken together, we conclude that nutlin-3a induces senescence through p53 activation in normal human fibroblasts, and p53-mediated mir34a, mir34b, and mir34c up-regulation and ING2 down-regulation may be involved in the senescence pathway.

Standard name | KUMAMOTO_RESPONSE_TO_NUTLIN_3A_DN
Systematic name | M6379
Organism | Homo sapiens
PMID | 18451145
Authors | Kumamoto K,Spillare EA,Fujita K,Horikawa I,Yamashita T,Appella E,Nagashima M,Takenoshita S,Yokota J,Harris CC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in response to nutlin-3a [PubChem=216345], an inhibitor of MDM2 [GeneID=4193], in skin fibroblast cultures after knockdown of TP53 [GeneID=7157] by RNAi.
Full description | Nutlin-3, an MDM2 inhibitor, activates p53, resulting in several types of cancer cells undergoing apoptosis. Although p53 is mutated or deleted in approximately 50% of all cancers, p53 is still functionally active in the other 50%. Consequently, nutlin-3 and similar drugs could be candidates for neoadjuvant therapy in cancers with a functional p53. Cellular senescence is also a phenotype induced by p53 activation and plays a critical role in protecting against tumor development. In this report, we found that nutlin-3a can induce senescence in normal human fibroblasts. Nutlin-3a activated and repressed a large number of p53-dependent genes, including those encoding microRNAs. mir-34a, mir-34b, and mir-34c, which have recently been shown to be downstream effectors of p53-mediated senescence, were up-regulated, and inhibitor of growth 2 (ING2) expression was suppressed by nutlin-3a treatment. Two candidates for a p53-DNA binding consensus sequence were found in the ING2 promoter regulatory region; thus, we performed chromatin immunoprecipitation and electrophoretic mobility shift assays and confirmed p53 binding directly to those sites. In addition, the luciferase activity of a construct containing the ING2 regulatory region was repressed after p53 activation. Antisense knockdown of ING2 induces p53-independent senescence, whereas overexpression of ING2 induces p53-dependent senescence. Taken together, we conclude that nutlin-3a induces senescence through p53 activation in normal human fibroblasts, and p53-mediated mir34a, mir34b, and mir34c up-regulation and ING2 down-regulation may be involved in the senescence pathway.

Standard name | ITO_PTTG1_TARGETS_UP
Systematic name | M2282
Organism | Homo sapiens
PMID | 18451147
Authors | Ito T,Shimada Y,Kan T,David S,Cheng Y,Mori Y,Agarwal R,Paun B,Jin Z,Olaru A,Hamilton JP,Yang J,Abraham JM,Meltzer SJ,Sato F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HSA/c and KYSE140 cells (esophageal squamous cell carcinoma, ESCC) after knockdown of PTTG1 [GeneID=9232] by RNAi.
Full description | Human pituitary tumor-transforming 1 (PTTG1)/securin is a putative oncoprotein that is overexpressed in various tumor types. However, the involvement of PTTG1 in gastrointestinal cancer development and progression remains unclear. In this study, we investigated the clinical significance and biological effects of PTTG1 in esophageal squamous cell carcinoma (ESCC). Immunohistochemical studies performed on 113 primary ESCC specimens revealed a high prevalence of PTTG1 overexpression (60.2%), which was significantly associated with lymph node metastasis (regional, P = 0.042; distant, P = 0.005), advanced tumor stage (P = 0.028), and poorer overall survival (P = 0.017, log-rank test; P = 0.044, Cox proportional hazard model). Eleven ESCC cell lines expressed PTTG1 protein at levels 2.4 to 6.6 times higher than those in normal esophageal epithelial cells (HEEpiC). PTTG1 protein expression was confined to the nucleus in HEEpiC cells but present in both the cytoplasm and nucleus in ESCC cells. Two small interfering RNAs (siRNA) inhibited PTTG1 mRNA and protein expression in three ESCC cell lines by 77% to 97%. In addition, PTTG1 down-regulation by these siRNAs significantly reduced cell motility in all three ESCC cell lines (P < 0.01) in vitro, as well as popliteal lymph node metastases of ESCC cells in nude mice (P = 0.020). Global gene expression profiling suggested that several members of the Ras and Rho gene families, including RRAS, RHOG, ARHGAP1, and ARHGADIA, represented potential downstream genes in the PTTG1 pathway. Taken together, these findings suggest that PTTG1 overexpression promotes cell motility and lymph node metastasis in ESCC patients, leading to poorer survival. Thus, PTTG1 constitutes a potential biomarker and therapeutic target in ESCCs with lymph node metastases.

Standard name | ITO_PTTG1_TARGETS_DN
Systematic name | M2292
Organism | Homo sapiens
PMID | 18451147
Authors | Ito T,Shimada Y,Kan T,David S,Cheng Y,Mori Y,Agarwal R,Paun B,Jin Z,Olaru A,Hamilton JP,Yang J,Abraham JM,Meltzer SJ,Sato F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HSA/c and KYSE140 cells (esophageal squamous cell carcinoma, ESCC) after knockdown of PTTG1 [GeneID=9232] by RNAi.
Full description | Human pituitary tumor-transforming 1 (PTTG1)/securin is a putative oncoprotein that is overexpressed in various tumor types. However, the involvement of PTTG1 in gastrointestinal cancer development and progression remains unclear. In this study, we investigated the clinical significance and biological effects of PTTG1 in esophageal squamous cell carcinoma (ESCC). Immunohistochemical studies performed on 113 primary ESCC specimens revealed a high prevalence of PTTG1 overexpression (60.2%), which was significantly associated with lymph node metastasis (regional, P = 0.042; distant, P = 0.005), advanced tumor stage (P = 0.028), and poorer overall survival (P = 0.017, log-rank test; P = 0.044, Cox proportional hazard model). Eleven ESCC cell lines expressed PTTG1 protein at levels 2.4 to 6.6 times higher than those in normal esophageal epithelial cells (HEEpiC). PTTG1 protein expression was confined to the nucleus in HEEpiC cells but present in both the cytoplasm and nucleus in ESCC cells. Two small interfering RNAs (siRNA) inhibited PTTG1 mRNA and protein expression in three ESCC cell lines by 77% to 97%. In addition, PTTG1 down-regulation by these siRNAs significantly reduced cell motility in all three ESCC cell lines (P < 0.01) in vitro, as well as popliteal lymph node metastases of ESCC cells in nude mice (P = 0.020). Global gene expression profiling suggested that several members of the Ras and Rho gene families, including RRAS, RHOG, ARHGAP1, and ARHGADIA, represented potential downstream genes in the PTTG1 pathway. Taken together, these findings suggest that PTTG1 overexpression promotes cell motility and lymph node metastasis in ESCC patients, leading to poorer survival. Thus, PTTG1 constitutes a potential biomarker and therapeutic target in ESCCs with lymph node metastases.

Standard name | LE_SKI_TARGETS_UP
Systematic name | M362
Organism | Homo sapiens
PMID | 18451154
Authors | Le Scolan E,Zhu Q,Wang L,Bandyopadhyay A,Javelaud D,Mauviel A,Sun L,Luo K
Category | C2
Sub-category | CGP
Brief description | Selected genes implicated in metastasis and epithelial-to-mesenchymal transition (EMT) which were up-regulated in MDA-MB-231 cells (breast cancer) upon knockdown of SKI [GeneID=6497] by RNAi.
Full description | c-Ski is an important corepressor of transforming growth factor-beta (TGF-beta) signaling through its ability to bind to and repress the activity of the Smad proteins. It was initially identified as an oncogene that promotes anchorage-independent growth of chicken and quail embryo fibroblasts when overexpressed. Although increased Ski expression is detected in many human cancer cells, the roles of Ski in mammalian carcinogenesis have yet to be defined. Here, we report that reducing Ski expression in breast and lung cancer cells does not affect tumor growth but enhances tumor metastasis in vivo. Thus, in these cells, Ski plays an antitumorigenic role. We also showed that TGF-beta, a cytokine that is often highly expressed in metastatic tumors, induces Ski degradation through the ubiquitin-dependent proteasome in malignant human cancer cells. On TGF-beta treatment, the E3 ubiquitin ligase Arkadia mediates degradation of Ski in a Smad-dependent manner. Although Arkadia interacts with Ski in the absence of TGF-beta, binding of phosphorylated Smad2 or Smad3 to Ski is required to induce efficient degradation of Ski by Arkadia. Our results suggest that the ability of TGF-beta to induce degradation of Ski could be an additional mechanism contributing to its protumorigenic activity.

Standard name | LE_SKI_TARGETS_DN
Systematic name | M15687
Organism | Homo sapiens
PMID | 18451154
Authors | Le Scolan E,Zhu Q,Wang L,Bandyopadhyay A,Javelaud D,Mauviel A,Sun L,Luo K
Category | C2
Sub-category | CGP
Brief description | Selected genes implicated in metastasis and epithelial-to-mesenchymal transition (EMT) which were down-regulated in MDA-MB-231 cells (breast cancer) upon knockdown of SKI [GeneID=6497] by RNAi.
Full description | c-Ski is an important corepressor of transforming growth factor-beta (TGF-beta) signaling through its ability to bind to and repress the activity of the Smad proteins. It was initially identified as an oncogene that promotes anchorage-independent growth of chicken and quail embryo fibroblasts when overexpressed. Although increased Ski expression is detected in many human cancer cells, the roles of Ski in mammalian carcinogenesis have yet to be defined. Here, we report that reducing Ski expression in breast and lung cancer cells does not affect tumor growth but enhances tumor metastasis in vivo. Thus, in these cells, Ski plays an antitumorigenic role. We also showed that TGF-beta, a cytokine that is often highly expressed in metastatic tumors, induces Ski degradation through the ubiquitin-dependent proteasome in malignant human cancer cells. On TGF-beta treatment, the E3 ubiquitin ligase Arkadia mediates degradation of Ski in a Smad-dependent manner. Although Arkadia interacts with Ski in the absence of TGF-beta, binding of phosphorylated Smad2 or Smad3 to Ski is required to induce efficient degradation of Ski by Arkadia. Our results suggest that the ability of TGF-beta to induce degradation of Ski could be an additional mechanism contributing to its protumorigenic activity.

Standard name | BONOME_OVARIAN_CANCER_POOR_SURVIVAL_UP
Systematic name | M816
Organism | Homo sapiens
PMID | 18593951
Authors | Bonome T,Levine DA,Shih J,Randonovich M,Pise-Masison CA,Bogomolniy F,Ozbun L,Brady J,Barrett JC,Boyd J,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Top highly correlated genes positively associated with poor survival of patients with suboptimally debulked ovarian tumors.
Full description | Despite the existence of morphologically indistinguishable disease, patients with advanced ovarian tumors display a broad range of survival end points. We hypothesize that gene expression profiling can identify a prognostic signature accounting for these distinct clinical outcomes. To resolve survival-associated loci, gene expression profiling was completed for an extensive set of 185 (90 optimal/95 suboptimal) primary ovarian tumors using the Affymetrix human U133A microarray. Cox regression analysis identified probe sets associated with survival in optimally and suboptimally debulked tumor sets at a P value of <0.01. Leave-one-out cross-validation was applied to each tumor cohort and confirmed by a permutation test. External validation was conducted by applying the gene signature to a publicly available array database of expression profiles of advanced stage suboptimally debulked tumors. The prognostic signature successfully classified the tumors according to survival for suboptimally (P = 0.0179) but not optimally debulked (P = 0.144) patients. The suboptimal gene signature was validated using the independent set of tumors (odds ratio, 8.75; P = 0.0146). To elucidate signaling events amenable to therapeutic intervention in suboptimally debulked patients, pathway analysis was completed for the top 57 survival-associated probe sets. For suboptimally debulked patients, confirmation of the predictive gene signature supports the existence of a clinically relevant predictor, as well as the possibility of novel therapeutic opportunities. Ultimately, the prognostic classifier defined for suboptimally debulked tumors may aid in the classification and enhancement of patient outcome for this high-risk population.

Standard name | BONOME_OVARIAN_CANCER_POOR_SURVIVAL_DN
Systematic name | M15807
Organism | Homo sapiens
PMID | 18593951
Authors | Bonome T,Levine DA,Shih J,Randonovich M,Pise-Masison CA,Bogomolniy F,Ozbun L,Brady J,Barrett JC,Boyd J,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Top highly correlated genes negatively associated with poor survival of patients with suboptimally debulked ovarian tumors.
Full description | Despite the existence of morphologically indistinguishable disease, patients with advanced ovarian tumors display a broad range of survival end points. We hypothesize that gene expression profiling can identify a prognostic signature accounting for these distinct clinical outcomes. To resolve survival-associated loci, gene expression profiling was completed for an extensive set of 185 (90 optimal/95 suboptimal) primary ovarian tumors using the Affymetrix human U133A microarray. Cox regression analysis identified probe sets associated with survival in optimally and suboptimally debulked tumor sets at a P value of <0.01. Leave-one-out cross-validation was applied to each tumor cohort and confirmed by a permutation test. External validation was conducted by applying the gene signature to a publicly available array database of expression profiles of advanced stage suboptimally debulked tumors. The prognostic signature successfully classified the tumors according to survival for suboptimally (P = 0.0179) but not optimally debulked (P = 0.144) patients. The suboptimal gene signature was validated using the independent set of tumors (odds ratio, 8.75; P = 0.0146). To elucidate signaling events amenable to therapeutic intervention in suboptimally debulked patients, pathway analysis was completed for the top 57 survival-associated probe sets. For suboptimally debulked patients, confirmation of the predictive gene signature supports the existence of a clinically relevant predictor, as well as the possibility of novel therapeutic opportunities. Ultimately, the prognostic classifier defined for suboptimally debulked tumors may aid in the classification and enhancement of patient outcome for this high-risk population.

Standard name | BONOME_OVARIAN_CANCER_SURVIVAL_OPTIMAL_DEBULKING
Systematic name | M7068
Organism | Homo sapiens
PMID | 18593951
Authors | Bonome T,Levine DA,Shih J,Randonovich M,Pise-Masison CA,Bogomolniy F,Ozbun L,Brady J,Barrett JC,Boyd J,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Genes whose expression in optimally debulked ovarian tumors is associated with survival prognosis.
Full description | Despite the existence of morphologically indistinguishable disease, patients with advanced ovarian tumors display a broad range of survival end points. We hypothesize that gene expression profiling can identify a prognostic signature accounting for these distinct clinical outcomes. To resolve survival-associated loci, gene expression profiling was completed for an extensive set of 185 (90 optimal/95 suboptimal) primary ovarian tumors using the Affymetrix human U133A microarray. Cox regression analysis identified probe sets associated with survival in optimally and suboptimally debulked tumor sets at a P value of <0.01. Leave-one-out cross-validation was applied to each tumor cohort and confirmed by a permutation test. External validation was conducted by applying the gene signature to a publicly available array database of expression profiles of advanced stage suboptimally debulked tumors. The prognostic signature successfully classified the tumors according to survival for suboptimally (P = 0.0179) but not optimally debulked (P = 0.144) patients. The suboptimal gene signature was validated using the independent set of tumors (odds ratio, 8.75; P = 0.0146). To elucidate signaling events amenable to therapeutic intervention in suboptimally debulked patients, pathway analysis was completed for the top 57 survival-associated probe sets. For suboptimally debulked patients, confirmation of the predictive gene signature supports the existence of a clinically relevant predictor, as well as the possibility of novel therapeutic opportunities. Ultimately, the prognostic classifier defined for suboptimally debulked tumors may aid in the classification and enhancement of patient outcome for this high-risk population.

Standard name | BONOME_OVARIAN_CANCER_SURVIVAL_SUBOPTIMAL_DEBULKING
Systematic name | M253
Organism | Homo sapiens
PMID | 18593951
Authors | Bonome T,Levine DA,Shih J,Randonovich M,Pise-Masison CA,Bogomolniy F,Ozbun L,Brady J,Barrett JC,Boyd J,Birrer MJ
Category | C2
Sub-category | CGP
Brief description | Genes whose expression in suboptimally debulked ovarian tumors is associated with survival prognosis.
Full description | Despite the existence of morphologically indistinguishable disease, patients with advanced ovarian tumors display a broad range of survival end points. We hypothesize that gene expression profiling can identify a prognostic signature accounting for these distinct clinical outcomes. To resolve survival-associated loci, gene expression profiling was completed for an extensive set of 185 (90 optimal/95 suboptimal) primary ovarian tumors using the Affymetrix human U133A microarray. Cox regression analysis identified probe sets associated with survival in optimally and suboptimally debulked tumor sets at a P value of <0.01. Leave-one-out cross-validation was applied to each tumor cohort and confirmed by a permutation test. External validation was conducted by applying the gene signature to a publicly available array database of expression profiles of advanced stage suboptimally debulked tumors. The prognostic signature successfully classified the tumors according to survival for suboptimally (P = 0.0179) but not optimally debulked (P = 0.144) patients. The suboptimal gene signature was validated using the independent set of tumors (odds ratio, 8.75; P = 0.0146). To elucidate signaling events amenable to therapeutic intervention in suboptimally debulked patients, pathway analysis was completed for the top 57 survival-associated probe sets. For suboptimally debulked patients, confirmation of the predictive gene signature supports the existence of a clinically relevant predictor, as well as the possibility of novel therapeutic opportunities. Ultimately, the prognostic classifier defined for suboptimally debulked tumors may aid in the classification and enhancement of patient outcome for this high-risk population.

Standard name | GALI_TP53_TARGETS_APOPTOTIC_UP
Systematic name | M16490
Organism | Homo sapiens
PMID | 18632613
Authors | Gali-Muhtasib H,Kuester D,Mawrin C,Bajbouj K,Diestel A,Ocker M,Habold C,Foltzer-Jourdainne C,Schoenfeld P,Peters B,Diab-Assaf M,Pommrich U,Itani W,Lippert H,Roessner A,Schneider-Stock R
Category | C2
Sub-category | CGP
Brief description | Apoptosis genes up-regulated by TP53 [GeneID=7157] in HCT116 cells (colon cancer) treated with thymoquinone [PubChem=10281].
Full description | There are few reports describing the role of p53-dependent gene repression in apoptotic cell death. To identify such apoptosis-associated p53 target genes, we used the pro-oxidant plant-derived drug thymoquinone and compared p53+/+ and p53-/- colon cancer cells HCT116. The p53 wild-type (wt) status correlated with more pronounced DNA damage and higher apoptosis after thymoquinone treatment. A significant up-regulation of the survival gene CHEK1 was observed in p53-/- cells in response to thymoquinone due to the lack of transcriptional repression of p53. In p53-/- cells, transfection with p53-wt vector and CHEK1 small interfering RNA treatment decreased CHEK1 mRNA and protein levels and restored apoptosis to the levels of the p53+/+ cells. p53-/- cells transplanted to nude mice treated with thymoquinone up-regulated CHEK1 expression and did not undergo apoptosis unlike p53+/+ cells. Immunofluorescence analysis revealed that the apoptosis resistance in p53-/- cells after thymoquinone treatment might be conveyed by shuttling of CHEK1 into the nucleus. We confirmed the in vivo existence of this CHEK1/p53 link in human colorectal cancer, showing that tumors lacking p53 had higher levels of CHEK1, which was accompanied by poorer apoptosis. CHEK1 overexpression was correlated with advanced tumor stages (P = 0.03), proximal tumor localization (P = 0.02), and worse prognosis (1.9-fold risk, univariate Cox regression; Kaplan-Meier, P = 0.04). We suggest that the inhibition of the stress response sensor CHEK1 might contribute to the antineoplastic activity of specific DNA-damaging drugs.

Standard name | GALI_TP53_TARGETS_APOPTOTIC_DN
Systematic name | M17309
Organism | Homo sapiens
PMID | 18632613
Authors | Gali-Muhtasib H,Kuester D,Mawrin C,Bajbouj K,Diestel A,Ocker M,Habold C,Foltzer-Jourdainne C,Schoenfeld P,Peters B,Diab-Assaf M,Pommrich U,Itani W,Lippert H,Roessner A,Schneider-Stock R
Category | C2
Sub-category | CGP
Brief description | Apoptosis genes down-regulated by TP53 [GeneID=7157] in HCT116 cells (colon cancer) treated with thymoquinone [PubChem=10281].
Full description | There are few reports describing the role of p53-dependent gene repression in apoptotic cell death. To identify such apoptosis-associated p53 target genes, we used the pro-oxidant plant-derived drug thymoquinone and compared p53+/+ and p53-/- colon cancer cells HCT116. The p53 wild-type (wt) status correlated with more pronounced DNA damage and higher apoptosis after thymoquinone treatment. A significant up-regulation of the survival gene CHEK1 was observed in p53-/- cells in response to thymoquinone due to the lack of transcriptional repression of p53. In p53-/- cells, transfection with p53-wt vector and CHEK1 small interfering RNA treatment decreased CHEK1 mRNA and protein levels and restored apoptosis to the levels of the p53+/+ cells. p53-/- cells transplanted to nude mice treated with thymoquinone up-regulated CHEK1 expression and did not undergo apoptosis unlike p53+/+ cells. Immunofluorescence analysis revealed that the apoptosis resistance in p53-/- cells after thymoquinone treatment might be conveyed by shuttling of CHEK1 into the nucleus. We confirmed the in vivo existence of this CHEK1/p53 link in human colorectal cancer, showing that tumors lacking p53 had higher levels of CHEK1, which was accompanied by poorer apoptosis. CHEK1 overexpression was correlated with advanced tumor stages (P = 0.03), proximal tumor localization (P = 0.02), and worse prognosis (1.9-fold risk, univariate Cox regression; Kaplan-Meier, P = 0.04). We suggest that the inhibition of the stress response sensor CHEK1 might contribute to the antineoplastic activity of specific DNA-damaging drugs.

Standard name | MOSERLE_IFNA_RESPONSE
Systematic name | M3218
Organism | Homo sapiens
PMID | 18632618
Authors | Moserle L,Indraccolo S,Ghisi M,Frasson C,Fortunato E,Canevari S,Miotti S,Tosello V,Zamarchi R,Corradin A,Minuzzo S,Rossi E,Basso G,Amadori A
Category | C2
Sub-category | CGP
Brief description | Top 50 genes up-regulated in ovarian cancer progenitor cells (also known as side population, SP, cells) in response to interferon alpha (IFNA).
Full description | The side population (SP), recently identified in several normal tissues and in a variety of tumors based on its ability to extrude some fluorescent dyes, may comprise cells endowed with stem cell features. In this study, we investigated the presence of SP in epithelial ovarian cancer and found it in 9 of 27 primary tumor samples analyzed, as well as in 4 of 6 cultures from xenotransplants. SP cells from one xenograft bearing a large SP fraction were characterized in detail. SP cells had higher proliferation rates, were much less apoptotic compared with non-SP cells, and generated tumors more rapidly than non-SP cells. We also investigated the effects of IFN-alpha, a cytokine that has widely been used to treat solid tumors, on epithelial ovarian cancer cells and observed that IFN-alpha exerted marked antiproliferative and proapoptotic effects on primary cultures containing high numbers of SP cells. In vitro, IFN-alpha treatment invariably caused a dramatic reduction in SP size in tumor cell lines of different origins; moreover, IFN-alpha treatment of purified SP cells was associated with a distinctive change in their transcriptional profile. Gene therapy with human IFN-alpha resulted in regression of established tumors bearing a large SP fraction, which was not observed when tumors bearing low SP levels were treated. These findings could have relevant clinical implications because they imply that tumors bearing large SP numbers, albeit rare, could be sensitive to IFN-alpha treatment.

Standard name | MCGARVEY_SILENCED_BY_METHYLATION_IN_COLON_CANCER
Systematic name | M8760
Organism | Homo sapiens
PMID | 18632628
Authors | McGarvey KM,Van Neste L,Cope L,Ohm JE,Herman JG,Van Criekinge W,Schuebel KE,Baylin SB
Category | C2
Sub-category | CGP
Brief description | Genes silenced in HCT116 cells (colon cancer) by methylation of CpG islands in their promoters.
Full description | Epigenetic gene regulation is a key determinant of heritable gene expression patterns and is critical for normal cellular function. Dysregulation of epigenetic transcriptional control is a fundamental feature of cancer, particularly manifesting as increased promoter DNA methylation with associated aberrant gene silencing, which plays a significant role in tumor progression. We now globally map key chromatin parameters for genes with promoter CpG island DNA hypermethylation in colon cancer cells by combining microarray gene expression analyses with chromatin immunoprecipitation-on-chip technology. We first show that the silent state of such genes universally correlates with a broad distribution of a low but distinct level of the PcG-mediated histone modification, methylation of lysine 27 of histone 3 (H3K27me), and a very low level of the active mark H3K4me2. This chromatin pattern, and particularly H3K4me2 levels, crisply separates DNA-hypermethylated genes from those where histone deacetylation is responsible for transcriptional silencing. Moreover, the chromatin pattern can markedly enhance identification of truly silent and DNA-hypermethylated genes. We additionally find that when DNA-hypermethylated genes are demethylated and reexpressed, they adopt a bivalent chromatin pattern, which is associated with the poised gene expression state of a large group of embryonic stem cell genes and is characterized by an increase in levels of both the H3K27me3 and H3K4me2 marks. Our data have great relevance for the increasing interest in reexpression of DNA-hypermethylated genes for the treatment of cancer.

Standard name | WILSON_PROTEASES_AT_TUMOR_BONE_INTERFACE_UP
Systematic name | M1792
Organism | Mus musculus
PMID | 18632634
Authors | Wilson TJ,Nannuru KC,Futakuchi M,Sadanandam A,Singh RK
Category | C2
Sub-category | CGP
Brief description | Protease genes up-regulated at tumor-bone interface compared to the tumor alone area.
Full description | Breast cancer commonly causes osteolytic metastases in bone, a process that is dependent on tumor-stromal interaction. Proteases play an important role in modulating tumor-stromal interactions in a manner that favors tumor establishment and progression. Whereas several studies have examined the role of proteases in modulating the bone microenvironment, little is currently known about their role in tumor-bone interaction during osteolytic metastasis. In cancer-induced osteolytic lesions, cleavage of receptor activator of nuclear factor-kappaB ligand (RANKL) to a soluble version (sRANKL) is critical for widespread osteoclast activation. Using a mouse model that mimics osteolytic changes associated with breast cancer-induced bone metastases, we identified cathepsin G, cathepsin K, matrix metalloproteinase (MMP)-9, and MMP13 to be proteases that are up-regulated at the tumor-bone interface using comparative cDNA microarray analysis and quantitative reverse transcription-PCR. Moreover, we showed that cathepsin G is capable of shedding the extracellular domain of RANKL, generating active sRANKL that is capable of inducing differentiation and activation of osteoclast precursors. The major source of cathepsin G at the tumor-bone interface seems to be osteoclasts that up-regulate production of cathepsin G via interaction with tumor cells. Furthermore, we showed that in vitro osteoclastogenesis is reduced by inhibition of cathepsin G in a coculture model and that in vivo inhibition of cathepsin G reduces mammary tumor-induced osteolysis. Together, our data indicate that cathepsin G activity at the tumor-bone interface plays an important role in mammary tumor-induced osteolysis and suggest that cathepsin G is a potentially novel therapeutic target in the treatment of breast cancer bone metastasis.

Standard name | WILSON_PROTEASES_AT_TUMOR_BONE_INTERFACE_DN
Systematic name | M1794
Organism | Mus musculus
PMID | 18632634
Authors | Wilson TJ,Nannuru KC,Futakuchi M,Sadanandam A,Singh RK
Category | C2
Sub-category | CGP
Brief description | Protease genes down-regulated at tumor-bone interface compared to the tumor alone area.
Full description | Breast cancer commonly causes osteolytic metastases in bone, a process that is dependent on tumor-stromal interaction. Proteases play an important role in modulating tumor-stromal interactions in a manner that favors tumor establishment and progression. Whereas several studies have examined the role of proteases in modulating the bone microenvironment, little is currently known about their role in tumor-bone interaction during osteolytic metastasis. In cancer-induced osteolytic lesions, cleavage of receptor activator of nuclear factor-kappaB ligand (RANKL) to a soluble version (sRANKL) is critical for widespread osteoclast activation. Using a mouse model that mimics osteolytic changes associated with breast cancer-induced bone metastases, we identified cathepsin G, cathepsin K, matrix metalloproteinase (MMP)-9, and MMP13 to be proteases that are up-regulated at the tumor-bone interface using comparative cDNA microarray analysis and quantitative reverse transcription-PCR. Moreover, we showed that cathepsin G is capable of shedding the extracellular domain of RANKL, generating active sRANKL that is capable of inducing differentiation and activation of osteoclast precursors. The major source of cathepsin G at the tumor-bone interface seems to be osteoclasts that up-regulate production of cathepsin G via interaction with tumor cells. Furthermore, we showed that in vitro osteoclastogenesis is reduced by inhibition of cathepsin G in a coculture model and that in vivo inhibition of cathepsin G reduces mammary tumor-induced osteolysis. Together, our data indicate that cathepsin G activity at the tumor-bone interface plays an important role in mammary tumor-induced osteolysis and suggest that cathepsin G is a potentially novel therapeutic target in the treatment of breast cancer bone metastasis.

Standard name | WEBER_METHYLATED_HCP_IN_FIBROBLAST_UP
Systematic name | M224
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Methylated germline-specific genes with high-CpG-density promoters (HCP) in primary fibroblasts.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | WEBER_METHYLATED_HCP_IN_FIBROBLAST_DN
Systematic name | M16646
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Unmethylated germline-specific genes with high-CpG-density promoters (HCP) in primary fibroblasts.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | WEBER_METHYLATED_HCP_IN_SPERM_DN
Systematic name | M1808
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Unmethylated germline-specific genes with high-CpG-density promoters (HCP) in sperm.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | WEBER_METHYLATED_HCP_IN_SPERM_UP
Systematic name | M1506
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Methylated germline-specific genes with high-CpG-density promoters (HCP) in sperm.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | BASSO_HAIRY_CELL_LEUKEMIA_UP
Systematic name | M13859
Organism | Homo sapiens
PMID | 14707115
Authors | Basso K,Liso A,Tiacci E,Benedetti R,Pulsoni A,Foa R,Di Raimondo F,Ambrosetti A,Califano A,Klein U,Dalla Favera R,Falini B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hairy cell leukemia (HCL) compared with normal and other neoplastic B cell populations.
Full description | Hairy cell leukemia (HCL) is a chronic B cell malignancy characterized by the diffuse infiltration of bone marrow and spleen by cells displaying a typical hairy morphology. However, the nature of the HCL phenotype and its relationship to normal B cells and to other lymphoma subtypes remains unclear. Using gene expression profiling, we show here that HCL displays a homogeneous pattern of gene expression, which is clearly distinct from that of other B cell non-Hodgkin lymphomas. Comparison with the gene expression profiles of purified normal B cell subpopulations, including germinal center (GC), pre-GC (naive), and post-GC (memory) B cells, shows that HCL cells are more related to memory cells, suggesting a derivation from this B cell population. Notably, when compared with memory cells, HCL cells displayed a remarkable conservation in proliferation, apoptosis, and DNA metabolism programs, whereas they appeared significantly altered in the expression of genes controlling cell adhesion and response to chemokines. Finally, these analyses have identified several genes that are specifically expressed in HCL and whose expression was confirmed at the protein level by immunocytochemical analysis of primary HCL cases. These results have biological implications relevant to the pathogenesis of this malignancy as well as clinical implications for its diagnosis and therapy.

Standard name | BASSO_HAIRY_CELL_LEUKEMIA_DN
Systematic name | M10728
Organism | Homo sapiens
PMID | 14707115
Authors | Basso K,Liso A,Tiacci E,Benedetti R,Pulsoni A,Foa R,Di Raimondo F,Ambrosetti A,Califano A,Klein U,Dalla Favera R,Falini B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hairy cell leukemia (HCL) compared with normal and other neoplastic B cell populations.
Full description | Hairy cell leukemia (HCL) is a chronic B cell malignancy characterized by the diffuse infiltration of bone marrow and spleen by cells displaying a typical hairy morphology. However, the nature of the HCL phenotype and its relationship to normal B cells and to other lymphoma subtypes remains unclear. Using gene expression profiling, we show here that HCL displays a homogeneous pattern of gene expression, which is clearly distinct from that of other B cell non-Hodgkin lymphomas. Comparison with the gene expression profiles of purified normal B cell subpopulations, including germinal center (GC), pre-GC (naive), and post-GC (memory) B cells, shows that HCL cells are more related to memory cells, suggesting a derivation from this B cell population. Notably, when compared with memory cells, HCL cells displayed a remarkable conservation in proliferation, apoptosis, and DNA metabolism programs, whereas they appeared significantly altered in the expression of genes controlling cell adhesion and response to chemokines. Finally, these analyses have identified several genes that are specifically expressed in HCL and whose expression was confirmed at the protein level by immunocytochemical analysis of primary HCL cases. These results have biological implications relevant to the pathogenesis of this malignancy as well as clinical implications for its diagnosis and therapy.

Standard name | TOYOTA_TARGETS_OF_MIR34B_AND_MIR34C
Systematic name | M19927
Organism | Homo sapiens
PMID | 18519671
Authors | Toyota M,Suzuki H,Sasaki Y,Maruyama R,Imai K,Shinomura Y,Tokino T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HCT116 cells (colon cancer) upon expression of MIR34B or MIR34C [GeneID=407041;407042] microRNAs.
Full description | Altered expression of microRNA (miRNA) is strongly implicated in cancer, and recent studies have shown that, in cancer, expression of some miRNAs cells is silenced in association with CpG island hypermethylation. To identify epigenetically silenced miRNAs in colorectal cancer (CRC), we screened for miRNAs induced in CRC cells by 5-aza-2'-deoxycytidine (DAC) treatment or DNA methyltransferase knockout. We found that miRNA-34b (miR-34b) and miR-34c, two components of the p53 network, are epigenetically silenced in CRC; that this down-regulation of miR-34b/c is associated with hypermethylation of the neighboring CpG island; and that DAC treatment rapidly restores miR-34b/c expression. Methylation of the miR-34b/c CpG island was frequently observed in CRC cell lines (nine of nine, 100%) and in primary CRC tumors (101 of 111, 90%), but not in normal colonic mucosa. Transfection of precursor miR-34b or miR-34c into CRC cells induced dramatic changes in the gene expression profile, and there was significant overlap between the genes down-regulated by miR-34b/c and those down-regulated by DAC. We also found that the miR-34b/c CpG island is a bidirectional promoter which drives expression of both miR-34b/c and B-cell translocation gene 4 (BTG4); that methylation of the CpG island is also associated with transcriptional silencing of BTG4; and that ectopic expression of BTG4 suppresses colony formation by CRC cells. Our results suggest that miR-34b/c and BTG4 are novel tumor suppressors in CRC and that the miR-34b/c CpG island, which bidirectionally regulates miR-34b/c and BTG4, is a frequent target of epigenetic silencing in CRC.

Standard name | IZADPANAH_STEM_CELL_ADIPOSE_VS_BONE_UP
Systematic name | M15887
Organism | Macaca mulatta
PMID | 18519682
Authors | Izadpanah R,Kaushal D,Kriedt C,Tsien F,Patel B,Dufour J,Bunnell BA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in adipose tissue mesenchymal stem cells (ASC) vs bone marrow mesenchymal stem cells (rBMSC)
Full description | Mesenchymal stem cells (MSC) derived from bone marrow stem cells (BMSC) and adipose tissue stem cells (ASC) of humans and rhesus macaques were evaluated for their cell cycle properties during protracted culture in vitro. Human ASCs (hASC) and rhesus BMSCs (rBMSC) underwent significantly more total population doublings than human BMSCs (hBMSC) and rhesus ASCs (rASC). The cell cycle profile of all MSCs was altered as cultures aged. hMSCs underwent an increase in the frequency of cells in the S phase at P20 and P30. However, rhesus MSCs from both sources developed a distinct polyploid population of cells at P20, which progressed to aneuploidy by P30. Karyotype analysis of MSCs revealed the development of tetraploid or aneuploid karyotypes in the rhesus cells at P20 or P30. Analysis of the transcriptome of the MSCs from early and late passages revealed significant alterations in the patterns of gene expression (8.8% of the genes were differentially expressed in hBMSCs versus hASCs, and 5.5% in rBMSCs versus rASCs). Gene expression changes were much less evident within the same cell type as aging occurred (0.7% in hMSCs and 0.9% in rMSC). Gene ontology analysis showed that functions involved in protein catabolism and regulation of pol II transcription were overrepresented in rASCs, whereas the regulation of I kappa B/nuclear factor-kappaB cascade were overrepresented in hBMSCs. Functional analysis of genes that were differentially expressed in rASCs and hBMSCs revealed that pathways involved in cell cycle, cell cycle checkpoints, protein-ubiquitination, and apoptosis were altered.

Standard name | IZADPANAH_STEM_CELL_ADIPOSE_VS_BONE_DN
Systematic name | M4913
Organism | Macaca mulatta
PMID | 18519682
Authors | Izadpanah R,Kaushal D,Kriedt C,Tsien F,Patel B,Dufour J,Bunnell BA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in adipose tissue mesenchymal stem cells (ASC) vs bone marrow mesenchymal stem cells (rBMSC)
Full description | Mesenchymal stem cells (MSC) derived from bone marrow stem cells (BMSC) and adipose tissue stem cells (ASC) of humans and rhesus macaques were evaluated for their cell cycle properties during protracted culture in vitro. Human ASCs (hASC) and rhesus BMSCs (rBMSC) underwent significantly more total population doublings than human BMSCs (hBMSC) and rhesus ASCs (rASC). The cell cycle profile of all MSCs was altered as cultures aged. hMSCs underwent an increase in the frequency of cells in the S phase at P20 and P30. However, rhesus MSCs from both sources developed a distinct polyploid population of cells at P20, which progressed to aneuploidy by P30. Karyotype analysis of MSCs revealed the development of tetraploid or aneuploid karyotypes in the rhesus cells at P20 or P30. Analysis of the transcriptome of the MSCs from early and late passages revealed significant alterations in the patterns of gene expression (8.8% of the genes were differentially expressed in hBMSCs versus hASCs, and 5.5% in rBMSCs versus rASCs). Gene expression changes were much less evident within the same cell type as aging occurred (0.7% in hMSCs and 0.9% in rMSC). Gene ontology analysis showed that functions involved in protein catabolism and regulation of pol II transcription were overrepresented in rASCs, whereas the regulation of I kappa B/nuclear factor-kappaB cascade were overrepresented in hBMSCs. Functional analysis of genes that were differentially expressed in rASCs and hBMSCs revealed that pathways involved in cell cycle, cell cycle checkpoints, protein-ubiquitination, and apoptosis were altered.

Standard name | ZHANG_BREAST_CANCER_PROGENITORS_UP
Systematic name | M15150
Organism | Mus musculus
PMID | 18559513
Authors | Zhang M,Behbod F,Atkinson RL,Landis MD,Kittrell F,Edwards D,Medina D,Tsimelzon A,Hilsenbeck S,Green JE,Michalowska AM,Rosen JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in cancer stem cells isolated from mammary tumors compared to the non-tumorigenic cells.
Full description | Using a syngeneic p53-null mouse mammary gland tumor model that closely mimics human breast cancer, we have identified, by limiting dilution transplantation and in vitro mammosphere assay, a Lin(-)CD29(H)CD24(H) subpopulation of tumor-initiating cells. Upon subsequent transplantation, this subpopulation generated heterogeneous tumors that displayed properties similar to the primary tumor. Analysis of biomarkers suggests the Lin(-)CD29(H)CD24(H) subpopulation may have arisen from a bipotent mammary progenitor. Differentially expressed genes in the Lin(-)CD29(H)CD24(H) mouse mammary gland tumor-initiating cell population include those involved in DNA damage response and repair, as well as genes involved in epigenetic regulation previously shown to be critical for stem cell self-renewal. These studies provide in vitro and in vivo data that support the cancer stem cell (CSC) hypothesis. Furthermore, this p53-null mouse mammary tumor model may allow us to identify new CSC markers and to test the functional importance of these markers.

Standard name | ZHANG_BREAST_CANCER_PROGENITORS_DN
Systematic name | M6489
Organism | Mus musculus
PMID | 18559513
Authors | Zhang M,Behbod F,Atkinson RL,Landis MD,Kittrell F,Edwards D,Medina D,Tsimelzon A,Hilsenbeck S,Green JE,Michalowska AM,Rosen JM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in cancer stem cells isolated from mammary tumors compared to the non-tumorigenic cells.
Full description | Using a syngeneic p53-null mouse mammary gland tumor model that closely mimics human breast cancer, we have identified, by limiting dilution transplantation and in vitro mammosphere assay, a Lin(-)CD29(H)CD24(H) subpopulation of tumor-initiating cells. Upon subsequent transplantation, this subpopulation generated heterogeneous tumors that displayed properties similar to the primary tumor. Analysis of biomarkers suggests the Lin(-)CD29(H)CD24(H) subpopulation may have arisen from a bipotent mammary progenitor. Differentially expressed genes in the Lin(-)CD29(H)CD24(H) mouse mammary gland tumor-initiating cell population include those involved in DNA damage response and repair, as well as genes involved in epigenetic regulation previously shown to be critical for stem cell self-renewal. These studies provide in vitro and in vivo data that support the cancer stem cell (CSC) hypothesis. Furthermore, this p53-null mouse mammary tumor model may allow us to identify new CSC markers and to test the functional importance of these markers.

Standard name | MISHRA_CARCINOMA_ASSOCIATED_FIBROBLAST_DN
Systematic name | M4577
Organism | Homo sapiens
PMID | 18519693
Authors | Mishra PJ,Humeniuk R,Medina DJ,Alexe G,Mesirov JP,Ganesan S,Glod JW,Banerjee D
Category | C2
Sub-category | CGP
Brief description | Top genes down-regulated in mesenchyme stem cells (MSC) grown in a tumor conditioned medium, which leads to carcinoma-associated fibroblast phenotype.
Full description | Carcinoma-associated fibroblasts (CAF) have recently been implicated in important aspects of epithelial solid tumor biology, such as neoplastic progression, tumor growth, angiogenesis, and metastasis. However, neither the source of CAFs nor the differences between CAFs and fibroblasts from nonneoplastic tissue have been well defined. In this study, we show that human bone marrow-derived mesenchymal stem cells (hMSCs) exposed to tumor-conditioned medium (TCM) over a prolonged period of time assume a CAF-like myofibroblastic phenotype. More importantly, these cells exhibit functional properties of CAFs, including sustained expression of stromal-derived factor-1 (SDF-1) and the ability to promote tumor cell growth both in vitro and in an in vivo coimplantation model, and expression of myofibroblast markers, including alpha-smooth muscle actin and fibroblast surface protein. hMSCs induced to differentiate to a myofibroblast-like phenotype using 5-azacytidine do not promote tumor cell growth as efficiently as hMSCs cultured in TCM nor do they show increased SDF-1 expression. Furthermore, gene expression profiling revealed similarities between TCM-exposed hMSCs and CAFs. Taken together, these data suggest that hMSCs are a source of CAFs and can be used in the modeling of tumor-stroma interactions. To our knowledge, this is the first report showing that hMSCs become activated and resemble carcinoma-associated myofibroblasts on prolonged exposure to conditioned medium from MDAMB231 human breast cancer cells.

Standard name | BERNARD_PPAPDC1B_TARGETS_UP
Systematic name | M15315
Organism | Homo sapiens
PMID | 18757432
Authors | Bernard-Pierrot I,Gruel N,Stransky N,Vincent-Salomon A,Reyal F,Raynal V,Vallot C,Pierron G,Radvanyi F,Delattre O
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ZR-75-1 cells (breast cancer, amplified 8p11-12 region) upon knockdown of PPAPDC1B [GeneID=84513] by RNAi.
Full description | The 8p11-12 chromosome region is one of the regions most frequently amplified in breast carcinoma (10-15% of cases). Several genes within this region have been identified as candidate oncogenes, as they are both amplified and overexpressed. However, very few studies have explored the role of these genes in cell transformation, with the aim of identifying valuable therapeutic targets. An analysis of comparative genomic hybridization array and expression profiling data for a series of 152 ductal breast carcinomas and 21 cell lines identified five genes (LSM1, BAG4, DDHD2, PPAPDC1B, and WHSC1L1) within the amplified region as consistently overexpressed due to an increased gene copy number. The use of small interfering RNA to knock down the expression of each of these genes showed the major role played by two genes, PPAPDC1B and WHSC1L1, in regulating the survival and transformation of two different cell lines harboring the 8p amplicon. The role of these two genes in cell survival and cell transformation was also confirmed by long-term knockdown expression studies using short hairpin RNAs. The potential of PPAPDC1B, which encodes a transmembrane phosphatase, as a therapeutic target was further shown by the strong inhibition of growth of breast tumor xenografts displaying 8p11-12 amplification induced by the silencing of PPAPDC1B. The oncogenic properties of PPAPDC1B were further shown by its ability to transform NIH-3T3 fibroblasts, inducing their anchorage-independent growth. Finally, microarray experiments on PPAPDC1B knockdown indicated that this gene interfered with multiple cell signaling pathways, including the Janus-activated kinase-signal transducer and activator of transcription, mitogen-activated protein kinase, and protein kinase C pathways. PPAPDC1B may also potentiate the estrogen receptor pathway by down-regulating DUSP22.

Standard name | BERNARD_PPAPDC1B_TARGETS_DN
Systematic name | M8123
Organism | Homo sapiens
PMID | 18757432
Authors | Bernard-Pierrot I,Gruel N,Stransky N,Vincent-Salomon A,Reyal F,Raynal V,Vallot C,Pierron G,Radvanyi F,Delattre O
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ZR-75-1 cells (breast cancer, amplified 8p11-12 region) upon knockdown of PPAPDC1B [GeneID=84513] by RNAi.
Full description | The 8p11-12 chromosome region is one of the regions most frequently amplified in breast carcinoma (10-15% of cases). Several genes within this region have been identified as candidate oncogenes, as they are both amplified and overexpressed. However, very few studies have explored the role of these genes in cell transformation, with the aim of identifying valuable therapeutic targets. An analysis of comparative genomic hybridization array and expression profiling data for a series of 152 ductal breast carcinomas and 21 cell lines identified five genes (LSM1, BAG4, DDHD2, PPAPDC1B, and WHSC1L1) within the amplified region as consistently overexpressed due to an increased gene copy number. The use of small interfering RNA to knock down the expression of each of these genes showed the major role played by two genes, PPAPDC1B and WHSC1L1, in regulating the survival and transformation of two different cell lines harboring the 8p amplicon. The role of these two genes in cell survival and cell transformation was also confirmed by long-term knockdown expression studies using short hairpin RNAs. The potential of PPAPDC1B, which encodes a transmembrane phosphatase, as a therapeutic target was further shown by the strong inhibition of growth of breast tumor xenografts displaying 8p11-12 amplification induced by the silencing of PPAPDC1B. The oncogenic properties of PPAPDC1B were further shown by its ability to transform NIH-3T3 fibroblasts, inducing their anchorage-independent growth. Finally, microarray experiments on PPAPDC1B knockdown indicated that this gene interfered with multiple cell signaling pathways, including the Janus-activated kinase-signal transducer and activator of transcription, mitogen-activated protein kinase, and protein kinase C pathways. PPAPDC1B may also potentiate the estrogen receptor pathway by down-regulating DUSP22.

Standard name | GAURNIER_PSMD4_TARGETS
Systematic name | M11428
Organism | Homo sapiens
PMID | 18632645
Authors | Gaurnier-Hausser A,Rothman VL,Dimitrov S,Tuszynski GP
Category | C2
Sub-category | CGP
Brief description | Inflammatory cytokines, chemokines and their cognate receptors up-regulated in THP-1 cells (monocyte) after treatment with PSMD4 [GeneID=5710].
Full description | We previously showed that angiocidin, a tumor and vascular associated protein, is a potent inhibitor of angiogenesis and tumor growth. Angiocidin is a multidomain protein that exerts its antiangiogenic activity through multiple mechanisms, including effects on cell matrix interaction. Here, we describe another activity of angiocidin that may contribute to its antitumor activity. We show that angiocidin activates monocytes to secrete a mixture of proinflammatory cytokines and induces them to differentiate into macrophage-like cells. Using the monocytic cell line THP-1, we show that angiocidin induces the cells to become adherent and phagocytic, express macrophage markers, and secrete matrix metalloproteinase-9. Microarray analysis of control and angiocidin-treated THP-1 cells revealed that angiocidin up-regulated p105/p50, p100/p52, and rel B, components of the nuclear factor-kappaB (NF-kappaB) pathway. We confirmed the microarray data and showed that angiocidin induced phosphorylation of I kappa beta, p50, and p65 and translocation of p50 and p65 to the nucleus. We also showed that angiocidin activated up-stream mediators of NF-kappaB, such as the mitogen-activated protein kinase (MAPK) pathway and phosphoinositide-3 kinase (PI3K). Blockage of NF-kappaB and MAPK activation with small molecule inhibitors completely prevented angiocidin-mediated secretion of cytokines from THP-1 cells, but did not inhibit their adhesive phenotype. Blocking PI3K inhibited both secretion of cytokines, as well as the adhesive phenotype. These data suggest that angiocidin activates monocytes to secrete cytokines and differentiates them to a macrophage-like phenotype through at least two pathways mediated by MAPK and NF-kappaB, as well as PI3K.

Standard name | EHLERS_ANEUPLOIDY_UP
Systematic name | M7775
Organism | Homo sapiens
PMID | 18172260
Authors | Ehlers JP,Worley L,Onken MD,Harbour JW
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the expression signature of aneuploidy in uveal melanoma tumors: low vs high aneuploidy.
Full description | PURPOSE: Aneuploidy is a hallmark of cancer and is closely linked to metastasis and poor clinical outcome. Yet, the mechanisms leading to aneuploidy and its role in tumor progression remain poorly understood. The extensive and complex karyotypic abnormalities seen in many solid tumors could hinder the identification of pathogenetically relevant chromosomal alterations. Uveal melanoma is an attractive solid tumor for studying aneuploidy because it is a relatively homogeneous cancer that is highly metastatic and has low nonspecific chromosomal instability. EXPERIMENTAL DESIGN: Comparative genomic hybridization and gene expression profiling were used to analyze patterns of aneuploidy in 49 primary uveal melanomas. This analysis was supplemented by a review of cytogenetic findings in 336 published cases. RESULTS: Three prognostically significant tumor subgroups were identified based on the status of chromosomes 3 and 6p. Discrete patterns of chromosomal alterations accumulated in these three subgroups in a nonrandom temporal sequence. Poor clinical outcome was associated with early chromosomal alterations rather than overall aneuploidy. A gene expression signature associated with aneuploidy was enriched for genes involved in cell cycle regulation, centrosome function, and DNA damage repair. One of these genes was PTEN, a tumor suppressor and genomic integrity guardian, which was down-regulated in association with increasing aneuploidy (P = 0.003). CONCLUSIONS: The relationship between aneuploidy and poor prognosis may be determined by specific, pathogenetically relevant chromosomal alterations, rather than overall aneuploidy. Such alterations can be identified using integrative genomic methods and may provide insights for novel therapeutic approaches.

Standard name | EHLERS_ANEUPLOIDY_DN
Systematic name | M2785
Organism | Homo sapiens
PMID | 18172260
Authors | Ehlers JP,Worley L,Onken MD,Harbour JW
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the expression signature of aneuploidy in uveal melanoma tumors: low vs high aneuploidy.
Full description | PURPOSE: Aneuploidy is a hallmark of cancer and is closely linked to metastasis and poor clinical outcome. Yet, the mechanisms leading to aneuploidy and its role in tumor progression remain poorly understood. The extensive and complex karyotypic abnormalities seen in many solid tumors could hinder the identification of pathogenetically relevant chromosomal alterations. Uveal melanoma is an attractive solid tumor for studying aneuploidy because it is a relatively homogeneous cancer that is highly metastatic and has low nonspecific chromosomal instability. EXPERIMENTAL DESIGN: Comparative genomic hybridization and gene expression profiling were used to analyze patterns of aneuploidy in 49 primary uveal melanomas. This analysis was supplemented by a review of cytogenetic findings in 336 published cases. RESULTS: Three prognostically significant tumor subgroups were identified based on the status of chromosomes 3 and 6p. Discrete patterns of chromosomal alterations accumulated in these three subgroups in a nonrandom temporal sequence. Poor clinical outcome was associated with early chromosomal alterations rather than overall aneuploidy. A gene expression signature associated with aneuploidy was enriched for genes involved in cell cycle regulation, centrosome function, and DNA damage repair. One of these genes was PTEN, a tumor suppressor and genomic integrity guardian, which was down-regulated in association with increasing aneuploidy (P = 0.003). CONCLUSIONS: The relationship between aneuploidy and poor prognosis may be determined by specific, pathogenetically relevant chromosomal alterations, rather than overall aneuploidy. Such alterations can be identified using integrative genomic methods and may provide insights for novel therapeutic approaches.

Standard name | ZHENG_GLIOBLASTOMA_PLASTICITY_UP
Systematic name | M1796
Organism | Mus musculus
PMID | 18948956
Authors | Zheng H,Ying H,Yan H,Kimmelman AC,Hiller DJ,Chen AJ,Perry SR,Tonon G,Chu GC,Ding Z,Stommel JM,Dunn KL,Wiedemeyer R,You MJ,Brennan C,Wang YA,Ligon KL,Wong WH,Chin L,DePinho RA
Category | C2
Sub-category | CGP
Brief description | The glioblastoma multiforme (GBM) plasticity signature: genes up-regulated in neural stem cells (NSC) with double knockout of TP53 and PTEN [GeneID=7157;5728] vs those with knockout of TP53 alone.
Full description | Glioblastoma (GBM) is a highly lethal brain tumour presenting as one of two subtypes with distinct clinical histories and molecular profiles. The primary GBM subtype presents acutely as a high-grade disease that typically harbours mutations in EGFR, PTEN and INK4A/ARF (also known as CDKN2A), and the secondary GBM subtype evolves from the slow progression of a low-grade disease that classically possesses PDGF and TP53 events. Here we show that concomitant central nervous system (CNS)-specific deletion of p53 and Pten in the mouse CNS generates a penetrant acute-onset high-grade malignant glioma phenotype with notable clinical, pathological and molecular resemblance to primary GBM in humans. This genetic observation prompted TP53 and PTEN mutational analysis in human primary GBM, demonstrating unexpectedly frequent inactivating mutations of TP53 as well as the expected PTEN mutations. Integrated transcriptomic profiling, in silico promoter analysis and functional studies of murine neural stem cells (NSCs) established that dual, but not singular, inactivation of p53 and Pten promotes an undifferentiated state with high renewal potential and drives increased Myc protein levels and its associated signature. Functional studies validated increased Myc activity as a potent contributor to the impaired differentiation and enhanced renewal of NSCs doubly null for p53 and Pten (p53(-/-) Pten(-/-)) as well as tumour neurospheres (TNSs) derived from this model. Myc also serves to maintain robust tumorigenic potential of p53(-/-) Pten(-/-) TNSs. These murine modelling studies, together with confirmatory transcriptomic/promoter studies in human primary GBM, validate a pathogenetic role of a common tumour suppressor mutation profile in human primary GBM and establish Myc as an important target for cooperative actions of p53 and Pten in the regulation of normal and malignant stem/progenitor cell differentiation, self-renewal and tumorigenic potential.

Standard name | ZHENG_GLIOBLASTOMA_PLASTICITY_DN
Systematic name | M1797
Organism | Mus musculus
PMID | 18948956
Authors | Zheng H,Ying H,Yan H,Kimmelman AC,Hiller DJ,Chen AJ,Perry SR,Tonon G,Chu GC,Ding Z,Stommel JM,Dunn KL,Wiedemeyer R,You MJ,Brennan C,Wang YA,Ligon KL,Wong WH,Chin L,DePinho RA
Category | C2
Sub-category | CGP
Brief description | The glioblastoma multiforme (GBM) plasticity signature: genes down-regulated in neural stem cells (NSC) with double knockout of TP53 and PTEN [GeneID=7157;5728] vs those with knockout of TP53 alone.
Full description | Glioblastoma (GBM) is a highly lethal brain tumour presenting as one of two subtypes with distinct clinical histories and molecular profiles. The primary GBM subtype presents acutely as a high-grade disease that typically harbours mutations in EGFR, PTEN and INK4A/ARF (also known as CDKN2A), and the secondary GBM subtype evolves from the slow progression of a low-grade disease that classically possesses PDGF and TP53 events. Here we show that concomitant central nervous system (CNS)-specific deletion of p53 and Pten in the mouse CNS generates a penetrant acute-onset high-grade malignant glioma phenotype with notable clinical, pathological and molecular resemblance to primary GBM in humans. This genetic observation prompted TP53 and PTEN mutational analysis in human primary GBM, demonstrating unexpectedly frequent inactivating mutations of TP53 as well as the expected PTEN mutations. Integrated transcriptomic profiling, in silico promoter analysis and functional studies of murine neural stem cells (NSCs) established that dual, but not singular, inactivation of p53 and Pten promotes an undifferentiated state with high renewal potential and drives increased Myc protein levels and its associated signature. Functional studies validated increased Myc activity as a potent contributor to the impaired differentiation and enhanced renewal of NSCs doubly null for p53 and Pten (p53(-/-) Pten(-/-)) as well as tumour neurospheres (TNSs) derived from this model. Myc also serves to maintain robust tumorigenic potential of p53(-/-) Pten(-/-) TNSs. These murine modelling studies, together with confirmatory transcriptomic/promoter studies in human primary GBM, validate a pathogenetic role of a common tumour suppressor mutation profile in human primary GBM and establish Myc as an important target for cooperative actions of p53 and Pten in the regulation of normal and malignant stem/progenitor cell differentiation, self-renewal and tumorigenic potential.

Standard name | BUCKANOVICH_T_LYMPHOCYTE_HOMING_ON_TUMOR_UP
Systematic name | M17086
Organism | Homo sapiens
PMID | 18157142
Authors | Buckanovich RJ,Facciabene A,Kim S,Benencia F,Sasaroli D,Balint K,Katsaros D,O'Brien-Jenkins A,Gimotty PA,Coukos G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in microdissected endothelial samples from ovarian cancer tumors with tumor-infiltrating lymphocytes (TIL) vs those without TILs.
Full description | In spite of their having sufficient immunogenicity, tumor vaccines remain largely ineffective. The mechanisms underlying this lack of efficacy are still unclear. Here we report a previously undescribed mechanism by which the tumor endothelium prevents T cell homing and hinders tumor immunotherapy. Transcriptional profiling of microdissected tumor endothelial cells from human ovarian cancers revealed genes associated with the absence or presence of tumor-infiltrating lymphocytes (TILs). Overexpression of the endothelin B receptor (ET(B)R) was associated with the absence of TILs and short patient survival time. The ET(B)R inhibitor BQ-788 increased T cell adhesion to human endothelium in vitro, an effect countered by intercellular adhesion molecule-1 (ICAM-1) blockade or treatment with NO donors. In mice, ET(B)R neutralization by BQ-788 increased T cell homing to tumors; this homing required ICAM-1 and enabled tumor response to otherwise ineffective immunotherapy in vivo without changes in systemic antitumor immune response. These findings highlight a molecular mechanism with the potential to be pharmacologically manipulated to enhance the efficacy of tumor immunotherapy in humans.

Standard name | BUCKANOVICH_T_LYMPHOCYTE_HOMING_ON_TUMOR_DN
Systematic name | M487
Organism | Homo sapiens
PMID | 18157142
Authors | Buckanovich RJ,Facciabene A,Kim S,Benencia F,Sasaroli D,Balint K,Katsaros D,O'Brien-Jenkins A,Gimotty PA,Coukos G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in microdissected endothelial samples from ovarian cancer tumors with tumor-infiltrating lymphocytes (TIL) vs those without TILs.
Full description | In spite of their having sufficient immunogenicity, tumor vaccines remain largely ineffective. The mechanisms underlying this lack of efficacy are still unclear. Here we report a previously undescribed mechanism by which the tumor endothelium prevents T cell homing and hinders tumor immunotherapy. Transcriptional profiling of microdissected tumor endothelial cells from human ovarian cancers revealed genes associated with the absence or presence of tumor-infiltrating lymphocytes (TILs). Overexpression of the endothelin B receptor (ET(B)R) was associated with the absence of TILs and short patient survival time. The ET(B)R inhibitor BQ-788 increased T cell adhesion to human endothelium in vitro, an effect countered by intercellular adhesion molecule-1 (ICAM-1) blockade or treatment with NO donors. In mice, ET(B)R neutralization by BQ-788 increased T cell homing to tumors; this homing required ICAM-1 and enabled tumor response to otherwise ineffective immunotherapy in vivo without changes in systemic antitumor immune response. These findings highlight a molecular mechanism with the potential to be pharmacologically manipulated to enhance the efficacy of tumor immunotherapy in humans.

Standard name | JONES_TCOF1_TARGETS
Systematic name | M1798
Organism | Mus musculus
PMID | 18246078
Authors | Jones NC,Lynn ML,Gaudenz K,Sakai D,Aoto K,Rey JP,Glynn EF,Ellington L,Du C,Dixon J,Dixon MJ,Trainor PA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in E8.5 embryos with heterozygous knockout of TCOF1 [GeneID=6949] compared to wild type.
Full description | Treacher Collins syndrome (TCS) is a congenital disorder of craniofacial development arising from mutations in TCOF1, which encodes the nucleolar phosphoprotein Treacle. Haploinsufficiency of Tcof1 perturbs mature ribosome biogenesis, resulting in stabilization of p53 and the cyclin G1-mediated cell-cycle arrest that underpins the specificity of neuroepithelial apoptosis and neural crest cell hypoplasia characteristic of TCS. Here we show that inhibition of p53 prevents cyclin G1-driven apoptotic elimination of neural crest cells while rescuing the craniofacial abnormalities associated with mutations in Tcof1 and extending life span. These improvements, however, occur independently of the effects on ribosome biogenesis; thus suggesting that it is p53-dependent neuroepithelial apoptosis that is the primary mechanism underlying the pathogenesis of TCS. Our work further implies that neuroepithelial and neural crest cells are particularly sensitive to cellular stress during embryogenesis and that suppression of p53 function provides an attractive avenue for possible clinical prevention of TCS craniofacial birth defects and possibly those of other neurocristopathies.

Standard name | AUJLA_IL22_AND_IL17A_SIGNALING
Systematic name | M6335
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C2
Sub-category | CGP
Brief description | Genes changed in HBE cells (bronchial epithelium) after treatment with IL22 and IL17A [GeneID=50616;3605].
Full description | Emerging evidence supports the concept that T helper type 17 (T(H)17) cells, in addition to mediating autoimmunity, have key roles in mucosal immunity against extracellular pathogens. Interleukin-22 (IL-22) and IL-17A are both effector cytokines produced by the T(H)17 lineage, and both were crucial for maintaining local control of the Gram-negative pulmonary pathogen, Klebsiella pneumoniae. Although both cytokines regulated CXC chemokines and granulocyte colony-stimulating factor production in the lung, only IL-22 increased lung epithelial cell proliferation and increased transepithelial resistance to injury. These data support the concept that the T(H)17 cell lineage and its effector molecules have evolved to effect host defense against extracellular pathogens at mucosal sites.

Standard name | ZHENG_IL22_SIGNALING_UP
Systematic name | M1800
Organism | Mus musculus
PMID | 18264109
Authors | Zheng Y,Valdez PA,Danilenko DM,Hu Y,Sa SM,Gong Q,Abbas AR,Modrusan Z,Ghilardi N,de Sauvage FJ,Ouyang W
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ex-vivo colonic tissue after treatment with IL22 [GeneID=50616].
Full description | Infections by attaching and effacing (A/E) bacterial pathogens, such as Escherichia coli O157:H7, pose a serious threat to public health. Using a mouse A/E pathogen, Citrobacter rodentium, we show that interleukin-22 (IL-22) has a crucial role in the early phase of host defense against C. rodentium. Infection of IL-22 knockout mice results in increased intestinal epithelial damage, systemic bacterial burden and mortality. We also find that IL-23 is required for the early induction of IL-22 during C. rodentium infection, and adaptive immunity is not essential for the protective role of IL-22 in this model. Instead, IL-22 is required for the direct induction of the Reg family of antimicrobial proteins, including RegIIIbeta and RegIIIgamma, in colonic epithelial cells. Exogenous mouse or human RegIIIgamma substantially improves survival of IL-22 knockout mice after C. rodentium infection. Together, our data identify a new innate immune function for IL-22 in regulating early defense mechanisms against A/E bacterial pathogens.

Standard name | ZHENG_IL22_SIGNALING_DN
Systematic name | M1802
Organism | Mus musculus
PMID | 18264109
Authors | Zheng Y,Valdez PA,Danilenko DM,Hu Y,Sa SM,Gong Q,Abbas AR,Modrusan Z,Ghilardi N,de Sauvage FJ,Ouyang W
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ex-vivo colonic tissue after treatment with IL22 [GeneID=50616].
Full description | Infections by attaching and effacing (A/E) bacterial pathogens, such as Escherichia coli O157:H7, pose a serious threat to public health. Using a mouse A/E pathogen, Citrobacter rodentium, we show that interleukin-22 (IL-22) has a crucial role in the early phase of host defense against C. rodentium. Infection of IL-22 knockout mice results in increased intestinal epithelial damage, systemic bacterial burden and mortality. We also find that IL-23 is required for the early induction of IL-22 during C. rodentium infection, and adaptive immunity is not essential for the protective role of IL-22 in this model. Instead, IL-22 is required for the direct induction of the Reg family of antimicrobial proteins, including RegIIIbeta and RegIIIgamma, in colonic epithelial cells. Exogenous mouse or human RegIIIgamma substantially improves survival of IL-22 knockout mice after C. rodentium infection. Together, our data identify a new innate immune function for IL-22 in regulating early defense mechanisms against A/E bacterial pathogens.

Standard name | BOCHKIS_FOXA2_TARGETS
Systematic name | M1806
Organism | Mus musculus
PMID | 18660816
Authors | Bochkis IM,Rubins NE,White P,Furth EE,Friedman JR,Kaestner KH
Category | C2
Sub-category | CGP
Brief description | Direct targets of FOXA2 [GeneID=3170] in liver, according to a ChIP-chip analysis.
Full description | Production of bile by the liver is crucial for the absorption of lipophilic nutrients. Dysregulation of bile acid homeostasis can lead to cholestatic liver disease and endoplasmic reticulum (ER) stress. We show by global location analysis ('ChIP-on-chip') and cell type-specific gene ablation that the winged helix transcription factor Foxa2 is required for normal bile acid homeostasis. As suggested by the location analysis, deletion of Foxa2 in hepatocytes in mice using the Cre-lox system leads to decreased transcription of genes encoding bile acid transporters on both the basolateral and canalicular membranes, resulting in intrahepatic cholestasis. Foxa2-deficient mice are strikingly sensitive to a diet containing cholic acid, which results in toxic accumulation of hepatic bile salts, ER stress and liver injury. In addition, we show that expression of FOXA2 is markedly decreased in liver samples from individuals with different cholestatic syndromes, suggesting that reduced FOXA2 abundance could exacerbate the injury.

Standard name | HONMA_DOCETAXEL_RESISTANCE
Systematic name | M10292
Organism | Homo sapiens
PMID | 18724378
Authors | Honma K,Iwao-Koizumi K,Takeshita F,Yamamoto Y,Yoshida T,Nishio K,Nagahara S,Kato K,Ochiya T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7-ADR cell line (breast cancer) resistant to docetaxel [PubChem=148124].
Full description | Drug resistance acquired by cancer cells has led to treatment failure. To understand the regulatory network underlying docetaxel resistance in breast cancer cells and to identify molecular targets for therapy, we tested small interfering RNAs (siRNAs) against 36 genes whose expression was elevated in human nonresponders to docetaxel for the ability to promote apoptosis of docetaxel-resistant human breast cancer cells (MCF7-ADR cells). The results indicate that the downregulation of the gene encoding ribophorin [corrected] II (RPN2), which is part of an N-oligosaccharyl transferase complex, most efficiently induces apoptosis of MCF7-ADR cells in the presence of docetaxel. RPN2 silencing induced reduced glycosylation of the P-glycoprotein, as well as decreased membrane localization, thereby sensitizing MCF7-ADR cells to docetaxel. Moreover, in vivo delivery of siRNA specific for RPN2 markedly reduced tumor growth in two types of models for drug resistance. Thus, RPN2 silencing makes cancer cells hypersensitive response to docetaxel, and RPN2 might be a new target for RNA interference-based therapeutics against drug resistance.

Standard name | WILENSKY_RESPONSE_TO_DARAPLADIB
Systematic name | M18107
Organism | Homo sapiens
PMID | 18806801
Authors | Wilensky RL,Shi Y,Mohler ER 3rd,Hamamdzic D,Burgert ME,Li J,Postle A,Fenning RS,Bollinger JG,Hoffman BE,Pelchovitz DJ,Yang J,Mirabile RC,Webb CL,Zhang L,Zhang P,Gelb MH,Walker MC,Zalewski A,Macphee CH
Category | C2
Sub-category | CGP
Brief description | Atherosclerotic process genes whose coronary expression changed after darapladib [PubChem=9939609] treatment.
Full description | Increased lipoprotein-associated phospholipase A(2) (Lp-PLA(2)) activity is associated with increased risk of cardiac events, but it is not known whether Lp-PLA(2) is a causative agent. Here we show that selective inhibition of Lp-PLA(2) with darapladib reduced development of advanced coronary atherosclerosis in diabetic and hypercholesterolemic swine. Darapladib markedly inhibited plasma and lesion Lp-PLA(2) activity and reduced lesion lysophosphatidylcholine content. Analysis of coronary gene expression showed that darapladib exerted a general anti-inflammatory action, substantially reducing the expression of 24 genes associated with macrophage and T lymphocyte functioning. Darapladib treatment resulted in a considerable decrease in plaque area and, notably, a markedly reduced necrotic core area and reduced medial destruction, resulting in fewer lesions with an unstable phenotype. These data show that selective inhibition of Lp-PLA(2) inhibits progression to advanced coronary atherosclerotic lesions and confirms a crucial role of vascular inflammation independent from hypercholesterolemia in the development of lesions implicated in the pathogenesis of myocardial infarction and stroke.

Standard name | MATZUK_OVULATION
Systematic name | M1807
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for ovulation, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_CUMULUS_EXPANSION
Systematic name | M1809
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for cumulus expansion, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_FERTILIZATION
Systematic name | M1811
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for fertilization, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_MATERNAL_EFFECT
Systematic name | M1812
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Maternal effect genes, based on mouse models wih female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_IMPLANTATION_AND_UTERINE
Systematic name | M1813
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for implantation and uterine, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_POSTIMPLANTATION_AND_POSTPARTUM
Systematic name | M1815
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for post-implantation and post-partum, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_STEROIDOGENESIS
Systematic name | M1818
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for steroidogenesis, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_MEIOTIC_AND_DNA_REPAIR
Systematic name | M1819
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Meitic and DNA repair genes important for female fertility, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_CENTRAL_FOR_FEMALE_FERTILITY
Systematic name | M1820
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes central for female fertility pathways, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_EMBRYONIC_GERM_CELL
Systematic name | M1821
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for embryonic germ cell, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_EARLY_ANTRAL_FOLLICLE
Systematic name | M1822
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for early anral follicle, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_LUTEAL_GENES
Systematic name | M1824
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Luteal genes, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_PREOVULATORY_FOLLICLE
Systematic name | M1827
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for preovulatory follicle, based on mouse models with female fertility defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_MALE_REPRODUCTION_SERTOLI
Systematic name | M1828
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for Sertoli, peritubular, Leydig and interstitial cells, based on mouse models with male reproductive defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_SPERMATOGONIA
Systematic name | M1829
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for spermatogonia, based on mouse models with male reproductive defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_SPERMATOCYTE
Systematic name | M1831
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for spermatocyte, based on mouse models with male reproductive defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_SPERMATID_DIFFERENTIATION
Systematic name | M1832
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Genes important for spermatid differentiation, based on mouse models with male reproductive defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | MATZUK_SPERMATOZOA
Systematic name | M1833
Organism | Mus musculus
PMID | 18989307
Authors | Matzuk MM,Lamb DJ
Category | C2
Sub-category | CGP
Brief description | Spermatozoa genes, based on mouse models with male reproductive defects.
Full description | Reproduction is required for the survival of all mammalian species, and thousands of essential 'sex' genes are conserved through evolution. Basic research helps to define these genes and the mechanisms responsible for the development, function and regulation of the male and female reproductive systems. However, many infertile couples continue to be labeled with the diagnosis of idiopathic infertility or given descriptive diagnoses that do not provide a cause for their defect. For other individuals with a known etiology, effective cures are lacking, although their infertility is often bypassed with assisted reproductive technologies (ART), some accompanied by safety or ethical concerns. Certainly, progress in the field of reproduction has been realized in the twenty-first century with advances in the understanding of the regulation of fertility, with the production of over 400 mutant mouse models with a reproductive phenotype and with the promise of regenerative gonadal stem cells. Indeed, the past six years have witnessed a virtual explosion in the identification of gene mutations or polymorphisms that cause or are linked to human infertility. Translation of these findings to the clinic remains slow, however, as do new methods to diagnose and treat infertile couples. Additionally, new approaches to contraception remain elusive. Nevertheless, the basic and clinical advances in the understanding of the molecular controls of reproduction are impressive and will ultimately improve patient care.

Standard name | BONCI_TARGETS_OF_MIR15A_AND_MIR16_1
Systematic name | M11682
Organism | Homo sapiens
PMID | 18931683
Authors | Bonci D,Coppola V,Musumeci M,Addario A,Giuffrida R,Memeo L,D'Urso L,Pagliuca A,Biffoni M,Labbaye C,Bartucci M,Muto G,Peschle C,De Maria R
Category | C2
Sub-category | CGP
Brief description | Potential targets of MIR15A and MIR16-1 [GeneID=406948;406950] microRNAs in prostate cancer.
Full description | MicroRNAs (miRNAs) are noncoding small RNAs that repress protein translation by targeting specific messenger RNAs. miR-15a and miR-16-1 act as putative tumor suppressors by targeting the oncogene BCL2. These miRNAs form a cluster at the chromosomal region 13q14, which is frequently deleted in cancer. Here, we report that the miR-15a and miR-16-1 cluster targets CCND1 (encoding cyclin D1) and WNT3A, which promotes several tumorigenic features such as survival, proliferation and invasion. In cancer cells of advanced prostate tumors, the miR-15a and miR-16 level is significantly decreased, whereas the expression of BCL2, CCND1 and WNT3A is inversely upregulated. Delivery of antagomirs specific for miR-15a and miR-16 to normal mouse prostate results in marked hyperplasia, and knockdown of miR-15a and miR-16 promotes survival, proliferation and invasiveness of untransformed prostate cells, which become tumorigenic in immunodeficient NOD-SCID mice. Conversely, reconstitution of miR-15a and miR-16-1 expression results in growth arrest, apoptosis and marked regression of prostate tumor xenografts. Altogether, we propose that miR-15a and miR-16 act as tumor suppressor genes in prostate cancer through the control of cell survival, proliferation and invasion. These findings have therapeutic implications and may be exploited for future treatment of prostate cancer.

Standard name | CHUNG_BLISTER_CYTOTOXICITY_UP
Systematic name | M3026
Organism | Homo sapiens
PMID | 19029983
Authors | Chung WH,Hung SI,Yang JY,Su SC,Huang SP,Wei CY,Chin SW,Chiou CC,Chu SC,Ho HC,Yang CH,Lu CF,Wu JY,Liao YD,Chen YT
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in blister cells from patients with adverse drug reactions (ADR).
Full description | Stevens-Johnson syndrome (SJS) and toxic epidermal necrolysis (TEN) are life-threatening adverse drug reactions characterized by massive epidermal necrosis, in which the specific danger signals involved remain unclear. Here we show that blister cells from skin lesions of SJS-TEN primarily consist of cytotoxic T lymphocytes (CTLs) and natural killer (NK) cells, and both blister fluids and cells were cytotoxic. Gene expression profiling identified granulysin as the most highly expressed cytotoxic molecule, confirmed by quantitative PCR and immunohistochemistry. Granulysin concentrations in the blister fluids were two to four orders of magnitude higher than perforin, granzyme B or soluble Fas ligand concentrations, and depleting granulysin reduced the cytotoxicity. Granulysin in the blister fluids was a 15-kDa secretory form, and injection of it into mouse skin resulted in features mimicking SJS-TEN. Our findings demonstrate that secretory granulysin is a key molecule responsible for the disseminated keratinocyte death in SJS-TEN and highlight a mechanism for CTL- or NK cell--mediated cytotoxicity that does not require direct cellular contact.

Standard name | CHUNG_BLISTER_CYTOTOXICITY_DN
Systematic name | M10850
Organism | Homo sapiens
PMID | 19029983
Authors | Chung WH,Hung SI,Yang JY,Su SC,Huang SP,Wei CY,Chin SW,Chiou CC,Chu SC,Ho HC,Yang CH,Lu CF,Wu JY,Liao YD,Chen YT
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in blister cells from patients with adverse drug reactions (ADR).
Full description | Stevens-Johnson syndrome (SJS) and toxic epidermal necrolysis (TEN) are life-threatening adverse drug reactions characterized by massive epidermal necrosis, in which the specific danger signals involved remain unclear. Here we show that blister cells from skin lesions of SJS-TEN primarily consist of cytotoxic T lymphocytes (CTLs) and natural killer (NK) cells, and both blister fluids and cells were cytotoxic. Gene expression profiling identified granulysin as the most highly expressed cytotoxic molecule, confirmed by quantitative PCR and immunohistochemistry. Granulysin concentrations in the blister fluids were two to four orders of magnitude higher than perforin, granzyme B or soluble Fas ligand concentrations, and depleting granulysin reduced the cytotoxicity. Granulysin in the blister fluids was a 15-kDa secretory form, and injection of it into mouse skin resulted in features mimicking SJS-TEN. Our findings demonstrate that secretory granulysin is a key molecule responsible for the disseminated keratinocyte death in SJS-TEN and highlight a mechanism for CTL- or NK cell--mediated cytotoxicity that does not require direct cellular contact.

Standard name | WHITEFORD_PEDIATRIC_CANCER_MARKERS
Systematic name | M7854
Organism | Homo sapiens
PMID | 17210681
Authors | Whiteford CC,Bilke S,Greer BT,Chen Q,Braunschweig TA,Cenacchi N,Wei JS,Smith MA,Houghton P,Morton C,Reynolds CP,Lock R,Gorlick R,Khanna C,Thiele CJ,Takikita M,Catchpoole D,Hewitt SM,Khan J
Category | C2
Sub-category | CGP
Brief description | Differentially expressed genes in a panel of xenografts representing 8 common pediatric tumors compared to the normal tissues.
Full description | Human tumor xenografts have been used extensively for rapid screening of the efficacy of anticancer drugs for the past 35 years. The selection of appropriate xenograft models for drug testing has been largely empirical and has not incorporated a similarity to the tumor type of origin at the molecular level. This study is the first comprehensive analysis of the transcriptome of a large set of pediatric xenografts, which are currently used for preclinical drug testing. Suitable models representing the tumor type of origin were identified. It was found that the characteristic expression patterns of the primary tumors were maintained in the corresponding xenografts for the majority of samples. Because a prerequisite for developing rationally designed drugs is that the target is expressed at the protein level, we developed tissue arrays from these xenografts and corroborated that high mRNA levels yielded high protein levels for two tested genes. The web database and availability of tissue arrays will allow for the rapid confirmation of the expression of potential targets at both the mRNA and the protein level for molecularly targeted agents. The database will facilitate the identification of tumor markers predictive of response to tested agents as well as the discovery of new molecular targets.

Standard name | GRADE_COLON_AND_RECTAL_CANCER_UP
Systematic name | M16740
Organism | Homo sapiens
PMID | 17210682
Authors | Grade M,Hörmann P,Becker S,Hummon AB,Wangsa D,Varma S,Simon R,Liersch T,Becker H,Difilippantonio MJ,Ghadimi BM,Ried T
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in both rectal and colon carcinoma compared to normal mucosa samples.
Full description | To characterize patterns of global transcriptional deregulation in primary colon carcinomas, we did gene expression profiling of 73 tumors [Unio Internationale Contra Cancrum stage II (n = 33) and stage III (n = 40)] using oligonucleotide microarrays. For 30 of the tumors, expression profiles were compared with those from matched normal mucosa samples. We identified a set of 1,950 genes with highly significant deregulation between tumors and mucosa samples (P < 1e-7). A significant proportion of these genes mapped to chromosome 20 (P = 0.01). Seventeen genes had a >5-fold average expression difference between normal colon mucosa and carcinomas, including up-regulation of MYC and of HMGA1, a putative oncogene. Furthermore, we identified 68 genes that were significantly differentially expressed between lymph node-negative and lymph node-positive tumors (P < 0.001), the functional annotation of which revealed a preponderance of genes that play a role in cellular immune response and surveillance. The microarray-derived gene expression levels of 20 deregulated genes were validated using quantitative real-time reverse transcription-PCR in >40 tumor and normal mucosa samples with good concordance between the techniques. Finally, we established a relationship between specific genomic imbalances, which were mapped for 32 of the analyzed colon tumors by comparative genomic hybridization, and alterations of global transcriptional activity. Previously, we had conducted a similar analysis of primary rectal carcinomas. The systematic comparison of colon and rectal carcinomas revealed a significant overlap of genomic imbalances and transcriptional deregulation, including activation of the Wnt/beta-catenin signaling cascade, suggesting similar pathogenic pathways.

Standard name | GRADE_COLON_AND_RECTAL_CANCER_DN
Systematic name | M15780
Organism | Homo sapiens
PMID | 17210682
Authors | Grade M,Hörmann P,Becker S,Hummon AB,Wangsa D,Varma S,Simon R,Liersch T,Becker H,Difilippantonio MJ,Ghadimi BM,Ried T
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in both rectal and colon carcinoma compared to normal mucosa samples.
Full description | To characterize patterns of global transcriptional deregulation in primary colon carcinomas, we did gene expression profiling of 73 tumors [Unio Internationale Contra Cancrum stage II (n = 33) and stage III (n = 40)] using oligonucleotide microarrays. For 30 of the tumors, expression profiles were compared with those from matched normal mucosa samples. We identified a set of 1,950 genes with highly significant deregulation between tumors and mucosa samples (P < 1e-7). A significant proportion of these genes mapped to chromosome 20 (P = 0.01). Seventeen genes had a >5-fold average expression difference between normal colon mucosa and carcinomas, including up-regulation of MYC and of HMGA1, a putative oncogene. Furthermore, we identified 68 genes that were significantly differentially expressed between lymph node-negative and lymph node-positive tumors (P < 0.001), the functional annotation of which revealed a preponderance of genes that play a role in cellular immune response and surveillance. The microarray-derived gene expression levels of 20 deregulated genes were validated using quantitative real-time reverse transcription-PCR in >40 tumor and normal mucosa samples with good concordance between the techniques. Finally, we established a relationship between specific genomic imbalances, which were mapped for 32 of the analyzed colon tumors by comparative genomic hybridization, and alterations of global transcriptional activity. Previously, we had conducted a similar analysis of primary rectal carcinomas. The systematic comparison of colon and rectal carcinomas revealed a significant overlap of genomic imbalances and transcriptional deregulation, including activation of the Wnt/beta-catenin signaling cascade, suggesting similar pathogenic pathways.

Standard name | GRADE_COLON_VS_RECTAL_CANCER_UP
Systematic name | M9538
Organism | Homo sapiens
PMID | 17210682
Authors | Grade M,Hörmann P,Becker S,Hummon AB,Wangsa D,Varma S,Simon R,Liersch T,Becker H,Difilippantonio MJ,Ghadimi BM,Ried T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in rectal but down-regulated in colon carcinoma compared to normal mucosa samples.
Full description | To characterize patterns of global transcriptional deregulation in primary colon carcinomas, we did gene expression profiling of 73 tumors [Unio Internationale Contra Cancrum stage II (n = 33) and stage III (n = 40)] using oligonucleotide microarrays. For 30 of the tumors, expression profiles were compared with those from matched normal mucosa samples. We identified a set of 1,950 genes with highly significant deregulation between tumors and mucosa samples (P < 1e-7). A significant proportion of these genes mapped to chromosome 20 (P = 0.01). Seventeen genes had a >5-fold average expression difference between normal colon mucosa and carcinomas, including up-regulation of MYC and of HMGA1, a putative oncogene. Furthermore, we identified 68 genes that were significantly differentially expressed between lymph node-negative and lymph node-positive tumors (P < 0.001), the functional annotation of which revealed a preponderance of genes that play a role in cellular immune response and surveillance. The microarray-derived gene expression levels of 20 deregulated genes were validated using quantitative real-time reverse transcription-PCR in >40 tumor and normal mucosa samples with good concordance between the techniques. Finally, we established a relationship between specific genomic imbalances, which were mapped for 32 of the analyzed colon tumors by comparative genomic hybridization, and alterations of global transcriptional activity. Previously, we had conducted a similar analysis of primary rectal carcinomas. The systematic comparison of colon and rectal carcinomas revealed a significant overlap of genomic imbalances and transcriptional deregulation, including activation of the Wnt/beta-catenin signaling cascade, suggesting similar pathogenic pathways.

Standard name | GRADE_COLON_VS_RECTAL_CANCER_DN
Systematic name | M9435
Organism | Homo sapiens
PMID | 17210682
Authors | Grade M,Hörmann P,Becker S,Hummon AB,Wangsa D,Varma S,Simon R,Liersch T,Becker H,Difilippantonio MJ,Ghadimi BM,Ried T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in rectal but up-regulated in colon carcinoma compared to normal mucosa samples.
Full description | To characterize patterns of global transcriptional deregulation in primary colon carcinomas, we did gene expression profiling of 73 tumors [Unio Internationale Contra Cancrum stage II (n = 33) and stage III (n = 40)] using oligonucleotide microarrays. For 30 of the tumors, expression profiles were compared with those from matched normal mucosa samples. We identified a set of 1,950 genes with highly significant deregulation between tumors and mucosa samples (P < 1e-7). A significant proportion of these genes mapped to chromosome 20 (P = 0.01). Seventeen genes had a >5-fold average expression difference between normal colon mucosa and carcinomas, including up-regulation of MYC and of HMGA1, a putative oncogene. Furthermore, we identified 68 genes that were significantly differentially expressed between lymph node-negative and lymph node-positive tumors (P < 0.001), the functional annotation of which revealed a preponderance of genes that play a role in cellular immune response and surveillance. The microarray-derived gene expression levels of 20 deregulated genes were validated using quantitative real-time reverse transcription-PCR in >40 tumor and normal mucosa samples with good concordance between the techniques. Finally, we established a relationship between specific genomic imbalances, which were mapped for 32 of the analyzed colon tumors by comparative genomic hybridization, and alterations of global transcriptional activity. Previously, we had conducted a similar analysis of primary rectal carcinomas. The systematic comparison of colon and rectal carcinomas revealed a significant overlap of genomic imbalances and transcriptional deregulation, including activation of the Wnt/beta-catenin signaling cascade, suggesting similar pathogenic pathways.

Standard name | BOQUEST_STEM_CELL_UP
Systematic name | M1834
Organism | Homo sapiens
PMID | 15635089
Authors | Boquest AC,Shahdadfar A,Frønsdal K,Sigurjonsson O,Tunheim SH,Collas P,Brinchmann JE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in freshly isolated CD31- [GeneID=5175] (stromal stem cells from adipose tissue) versus the CD31+ (non-stem) counterparts.
Full description | Stromal stem cells proliferate in vitro and may be differentiated along several lineages. Freshly isolated, these cells have been too few or insufficiently pure to be thoroughly characterized. Here, we have isolated two populations of CD45-CD34+CD105+ cells from human adipose tissue which could be separated based on expression of CD31. Compared with CD31+ cells, CD31- cells overexpressed transcripts associated with cell cycle quiescence and stemness, and transcripts involved in the biology of cartilage, bone, fat, muscle, and neural tissues. In contrast, CD31+ cells overexpressed transcripts associated with endothelium and the major histocompatibility complex class II complex. Clones of CD31- cells could be expanded in vitro and differentiated into cells with characteristics of bone, fat, and neural-like tissue. On culture, transcripts associated with cell cycle quiescence, stemness, certain cytokines and organ specific genes were down-regulated, whereas transcripts associated with signal transduction, cell adhesion, and cytoskeletal +CD105+CD31- cells from human adipose tissue have stromal stem cell properties which may make them useful for tissue engineering.

Standard name | BOQUEST_STEM_CELL_DN
Systematic name | M1578
Organism | Homo sapiens
PMID | 15635089
Authors | Boquest AC,Shahdadfar A,Frønsdal K,Sigurjonsson O,Tunheim SH,Collas P,Brinchmann JE
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in freshly isolated CD31- [GeneID=5175] (stromal stem cells from adipose tissue) versus the CD31+ (non-stem) counterparts.
Full description | Stromal stem cells proliferate in vitro and may be differentiated along several lineages. Freshly isolated, these cells have been too few or insufficiently pure to be thoroughly characterized. Here, we have isolated two populations of CD45-CD34+CD105+ cells from human adipose tissue which could be separated based on expression of CD31. Compared with CD31+ cells, CD31- cells overexpressed transcripts associated with cell cycle quiescence and stemness, and transcripts involved in the biology of cartilage, bone, fat, muscle, and neural tissues. In contrast, CD31+ cells overexpressed transcripts associated with endothelium and the major histocompatibility complex class II complex. Clones of CD31- cells could be expanded in vitro and differentiated into cells with characteristics of bone, fat, and neural-like tissue. On culture, transcripts associated with cell cycle quiescence, stemness, certain cytokines and organ specific genes were down-regulated, whereas transcripts associated with signal transduction, cell adhesion, and cytoskeletal +CD105+CD31- cells from human adipose tissue have stromal stem cell properties which may make them useful for tissue engineering.

Standard name | BOQUEST_STEM_CELL_CULTURED_VS_FRESH_UP
Systematic name | M17923
Organism | Homo sapiens
PMID | 15635089
Authors | Boquest AC,Shahdadfar A,Frønsdal K,Sigurjonsson O,Tunheim SH,Collas P,Brinchmann JE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in cultured stromal stem cells from adipose tissue, compared to the freshly isolated cells.
Full description | Stromal stem cells proliferate in vitro and may be differentiated along several lineages. Freshly isolated, these cells have been too few or insufficiently pure to be thoroughly characterized. Here, we have isolated two populations of CD45-CD34+CD105+ cells from human adipose tissue which could be separated based on expression of CD31. Compared with CD31+ cells, CD31- cells overexpressed transcripts associated with cell cycle quiescence and stemness, and transcripts involved in the biology of cartilage, bone, fat, muscle, and neural tissues. In contrast, CD31+ cells overexpressed transcripts associated with endothelium and the major histocompatibility complex class II complex. Clones of CD31- cells could be expanded in vitro and differentiated into cells with characteristics of bone, fat, and neural-like tissue. On culture, transcripts associated with cell cycle quiescence, stemness, certain cytokines and organ specific genes were down-regulated, whereas transcripts associated with signal transduction, cell adhesion, and cytoskeletal +CD105+CD31- cells from human adipose tissue have stromal stem cell properties which may make them useful for tissue engineering.

Standard name | BOQUEST_STEM_CELL_CULTURED_VS_FRESH_DN
Systematic name | M12827
Organism | Homo sapiens
PMID | 15635089
Authors | Boquest AC,Shahdadfar A,Frønsdal K,Sigurjonsson O,Tunheim SH,Collas P,Brinchmann JE
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in cultured stromal stem cells from adipose tissue, compared to the freshly isolated cells.
Full description | Stromal stem cells proliferate in vitro and may be differentiated along several lineages. Freshly isolated, these cells have been too few or insufficiently pure to be thoroughly characterized. Here, we have isolated two populations of CD45-CD34+CD105+ cells from human adipose tissue which could be separated based on expression of CD31. Compared with CD31+ cells, CD31- cells overexpressed transcripts associated with cell cycle quiescence and stemness, and transcripts involved in the biology of cartilage, bone, fat, muscle, and neural tissues. In contrast, CD31+ cells overexpressed transcripts associated with endothelium and the major histocompatibility complex class II complex. Clones of CD31- cells could be expanded in vitro and differentiated into cells with characteristics of bone, fat, and neural-like tissue. On culture, transcripts associated with cell cycle quiescence, stemness, certain cytokines and organ specific genes were down-regulated, whereas transcripts associated with signal transduction, cell adhesion, and cytoskeletal +CD105+CD31- cells from human adipose tissue have stromal stem cell properties which may make them useful for tissue engineering.

Standard name | NAKAMURA_METASTASIS
Systematic name | M17162
Organism | Homo sapiens
PMID | 17210693
Authors | Nakamura T,Fidler IJ,Coombes KR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in highly metastatic pancreatic cancer cells.
Full description | To determine the influence of the microenvironment on changes in gene expression, we did microarray analysis on three variant lines of a human pancreatic cancer (FG, L3.3, and L3.6pl) with different metastatic potentials. The variant lines were grown in tissue culture in the subcutis (ectopic) or pancreas (orthotopic) of nude mice. Compared with tissue culture, the number of genes of which the expression was affected by the microenvironment was up-regulated in tumors growing in the subcutis and pancreas. In addition, highly metastatic L3.6pl cells growing in the pancreas expressed significantly higher levels of 226 genes than did the L3.3 or FG variant cells. Growth of the variant lines in the subcutis did not yield similar results, indicating that the orthotopic microenvironment significantly influences gene expression in pancreatic cancer cells. These data suggest that investigations of the functional consequence of gene expression require accounting for experimental growth conditions.

Standard name | NAKAMURA_METASTASIS_MODEL_UP
Systematic name | M18483
Organism | Homo sapiens
PMID | 17210693
Authors | Nakamura T,Fidler IJ,Coombes KR
Category | C2
Sub-category | CGP
Brief description | Top genes up-regulated in orthotopic tumors from highly metastatic pancreatic cancer cells.
Full description | To determine the influence of the microenvironment on changes in gene expression, we did microarray analysis on three variant lines of a human pancreatic cancer (FG, L3.3, and L3.6pl) with different metastatic potentials. The variant lines were grown in tissue culture in the subcutis (ectopic) or pancreas (orthotopic) of nude mice. Compared with tissue culture, the number of genes of which the expression was affected by the microenvironment was up-regulated in tumors growing in the subcutis and pancreas. In addition, highly metastatic L3.6pl cells growing in the pancreas expressed significantly higher levels of 226 genes than did the L3.3 or FG variant cells. Growth of the variant lines in the subcutis did not yield similar results, indicating that the orthotopic microenvironment significantly influences gene expression in pancreatic cancer cells. These data suggest that investigations of the functional consequence of gene expression require accounting for experimental growth conditions.

Standard name | NAKAMURA_METASTASIS_MODEL_DN
Systematic name | M15940
Organism | Homo sapiens
PMID | 17210693
Authors | Nakamura T,Fidler IJ,Coombes KR
Category | C2
Sub-category | CGP
Brief description | Bottom genes down-regulated in subcutaneous tumors from highly metastatic pancreatic cancer cells.
Full description | To determine the influence of the microenvironment on changes in gene expression, we did microarray analysis on three variant lines of a human pancreatic cancer (FG, L3.3, and L3.6pl) with different metastatic potentials. The variant lines were grown in tissue culture in the subcutis (ectopic) or pancreas (orthotopic) of nude mice. Compared with tissue culture, the number of genes of which the expression was affected by the microenvironment was up-regulated in tumors growing in the subcutis and pancreas. In addition, highly metastatic L3.6pl cells growing in the pancreas expressed significantly higher levels of 226 genes than did the L3.3 or FG variant cells. Growth of the variant lines in the subcutis did not yield similar results, indicating that the orthotopic microenvironment significantly influences gene expression in pancreatic cancer cells. These data suggest that investigations of the functional consequence of gene expression require accounting for experimental growth conditions.

Standard name | GRATIAS_RETINOBLASTOMA_16Q24
Systematic name | M8458
Organism | Homo sapiens
PMID | 17210724
Authors | Gratias S,Rieder H,Ullmann R,Klein-Hitpass L,Schneider S,Bölöni R,Kappler M,Lohmann DR
Category | C2
Sub-category | CGP
Brief description | Genes from 16q24 region up-regulated in retinoblastoma tumors with 16q24 LOH (loss of heterozygocity) compared to those without the LOH.
Full description | In addition to RB1 gene mutations, retinoblastomas frequently show gains of 1q and 6p and losses of 16q. To identify suppressor genes on 16q, we analyzed 22 short tandem repeat loci in 58 patients with known RB1 mutations. A subset of tumors was also investigated by conventional and matrix comparative genomic hybridization. In 40 of 58 (69%) tumors, we found no loss of heterozygosity (LOH) at any 16q marker. LOH was detected in 18 of 58 (31%) tumors, including five with allelic imbalance at some markers. In one tumor LOH was only observed at 16q24. As the parental origin of allele loss was unbiased, an imprinted locus is unlikely to be involved. Analysis of gene expression by microarray hybridization and quantitative RT real-time PCR did not identify a candidate suppressor in 16q24. Cadherin 13 (CDH13), CBFA2T3, and WFDC1, which are candidate suppressors in other tumor entities with 16q24 loss, did not show loss of expression. In addition, mutation and methylation analysis showed no somatic alteration of CDH13. Results in all tumors with chromosome 16 alterations define a single minimal deleted region of 5.7 Mb in the telomeric part of 16q24 with the centromeric boundary defined by retention of heterozygosity for a single nucleotide variant in exon 10 of CDH13 (Mb 82.7). Interestingly, clinical presentation of tumors with and without 16q alterations was distinct. Specifically, almost all retinoblastomas with 16q24 loss showed diffuse intraocular seeding. This suggests that genetic alterations in the minimal deleted region are associated with impaired cell-to-cell adhesion.

Standard name | WEST_ADRENOCORTICAL_TUMOR_UP
Systematic name | M1918
Organism | Homo sapiens
PMID | 17234769
Authors | West AN,Neale GA,Pounds S,Figueredo BC,Rodriguez Galindo C,Pianovski MA,Oliveira Filho AG,Malkin D,Lalli E,Ribeiro R,Zambetti GP
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in pediatric adrenocortical tumors (ACT) compared to the normal tissue.
Full description | Pediatric adrenocortical tumors (ACT) are rare and often fatal malignancies; little is known regarding their etiology and biology. To provide additional insight into the nature of ACT, we determined the gene expression profiles of 24 pediatric tumors (five adenomas, 18 carcinomas, and one undetermined) and seven normal adrenal glands. Distinct patterns of gene expression, validated by quantitative real-time PCR and Western blot analysis, were identified that distinguish normal adrenal cortex from tumor. Differences in gene expression were also identified between adrenocortical adenomas and carcinomas. In addition, pediatric adrenocortical carcinomas were found to share similar patterns of gene expression when compared with those published for adult ACT. This study represents the first microarray analysis of childhood ACT. Our findings lay the groundwork for establishing gene expression profiles that may aid in the diagnosis and prognosis of pediatric ACT, and in the identification of signaling pathways that contribute to this disease.

Standard name | WEST_ADRENOCORTICAL_TUMOR_DN
Systematic name | M3837
Organism | Homo sapiens
PMID | 17234769
Authors | West AN,Neale GA,Pounds S,Figueredo BC,Rodriguez Galindo C,Pianovski MA,Oliveira Filho AG,Malkin D,Lalli E,Ribeiro R,Zambetti GP
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in pediatric adrenocortical tumors (ACT) compared to the normal tissue.
Full description | Pediatric adrenocortical tumors (ACT) are rare and often fatal malignancies; little is known regarding their etiology and biology. To provide additional insight into the nature of ACT, we determined the gene expression profiles of 24 pediatric tumors (five adenomas, 18 carcinomas, and one undetermined) and seven normal adrenal glands. Distinct patterns of gene expression, validated by quantitative real-time PCR and Western blot analysis, were identified that distinguish normal adrenal cortex from tumor. Differences in gene expression were also identified between adrenocortical adenomas and carcinomas. In addition, pediatric adrenocortical carcinomas were found to share similar patterns of gene expression when compared with those published for adult ACT. This study represents the first microarray analysis of childhood ACT. Our findings lay the groundwork for establishing gene expression profiles that may aid in the diagnosis and prognosis of pediatric ACT, and in the identification of signaling pathways that contribute to this disease.

Standard name | WEST_ADRENOCORTICAL_CARCINOMA_VS_ADENOMA_UP
Systematic name | M14030
Organism | Homo sapiens
PMID | 17234769
Authors | West AN,Neale GA,Pounds S,Figueredo BC,Rodriguez Galindo C,Pianovski MA,Oliveira Filho AG,Malkin D,Lalli E,Ribeiro R,Zambetti GP
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in pediatric adrenocortical carcinoma (ACC) compared to the adenoma (ACA) tumors.
Full description | Pediatric adrenocortical tumors (ACT) are rare and often fatal malignancies; little is known regarding their etiology and biology. To provide additional insight into the nature of ACT, we determined the gene expression profiles of 24 pediatric tumors (five adenomas, 18 carcinomas, and one undetermined) and seven normal adrenal glands. Distinct patterns of gene expression, validated by quantitative real-time PCR and Western blot analysis, were identified that distinguish normal adrenal cortex from tumor. Differences in gene expression were also identified between adrenocortical adenomas and carcinomas. In addition, pediatric adrenocortical carcinomas were found to share similar patterns of gene expression when compared with those published for adult ACT. This study represents the first microarray analysis of childhood ACT. Our findings lay the groundwork for establishing gene expression profiles that may aid in the diagnosis and prognosis of pediatric ACT, and in the identification of signaling pathways that contribute to this disease.

Standard name | WEST_ADRENOCORTICAL_CARCINOMA_VS_ADENOMA_DN
Systematic name | M18519
Organism | Homo sapiens
PMID | 17234769
Authors | West AN,Neale GA,Pounds S,Figueredo BC,Rodriguez Galindo C,Pianovski MA,Oliveira Filho AG,Malkin D,Lalli E,Ribeiro R,Zambetti GP
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in pediatric adrenocortical carcinoma (ACC) compared to the adenoma (ACA) tumors.
Full description | Pediatric adrenocortical tumors (ACT) are rare and often fatal malignancies; little is known regarding their etiology and biology. To provide additional insight into the nature of ACT, we determined the gene expression profiles of 24 pediatric tumors (five adenomas, 18 carcinomas, and one undetermined) and seven normal adrenal glands. Distinct patterns of gene expression, validated by quantitative real-time PCR and Western blot analysis, were identified that distinguish normal adrenal cortex from tumor. Differences in gene expression were also identified between adrenocortical adenomas and carcinomas. In addition, pediatric adrenocortical carcinomas were found to share similar patterns of gene expression when compared with those published for adult ACT. This study represents the first microarray analysis of childhood ACT. Our findings lay the groundwork for establishing gene expression profiles that may aid in the diagnosis and prognosis of pediatric ACT, and in the identification of signaling pathways that contribute to this disease.

Standard name | DONATO_CELL_CYCLE_TRETINOIN
Systematic name | M12434
Organism | Homo sapiens
PMID | 17234770
Authors | Donato LJ,Suh JH,Noy N
Category | C2
Sub-category | CGP
Brief description | Genes involved in cell cycle regulation which were up-regulated in MCF-7 cells (breast cancer) by tretinoin (retinoic acid) [PubChem=444795].
Full description | The anticarcinogenic activities of retinoic acid (RA) are believed to be mediated by the nuclear RA receptor (RAR) and by the RA-binding protein cellular RA-binding protein-II (CRABP-II). In MCF-7 mammary carcinoma cells, growth inhibition by RA entails an early cell cycle arrest followed by induction of apoptosis. Here, we aimed to obtain insights into the initial cell cycle response. We show that a 3- to 5-h RA pulse is sufficient for inducing a robust growth arrest 2 to 4 days later, demonstrating inhibition of the G1-S transition by RA is triggered by immediate-early RAR targets and does not require the continuous presence of the hormone throughout the arrest program. Expression array analyses revealed that RA induces the expression of several genes involved in cell cycle regulation, including the p53-controlled antiproliferative gene B-cell translocation gene, member 2 (Btg2) and the BTG family member Tob1. We show that induction of Btg2 by RA does not require de novo protein synthesis and is augmented by overexpression of CRABP-II. Additionally, we identify a RA response element in the Btg2 promoter and show that the element binds retinoid X receptor/RAR heterodimers in vitro, is occupied by the heterodimers in cells, and can drive RA-induced activation of a reporter gene. Hence, Btg2 is a novel direct target for RA signaling. In concert with the reports that Btg2 inhibits cell cycle progression by down-regulating cyclin D1, induction of Btg2 by RA was accompanied by a marked decrease in cyclin D1 expression. The observations thus show that the antiproliferative activity of RA in MCF-7 cells is mediated, at least in part, by Btg2.

Standard name | CHO_NR4A1_TARGETS
Systematic name | M14560
Organism | Homo sapiens
PMID | 17234778
Authors | Cho SD,Yoon K,Chintharlapalli S,Abdelrahim M,Lei P,Hamilton S,Khan S,Ramaiah SK,Safe S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RKO cells (colon cancer) after treatment with the NR4A1 [GeneID=3164] agonist, DIM-C-pPhOCH3.
Full description | Nerve growth factor-induced Balpha (NGFI-Balpha, Nur77) is an orphan nuclear receptor with no known endogenous ligands; however, recent studies on a series of methylene-substituted diindolylmethanes (C-DIM) have identified 1,1-bis(3'-indolyl)-1-(phenyl)methane (DIM-C-Ph) and 1,1-bis(3'-indolyl)-1-(p-anisyl)methane (DIM-C-pPhOCH3) as Nur77 agonists. Nur77 is expressed in several colon cancer cell lines (RKO, SW480, HCT-116, HT-29, and HCT-15), and we also observed by immunostaining that Nur77 was overexpressed in colon tumors compared with normal colon tissue. DIM-C-Ph and DIM-C-pPhOCH3 decreased survival and induced apoptosis in RKO colon cancer cells, and this was accompanied by induction of tumor necrosis factor-related apoptosis-inducing ligand (TRAIL) protein. The induction of apoptosis and TRAIL by DIM-C-pPhOCH3 was significantly inhibited by a small inhibitory RNA for Nur77 (iNur77); however, it was evident from RNA interference studies that DIM-C-pPhOCH3 also induced Nur77-independent apoptosis. Analysis of DIM-C-pPhOCH3-induced gene expression using microarrays identified several proapoptotic genes, and analysis by reverse transcription-PCR in the presence or absence of iNur77 showed that induction of programmed cell death gene 1 was Nur77 dependent, whereas induction of cystathionase and activating transcription factor 3 was Nur77 independent. DIM-C-pPhOCH3 (25 mg/kg/d) also inhibited tumor growth in athymic nude mice bearing RKO cell xenografts. These results show that Nur77-active C-DIM compounds represent a new class of anti-colon cancer drugs that act through receptor-dependent and receptor-independent pathways.

Standard name | BHATI_G2M_ARREST_BY_2METHOXYESTRADIOL_UP
Systematic name | M18550
Organism | Homo sapiens
PMID | 17234781
Authors | Bhati R,Gökmen-Polar Y,Sledge GW,Fan C,Nakshatri H,Ketelsen D,Borchers CH,Dial MJ,Patterson C,Klauber-DeMore N
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in MDA-MB-435 cells (breast cancer) undergoing G2/M arrest after treatment with 2-methoxyestradiol (2ME2)[PubChem=1573].
Full description | 2-methoxyestradiol (2ME2), an estradiol metabolite with antiproliferative and antiangiogenic activities, is in phase I/II clinical trials for breast cancer. 2ME2 inhibits microtubule polymerization and causes cells to arrest in G2-M. The purpose of this study was to further elucidate the molecular mechanism of 2ME2. MDA-MB-435 breast cancer cells were treated with 2ME2 (2 micromol/L) or vehicle alone. RNA was extracted and genomic profiling was done using 22k Agilent microarrays. Expression Analysis Systematic Explorer was used to determine enrichment of Gene Ontology categories. Protein isolates were subjected to Western blot analysis. Protein synthesis was measured with a [35S]methionine pulse assay. An MDA-MB-435 cell line with two beta-tubulin mutations (2ME2R) was used to determine whether novel mechanisms were tubulin-dependent. Gene Ontology categories enriched include genes that regulate the mitotic spindle assembly checkpoint, apoptosis, and the cytosolic ribosome. The target of the mitotic spindle assembly checkpoint is the anaphase-promoting complex (APC). APC inhibition was confirmed by measuring protein levels of its targets securin and cyclin B1, which were increased in 2ME2-treated cells. Because gene expression in the cytosolic ribosome category was decreased, we evaluated whether 2ME2 decreases protein translation. This was confirmed with a pulse assay, which showed decreased isotope incorporation in 2ME2-treated cells, which was maintained in the tubulin-resistant 2ME2R cells. APC inhibition was not maintained in 2ME2R cells. 2ME2 induces tubulin-dependent cell cycle arrest through regulation of genes involved in the mitotic spindle assembly checkpoint, which results in inhibition of the APC and tubulin-independent inhibition of protein translation.

Standard name | BHATI_G2M_ARREST_BY_2METHOXYESTRADIOL_DN
Systematic name | M10839
Organism | Homo sapiens
PMID | 17234781
Authors | Bhati R,Gökmen-Polar Y,Sledge GW,Fan C,Nakshatri H,Ketelsen D,Borchers CH,Dial MJ,Patterson C,Klauber-DeMore N
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in MDA-MB-435 cells (breast cancer) undergoing G2/M arrest after treatment with 2-methoxyestradiol (2ME2) [PubChem=1573].
Full description | 2-methoxyestradiol (2ME2), an estradiol metabolite with antiproliferative and antiangiogenic activities, is in phase I/II clinical trials for breast cancer. 2ME2 inhibits microtubule polymerization and causes cells to arrest in G2-M. The purpose of this study was to further elucidate the molecular mechanism of 2ME2. MDA-MB-435 breast cancer cells were treated with 2ME2 (2 micromol/L) or vehicle alone. RNA was extracted and genomic profiling was done using 22k Agilent microarrays. Expression Analysis Systematic Explorer was used to determine enrichment of Gene Ontology categories. Protein isolates were subjected to Western blot analysis. Protein synthesis was measured with a [35S]methionine pulse assay. An MDA-MB-435 cell line with two beta-tubulin mutations (2ME2R) was used to determine whether novel mechanisms were tubulin-dependent. Gene Ontology categories enriched include genes that regulate the mitotic spindle assembly checkpoint, apoptosis, and the cytosolic ribosome. The target of the mitotic spindle assembly checkpoint is the anaphase-promoting complex (APC). APC inhibition was confirmed by measuring protein levels of its targets securin and cyclin B1, which were increased in 2ME2-treated cells. Because gene expression in the cytosolic ribosome category was decreased, we evaluated whether 2ME2 decreases protein translation. This was confirmed with a pulse assay, which showed decreased isotope incorporation in 2ME2-treated cells, which was maintained in the tubulin-resistant 2ME2R cells. APC inhibition was not maintained in 2ME2R cells. 2ME2 induces tubulin-dependent cell cycle arrest through regulation of genes involved in the mitotic spindle assembly checkpoint, which results in inhibition of the APC and tubulin-independent inhibition of protein translation.

Standard name | CLIMENT_BREAST_CANCER_COPY_NUMBER_UP
Systematic name | M13910
Organism | Homo sapiens
PMID | 17234794
Authors | Climent J,Dimitrow P,Fridlyand J,Palacios J,Siebert R,Albertson DG,Gray JW,Pinkel D,Lluch A,Martinez-Climent JA
Category | C2
Sub-category | CGP
Brief description | Genes from the most frequent genomic gains and amplifications in a panel of patients with lymph node negative breast cancer (NNBC).
Full description | Despite the recent consensus on the eligibility of adjuvant systemic therapy in patients with lymph node-negative breast cancer (NNBC) based on clinicopathologic criteria, specific biological markers are needed to predict sensitivity to the different available therapeutic options. We examined the feasibility of developing a genomic predictor of chemotherapy response and recurrence risk in 185 patients with NNBC using assembled arrays containing 2,460 bacterial artificial chromosome clones for scanning the genome for DNA copy number changes. After surgery, 90 patients received anthracycline-based chemotherapy, whereas 95 did not. Tamoxifen was administered to patients with hormone receptor-positive tumors. The association of genomic and clinicopathologic data and outcome was computed using Cox proportional hazard models and multiple testing adjustment procedures. Analysis of NNBC genomes revealed a common genomic signature. Specific DNA copy number aberrations were associated with hormonal receptor status, but not with other clinicopathologic variables. In patients treated with chemotherapy, none of the genomic changes were significantly correlated with recurrence. In patients not receiving chemotherapy, deletion of eight bacterial artificial chromosome clones clustered to chromosome 11q was independently associated with relapse (disease-free survival at 10 years+/-SE, 40%+/-14% versus 86%+/-6%; P<0.0001). The 54 patients with deletion of 11q (29%) did not present more aggressive clinicopathologic features than those without 11q loss. The adverse influence of 11q deletion on clinical outcome was confirmed in an independent validation series of 88 patients with NNBC. Our data suggests that patients with NNBC with the 11q deletion might benefit from anthracycline-based chemotherapy despite other clinical, pathologic, or genetic features. However, these initial findings should be evaluated in randomized clinical trials.

Standard name | CLIMENT_BREAST_CANCER_COPY_NUMBER_DN
Systematic name | M5098
Organism | Homo sapiens
PMID | 17234794
Authors | Climent J,Dimitrow P,Fridlyand J,Palacios J,Siebert R,Albertson DG,Gray JW,Pinkel D,Lluch A,Martinez-Climent JA
Category | C2
Sub-category | CGP
Brief description | Genes from the most frequent genomic losses and homozygous deletions in a panel of patients with lymph node negative breast cancer (NNBC).
Full description | Despite the recent consensus on the eligibility of adjuvant systemic therapy in patients with lymph node-negative breast cancer (NNBC) based on clinicopathologic criteria, specific biological markers are needed to predict sensitivity to the different available therapeutic options. We examined the feasibility of developing a genomic predictor of chemotherapy response and recurrence risk in 185 patients with NNBC using assembled arrays containing 2,460 bacterial artificial chromosome clones for scanning the genome for DNA copy number changes. After surgery, 90 patients received anthracycline-based chemotherapy, whereas 95 did not. Tamoxifen was administered to patients with hormone receptor-positive tumors. The association of genomic and clinicopathologic data and outcome was computed using Cox proportional hazard models and multiple testing adjustment procedures. Analysis of NNBC genomes revealed a common genomic signature. Specific DNA copy number aberrations were associated with hormonal receptor status, but not with other clinicopathologic variables. In patients treated with chemotherapy, none of the genomic changes were significantly correlated with recurrence. In patients not receiving chemotherapy, deletion of eight bacterial artificial chromosome clones clustered to chromosome 11q was independently associated with relapse (disease-free survival at 10 years+/-SE, 40%+/-14% versus 86%+/-6%; P<0.0001). The 54 patients with deletion of 11q (29%) did not present more aggressive clinicopathologic features than those without 11q loss. The adverse influence of 11q deletion on clinical outcome was confirmed in an independent validation series of 88 patients with NNBC. Our data suggests that patients with NNBC with the 11q deletion might benefit from anthracycline-based chemotherapy despite other clinical, pathologic, or genetic features. However, these initial findings should be evaluated in randomized clinical trials.

Standard name | SHARMA_PILOCYTIC_ASTROCYTOMA_LOCATION_UP
Systematic name | M4447
Organism | Homo sapiens
PMID | 17283119
Authors | Sharma MK,Mansur DB,Reifenberger G,Perry A,Leonard JR,Aldape KD,Albin MG,Emnett RJ,Loeser S,Watson MA,Nagarajan R,Gutmann DH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pilocytic astrocytoma (PA) from supratentorial regions compared to the infratentorial PA tumors.
Full description | Pilocytic astrocytomas (PAs) are the most common glioma in children. Whereas many PAs are slow-growing or clinically indolent, others exhibit more aggressive features with tumor recurrence and death. To identify genetic signatures that might predict PA clinical behavior, we did gene expression profiling on 41 primary PAs arising sporadically and in patients with neurofibromatosis type 1 (NF1). Whereas no expression signature was found that could discriminate clinically aggressive or recurrent tumors from more indolent cases, PAs arising in patients with NF1 did exhibit a unique gene expression pattern. In addition, we identified a gene expression signature that stratified PAs by location (supratentorial versus infratentorial). Lastly, we also identified a gene expression pattern common to PAs and normal mouse astrocytes and neural stem cells from these distinct brain regions as well as a gene expression pattern shared between PAs and another human glial tumor (ependymoma) arising supratentorially compared with those originating in the posterior fossa. These results suggest that glial tumors share an intrinsic, lineage-specific molecular signature that reflects the brain region in which their nonmalignant predecessors originated.

Standard name | SHARMA_PILOCYTIC_ASTROCYTOMA_LOCATION_DN
Systematic name | M19757
Organism | Homo sapiens
PMID | 17283119
Authors | Sharma MK,Mansur DB,Reifenberger G,Perry A,Leonard JR,Aldape KD,Albin MG,Emnett RJ,Loeser S,Watson MA,Nagarajan R,Gutmann DH
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pilocytic astrocytoma (PA) from supratentorial regions compared to the infratentorial PA tumors.
Full description | Pilocytic astrocytomas (PAs) are the most common glioma in children. Whereas many PAs are slow-growing or clinically indolent, others exhibit more aggressive features with tumor recurrence and death. To identify genetic signatures that might predict PA clinical behavior, we did gene expression profiling on 41 primary PAs arising sporadically and in patients with neurofibromatosis type 1 (NF1). Whereas no expression signature was found that could discriminate clinically aggressive or recurrent tumors from more indolent cases, PAs arising in patients with NF1 did exhibit a unique gene expression pattern. In addition, we identified a gene expression signature that stratified PAs by location (supratentorial versus infratentorial). Lastly, we also identified a gene expression pattern common to PAs and normal mouse astrocytes and neural stem cells from these distinct brain regions as well as a gene expression pattern shared between PAs and another human glial tumor (ependymoma) arising supratentorially compared with those originating in the posterior fossa. These results suggest that glial tumors share an intrinsic, lineage-specific molecular signature that reflects the brain region in which their nonmalignant predecessors originated.

Standard name | TSUDA_ALVEOLAR_SOFT_PART_SARCOMA
Systematic name | M4000
Organism | Homo sapiens
PMID | 17283122
Authors | Tsuda M,Davis IJ,Argani P,Shukla N,McGill GG,Nagai M,Saito T,Laé M,Fisher DE,Ladanyi M
Category | C2
Sub-category | CGP
Brief description | Protein kinase genes most significantly up-regulated in ASPS (alveolar soft part sarcoma) tumors compared to four other types of primitive sarcomas.
Full description | Specific chromosomal translocations encoding chimeric transcription factors are considered to play crucial oncogenic roles in a variety of human cancers but the fusion proteins themselves seldom represent suitable therapeutic targets. Oncogenic TFE3 fusion proteins define a subset of pediatric renal adenocarcinomas and one fusion (ASPL-TFE3) is also characteristic of alveolar soft part sarcoma (ASPS). By expression profiling, we identified the MET receptor tyrosine kinase gene as significantly overexpressed in ASPS relative to four other types of primitive sarcomas. We therefore examined MET as a direct transcriptional target of ASPL-TFE3. ASPL-TFE3 binds to the MET promoter and strongly activates it. Likewise, PSF-TFE3 and NONO-TFE3 also bind this promoter. Induction of MET by ASPL-TFE3 results in strong MET autophosphorylation and activation of downstream signaling in the presence of hepatocyte growth factor (HGF). In cancer cell lines containing endogenous TFE3 fusion proteins, inhibiting MET by RNA interference or by the inhibitor PHA665752 abolishes HGF-dependent MET activation, causing decreased cell growth and loss of HGF-dependent phenotypes. MET is thus a potential therapeutic target in these cancers. Aberrant transcriptional up-regulation of MET by oncogenic TFE3 fusion proteins represents another mechanism by which certain cancers become dependent on MET signaling. The identification of kinase signaling pathways transcriptionally up-regulated by oncogenic fusion proteins may reveal more accessible therapeutic targets in this class of human cancers.

Standard name | RAY_TUMORIGENESIS_BY_ERBB2_CDC25A_UP
Systematic name | M1844
Organism | Mus musculus
PMID | 17283130
Authors | Ray D,Terao Y,Fuhrken PG,Ma ZQ,DeMayo FJ,Christov K,Heerema NA,Franks R,Tsai SY,Papoutsakis ET,Kiyokawa H
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in breast tumors from transgenic mice overexpressing ERBB2 and CDC25A [GeneID=2064;993] compared to those from mice overexpressing ERBB2 only.
Full description | Checkpoint pathways help cells maintain genomic integrity, delaying cell cycle progression in response to various risks of fidelity, such as genotoxic stresses, compromised DNA replication, and impaired spindle control. Cancer cells frequently exhibit genomic instability, and recent studies showed that checkpoint pathways are likely to serve as a tumor-suppressive barrier in vivo. The cell cycle-promoting phosphatase CDC25A is an activator of cyclin-dependent kinases and one of the downstream targets for the CHK1-mediated checkpoint pathway. Whereas CDC25A overexpression is observed in various human cancer tissues, it has not been determined whether deregulated CDC25A expression triggers or promotes tumorigenesis in vivo. Here, we show that transgenic expression of CDC25A cooperates markedly with oncogenic ras or neu in murine mammary tumorigenesis. MMTV-CDC25A transgenic mice exhibit alveolar hyperplasia in the mammary tissue but do not develop spontaneous mammary tumors. The MMTV-CDC25A transgene markedly shortens latency of tumorigenesis in MMTV-ras mice. The MMTV-CDC25A transgene also accelerates tumor growth in MMTV-neu mice with apparent cell cycle miscoordination. CDC25A-overexpressing tumors, which invade more aggressively, exhibit various chromosomal aberrations on fragile regions, including the mouse counterpart of human 1p31-36, according to array-based comparative genomic hybridization and karyotyping. The chromosomal aberrations account for substantial changes in gene expression profile rendered by transgenic expression of CDC25A, including down-regulation of Trp73. These data indicate that deregulated control of cellular CDC25A levels leads to in vivo genomic instability, which cooperates with the neu-ras oncogenic pathway in mammary tumorigenesis.

Standard name | RAY_TUMORIGENESIS_BY_ERBB2_CDC25A_DN
Systematic name | M1845
Organism | Mus musculus
PMID | 17283130
Authors | Ray D,Terao Y,Fuhrken PG,Ma ZQ,DeMayo FJ,Christov K,Heerema NA,Franks R,Tsai SY,Papoutsakis ET,Kiyokawa H
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in breast tumors from transgenic mice overexpressing ERBB2 and CDC25A [GeneID=2064;993] compared to those from mice overexpressing ERBB2 only.
Full description | Checkpoint pathways help cells maintain genomic integrity, delaying cell cycle progression in response to various risks of fidelity, such as genotoxic stresses, compromised DNA replication, and impaired spindle control. Cancer cells frequently exhibit genomic instability, and recent studies showed that checkpoint pathways are likely to serve as a tumor-suppressive barrier in vivo. The cell cycle-promoting phosphatase CDC25A is an activator of cyclin-dependent kinases and one of the downstream targets for the CHK1-mediated checkpoint pathway. Whereas CDC25A overexpression is observed in various human cancer tissues, it has not been determined whether deregulated CDC25A expression triggers or promotes tumorigenesis in vivo. Here, we show that transgenic expression of CDC25A cooperates markedly with oncogenic ras or neu in murine mammary tumorigenesis. MMTV-CDC25A transgenic mice exhibit alveolar hyperplasia in the mammary tissue but do not develop spontaneous mammary tumors. The MMTV-CDC25A transgene markedly shortens latency of tumorigenesis in MMTV-ras mice. The MMTV-CDC25A transgene also accelerates tumor growth in MMTV-neu mice with apparent cell cycle miscoordination. CDC25A-overexpressing tumors, which invade more aggressively, exhibit various chromosomal aberrations on fragile regions, including the mouse counterpart of human 1p31-36, according to array-based comparative genomic hybridization and karyotyping. The chromosomal aberrations account for substantial changes in gene expression profile rendered by transgenic expression of CDC25A, including down-regulation of Trp73. These data indicate that deregulated control of cellular CDC25A levels leads to in vivo genomic instability, which cooperates with the neu-ras oncogenic pathway in mammary tumorigenesis.

Standard name | YAGUE_PRETUMOR_DRUG_RESISTANCE_UP
Systematic name | M12825
Organism | Homo sapiens
PMID | 17283147
Authors | Yagüe E,Arance A,Kubitza L,O'Hare M,Jat P,Ogilvie CM,Hart IR,Higgins CF,Raguz S
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes common to all pretumorigenic cells with acquired drug resistance.
Full description | Resistance to chemotherapy is one of the principal causes of cancer mortality and is generally considered a late event in tumor progression. Although cellular models of drug resistance have been useful in identifying the molecules responsible for conferring drug resistance, most of these cellular models are derived from cell lines isolated from patients at a late stage in cancer progression. To ask at which stage in the tumorigenic progression does the cell gain the ability to acquire drug resistance, we generated a series of pre-tumorigenic and tumorigenic cells from human embryonic skin fibroblasts by introducing, sequentially, the catalytic subunit of telomerase, SV40 large T and small T oncoproteins, and an oncogenic form of ras. We show that the ability to acquire multidrug resistance (MDR) can arise before the malignant transformation stage. The minimal set of changes necessary to obtain pre-tumorigenic drug-resistant cells is expression of telomerase and inactivation of p53 and pRb. Thus, the pathways inactivated during tumorigenesis also confer the ability to acquire drug resistance. Microarray and functional studies of drug-resistant pre-tumorigenic cells indicate that the drug efflux pump P-glycoprotein is responsible for the MDR phenotype in this pre-tumorigenic cell model.

Standard name | YAGUE_PRETUMOR_DRUG_RESISTANCE_DN
Systematic name | M2070
Organism | Homo sapiens
PMID | 17283147
Authors | Yagüe E,Arance A,Kubitza L,O'Hare M,Jat P,Ogilvie CM,Hart IR,Higgins CF,Raguz S
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes common to all pretumorigenic cells with acquired drug resistance.
Full description | Resistance to chemotherapy is one of the principal causes of cancer mortality and is generally considered a late event in tumor progression. Although cellular models of drug resistance have been useful in identifying the molecules responsible for conferring drug resistance, most of these cellular models are derived from cell lines isolated from patients at a late stage in cancer progression. To ask at which stage in the tumorigenic progression does the cell gain the ability to acquire drug resistance, we generated a series of pre-tumorigenic and tumorigenic cells from human embryonic skin fibroblasts by introducing, sequentially, the catalytic subunit of telomerase, SV40 large T and small T oncoproteins, and an oncogenic form of ras. We show that the ability to acquire multidrug resistance (MDR) can arise before the malignant transformation stage. The minimal set of changes necessary to obtain pre-tumorigenic drug-resistant cells is expression of telomerase and inactivation of p53 and pRb. Thus, the pathways inactivated during tumorigenesis also confer the ability to acquire drug resistance. Microarray and functional studies of drug-resistant pre-tumorigenic cells indicate that the drug efflux pump P-glycoprotein is responsible for the MDR phenotype in this pre-tumorigenic cell model.

Standard name | BRUECKNER_TARGETS_OF_MIRLET7A3_UP
Systematic name | M8831
Organism | Homo sapiens
PMID | 17308078
Authors | Brueckner B,Stresemann C,Kuner R,Mund C,Musch T,Meister M,Sültmann H,Lyko F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A549 cells (lung cancer) expressing MIRLET7A3 [GeneID=406883] microRNA off a plasmid vector.
Full description | MicroRNAs (miRNAs) are small noncoding RNAs that repress their target mRNAs by complementary base pairing and induction of the RNA interference pathway. It has been shown that miRNA expression can be regulated by DNA methylation and it has been suggested that altered miRNA gene methylation might contribute to human tumorigenesis. In this study, we show that the human let-7a-3 gene on chromosome 22q13.31 is associated with a CpG island. Let-7a-3 belongs to the archetypal let-7 miRNA gene family and was found to be methylated by the DNA methyltransferases DNMT1 and DNMT3B. The gene was heavily methylated in normal human tissues but hypomethylated in some lung adenocarcinomas. Let-7a-3 hypomethylation facilitated epigenetic reactivation of the gene and elevated expression of let-7a-3 in a human lung cancer cell line resulted in enhanced tumor phenotypes and oncogenic changes in transcription profiles. Our results thus identify let-7a-3 as an epigenetically regulated miRNA gene with oncogenic function and suggest that aberrant miRNA gene methylation might contribute to the human cancer epigenome.

Standard name | BRUECKNER_TARGETS_OF_MIRLET7A3_DN
Systematic name | M11825
Organism | Homo sapiens
PMID | 17308078
Authors | Brueckner B,Stresemann C,Kuner R,Mund C,Musch T,Meister M,Sültmann H,Lyko F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A549 cells (lung cancer) expressing MIRLET7A3 [GeneID=406883] microRNA off a plasmid vector.
Full description | MicroRNAs (miRNAs) are small noncoding RNAs that repress their target mRNAs by complementary base pairing and induction of the RNA interference pathway. It has been shown that miRNA expression can be regulated by DNA methylation and it has been suggested that altered miRNA gene methylation might contribute to human tumorigenesis. In this study, we show that the human let-7a-3 gene on chromosome 22q13.31 is associated with a CpG island. Let-7a-3 belongs to the archetypal let-7 miRNA gene family and was found to be methylated by the DNA methyltransferases DNMT1 and DNMT3B. The gene was heavily methylated in normal human tissues but hypomethylated in some lung adenocarcinomas. Let-7a-3 hypomethylation facilitated epigenetic reactivation of the gene and elevated expression of let-7a-3 in a human lung cancer cell line resulted in enhanced tumor phenotypes and oncogenic changes in transcription profiles. Our results thus identify let-7a-3 as an epigenetically regulated miRNA gene with oncogenic function and suggest that aberrant miRNA gene methylation might contribute to the human cancer epigenome.

Standard name | PODAR_RESPONSE_TO_ADAPHOSTIN_UP
Systematic name | M16336
Organism | Homo sapiens
PMID | 17308109
Authors | Podar K,Raab MS,Tonon G,Sattler M,Barilà D,Zhang J,Tai YT,Yasui H,Raje N,DePinho RA,Hideshima T,Chauhan D,Anderson KC
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in MM1.S cells (multiple myeloma) treated with adaphostin [PubChem=387042], a tyrosine kinase inhibitor with anticancer properties.
Full description | Here we show the antimyeloma cytotoxicity of adaphostin and carried out expression profiling of adaphostin-treated multiple myeloma (MM) cells to identify its molecular targets. Surprisingly, c-Jun was the most up-regulated gene even at the earliest point of analysis (2 h). We also observed adaphostin-induced c-Abl cleavage in immunoblot analysis. Proteasome inhibitor bortezomib, but not melphalan or dexamethasone, induced similar effects, indicating unique agent-dependent mechanisms. Using caspase inhibitors, as well as caspase-resistant mutants of c-Abl (TM-c-Abl and D565A-Abl), we then showed that c-Abl cleavage in MM cells requires caspase activity. Importantly, both overexpression of the c-Abl fragment or c-Jun and knockdown of c-Abl and c-Jun expression by small interfering RNA confirmed that adaphostin-induced c-Jun up-regulation triggers downstream caspase-mediated c-Abl cleavage, inhibition of MM cell growth, and induction of apoptosis. Finally, our data suggest that this mechanism may not only be restricted to MM but may also be important in a broad range of malignancies including erythroleukemia and solid tumors.

Standard name | PODAR_RESPONSE_TO_ADAPHOSTIN_DN
Systematic name | M8876
Organism | Homo sapiens
PMID | 17308109
Authors | Podar K,Raab MS,Tonon G,Sattler M,Barilà D,Zhang J,Tai YT,Yasui H,Raje N,DePinho RA,Hideshima T,Chauhan D,Anderson KC
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in MM1.S cells (multiple myeloma) treated with adaphostin [PubChem=387042], a tyrosine kinase inhibitor with anticancer properties.
Full description | Here we show the antimyeloma cytotoxicity of adaphostin and carried out expression profiling of adaphostin-treated multiple myeloma (MM) cells to identify its molecular targets. Surprisingly, c-Jun was the most up-regulated gene even at the earliest point of analysis (2 h). We also observed adaphostin-induced c-Abl cleavage in immunoblot analysis. Proteasome inhibitor bortezomib, but not melphalan or dexamethasone, induced similar effects, indicating unique agent-dependent mechanisms. Using caspase inhibitors, as well as caspase-resistant mutants of c-Abl (TM-c-Abl and D565A-Abl), we then showed that c-Abl cleavage in MM cells requires caspase activity. Importantly, both overexpression of the c-Abl fragment or c-Jun and knockdown of c-Abl and c-Jun expression by small interfering RNA confirmed that adaphostin-induced c-Jun up-regulation triggers downstream caspase-mediated c-Abl cleavage, inhibition of MM cell growth, and induction of apoptosis. Finally, our data suggest that this mechanism may not only be restricted to MM but may also be important in a broad range of malignancies including erythroleukemia and solid tumors.

Standard name | LU_TUMOR_ENDOTHELIAL_MARKERS_UP
Systematic name | M17004
Organism | Homo sapiens
PMID | 17308118
Authors | Lu C,Bonome T,Li Y,Kamat AA,Han LY,Schmandt R,Coleman RL,Gershenson DM,Jaffe RB,Birrer MJ,Sood AK
Category | C2
Sub-category | CGP
Brief description | Genes specifically up-regulated in tumor endothelium.
Full description | Therapeutic strategies based on antiangiogenic approaches are beginning to show great promise in clinical studies. However, full realization of these approaches requires identification of key differences in gene expression between endothelial cells from tumors versus their normal counterparts. Here, we examined gene expression differences in purified endothelial cells from 10 invasive epithelial ovarian cancers and 5 normal ovaries using Affymetrix U133 Plus 2.0 microarrays. More than 400 differentially expressed genes were identified in tumor-associated endothelial cells. We selected and validated 23 genes that were overexpressed by 3.6- to 168-fold using real-time reverse transcription-PCR and/or immunohistochemistry. Among these, the polycomb group protein enhancer of Zeste homologue 2 (EZH2), the Notch ligand Jagged1, and PTK2 were elevated 3- to 4.3-fold in tumor-associated endothelial cells. Silencing these genes individually with small interfering RNA blocked endothelial cell migration and tube formation in vitro. The present study shows that tumor and normal endothelium differ at the molecular level, which may have significant implications for the development of antiangiogenic therapies.

Standard name | LU_TUMOR_ENDOTHELIAL_MARKERS_DN
Systematic name | M8822
Organism | Homo sapiens
PMID | 17308118
Authors | Lu C,Bonome T,Li Y,Kamat AA,Han LY,Schmandt R,Coleman RL,Gershenson DM,Jaffe RB,Birrer MJ,Sood AK
Category | C2
Sub-category | CGP
Brief description | Genes specifically down-regulated in tumor endothelium.
Full description | Therapeutic strategies based on antiangiogenic approaches are beginning to show great promise in clinical studies. However, full realization of these approaches requires identification of key differences in gene expression between endothelial cells from tumors versus their normal counterparts. Here, we examined gene expression differences in purified endothelial cells from 10 invasive epithelial ovarian cancers and 5 normal ovaries using Affymetrix U133 Plus 2.0 microarrays. More than 400 differentially expressed genes were identified in tumor-associated endothelial cells. We selected and validated 23 genes that were overexpressed by 3.6- to 168-fold using real-time reverse transcription-PCR and/or immunohistochemistry. Among these, the polycomb group protein enhancer of Zeste homologue 2 (EZH2), the Notch ligand Jagged1, and PTK2 were elevated 3- to 4.3-fold in tumor-associated endothelial cells. Silencing these genes individually with small interfering RNA blocked endothelial cell migration and tube formation in vitro. The present study shows that tumor and normal endothelium differ at the molecular level, which may have significant implications for the development of antiangiogenic therapies.

Standard name | LU_TUMOR_ANGIOGENESIS_UP
Systematic name | M9946
Organism | Homo sapiens
PMID | 17308118
Authors | Lu C,Bonome T,Li Y,Kamat AA,Han LY,Schmandt R,Coleman RL,Gershenson DM,Jaffe RB,Birrer MJ,Sood AK
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes of putative pathways stimulated in tumor endothelial cells by papillary serous ovarian epithelial tumor cells.
Full description | Therapeutic strategies based on antiangiogenic approaches are beginning to show great promise in clinical studies. However, full realization of these approaches requires identification of key differences in gene expression between endothelial cells from tumors versus their normal counterparts. Here, we examined gene expression differences in purified endothelial cells from 10 invasive epithelial ovarian cancers and 5 normal ovaries using Affymetrix U133 Plus 2.0 microarrays. More than 400 differentially expressed genes were identified in tumor-associated endothelial cells. We selected and validated 23 genes that were overexpressed by 3.6- to 168-fold using real-time reverse transcription-PCR and/or immunohistochemistry. Among these, the polycomb group protein enhancer of Zeste homologue 2 (EZH2), the Notch ligand Jagged1, and PTK2 were elevated 3- to 4.3-fold in tumor-associated endothelial cells. Silencing these genes individually with small interfering RNA blocked endothelial cell migration and tube formation in vitro. The present study shows that tumor and normal endothelium differ at the molecular level, which may have significant implications for the development of antiangiogenic therapies.

Standard name | LIN_TUMOR_ESCAPE_FROM_IMMUNE_ATTACK
Systematic name | M1847
Organism | Mus musculus
PMID | 17308126
Authors | Lin KY,Lu D,Hung CF,Peng S,Huang L,Jie C,Murillo F,Rowley J,Tsai YC,He L,Kim DJ,Jaffee E,Pardoll D,Wu TC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in highly immune-resistant cancer cell line developed from a susceptible cancer using an in vivo selection strategy.
Full description | Immune escape is an important reason why the immune system cannot control tumor growth, but how escape variants emerge during immunotherapy remains poorly understood. Here, we identify a new mechanism of tumor immune escape using an in vivo selection strategy. We generated a highly immune-resistant cancer cell line (P3) by subjecting a susceptible cancer cell line (P0/TC-1) to multiple rounds of in vivo immune selection. Microarray analysis of P0 and P3 revealed that vascular cell adhesion molecule-1 (VCAM-1) is up-regulated in the P3-resistant variant. Retroviral transfer of VCAM-1 into P0 significantly increased its resistance against a vaccine-induced immune response. Analysis of tumors showed a dramatic decrease in the number of tumor-infiltrating cluster of differentiation 8(+) (CD8(+)) T cells in the tumors expressing VCAM-1. In vitro transwell migration assays showed that VCAM-1 can promote the migration of CD8(+) T cells through its interaction with the alpha(4)beta(1) integrin. Site-directed mutagenesis of VCAM-1 at amino acid residues required for interaction with alpha(4)beta(1) integrin completely abolished the immune resistance conferred by VCAM-1 in vivo. Surface staining showed that most renal cell carcinomas (RCC) express VCAM-1, whereas an RCC that responded to vaccination was VCAM-1 negative. These data provide evidence that tumor expression of VCAM-1 represents a new mechanism of immune evasion and has important implications for the development of immunotherapy for human RCC.

Standard name | CHEN_HOXA5_TARGETS_6HR_UP
Systematic name | M3475
Organism | Homo sapiens
PMID | 15757903
Authors | Chen H,Rubin E,Zhang H,Chung S,Jie CC,Garrett E,Biswal S,Sukumar S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated 6 h after induction of HoxA5 [GeneID=3205] expression in a breast cancer cell line.
Full description | The homeobox gene HOXA5 encodes a transcription factor that has been shown to play important roles in embryogenesis, hematopoiesis, and tumorigenesis. In order to decipher downstream signaling pathways of HOXA5, we utilized oligonucleotide microarray analysis to identify genes that are differentially expressed in HOXA5-induced cells compared with uninduced cells. Comparative analysis of gene expression changes after 9 h of HOXA5 induction in Hs578T breast cancer cells identified 306 genes whose expression was modulated at least 2-fold. Ten of these 306 genes were also up-regulated by at least 2-fold at 6 h post-induction. The expression of all of these 10 genes was confirmed by semiquantitative reverse transcription-PCR. Among these 10 genes, which are most likely to be direct targets of HOXA5, we initiated an investigation into the pleiotrophin gene by first cloning its promoter. Transient transfection assays indicated that HOXA5 can specifically activate the pleiotrophin promoter. Promoter deletion, chromatin immunoprecipitation assay, and gel-shift assays were performed to show that HOXA5 can directly bind to one binding site on the pleiotrophin promoter. These data strongly suggest that microarray analysis can successfully identify many potential direct downstream genes of HOXA5. Further functional analysis of these targets will allow us to better understand the diverse functions of HOXA5 in embryonic development and tumorigenesis.

Standard name | CHEN_HOXA5_TARGETS_6HR_DN
Systematic name | M13148
Organism | Homo sapiens
PMID | 15757903
Authors | Chen H,Rubin E,Zhang H,Chung S,Jie CC,Garrett E,Biswal S,Sukumar S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated 6 h after induction of HoxA5 [GeneID=3205] expression in a breast cancer cell line.
Full description | The homeobox gene HOXA5 encodes a transcription factor that has been shown to play important roles in embryogenesis, hematopoiesis, and tumorigenesis. In order to decipher downstream signaling pathways of HOXA5, we utilized oligonucleotide microarray analysis to identify genes that are differentially expressed in HOXA5-induced cells compared with uninduced cells. Comparative analysis of gene expression changes after 9 h of HOXA5 induction in Hs578T breast cancer cells identified 306 genes whose expression was modulated at least 2-fold. Ten of these 306 genes were also up-regulated by at least 2-fold at 6 h post-induction. The expression of all of these 10 genes was confirmed by semiquantitative reverse transcription-PCR. Among these 10 genes, which are most likely to be direct targets of HOXA5, we initiated an investigation into the pleiotrophin gene by first cloning its promoter. Transient transfection assays indicated that HOXA5 can specifically activate the pleiotrophin promoter. Promoter deletion, chromatin immunoprecipitation assay, and gel-shift assays were performed to show that HOXA5 can directly bind to one binding site on the pleiotrophin promoter. These data strongly suggest that microarray analysis can successfully identify many potential direct downstream genes of HOXA5. Further functional analysis of these targets will allow us to better understand the diverse functions of HOXA5 in embryonic development and tumorigenesis.

Standard name | CHEN_HOXA5_TARGETS_9HR_UP
Systematic name | M17621
Organism | Homo sapiens
PMID | 15757903
Authors | Chen H,Rubin E,Zhang H,Chung S,Jie CC,Garrett E,Biswal S,Sukumar S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated 9 h after induction of HoxA5 [GeneID=3205] expression in a breast cancer cell line.
Full description | The homeobox gene HOXA5 encodes a transcription factor that has been shown to play important roles in embryogenesis, hematopoiesis, and tumorigenesis. In order to decipher downstream signaling pathways of HOXA5, we utilized oligonucleotide microarray analysis to identify genes that are differentially expressed in HOXA5-induced cells compared with uninduced cells. Comparative analysis of gene expression changes after 9 h of HOXA5 induction in Hs578T breast cancer cells identified 306 genes whose expression was modulated at least 2-fold. Ten of these 306 genes were also up-regulated by at least 2-fold at 6 h post-induction. The expression of all of these 10 genes was confirmed by semiquantitative reverse transcription-PCR. Among these 10 genes, which are most likely to be direct targets of HOXA5, we initiated an investigation into the pleiotrophin gene by first cloning its promoter. Transient transfection assays indicated that HOXA5 can specifically activate the pleiotrophin promoter. Promoter deletion, chromatin immunoprecipitation assay, and gel-shift assays were performed to show that HOXA5 can directly bind to one binding site on the pleiotrophin promoter. These data strongly suggest that microarray analysis can successfully identify many potential direct downstream genes of HOXA5. Further functional analysis of these targets will allow us to better understand the diverse functions of HOXA5 in embryonic development and tumorigenesis.

Standard name | CHEN_HOXA5_TARGETS_9HR_DN
Systematic name | M15493
Organism | Homo sapiens
PMID | 15757903
Authors | Chen H,Rubin E,Zhang H,Chung S,Jie CC,Garrett E,Biswal S,Sukumar S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated 9 h after induction of HoxA5 [GeneID=3205] expression in a breast cancer cell line.
Full description | The homeobox gene HOXA5 encodes a transcription factor that has been shown to play important roles in embryogenesis, hematopoiesis, and tumorigenesis. In order to decipher downstream signaling pathways of HOXA5, we utilized oligonucleotide microarray analysis to identify genes that are differentially expressed in HOXA5-induced cells compared with uninduced cells. Comparative analysis of gene expression changes after 9 h of HOXA5 induction in Hs578T breast cancer cells identified 306 genes whose expression was modulated at least 2-fold. Ten of these 306 genes were also up-regulated by at least 2-fold at 6 h post-induction. The expression of all of these 10 genes was confirmed by semiquantitative reverse transcription-PCR. Among these 10 genes, which are most likely to be direct targets of HOXA5, we initiated an investigation into the pleiotrophin gene by first cloning its promoter. Transient transfection assays indicated that HOXA5 can specifically activate the pleiotrophin promoter. Promoter deletion, chromatin immunoprecipitation assay, and gel-shift assays were performed to show that HOXA5 can directly bind to one binding site on the pleiotrophin promoter. These data strongly suggest that microarray analysis can successfully identify many potential direct downstream genes of HOXA5. Further functional analysis of these targets will allow us to better understand the diverse functions of HOXA5 in embryonic development and tumorigenesis.

Standard name | LIN_NPAS4_TARGETS_UP
Systematic name | M687
Organism | Mus musculus
PMID | 18815592
Authors | Lin Y,Bloodgood BL,Hauser JL,Lapan AD,Koon AC,Kim TK,Hu LS,Malik AN,Greenberg ME
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in neurons after NPAS4 [GeneID=266743] knockdown by RNAi.
Full description | Neuronal activity regulates the development and maturation of excitatory and inhibitory synapses in the mammalian brain. Several recent studies have identified signalling networks within neurons that control excitatory synapse development. However, less is known about the molecular mechanisms that regulate the activity-dependent development of GABA (gamma-aminobutyric acid)-releasing inhibitory synapses. Here we report the identification of a transcription factor, Npas4, that plays a role in the development of inhibitory synapses by regulating the expression of activity-dependent genes, which in turn control the number of GABA-releasing synapses that form on excitatory neurons. These findings demonstrate that the activity-dependent gene program regulates inhibitory synapse development, and suggest a new role for this program in controlling the homeostatic balance between synaptic excitation and inhibition.

Standard name | LIN_NPAS4_TARGETS_DN
Systematic name | M7327
Organism | Mus musculus
PMID | 18815592
Authors | Lin Y,Bloodgood BL,Hauser JL,Lapan AD,Koon AC,Kim TK,Hu LS,Malik AN,Greenberg ME
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in neurons after NPAS4 [GeneID=266743] knockdown by RNAi.
Full description | Neuronal activity regulates the development and maturation of excitatory and inhibitory synapses in the mammalian brain. Several recent studies have identified signalling networks within neurons that control excitatory synapse development. However, less is known about the molecular mechanisms that regulate the activity-dependent development of GABA (gamma-aminobutyric acid)-releasing inhibitory synapses. Here we report the identification of a transcription factor, Npas4, that plays a role in the development of inhibitory synapses by regulating the expression of activity-dependent genes, which in turn control the number of GABA-releasing synapses that form on excitatory neurons. These findings demonstrate that the activity-dependent gene program regulates inhibitory synapse development, and suggest a new role for this program in controlling the homeostatic balance between synaptic excitation and inhibition.

Standard name | CADWELL_ATG16L1_TARGETS_UP
Systematic name | M5688
Organism | Mus musculus
PMID | 18849966
Authors | Cadwell K,Liu JY,Brown SL,Miyoshi H,Loh J,Lennerz JK,Kishi C,Kc W,Carrero JA,Hunt S,Stone CD,Brunt EM,Xavier RJ,Sleckman BP,Li E,Mizushima N,Stappenbeck TS,Virgin HW 4th
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Paneth cell (part of intestiinal epithelium) of mice with hypomorphic (reduced function) form of ATG16L1 [GeneID=55054].
Full description | Susceptibility to Crohn's disease, a complex inflammatory disease involving the small intestine, is controlled by over 30 loci. One Crohn's disease risk allele is in ATG16L1, a gene homologous to the essential yeast autophagy gene ATG16 (ref. 2). It is not known how ATG16L1 or autophagy contributes to intestinal biology or Crohn's disease pathogenesis. To address these questions, we generated and characterized mice that are hypomorphic for ATG16L1 protein expression, and validated conclusions on the basis of studies in these mice by analysing intestinal tissues that we collected from Crohn's disease patients carrying the Crohn's disease risk allele of ATG16L1. Here we show that ATG16L1 is a bona fide autophagy protein. Within the ileal epithelium, both ATG16L1 and a second essential autophagy protein ATG5 are selectively important for the biology of the Paneth cell, a specialized epithelial cell that functions in part by secretion of granule contents containing antimicrobial peptides and other proteins that alter the intestinal environment. ATG16L1- and ATG5-deficient Paneth cells exhibited notable abnormalities in the granule exocytosis pathway. In addition, transcriptional analysis revealed an unexpected gain of function specific to ATG16L1-deficient Paneth cells including increased expression of genes involved in peroxisome proliferator-activated receptor (PPAR) signalling and lipid metabolism, of acute phase reactants and of two adipocytokines, leptin and adiponectin, known to directly influence intestinal injury responses. Importantly, Crohn's disease patients homozygous for the ATG16L1 Crohn's disease risk allele displayed Paneth cell granule abnormalities similar to those observed in autophagy-protein-deficient mice and expressed increased levels of leptin protein. Thus, ATG16L1, and probably the process of autophagy, have a role within the intestinal epithelium of mice and Crohn's disease patients by selective effects on the cell biology and specialized regulatory properties of Paneth cells.

Standard name | CADWELL_ATG16L1_TARGETS_DN
Systematic name | M12482
Organism | Mus musculus
PMID | 18849966
Authors | Cadwell K,Liu JY,Brown SL,Miyoshi H,Loh J,Lennerz JK,Kishi C,Kc W,Carrero JA,Hunt S,Stone CD,Brunt EM,Xavier RJ,Sleckman BP,Li E,Mizushima N,Stappenbeck TS,Virgin HW 4th
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Paneth cell (part of intestiinal epithelium) of mice with hypomorphic (reduced function) form of ATG16L1 [GeneID=55054].
Full description | Susceptibility to Crohn's disease, a complex inflammatory disease involving the small intestine, is controlled by over 30 loci. One Crohn's disease risk allele is in ATG16L1, a gene homologous to the essential yeast autophagy gene ATG16 (ref. 2). It is not known how ATG16L1 or autophagy contributes to intestinal biology or Crohn's disease pathogenesis. To address these questions, we generated and characterized mice that are hypomorphic for ATG16L1 protein expression, and validated conclusions on the basis of studies in these mice by analysing intestinal tissues that we collected from Crohn's disease patients carrying the Crohn's disease risk allele of ATG16L1. Here we show that ATG16L1 is a bona fide autophagy protein. Within the ileal epithelium, both ATG16L1 and a second essential autophagy protein ATG5 are selectively important for the biology of the Paneth cell, a specialized epithelial cell that functions in part by secretion of granule contents containing antimicrobial peptides and other proteins that alter the intestinal environment. ATG16L1- and ATG5-deficient Paneth cells exhibited notable abnormalities in the granule exocytosis pathway. In addition, transcriptional analysis revealed an unexpected gain of function specific to ATG16L1-deficient Paneth cells including increased expression of genes involved in peroxisome proliferator-activated receptor (PPAR) signalling and lipid metabolism, of acute phase reactants and of two adipocytokines, leptin and adiponectin, known to directly influence intestinal injury responses. Importantly, Crohn's disease patients homozygous for the ATG16L1 Crohn's disease risk allele displayed Paneth cell granule abnormalities similar to those observed in autophagy-protein-deficient mice and expressed increased levels of leptin protein. Thus, ATG16L1, and probably the process of autophagy, have a role within the intestinal epithelium of mice and Crohn's disease patients by selective effects on the cell biology and specialized regulatory properties of Paneth cells.

Standard name | BREDEMEYER_RAG_SIGNALING_NOT_VIA_ATM_UP
Systematic name | M15542
Organism | Mus musculus
PMID | 18849970
Authors | Bredemeyer AL,Helmink BA,Innes CL,Calderon B,McGinnis LM,Mahowald GK,Gapud EJ,Walker LM,Collins JB,Weaver BK,Mandik-Nayak L,Schreiber RD,Allen PM,May MJ,Paules RS,Bassing CH,Sleckman BP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pre B lymphocyte after induction of physiological DNA double-strand breaks (DSB) by RAG2 [GeneID=5897]; the changes are independent of ATM [GeneID=472] signaling.
Full description | DNA double-strand breaks are generated by genotoxic agents and by cellular endonucleases as intermediates of several important physiological processes. The cellular response to genotoxic DNA breaks includes the activation of transcriptional programs known primarily to regulate cell-cycle checkpoints and cell survival. DNA double-strand breaks are generated in all developing lymphocytes during the assembly of antigen receptor genes, a process that is essential for normal lymphocyte development. Here we show that in murine lymphocytes these physiological DNA breaks activate a broad transcriptional program. This program transcends the canonical DNA double-strand break response and includes many genes that regulate diverse cellular processes important for lymphocyte development. Moreover, the expression of several of these genes is regulated similarly in response to genotoxic DNA damage. Thus, physiological DNA double-strand breaks provide cues that can regulate cell-type-specific processes not directly involved in maintaining the integrity of the genome, and genotoxic DNA breaks could disrupt normal cellular functions by corrupting these processes.

Standard name | BREDEMEYER_RAG_SIGNALING_NOT_VIA_ATM_DN
Systematic name | M6023
Organism | Mus musculus
PMID | 18849970
Authors | Bredemeyer AL,Helmink BA,Innes CL,Calderon B,McGinnis LM,Mahowald GK,Gapud EJ,Walker LM,Collins JB,Weaver BK,Mandik-Nayak L,Schreiber RD,Allen PM,May MJ,Paules RS,Bassing CH,Sleckman BP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pre B lymphocyte after induction of physiological DNA double-strand breaks (DSB) by RAG2 [GeneID=5897]; the changes are independent of ATM [GeneID=472] signaling.
Full description | DNA double-strand breaks are generated by genotoxic agents and by cellular endonucleases as intermediates of several important physiological processes. The cellular response to genotoxic DNA breaks includes the activation of transcriptional programs known primarily to regulate cell-cycle checkpoints and cell survival. DNA double-strand breaks are generated in all developing lymphocytes during the assembly of antigen receptor genes, a process that is essential for normal lymphocyte development. Here we show that in murine lymphocytes these physiological DNA breaks activate a broad transcriptional program. This program transcends the canonical DNA double-strand break response and includes many genes that regulate diverse cellular processes important for lymphocyte development. Moreover, the expression of several of these genes is regulated similarly in response to genotoxic DNA damage. Thus, physiological DNA double-strand breaks provide cues that can regulate cell-type-specific processes not directly involved in maintaining the integrity of the genome, and genotoxic DNA breaks could disrupt normal cellular functions by corrupting these processes.

Standard name | BREDEMEYER_RAG_SIGNALING_VIA_ATM_NOT_VIA_NFKB_UP
Systematic name | M2831
Organism | Mus musculus
PMID | 18849970
Authors | Bredemeyer AL,Helmink BA,Innes CL,Calderon B,McGinnis LM,Mahowald GK,Gapud EJ,Walker LM,Collins JB,Weaver BK,Mandik-Nayak L,Schreiber RD,Allen PM,May MJ,Paules RS,Bassing CH,Sleckman BP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pre B lymphocyte after induction of physiological DNA double-strand breaks (DSB) by RAG2 [GeneID=5897]; the changes depend on ATM [GeneID=472] but not NFKB signaling.
Full description | DNA double-strand breaks are generated by genotoxic agents and by cellular endonucleases as intermediates of several important physiological processes. The cellular response to genotoxic DNA breaks includes the activation of transcriptional programs known primarily to regulate cell-cycle checkpoints and cell survival. DNA double-strand breaks are generated in all developing lymphocytes during the assembly of antigen receptor genes, a process that is essential for normal lymphocyte development. Here we show that in murine lymphocytes these physiological DNA breaks activate a broad transcriptional program. This program transcends the canonical DNA double-strand break response and includes many genes that regulate diverse cellular processes important for lymphocyte development. Moreover, the expression of several of these genes is regulated similarly in response to genotoxic DNA damage. Thus, physiological DNA double-strand breaks provide cues that can regulate cell-type-specific processes not directly involved in maintaining the integrity of the genome, and genotoxic DNA breaks could disrupt normal cellular functions by corrupting these processes.

Standard name | BREDEMEYER_RAG_SIGNALING_VIA_ATM_NOT_VIA_NFKB_DN
Systematic name | M3644
Organism | Mus musculus
PMID | 18849970
Authors | Bredemeyer AL,Helmink BA,Innes CL,Calderon B,McGinnis LM,Mahowald GK,Gapud EJ,Walker LM,Collins JB,Weaver BK,Mandik-Nayak L,Schreiber RD,Allen PM,May MJ,Paules RS,Bassing CH,Sleckman BP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pre B lymphocyte after induction of physiological DNA double-strand breaks (DSB) by RAG2 [GeneID=5897]; the changes depend on ATM [GeneID=472] but not NFKB signaling.
Full description | DNA double-strand breaks are generated by genotoxic agents and by cellular endonucleases as intermediates of several important physiological processes. The cellular response to genotoxic DNA breaks includes the activation of transcriptional programs known primarily to regulate cell-cycle checkpoints and cell survival. DNA double-strand breaks are generated in all developing lymphocytes during the assembly of antigen receptor genes, a process that is essential for normal lymphocyte development. Here we show that in murine lymphocytes these physiological DNA breaks activate a broad transcriptional program. This program transcends the canonical DNA double-strand break response and includes many genes that regulate diverse cellular processes important for lymphocyte development. Moreover, the expression of several of these genes is regulated similarly in response to genotoxic DNA damage. Thus, physiological DNA double-strand breaks provide cues that can regulate cell-type-specific processes not directly involved in maintaining the integrity of the genome, and genotoxic DNA breaks could disrupt normal cellular functions by corrupting these processes.

Standard name | CONRAD_STEM_CELL
Systematic name | M15383
Organism | Homo sapiens
PMID | 18849962
Authors | Conrad S,Renninger M,Hennenlotter J,Wiesner T,Just L,Bonin M,Aicher W,Bühring HJ,Mattheus U,Mack A,Wagner HJ,Minger S,Matzkies M,Reppel M,Hescheler J,Sievert KD,Stenzl A,Skutella T
Category | C2
Sub-category | CGP
Brief description | Supplementary Table 2. Genelist comparing microarray expression profiles of spermatogonial cells, haGSCs and hES (H1) cells. Examples of expression rates of different hES cell enriched and germ cell specific genes, surface markers for germ cell selection and signal transduction in all three cell types (spermatogonial cells = SC).
Full description | Human primordial germ cells and mouse neonatal and adult germline stem cells are pluripotent and show similar properties to embryonic stem cells. Here we report the successful establishment of human adult germline stem cells derived from spermatogonial cells of adult human testis. Cellular and molecular characterization of these cells revealed many similarities to human embryonic stem cells, and the germline stem cells produced teratomas after transplantation into immunodeficient mice. The human adult germline stem cells differentiated into various types of somatic cells of all three germ layers when grown under conditions used to induce the differentiation of human embryonic stem cells. We conclude that the generation of human adult germline stem cells from testicular biopsies may provide simple and non-controversial access to individual cell-based therapy without the ethical and immunological problems associated with human embryonic stem cells.

Standard name | CONRAD_GERMLINE_STEM_CELL
Systematic name | M15040
Organism | Homo sapiens
PMID | 18849962
Authors | Conrad S,Renninger M,Hennenlotter J,Wiesner T,Just L,Bonin M,Aicher W,Bühring HJ,Mattheus U,Mack A,Wagner HJ,Minger S,Matzkies M,Reppel M,Hescheler J,Sievert KD,Stenzl A,Skutella T
Category | C2
Sub-category | CGP
Brief description | Genes enriched in pluripotent adult germline stem cells.
Full description | Human primordial germ cells and mouse neonatal and adult germline stem cells are pluripotent and show similar properties to embryonic stem cells. Here we report the successful establishment of human adult germline stem cells derived from spermatogonial cells of adult human testis. Cellular and molecular characterization of these cells revealed many similarities to human embryonic stem cells, and the germline stem cells produced teratomas after transplantation into immunodeficient mice. The human adult germline stem cells differentiated into various types of somatic cells of all three germ layers when grown under conditions used to induce the differentiation of human embryonic stem cells. We conclude that the generation of human adult germline stem cells from testicular biopsies may provide simple and non-controversial access to individual cell-based therapy without the ethical and immunological problems associated with human embryonic stem cells.

Standard name | THUM_MIR21_TARGETS_HEART_DISEASE_UP
Systematic name | M13796
Organism | Mus musculus
PMID | 19043405
Authors | Thum T,Gross C,Fiedler J,Fischer T,Kissler S,Bussen M,Galuppo P,Just S,Rottbauer W,Frantz S,Castoldi M,Soutschek J,Koteliansky V,Rosenwald A,Basson MA,Licht JD,Pena JT,Rouhanifard SH,Muckenthaler MU,Tuschl T,Martin GR,Bauersachs J,Engelhardt S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in a mouse model of heart disease whose expression reverted to normal by silencing of MIR21 [GeneID=406991] microRNA.
Full description | MicroRNAs comprise a broad class of small non-coding RNAs that control expression of complementary target messenger RNAs. Dysregulation of microRNAs by several mechanisms has been described in various disease states including cardiac disease. Whereas previous studies of cardiac disease have focused on microRNAs that are primarily expressed in cardiomyocytes, the role of microRNAs expressed in other cell types of the heart is unclear. Here we show that microRNA-21 (miR-21, also known as Mirn21) regulates the ERK-MAP kinase signalling pathway in cardiac fibroblasts, which has impacts on global cardiac structure and function. miR-21 levels are increased selectively in fibroblasts of the failing heart, augmenting ERK-MAP kinase activity through inhibition of sprouty homologue 1 (Spry1). This mechanism regulates fibroblast survival and growth factor secretion, apparently controlling the extent of interstitial fibrosis and cardiac hypertrophy. In vivo silencing of miR-21 by a specific antagomir in a mouse pressure-overload-induced disease model reduces cardiac ERK-MAP kinase activity, inhibits interstitial fibrosis and attenuates cardiac dysfunction. These findings reveal that microRNAs can contribute to myocardial disease by an effect in cardiac fibroblasts. Our results validate miR-21 as a disease target in heart failure and establish the therapeutic efficacy of microRNA therapeutic intervention in a cardiovascular disease setting.

Standard name | THUM_MIR21_TARGETS_HEART_DISEASE_DN
Systematic name | M18073
Organism | Mus musculus
PMID | 19043405
Authors | Thum T,Gross C,Fiedler J,Fischer T,Kissler S,Bussen M,Galuppo P,Just S,Rottbauer W,Frantz S,Castoldi M,Soutschek J,Koteliansky V,Rosenwald A,Basson MA,Licht JD,Pena JT,Rouhanifard SH,Muckenthaler MU,Tuschl T,Martin GR,Bauersachs J,Engelhardt S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in a mouse model of heart disease whose expression reverted to normal by silencing of MIR21 [GeneID=406991] microRNA.
Full description | MicroRNAs comprise a broad class of small non-coding RNAs that control expression of complementary target messenger RNAs. Dysregulation of microRNAs by several mechanisms has been described in various disease states including cardiac disease. Whereas previous studies of cardiac disease have focused on microRNAs that are primarily expressed in cardiomyocytes, the role of microRNAs expressed in other cell types of the heart is unclear. Here we show that microRNA-21 (miR-21, also known as Mirn21) regulates the ERK-MAP kinase signalling pathway in cardiac fibroblasts, which has impacts on global cardiac structure and function. miR-21 levels are increased selectively in fibroblasts of the failing heart, augmenting ERK-MAP kinase activity through inhibition of sprouty homologue 1 (Spry1). This mechanism regulates fibroblast survival and growth factor secretion, apparently controlling the extent of interstitial fibrosis and cardiac hypertrophy. In vivo silencing of miR-21 by a specific antagomir in a mouse pressure-overload-induced disease model reduces cardiac ERK-MAP kinase activity, inhibits interstitial fibrosis and attenuates cardiac dysfunction. These findings reveal that microRNAs can contribute to myocardial disease by an effect in cardiac fibroblasts. Our results validate miR-21 as a disease target in heart failure and establish the therapeutic efficacy of microRNA therapeutic intervention in a cardiovascular disease setting.

Standard name | KUUSELO_PANCREATIC_CANCER_19Q13_AMPLIFICATION
Systematic name | M14529
Organism | Homo sapiens
PMID | 17332321
Authors | Kuuselo R,Savinainen K,Azorsa DO,Basu GD,Karhu R,Tuzmen S,Mousses S,Kallioniemi A
Category | C2
Sub-category | CGP
Brief description | List of genes in the 19q13 amplicon region based on a copy number alterations study of a panel of 16 pancreatic cancer cell lines and 31 primary tumors.
Full description | Pancreatic cancer is a highly aggressive disease characterized by poor prognosis and vast genetic instability. Recent microarray-based, genome-wide surveys have identified multiple recurrent copy number aberrations in pancreatic cancer; however, the target genes are, for the most part, unknown. Here, we characterized the 19q13 amplicon in pancreatic cancer to identify putative new drug targets. Copy number increases at 19q13 were quantitated in 16 pancreatic cancer cell lines and 31 primary tumors by fluorescence in situ hybridization. Cell line copy number data delineated a 1.1 Mb amplicon, the presence of which was also validated in 10% of primary pancreatic tumors. Comprehensive expression analysis by quantitative real-time reverse transcription-PCR indicated that seven transcripts within this region had consistently elevated expression levels in the amplified versus nonamplified cell lines. High-throughput loss-of-function screen by RNA interference was applied across the amplicon to identify genes whose down-regulation affected cell viability. This screen revealed five genes whose down-regulation led to significantly decreased cell viability in the amplified PANC-1 cells but not in the nonamplified MiaPaca-2 cells, suggesting the presence of multiple biologically interesting genes in this region. Of these, the transcriptional regulator intersex-like (IXL) was consistently overexpressed in amplified cells and had the most dramatic effect on cell viability. IXL silencing also resulted in G(0)-G(1) cell cycle arrest and increased apoptosis in PANC-1 cells. These findings implicate IXL as a novel amplification target gene in pancreatic cancer and suggest that IXL is required for cancer cell survival in 19q13-amplified tumors.

Standard name | HUANG_DASATINIB_RESISTANCE_UP
Systematic name | M3015
Organism | Homo sapiens
PMID | 17332353
Authors | Huang F,Reeves K,Han X,Fairchild C,Platero S,Wong TW,Lee F,Shaw P,Clark E
Category | C2
Sub-category | CGP
Brief description | Genes whose expression positively correlated with sensitivity of breast cancer cell lines to dasatinib [PubChem=3062316].
Full description | Dasatinib is a multitargeted kinase inhibitor that was recently approved for the treatment of chronic myelogenous leukemia and Philadelphia chromosome-positive acute lymphoblastic leukemia with resistance or intolerance to prior therapy. It is also in clinical trials for treating patients with solid tumors. The identification of molecular markers predictive of response to dasatinib could assist in clinical development by selecting patients most likely to derive clinical benefit. Using baseline gene expression profiling of a panel of 23 breast cancer cell lines, we identified genomic signatures highly correlated with in vitro sensitivity to dasatinib. The ability of these signatures to predict dasatinib sensitivity was further confirmed and validated in independent test cell lines. A six-gene model was used to correctly predict dasatinib sensitivity in 11 out of 12 (92%) additional breast and 19 out of 23 (83%) lung cancer cell lines. Quantitative real-time PCR and immunohistochemical assays further confirmed the differential expression pattern of selected markers. Finally, these gene signatures were observed in a subset of primary breast, lung, and ovarian tumors suggesting potential utility in patient selection. The subset of breast cancer patients expressing the dasatinib-sensitive signature includes a distinct clinical and molecular subgroup: the so-called triple negative (i.e., estrogen receptor-negative, progesterone receptor-negative, and HER2-negative) or basal breast cancer subtype. This patient population has a poor prognosis and currently has few effective treatment options. Our results implicate that dasatinib may represent a valuable treatment option in this difficult-to-treat population. To test this hypothesis, clinical studies are now under way to determine the activity of dasatinib in these patients.

Standard name | HUANG_DASATINIB_RESISTANCE_DN
Systematic name | M16369
Organism | Homo sapiens
PMID | 17332353
Authors | Huang F,Reeves K,Han X,Fairchild C,Platero S,Wong TW,Lee F,Shaw P,Clark E
Category | C2
Sub-category | CGP
Brief description | Genes whose expression negatively correlated with resistance of breast cancer cell lines to dasatinib [PubChem=3062316].
Full description | Dasatinib is a multitargeted kinase inhibitor that was recently approved for the treatment of chronic myelogenous leukemia and Philadelphia chromosome-positive acute lymphoblastic leukemia with resistance or intolerance to prior therapy. It is also in clinical trials for treating patients with solid tumors. The identification of molecular markers predictive of response to dasatinib could assist in clinical development by selecting patients most likely to derive clinical benefit. Using baseline gene expression profiling of a panel of 23 breast cancer cell lines, we identified genomic signatures highly correlated with in vitro sensitivity to dasatinib. The ability of these signatures to predict dasatinib sensitivity was further confirmed and validated in independent test cell lines. A six-gene model was used to correctly predict dasatinib sensitivity in 11 out of 12 (92%) additional breast and 19 out of 23 (83%) lung cancer cell lines. Quantitative real-time PCR and immunohistochemical assays further confirmed the differential expression pattern of selected markers. Finally, these gene signatures were observed in a subset of primary breast, lung, and ovarian tumors suggesting potential utility in patient selection. The subset of breast cancer patients expressing the dasatinib-sensitive signature includes a distinct clinical and molecular subgroup: the so-called triple negative (i.e., estrogen receptor-negative, progesterone receptor-negative, and HER2-negative) or basal breast cancer subtype. This patient population has a poor prognosis and currently has few effective treatment options. Our results implicate that dasatinib may represent a valuable treatment option in this difficult-to-treat population. To test this hypothesis, clinical studies are now under way to determine the activity of dasatinib in these patients.

Standard name | MATTHEWS_SKIN_CARCINOGENESIS_VIA_JUN
Systematic name | M1848
Organism | Mus musculus
PMID | 17363560
Authors | Matthews CP,Birkholz AM,Baker AR,Perella CM,Beck GR Jr,Young MR,Colburn NH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by skin tumor promoters but completely blocked by expression of TAM67, a dominan-negative form of JUN [GeneID=3725].
Full description | Activation of activator protein 1 (AP-1) and nuclear factor kappaB (NFkappaB)-dependent transcription is required for tumor promotion in cell culture models and transgenic mice. Dominant-negative c-Jun (TAM67) blocks AP-1 activation by dimerizing with Jun or Fos family proteins and blocks NFkappaB activation by interacting with NFkappaB p65. Two-stage [7,12-dimethylbenz(a)anthracene (DMBA)/12-O-tetradecanoylphorbol-13-acetate (TPA)] skin carcinogenesis experiments in a model relevant to human cancer risk, transgenic mice expressing human papillomavirus 16 E7 oncogene (K14-HPV16-E7), show E7-enhanced tumor promotion. A cross to K14-TAM67-expressing mice results in dramatic inhibition of tumor promoter-induced AP-1 luciferase reporter activation and papillomagenesis. Epithelial specific TAM67 expression inhibits tumorigenesis without affecting TPA- or E7-induced hyperproliferation of the skin. Thus, the mouse model enriches for TAM67 targets relevant to tumorigenesis rather than to general cell proliferation or hyperplasia, implicating a subset of AP-1- and/or NFkappaB-dependent genes. The aim of the present study was to identify target genes responsible for TAM67 inhibition of DMBA-TPA-induced tumorigenesis. Microarray expression analysis of epidermal tissues revealed small sets of genes in which expression is both up-regulated by tumor promoter and down-regulated by TAM67. Among these, cyclooxygenase-2 (Cox-2/Ptgs2) and osteopontin (Opn/Spp1) are known to be functionally significant in driving carcinogenesis. Results identify both Cox-2 and Opn as transcriptional targets of TAM67 with CRE, but not NFkappaB sites important in the Cox-2 promoter and an AP-1 site important in the Opn promoter.

Standard name | MATTHEWS_AP1_TARGETS
Systematic name | M1850
Organism | Mus musculus
PMID | 17363560
Authors | Matthews CP,Birkholz AM,Baker AR,Perella CM,Beck GR Jr,Young MR,Colburn NH
Category | C2
Sub-category | CGP
Brief description | Known targets of AP1 that were down-regulated by overexpression of TAM67, a dominant-negative form of JUN [GeneID=3725].
Full description | Activation of activator protein 1 (AP-1) and nuclear factor kappaB (NFkappaB)-dependent transcription is required for tumor promotion in cell culture models and transgenic mice. Dominant-negative c-Jun (TAM67) blocks AP-1 activation by dimerizing with Jun or Fos family proteins and blocks NFkappaB activation by interacting with NFkappaB p65. Two-stage [7,12-dimethylbenz(a)anthracene (DMBA)/12-O-tetradecanoylphorbol-13-acetate (TPA)] skin carcinogenesis experiments in a model relevant to human cancer risk, transgenic mice expressing human papillomavirus 16 E7 oncogene (K14-HPV16-E7), show E7-enhanced tumor promotion. A cross to K14-TAM67-expressing mice results in dramatic inhibition of tumor promoter-induced AP-1 luciferase reporter activation and papillomagenesis. Epithelial specific TAM67 expression inhibits tumorigenesis without affecting TPA- or E7-induced hyperproliferation of the skin. Thus, the mouse model enriches for TAM67 targets relevant to tumorigenesis rather than to general cell proliferation or hyperplasia, implicating a subset of AP-1- and/or NFkappaB-dependent genes. The aim of the present study was to identify target genes responsible for TAM67 inhibition of DMBA-TPA-induced tumorigenesis. Microarray expression analysis of epidermal tissues revealed small sets of genes in which expression is both up-regulated by tumor promoter and down-regulated by TAM67. Among these, cyclooxygenase-2 (Cox-2/Ptgs2) and osteopontin (Opn/Spp1) are known to be functionally significant in driving carcinogenesis. Results identify both Cox-2 and Opn as transcriptional targets of TAM67 with CRE, but not NFkappaB sites important in the Cox-2 promoter and an AP-1 site important in the Opn promoter.

Standard name | QI_PLASMACYTOMA_UP
Systematic name | M1851
Organism | Mus musculus
PMID | 17363561
Authors | Qi CF,Zhou JX,Lee CH,Naghashfar Z,Xiang S,Kovalchuk AL,Fredrickson TN,Hartley JW,Roopenian DC,Davidson WF,Janz S,Morse HC 3rd
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes that best disciminate plasmablastic plasmacytoma from plasmacytic plasmacytoma tumors.
Full description | We have compared histologic features and gene expression profiles of newly identified plasmacytomas from NFS.V(+) congenic mice with plasmacytomas of IL6 transgenic, Fasl mutant, and SJL-beta2M(-/-) mice. NFS.V(+) tumors comprised an overlapping morphologic spectrum of high-grade/anaplastic, intermediate-grade/plasmablastic, and low-grade/plasmacytic cases with similarities to subsets of human multiple myeloma and plasmacytoma. Microarray and immunohistochemical analyses of genes expressed by the most prevalent tumors, plasmablastic plasmacytomas, showed them to be most closely related to immunoblastic lymphomas, less so to plasmacytomas of Fasl mutant and SJL mice, and least to plasmacytic plasmacytomas of IL6 transgenic mice. Plasmablastic tumors seemed to develop in an inflammatory environment associated with gene signatures of T cells, natural killer cells, and macrophages not seen with plasmacytic plasmacytomas. Plasmablastic plasmacytomas from NFS.V(+) and SJL-beta2M(-/-) mice did not have structural alterations in Myc or T(12;15) translocations and did not express Myc at high levels, regular features of transgenic and pristane-induced plasmacytomas. These findings imply that, as for human multiple myeloma, Myc-independent routes of transformation contribute to the pathogenesis of these tumors. These findings suggest that plasma cell neoplasms of mice and humans exhibit similar degrees of complexity. Mouse plasmacytomas, previously considered to be homogeneous, may thus be as diverse as their human counterparts with respect to oncogenic mechanisms of plasma cell transformation. Selecting specific types of mouse plasmacytomas that relate most closely to subtypes of human multiple myeloma may provide new opportunities for preclinical testing of drugs for treatment of the human disease.

Standard name | QI_PLASMACYTOMA_DN
Systematic name | M1852
Organism | Mus musculus
PMID | 17363561
Authors | Qi CF,Zhou JX,Lee CH,Naghashfar Z,Xiang S,Kovalchuk AL,Fredrickson TN,Hartley JW,Roopenian DC,Davidson WF,Janz S,Morse HC 3rd
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes that best disciminate plasmablastic plasmacytoma from plasmacytic plasmacytoma tumors.
Full description | We have compared histologic features and gene expression profiles of newly identified plasmacytomas from NFS.V(+) congenic mice with plasmacytomas of IL6 transgenic, Fasl mutant, and SJL-beta2M(-/-) mice. NFS.V(+) tumors comprised an overlapping morphologic spectrum of high-grade/anaplastic, intermediate-grade/plasmablastic, and low-grade/plasmacytic cases with similarities to subsets of human multiple myeloma and plasmacytoma. Microarray and immunohistochemical analyses of genes expressed by the most prevalent tumors, plasmablastic plasmacytomas, showed them to be most closely related to immunoblastic lymphomas, less so to plasmacytomas of Fasl mutant and SJL mice, and least to plasmacytic plasmacytomas of IL6 transgenic mice. Plasmablastic tumors seemed to develop in an inflammatory environment associated with gene signatures of T cells, natural killer cells, and macrophages not seen with plasmacytic plasmacytomas. Plasmablastic plasmacytomas from NFS.V(+) and SJL-beta2M(-/-) mice did not have structural alterations in Myc or T(12;15) translocations and did not express Myc at high levels, regular features of transgenic and pristane-induced plasmacytomas. These findings imply that, as for human multiple myeloma, Myc-independent routes of transformation contribute to the pathogenesis of these tumors. These findings suggest that plasma cell neoplasms of mice and humans exhibit similar degrees of complexity. Mouse plasmacytomas, previously considered to be homogeneous, may thus be as diverse as their human counterparts with respect to oncogenic mechanisms of plasma cell transformation. Selecting specific types of mouse plasmacytomas that relate most closely to subtypes of human multiple myeloma may provide new opportunities for preclinical testing of drugs for treatment of the human disease.

Standard name | TAYLOR_METHYLATED_IN_ACUTE_LYMPHOBLASTIC_LEUKEMIA
Systematic name | M2438
Organism | Homo sapiens
PMID | 17363581
Authors | Taylor KH,Pena-Hernandez KE,Davis JW,Arthur GL,Duff DJ,Shi H,Rahmatpanah FB,Sjahputera O,Caldwell CW
Category | C2
Sub-category | CGP
Brief description | Genes whose DNA methylation differed between primary ALL cells (acute lymphoblastic leukemia) and normal peripheral blood samples.
Full description | This study examined DNA methylation associated with acute lymphoblastic leukemia (ALL) and showed that selected molecular targets can be pharmacologically modulated to reverse gene silencing. A CpG island (CGI) microarray containing more than 3,400 unique clones that span all human chromosomes was used for large-scale discovery experiments and led to 262 unique CGI loci being statistically identified as methylated in ALL lymphoblasts. The methylation status of 10 clones encompassing 11 genes (DCC, DLC-1, DDX51, KCNK2, LRP1B, NKX6-1, NOPE, PCDHGA12, RPIB9, ABCB1, and SLC2A14) identified as differentially methylated between ALL patients and controls was independently verified. Consequently, the methylation status of DDX51 was found to differentiate patients with B- and T-ALL subtypes (P = 0.011, Fisher's exact test). Next, the relationship between methylation and expression of these genes was examined in ALL cell lines (NALM-6 and Jurkat) before and after treatments with 5-aza-2-deoxycytidine and trichostatin A. More than a 10-fold increase in mRNA expression was observed for two previously identified tumor suppressor genes (DLC-1 and DCC) and also for RPIB9 and PCDHGA12. Although the mechanisms that lead to the CGI methylation of these genes are unknown, bisulfite sequencing of the promoter of RPIB9 suggests that expression is inhibited by methylation within SP1 and AP2 transcription factor binding motifs. Finally, specific chromosomal methylation hotspots were found to be associated with ALL. This study sets the stage for acquiring a better biological understanding of ALL and for the identification of epigenetic biomarkers useful for differential diagnosis, therapeutic monitoring, and the detection of leukemic relapse.

Standard name | CHNG_MULTIPLE_MYELOMA_HYPERPLOID_UP
Systematic name | M15555
Organism | Homo sapiens
PMID | 17409404
Authors | Chng WJ,Kumar S,Vanwier S,Ahmann G,Price-Troska T,Henderson K,Chung TH,Kim S,Mulligan G,Bryant B,Carpten J,Gertz M,Rajkumar SV,Lacy M,Dispenzieri A,Kyle R,Greipp P,Bergsagel PL,Fonseca R
Category | C2
Sub-category | CGP
Brief description | Protein biosynthesis, transport or catabolism genes up-regulated in hyperploid multiple myeloma (MM) compared to the non-hyperploid MM samples.
Full description | Hyperdiploid multiple myeloma (H-MM) is the most common form of myeloma. In this gene expression profiling study, we show that H-MM is defined by a protein biosynthesis signature that is primarily driven by a gene dosage mechanism as a result of trisomic chromosomes. Within H-MM, four independently validated patient clusters overexpressing nonoverlapping sets of genes that form cognate pathways/networks that have potential biological importance in multiple myeloma were identified. One prominent cluster, cluster 1, is characterized by high expression of cancer testis antigen and proliferation-associated genes. Tumors from these patients were more proliferative than tumors in other clusters (median plasma cell labeling index, 3.8; P < 0.05). Another cluster, cluster 3, is characterized by genes involved in tumor necrosis factor/nuclear factor-kappaB signaling and antiapoptosis. These patients have better response to bortezomib as compared with patients within other clusters (70% versus 29%; P = 0.02). Furthermore, for a group of patients generally thought to have better prognosis, a cluster of patients with short survival (cluster 1; median survival, 27 months) could be identified. This analysis illustrates the heterogeneity within H-MM and the importance of defining specific cytogenetic prognostic factors. Furthermore, the signatures that defined these clusters may provide a basis for tailoring treatment to individual patients.

Standard name | CHNG_MULTIPLE_MYELOMA_HYPERPLOID_DN
Systematic name | M8214
Organism | Homo sapiens
PMID | 17409404
Authors | Chng WJ,Kumar S,Vanwier S,Ahmann G,Price-Troska T,Henderson K,Chung TH,Kim S,Mulligan G,Bryant B,Carpten J,Gertz M,Rajkumar SV,Lacy M,Dispenzieri A,Kyle R,Greipp P,Bergsagel PL,Fonseca R
Category | C2
Sub-category | CGP
Brief description | Protein biosynthesis, transport or catabolism genes down-regulated in hyperploid multiple myeloma (MM) compared to the non-hyperploid MM samples.
Full description | Hyperdiploid multiple myeloma (H-MM) is the most common form of myeloma. In this gene expression profiling study, we show that H-MM is defined by a protein biosynthesis signature that is primarily driven by a gene dosage mechanism as a result of trisomic chromosomes. Within H-MM, four independently validated patient clusters overexpressing nonoverlapping sets of genes that form cognate pathways/networks that have potential biological importance in multiple myeloma were identified. One prominent cluster, cluster 1, is characterized by high expression of cancer testis antigen and proliferation-associated genes. Tumors from these patients were more proliferative than tumors in other clusters (median plasma cell labeling index, 3.8; P < 0.05). Another cluster, cluster 3, is characterized by genes involved in tumor necrosis factor/nuclear factor-kappaB signaling and antiapoptosis. These patients have better response to bortezomib as compared with patients within other clusters (70% versus 29%; P = 0.02). Furthermore, for a group of patients generally thought to have better prognosis, a cluster of patients with short survival (cluster 1; median survival, 27 months) could be identified. This analysis illustrates the heterogeneity within H-MM and the importance of defining specific cytogenetic prognostic factors. Furthermore, the signatures that defined these clusters may provide a basis for tailoring treatment to individual patients.

Standard name | HUPER_BREAST_BASAL_VS_LUMINAL_UP
Systematic name | M13422
Organism | Homo sapiens
PMID | 17409405
Authors | Huper G,Marks JR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in basal mammary epithelial cells compared to the luminal ones.
Full description | Epithelial cells within the normal breast duct seem to be the primary target for neoplastic transformation events that eventually produce breast cancer. Normal epithelial cells are easily isolated and propagated using standard techniques. However, these techniques almost invariably result in populations of cells that are largely basal in character. Because only approximately 20% of human breast cancers exhibit a basal phenotype, our understanding of the disease may be skewed by using these cells as the primary comparator to cancer. Further, because germ line mutations in BRCA1 yield breast cancers that are most often of the basal type, a comparison of normal basal and luminal cells could yield insight into the tissue and cell type specificity of this hereditary cancer susceptibility gene. In this report, we describe a simplified and efficient method for isolating basal and luminal cells from normal human breast tissue. These isogenic cells can be independently propagated and maintain phenotypic markers consistent with their respective lineages. Using these cultured cells, we show that basal and luminal cells exhibit distinct responses to ionizing radiation. Basal cells undergo a rapid but labile cell cycle arrest, whereas luminal cells show a much more durable arrest, primarily at the G(2)-M boundary. Molecular markers, including p53 protein accumulation, p53-activated genes, and BRCA1 nuclear focus formation all correlate with the respective cell cycle responses. Further, we show that short-term cultures of human breast tissue fragments treated with ionizing radiation show a similar phenomenon as indicated by the biphasic accumulation of p53 protein in the basal versus luminal layer. Together, these results indicate that normal basal cells have a transitory cell cycle arrest after DNA damage that may underlie their increased susceptibility to transformation after the loss of functional BRCA1.

Standard name | HUPER_BREAST_BASAL_VS_LUMINAL_DN
Systematic name | M5505
Organism | Homo sapiens
PMID | 17409405
Authors | Huper G,Marks JR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in basal mammary epithelial cells compared to the luminal ones.
Full description | Epithelial cells within the normal breast duct seem to be the primary target for neoplastic transformation events that eventually produce breast cancer. Normal epithelial cells are easily isolated and propagated using standard techniques. However, these techniques almost invariably result in populations of cells that are largely basal in character. Because only approximately 20% of human breast cancers exhibit a basal phenotype, our understanding of the disease may be skewed by using these cells as the primary comparator to cancer. Further, because germ line mutations in BRCA1 yield breast cancers that are most often of the basal type, a comparison of normal basal and luminal cells could yield insight into the tissue and cell type specificity of this hereditary cancer susceptibility gene. In this report, we describe a simplified and efficient method for isolating basal and luminal cells from normal human breast tissue. These isogenic cells can be independently propagated and maintain phenotypic markers consistent with their respective lineages. Using these cultured cells, we show that basal and luminal cells exhibit distinct responses to ionizing radiation. Basal cells undergo a rapid but labile cell cycle arrest, whereas luminal cells show a much more durable arrest, primarily at the G(2)-M boundary. Molecular markers, including p53 protein accumulation, p53-activated genes, and BRCA1 nuclear focus formation all correlate with the respective cell cycle responses. Further, we show that short-term cultures of human breast tissue fragments treated with ionizing radiation show a similar phenomenon as indicated by the biphasic accumulation of p53 protein in the basal versus luminal layer. Together, these results indicate that normal basal cells have a transitory cell cycle arrest after DNA damage that may underlie their increased susceptibility to transformation after the loss of functional BRCA1.

Standard name | MALONEY_RESPONSE_TO_17AAG_UP
Systematic name | M1857
Organism | Homo sapiens
PMID | 17409432
Authors | Maloney A,Clarke PA,Naaby-Hansen S,Stein R,Koopman JO,Akpan A,Yang A,Zvelebil M,Cramer R,Stimson L,Aherne W,Banerji U,Judson I,Sharp S,Powers M,deBilly E,Salmons J,Walton M,Burlingame A,Waterfield M,Workman P
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in A2780 cells (ovarian cancer) treated with 17AAG [PubChem=6440175], a chemical with anticancer properties.
Full description | The promising antitumor activity of 17-allylamino-17-demethoxygeldanamycin (17AAG) results from inhibition of the molecular chaperone heat shock protein 90 (HSP90) and subsequent degradation of multiple oncogenic client proteins. Gene expression microarray and proteomic analysis were used to profile molecular changes in the A2780 human ovarian cancer cell line treated with 17AAG. Comparison of results with an inactive analogue and an alternative HSP90 inhibitor radicicol indicated that increased expression of HSP72, HSC70, HSP27, HSP47, and HSP90beta at the mRNA level were on-target effects of 17AAG. HSP27 protein levels were increased in tumor biopsies following treatment of patients with 17AAG. A group of MYC-regulated mRNAs was decreased by 17AAG. Of particular interest and novelty were changes in expression of chromatin-associated proteins. Expression of the heterochromatin protein 1 was increased, and expression of the histone acetyltransferase 1 and the histone arginine methyltransferase PRMT5 was decreased by 17AAG. PRMT5 was shown to be a novel HSP90-binding partner and potential client protein. Cellular protein acetylation was reduced by 17AAG, which was shown to have an antagonistic interaction on cell proliferation with the histone deacetylase inhibitor trichostatin A. This mRNA and protein expression analysis has provided new insights into the complex molecular pharmacology of 17AAG and suggested new genes and proteins that may be involved in response to the drug or be potential biomarkers of drug action.

Standard name | MALONEY_RESPONSE_TO_17AAG_DN
Systematic name | M1858
Organism | Homo sapiens
PMID | 17409432
Authors | Maloney A,Clarke PA,Naaby-Hansen S,Stein R,Koopman JO,Akpan A,Yang A,Zvelebil M,Cramer R,Stimson L,Aherne W,Banerji U,Judson I,Sharp S,Powers M,deBilly E,Salmons J,Walton M,Burlingame A,Waterfield M,Workman P
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in A2780 cells (ovarian cancer) treated with 17AAG [PubChem=6440175], a chemical with anticancer properties.
Full description | The promising antitumor activity of 17-allylamino-17-demethoxygeldanamycin (17AAG) results from inhibition of the molecular chaperone heat shock protein 90 (HSP90) and subsequent degradation of multiple oncogenic client proteins. Gene expression microarray and proteomic analysis were used to profile molecular changes in the A2780 human ovarian cancer cell line treated with 17AAG. Comparison of results with an inactive analogue and an alternative HSP90 inhibitor radicicol indicated that increased expression of HSP72, HSC70, HSP27, HSP47, and HSP90beta at the mRNA level were on-target effects of 17AAG. HSP27 protein levels were increased in tumor biopsies following treatment of patients with 17AAG. A group of MYC-regulated mRNAs was decreased by 17AAG. Of particular interest and novelty were changes in expression of chromatin-associated proteins. Expression of the heterochromatin protein 1 was increased, and expression of the histone acetyltransferase 1 and the histone arginine methyltransferase PRMT5 was decreased by 17AAG. PRMT5 was shown to be a novel HSP90-binding partner and potential client protein. Cellular protein acetylation was reduced by 17AAG, which was shown to have an antagonistic interaction on cell proliferation with the histone deacetylase inhibitor trichostatin A. This mRNA and protein expression analysis has provided new insights into the complex molecular pharmacology of 17AAG and suggested new genes and proteins that may be involved in response to the drug or be potential biomarkers of drug action.

Standard name | CUI_GLUCOSE_DEPRIVATION
Systematic name | M9780
Organism | Homo sapiens
PMID | 17409444
Authors | Cui H,Darmanin S,Natsuisaka M,Kondo T,Asaka M,Shindoh M,Higashino F,Hamuro J,Okada F,Kobayashi M,Nakagawa K,Koide H
Category | C2
Sub-category | CGP
Brief description | Representative genes up-regulated in MiaPaCa2 cells (pancreatic cancer) under glucose-deprived conditions.
Full description | Although hypovasculature is an outstanding characteristic of pancreatic cancers, the tumor cells survive and proliferate under severe hypoxic, glucose-deprived conditions caused by low blood supply. It is well known that the hypoxia-inducible factor-1 pathway is essential for the survival of pancreatic cancer cells under hypoxic conditions. To discover how pancreatic cancer cells adapt to glucose deprivation as well as hypoxia, we sought glucose deprivation-inducible genes by means of a DNA microarray system. We identified 63 genes whose expression was enhanced under glucose-deprived conditions at >2-fold higher levels than under normal glucose conditions. Among these genes, asparagine synthetase (ASNS) was studied in detail. Although it is known to be associated with drug resistance in leukemia and oncogenesis triggered by mutated p53, its function is yet to be determined. In this study, we found that glucose deprivation induced the overexpression of ASNS through an AMP-activated protein kinase-independent and activating transcription factor-4-dependent manner and that ASNS protects pancreatic cancer cells from apoptosis induced by glucose deprivation itself. ASNS overexpression also induced resistance to apoptosis triggered by cisplatin [cis-diammine-dichloroplatinum (CDDP)] and carboplatin, but not by 5-fluorouracil, paclitaxel, etoposide, or gemcitabine. We show that glucose deprivation induces the activation of c-jun NH(2)-terminal kinase (JNK)/stress-activated protein kinase (SAPK) in a mock transfectant but not in an ASNS transfectant. Consequently, an inhibitor of JNK/SAPK decreased the sensitivity of pancreatic cancer cells to apoptosis by glucose deprivation and CDDP. These results strongly suggest that ASNS is induced by glucose deprivation and may play a pivotal role in the survival of pancreatic cancer cells under glucose-deprived conditions.

Standard name | BLUM_RESPONSE_TO_SALIRASIB_UP
Systematic name | M7300
Organism | Homo sapiens
PMID | 17409441
Authors | Blum R,Elkon R,Yaari S,Zundelevich A,Jacob-Hirsch J,Rechavi G,Shamir R,Kloog Y
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated in response to the Ras inhibitor salirasib [PubChem=5469318] in a panel of cancer cell lines with constantly active HRAS [GeneID=3265].
Full description | Deregulation of Ras pathways results in complex abnormalities of multiple signaling cascades that contribute to human malignancies. Ras is therefore considered an appropriate target for cancer therapy. In light of the complexity of the deregulated Ras pathway, it is important to decipher at the molecular level the response of cancer cells to Ras inhibitors that would reregulate it. In the present study, we used gene expression profiling as a robust method for the global dissection of gene expression alterations that resulted from treatment with the Ras inhibitor S-farnesylthiosalicylic acid (FTS; salirasib). Use of a ranking-based procedure, combined with functional analysis and promoter sequence analysis, enabled us to decipher the common and most prominent patterns of the transcriptional response of five different human cancer cell lines to FTS. Remarkably, the analysis identified a distinctive core transcriptional response to FTS that was common to all cancer cell lines tested. This signature fits well to a recently described deregulated Ras pathway signature that predicted sensitivity to FTS. Taken together, these studies provide strong support for the conclusion that FTS specifically reregulates defective Ras pathways in human tumor cells. Ras pathway reregulation by FTS was manifested by repression of E2F-regulated and NF-Y-regulated genes and of the transcription factor FOS (all of which control cell proliferation), repression of survivin expression (which blocks apoptosis), and induction of activating transcription factor-regulated and Bach2-regulated genes (which participate in translation and stress responses). Our results suggest that cancer patients with deregulated Ras pathway tumors might benefit from FTS treatment.

Standard name | BLUM_RESPONSE_TO_SALIRASIB_DN
Systematic name | M2879
Organism | Homo sapiens
PMID | 17409441
Authors | Blum R,Elkon R,Yaari S,Zundelevich A,Jacob-Hirsch J,Rechavi G,Shamir R,Kloog Y
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated in response to the Ras inhibitor salirasib [PubChem=5469318] in a panel of cancer cell lines with constantly active HRAS [GeneID=3265].
Full description | Deregulation of Ras pathways results in complex abnormalities of multiple signaling cascades that contribute to human malignancies. Ras is therefore considered an appropriate target for cancer therapy. In light of the complexity of the deregulated Ras pathway, it is important to decipher at the molecular level the response of cancer cells to Ras inhibitors that would reregulate it. In the present study, we used gene expression profiling as a robust method for the global dissection of gene expression alterations that resulted from treatment with the Ras inhibitor S-farnesylthiosalicylic acid (FTS; salirasib). Use of a ranking-based procedure, combined with functional analysis and promoter sequence analysis, enabled us to decipher the common and most prominent patterns of the transcriptional response of five different human cancer cell lines to FTS. Remarkably, the analysis identified a distinctive core transcriptional response to FTS that was common to all cancer cell lines tested. This signature fits well to a recently described deregulated Ras pathway signature that predicted sensitivity to FTS. Taken together, these studies provide strong support for the conclusion that FTS specifically reregulates defective Ras pathways in human tumor cells. Ras pathway reregulation by FTS was manifested by repression of E2F-regulated and NF-Y-regulated genes and of the transcription factor FOS (all of which control cell proliferation), repression of survivin expression (which blocks apoptosis), and induction of activating transcription factor-regulated and Bach2-regulated genes (which participate in translation and stress responses). Our results suggest that cancer patients with deregulated Ras pathway tumors might benefit from FTS treatment.

Standard name | WINTER_HYPOXIA_METAGENE
Systematic name | M14072
Organism | Homo sapiens
PMID | 17409455
Authors | Winter SC,Buffa FM,Silva P,Miller C,Valentine HR,Turley H,Shah KA,Cox GJ,Corbridge RJ,Homer JJ,Musgrove B,Slevin N,Sloan P,Price P,West CM,Harris AL
Category | C2
Sub-category | CGP
Brief description | Genes regulated by hypoxia, based on literature searches.
Full description | Affymetrix U133plus2 GeneChips were used to profile 59 head and neck squamous cell cancers. A hypoxia metagene was obtained by analysis of genes whose in vivo expression clustered with the expression of 10 well-known hypoxia-regulated genes (e.g., CA9, GLUT1, and VEGF). To minimize random aggregation, strongly correlated up-regulated genes appearing in >50% of clusters defined a signature comprising 99 genes, of which 27% were previously known to be hypoxia associated. The median RNA expression of the 99 genes in the signature was an independent prognostic factor for recurrence-free survival in a publicly available head and neck cancer data set, outdoing the original intrinsic classifier. In a published breast cancer series, the hypoxia signature was a significant prognostic factor for overall survival independent of clinicopathologic risk factors and a trained profile. The work highlights the validity and potential of using data from analysis of in vitro stress pathways for deriving a biological metagene/gene signature in vivo.

Standard name | ALONSO_METASTASIS_EMT_UP
Systematic name | M8191
Organism | Homo sapiens
PMID | 17409456
Authors | Alonso SR,Tracey L,Ortiz P,Pérez-Gómez B,Palacios J,Pollán M,Linares J,Serrano S,Sáez-Castillo AI,Sánchez L,Pajares R,Sánchez-Aguilera A,Artiga MJ,Piris MA,Rodríguez-Peralto JL
Category | C2
Sub-category | CGP
Brief description | EMT (epithelial-mesenchymal transition) genes up-regulated genes in melanoma tumous that developed metastatic disease compared to primary melanoma that did not.
Full description | Metastatic disease is the primary cause of death in cutaneous malignant melanoma (CMM) patients. To understand the mechanisms of CMM metastasis and identify potential predictive markers, we analyzed gene-expression profiles of 34 vertical growth phase melanoma cases using cDNA microarrays. All patients had a minimum follow-up of 36 months. Twenty-one cases developed nodal metastatic disease and 13 did not. Comparison of gene expression profiling of metastatic and nonmetastatic melanoma cases identified 243 genes with a >2-fold differential expression ratio and a false discovery rate of <0.2 (206 up-regulated and 37 down-regulated). This set of genes included molecules involved in cell cycle and apoptosis regulation, epithelial-mesenchymal transition (EMT), signal transduction, nucleic acid binding and transcription, protein synthesis and degradation, metabolism, and a specific group of melanoma- and neural-related proteins. Validation of these expression data in an independent series of melanomas using tissue microarrays confirmed that the expression of a set of proteins included in the EMT group (N-cadherin, osteopontin, and SPARC/osteonectin) were significantly associated with metastasis development. Our results suggest that EMT-related genes contribute to the promotion of the metastatic phenotype in primary CMM by supporting specific adhesive, invasive, and migratory properties. These data give a better understanding of the biology of this aggressive tumor and may provide new prognostic and patient stratification markers in addition to potential therapeutic targets.

Standard name | ALONSO_METASTASIS_EMT_DN
Systematic name | M3029
Organism | Homo sapiens
PMID | 17409456
Authors | Alonso SR,Tracey L,Ortiz P,Pérez-Gómez B,Palacios J,Pollán M,Linares J,Serrano S,Sáez-Castillo AI,Sánchez L,Pajares R,Sánchez-Aguilera A,Artiga MJ,Piris MA,Rodríguez-Peralto JL
Category | C2
Sub-category | CGP
Brief description | EMT (epithelial-mesenchymal transition) genes down-regulated genes in melanoma tumous that developed metastatic disease compared to primary melanoma that did not.
Full description | Metastatic disease is the primary cause of death in cutaneous malignant melanoma (CMM) patients. To understand the mechanisms of CMM metastasis and identify potential predictive markers, we analyzed gene-expression profiles of 34 vertical growth phase melanoma cases using cDNA microarrays. All patients had a minimum follow-up of 36 months. Twenty-one cases developed nodal metastatic disease and 13 did not. Comparison of gene expression profiling of metastatic and nonmetastatic melanoma cases identified 243 genes with a >2-fold differential expression ratio and a false discovery rate of <0.2 (206 up-regulated and 37 down-regulated). This set of genes included molecules involved in cell cycle and apoptosis regulation, epithelial-mesenchymal transition (EMT), signal transduction, nucleic acid binding and transcription, protein synthesis and degradation, metabolism, and a specific group of melanoma- and neural-related proteins. Validation of these expression data in an independent series of melanomas using tissue microarrays confirmed that the expression of a set of proteins included in the EMT group (N-cadherin, osteopontin, and SPARC/osteonectin) were significantly associated with metastasis development. Our results suggest that EMT-related genes contribute to the promotion of the metastatic phenotype in primary CMM by supporting specific adhesive, invasive, and migratory properties. These data give a better understanding of the biology of this aggressive tumor and may provide new prognostic and patient stratification markers in addition to potential therapeutic targets.

Standard name | ALONSO_METASTASIS_NEURAL_UP
Systematic name | M19437
Organism | Homo sapiens
PMID | 17409456
Authors | Alonso SR,Tracey L,Ortiz P,Pérez-Gómez B,Palacios J,Pollán M,Linares J,Serrano S,Sáez-Castillo AI,Sánchez L,Pajares R,Sánchez-Aguilera A,Artiga MJ,Piris MA,Rodríguez-Peralto JL
Category | C2
Sub-category | CGP
Brief description | Neural-related genes up-regulated in melanoma tumors that developed metastases compared to primary melanoma that did not.
Full description | Metastatic disease is the primary cause of death in cutaneous malignant melanoma (CMM) patients. To understand the mechanisms of CMM metastasis and identify potential predictive markers, we analyzed gene-expression profiles of 34 vertical growth phase melanoma cases using cDNA microarrays. All patients had a minimum follow-up of 36 months. Twenty-one cases developed nodal metastatic disease and 13 did not. Comparison of gene expression profiling of metastatic and nonmetastatic melanoma cases identified 243 genes with a >2-fold differential expression ratio and a false discovery rate of <0.2 (206 up-regulated and 37 down-regulated). This set of genes included molecules involved in cell cycle and apoptosis regulation, epithelial-mesenchymal transition (EMT), signal transduction, nucleic acid binding and transcription, protein synthesis and degradation, metabolism, and a specific group of melanoma- and neural-related proteins. Validation of these expression data in an independent series of melanomas using tissue microarrays confirmed that the expression of a set of proteins included in the EMT group (N-cadherin, osteopontin, and SPARC/osteonectin) were significantly associated with metastasis development. Our results suggest that EMT-related genes contribute to the promotion of the metastatic phenotype in primary CMM by supporting specific adhesive, invasive, and migratory properties. These data give a better understanding of the biology of this aggressive tumor and may provide new prognostic and patient stratification markers in addition to potential therapeutic targets.

Standard name | ALONSO_METASTASIS_UP
Systematic name | M3582
Organism | Homo sapiens
PMID | 17409456
Authors | Alonso SR,Tracey L,Ortiz P,Pérez-Gómez B,Palacios J,Pollán M,Linares J,Serrano S,Sáez-Castillo AI,Sánchez L,Pajares R,Sánchez-Aguilera A,Artiga MJ,Piris MA,Rodríguez-Peralto JL
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in melanoma tumous that developed metastatic disease compared to primary melanoma that did not.
Full description | Metastatic disease is the primary cause of death in cutaneous malignant melanoma (CMM) patients. To understand the mechanisms of CMM metastasis and identify potential predictive markers, we analyzed gene-expression profiles of 34 vertical growth phase melanoma cases using cDNA microarrays. All patients had a minimum follow-up of 36 months. Twenty-one cases developed nodal metastatic disease and 13 did not. Comparison of gene expression profiling of metastatic and nonmetastatic melanoma cases identified 243 genes with a >2-fold differential expression ratio and a false discovery rate of <0.2 (206 up-regulated and 37 down-regulated). This set of genes included molecules involved in cell cycle and apoptosis regulation, epithelial-mesenchymal transition (EMT), signal transduction, nucleic acid binding and transcription, protein synthesis and degradation, metabolism, and a specific group of melanoma- and neural-related proteins. Validation of these expression data in an independent series of melanomas using tissue microarrays confirmed that the expression of a set of proteins included in the EMT group (N-cadherin, osteopontin, and SPARC/osteonectin) were significantly associated with metastasis development. Our results suggest that EMT-related genes contribute to the promotion of the metastatic phenotype in primary CMM by supporting specific adhesive, invasive, and migratory properties. These data give a better understanding of the biology of this aggressive tumor and may provide new prognostic and patient stratification markers in addition to potential therapeutic targets.

Standard name | ALONSO_METASTASIS_DN
Systematic name | M17331
Organism | Homo sapiens
PMID | 17409456
Authors | Alonso SR,Tracey L,Ortiz P,Pérez-Gómez B,Palacios J,Pollán M,Linares J,Serrano S,Sáez-Castillo AI,Sánchez L,Pajares R,Sánchez-Aguilera A,Artiga MJ,Piris MA,Rodríguez-Peralto JL
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in melanoma tumors that developed metastatic disease compared to primary melanoma that did not.
Full description | Metastatic disease is the primary cause of death in cutaneous malignant melanoma (CMM) patients. To understand the mechanisms of CMM metastasis and identify potential predictive markers, we analyzed gene-expression profiles of 34 vertical growth phase melanoma cases using cDNA microarrays. All patients had a minimum follow-up of 36 months. Twenty-one cases developed nodal metastatic disease and 13 did not. Comparison of gene expression profiling of metastatic and nonmetastatic melanoma cases identified 243 genes with a >2-fold differential expression ratio and a false discovery rate of <0.2 (206 up-regulated and 37 down-regulated). This set of genes included molecules involved in cell cycle and apoptosis regulation, epithelial-mesenchymal transition (EMT), signal transduction, nucleic acid binding and transcription, protein synthesis and degradation, metabolism, and a specific group of melanoma- and neural-related proteins. Validation of these expression data in an independent series of melanomas using tissue microarrays confirmed that the expression of a set of proteins included in the EMT group (N-cadherin, osteopontin, and SPARC/osteonectin) were significantly associated with metastasis development. Our results suggest that EMT-related genes contribute to the promotion of the metastatic phenotype in primary CMM by supporting specific adhesive, invasive, and migratory properties. These data give a better understanding of the biology of this aggressive tumor and may provide new prognostic and patient stratification markers in addition to potential therapeutic targets.

Standard name | CROMER_TUMORIGENESIS_UP
Systematic name | M178
Organism | Homo sapiens
PMID | 14676830
Authors | Cromer A,Carles A,Millon R,Ganguli G,Chalmel F,Lemaire F,Young J,Dembélé D,Thibault C,Muller D,Poch O,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Tumorigenesis markers of head and neck squamous cell carcinoma (HNSCC): up-regulated in the 'early' tumors vs normal samples.
Full description | Head and neck squamous cell carcinoma (HNSCC) is the sixth most common cancer among men in the developed world. There is a need, for both clinical and scientific reasons, to find markers to identify patients with aggressive disease as early as possible, and to understand the events leading to malignant transformation and susceptibility to metastasis. We report the first large-scale gene expression analysis of a unique HNSCC location, the hypopharynx. Four normal and 34 tumour samples were analysed with 12 600 gene microarrays. Clusters of differentially expressed genes were identified in the chromosomal regions 3q27.3, 17q21.2-q21.31, 7q11.22-q22.1 and 11q13.1-q13.3, which, interestingly, have already been identified by comparative genomic hybridization (CGH) as major regions of gene amplification. We showed that six overexpressed genes (EIF4G1, DVL3, EPHB4, MCM7, BRMS1 and SART1) located in these regions are indeed amplified. We report 119 genes that are highly differentially expressed between 'early' tumours and normal samples. Of these, we validated by quantitative PCR six novel poorly characterized genes. These genes are potential new markers of HNSCC. Comparing patients with relatively nonaggressive and aggressive tumours (without or with clinical evidence of metastasis 3 years after surgery), we identified 164 differentially expressed genes potentially involved in the acquisition of metastatic potential. This study contributes to the understanding of HNSCC, staging patients into prognostic groups and identifying high-risk patients who may benefit from more aggressive treatment.

Standard name | CROMER_TUMORIGENESIS_DN
Systematic name | M16948
Organism | Homo sapiens
PMID | 14676830
Authors | Cromer A,Carles A,Millon R,Ganguli G,Chalmel F,Lemaire F,Young J,Dembélé D,Thibault C,Muller D,Poch O,Abecassis J,Wasylyk B
Category | C2
Sub-category | CGP
Brief description | Tumorigenesis markers of head and neck squamous cell carcinoma (HNSCC): down-regulated in the 'early' tumors vs normal samples.
Full description | Head and neck squamous cell carcinoma (HNSCC) is the sixth most common cancer among men in the developed world. There is a need, for both clinical and scientific reasons, to find markers to identify patients with aggressive disease as early as possible, and to understand the events leading to malignant transformation and susceptibility to metastasis. We report the first large-scale gene expression analysis of a unique HNSCC location, the hypopharynx. Four normal and 34 tumour samples were analysed with 12 600 gene microarrays. Clusters of differentially expressed genes were identified in the chromosomal regions 3q27.3, 17q21.2-q21.31, 7q11.22-q22.1 and 11q13.1-q13.3, which, interestingly, have already been identified by comparative genomic hybridization (CGH) as major regions of gene amplification. We showed that six overexpressed genes (EIF4G1, DVL3, EPHB4, MCM7, BRMS1 and SART1) located in these regions are indeed amplified. We report 119 genes that are highly differentially expressed between 'early' tumours and normal samples. Of these, we validated by quantitative PCR six novel poorly characterized genes. These genes are potential new markers of HNSCC. Comparing patients with relatively nonaggressive and aggressive tumours (without or with clinical evidence of metastasis 3 years after surgery), we identified 164 differentially expressed genes potentially involved in the acquisition of metastatic potential. This study contributes to the understanding of HNSCC, staging patients into prognostic groups and identifying high-risk patients who may benefit from more aggressive treatment.

Standard name | KRISHNAN_FURIN_TARGETS_UP
Systematic name | M15228
Organism | Mus musculus
PMID | 18690214
Authors | Krishnan MN,Ng A,Sukumaran B,Gilfoy FD,Uchil PD,Sultana H,Brass AL,Adametz R,Tsui M,Qian F,Montgomery RR,Lev S,Mason PW,Koski RA,Elledge SJ,Xavier RJ,Agaisse H,Fikrig E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in naive T lymphocytes lacking FURIN [GeneID=5045]: Cre-Lox knockout of FURIN in CD4+ [GeneID=920] cells.
Full description | West Nile virus (WNV), and related flaviviruses such as tick-borne encephalitis, Japanese encephalitis, yellow fever and dengue viruses, constitute a significant global human health problem. However, our understanding of the molecular interaction of such flaviviruses with mammalian host cells is limited. WNV encodes only 10 proteins, implying that it may use many cellular proteins for infection. WNV enters the cytoplasm through pH-dependent endocytosis, undergoes cycles of translation and replication, assembles progeny virions in association with endoplasmic reticulum, and exits along the secretory pathway. RNA interference (RNAi) presents a powerful forward genetics approach to dissect virus-host cell interactions. Here we report the identification of 305 host proteins that affect WNV infection, using a human-genome-wide RNAi screen. Functional clustering of the genes revealed a complex dependence of this virus on host cell physiology, requiring a wide variety of molecules and cellular pathways for successful infection. We further demonstrate a requirement for the ubiquitin ligase CBLL1 in WNV internalization, a post-entry role for the endoplasmic-reticulum-associated degradation pathway in viral infection, and the monocarboxylic acid transporter MCT4 as a viral replication resistance factor. By extending this study to dengue virus, we show that flaviviruses have both overlapping and unique interaction strategies with host cells. This study provides a comprehensive molecular portrait of WNV-human cell interactions that forms a model for understanding single plus-stranded RNA virus infection, and reveals potential antiviral targets.

Standard name | KRISHNAN_FURIN_TARGETS_DN
Systematic name | M8701
Organism | Mus musculus
PMID | 18690214
Authors | Krishnan MN,Ng A,Sukumaran B,Gilfoy FD,Uchil PD,Sultana H,Brass AL,Adametz R,Tsui M,Qian F,Montgomery RR,Lev S,Mason PW,Koski RA,Elledge SJ,Xavier RJ,Agaisse H,Fikrig E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in naive T lymphocytes lacking FURIN [GeneID=5045]: Cre-Lox knockout of FURIN in CD4+ [GeneID=920] cells.
Full description | West Nile virus (WNV), and related flaviviruses such as tick-borne encephalitis, Japanese encephalitis, yellow fever and dengue viruses, constitute a significant global human health problem. However, our understanding of the molecular interaction of such flaviviruses with mammalian host cells is limited. WNV encodes only 10 proteins, implying that it may use many cellular proteins for infection. WNV enters the cytoplasm through pH-dependent endocytosis, undergoes cycles of translation and replication, assembles progeny virions in association with endoplasmic reticulum, and exits along the secretory pathway. RNA interference (RNAi) presents a powerful forward genetics approach to dissect virus-host cell interactions. Here we report the identification of 305 host proteins that affect WNV infection, using a human-genome-wide RNAi screen. Functional clustering of the genes revealed a complex dependence of this virus on host cell physiology, requiring a wide variety of molecules and cellular pathways for successful infection. We further demonstrate a requirement for the ubiquitin ligase CBLL1 in WNV internalization, a post-entry role for the endoplasmic-reticulum-associated degradation pathway in viral infection, and the monocarboxylic acid transporter MCT4 as a viral replication resistance factor. By extending this study to dengue virus, we show that flaviviruses have both overlapping and unique interaction strategies with host cells. This study provides a comprehensive molecular portrait of WNV-human cell interactions that forms a model for understanding single plus-stranded RNA virus infection, and reveals potential antiviral targets.

Standard name | MUELLER_PLURINET
Systematic name | M123
Organism | Homo sapiens
PMID | 18724358
Authors | Müller FJ,Laurent LC,Kostka D,Ulitsky I,Williams R,Lu C,Park IH,Rao MS,Shamir R,Schwartz PH,Schmidt NO,Loring JF
Category | C2
Sub-category | CGP
Brief description | Genes constituting the PluriNet protein-protein network shared by the pluripotent cells (embryonic stem cells, embryonical carcinomas and induced pluripotent cells).
Full description | Stem cells are defined as self-renewing cell populations that can differentiate into multiple distinct cell types. However, hundreds of different human cell lines from embryonic, fetal and adult sources have been called stem cells, even though they range from pluripotent cells-typified by embryonic stem cells, which are capable of virtually unlimited proliferation and differentiation-to adult stem cell lines, which can generate a far more limited repertoire of differentiated cell types. The rapid increase in reports of new sources of stem cells and their anticipated value to regenerative medicine has highlighted the need for a general, reproducible method for classification of these cells. We report here the creation and analysis of a database of global gene expression profiles (which we call the 'stem cell matrix') that enables the classification of cultured human stem cells in the context of a wide variety of pluripotent, multipotent and differentiated cell types. Using an unsupervised clustering method to categorize a collection of approximately 150 cell samples, we discovered that pluripotent stem cell lines group together, whereas other cell types, including brain-derived neural stem cell lines, are very diverse. Using further bioinformatic analysis we uncovered a protein-protein network (PluriNet) that is shared by the pluripotent cells (embryonic stem cells, embryonal carcinomas and induced pluripotent cells). Analysis of published data showed that the PluriNet seems to be a common characteristic of pluripotent cells, including mouse embryonic stem and induced pluripotent cells and human oocytes. Our results offer a new strategy for classifying stem cells and support the idea that pluripotency and self-renewal are under tight control by specific molecular networks.

Standard name | YAUCH_HEDGEHOG_SIGNALING_PARACRINE_UP
Systematic name | M19384
Organism | Mus musculus
PMID | 18754008
Authors | Yauch RL,Gould SE,Scales SJ,Tang T,Tian H,Ahn CP,Marshall D,Fu L,Januario T,Kallop D,Nannini-Pepe M,Kotkow K,Marsters JC,Rubin LL,de Sauvage FJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mouse stroma of pancreatic adenocarcinoma zenografts after treatment with HhAntag, a hedgehog (Hh) pathway inhibitor.
Full description | Ligand-dependent activation of the hedgehog (Hh) signalling pathway has been associated with tumorigenesis in a number of human tissues. Here we show that, although previous reports have described a cell-autonomous role for Hh signalling in these tumours, Hh ligands fail to activate signalling in tumour epithelial cells. In contrast, our data support ligand-dependent activation of the Hh pathway in the stromal microenvironment. Specific inhibition of Hh signalling using small molecule inhibitors, a neutralizing anti-Hh antibody or genetic deletion of smoothened (Smo) in the mouse stroma results in growth inhibition in xenograft tumour models. Taken together, these studies demonstrate a paracrine requirement for Hh ligand signalling in the tumorigenesis of Hh-expressing cancers and have important implications for the development of Hh pathway antagonists in cancer.

Standard name | YAUCH_HEDGEHOG_SIGNALING_PARACRINE_DN
Systematic name | M9331
Organism | Mus musculus
PMID | 18754008
Authors | Yauch RL,Gould SE,Scales SJ,Tang T,Tian H,Ahn CP,Marshall D,Fu L,Januario T,Kallop D,Nannini-Pepe M,Kotkow K,Marsters JC,Rubin LL,de Sauvage FJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mouse stroma of pancreatic adenocarcinoma zenografts after treatment with HhAntag, a hedgehog (Hh) pathway inhibitor.
Full description | Ligand-dependent activation of the hedgehog (Hh) signalling pathway has been associated with tumorigenesis in a number of human tissues. Here we show that, although previous reports have described a cell-autonomous role for Hh signalling in these tumours, Hh ligands fail to activate signalling in tumour epithelial cells. In contrast, our data support ligand-dependent activation of the Hh pathway in the stromal microenvironment. Specific inhibition of Hh signalling using small molecule inhibitors, a neutralizing anti-Hh antibody or genetic deletion of smoothened (Smo) in the mouse stroma results in growth inhibition in xenograft tumour models. Taken together, these studies demonstrate a paracrine requirement for Hh ligand signalling in the tumorigenesis of Hh-expressing cancers and have important implications for the development of Hh pathway antagonists in cancer.

Standard name | FIRESTEIN_CTNNB1_PATHWAY_AND_PROLIFERATION
Systematic name | M16807
Organism | Homo sapiens
PMID | 18794900
Authors | Firestein R,Bass AJ,Kim SY,Dunn IF,Silver SJ,Guney I,Freed E,Ligon AH,Vena N,Ogino S,Chheda MG,Tamayo P,Finn S,Shrestha Y,Boehm JS,Jain S,Bojarski E,Mermel C,Barretina J,Chan JA,Baselga J,Tabernero J,Root DE,Fuchs CS,Loda M,Shivdasani RA,Meyerson M,Hahn WC
Category | C2
Sub-category | CGP
Brief description | Genes required for both proliferation and CTNNB1 [GeneID=1499] activity in DLD-1 cell (colon cancer with APC [GeneID=324] deletions).
Full description | Aberrant activation of the canonical WNT/beta-catenin pathway occurs in almost all colorectal cancers and contributes to their growth, invasion and survival. Although dysregulated beta-catenin activity drives colon tumorigenesis, further genetic perturbations are required to elaborate full malignant transformation. To identify genes that both modulate beta-catenin activity and are essential for colon cancer cell proliferation, we conducted two loss-of-function screens in human colon cancer cells and compared genes identified in these screens with an analysis of copy number alterations in colon cancer specimens. One of these genes, CDK8, which encodes a member of the mediator complex, is located at 13q12.13, a region of recurrent copy number gain in a substantial fraction of colon cancers. Here we show that the suppression of CDK8 expression inhibits proliferation in colon cancer cells characterized by high levels of CDK8 and beta-catenin hyperactivity. CDK8 kinase activity was necessary for beta-catenin-driven transformation and for expression of several beta-catenin transcriptional targets. Together these observations suggest that therapeutic interventions targeting CDK8 may confer a clinical benefit in beta-catenin-driven malignancies.

Standard name | FIRESTEIN_CTNNB1_PATHWAY
Systematic name | M1489
Organism | Homo sapiens
PMID | 18794900
Authors | Firestein R,Bass AJ,Kim SY,Dunn IF,Silver SJ,Guney I,Freed E,Ligon AH,Vena N,Ogino S,Chheda MG,Tamayo P,Finn S,Shrestha Y,Boehm JS,Jain S,Bojarski E,Mermel C,Barretina J,Chan JA,Baselga J,Tabernero J,Root DE,Fuchs CS,Loda M,Shivdasani RA,Meyerson M,Hahn WC
Category | C2
Sub-category | CGP
Brief description | Genes required for CTNNB1 [GeneID=1499] activity in DLD-1 cell (colon cancer with APC [GeneID=324] deletions), based on shRNA screen.
Full description | Aberrant activation of the canonical WNT/beta-catenin pathway occurs in almost all colorectal cancers and contributes to their growth, invasion and survival. Although dysregulated beta-catenin activity drives colon tumorigenesis, further genetic perturbations are required to elaborate full malignant transformation. To identify genes that both modulate beta-catenin activity and are essential for colon cancer cell proliferation, we conducted two loss-of-function screens in human colon cancer cells and compared genes identified in these screens with an analysis of copy number alterations in colon cancer specimens. One of these genes, CDK8, which encodes a member of the mediator complex, is located at 13q12.13, a region of recurrent copy number gain in a substantial fraction of colon cancers. Here we show that the suppression of CDK8 expression inhibits proliferation in colon cancer cells characterized by high levels of CDK8 and beta-catenin hyperactivity. CDK8 kinase activity was necessary for beta-catenin-driven transformation and for expression of several beta-catenin transcriptional targets. Together these observations suggest that therapeutic interventions targeting CDK8 may confer a clinical benefit in beta-catenin-driven malignancies.

Standard name | FIRESTEIN_PROLIFERATION
Systematic name | M5354
Organism | Homo sapiens
PMID | 18794900
Authors | Firestein R,Bass AJ,Kim SY,Dunn IF,Silver SJ,Guney I,Freed E,Ligon AH,Vena N,Ogino S,Chheda MG,Tamayo P,Finn S,Shrestha Y,Boehm JS,Jain S,Bojarski E,Mermel C,Barretina J,Chan JA,Baselga J,Tabernero J,Root DE,Fuchs CS,Loda M,Shivdasani RA,Meyerson M,Hahn WC
Category | C2
Sub-category | CGP
Brief description | Genes required for proliferation of DLD-1 cell (colon cancer with APC [GeneID=324] deletions), based on shRNA screen.
Full description | Aberrant activation of the canonical WNT/beta-catenin pathway occurs in almost all colorectal cancers and contributes to their growth, invasion and survival. Although dysregulated beta-catenin activity drives colon tumorigenesis, further genetic perturbations are required to elaborate full malignant transformation. To identify genes that both modulate beta-catenin activity and are essential for colon cancer cell proliferation, we conducted two loss-of-function screens in human colon cancer cells and compared genes identified in these screens with an analysis of copy number alterations in colon cancer specimens. One of these genes, CDK8, which encodes a member of the mediator complex, is located at 13q12.13, a region of recurrent copy number gain in a substantial fraction of colon cancers. Here we show that the suppression of CDK8 expression inhibits proliferation in colon cancer cells characterized by high levels of CDK8 and beta-catenin hyperactivity. CDK8 kinase activity was necessary for beta-catenin-driven transformation and for expression of several beta-catenin transcriptional targets. Together these observations suggest that therapeutic interventions targeting CDK8 may confer a clinical benefit in beta-catenin-driven malignancies.

Standard name | ZHOU_PANCREATIC_EXOCRINE_PROGENITOR
Systematic name | M1860
Organism | Mus musculus
PMID | 18754011
Authors | Zhou Q,Brown J,Kanarek A,Rajagopal J,Melton DA
Category | C2
Sub-category | CGP
Brief description | Transcription factors expressed in progenitors of exocrine pancreatic cells.
Full description | One goal of regenerative medicine is to instructively convert adult cells into other cell types for tissue repair and regeneration. Although isolated examples of adult cell reprogramming are known, there is no general understanding of how to turn one cell type into another in a controlled manner. Here, using a strategy of re-expressing key developmental regulators in vivo, we identify a specific combination of three transcription factors (Ngn3 (also known as Neurog3) Pdx1 and Mafa) that reprograms differentiated pancreatic exocrine cells in adult mice into cells that closely resemble beta-cells. The induced beta-cells are indistinguishable from endogenous islet beta-cells in size, shape and ultrastructure. They express genes essential for beta-cell function and can ameliorate hyperglycaemia by remodelling local vasculature and secreting insulin. This study provides an example of cellular reprogramming using defined factors in an adult organ and suggests a general paradigm for directing cell reprogramming without reversion to a pluripotent stem cell state.

Standard name | ZHOU_PANCREATIC_ENDOCRINE_PROGENITOR
Systematic name | M1862
Organism | Mus musculus
PMID | 18754011
Authors | Zhou Q,Brown J,Kanarek A,Rajagopal J,Melton DA
Category | C2
Sub-category | CGP
Brief description | Transcription factors expressed in progenitors of endocrine pancreatic cells.
Full description | One goal of regenerative medicine is to instructively convert adult cells into other cell types for tissue repair and regeneration. Although isolated examples of adult cell reprogramming are known, there is no general understanding of how to turn one cell type into another in a controlled manner. Here, using a strategy of re-expressing key developmental regulators in vivo, we identify a specific combination of three transcription factors (Ngn3 (also known as Neurog3) Pdx1 and Mafa) that reprograms differentiated pancreatic exocrine cells in adult mice into cells that closely resemble beta-cells. The induced beta-cells are indistinguishable from endogenous islet beta-cells in size, shape and ultrastructure. They express genes essential for beta-cell function and can ameliorate hyperglycaemia by remodelling local vasculature and secreting insulin. This study provides an example of cellular reprogramming using defined factors in an adult organ and suggests a general paradigm for directing cell reprogramming without reversion to a pluripotent stem cell state.

Standard name | ZHOU_PANCREATIC_BETA_CELL
Systematic name | M1863
Organism | Mus musculus
PMID | 18754011
Authors | Zhou Q,Brown J,Kanarek A,Rajagopal J,Melton DA
Category | C2
Sub-category | CGP
Brief description | Transcription factors expressed in adult pancreatic beta cells.
Full description | One goal of regenerative medicine is to instructively convert adult cells into other cell types for tissue repair and regeneration. Although isolated examples of adult cell reprogramming are known, there is no general understanding of how to turn one cell type into another in a controlled manner. Here, using a strategy of re-expressing key developmental regulators in vivo, we identify a specific combination of three transcription factors (Ngn3 (also known as Neurog3) Pdx1 and Mafa) that reprograms differentiated pancreatic exocrine cells in adult mice into cells that closely resemble beta-cells. The induced beta-cells are indistinguishable from endogenous islet beta-cells in size, shape and ultrastructure. They express genes essential for beta-cell function and can ameliorate hyperglycaemia by remodelling local vasculature and secreting insulin. This study provides an example of cellular reprogramming using defined factors in an adult organ and suggests a general paradigm for directing cell reprogramming without reversion to a pluripotent stem cell state.

Standard name | ISHIKAWA_STING_SIGNALING
Systematic name | M7982
Organism | Homo sapiens
PMID | 18724357
Authors | Ishikawa H,Barber GN
Category | C2
Sub-category | CGP
Brief description | Prmary innate immune response genes induced in 293T cells (embryonic kidney) by overexpression of STING (TMEM173) [GeneID=340061].
Full description | The cellular innate immune system is essential for recognizing pathogen infection and for establishing effective host defence. But critical molecular determinants responsible for facilitating an appropriate immune response-following infection with DNA and RNA viruses, for example-remain to be identified. Here we report the identification, following expression cloning, of a molecule (STING; stimulator of interferon genes) that appears essential for effective innate immune signalling processes. It comprises five putative transmembrane regions, predominantly resides in the endoplasmic reticulum and is able to activate both NF-kappaB and IRF3 transcription pathways to induce expression of type I interferon (IFN-alpha and IFN-beta ) and exert a potent anti-viral state following expression. In contrast, loss of STING rendered murine embryonic fibroblasts extremely susceptible to negative-stranded virus infection, including vesicular stomatitis virus. Further, STING ablation abrogated the ability of intracellular B-form DNA, as well as members of the herpesvirus family, to induce IFN-beta, but did not significantly affect the Toll-like receptor (TLR) pathway. Yeast two-hybrid and co-immunoprecipitation studies indicated that STING interacts with RIG-I and with SSR2 (also known as TRAPbeta), which is a member of the translocon-associated protein (TRAP) complex required for protein translocation across the endoplasmic reticulum membrane following translation. Ablation by RNA interference of both TRAPbeta and translocon adaptor SEC61beta was subsequently found to inhibit STING's ability to stimulate expression of IFN-beta. Thus, as well as identifying a regulator of innate immune signalling, our results imply a potential role for the translocon in innate signalling pathways activated by select viruses as well as intracellular DNA.

Standard name | WANG_TUMOR_INVASIVENESS_UP
Systematic name | M1865
Organism | Mus musculus
PMID | 17440055
Authors | Wang W,Wyckoff JB,Goswami S,Wang Y,Sidani M,Segall JE,Condeelis JS
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the subpopulation of invasive PyMT cells (breast cancer) compared to the general population of PyMT cells.
Full description | Correlating tumor cell behavior in vivo with patterns of gene expression has led to new insights into the microenvironment of tumor cells in the primary tumor. Until now, these studies have been done with cell line-derived tumors. In the current study, we have analyzed, in polyoma middle T oncogene (PyMT)-derived mammary tumors, tumor cell behavior and gene expression patterns of the invasive subpopulation of tumor cells by multiphoton-based intravital imaging and microarray-based expression profiling, respectively. Our results indicate that the patterns of cell behavior that contribute to invasion and metastasis in the PyMT tumor are similar to those seen previously in rat MTLn3 cell line-derived mammary tumors. The invasive tumor cells collected from PyMT mouse mammary tumors, like their counterparts from rat xenograft mammary tumors, are a population that is relatively nondividing and nonapoptotic but chemotherapy resistant and chemotactic. Changes in the expression of genes that occur uniquely in the invasive subpopulation of tumor cells in the PyMT mammary tumors that fall on the Arp2/3 complex, capping protein and cofilin pathways show a pattern like that seen previously in invasive tumor cells from the MTLn3 cell line-derived tumors. These changes predict an enhanced activity of the cofilin pathway, and this was confirmed in isolated invasive PyMT tumor cells. We conclude that changes in gene expression and their related changes in cell behavior, which were identified in the invasive tumor cells of cell line-derived tumors, are conserved in the invasive tumor cells of PyMT-derived mouse mammary tumors, although these tumor types have different genetic origins.

Standard name | WANG_TUMOR_INVASIVENESS_DN
Systematic name | M1866
Organism | Mus musculus
PMID | 17440055
Authors | Wang W,Wyckoff JB,Goswami S,Wang Y,Sidani M,Segall JE,Condeelis JS
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the subpopulation of invasive PyMT cells (breast cancer) compared to the general population of PyMT cells.
Full description | Correlating tumor cell behavior in vivo with patterns of gene expression has led to new insights into the microenvironment of tumor cells in the primary tumor. Until now, these studies have been done with cell line-derived tumors. In the current study, we have analyzed, in polyoma middle T oncogene (PyMT)-derived mammary tumors, tumor cell behavior and gene expression patterns of the invasive subpopulation of tumor cells by multiphoton-based intravital imaging and microarray-based expression profiling, respectively. Our results indicate that the patterns of cell behavior that contribute to invasion and metastasis in the PyMT tumor are similar to those seen previously in rat MTLn3 cell line-derived mammary tumors. The invasive tumor cells collected from PyMT mouse mammary tumors, like their counterparts from rat xenograft mammary tumors, are a population that is relatively nondividing and nonapoptotic but chemotherapy resistant and chemotactic. Changes in the expression of genes that occur uniquely in the invasive subpopulation of tumor cells in the PyMT mammary tumors that fall on the Arp2/3 complex, capping protein and cofilin pathways show a pattern like that seen previously in invasive tumor cells from the MTLn3 cell line-derived tumors. These changes predict an enhanced activity of the cofilin pathway, and this was confirmed in isolated invasive PyMT tumor cells. We conclude that changes in gene expression and their related changes in cell behavior, which were identified in the invasive tumor cells of cell line-derived tumors, are conserved in the invasive tumor cells of PyMT-derived mouse mammary tumors, although these tumor types have different genetic origins.

Standard name | JIANG_TIP30_TARGETS_UP
Systematic name | M12641
Organism | Homo sapiens
PMID | 17440068
Authors | Jiang C,Pecha J,Hoshino I,Ankrapp D,Xiao H
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in HepG2 cells (liver cancer) overexpressing an oncogenic variant of tumor suppressor TIP30 [GeneID=10553] compared to its wild type form.
Full description | TIP30 is a tumor suppressor whose expression is altered in human liver, prostate, lung, colon, and breast cancers. Mice lacking TIP30 spontaneously developed hepatocellular carcinomas (HCC) and other tumors at a higher incidence than wild-type mice. Somatic missense mutations in the TIP30 gene were identified in human HCC tissue specimens, which resulted in instability or abnormal cellular distribution of TIP30 protein in cells. Here, we show that TIP30 mutants are able to promote cell growth and invasion and inhibit cisplatin-induced apoptosis in the HCC cell line HepG2 negative for endogenous TIP30. Moreover, one of the TIP30 mutants can dramatically accelerate tumor formation in immunodeficient mice. Analysis of gene expression in HepG2 cells, ectopically expressing either wild-type TIP30 or mutant TIP30, by Affymetrix GeneChip array, real-time quantitative PCR, and Western blotting assays reveals that TIP30 mutants can alter expression of genes involved in the regulation of tumorigenesis. This includes up-regulation of expression of N-cadherin and c-MYC and down-regulation of expression of p53 and E-cadherin. N-cadherin knockdown with small interfering RNA in HepG2 cells expressing mutant TIP30 resulted in a profound reduction in cell viability. Taken together, our data indicate that somatic mutations in the TIP30 gene may abolish its native tumor-suppressor activity and gain oncogenic activities partially through up-regulation of N-cadherin, thereby potentiating the pathogenesis of HCC in patients.

Standard name | JIANG_TIP30_TARGETS_DN
Systematic name | M13930
Organism | Homo sapiens
PMID | 17440068
Authors | Jiang C,Pecha J,Hoshino I,Ankrapp D,Xiao H
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in HepG2 cells (liver cancer) overexpressing an oncogenic variant of tumor suppressor TIP30 [GeneID=10553] compared to its wild type form.
Full description | TIP30 is a tumor suppressor whose expression is altered in human liver, prostate, lung, colon, and breast cancers. Mice lacking TIP30 spontaneously developed hepatocellular carcinomas (HCC) and other tumors at a higher incidence than wild-type mice. Somatic missense mutations in the TIP30 gene were identified in human HCC tissue specimens, which resulted in instability or abnormal cellular distribution of TIP30 protein in cells. Here, we show that TIP30 mutants are able to promote cell growth and invasion and inhibit cisplatin-induced apoptosis in the HCC cell line HepG2 negative for endogenous TIP30. Moreover, one of the TIP30 mutants can dramatically accelerate tumor formation in immunodeficient mice. Analysis of gene expression in HepG2 cells, ectopically expressing either wild-type TIP30 or mutant TIP30, by Affymetrix GeneChip array, real-time quantitative PCR, and Western blotting assays reveals that TIP30 mutants can alter expression of genes involved in the regulation of tumorigenesis. This includes up-regulation of expression of N-cadherin and c-MYC and down-regulation of expression of p53 and E-cadherin. N-cadherin knockdown with small interfering RNA in HepG2 cells expressing mutant TIP30 resulted in a profound reduction in cell viability. Taken together, our data indicate that somatic mutations in the TIP30 gene may abolish its native tumor-suppressor activity and gain oncogenic activities partially through up-regulation of N-cadherin, thereby potentiating the pathogenesis of HCC in patients.

Standard name | GRESHOCK_CANCER_COPY_NUMBER_UP
Systematic name | M9150
Organism | Homo sapiens
PMID | 17440070
Authors | Greshock J,Nathanson K,Martin AM,Zhang L,Coukos G,Weber BL,Zaks TZ
Category | C2
Sub-category | CGP
Brief description | Genes from common genomic gains observed in a meta analyis of copy number alterations across a panel of different cancer cell lines and tumor samples.
Full description | Tumor-derived cell lines are used as in vitro cancer models, but their ability to accurately reflect the phenotype and genotype of the parental histology remains questionable, given the prevalence of documented cell line-specific cytogenetic changes. We have addressed the issue of whether copy number alterations seen in tumor-derived cell lines reflect those observed in studies of fresh tissue by carrying out a meta-analysis of array-based comparative genomic hybridization data that considers both copy number alteration frequencies and the occurrence of cancer gene amplifications and homozygous deletions. Pairwise correlation comparisons between the data sets of seven diagnosis-specific matched tumor and cell line groups indicate that the trends in aberration frequencies are highly correlated between tumors and cell line sets of matched cancer histology relative to unmatched pairings. Despite their similarities, cell lines showed uniformly higher locus-specific alteration frequencies (P = 0.004) and several recurring cell line-specific alterations emerged. These include the previously documented losses of 13q and 9p and gains of 20q, as well as additional undescribed cell line-specific gains of 5p, 7p, and 17q and losses of 18q and 4q. These results indicate that, on average, cell lines preserve in vitro the genetic aberrations that are unique to the parent histology from which they were derived while acquiring additional locus-specific alterations. These data may enable a more predictive understanding of individual cell lines as in vitro models of cancer biology and therapy.

Standard name | WANG_NEOPLASTIC_TRANSFORMATION_BY_CCND1_MYC
Systematic name | M1867
Organism | Mus musculus
PMID | 17440082
Authors | Wang Y,Thakur A,Sun Y,Wu J,Biliran H,Bollig A,Liao DJ
Category | C2
Sub-category | CGP
Brief description | Selected genes changed in NMuMG cells (mammary epithelium) transformed by overexpression of CCND1 [GeneID=595] vs those transformed by overexpression of CCND1 and MYC [GeneID=4609].
Full description | Cyclin D1 is one of the most commonly overexpressed oncogenes in breast cancer; yet, it is not clear whether cyclin D1 alone is capable of causing malignant transformation of mammary epithelial cells. Here, we show that ectopic expression of cyclin D1 in benign mouse mammary epithelial cells promotes cell proliferation, anchorage-independent growth in soft agar, and tumorigenesis in severe combined immunodeficient mice. To address the possible interaction of cyclin D1 and c-myc in malignant transformation, we used cyclin D1/c-myc dual-expressing clones, which displayed more aggressive and invasive phenotype than cyclin D1-expressing clones. These data provide evidence that overexpression of cyclin D1 or coexpression with c-myc could cause invasive malignant transformation of benign mouse mammary epithelial cells. Furthermore, microarray analysis of cyclin D1 and cyclin D1/c-myc clones showed that these two tumor-producing clones might use distinct invasive pathways. In summary, overexpression of cyclin D1 may commit mammary epithelia to a tumor-prone phenotype in which cooperation with other genes, such as synergy with c-myc, may lead to a more aggressive phenotype.

Standard name | TSAI_RESPONSE_TO_RADIATION_THERAPY
Systematic name | M308
Organism | Mus musculus
PMID | 17440099
Authors | Tsai MH,Cook JA,Chandramouli GV,DeGraff W,Yan H,Zhao S,Coleman CN,Mitchell JB,Chuang EY
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in response to both single dose and fractionated radiation that were common to all three cell lines studied.
Full description | Studies were conducted to determine whether gene expression profiles following a single dose of radiation would yield equivalent profiles following fractionated radiation in different tumor cell lines. MCF7 (breast), DU145 (prostate), and SF539 (gliosarcoma) cells were exposed to a total radiation dose of 10 Gy administered as a single dose (SD) or by daily multifractions (MF) of 5 x 2 Gy. Following radiation treatment, mRNA was isolated at 1, 4, 10, and 24 h and processed for cDNA microarray analysis. To determine the influence of the tumor microenvironment on gene expression, one cell type (DU145) was evaluated growing as a solid tumor in athymic nude mice for both radiation protocols. Unsupervised hierarchical cluster map analysis showed significant differences in gene expression profiles between SD and MF treatments for cells treated in vitro, with MF yielding a more robust induction compared with SD. Several genes were uniquely up-regulated by MF treatment, including multiple IFN-related genes (STAT1, G1P2, OAS1, OAS3, G1P3, IFITM1) and TGF-beta-associated genes (EGR1, VEGF, THBS1, and TGFB2). DU145 cells grown in vivo exhibited a completely different set of genes induced by both SD and MF compared with the same cells exposed in vitro. The results of the study clearly show distinct differences in the molecular response of cells between SD and MF radiation exposures and show that the tumor microenvironment can significantly influence the pattern of gene expression after radiation exposures.

Standard name | SASAI_TARGETS_OF_CXCR6_AND_PTCH1_UP
Systematic name | M10694
Organism | Mus musculus
PMID | 17413002
Authors | Sasai K,Romer JT,Kimura H,Eberhart DE,Rice DS,Curran T
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in medulloblastoma tumors from heterozygotic CXCR6 [GeneID=10663] knockout mice compared to those from PTCH1 [GeneID=5727] heterozygotic knockout mice.
Full description | The sonic hedgehog (Shh) pathway is activated in approximately 30% of human medulloblastoma resulting in increased expression of downstream target genes. In about half of these cases, this has been shown to be a consequence of mutations in regulatory genes within the pathway, including Ptc1, Smo, and Sufu. However, for some tumors, no mutations have been detected in known pathway genes. This suggests that either mutations in other genes promote tumorigenesis or that epigenetic alterations increase pathway activity in these tumors. Here, we report that 3% to 4% of mice lacking either one or both functional copies of Cxcr6 develop medulloblastoma. Although CXCR6 is not known to be involved in Shh signaling, tumors derived from Cxcr6 mutant mice expressed Shh pathway target genes including Gli1, Gli2, Ptc2, and Sfrp1, indicating elevated pathway activity. Interestingly, the level of Ptc1 expression was decreased in tumor cells although two normal copies of Ptc1 were retained. This implies that reduced CXCR6 function leads to suppression of Ptc1 thereby increasing Smoothened function and promoting tumorigenesis. We used a direct transplant model to test the sensitivity of medulloblastoma arising in Cxcr6 mutant mice to a small-molecule inhibitor of Smoothened (HhAntag). We found that transplanted tumors were dramatically inhibited in mice treated for only 4 days with HhAntag. These findings suggest that HhAntag may be effective against tumors lacking mutations in known Shh pathway genes.

Standard name | SASAI_TARGETS_OF_CXCR6_AND_PTCH1_DN
Systematic name | M17228
Organism | Mus musculus
PMID | 17413002
Authors | Sasai K,Romer JT,Kimura H,Eberhart DE,Rice DS,Curran T
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in medulloblastoma tumors from heterozygotic CXCR6 [GeneID=10663] knockout mice compared to those from PTCH1 [GeneID=5727] heterozygotic knockout mice.
Full description | The sonic hedgehog (Shh) pathway is activated in approximately 30% of human medulloblastoma resulting in increased expression of downstream target genes. In about half of these cases, this has been shown to be a consequence of mutations in regulatory genes within the pathway, including Ptc1, Smo, and Sufu. However, for some tumors, no mutations have been detected in known pathway genes. This suggests that either mutations in other genes promote tumorigenesis or that epigenetic alterations increase pathway activity in these tumors. Here, we report that 3% to 4% of mice lacking either one or both functional copies of Cxcr6 develop medulloblastoma. Although CXCR6 is not known to be involved in Shh signaling, tumors derived from Cxcr6 mutant mice expressed Shh pathway target genes including Gli1, Gli2, Ptc2, and Sfrp1, indicating elevated pathway activity. Interestingly, the level of Ptc1 expression was decreased in tumor cells although two normal copies of Ptc1 were retained. This implies that reduced CXCR6 function leads to suppression of Ptc1 thereby increasing Smoothened function and promoting tumorigenesis. We used a direct transplant model to test the sensitivity of medulloblastoma arising in Cxcr6 mutant mice to a small-molecule inhibitor of Smoothened (HhAntag). We found that transplanted tumors were dramatically inhibited in mice treated for only 4 days with HhAntag. These findings suggest that HhAntag may be effective against tumors lacking mutations in known Shh pathway genes.

Standard name | MIKI_COEXPRESSED_WITH_CYP19A1
Systematic name | M1868
Organism | Homo sapiens
PMID | 17440110
Authors | Miki Y,Suzuki T,Tazawa C,Yamaguchi Y,Kitada K,Honma S,Moriya T,Hirakawa H,Evans DB,Hayashi S,Ohuchi N,Sasano H
Category | C2
Sub-category | CGP
Brief description | Nuclear receptors whose expression correlated with that of aromatase (CYP19A1) [GeneID=1588] in a panel of breast cancer biopsies.
Full description | Aromatase is a key enzyme in intratumoral estrogen production required for the production of estrogens through the conversion of serum androgens in postmenopausal breast cancer patients. There have been, however, controversies regarding the intratumoral localization of aromatase in human breast carcinoma tissues. Therefore, we have first examined the intratumoral localization of aromatase mRNA/protein in 19 breast carcinomas using laser capture microdissection/quantitative reverse transcription-PCR (RT-PCR) and immunohistochemistry. Aromatase mRNA and protein were detected in both intratumoral stromal and parenchymal cells in breast carcinoma tissues. Subsequent microarray expression profiling and clustering analyses, in addition to quantitative RT-PCR studies, showed a significant positive correlation between aromatase and estrogen-related receptor alpha mRNA expression in isolated carcinoma cells. We further examined an interaction between stromal cells isolated from human breast carcinoma tissues and breast carcinoma cell lines using a coculture system to study the biological characteristic of aromatase expression in carcinoma cells. Aromatase mRNA and enzyme activity and 17beta-hydroxysteroid dehydrogenase type 1 mRNA in breast carcinoma cell lines, including MCF-7 and SK-BR-3 cells, were up-regulated in the presence of patient-derived 32N or 74T intratumoral stromal cells. The results from steroid conversion assays were also consistent with the findings above. The results of our study also showed that aromatase inhibitors were more effective in inhibiting aromatization induced by coculture in MCF-7 than that in stromal 32N. The examination of the localization of aromatase and its regulation, including the interactions existing between different cell types in human breast carcinoma tissues, may provide important information as to achieving better clinical response to aromatase inhibitors in breast cancer patients.

Standard name | BEIER_GLIOMA_STEM_CELL_UP
Systematic name | M9126
Organism | Homo sapiens
PMID | 17483311
Authors | Beier D,Hau P,Proescholdt M,Lohmeier A,Wischhusen J,Oefner PJ,Aigner L,Brawanski A,Bogdahn U,Beier CP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in cancer stem cells derived from glyoblastoma tumors: CD133+ [GeneID=8842] vs. CD133- cells.
Full description | Although glioblastomas show the same histologic phenotype, biological hallmarks such as growth and differentiation properties vary considerably between individual cases. To investigate whether different subtypes of glioblastomas might originate from different cells of origin, we cultured tumor cells from 22 glioblastomas under medium conditions favoring the growth of neural and cancer stem cells (CSC). Secondary glioblastoma (n = 7)-derived cells did not show any growth in the medium used, suggesting the absence of neural stem cell-like tumor cells. In contrast, 11/15 primary glioblastomas contained a significant CD133(+) subpopulation that displayed neurosphere-like, nonadherent growth and asymmetrical cell divisions yielding cells expressing markers characteristic for all three neural lineages. Four of 15 cell lines derived from primary glioblastomas grew adherently in vitro and were driven by CD133(-) tumor cells that fulfilled stem cell criteria. Both subtypes were similarly tumorigenic in nude mice in vivo. Clinically, CD133(-) glioblastomas were characterized by a lower proliferation index, whereas glial fibrillary acidic protein staining was similar. GeneArray analysis revealed 117 genes to be differentially expressed by these two subtypes. Together, our data provide first evidence that CD133(+) CSC maintain only a subset of primary glioblastomas. The remainder stems from previously unknown CD133(-) tumor cells with apparent stem cell-like properties but distinct molecular profiles and growth characteristics in vitro and in vivo.

Standard name | BEIER_GLIOMA_STEM_CELL_DN
Systematic name | M11720
Organism | Homo sapiens
PMID | 17483311
Authors | Beier D,Hau P,Proescholdt M,Lohmeier A,Wischhusen J,Oefner PJ,Aigner L,Brawanski A,Bogdahn U,Beier CP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in cancer stem cells derived from glyoblastoma tumors: CD133+ [GeneID=8842] vs. CD133- cells.
Full description | Although glioblastomas show the same histologic phenotype, biological hallmarks such as growth and differentiation properties vary considerably between individual cases. To investigate whether different subtypes of glioblastomas might originate from different cells of origin, we cultured tumor cells from 22 glioblastomas under medium conditions favoring the growth of neural and cancer stem cells (CSC). Secondary glioblastoma (n = 7)-derived cells did not show any growth in the medium used, suggesting the absence of neural stem cell-like tumor cells. In contrast, 11/15 primary glioblastomas contained a significant CD133(+) subpopulation that displayed neurosphere-like, nonadherent growth and asymmetrical cell divisions yielding cells expressing markers characteristic for all three neural lineages. Four of 15 cell lines derived from primary glioblastomas grew adherently in vitro and were driven by CD133(-) tumor cells that fulfilled stem cell criteria. Both subtypes were similarly tumorigenic in nude mice in vivo. Clinically, CD133(-) glioblastomas were characterized by a lower proliferation index, whereas glial fibrillary acidic protein staining was similar. GeneArray analysis revealed 117 genes to be differentially expressed by these two subtypes. Together, our data provide first evidence that CD133(+) CSC maintain only a subset of primary glioblastomas. The remainder stems from previously unknown CD133(-) tumor cells with apparent stem cell-like properties but distinct molecular profiles and growth characteristics in vitro and in vivo.

Standard name | VART_KSHV_INFECTION_ANGIOGENIC_MARKERS_UP
Systematic name | M12112
Organism | Homo sapiens
PMID | 17483315
Authors | Vart RJ,Nikitenko LL,Lagos D,Trotter MW,Cannon M,Bourboulia D,Gratrix F,Takeuchi Y,Boshoff C
Category | C2
Sub-category | CGP
Brief description | Angiogenic markers up-regulated in lymph endothelial cells upon infection with KSHV (Kaposi's sarcoma herpes virus).
Full description | Kaposi's sarcoma (KS) is caused by Kaposi's sarcoma-associated herpesvirus (KSHV) and consists of proliferating spindle cells, which are related to lymphatic endothelial cells (LEC). Angiopoietin-2 (Ang2) is a secreted proangiogenic and lymphangiogenic molecule. Here, we show the expression of Ang2 protein in KS and confirm that KSHV infection up-regulates Ang2 in LEC. We show that a paracrine mechanism contributes to this up-regulation. A lentiviral library of individual KSHV-encoding genes, comprising the majority of known latent genes and a selection of lytic viral genes, was constructed to investigate the underlying mechanism of this up-regulation. Two lytic genes, viral interleukin-6 (vIL6) and viral G-protein-coupled receptor (vGPCR), up-regulated Ang2 expression in LEC. Both vIL6 and vGPCR are expressed in KSHV-infected LEC and caused up-regulation of Ang2 in a paracrine manner. KSHV, vIL6, and vGPCR up-regulated Ang2 through the mitogen-activated protein kinase (MAPK) pathway. Gene expression microarray analysis identified several other angiogenic molecules affected by KSHV, including the vascular endothelial growth factor (VEGF)/VEGF receptor (VEGFR) axis, which is also affected by vIL6 and vGPCR in LEC, and matrix metalloproteinases, which could act in concert with Ang2 to contribute to KS development. These findings support the paracrine and autocrine roles of the lytic KSHV-encoded proteins, vIL6 and vGPCR, in KS pathogenesis and identify Ang2 as a potential therapeutic target for this neoplasm.

Standard name | VART_KSHV_INFECTION_ANGIOGENIC_MARKERS_DN
Systematic name | M5825
Organism | Homo sapiens
PMID | 17483315
Authors | Vart RJ,Nikitenko LL,Lagos D,Trotter MW,Cannon M,Bourboulia D,Gratrix F,Takeuchi Y,Boshoff C
Category | C2
Sub-category | CGP
Brief description | Angiogenic markers down-regulated in lymph endothelial cells upon infection with KSHV (Kaposi's sarcoma herpes virus).
Full description | Kaposi's sarcoma (KS) is caused by Kaposi's sarcoma-associated herpesvirus (KSHV) and consists of proliferating spindle cells, which are related to lymphatic endothelial cells (LEC). Angiopoietin-2 (Ang2) is a secreted proangiogenic and lymphangiogenic molecule. Here, we show the expression of Ang2 protein in KS and confirm that KSHV infection up-regulates Ang2 in LEC. We show that a paracrine mechanism contributes to this up-regulation. A lentiviral library of individual KSHV-encoding genes, comprising the majority of known latent genes and a selection of lytic viral genes, was constructed to investigate the underlying mechanism of this up-regulation. Two lytic genes, viral interleukin-6 (vIL6) and viral G-protein-coupled receptor (vGPCR), up-regulated Ang2 expression in LEC. Both vIL6 and vGPCR are expressed in KSHV-infected LEC and caused up-regulation of Ang2 in a paracrine manner. KSHV, vIL6, and vGPCR up-regulated Ang2 through the mitogen-activated protein kinase (MAPK) pathway. Gene expression microarray analysis identified several other angiogenic molecules affected by KSHV, including the vascular endothelial growth factor (VEGF)/VEGF receptor (VEGFR) axis, which is also affected by vIL6 and vGPCR in LEC, and matrix metalloproteinases, which could act in concert with Ang2 to contribute to KS development. These findings support the paracrine and autocrine roles of the lytic KSHV-encoded proteins, vIL6 and vGPCR, in KS pathogenesis and identify Ang2 as a potential therapeutic target for this neoplasm.

Standard name | MOOTHA_HUMAN_MITODB_6_2002
Systematic name | M9433
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Mitochondrial genes; based on literature and sequence annotation resources and converted to Affymetrix HG-U133A probe sets.
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | MOOTHA_PGC
Systematic name | M9788
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in differentiating C2C12 cells (myoblasts) upon expression of PPARGC1A [GeneID=10891] off an adenoviral vector.
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | MOOTHA_TCA
Systematic name | M18669
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Tricarboxylic acid related genes; based on literature and sequence annotation resources and converted to Affymetrix HG-U133A probe sets.
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | LEE_LIVER_CANCER_SURVIVAL_DN
Systematic name | M7987
Organism | Homo sapiens
PMID | 15349906
Authors | Lee JS,Chu IS,Heo J,Calvisi DF,Sun Z,Roskams T,Durnez A,Demetris AJ,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes highly expressed in hepatocellular carcinoma with poor survival.
Full description | We analyzed global gene expression patterns of 91 human hepatocellular carcinomas (HCCs) to define the molecular characteristics of the tumors and to test the prognostic value of the expression profiles. Unsupervised classification methods revealed two distinctive subclasses of HCC that are highly associated with patient survival. This association was validated via 5 independent supervised learning methods. We also identified the genes most strongly associated with survival by using the Cox proportional hazards survival analysis. This approach identified a limited number of genes that accurately predicted the length of survival and provides new molecular insight into the pathogenesis of HCC. Tumors from the low survival subclass have strong cell proliferation and antiapoptosis gene expression signatures. In addition, the low survival subclass displayed higher expression of genes involved in ubiquitination and histone modification, suggesting an etiological involvement of these processes in accelerating the progression of HCC. In conclusion, the biological differences identified in the HCC subclasses should provide an attractive source for the development of therapeutic targets (e.g., HIF1a) for selective treatment of HCC patients. Supplementary material for this article can be found on the HEPATOLOGY Web site (http://interscience.wiley.com/jpages/0270-9139/suppmat/index.html)

Standard name | LEE_LIVER_CANCER_SURVIVAL_UP
Systematic name | M6145
Organism | Homo sapiens
PMID | 15349906
Authors | Lee JS,Chu IS,Heo J,Calvisi DF,Sun Z,Roskams T,Durnez A,Demetris AJ,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Genes highly expressed in hepatocellular carcinoma with good survival.
Full description | We analyzed global gene expression patterns of 91 human hepatocellular carcinomas (HCCs) to define the molecular characteristics of the tumors and to test the prognostic value of the expression profiles. Unsupervised classification methods revealed two distinctive subclasses of HCC that are highly associated with patient survival. This association was validated via 5 independent supervised learning methods. We also identified the genes most strongly associated with survival by using the Cox proportional hazards survival analysis. This approach identified a limited number of genes that accurately predicted the length of survival and provides new molecular insight into the pathogenesis of HCC. Tumors from the low survival subclass have strong cell proliferation and antiapoptosis gene expression signatures. In addition, the low survival subclass displayed higher expression of genes involved in ubiquitination and histone modification, suggesting an etiological involvement of these processes in accelerating the progression of HCC. In conclusion, the biological differences identified in the HCC subclasses should provide an attractive source for the development of therapeutic targets (e.g., HIF1a) for selective treatment of HCC patients. Supplementary material for this article can be found on the HEPATOLOGY Web site (http://interscience.wiley.com/jpages/0270-9139/suppmat/index.html)

Standard name | MOOTHA_MITOCHONDRIA
Systematic name | M9577
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Mitochondrial genes
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | MOOTHA_ROS
Systematic name | M2999
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Reactive oxidative species (ROS) genes; based on literature and sequence annotation resources and converted to Affymetrix HG-U133A probe sets.
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | DAVIES_MULTIPLE_MYELOMA_VS_MGUS_UP
Systematic name | M13055
Organism | Homo sapiens
PMID | 12947006
Authors | Davies FE,Dring AM,Li C,Rawstron AC,Shammas MA,O'Connor SM,Fenton JA,Hideshima T,Chauhan D,Tai IT,Robinson E,Auclair D,Rees K,Gonzalez D,Ashcroft AJ,Dasgupta R,Mitsiades C,Mitsiades N,Chen LB,Wong WH,Munshi NC,Morgan GJ,Anderson KC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in multiple myeloma (MM) compared to monoclonal gammopathy of uncertain significance (MGUS).
Full description | To define specific pathways important in the multistep transformation process of normal plasma cells (PCs) to monoclonal gammopathy of uncertain significance (MGUS) and multiple myeloma (MM), we have applied microarray analysis to PCs from 5 healthy donors (N), 7 patients with MGUS, and 24 patients with newly diagnosed MM. Unsupervised hierarchical clustering using 125 genes with a large variation across all samples defined 2 groups: N and MGUS/MM. Supervised analysis identified 263 genes differentially expressed between N and MGUS and 380 genes differentially expressed between N and MM, 197 of which were also differentially regulated between N and MGUS. Only 74 genes were differentially expressed between MGUS and MM samples, indicating that the differences between MGUS and MM are smaller than those between N and MM or N and MGUS. Differentially expressed genes included oncogenes/tumor-suppressor genes (LAF4, RB1, and disabled homolog 2), cell-signaling genes (RAS family members, B-cell signaling and NF-kappaB genes), DNA-binding and transcription-factor genes (XBP1, zinc finger proteins, forkhead box, and ring finger proteins), and developmental genes (WNT and SHH pathways). Understanding the molecular pathogenesis of MM by gene expression profiling has demonstrated sequential genetic changes from N to malignant PCs and highlighted important pathways involved in the transformation of MGUS to MM.

Standard name | DAVIES_MULTIPLE_MYELOMA_VS_MGUS_DN
Systematic name | M10219
Organism | Homo sapiens
PMID | 12947006
Authors | Davies FE,Dring AM,Li C,Rawstron AC,Shammas MA,O'Connor SM,Fenton JA,Hideshima T,Chauhan D,Tai IT,Robinson E,Auclair D,Rees K,Gonzalez D,Ashcroft AJ,Dasgupta R,Mitsiades C,Mitsiades N,Chen LB,Wong WH,Munshi NC,Morgan GJ,Anderson KC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in multiple myeloma (MM) compared to monoclonal gammopathy of uncertain significance (MGUS).
Full description | To define specific pathways important in the multistep transformation process of normal plasma cells (PCs) to monoclonal gammopathy of uncertain significance (MGUS) and multiple myeloma (MM), we have applied microarray analysis to PCs from 5 healthy donors (N), 7 patients with MGUS, and 24 patients with newly diagnosed MM. Unsupervised hierarchical clustering using 125 genes with a large variation across all samples defined 2 groups: N and MGUS/MM. Supervised analysis identified 263 genes differentially expressed between N and MGUS and 380 genes differentially expressed between N and MM, 197 of which were also differentially regulated between N and MGUS. Only 74 genes were differentially expressed between MGUS and MM samples, indicating that the differences between MGUS and MM are smaller than those between N and MM or N and MGUS. Differentially expressed genes included oncogenes/tumor-suppressor genes (LAF4, RB1, and disabled homolog 2), cell-signaling genes (RAS family members, B-cell signaling and NF-kappaB genes), DNA-binding and transcription-factor genes (XBP1, zinc finger proteins, forkhead box, and ring finger proteins), and developmental genes (WNT and SHH pathways). Understanding the molecular pathogenesis of MM by gene expression profiling has demonstrated sequential genetic changes from N to malignant PCs and highlighted important pathways involved in the transformation of MGUS to MM.

Standard name | BOYLAN_MULTIPLE_MYELOMA_C_CLUSTER_UP
Systematic name | M1367
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes from cluster 1: up-regulated in group C of tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609] in plasma cells.
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_C_CLUSTER_DN
Systematic name | M17990
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes from cluster 2: down-regulated in group C of tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609] in plasma cells.
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_D_CLUSTER_UP
Systematic name | M2658
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes from cluster 3: up-regulated in group D of tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609] in plasma cells.
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_D_CLUSTER_DN
Systematic name | M12678
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes from cluster 4: down-regulated in group D of tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609] in plasma cells.
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_D_UP
Systematic name | M5863
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in group D of tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609] in plasma cells.
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_D_DN
Systematic name | M11718
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in group D of tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609] in plasma cells.
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_C_D_UP
Systematic name | M16927
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated both in group C and D of tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609] in plasma cells.
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_C_D_DN
Systematic name | M8646
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated both in group C and D of tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609] in plasma cells.
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_C_UP
Systematic name | M847
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in group C of tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609] in plasma cells.
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_C_DN
Systematic name | M7735
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in group C of tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609] in plasma cells.
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | WU_SILENCED_BY_METHYLATION_IN_BLADDER_CANCER
Systematic name | M19766
Organism | Homo sapiens
PMID | 17456585
Authors | Wu G,Guo Z,Chang X,Kim MS,Nagpal JK,Liu J,Maki JM,Kivirikko KI,Ethier SP,Trink B,Sidransky D
Category | C2
Sub-category | CGP
Brief description | Genes silenced by DNA methylation in bladder cancer cell lines.
Full description | Promoter hypermethylation is one of the common mechanisms leading to gene silencing in various human cancers. Using a combination of pharmacologic unmasking and microarray techniques, we identified 59 candidate hypermethylated genes, including LOXL1, a lysyl oxidase-like gene, in human bladder cancer cells. We further showed that LOXL1 and LOXL4 are commonly silenced genes in human bladder cancer cells, and this silence is predominantly related to promoter methylation. We also found LOXL1 and LOXL4 gene methylation and loss of expression in primary bladder tumors. In addition, somatic mutations were identified in LOXL4, but not in LOXL1 in bladder cancer. Moreover, reintroduction of LOXL1 and LOXL4 genes into human bladder cancer cells leads to a decrease of colony formation ability. Further studies indicated that the overexpression of LOXL1 and LOXL4 could antagonize Ras in activating the extracellular signal-regulated kinase (ERK) signaling pathway. Thus, our current study suggests for the first time that lysyl oxidase-like genes can act as tumor suppressor genes and exert their functions through the inhibition of the Ras/ERK signaling pathway in human bladder cancer.

Standard name | FERRARI_RESPONSE_TO_FENRETINIDE_UP
Systematic name | M14827
Organism | Homo sapiens
PMID | 15958647
Authors | Ferrari N,Pfeffer U,Dell'Eva R,Ambrosini C,Noonan DM,Albini A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HUVEC cells (umbilical vein endothelium) by fenretinide [PubChem=1744].
Full description | PURPOSE: Tumor growth appears to be an angiogenesis-dependent process. N-(4-hydroxyphenyl)retinamide (fenretinide; 4HPR) has been found to inhibit and/or prevent tumor growth under diverse conditions. Although 4HPR is antiangiogenic, the molecular mechanisms of this effect remain largely unknown. EXPERIMENTAL DESIGN: Endothelial cells were treated with 4HPR in vitro to study the effects on migration, invasion, and organization, as well as gene expression by microarray and quantitative PCR studies. In vivo angiogenesis was evaluated in the Matrigel model. RESULTS: 4HPR treatment substantially modified the biological activities of endothelial cells, repressing their capacity to migrate, invade, and organize into capillary-like structures. The inhibition of invasion induced by 4HPR was also associated with decreased activities of the metalloproteases matrix metalloproteinase-2 and CD13/APN. Using oligonucleotide microarrays, we observed that bone morphogenetic protein-2 and macrophage inhibitory cytokine-1, two multifunctional cytokines of the transforming growth factor-beta family that regulate the growth, differentiation, apoptosis, and matrix accumulation of a variety of cells, are up-regulated in vitro by 4HPR. Both these molecules specifically inhibited endothelial cell growth, migration, and invasion in vitro and suppressed angiogenesis in the Matrigel plug assay in vivo. Blocking antibodies to bone morphogenetic protein-2 were able to reverse the suppressive effects of 4HPR in vitro and in vivo. CONCLUSIONS: These data support the conclusion that 4HPR inhibits tumor growth by repression of new vessel growth and identify novel points of regulation of angiogenesis in transforming growth factor-beta family proteins.

Standard name | FERRARI_RESPONSE_TO_FENRETINIDE_DN
Systematic name | M1585
Organism | Homo sapiens
PMID | 15958647
Authors | Ferrari N,Pfeffer U,Dell'Eva R,Ambrosini C,Noonan DM,Albini A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HUVEC cells (umbilical vein endothelium) by fenretinide [PubChem=1744].
Full description | PURPOSE: Tumor growth appears to be an angiogenesis-dependent process. N-(4-hydroxyphenyl)retinamide (fenretinide; 4HPR) has been found to inhibit and/or prevent tumor growth under diverse conditions. Although 4HPR is antiangiogenic, the molecular mechanisms of this effect remain largely unknown. EXPERIMENTAL DESIGN: Endothelial cells were treated with 4HPR in vitro to study the effects on migration, invasion, and organization, as well as gene expression by microarray and quantitative PCR studies. In vivo angiogenesis was evaluated in the Matrigel model. RESULTS: 4HPR treatment substantially modified the biological activities of endothelial cells, repressing their capacity to migrate, invade, and organize into capillary-like structures. The inhibition of invasion induced by 4HPR was also associated with decreased activities of the metalloproteases matrix metalloproteinase-2 and CD13/APN. Using oligonucleotide microarrays, we observed that bone morphogenetic protein-2 and macrophage inhibitory cytokine-1, two multifunctional cytokines of the transforming growth factor-beta family that regulate the growth, differentiation, apoptosis, and matrix accumulation of a variety of cells, are up-regulated in vitro by 4HPR. Both these molecules specifically inhibited endothelial cell growth, migration, and invasion in vitro and suppressed angiogenesis in the Matrigel plug assay in vivo. Blocking antibodies to bone morphogenetic protein-2 were able to reverse the suppressive effects of 4HPR in vitro and in vivo. CONCLUSIONS: These data support the conclusion that 4HPR inhibits tumor growth by repression of new vessel growth and identify novel points of regulation of angiogenesis in transforming growth factor-beta family proteins.

Standard name | HELLEBREKERS_SILENCED_DURING_TUMOR_ANGIOGENESIS
Systematic name | M19128
Organism | Homo sapiens
PMID | 17483324
Authors | Hellebrekers DM,Melotte V,Viré E,Langenkamp E,Molema G,Fuks F,Herman JG,Criekinge Van W,Griffioen AW,Engeland van M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in tumor-conditioned vs quiescent endothelial cells and up-regulated upon treatment with decitabine and TSA [PubChem=451668;5562].
Full description | Tumor angiogenesis requires intricate regulation of gene expression in endothelial cells. We recently showed that DNA methyltransferase (DNMT) and histone deacetylase (HDAC) inhibitors directly repress endothelial cell growth and tumor angiogenesis, suggesting that epigenetic modifications mediated by DNMTs and HDAC are involved in regulation of endothelial cell gene expression during tumor angiogenesis. To understand the mechanisms behind the epigenetic regulation of tumor angiogenesis, we used microarray analysis to perform a comprehensive screen to identify genes down-regulated in tumor-conditioned versus quiescent endothelial cells, and reexpressed by 5-aza-2'-deoxycytidine (DAC) and trichostatin A (TSA). Among the 81 genes identified, 77% harbored a promoter CpG island. Validation of mRNA levels of a subset of genes confirmed significant down-regulation in tumor-conditioned endothelial cells and reactivation by treatment with a combination of DAC and TSA, as well as by both compounds separately. Silencing of these genes in tumor-conditioned endothelial cells correlated with promoter histone H3 deacetylation and loss of H3 lysine 4 methylation, but did not involve DNA methylation of promoter CpG islands. For six genes, down-regulation in microdissected human tumor endothelium was confirmed. Functional validation by RNA interference revealed that clusterin, fibrillin 1, and quiescin Q6 are negative regulators of endothelial cell growth and angiogenesis. In summary, our data identify novel angiogenesis-suppressing genes that become silenced in tumor-conditioned endothelial cells in association with promoter histone modifications and reactivated by DNMT and HDAC inhibitors through reversal of these epigenetic modifications, providing a mechanism for epigenetic regulation of tumor angiogenesis.

Standard name | REICHERT_G1S_REGULATORS_AS_PI3K_TARGETS
Systematic name | M679
Organism | Homo sapiens
PMID | 17483325
Authors | Reichert M,Saur D,Hamacher R,Schmid RM,Schneider G
Category | C2
Sub-category | CGP
Brief description | G1 to S phase regulators significantly changed in DanG cells (pancreatic cancer) treated with Ly294002 [PubChem=3973], a phosphoinositide 3-kinase (PI3K) inhibitor.
Full description | The phosphoinositide-3-kinase (PI3K)/AKT signaling pathway controls fundamental processes of cancer cell biology like proliferation and cell survival. The PI3K/AKT pathway is activated in pancreatic ductal adenocarcinoma (PDAC) cells. The molecular mechanisms linking PI3K signaling to the cell cycle machinery in PDAC cells are not investigated in detail. Using the PI3K inhibitor Ly294002 as well as small interfering RNA targeting AKT1 expression, we show that PI3K controls the proliferation and G(1) phase progression of PDAC cells. Gene profiling revealed several important regulators of G(1)-S phase progression controlled by PI3K signaling like p21(Cip1), S-phase kinase-associated protein 2 (SKP2), CDC25a, cyclin A, cyclin D2, CDK2, and cyclin E. We show that the F-box protein SKP2, an oncogene up-regulated in PDAC, is transcriptionally regulated by the PI3K/AKT1 pathway in PDAC cells. At the molecular level, the control of the SKP2 gene by PI3K is due to the regulation of E2F1 binding to the proximal SKP2 gene promoter. The complex and profound connection of PI3K/AKT1 signaling to the cell cycle qualifies this pathway as a suitable target for therapeutic intervention in PDAC.

Standard name | GU_PDEF_TARGETS_UP
Systematic name | M3955
Organism | Homo sapiens
PMID | 17483333
Authors | Gu X,Zerbini LF,Otu HH,Bhasin M,Yang Q,Joseph MG,Grall F,Onatunde T,Correa RG,Libermann TA
Category | C2
Sub-category | CGP
Brief description | Integrin, VEGF, Wnt and TGFbeta signaling pathway genes up-regulated in PC-3 cells (prostate cancer) after knockdown of PDEF [GeneID=25803] by RNAi.
Full description | The epithelium-specific Ets transcription factor, PDEF, plays a role in prostate and breast cancer, although its precise function has not been established. In prostate cancer, PDEF is involved in regulating prostate-specific antigen expression via interaction with the androgen receptor and NKX3.1, and down-regulation of PDEF by antiproliferative agents has been associated with reduced PDEF expression. We now report that reduced expression of PDEF leads to a morphologic change, increased migration and invasiveness in prostate cancer cells, reminiscent of transforming growth factor beta (TGFbeta) function and epithelial-to-mesenchymal transition. Indeed, inhibition of PDEF expression triggers a transcriptional program of genes involved in the TGFbeta pathway, migration, invasion, adhesion, and epithelial dedifferentiation. Our results establish PDEF as a critical regulator of genes involved in cell motility, invasion, and adhesion of prostate cancer cells.

Standard name | GU_PDEF_TARGETS_DN
Systematic name | M10480
Organism | Homo sapiens
PMID | 17483333
Authors | Gu X,Zerbini LF,Otu HH,Bhasin M,Yang Q,Joseph MG,Grall F,Onatunde T,Correa RG,Libermann TA
Category | C2
Sub-category | CGP
Brief description | Integrin, VEGF, Wnt and TGFbeta signaling pathway genes down-regulated in PC-3 cells (prostate cancer) after knockdown of PDEF [GeneID=25803] by RNAi.
Full description | The epithelium-specific Ets transcription factor, PDEF, plays a role in prostate and breast cancer, although its precise function has not been established. In prostate cancer, PDEF is involved in regulating prostate-specific antigen expression via interaction with the androgen receptor and NKX3.1, and down-regulation of PDEF by antiproliferative agents has been associated with reduced PDEF expression. We now report that reduced expression of PDEF leads to a morphologic change, increased migration and invasiveness in prostate cancer cells, reminiscent of transforming growth factor beta (TGFbeta) function and epithelial-to-mesenchymal transition. Indeed, inhibition of PDEF expression triggers a transcriptional program of genes involved in the TGFbeta pathway, migration, invasion, adhesion, and epithelial dedifferentiation. Our results establish PDEF as a critical regulator of genes involved in cell motility, invasion, and adhesion of prostate cancer cells.

Standard name | TOOKER_GEMCITABINE_RESISTANCE_UP
Systematic name | M19654
Organism | Homo sapiens
PMID | 17483357
Authors | Tooker P,Yen WC,Ng SC,Negro-Vilar A,Hermann TW
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in Calu3 cells (non-small cell lung cancer, NSCLC) resistant to gemcitabine [PubChem=3461] which became down-regulated in response to bexarotene [PubChem=82146].
Full description | Acquired drug resistance is a major obstacle in cancer therapy. As for many other drugs, this is also the case for gemcitabine, a nucleoside analogue with activity against non-small cell lung cancer (NSCLC). Here, we evaluate the ability of bexarotene to modulate the acquisition and maintenance of gemcitabine resistance in Calu3 NSCLC models. In the prevention model, Calu3 cells treated repeatedly with gemcitabine alone gradually developed resistance. However, with inclusion of bexarotene, the cells remained chemosensitive. RNA analysis showed a strong increase of rrm1 (ribonucleotide reductase M1) expression in the resistant cells (Calu3-GemR), a gene known to be involved in gemcitabine resistance. In addition, the expression of genes surrounding the chromosomal location of rrm1 was increased, suggesting that resistance was due to gene amplification at the chr11 p15.5 locus. Analysis of genomic DNA confirmed that the rrm1 gene copy number was increased over 10-fold. Correspondingly, fluorescence in situ hybridization analysis of metaphase chromosomes showed an intrachromosomal amplification of the rrm1 locus. In the therapeutic model, bexarotene gradually resensitized Calu3-GemR cells to gemcitabine, reaching parental drug sensitivity after 10 treatment cycles. This was associated with a loss in rrm1 amplification. Corresponding with the in vitro data, xenograft tumors generated from the resistant cells did not respond to gemcitabine but were growth inhibited when bexarotene was added to the cytotoxic agent. The data indicate that bexarotene can resensitize gemcitabine-resistant tumor cells by reversing gene amplification. This suggests that bexarotene may have clinical utility in cancers where drug resistance by gene amplification is a major obstacle to successful therapy.

Standard name | TOOKER_GEMCITABINE_RESISTANCE_DN
Systematic name | M18806
Organism | Homo sapiens
PMID | 17483357
Authors | Tooker P,Yen WC,Ng SC,Negro-Vilar A,Hermann TW
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in Calu3 cells (non-small cell lung cancer, NSCLC) resistant to gemcitabine [PubChem=3461] which became up-regulated in response to bexarotene [PubChem=82146].
Full description | Acquired drug resistance is a major obstacle in cancer therapy. As for many other drugs, this is also the case for gemcitabine, a nucleoside analogue with activity against non-small cell lung cancer (NSCLC). Here, we evaluate the ability of bexarotene to modulate the acquisition and maintenance of gemcitabine resistance in Calu3 NSCLC models. In the prevention model, Calu3 cells treated repeatedly with gemcitabine alone gradually developed resistance. However, with inclusion of bexarotene, the cells remained chemosensitive. RNA analysis showed a strong increase of rrm1 (ribonucleotide reductase M1) expression in the resistant cells (Calu3-GemR), a gene known to be involved in gemcitabine resistance. In addition, the expression of genes surrounding the chromosomal location of rrm1 was increased, suggesting that resistance was due to gene amplification at the chr11 p15.5 locus. Analysis of genomic DNA confirmed that the rrm1 gene copy number was increased over 10-fold. Correspondingly, fluorescence in situ hybridization analysis of metaphase chromosomes showed an intrachromosomal amplification of the rrm1 locus. In the therapeutic model, bexarotene gradually resensitized Calu3-GemR cells to gemcitabine, reaching parental drug sensitivity after 10 treatment cycles. This was associated with a loss in rrm1 amplification. Corresponding with the in vitro data, xenograft tumors generated from the resistant cells did not respond to gemcitabine but were growth inhibited when bexarotene was added to the cytotoxic agent. The data indicate that bexarotene can resensitize gemcitabine-resistant tumor cells by reversing gene amplification. This suggests that bexarotene may have clinical utility in cancers where drug resistance by gene amplification is a major obstacle to successful therapy.

Standard name | BOHN_PRIMARY_IMMUNODEFICIENCY_SYNDROM_UP
Systematic name | M7603
Organism | Homo sapiens
PMID | 17195838
Authors | Bohn G,Allroth A,Brandes G,Thiel J,Glocker E,Schäffer AA,Rathinam C,Taub N,Teis D,Zeidler C,Dewey RA,Geffers R,Buer J,Huber LA,Welte K,Grimbacher B,Klein C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in B lymphocytes from patients with primary immunodefiency syndrom.
Full description | Lysosome-related organelles have versatile functions, including protein and lipid degradation, signal transduction and protein secretion. The molecular elucidation of rare congenital diseases affecting endosomal-lysosomal biogenesis has given insights into physiological functions of the innate and adaptive immune system. Here, we describe a previously unknown human primary immunodeficiency disorder and provide evidence that the endosomal adaptor protein p14, previously characterized as confining mitogen-activated protein kinase (MAPK) signaling to late endosomes, is crucial for the function of neutrophils, B cells, cytotoxic T cells and melanocytes. Combining genetic linkage studies and transcriptional profiling analysis, we identified a homozygous point mutation in the 3' untranslated region (UTR) of p14 (also known as MAPBPIP), resulting in decreased protein expression. In p14-deficient cells, the distribution of late endosomes was severely perturbed, suggesting a previously unknown role for p14 in endosomal biogenesis. These findings have implications for understanding endosomal membrane dynamics, compartmentalization of cell signal cascades, and their role in immunity.

Standard name | BOHN_PRIMARY_IMMUNODEFICIENCY_SYNDROM_DN
Systematic name | M11778
Organism | Homo sapiens
PMID | 17195838
Authors | Bohn G,Allroth A,Brandes G,Thiel J,Glocker E,Schäffer AA,Rathinam C,Taub N,Teis D,Zeidler C,Dewey RA,Geffers R,Buer J,Huber LA,Welte K,Grimbacher B,Klein C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in B lymphocytes from patients with primary immunodefiency syndrom.
Full description | Lysosome-related organelles have versatile functions, including protein and lipid degradation, signal transduction and protein secretion. The molecular elucidation of rare congenital diseases affecting endosomal-lysosomal biogenesis has given insights into physiological functions of the innate and adaptive immune system. Here, we describe a previously unknown human primary immunodeficiency disorder and provide evidence that the endosomal adaptor protein p14, previously characterized as confining mitogen-activated protein kinase (MAPK) signaling to late endosomes, is crucial for the function of neutrophils, B cells, cytotoxic T cells and melanocytes. Combining genetic linkage studies and transcriptional profiling analysis, we identified a homozygous point mutation in the 3' untranslated region (UTR) of p14 (also known as MAPBPIP), resulting in decreased protein expression. In p14-deficient cells, the distribution of late endosomes was severely perturbed, suggesting a previously unknown role for p14 in endosomal biogenesis. These findings have implications for understanding endosomal membrane dynamics, compartmentalization of cell signal cascades, and their role in immunity.

Standard name | FLOTHO_PEDIATRIC_ALL_THERAPY_RESPONSE_UP
Systematic name | M16479
Organism | Homo sapiens
PMID | 16627760
Authors | Flotho C,Coustan-Smith E,Pei D,Iwamoto S,Song G,Cheng C,Pui CH,Downing JR,Campana D
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes significantly associated with positive minimal residual disease (MRD) on day 46 after chemotherapy treatment of children with acute lymphoblastic leukemia (ALL).
Full description | In childhood acute lymphoblastic leukemia (ALL), early response to treatment is a powerful prognostic indicator. To identify genes associated with this response, we analyzed gene expression of diagnostic lymphoblasts from 189 children with ALL and compared the findings with minimal residual disease (MRD) levels on days 19 and 46 of remission induction treatment. After excluding genes associated with genetic subgroups, we identified 17 genes that were significantly associated with MRD. The caspase 8-associated protein 2 (CASP8AP2) gene was studied further because of its reported role in apoptosis and glucocorticoid signaling. In a separate cohort of 99 patients not included in the comparison of gene expression profiles and MRD, low levels of CASP8AP2 expression predicted a lower event-free survival (P = .02) and a higher rate of leukemia relapse (P = .01) and were an independent predictor of outcome. High levels of CASP8AP2 expression were associated with a greater propensity of leukemic lymphoblasts to undergo apoptosis. We conclude that measurement of CASP8AP2 expression at diagnosis offers a means to identify patients whose leukemic cells are highly susceptible to chemotherapy. Therefore, this gene is a strong candidate for inclusion in gene expression arrays specifically designed for leukemia diagnosis.

Standard name | FLOTHO_PEDIATRIC_ALL_THERAPY_RESPONSE_DN
Systematic name | M4866
Organism | Homo sapiens
PMID | 16627760
Authors | Flotho C,Coustan-Smith E,Pei D,Iwamoto S,Song G,Cheng C,Pui CH,Downing JR,Campana D
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes significantly associated with positive minimal residual disease (MRD) on day 46 after chemotherapy treatment of children with acute lymphoblastic leukemia (ALL).
Full description | In childhood acute lymphoblastic leukemia (ALL), early response to treatment is a powerful prognostic indicator. To identify genes associated with this response, we analyzed gene expression of diagnostic lymphoblasts from 189 children with ALL and compared the findings with minimal residual disease (MRD) levels on days 19 and 46 of remission induction treatment. After excluding genes associated with genetic subgroups, we identified 17 genes that were significantly associated with MRD. The caspase 8-associated protein 2 (CASP8AP2) gene was studied further because of its reported role in apoptosis and glucocorticoid signaling. In a separate cohort of 99 patients not included in the comparison of gene expression profiles and MRD, low levels of CASP8AP2 expression predicted a lower event-free survival (P = .02) and a higher rate of leukemia relapse (P = .01) and were an independent predictor of outcome. High levels of CASP8AP2 expression were associated with a greater propensity of leukemic lymphoblasts to undergo apoptosis. We conclude that measurement of CASP8AP2 expression at diagnosis offers a means to identify patients whose leukemic cells are highly susceptible to chemotherapy. Therefore, this gene is a strong candidate for inclusion in gene expression arrays specifically designed for leukemia diagnosis.

Standard name | VILIMAS_NOTCH1_TARGETS_UP
Systematic name | M1869
Organism | Mus musculus
PMID | 17173050
Authors | Vilimas T,Mascarenhas J,Palomero T,Mandal M,Buonamici S,Meng F,Thompson B,Spaulding C,Macaroun S,Alegre ML,Kee BL,Ferrando A,Miele L,Aifantis I
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in bone marrow progenitors by constitutively active NOTCH1 [GeneID=4851].
Full description | T-cell acute lymphoblastic leukemia (T-ALL), unlike other ALL types, is only infrequently associated with chromosomal aberrations, but it was recently shown that most individuals with T-ALL carry activating mutations in the NOTCH1 gene. However, the signaling pathways and target genes responsible for Notch1-induced neoplastic transformation remain undefined. We report here that constitutively active Notch1 activates the NF-kappaB pathway transcriptionally and via the IkappaB kinase (IKK) complex, thereby causing increased expression of several well characterized target genes of NF-kappaB in bone marrow hematopoietic stem cells and progenitors. Our observations demonstrate that the NF-kappaB pathway is highly active in established human T-ALL and that inhibition of the pathway can efficiently restrict tumor growth both in vitro and in vivo. These findings identify NF-kappaB as one of the major mediators of Notch1-induced transformation and suggest that the NF-kappaB pathway is a potential target of future therapies of T-ALL.

Standard name | VILIMAS_NOTCH1_TARGETS_DN
Systematic name | M1873
Organism | Mus musculus
PMID | 17173050
Authors | Vilimas T,Mascarenhas J,Palomero T,Mandal M,Buonamici S,Meng F,Thompson B,Spaulding C,Macaroun S,Alegre ML,Kee BL,Ferrando A,Miele L,Aifantis I
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in bone marrow progenitors by constitutively active NOTCH1 [GeneID=4851].
Full description | T-cell acute lymphoblastic leukemia (T-ALL), unlike other ALL types, is only infrequently associated with chromosomal aberrations, but it was recently shown that most individuals with T-ALL carry activating mutations in the NOTCH1 gene. However, the signaling pathways and target genes responsible for Notch1-induced neoplastic transformation remain undefined. We report here that constitutively active Notch1 activates the NF-kappaB pathway transcriptionally and via the IkappaB kinase (IKK) complex, thereby causing increased expression of several well characterized target genes of NF-kappaB in bone marrow hematopoietic stem cells and progenitors. Our observations demonstrate that the NF-kappaB pathway is highly active in established human T-ALL and that inhibition of the pathway can efficiently restrict tumor growth both in vitro and in vivo. These findings identify NF-kappaB as one of the major mediators of Notch1-induced transformation and suggest that the NF-kappaB pathway is a potential target of future therapies of T-ALL.

Standard name | SPIRA_SMOKERS_LUNG_CANCER_UP
Systematic name | M7880
Organism | Homo sapiens
PMID | 17334370
Authors | Spira A,Beane JE,Shah V,Steiling K,Liu G,Schembri F,Gilman S,Dumas YM,Calner P,Sebastiani P,Sridhar S,Beamis J,Lamb C,Anderson T,Gerry N,Keane J,Lenburg ME,Brody JS
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes that distinguished smokers with and without lung cancer.
Full description | Lung cancer is the leading cause of death from cancer in the US and the world. The high mortality rate (80-85% within 5 years) results, in part, from a lack of effective tools to diagnose the disease at an early stage. Given that cigarette smoke creates a field of injury throughout the airway, we sought to determine if gene expression in histologically normal large-airway epithelial cells obtained at bronchoscopy from smokers with suspicion of lung cancer could be used as a lung cancer biomarker. Using a training set (n = 77) and gene-expression profiles from Affymetrix HG-U133A microarrays, we identified an 80-gene biomarker that distinguishes smokers with and without lung cancer. We tested the biomarker on an independent test set (n = 52), with an accuracy of 83% (80% sensitive, 84% specific), and on an additional validation set independently obtained from five medical centers (n = 35). Our biomarker had approximately 90% sensitivity for stage 1 cancer across all subjects. Combining cytopathology of lower airway cells obtained at bronchoscopy with the biomarker yielded 95% sensitivity and a 95% negative predictive value. These findings indicate that gene expression in cytologically normal large-airway epithelial cells can serve as a lung cancer biomarker, potentially owing to a cancer-specific airway-wide response to cigarette smoke.

Standard name | SPIRA_SMOKERS_LUNG_CANCER_DN
Systematic name | M6515
Organism | Homo sapiens
PMID | 17334370
Authors | Spira A,Beane JE,Shah V,Steiling K,Liu G,Schembri F,Gilman S,Dumas YM,Calner P,Sebastiani P,Sridhar S,Beamis J,Lamb C,Anderson T,Gerry N,Keane J,Lenburg ME,Brody JS
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes that distinguished smokers with and without lung cancer.
Full description | Lung cancer is the leading cause of death from cancer in the US and the world. The high mortality rate (80-85% within 5 years) results, in part, from a lack of effective tools to diagnose the disease at an early stage. Given that cigarette smoke creates a field of injury throughout the airway, we sought to determine if gene expression in histologically normal large-airway epithelial cells obtained at bronchoscopy from smokers with suspicion of lung cancer could be used as a lung cancer biomarker. Using a training set (n = 77) and gene-expression profiles from Affymetrix HG-U133A microarrays, we identified an 80-gene biomarker that distinguishes smokers with and without lung cancer. We tested the biomarker on an independent test set (n = 52), with an accuracy of 83% (80% sensitive, 84% specific), and on an additional validation set independently obtained from five medical centers (n = 35). Our biomarker had approximately 90% sensitivity for stage 1 cancer across all subjects. Combining cytopathology of lower airway cells obtained at bronchoscopy with the biomarker yielded 95% sensitivity and a 95% negative predictive value. These findings indicate that gene expression in cytologically normal large-airway epithelial cells can serve as a lung cancer biomarker, potentially owing to a cancer-specific airway-wide response to cigarette smoke.

Standard name | LUDWICZEK_TREATING_IRON_OVERLOAD
Systematic name | M1874
Organism | Mus musculus
PMID | 17293870
Authors | Ludwiczek S,Theurl I,Muckenthaler MU,Jakab M,Mair SM,Theurl M,Kiss J,Paulmichl M,Hentze MW,Ritter M,Weiss G
Category | C2
Sub-category | CGP
Brief description | Genes changed in liver in response to nifedipine [PubChem=4485] treatment of iron overload.
Full description | Hereditary hemochromatosis and transfusional iron overload are frequent clinical conditions associated with progressive iron accumulation in parenchymal tissues, leading to eventual organ failure. We have discovered a new mechanism to reverse iron overload-pharmacological modulation of the divalent metal transporter-1 (DMT-1). DMT-1 mediates intracellular iron transport during the transferrin cycle and apical iron absorption in the duodenum. Its additional functions in iron handling in the kidney and liver are less well understood. We show that the L-type calcium channel blocker nifedipine increases DMT-1-mediated cellular iron transport 10- to 100-fold at concentrations between 1 and 100 microM. Mechanistically, nifedipine causes this effect by prolonging the iron-transporting activity of DMT-1. We show that nifedipine mobilizes iron from the liver of mice with primary and secondary iron overload and enhances urinary iron excretion. Modulation of DMT-1 function by L-type calcium channel blockers emerges as a new pharmacological therapy for the treatment of iron overload disorders.

Standard name | JU_AGING_TERC_TARGETS_UP
Systematic name | M1875
Organism | Mus musculus
PMID | 17486088
Authors | Ju Z,Jiang H,Jaworski M,Rathinam C,Gompf A,Klein C,Trumpp A,Rudolph KL
Category | C2
Sub-category | CGP
Brief description | Cytokines, growth factors, and secreted proteins that show increased expression on a protein array of samples from aged TERC [GeneID=7012] knockout mice.
Full description | Cell-intrinsic checkpoints limit the proliferative capacity of primary cells in response to telomere dysfunction. It is not known, however, whether telomere dysfunction contributes to cell-extrinsic alterations that impair stem cell function and organ homeostasis. Here we show that telomere dysfunction provokes defects of the hematopoietic environment that impair B lymphopoiesis but increase myeloid proliferation in aging telomerase knockout (Terc(-/-)) mice. Moreover, the dysfunctional environment limited the engraftment of transplanted wild-type hematopoietic stem cells (HSCs). Dysfunction of the hematopoietic environment was age dependent and correlated with progressive telomere shortening in bone marrow stromal cells. Telomere dysfunction impaired mesenchymal progenitor cell function, reduced the capacity of bone marrow stromal cells to maintain functional HSCs, and increased the expression of various cytokines, including granulocyte colony-stimulating factor (G-CSF), in the plasma of aging mice. Administration of G-CSF to wild-type mice mimicked some of the defects seen in aging Terc(-/-) mice, including impairment of B lymphopoiesis and HSC engraftment. Conversely, inhibition of G-CSF improved HSC engraftment in aged Terc(-/-) mice. Taken together, these results show that telomere dysfunction induces alterations of the environment that can have implications for organismal aging and cell transplantation therapies.

Standard name | ZAIDI_OSTEOBLAST_TRANSCRIPTION_FACTORS
Systematic name | M6267
Organism | Homo sapiens
PMID | 17618270
Authors | Zaidi M
Category | C2
Sub-category | CGP
Brief description | An assortment of osteoblast transcriptional regulators.
Full description | The use of genetically manipulated mouse models, gene and protein discovery and the cataloguing of genetic mutations have each allowed us to obtain new insights into skeletal morphogenesis and remodeling. These techniques have made it possible to identify molecules that are obligatory for specific cellular functions, and to exploit these molecules for therapeutic purposes. New insights into the pathophysiology of diseases have also enabled us to understand molecular defects in a way that was not possible a decade ago. This review summarizes our current understanding of the carefully orchestrated cross-talk between cells of the bone marrow and between bone cells and the brain through which bone is constantly remodeled during adult life. It also highlights molecular aberrations that cause bone cells to become dysfunctional, as well as therapeutic options and opportunities to counteract skeletal loss.

Standard name | WAGNER_APO2_SENSITIVITY
Systematic name | M13240
Organism | Homo sapiens
PMID | 17767167
Authors | Wagner KW,Punnoose EA,Januario T,Lawrence DA,Pitti RM,Lancaster K,Lee D,von Goetz M,Yee SF,Totpal K,Huw L,Katta V,Cavet G,Hymowitz SG,Amler L,Ashkenazi A
Category | C2
Sub-category | CGP
Brief description | Genes whose expression most significantly correlated with cancer cell line sensitivity to the proapoptotic ligand APO2 [GeneID=8797].
Full description | Apo2L/TRAIL stimulates cancer cell death through the proapoptotic receptors DR4 and DR5, but the determinants of tumor susceptibility to this ligand are not fully defined. mRNA expression of the peptidyl O-glycosyltransferase GALNT14 correlated with Apo2L/TRAIL sensitivity in pancreatic carcinoma, non-small-cell lung carcinoma and melanoma cell lines, and up to 30% of samples from various human malignancies showed GALNT14 overexpression. RNA interference of GALNT14 reduced cellular Apo2L/TRAIL sensitivity, whereas overexpression increased responsiveness. Biochemical analysis of DR5 identified several ectodomain O-(N-acetyl galactosamine-galactose-sialic acid) structures. Sequence comparison predicted conserved extracellular DR4 and DR5 O-glycosylation sites; progressive mutation of the DR5 sites attenuated apoptotic signaling. O-glycosylation promoted ligand-stimulated clustering of DR4 and DR5, which mediated recruitment and activation of the apoptosis-initiating protease caspase-8. These results uncover a new link between death-receptor O-glycosylation and apoptotic signaling, providing potential predictive biomarkers for Apo2L/TRAIL-based cancer therapy.

Standard name | PALOMERO_GSI_SENSITIVITY_UP
Systematic name | M4163
Organism | Homo sapiens
PMID | 17873882
Authors | Palomero T,Sulis ML,Cortina M,Real PJ,Barnes K,Ciofani M,Caparros E,Buteau J,Brown K,Perkins SL,Bhagat G,Agarwal AM,Basso G,Castillo M,Nagase S,Cordon-Cardo C,Parsons R,Zúñiga-Pflücker JC,Dominguez M,Ferrando AA
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes associated with sensitivity and resistance to gamma-secretase (GSI) in T-cell acute lymphoblastic leukemia (T-ALL) cell lines.
Full description | Gain-of-function mutations in NOTCH1 are common in T-cell lymphoblastic leukemias and lymphomas (T-ALL), making this receptor a promising target for drugs such as gamma-secretase inhibitors, which block a proteolytic cleavage required for NOTCH1 activation. However, the enthusiasm for these therapies has been tempered by tumor resistance and the paucity of information on the oncogenic programs regulated by oncogenic NOTCH1. Here we show that NOTCH1 regulates the expression of PTEN (encoding phosphatase and tensin homolog) and the activity of the phosphoinositol-3 kinase (PI3K)-AKT signaling pathway in normal and leukemic T cells. Notch signaling and the PI3K-AKT pathway synergize in vivo in a Drosophila melanogaster model of Notch-induced tumorigenesis, and mutational loss of PTEN is associated with human T-ALL resistance to pharmacological inhibition of NOTCH1. Overall, these findings identify transcriptional control of PTEN and regulation of the PI3K-AKT pathway as key elements of the leukemogenic program activated by NOTCH1 and provide the basis for the design of new therapeutic strategies for T-ALL.

Standard name | PALOMERO_GSI_SENSITIVITY_DN
Systematic name | M14865
Organism | Homo sapiens
PMID | 17873882
Authors | Palomero T,Sulis ML,Cortina M,Real PJ,Barnes K,Ciofani M,Caparros E,Buteau J,Brown K,Perkins SL,Bhagat G,Agarwal AM,Basso G,Castillo M,Nagase S,Cordon-Cardo C,Parsons R,Zúñiga-Pflücker JC,Dominguez M,Ferrando AA
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes associated with sensitivity and resistance to gamma-secretase (GSI) in T-cell acute lymphoblastic leukemia (T-ALL) cell lines.
Full description | Gain-of-function mutations in NOTCH1 are common in T-cell lymphoblastic leukemias and lymphomas (T-ALL), making this receptor a promising target for drugs such as gamma-secretase inhibitors, which block a proteolytic cleavage required for NOTCH1 activation. However, the enthusiasm for these therapies has been tempered by tumor resistance and the paucity of information on the oncogenic programs regulated by oncogenic NOTCH1. Here we show that NOTCH1 regulates the expression of PTEN (encoding phosphatase and tensin homolog) and the activity of the phosphoinositol-3 kinase (PI3K)-AKT signaling pathway in normal and leukemic T cells. Notch signaling and the PI3K-AKT pathway synergize in vivo in a Drosophila melanogaster model of Notch-induced tumorigenesis, and mutational loss of PTEN is associated with human T-ALL resistance to pharmacological inhibition of NOTCH1. Overall, these findings identify transcriptional control of PTEN and regulation of the PI3K-AKT pathway as key elements of the leukemogenic program activated by NOTCH1 and provide the basis for the design of new therapeutic strategies for T-ALL.

Standard name | SOUCEK_MYC_TARGETS
Systematic name | M11290
Organism | Mus musculus
PMID | 17906636
Authors | Soucek L,Lawlor ER,Soto D,Shchors K,Swigart LB,Evan GI
Category | C2
Sub-category | CGP
Brief description | Chemokine genes up-regulated within 2 hr of c-Myc [GeneID=4609] activation in a mouse model of Myc-induced pancreatic beta-cell tumorigenesis.
Full description | An association between inflammation and cancer has long been recognized, but the cause and effect relationship linking the two remains unclear. Myc is a pleiotropic transcription factor that is overexpressed in many human cancers and instructs many extracellular aspects of the tumor tissue phenotype, including remodeling of tumor stroma and angiogenesis. Here we show in a beta-cell tumor model that activation of Myc in vivo triggers rapid recruitment of mast cells to the tumor site-a recruitment that is absolutely required for macroscopic tumor expansion. In addition, treatment of established beta-cell tumors with a mast cell inhibitor rapidly triggers hypoxia and cell death of tumor and endothelial cells. Inhibitors of mast cell function may therefore prove therapeutically useful in restraining expansion and survival of pancreatic and other cancers.

Standard name | SEKI_INFLAMMATORY_RESPONSE_LPS_UP
Systematic name | M7245
Organism | Mus musculus
PMID | 17952090
Authors | Seki E,De Minicis S,Osterreicher CH,Kluwe J,Osawa Y,Brenner DA,Schwabe RF
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatic stellar cells after stimulation with bacterial lipopolysacharide (LPS).
Full description | Hepatic injury is associated with a defective intestinal barrier and increased hepatic exposure to bacterial products. Here we report that the intestinal bacterial microflora and a functional Toll-like receptor 4 (TLR4), but not TLR2, are required for hepatic fibrogenesis. Using Tlr4-chimeric mice and in vivo lipopolysaccharide (LPS) challenge, we demonstrate that quiescent hepatic stellate cells (HSCs), the main precursors for myofibroblasts in the liver, are the predominant target through which TLR4 ligands promote fibrogenesis. In quiescent HSCs, TLR4 activation not only upregulates chemokine secretion and induces chemotaxis of Kupffer cells, but also downregulates the transforming growth factor (TGF)-beta pseudoreceptor Bambi to sensitize HSCs to TGF-beta-induced signals and allow for unrestricted activation by Kupffer cells. LPS-induced Bambi downregulation and sensitization to TGF-beta is mediated by a MyD88-NF-kappaB-dependent pathway. Accordingly, Myd88-deficient mice have decreased hepatic fibrosis. Thus, modulation of TGF-beta signaling by a TLR4-MyD88-NF-kappaB axis provides a novel link between proinflammatory and profibrogenic signals.

Standard name | SEKI_INFLAMMATORY_RESPONSE_LPS_DN
Systematic name | M1980
Organism | Mus musculus
PMID | 17952090
Authors | Seki E,De Minicis S,Osterreicher CH,Kluwe J,Osawa Y,Brenner DA,Schwabe RF
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatic stellar cells after stimulation with bacterial lipopolysacharide (LPS).
Full description | Hepatic injury is associated with a defective intestinal barrier and increased hepatic exposure to bacterial products. Here we report that the intestinal bacterial microflora and a functional Toll-like receptor 4 (TLR4), but not TLR2, are required for hepatic fibrogenesis. Using Tlr4-chimeric mice and in vivo lipopolysaccharide (LPS) challenge, we demonstrate that quiescent hepatic stellate cells (HSCs), the main precursors for myofibroblasts in the liver, are the predominant target through which TLR4 ligands promote fibrogenesis. In quiescent HSCs, TLR4 activation not only upregulates chemokine secretion and induces chemotaxis of Kupffer cells, but also downregulates the transforming growth factor (TGF)-beta pseudoreceptor Bambi to sensitize HSCs to TGF-beta-induced signals and allow for unrestricted activation by Kupffer cells. LPS-induced Bambi downregulation and sensitization to TGF-beta is mediated by a MyD88-NF-kappaB-dependent pathway. Accordingly, Myd88-deficient mice have decreased hepatic fibrosis. Thus, modulation of TGF-beta signaling by a TLR4-MyD88-NF-kappaB axis provides a novel link between proinflammatory and profibrogenic signals.

Standard name | RAY_ALZHEIMERS_DISEASE
Systematic name | M11893
Organism | Homo sapiens
PMID | 17934472
Authors | Ray S,Britschgi M,Herbert C,Takeda-Uchimura Y,Boxer A,Blennow K,Friedman LF,Galasko DR,Jutel M,Karydas A,Kaye JA,Leszek J,Miller BL,Minthon L,Quinn JF,Rabinovici GD,Robinson WH,Sabbagh MN,So YT,Sparks DL,Tabaton M,Tinklenberg J,Yesavage JA,Tibshirani R,Wyss-Coray T
Category | C2
Sub-category | CGP
Brief description | A biomarker of plasma signaling proteins that predicts clinical Alzheimer's diagnosis.
Full description | A molecular test for Alzheimer's disease could lead to better treatment and therapies. We found 18 signaling proteins in blood plasma that can be used to classify blinded samples from Alzheimer's and control subjects with close to 90% accuracy and to identify patients who had mild cognitive impairment that progressed to Alzheimer's disease 2-6 years later. Biological analysis of the 18 proteins points to systemic dysregulation of hematopoiesis, immune responses, apoptosis and neuronal support in presymptomatic Alzheimer's disease.

Standard name | HUNSBERGER_EXERCISE_REGULATED_GENES
Systematic name | M1878
Organism | Mus musculus
PMID | 18059283
Authors | Hunsberger JG,Newton SS,Bennett AH,Duman CH,Russell DS,Salton SR,Duman RS
Category | C2
Sub-category | CGP
Brief description | Exercise regulated genes in hyppocampus.
Full description | Exercise has many health benefits, including antidepressant actions in depressed human subjects, but the mechanisms underlying these effects have not been elucidated. We used a custom microarray to identify a previously undescribed profile of exercise-regulated genes in the mouse hippocampus, a brain region implicated in mood and antidepressant response. Pathway analysis of the regulated genes shows that exercise upregulates a neurotrophic factor signaling cascade that has been implicated in the actions of antidepressants. One of the most highly regulated target genes of exercise and of the growth factor pathway is the gene encoding the VGF nerve growth factor, a peptide precursor previously shown to influence synaptic plasticity and metabolism. We show that administration of a synthetic VGF-derived peptide produces a robust antidepressant response in mice and, conversely, that mutation of VGF in mice produces the opposite effects. The results suggest a new role for VGF and identify VGF signaling as a potential therapeutic target for antidepressant drug development.

Standard name | PIONTEK_PKD1_TARGETS_UP
Systematic name | M1879
Organism | Mus musculus
PMID | 17965720
Authors | Piontek K,Menezes LF,Garcia-Gonzalez MA,Huso DL,Germino GG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during later stages of renal maturation (days P14-P16) in kidney specific knockout of PKD1 [GeneID=5310].
Full description | Autosomal dominant polycystic kidney disease is an important cause of end-stage renal disease, for which there is no proven therapy. Mutations in PKD1 (the gene encoding polycystin-1) are the principal cause of this disease. The disease begins in utero and is slowly progressive, but it is not known whether cystogenesis is an ongoing process during adult life. We now show that inactivation of Pkd1 in mice before postnatal day 13 results in severely cystic kidneys within 3 weeks, whereas inactivation at day 14 and later results in cysts only after 5 months. We found that cellular proliferation was not appreciably higher in cystic specimens than in age-matched controls, but the abrupt change in response to Pkd1 inactivation corresponded to a previously unrecognized brake point during renal growth and significant changes in gene expression. These findings suggest that the effects of Pkd1 inactivation are defined by a developmental switch that signals the end of the terminal renal maturation process. Our studies show that Pkd1 regulates tubular morphology in both developing and adult kidney, but the pathologic consequences of inactivation are defined by the organ's developmental status. These results have important implications for clinical understanding of the disease and therapeutic approaches.

Standard name | PIONTEK_PKD1_TARGETS_DN
Systematic name | M1880
Organism | Mus musculus
PMID | 17965720
Authors | Piontek K,Menezes LF,Garcia-Gonzalez MA,Huso DL,Germino GG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during later stages of renal maturation (days P14-P16) in kidney specific knockout of PKD1 [GeneID=5310].
Full description | Autosomal dominant polycystic kidney disease is an important cause of end-stage renal disease, for which there is no proven therapy. Mutations in PKD1 (the gene encoding polycystin-1) are the principal cause of this disease. The disease begins in utero and is slowly progressive, but it is not known whether cystogenesis is an ongoing process during adult life. We now show that inactivation of Pkd1 in mice before postnatal day 13 results in severely cystic kidneys within 3 weeks, whereas inactivation at day 14 and later results in cysts only after 5 months. We found that cellular proliferation was not appreciably higher in cystic specimens than in age-matched controls, but the abrupt change in response to Pkd1 inactivation corresponded to a previously unrecognized brake point during renal growth and significant changes in gene expression. These findings suggest that the effects of Pkd1 inactivation are defined by a developmental switch that signals the end of the terminal renal maturation process. Our studies show that Pkd1 regulates tubular morphology in both developing and adult kidney, but the pathologic consequences of inactivation are defined by the organ's developmental status. These results have important implications for clinical understanding of the disease and therapeutic approaches.

Standard name | CHAUHAN_RESPONSE_TO_METHOXYESTRADIOL_UP
Systematic name | M6562
Organism | Homo sapiens
PMID | 12480690
Authors | Chauhan D,Li G,Auclair D,Hideshima T,Richardson P,Podar K,Mitsiades N,Mitsiades C,Li C,Kim RS,Munshi N,Chen LB,Wong W,Anderson KC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by 2-methoxyestradiol (2ME2) [PubChem=1573] in the MM.1S cell line (multiple myeloma) sensitive to dexamethasone [PubChem=5743].
Full description | Our previous study demonstrated that 2-methoxyestradiol (2ME2), an estrogen derivative, induces apoptosis in multiple myeloma (MM) cells; however, the related transcriptional events are unclear. In the present study, we used oligonucleotide microarrays to identify genes altered during 2ME2-induced apoptosis in MM cells. 2ME2 triggers an early transient induction of genes known to trigger cell death and repression of growth/survival-related genes. Many genes regulating cell defense/repair machinery also were transiently induced. Since 2ME2 also induces apoptosis in MM cells resistant to conventional therapies such as dexamethasone (Dex), we compared the gene profiles of 2ME2-treated and Dex-resistant MM cells. Our results suggest that 2ME2 overcomes Dex resistance by modulating genes that confer chemoresistance in MM cells. Microarray results were confirmed by Northern and Western blot analyses. A comparative analysis of selected genes from freshly isolated MM patient cells and 2ME2-treated MM.1S MM cells further provides an in vivo relevance of our in vitro studies. Collectively, these findings suggest genetic events mediating anti-MM activity of 2ME2, as well as mechanisms whereby 2ME2 overcomes Dex resistance in MM cells. These studies may therefore allow improved therapeutic use of 2ME2, based upon targeting genes that regulate MM cell growth and survival.

Standard name | CHAUHAN_RESPONSE_TO_METHOXYESTRADIOL_DN
Systematic name | M17723
Organism | Homo sapiens
PMID | 12480690
Authors | Chauhan D,Li G,Auclair D,Hideshima T,Richardson P,Podar K,Mitsiades N,Mitsiades C,Li C,Kim RS,Munshi N,Chen LB,Wong W,Anderson KC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by 2-methoxyestradiol (2ME2) [PubChem=1573] in the MM.1S cell line (multiple myeloma) sensitive to dexamethasone [PubChem=5743].
Full description | Our previous study demonstrated that 2-methoxyestradiol (2ME2), an estrogen derivative, induces apoptosis in multiple myeloma (MM) cells; however, the related transcriptional events are unclear. In the present study, we used oligonucleotide microarrays to identify genes altered during 2ME2-induced apoptosis in MM cells. 2ME2 triggers an early transient induction of genes known to trigger cell death and repression of growth/survival-related genes. Many genes regulating cell defense/repair machinery also were transiently induced. Since 2ME2 also induces apoptosis in MM cells resistant to conventional therapies such as dexamethasone (Dex), we compared the gene profiles of 2ME2-treated and Dex-resistant MM cells. Our results suggest that 2ME2 overcomes Dex resistance by modulating genes that confer chemoresistance in MM cells. Microarray results were confirmed by Northern and Western blot analyses. A comparative analysis of selected genes from freshly isolated MM patient cells and 2ME2-treated MM.1S MM cells further provides an in vivo relevance of our in vitro studies. Collectively, these findings suggest genetic events mediating anti-MM activity of 2ME2, as well as mechanisms whereby 2ME2 overcomes Dex resistance in MM cells. These studies may therefore allow improved therapeutic use of 2ME2, based upon targeting genes that regulate MM cell growth and survival.

Standard name | FRASOR_RESPONSE_TO_SERM_OR_FULVESTRANT_UP
Systematic name | M8108
Organism | Homo sapiens
PMID | 14973112
Authors | Frasor J,Stossi F,Danes JM,Komm B,Lyttle CR,Katzenellenbogen BS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) by selective estrogen receptor modulators (SERM) 4-hydroxytamoxifen, raloxifene, or ICI 182780 but not by estradiol [PubChem=44959;5035;3478439;5757].
Full description | Selective estrogen receptor modulators (SERMs) such as tamoxifen are effective in the treatment of many estrogen receptor-positive breast cancers and have also proven to be effective in the prevention of breast cancer in women at high risk for the disease. The comparative abilities of tamoxifen versus raloxifene in breast cancer prevention are currently being compared in the Study of Tamoxifen and Raloxifene trial. To better understand the actions of these compounds in breast cancer, we have examined their effects on the expression of approximately 12,000 genes, using Affymetrix GeneChip microarrays, with quantitative PCR verification in many cases, categorizing their actions as agonist, antagonist, or partial agonist/antagonist. Analysis of gene stimulation and inhibition by the SERMs trans-hydroxytamoxifen (TOT) and raloxifene (Ral) or ICI 182,780 (ICI) and by estradiol (E2) in estrogen receptor-containing MCF-7 human breast cancer cells revealed that (a) TOT was the most E2-like of the three compounds, (b) all three compounds either partially or fully antagonized the action of E2 on most genes, with the order of antagonist activity being ICI > Ral > TOT, (c) TOT and Ral, but not ICI, displayed partial agonist/partial antagonist activity on a number of E2-regulated genes, (d) several stimulatory cell cycle-related genes were down-regulated exclusively by ICI, (e) the estrogen-like activity of Ral nearly always overlapped with that of TOT, indicating that Ral has little unique agonist activity different from that of TOT, and (f) some genes were specifically up-regulated by TOT but not Ral, ICI, or E2. Hence, gene expression profiling can discern fundamental differences among SERMs and provides insight into the distinct biologies of TOT, Ral, and ICI in breast cancer.

Standard name | FRASOR_RESPONSE_TO_SERM_OR_FULVESTRANT_DN
Systematic name | M11250
Organism | Homo sapiens
PMID | 14973112
Authors | Frasor J,Stossi F,Danes JM,Komm B,Lyttle CR,Katzenellenbogen BS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) by selective estrogen receptor modulators (SERM) 4-hydroxytamoxifen, raloxifene, or ICI 182780 but not by estradiol [PubChem=44959;5035;3478439;5757].
Full description | Selective estrogen receptor modulators (SERMs) such as tamoxifen are effective in the treatment of many estrogen receptor-positive breast cancers and have also proven to be effective in the prevention of breast cancer in women at high risk for the disease. The comparative abilities of tamoxifen versus raloxifene in breast cancer prevention are currently being compared in the Study of Tamoxifen and Raloxifene trial. To better understand the actions of these compounds in breast cancer, we have examined their effects on the expression of approximately 12,000 genes, using Affymetrix GeneChip microarrays, with quantitative PCR verification in many cases, categorizing their actions as agonist, antagonist, or partial agonist/antagonist. Analysis of gene stimulation and inhibition by the SERMs trans-hydroxytamoxifen (TOT) and raloxifene (Ral) or ICI 182,780 (ICI) and by estradiol (E2) in estrogen receptor-containing MCF-7 human breast cancer cells revealed that (a) TOT was the most E2-like of the three compounds, (b) all three compounds either partially or fully antagonized the action of E2 on most genes, with the order of antagonist activity being ICI > Ral > TOT, (c) TOT and Ral, but not ICI, displayed partial agonist/partial antagonist activity on a number of E2-regulated genes, (d) several stimulatory cell cycle-related genes were down-regulated exclusively by ICI, (e) the estrogen-like activity of Ral nearly always overlapped with that of TOT, indicating that Ral has little unique agonist activity different from that of TOT, and (f) some genes were specifically up-regulated by TOT but not Ral, ICI, or E2. Hence, gene expression profiling can discern fundamental differences among SERMs and provides insight into the distinct biologies of TOT, Ral, and ICI in breast cancer.

Standard name | GOLDRATH_ANTIGEN_RESPONSE
Systematic name | M11884
Organism | Mus musculus
PMID | 15548615
Authors | Goldrath AW,Luckey CJ,Park R,Benoist C,Mathis D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated at the peak of an antigen response of naive CD8+ [GeneID=925;926] T-cells.
Full description | Naive T cells proliferate independently of cognate antigen when introduced into lymphopenic hosts. Lymphopenia-induced proliferation depends on low-affinity MHC/self-peptide complexes and on IL-7. To elucidate the intracellular signals mediating this proliferation, we analyzed changes in gene expression in naive CD8+ T cells at different times after their transfer into a lymphopenic environment. The genes induced in response to lymphopenia were largely an attenuated subset of those turned up by full antigenic stimulation, including genes related to cell cycling, whereas excluding genes specifically associated with effector activity. After the initial phase of proliferation in an empty compartment, the naive T cells adopted a stable pattern of gene expression similar to that of antigen-experienced memory cells. Thus, T cells proliferating in lymphopenic hosts do not exhibit a unique gene-expression profile, instead relying on traditional signals for this antigen-independent proliferation; this process ultimately results in differentiation to authentic memory cells.

Standard name | ICHIBA_GRAFT_VERSUS_HOST_DISEASE_D7_UP
Systematic name | M5487
Organism | Mus musculus
PMID | 12663442
Authors | Ichiba T,Teshima T,Kuick R,Misek DE,Liu C,Takada Y,Maeda Y,Reddy P,Williams DL,Hanash SM,Ferrara JL
Category | C2
Sub-category | CGP
Brief description | Hepatic graft versus host disease (GVHD), day 7: up-regulated in allogeneic vs syngeneic bone marrow transplant.
Full description | The liver, skin, and gastrointestinal tract are major target organs of acute graft-versus-host disease (GVHD), the major complication of allogeneic bone marrow transplantation (BMT). In order to gain a better understanding of acute GVHD in the liver, we compared the gene expression profiles of livers after experimental allogeneic and syngeneic BMT using oligonucleotide microarray. At 35 days after allogeneic BMT when hepatic GVHD was histologically evident, genes related to cellular effectors and acute-phase proteins were up-regulated, whereas genes largely related to metabolism and endocrine function were down-regulated. At day 7 after BMT before the development of histologic changes in the liver, interferon gamma (IFN-gamma)-inducible genes, major histocompatibility (MHC) class II molecules, and genes related to leukocyte trafficking had been up-regulated. Immunohistochemistry demonstrated that expression of IFN-gamma protein itself was increased in the spleen but not in hepatic tissue. These results suggest that the increased expression of genes associated with the attraction and activation of donor T cells induced by IFN-gamma early after BMT is important in the initiation of hepatic GVHD in this model and provide new potential molecular targets for early detection and intervention of acute GVHD.

Standard name | ICHIBA_GRAFT_VERSUS_HOST_DISEASE_D7_DN
Systematic name | M19469
Organism | Mus musculus
PMID | 12663442
Authors | Ichiba T,Teshima T,Kuick R,Misek DE,Liu C,Takada Y,Maeda Y,Reddy P,Williams DL,Hanash SM,Ferrara JL
Category | C2
Sub-category | CGP
Brief description | Hepatic graft versus host disease (GVHD), day 7: down-regulated in allogeneic vs syngeneic bone marrow transplant.
Full description | The liver, skin, and gastrointestinal tract are major target organs of acute graft-versus-host disease (GVHD), the major complication of allogeneic bone marrow transplantation (BMT). In order to gain a better understanding of acute GVHD in the liver, we compared the gene expression profiles of livers after experimental allogeneic and syngeneic BMT using oligonucleotide microarray. At 35 days after allogeneic BMT when hepatic GVHD was histologically evident, genes related to cellular effectors and acute-phase proteins were up-regulated, whereas genes largely related to metabolism and endocrine function were down-regulated. At day 7 after BMT before the development of histologic changes in the liver, interferon gamma (IFN-gamma)-inducible genes, major histocompatibility (MHC) class II molecules, and genes related to leukocyte trafficking had been up-regulated. Immunohistochemistry demonstrated that expression of IFN-gamma protein itself was increased in the spleen but not in hepatic tissue. These results suggest that the increased expression of genes associated with the attraction and activation of donor T cells induced by IFN-gamma early after BMT is important in the initiation of hepatic GVHD in this model and provide new potential molecular targets for early detection and intervention of acute GVHD.

Standard name | ICHIBA_GRAFT_VERSUS_HOST_DISEASE_35D_UP
Systematic name | M19618
Organism | Mus musculus
PMID | 12663442
Authors | Ichiba T,Teshima T,Kuick R,Misek DE,Liu C,Takada Y,Maeda Y,Reddy P,Williams DL,Hanash SM,Ferrara JL
Category | C2
Sub-category | CGP
Brief description | Hepatic graft versus host disease (GVHD), day 35: genes up-regulated in allogeneic vs syngeneic bone marrow transplant.
Full description | The liver, skin, and gastrointestinal tract are major target organs of acute graft-versus-host disease (GVHD), the major complication of allogeneic bone marrow transplantation (BMT). In order to gain a better understanding of acute GVHD in the liver, we compared the gene expression profiles of livers after experimental allogeneic and syngeneic BMT using oligonucleotide microarray. At 35 days after allogeneic BMT when hepatic GVHD was histologically evident, genes related to cellular effectors and acute-phase proteins were up-regulated, whereas genes largely related to metabolism and endocrine function were down-regulated. At day 7 after BMT before the development of histologic changes in the liver, interferon gamma (IFN-gamma)-inducible genes, major histocompatibility (MHC) class II molecules, and genes related to leukocyte trafficking had been up-regulated. Immunohistochemistry demonstrated that expression of IFN-gamma protein itself was increased in the spleen but not in hepatic tissue. These results suggest that the increased expression of genes associated with the attraction and activation of donor T cells induced by IFN-gamma early after BMT is important in the initiation of hepatic GVHD in this model and provide new potential molecular targets for early detection and intervention of acute GVHD.

Standard name | ICHIBA_GRAFT_VERSUS_HOST_DISEASE_35D_DN
Systematic name | M13337
Organism | Mus musculus
PMID | 12663442
Authors | Ichiba T,Teshima T,Kuick R,Misek DE,Liu C,Takada Y,Maeda Y,Reddy P,Williams DL,Hanash SM,Ferrara JL
Category | C2
Sub-category | CGP
Brief description | Hepatic graft versus host disease (GVHD), day 35: genes down-regulated in allogeneic vs syngeneic bone marrow transplant.
Full description | The liver, skin, and gastrointestinal tract are major target organs of acute graft-versus-host disease (GVHD), the major complication of allogeneic bone marrow transplantation (BMT). In order to gain a better understanding of acute GVHD in the liver, we compared the gene expression profiles of livers after experimental allogeneic and syngeneic BMT using oligonucleotide microarray. At 35 days after allogeneic BMT when hepatic GVHD was histologically evident, genes related to cellular effectors and acute-phase proteins were up-regulated, whereas genes largely related to metabolism and endocrine function were down-regulated. At day 7 after BMT before the development of histologic changes in the liver, interferon gamma (IFN-gamma)-inducible genes, major histocompatibility (MHC) class II molecules, and genes related to leukocyte trafficking had been up-regulated. Immunohistochemistry demonstrated that expression of IFN-gamma protein itself was increased in the spleen but not in hepatic tissue. These results suggest that the increased expression of genes associated with the attraction and activation of donor T cells induced by IFN-gamma early after BMT is important in the initiation of hepatic GVHD in this model and provide new potential molecular targets for early detection and intervention of acute GVHD.

Standard name | LINDSTEDT_DENDRITIC_CELL_MATURATION_A
Systematic name | M17033
Organism | Homo sapiens
PMID | 12356685
Authors | Lindstedt M,Johansson-Lindbom B,Borrebaeck CA
Category | C2
Sub-category | CGP
Brief description | Maturation of monocyte-derived dendritic cells (DC) in response to inflammatory stimuli: genes up-regulated only at 8 hr after the stimulation (cluster A).
Full description | Maturation of dendritic cells (DC) serves a deterministic role in the link between innate and adaptive immunity, constituting a checkpoint with regard to whether responses from the lymphocyte compartment shall be raised and what class of response is needed to protect the host against invading pathogens. Since DC have not been shown to possess mechanisms such as gene recombination or somatic mutation for generating a diverse repertoire of antigen-recognition receptors, it is unlikely that these leukocytes can intrinsically respond to all conceivable molecules present in our environment. In the present study, we have therefore determined how mediators of the inflammatory response regulate global gene transcription in DC. The data represent an extensive and time-ordered reprogramming of the DC during their course of maturation, involving genes encoding proteins that regulate responses of both innate cells and lymphocytes. This transcriptional reorganization may reflect the effect of in vivo released inflammatory mediators induced by endogenous or pathogenic stimulation.

Standard name | LINDSTEDT_DENDRITIC_CELL_MATURATION_B
Systematic name | M12480
Organism | Homo sapiens
PMID | 12356685
Authors | Lindstedt M,Johansson-Lindbom B,Borrebaeck CA
Category | C2
Sub-category | CGP
Brief description | Maturation of monocyte-derived dendritic cells (DC) in response to inflammatory stimuli: genes up-regulated both at 8 hr and 48 hr after the stimulation (cluster B).
Full description | Maturation of dendritic cells (DC) serves a deterministic role in the link between innate and adaptive immunity, constituting a checkpoint with regard to whether responses from the lymphocyte compartment shall be raised and what class of response is needed to protect the host against invading pathogens. Since DC have not been shown to possess mechanisms such as gene recombination or somatic mutation for generating a diverse repertoire of antigen-recognition receptors, it is unlikely that these leukocytes can intrinsically respond to all conceivable molecules present in our environment. In the present study, we have therefore determined how mediators of the inflammatory response regulate global gene transcription in DC. The data represent an extensive and time-ordered reprogramming of the DC during their course of maturation, involving genes encoding proteins that regulate responses of both innate cells and lymphocytes. This transcriptional reorganization may reflect the effect of in vivo released inflammatory mediators induced by endogenous or pathogenic stimulation.

Standard name | LINDSTEDT_DENDRITIC_CELL_MATURATION_C
Systematic name | M9210
Organism | Homo sapiens
PMID | 12356685
Authors | Lindstedt M,Johansson-Lindbom B,Borrebaeck CA
Category | C2
Sub-category | CGP
Brief description | Maturation of monocyte-derived dendritic cells (DC) in response to inflammatory stimuli: genes up-regulated only at 48 hr after the stimulation (cluster C).
Full description | Maturation of dendritic cells (DC) serves a deterministic role in the link between innate and adaptive immunity, constituting a checkpoint with regard to whether responses from the lymphocyte compartment shall be raised and what class of response is needed to protect the host against invading pathogens. Since DC have not been shown to possess mechanisms such as gene recombination or somatic mutation for generating a diverse repertoire of antigen-recognition receptors, it is unlikely that these leukocytes can intrinsically respond to all conceivable molecules present in our environment. In the present study, we have therefore determined how mediators of the inflammatory response regulate global gene transcription in DC. The data represent an extensive and time-ordered reprogramming of the DC during their course of maturation, involving genes encoding proteins that regulate responses of both innate cells and lymphocytes. This transcriptional reorganization may reflect the effect of in vivo released inflammatory mediators induced by endogenous or pathogenic stimulation.

Standard name | LINDSTEDT_DENDRITIC_CELL_MATURATION_D
Systematic name | M3848
Organism | Homo sapiens
PMID | 12356685
Authors | Lindstedt M,Johansson-Lindbom B,Borrebaeck CA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during the course of maturation of monocyte-derived dendritic cells (DC) in response to inflammatory stimuli (cluster D).
Full description | Maturation of dendritic cells (DC) serves a deterministic role in the link between innate and adaptive immunity, constituting a checkpoint with regard to whether responses from the lymphocyte compartment shall be raised and what class of response is needed to protect the host against invading pathogens. Since DC have not been shown to possess mechanisms such as gene recombination or somatic mutation for generating a diverse repertoire of antigen-recognition receptors, it is unlikely that these leukocytes can intrinsically respond to all conceivable molecules present in our environment. In the present study, we have therefore determined how mediators of the inflammatory response regulate global gene transcription in DC. The data represent an extensive and time-ordered reprogramming of the DC during their course of maturation, involving genes encoding proteins that regulate responses of both innate cells and lymphocytes. This transcriptional reorganization may reflect the effect of in vivo released inflammatory mediators induced by endogenous or pathogenic stimulation.

Standard name | MARSHALL_VIRAL_INFECTION_RESPONSE_UP
Systematic name | M1881
Organism | Mus musculus
PMID | 15831586
Authors | Marshall DR,Olivas E,Andreansky S,La Gruta NL,Neale GA,Gutierrez A,Wichlan DG,Wingo S,Cheng C,Doherty PC,Turner SJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the influenza-specific CD8+ [GeneID=925] T lymphocytes from bronchoalveolar lavage (BAL) compared to those from spleen.
Full description | The restriction of influenza A virus replication to mouse respiratory epithelium means that this host response is anatomically compartmentalized, on the one hand, to sites of T cell stimulation and proliferation in the secondary lymphoid tissue and, on the other hand, to the site of effector T cell function and pathology in the pneumonic lung. Thus, it is hardly surprising that virus-specific CD8(+) T cells recovered by bronchoalveolar lavage (BAL) from the infected respiratory tract seem more activated in terms of both cytolytic activity and cytokine production than those cells isolated from the spleen. The present analysis uses Affymetrix microarray technology to compare profiles of gene expression in these two lineage-related, yet anatomically separate, lymphocyte populations. Ninety differentially expressed genes were identified for influenza-specific CD8(+)D(b)NP(366)(+) T cells obtained directly ex vivo by BAL or spleen disruption, with nine genes being further analyzed by quantitative, real-time PCR at the population level. Integrin alphaE, for example, was shown by Affymetrix and real-time mRNA analyses and then by single-cell PCR and protein staining to be present at a much higher prevalence on the BAL CD8(+)D(b)NP(366)(+) set. The unpredicted finding, however, was that mRNA expression for 75% of the 90 genes was lower in T cells from the BAL than from the spleen. Apparently, the localization of virus-specific CD8(+) T cells to the site of virus-induced pathology is associated with a narrowing, or focusing, of gene expression that favors enhanced effector function in the damaged, high-antigen load environment of the pneumonic lung.

Standard name | MARSHALL_VIRAL_INFECTION_RESPONSE_DN
Systematic name | M1882
Organism | Mus musculus
PMID | 15831586
Authors | Marshall DR,Olivas E,Andreansky S,La Gruta NL,Neale GA,Gutierrez A,Wichlan DG,Wingo S,Cheng C,Doherty PC,Turner SJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the influenza-specific CD8+ [GeneID=925] T lymphocytes from bronchoalveolar lavage (BAL) compared to those from spleen.
Full description | The restriction of influenza A virus replication to mouse respiratory epithelium means that this host response is anatomically compartmentalized, on the one hand, to sites of T cell stimulation and proliferation in the secondary lymphoid tissue and, on the other hand, to the site of effector T cell function and pathology in the pneumonic lung. Thus, it is hardly surprising that virus-specific CD8(+) T cells recovered by bronchoalveolar lavage (BAL) from the infected respiratory tract seem more activated in terms of both cytolytic activity and cytokine production than those cells isolated from the spleen. The present analysis uses Affymetrix microarray technology to compare profiles of gene expression in these two lineage-related, yet anatomically separate, lymphocyte populations. Ninety differentially expressed genes were identified for influenza-specific CD8(+)D(b)NP(366)(+) T cells obtained directly ex vivo by BAL or spleen disruption, with nine genes being further analyzed by quantitative, real-time PCR at the population level. Integrin alphaE, for example, was shown by Affymetrix and real-time mRNA analyses and then by single-cell PCR and protein staining to be present at a much higher prevalence on the BAL CD8(+)D(b)NP(366)(+) set. The unpredicted finding, however, was that mRNA expression for 75% of the 90 genes was lower in T cells from the BAL than from the spleen. Apparently, the localization of virus-specific CD8(+) T cells to the site of virus-induced pathology is associated with a narrowing, or focusing, of gene expression that favors enhanced effector function in the damaged, high-antigen load environment of the pneumonic lung.

Standard name | MARTINELLI_IMMATURE_NEUTROPHIL_UP
Systematic name | M14418
Organism | Homo sapiens
PMID | 15302890
Authors | Martinelli S,Urosevic M,Daryadel A,Oberholzer PA,Baumann C,Fey MF,Dummer R,Simon HU,Yousefi S
Category | C2
Sub-category | CGP
Brief description | Neutrophil-specific genes up-regulated in comparison of immature with mature neutrophils.
Full description | Interferons (IFNs) are cytokines that possess potent anti-viral and immunoregulatory activities. In contrast, their potential role(s) in anti-bacterial defense and neutrophil activation mechanisms is less well explored. By comparing gene expression patterns between immature and mature human neutrophils, we obtained evidence that intracellular proteases and other anti-bacterial proteins are produced at earlier stages of maturation, whereas the genes for receptors and signaling molecules required for the release of these effector molecules are preferentially induced during terminal differentiation. For instance, mature neutrophils strongly expressed genes that increase their responses to type I and type II IFNs. Interestingly, granulocyte/macrophage colony-stimulating factor was identified as a repressor of IFN signaling components and consequently of IFN-responsive genes. Both IFN-alpha and IFN-gamma induced strong tyrosine phosphorylation of STAT1 in mature but not in immature neutrophils. Functional in vitro studies suggested that IFNs act as priming factors on mature neutrophils, allowing the formation of extracellular traps upon subsequent stimulation with complement factor 5a (C5a). In contrast, both IFN-alpha and IFN-gamma had only little capacity to prime immature cells in this system. Moreover, both IFNs did not have significant anti-proliferative effects on immature neutrophils. These data contribute to our understanding regarding changes of gene expression during neutrophil differentiation and IFN-mediated anti-bacterial defense mechanisms.

Standard name | MARTINELLI_IMMATURE_NEUTROPHIL_DN
Systematic name | M5149
Organism | Homo sapiens
PMID | 15302890
Authors | Martinelli S,Urosevic M,Daryadel A,Oberholzer PA,Baumann C,Fey MF,Dummer R,Simon HU,Yousefi S
Category | C2
Sub-category | CGP
Brief description | Neutrophil-specific genes down-regulated in comparison of immature with mature neutrophils.
Full description | Interferons (IFNs) are cytokines that possess potent anti-viral and immunoregulatory activities. In contrast, their potential role(s) in anti-bacterial defense and neutrophil activation mechanisms is less well explored. By comparing gene expression patterns between immature and mature human neutrophils, we obtained evidence that intracellular proteases and other anti-bacterial proteins are produced at earlier stages of maturation, whereas the genes for receptors and signaling molecules required for the release of these effector molecules are preferentially induced during terminal differentiation. For instance, mature neutrophils strongly expressed genes that increase their responses to type I and type II IFNs. Interestingly, granulocyte/macrophage colony-stimulating factor was identified as a repressor of IFN signaling components and consequently of IFN-responsive genes. Both IFN-alpha and IFN-gamma induced strong tyrosine phosphorylation of STAT1 in mature but not in immature neutrophils. Functional in vitro studies suggested that IFNs act as priming factors on mature neutrophils, allowing the formation of extracellular traps upon subsequent stimulation with complement factor 5a (C5a). In contrast, both IFN-alpha and IFN-gamma had only little capacity to prime immature cells in this system. Moreover, both IFNs did not have significant anti-proliferative effects on immature neutrophils. These data contribute to our understanding regarding changes of gene expression during neutrophil differentiation and IFN-mediated anti-bacterial defense mechanisms.

Standard name | NICK_RESPONSE_TO_PROC_TREATMENT_DN
Systematic name | M8801
Organism | Homo sapiens
PMID | 15339848
Authors | Nick JA,Coldren CD,Geraci MW,Poch KR,Fouty BW,O'Brien J,Gruber M,Zarini S,Murphy RC,Kuhn K,Richter D,Kast KR,Abraham E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in neutrophils upon treatment with activated protein C (PROC) [GeneID=5624] of pulmonary inflammation induced by bacterial lipopolysaccharide (LPS).
Full description | Recombinant human activated protein C (rhAPC) is a natural anticoagulant with potentially important anti-inflammatory properties. In humans with severe sepsis, rhAPC treatment reduces mortality, but mechanisms responsible have not been well characterized. Accumulation of activated neutrophils in the lungs and other organs during severe infection contributes to sepsis-induced organ dysfunction, including acute inflammatory lung injury. Because neutrophils express an APC receptor, we hypothesized that immunomodulatory effects of rhAPC occur, in part, via modulation of neutrophil responses. To examine this issue, we performed a double-blinded, placebo-controlled study of rhAPC in a human model of endotoxin-induced pulmonary inflammation. Administration of rhAPC significantly reduced leukocyte accumulation to the airspaces, independent of pulmonary cytokine or chemokine release. Neutrophils recovered from bronchoalveolar lavage fluid of volunteers receiving rhAPC demonstrated decreased chemotaxis ex vivo. Decreased neutrophil chemotaxis following exposure to rhAPC was confirmed in vitro. No differences were detected in gene expression, kinase activation, cytokine release, cell survival, or apoptosis of neutrophils recovered in the presence or absence of rhAPC. These studies demonstrate that rhAPC reduces both endotoxin-induced accumulation of leukocytes in the airspaces and neutrophil chemotaxis. These rhAPC-induced effects on neutrophil function may represent a mechanism by which rhAPC improves survival in patients with sepsis.

Standard name | NUTT_GBM_VS_AO_GLIOMA_UP
Systematic name | M6921
Organism | Homo sapiens
PMID | 12670911
Authors | Nutt CL,Mani DR,Betensky RA,Tamayo P,Cairncross JG,Ladd C,Pohl U,Hartmann C,McLaughlin ME,Batchelor TT,Black PM,von Deimling A,Pomeroy SL,Golub TR,Louis DN
Category | C2
Sub-category | CGP
Brief description | Top 50 marker genes for glioblastoma multiforme (GBM), a class of high grade glioma.
Full description | In modern clinical neuro-oncology, histopathological diagnosis affects therapeutic decisions and prognostic estimation more than any other variable. Among high-grade gliomas, histologically classic glioblastomas and anaplastic oligodendrogliomas follow markedly different clinical courses. Unfortunately, many malignant gliomas are diagnostically challenging; these nonclassic lesions are difficult to classify by histological features, generating considerable interobserver variability and limited diagnostic reproducibility. The resulting tentative pathological diagnoses create significant clinical confusion. We investigated whether gene expression profiling, coupled with class prediction methodology, could be used to classify high-grade gliomas in a manner more objective, explicit, and consistent than standard pathology. Microarray analysis was used to determine the expression of approximately 12000 genes in a set of 50 gliomas, 28 glioblastomas and 22 anaplastic oligodendrogliomas. Supervised learning approaches were used to build a two-class prediction model based on a subset of 14 glioblastomas and 7 anaplastic oligodendrogliomas with classic histology. A 20-feature k-nearest neighbor model correctly classified 18 of the 21 classic cases in leave-one-out cross-validation when compared with pathological diagnoses. This model was then used to predict the classification of clinically common, histologically nonclassic samples. When tumors were classified according to pathology, the survival of patients with nonclassic glioblastoma and nonclassic anaplastic oligodendroglioma was not significantly different (P = 0.19). However, class distinctions according to the model were significantly associated with survival outcome (P = 0.05). This class prediction model was capable of classifying high-grade, nonclassic glial tumors objectively and reproducibly. Moreover, the model provided a more accurate predictor of prognosis in these nonclassic lesions than did pathological classification. These data suggest that class prediction models, based on defined molecular profiles, classify diagnostically challenging malignant gliomas in a manner that better correlates with clinical outcome than does standard pathology.

Standard name | NUTT_GBM_VS_AO_GLIOMA_DN
Systematic name | M2577
Organism | Homo sapiens
PMID | 12670911
Authors | Nutt CL,Mani DR,Betensky RA,Tamayo P,Cairncross JG,Ladd C,Pohl U,Hartmann C,McLaughlin ME,Batchelor TT,Black PM,von Deimling A,Pomeroy SL,Golub TR,Louis DN
Category | C2
Sub-category | CGP
Brief description | Top 50 marker genes for anaplastic oligodendroglioma (AO), a class of high grade glioma.
Full description | In modern clinical neuro-oncology, histopathological diagnosis affects therapeutic decisions and prognostic estimation more than any other variable. Among high-grade gliomas, histologically classic glioblastomas and anaplastic oligodendrogliomas follow markedly different clinical courses. Unfortunately, many malignant gliomas are diagnostically challenging; these nonclassic lesions are difficult to classify by histological features, generating considerable interobserver variability and limited diagnostic reproducibility. The resulting tentative pathological diagnoses create significant clinical confusion. We investigated whether gene expression profiling, coupled with class prediction methodology, could be used to classify high-grade gliomas in a manner more objective, explicit, and consistent than standard pathology. Microarray analysis was used to determine the expression of approximately 12000 genes in a set of 50 gliomas, 28 glioblastomas and 22 anaplastic oligodendrogliomas. Supervised learning approaches were used to build a two-class prediction model based on a subset of 14 glioblastomas and 7 anaplastic oligodendrogliomas with classic histology. A 20-feature k-nearest neighbor model correctly classified 18 of the 21 classic cases in leave-one-out cross-validation when compared with pathological diagnoses. This model was then used to predict the classification of clinically common, histologically nonclassic samples. When tumors were classified according to pathology, the survival of patients with nonclassic glioblastoma and nonclassic anaplastic oligodendroglioma was not significantly different (P = 0.19). However, class distinctions according to the model were significantly associated with survival outcome (P = 0.05). This class prediction model was capable of classifying high-grade, nonclassic glial tumors objectively and reproducibly. Moreover, the model provided a more accurate predictor of prognosis in these nonclassic lesions than did pathological classification. These data suggest that class prediction models, based on defined molecular profiles, classify diagnostically challenging malignant gliomas in a manner that better correlates with clinical outcome than does standard pathology.

Standard name | PARK_APL_PATHOGENESIS_UP
Systematic name | M3993
Organism | Homo sapiens
PMID | 12893766
Authors | Park DJ,Vuong PT,de Vos S,Douer D,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in U937 cells (acute promyelocytic leukemia, APL) expressing RARA [GeneID=5914] fused with either PML or PLZF [GeneID=5371;7704].
Full description | Acute promyelocytic leukemia (APL) is associated with chromosomal translocations involving retinoic acid receptor alpha (RAR alpha) and its fusion partners including promyelocytic leukemia (PML) and promyelocytic leukemia zinc finger (PLZF). Using oligonucleotide arrays, we examined changes in global gene expression mediated by the ectopic expression of either PML/RAR alpha (retinoid-sensitive) or PLZF/RAR alpha (retinoid-resistant) in U937 cells. Of more than 5000 genes analyzed, 16 genes were commonly up-regulated, and 57 genes were down-regulated by both fusion proteins suggesting their role in the APL phenotype. In our APL model, for example, TNFAIP2, TNFR2, ELF4, RAR gamma, and HoxA1 were down-regulated by both fusion proteins in the absence of retinoic acid (RA). RA strongly up-regulated these genes in PML/RAR alpha, but not in PLZF/RAR alpha expressing U937 cells. Expression studies in NB4, retinoid-resistant NB4-R2, normal human CD34+ cells, and APL patient samples strongly suggest their role in the regulation of granulocytic differentiation. Furthermore, combined treatment with tumor necrosis factor alpha (TNF alpha) and RA synergistically enhanced granulocytic differentiation in NB4 cells but not in NB4-R2 cells. Our data indicate that APL pathogenesis and retinoid-induced granulocytic differentiation of APL cells involve genes in the cell death pathway, and that cooperation between the RA and TNFalpha signaling pathways exists. Targeting both the retinoid-dependent differentiation and the cell death pathways may improve leukemic therapy, especially in retinoid-resistant acute myeloid leukemia.

Standard name | PARK_APL_PATHOGENESIS_DN
Systematic name | M2541
Organism | Homo sapiens
PMID | 12893766
Authors | Park DJ,Vuong PT,de Vos S,Douer D,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in U937 cells (acute promyelocytic leukemia, APL) expressing RARA [GeneID=5914] fused with either PML or PLZF [GeneID=5371;7704].
Full description | Acute promyelocytic leukemia (APL) is associated with chromosomal translocations involving retinoic acid receptor alpha (RAR alpha) and its fusion partners including promyelocytic leukemia (PML) and promyelocytic leukemia zinc finger (PLZF). Using oligonucleotide arrays, we examined changes in global gene expression mediated by the ectopic expression of either PML/RAR alpha (retinoid-sensitive) or PLZF/RAR alpha (retinoid-resistant) in U937 cells. Of more than 5000 genes analyzed, 16 genes were commonly up-regulated, and 57 genes were down-regulated by both fusion proteins suggesting their role in the APL phenotype. In our APL model, for example, TNFAIP2, TNFR2, ELF4, RAR gamma, and HoxA1 were down-regulated by both fusion proteins in the absence of retinoic acid (RA). RA strongly up-regulated these genes in PML/RAR alpha, but not in PLZF/RAR alpha expressing U937 cells. Expression studies in NB4, retinoid-resistant NB4-R2, normal human CD34+ cells, and APL patient samples strongly suggest their role in the regulation of granulocytic differentiation. Furthermore, combined treatment with tumor necrosis factor alpha (TNF alpha) and RA synergistically enhanced granulocytic differentiation in NB4 cells but not in NB4-R2 cells. Our data indicate that APL pathogenesis and retinoid-induced granulocytic differentiation of APL cells involve genes in the cell death pathway, and that cooperation between the RA and TNFalpha signaling pathways exists. Targeting both the retinoid-dependent differentiation and the cell death pathways may improve leukemic therapy, especially in retinoid-resistant acute myeloid leukemia.

Standard name | PARK_TRETINOIN_RESPONSE
Systematic name | M15935
Organism | Homo sapiens
PMID | 12893766
Authors | Park DJ,Vuong PT,de Vos S,Douer D,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in U937 cells (acute promyelocytic leukemia, APL) by tretinoin (ATRA) [PubChem=444795].
Full description | Acute promyelocytic leukemia (APL) is associated with chromosomal translocations involving retinoic acid receptor alpha (RAR alpha) and its fusion partners including promyelocytic leukemia (PML) and promyelocytic leukemia zinc finger (PLZF). Using oligonucleotide arrays, we examined changes in global gene expression mediated by the ectopic expression of either PML/RAR alpha (retinoid-sensitive) or PLZF/RAR alpha (retinoid-resistant) in U937 cells. Of more than 5000 genes analyzed, 16 genes were commonly up-regulated, and 57 genes were down-regulated by both fusion proteins suggesting their role in the APL phenotype. In our APL model, for example, TNFAIP2, TNFR2, ELF4, RAR gamma, and HoxA1 were down-regulated by both fusion proteins in the absence of retinoic acid (RA). RA strongly up-regulated these genes in PML/RAR alpha, but not in PLZF/RAR alpha expressing U937 cells. Expression studies in NB4, retinoid-resistant NB4-R2, normal human CD34+ cells, and APL patient samples strongly suggest their role in the regulation of granulocytic differentiation. Furthermore, combined treatment with tumor necrosis factor alpha (TNF alpha) and RA synergistically enhanced granulocytic differentiation in NB4 cells but not in NB4-R2 cells. Our data indicate that APL pathogenesis and retinoid-induced granulocytic differentiation of APL cells involve genes in the cell death pathway, and that cooperation between the RA and TNFalpha signaling pathways exists. Targeting both the retinoid-dependent differentiation and the cell death pathways may improve leukemic therapy, especially in retinoid-resistant acute myeloid leukemia.

Standard name | PARK_TRETINOIN_RESPONSE_AND_PML_RARA_FUSION
Systematic name | M19270
Organism | Homo sapiens
PMID | 12893766
Authors | Park DJ,Vuong PT,de Vos S,Douer D,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by tretinoin (ATRA) [PubChem=444795] in U937 cells (acute promyelocytic leukemia, APL) made sensitive to the drug by expression of the PML-RARA fusion [GeneID=5371;5914].
Full description | Acute promyelocytic leukemia (APL) is associated with chromosomal translocations involving retinoic acid receptor alpha (RAR alpha) and its fusion partners including promyelocytic leukemia (PML) and promyelocytic leukemia zinc finger (PLZF). Using oligonucleotide arrays, we examined changes in global gene expression mediated by the ectopic expression of either PML/RAR alpha (retinoid-sensitive) or PLZF/RAR alpha (retinoid-resistant) in U937 cells. Of more than 5000 genes analyzed, 16 genes were commonly up-regulated, and 57 genes were down-regulated by both fusion proteins suggesting their role in the APL phenotype. In our APL model, for example, TNFAIP2, TNFR2, ELF4, RAR gamma, and HoxA1 were down-regulated by both fusion proteins in the absence of retinoic acid (RA). RA strongly up-regulated these genes in PML/RAR alpha, but not in PLZF/RAR alpha expressing U937 cells. Expression studies in NB4, retinoid-resistant NB4-R2, normal human CD34+ cells, and APL patient samples strongly suggest their role in the regulation of granulocytic differentiation. Furthermore, combined treatment with tumor necrosis factor alpha (TNF alpha) and RA synergistically enhanced granulocytic differentiation in NB4 cells but not in NB4-R2 cells. Our data indicate that APL pathogenesis and retinoid-induced granulocytic differentiation of APL cells involve genes in the cell death pathway, and that cooperation between the RA and TNFalpha signaling pathways exists. Targeting both the retinoid-dependent differentiation and the cell death pathways may improve leukemic therapy, especially in retinoid-resistant acute myeloid leukemia.

Standard name | PARK_TRETINOIN_RESPONSE_AND_RARA_PLZF_FUSION
Systematic name | M11798
Organism | Homo sapiens
PMID | 12893766
Authors | Park DJ,Vuong PT,de Vos S,Douer D,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by tretinoin (ATRA) [PubChem=444795] in U937 cells (acute promyelocytic leukemia, APL) made resistant to the drug by expression of the PLZF-RARA fusion [GeneID=7704, 5914].
Full description | Acute promyelocytic leukemia (APL) is associated with chromosomal translocations involving retinoic acid receptor alpha (RAR alpha) and its fusion partners including promyelocytic leukemia (PML) and promyelocytic leukemia zinc finger (PLZF). Using oligonucleotide arrays, we examined changes in global gene expression mediated by the ectopic expression of either PML/RAR alpha (retinoid-sensitive) or PLZF/RAR alpha (retinoid-resistant) in U937 cells. Of more than 5000 genes analyzed, 16 genes were commonly up-regulated, and 57 genes were down-regulated by both fusion proteins suggesting their role in the APL phenotype. In our APL model, for example, TNFAIP2, TNFR2, ELF4, RAR gamma, and HoxA1 were down-regulated by both fusion proteins in the absence of retinoic acid (RA). RA strongly up-regulated these genes in PML/RAR alpha, but not in PLZF/RAR alpha expressing U937 cells. Expression studies in NB4, retinoid-resistant NB4-R2, normal human CD34+ cells, and APL patient samples strongly suggest their role in the regulation of granulocytic differentiation. Furthermore, combined treatment with tumor necrosis factor alpha (TNF alpha) and RA synergistically enhanced granulocytic differentiation in NB4 cells but not in NB4-R2 cells. Our data indicate that APL pathogenesis and retinoid-induced granulocytic differentiation of APL cells involve genes in the cell death pathway, and that cooperation between the RA and TNFalpha signaling pathways exists. Targeting both the retinoid-dependent differentiation and the cell death pathways may improve leukemic therapy, especially in retinoid-resistant acute myeloid leukemia.

Standard name | ZHANG_INTERFERON_RESPONSE
Systematic name | M3559
Organism | Homo sapiens
PMID | 15619625
Authors | Zhang W,Yang H,Kong X,Mohapatra S,San Juan-Vergara H,Hellermann G,Behera S,Singam R,Lockey RF,Mohapatra SS
Category | C2
Sub-category | CGP
Brief description | Interferon-inducible genes up-regulated in A549 cells (lung cancer) infected with a respiratory syncytial virus (RSV) that had its NS1 [GeneID=1494468] gene knocked down by RNAi.
Full description | Respiratory syncytial virus (RSV) infection is one of the major causes of respiratory tract infection for which no vaccine or antiviral treatment is available. The RSV NS1 protein seems to antagonize the host interferon (IFN) response; however, its mechanism is unknown. Here, we used a plasmid-borne small interfering RNA targeting the NS1 gene (siNS1) to examine the role of NS1 in modulating RSV infection. RSV replication was reduced in A549 cells, but not IFN-deficient Vero cells, transfected with siNS1. siNS1 induced upregulated expression of IFN-beta and IFN-inducible genes in A549 cells. siNS1-transfected human dendritic cells, upon RSV infection, produced elevated type-1 IFN and induced differentiation of naive CD4+ T cells to T helper type 1 (TH1) cells. Mice treated intranasally with siNS1 nanoparticles before or after infection with RSV showed substantially decreased virus titers in the lung and decreased inflammation and airway reactivity compared to controls. Thus, siNS1 nanoparticles may provide an effective inhibition of RSV infection in humans.

Standard name | WU_ALZHEIMER_DISEASE_UP
Systematic name | M17609
Organism | Homo sapiens
PMID | 16116430
Authors | Wu Z,Guo H,Chow N,Sallstrom J,Bell RD,Deane R,Brooks AI,Kanagala S,Rubio A,Sagare A,Liu D,Li F,Armstrong D,Gasiewicz T,Zidovetzki R,Song X,Hofman F,Zlokovic BV
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in brain endothelial cells from patients with Alzheimer disease.
Full description | Neurovascular dysfunction substantially contributes to Alzheimer disease. Here, we show that transcriptional profiling of human brain endothelial cells (BECs) defines a subset of genes whose expression is age-independent but is considerably altered in Alzheimer disease, including the homeobox gene MEOX2 (also known as GAX), a regulator of vascular differentiation, whose expression is low in Alzheimer disease. By using viral-mediated MEOX2 gene silencing and transfer, we show that restoring expression of the protein it encodes, GAX, in BECs from individuals with Alzheimer disease stimulates angiogenesis, transcriptionally suppresses AFX1 forkhead transcription factor-mediated apoptosis and increases the levels of a major amyloid-beta peptide (Abeta) clearance receptor, the low-density lipoprotein receptor-related protein 1 (LRP), at the blood-brain barrier. In mice, deletion of Meox2 (also known as Gax) results in reductions in brain capillary density and resting cerebral blood flow, loss of the angiogenic response to hypoxia in the brain and an impaired Abeta efflux from brain caused by reduced LRP levels. The link of MEOX2 to neurovascular dysfunction in Alzheimer disease provides new mechanistic and therapeutic insights into this illness.

Standard name | WU_ALZHEIMER_DISEASE_DN
Systematic name | M13334
Organism | Homo sapiens
PMID | 16116430
Authors | Wu Z,Guo H,Chow N,Sallstrom J,Bell RD,Deane R,Brooks AI,Kanagala S,Rubio A,Sagare A,Liu D,Li F,Armstrong D,Gasiewicz T,Zidovetzki R,Song X,Hofman F,Zlokovic BV
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in brain endothelial cells from patients with Alzheimer disease.
Full description | Neurovascular dysfunction substantially contributes to Alzheimer disease. Here, we show that transcriptional profiling of human brain endothelial cells (BECs) defines a subset of genes whose expression is age-independent but is considerably altered in Alzheimer disease, including the homeobox gene MEOX2 (also known as GAX), a regulator of vascular differentiation, whose expression is low in Alzheimer disease. By using viral-mediated MEOX2 gene silencing and transfer, we show that restoring expression of the protein it encodes, GAX, in BECs from individuals with Alzheimer disease stimulates angiogenesis, transcriptionally suppresses AFX1 forkhead transcription factor-mediated apoptosis and increases the levels of a major amyloid-beta peptide (Abeta) clearance receptor, the low-density lipoprotein receptor-related protein 1 (LRP), at the blood-brain barrier. In mice, deletion of Meox2 (also known as Gax) results in reductions in brain capillary density and resting cerebral blood flow, loss of the angiogenic response to hypoxia in the brain and an impaired Abeta efflux from brain caused by reduced LRP levels. The link of MEOX2 to neurovascular dysfunction in Alzheimer disease provides new mechanistic and therapeutic insights into this illness.

Standard name | MIZUKAMI_HYPOXIA_UP
Systematic name | M208
Organism | Homo sapiens
PMID | 16127434
Authors | Mizukami Y,Jo WS,Duerr EM,Gala M,Li J,Zhang X,Zimmer MA,Iliopoulos O,Zukerberg LR,Kohgo Y,Lynch MP,Rueda BR,Chung DC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DLD-1 cells (colon cancer) in response to hypoxia; might not be direct targets of HIF1A [GeneID=3091].
Full description | Hypoxia inducible factor-1 (HIF-1) is considered a crucial mediator of the cellular response to hypoxia through its regulation of genes that control angiogenesis. It represents an attractive therapeutic target in colon cancer, one of the few tumor types that shows a clinical response to antiangiogenic therapy. But it is unclear whether inhibition of HIF-1 alone is sufficient to block tumor angiogenesis. In HIF-1alpha knockdown DLD-1 colon cancer cells (DLD-1(HIF-kd)), the hypoxic induction of vascular endothelial growth factor (VEGF) was only partially blocked. Xenografts remained highly vascularized with microvessel densities identical to DLD-1 tumors that had wild-type HIF-1alpha (DLD-1(HIF-wt)). In addition to the preserved expression of VEGF, the proangiogenic cytokine interleukin (IL)-8 was induced by hypoxia in DLD-1(HIF-kd) but not DLD-1(HIF-wt) cells. This induction was mediated by the production of hydrogen peroxide and subsequent activation of NF-kappaB. Furthermore, the KRAS oncogene, which is commonly mutated in colon cancer, enhanced the hypoxic induction of IL-8. A neutralizing antibody to IL-8 substantially inhibited angiogenesis and tumor growth in DLD-1(HIF-kd) but not DLD-1(HIF-wt) xenografts, verifying the functional significance of this IL-8 response. Thus, compensatory pathways can be activated to preserve the tumor angiogenic response, and strategies that inhibit HIF-1alpha may be most effective when IL-8 is simultaneously targeted.

Standard name | MIZUKAMI_HYPOXIA_DN
Systematic name | M12751
Organism | Homo sapiens
PMID | 16127434
Authors | Mizukami Y,Jo WS,Duerr EM,Gala M,Li J,Zhang X,Zimmer MA,Iliopoulos O,Zukerberg LR,Kohgo Y,Lynch MP,Rueda BR,Chung DC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in DLD-1 cells (colon cancer) in response to hypoxia; might not be direct targets of HIF1A [GeneID=3091].
Full description | Hypoxia inducible factor-1 (HIF-1) is considered a crucial mediator of the cellular response to hypoxia through its regulation of genes that control angiogenesis. It represents an attractive therapeutic target in colon cancer, one of the few tumor types that shows a clinical response to antiangiogenic therapy. But it is unclear whether inhibition of HIF-1 alone is sufficient to block tumor angiogenesis. In HIF-1alpha knockdown DLD-1 colon cancer cells (DLD-1(HIF-kd)), the hypoxic induction of vascular endothelial growth factor (VEGF) was only partially blocked. Xenografts remained highly vascularized with microvessel densities identical to DLD-1 tumors that had wild-type HIF-1alpha (DLD-1(HIF-wt)). In addition to the preserved expression of VEGF, the proangiogenic cytokine interleukin (IL)-8 was induced by hypoxia in DLD-1(HIF-kd) but not DLD-1(HIF-wt) cells. This induction was mediated by the production of hydrogen peroxide and subsequent activation of NF-kappaB. Furthermore, the KRAS oncogene, which is commonly mutated in colon cancer, enhanced the hypoxic induction of IL-8. A neutralizing antibody to IL-8 substantially inhibited angiogenesis and tumor growth in DLD-1(HIF-kd) but not DLD-1(HIF-wt) xenografts, verifying the functional significance of this IL-8 response. Thus, compensatory pathways can be activated to preserve the tumor angiogenic response, and strategies that inhibit HIF-1alpha may be most effective when IL-8 is simultaneously targeted.

Standard name | YOSHIMURA_MAPK8_TARGETS_UP
Systematic name | M1884
Organism | Rattus norvegicus
PMID | 16311603
Authors | Yoshimura K,Aoki H,Ikeda Y,Fujii K,Akiyama N,Furutani A,Hoshii Y,Tanaka N,Ricci R,Ishihara T,Esato K,Hamano K,Matsuzaki M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in vascular smooth muscle cells (VSMC) by MAPK8 (JNK1) [GeneID=5599].
Full description | Abdominal aortic aneurysm (AAA) is a common disease among elderly people that, when surgical treatment is inapplicable, results in progressive expansion and rupture of the aorta with high mortality. Although nonsurgical treatment for AAA is much awaited, few options are available because its molecular pathogenesis remains elusive. Here, we identify JNK as a proximal signaling molecule in the pathogenesis of AAA. Human AAA tissue showed a high level of phosphorylated JNK. We show that JNK programs a gene expression pattern in different cell types that cooperatively enhances the degradation of the extracellular matrix while suppressing biosynthetic enzymes of the extracellular matrix. Selective inhibition of JNK in vivo not only prevented the development of AAA but also caused regression of established AAA in two mouse models. Thus, JNK promotes abnormal extracellular matrix metabolism in the tissue of AAA and may represent a therapeutic target.

Standard name | YOSHIMURA_MAPK8_TARGETS_DN
Systematic name | M1885
Organism | Rattus norvegicus
PMID | 16311603
Authors | Yoshimura K,Aoki H,Ikeda Y,Fujii K,Akiyama N,Furutani A,Hoshii Y,Tanaka N,Ricci R,Ishihara T,Esato K,Hamano K,Matsuzaki M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in vascular smooth muscle cells (VSMC) by MAPK8 (JNK1) [GeneID=5599].
Full description | Abdominal aortic aneurysm (AAA) is a common disease among elderly people that, when surgical treatment is inapplicable, results in progressive expansion and rupture of the aorta with high mortality. Although nonsurgical treatment for AAA is much awaited, few options are available because its molecular pathogenesis remains elusive. Here, we identify JNK as a proximal signaling molecule in the pathogenesis of AAA. Human AAA tissue showed a high level of phosphorylated JNK. We show that JNK programs a gene expression pattern in different cell types that cooperatively enhances the degradation of the extracellular matrix while suppressing biosynthetic enzymes of the extracellular matrix. Selective inhibition of JNK in vivo not only prevented the development of AAA but also caused regression of established AAA in two mouse models. Thus, JNK promotes abnormal extracellular matrix metabolism in the tissue of AAA and may represent a therapeutic target.

Standard name | WUNDER_INFLAMMATORY_RESPONSE_AND_CHOLESTEROL_UP
Systematic name | M1887
Organism | Mus musculus
PMID | 16951684
Authors | Wunder C,Churin Y,Winau F,Warnecke D,Vieth M,Lindner B,Zähringer U,Mollenkopf HJ,Heinz E,Meyer TF
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in gastric mucosal tissue of mice on 2% cholesterol [PubChem=5997] diet and infected with H. pylori vs those infected with H. pylori while on 0% cholesterol diet.
Full description | Helicobacter pylori infection causes gastric pathology such as ulcer and carcinoma. Because H. pylori is auxotrophic for cholesterol, we have explored the assimilation of cholesterol by H. pylori in infection. Here we show that H. pylori follows a cholesterol gradient and extracts the lipid from plasma membranes of epithelial cells for subsequent glucosylation. Excessive cholesterol promotes phagocytosis of H. pylori by antigen-presenting cells, such as macrophages and dendritic cells, and enhances antigen-specific T cell responses. A cholesterol-rich diet during bacterial challenge leads to T cell-dependent reduction of the H. pylori burden in the stomach. Intrinsic alpha-glucosylation of cholesterol abrogates phagocytosis of H. pylori and subsequent T cell activation. We identify the gene hp0421 as encoding the enzyme cholesterol-alpha-glucosyltransferase responsible for cholesterol glucosylation. Generation of knockout mutants lacking hp0421 corroborates the importance of cholesteryl glucosides for escaping phagocytosis, T cell activation and bacterial clearance in vivo. Thus, we propose a mechanism regulating the host-pathogen interaction whereby glucosylation of a lipid tips the scales towards immune evasion or response.

Standard name | WUNDER_INFLAMMATORY_RESPONSE_AND_CHOLESTEROL_DN
Systematic name | M1888
Organism | Mus musculus
PMID | 16951684
Authors | Wunder C,Churin Y,Winau F,Warnecke D,Vieth M,Lindner B,Zähringer U,Mollenkopf HJ,Heinz E,Meyer TF
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in gastric mucosal tissue of mice on 2% cholesterol [PubChem=5997] diet and infected with H. pylori vs those infected with H. pylori while on 0% cholesterol diet.
Full description | Helicobacter pylori infection causes gastric pathology such as ulcer and carcinoma. Because H. pylori is auxotrophic for cholesterol, we have explored the assimilation of cholesterol by H. pylori in infection. Here we show that H. pylori follows a cholesterol gradient and extracts the lipid from plasma membranes of epithelial cells for subsequent glucosylation. Excessive cholesterol promotes phagocytosis of H. pylori by antigen-presenting cells, such as macrophages and dendritic cells, and enhances antigen-specific T cell responses. A cholesterol-rich diet during bacterial challenge leads to T cell-dependent reduction of the H. pylori burden in the stomach. Intrinsic alpha-glucosylation of cholesterol abrogates phagocytosis of H. pylori and subsequent T cell activation. We identify the gene hp0421 as encoding the enzyme cholesterol-alpha-glucosyltransferase responsible for cholesterol glucosylation. Generation of knockout mutants lacking hp0421 corroborates the importance of cholesteryl glucosides for escaping phagocytosis, T cell activation and bacterial clearance in vivo. Thus, we propose a mechanism regulating the host-pathogen interaction whereby glucosylation of a lipid tips the scales towards immune evasion or response.

Standard name | RAY_TARGETS_OF_P210_BCR_ABL_FUSION_UP
Systematic name | M16309
Organism | Homo sapiens
PMID | 15155749
Authors | Ray S,Lu Y,Kaufmann SH,Gustafson WC,Karp JE,Boldogh I,Fields AP,Brasier AR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HL-60 cells (acute myeloid leukemia, AML) by expression of p210 BCR-ABL [GeneID=613;25] fusion protein.
Full description | Chronic myelogenous leukemia (CML) results from a t(9,22) translocation, producing the p210(BCR-ABL) oncoprotein, a tyrosine kinase that causes transformation and chemotherapy resistance. To further understand mechanisms mediating chemotherapy resistance, we identified 556 differentially regulated genes in HL-60 cells stably expressing p210(BCR-ABL) versus those expressing an empty vector using cDNA macro- and oligonucleotide microarrays. These BCR-ABL-regulated gene products play diverse roles in cellular function including apoptosis, cell cycle regulation, intracellular signaling, transcription, and cellular adhesion. In particular, we identified up-regulation of the inducible form of heat shock protein 70 (Hsp70), and further explored the mechanism for its up-regulation. In HL-60/BCR-ABL and K562 cells (expressing p210(BCR-ABL)), abundant cytoplasmic Hsp70 expression was detected by immunoblot analysis. Moreover, cells isolated from bone marrow aspirates of patients in different stages of CML (chronic, aggressive, and blast crisis) express Hsp70. Expression of p210(BCR-ABL) in BCR-ABL negative cells induced transcription of the proximal Hsp70 promoter. Mutational analysis mapped the major p210(BCR-ABL) responsive element to a high affinity 5'(A/T)GATA(A/G)-3' GATA response element (GATA-RE) that binds GATA-1 in CML cells. The GATA-RE was sufficient to confer p210(BCR-ABL)- and p185(BCR-ABL)-mediated trans-activation to an inert promoter. Short interfering RNA mediated knockdown of Hsp70 expression in K562 cells induced marked sensitivity to paclitaxel-induced apoptosis. Together these findings indicate that BCR-ABL confers chemotherapeutic resistance through intracellular signaling to the GATA-RE element found in the promoter region of the anti-apoptotic Hsp70 protein. We suggest that down-regulation of the GATA-Hsp70 pathway may be useful in the treatment of chemotherapy-resistant CML.

Standard name | RAY_TARGETS_OF_P210_BCR_ABL_FUSION_DN
Systematic name | M319
Organism | Homo sapiens
PMID | 15155749
Authors | Ray S,Lu Y,Kaufmann SH,Gustafson WC,Karp JE,Boldogh I,Fields AP,Brasier AR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HL-60 cells (acute myeloid leukemia, AML) by expression of p210 BCR-ABL [GeneID=613;25] fusion protein.
Full description | Chronic myelogenous leukemia (CML) results from a t(9,22) translocation, producing the p210(BCR-ABL) oncoprotein, a tyrosine kinase that causes transformation and chemotherapy resistance. To further understand mechanisms mediating chemotherapy resistance, we identified 556 differentially regulated genes in HL-60 cells stably expressing p210(BCR-ABL) versus those expressing an empty vector using cDNA macro- and oligonucleotide microarrays. These BCR-ABL-regulated gene products play diverse roles in cellular function including apoptosis, cell cycle regulation, intracellular signaling, transcription, and cellular adhesion. In particular, we identified up-regulation of the inducible form of heat shock protein 70 (Hsp70), and further explored the mechanism for its up-regulation. In HL-60/BCR-ABL and K562 cells (expressing p210(BCR-ABL)), abundant cytoplasmic Hsp70 expression was detected by immunoblot analysis. Moreover, cells isolated from bone marrow aspirates of patients in different stages of CML (chronic, aggressive, and blast crisis) express Hsp70. Expression of p210(BCR-ABL) in BCR-ABL negative cells induced transcription of the proximal Hsp70 promoter. Mutational analysis mapped the major p210(BCR-ABL) responsive element to a high affinity 5'(A/T)GATA(A/G)-3' GATA response element (GATA-RE) that binds GATA-1 in CML cells. The GATA-RE was sufficient to confer p210(BCR-ABL)- and p185(BCR-ABL)-mediated trans-activation to an inert promoter. Short interfering RNA mediated knockdown of Hsp70 expression in K562 cells induced marked sensitivity to paclitaxel-induced apoptosis. Together these findings indicate that BCR-ABL confers chemotherapeutic resistance through intracellular signaling to the GATA-RE element found in the promoter region of the anti-apoptotic Hsp70 protein. We suggest that down-regulation of the GATA-Hsp70 pathway may be useful in the treatment of chemotherapy-resistant CML.

Standard name | RUIZ_TNC_TARGETS_UP
Systematic name | M988
Organism | Homo sapiens
PMID | 15492259
Authors | Ruiz C,Huang W,Hegi ME,Lange K,Hamou MF,Fluri E,Oakeley EJ,Chiquet-Ehrismann R,Orend G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T98G cells (glioblastoma) by TNC [GeneID=3371].
Full description | Tenascin-C is an adhesion-modulating extracellular matrix molecule that is highly expressed in tumor stroma and stimulates tumor cell proliferation. Adhesion of T98G glioblastoma cells to a fibronectin substratum is inhibited by tenascin-C. To address the mechanism of action, we performed a RNA expression analysis of T89G cells grown in the presence or absence of tenascin-C and found that tenascin-C down-regulates tropomyosin-1. Upon overexpression of tropomyosin-1, cell spreading on a fibronectin/tenascin-C substratum was restored, indicating that tenascin-C destabilizes actin stress fibers through down-regulation of tropomyosin-1. Tenascin-C also increased the expression of the endothelin receptor type A and stimulated the corresponding mitogen-activated protein kinase signaling pathway, which triggers extracellular signal-regulated kinase 1/2 phosphorylation and c-Fos expression. Tenascin-C additionally caused down-regulation of the Wnt inhibitor Dickkopf 1. In consequence, Wnt signaling was enhanced through stabilization of beta-catenin and stimulated the expression of the beta-catenin target Id2. Finally, our in vivo data derived from astrocytoma tissue arrays link increased tenascin-C and Id2 expression with high malignancy. Because increased endothelin and Wnt signaling, as well as reduced tropomyosin-1 expression, are closely linked to transformation and tumorigenesis, we suggest that tenascin-C specifically modulates these signaling pathways to enhance proliferation of glioma cells.

Standard name | RUIZ_TNC_TARGETS_DN
Systematic name | M19048
Organism | Homo sapiens
PMID | 15492259
Authors | Ruiz C,Huang W,Hegi ME,Lange K,Hamou MF,Fluri E,Oakeley EJ,Chiquet-Ehrismann R,Orend G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T98G cells (glioblastoma) by TNC [GeneID=3371].
Full description | Tenascin-C is an adhesion-modulating extracellular matrix molecule that is highly expressed in tumor stroma and stimulates tumor cell proliferation. Adhesion of T98G glioblastoma cells to a fibronectin substratum is inhibited by tenascin-C. To address the mechanism of action, we performed a RNA expression analysis of T89G cells grown in the presence or absence of tenascin-C and found that tenascin-C down-regulates tropomyosin-1. Upon overexpression of tropomyosin-1, cell spreading on a fibronectin/tenascin-C substratum was restored, indicating that tenascin-C destabilizes actin stress fibers through down-regulation of tropomyosin-1. Tenascin-C also increased the expression of the endothelin receptor type A and stimulated the corresponding mitogen-activated protein kinase signaling pathway, which triggers extracellular signal-regulated kinase 1/2 phosphorylation and c-Fos expression. Tenascin-C additionally caused down-regulation of the Wnt inhibitor Dickkopf 1. In consequence, Wnt signaling was enhanced through stabilization of beta-catenin and stimulated the expression of the beta-catenin target Id2. Finally, our in vivo data derived from astrocytoma tissue arrays link increased tenascin-C and Id2 expression with high malignancy. Because increased endothelin and Wnt signaling, as well as reduced tropomyosin-1 expression, are closely linked to transformation and tumorigenesis, we suggest that tenascin-C specifically modulates these signaling pathways to enhance proliferation of glioma cells.

Standard name | RUTELLA_RESPONSE_TO_CSF2RB_AND_IL4_UP
Systematic name | M12636
Organism | Homo sapiens
PMID | 16527888
Authors | Rutella S,Bonanno G,Procoli A,Mariotti A,de Ritis DG,Curti A,Danese S,Pessina G,Pandolfi S,Natoni F,Di Febo A,Scambia G,Manfredini R,Salati S,Ferrari S,Pierelli L,Leone G,Lemoli RM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in peripheral blood monocytes by CSF2RB (GM-CSF) and IL4 [GeneID=1437;3565].
Full description | Several hematopoietic growth factors, including interleukin-10 (IL-10) and transforming growth factor-beta1 (TGF-beta1), promote the differentiation of tolerogenic dendritic cells (DCs). Hepatocyte growth factor (HGF) is a pleiotropic cytokine whose effects on human DC differentiation and function have not been investigated. Monocytes cultured with HGF (HGFMo) differentiated into accessory cells with DC-like morphology, released low amounts of IL-12p70 and up-regulated IL-10 both at the mRNA and at the protein level. Upon activation with HGFMo, allogeneic CD4+CD25- T cells expressed the T regulatory (Treg)-associated transcription factor FoxP3, proliferated poorly, and released high levels of IL-10. Interestingly, blockade of surface immunoglobulin-like transcript 3 (ILT3) on HGFMo or neutralization of secreted IL-10 translated into partial restoration of T-cell proliferation. Secondary stimulation of HGFMo-primed CD4+ T cells with immunogenic DCs differentiated with granulocyte-macrophage colony-stimulating factor (GM-CSF) and IL-4 from monocytes of the same donor resulted in measurable T-cell proliferation. HGFMo-primed CD4+ T cells significantly inhibited the proliferation of naive CD4+CD25- T cells in a cell-contact-dependent manner. Finally, DNA microarray analysis revealed a unique gene-expression profile of HGF-activated monocytes. Collectively, our findings point to a novel role for HGF in the regulation of monocyte/DC functions that might be exploited therapeutically.

Standard name | RUTELLA_RESPONSE_TO_CSF2RB_AND_IL4_DN
Systematic name | M8582
Organism | Homo sapiens
PMID | 16527888
Authors | Rutella S,Bonanno G,Procoli A,Mariotti A,de Ritis DG,Curti A,Danese S,Pessina G,Pandolfi S,Natoni F,Di Febo A,Scambia G,Manfredini R,Salati S,Ferrari S,Pierelli L,Leone G,Lemoli RM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in peripheral blood monocytes by CSF2RB (GM-CSF) and IL4 [GeneID=1437;3565].
Full description | Several hematopoietic growth factors, including interleukin-10 (IL-10) and transforming growth factor-beta1 (TGF-beta1), promote the differentiation of tolerogenic dendritic cells (DCs). Hepatocyte growth factor (HGF) is a pleiotropic cytokine whose effects on human DC differentiation and function have not been investigated. Monocytes cultured with HGF (HGFMo) differentiated into accessory cells with DC-like morphology, released low amounts of IL-12p70 and up-regulated IL-10 both at the mRNA and at the protein level. Upon activation with HGFMo, allogeneic CD4+CD25- T cells expressed the T regulatory (Treg)-associated transcription factor FoxP3, proliferated poorly, and released high levels of IL-10. Interestingly, blockade of surface immunoglobulin-like transcript 3 (ILT3) on HGFMo or neutralization of secreted IL-10 translated into partial restoration of T-cell proliferation. Secondary stimulation of HGFMo-primed CD4+ T cells with immunogenic DCs differentiated with granulocyte-macrophage colony-stimulating factor (GM-CSF) and IL-4 from monocytes of the same donor resulted in measurable T-cell proliferation. HGFMo-primed CD4+ T cells significantly inhibited the proliferation of naive CD4+CD25- T cells in a cell-contact-dependent manner. Finally, DNA microarray analysis revealed a unique gene-expression profile of HGF-activated monocytes. Collectively, our findings point to a novel role for HGF in the regulation of monocyte/DC functions that might be exploited therapeutically.

Standard name | RUTELLA_RESPONSE_TO_HGF_UP
Systematic name | M18149
Organism | Homo sapiens
PMID | 16527888
Authors | Rutella S,Bonanno G,Procoli A,Mariotti A,de Ritis DG,Curti A,Danese S,Pessina G,Pandolfi S,Natoni F,Di Febo A,Scambia G,Manfredini R,Salati S,Ferrari S,Pierelli L,Leone G,Lemoli RM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in peripheral blood monocytes by HGF [GeneID=3082].
Full description | Several hematopoietic growth factors, including interleukin-10 (IL-10) and transforming growth factor-beta1 (TGF-beta1), promote the differentiation of tolerogenic dendritic cells (DCs). Hepatocyte growth factor (HGF) is a pleiotropic cytokine whose effects on human DC differentiation and function have not been investigated. Monocytes cultured with HGF (HGFMo) differentiated into accessory cells with DC-like morphology, released low amounts of IL-12p70 and up-regulated IL-10 both at the mRNA and at the protein level. Upon activation with HGFMo, allogeneic CD4+CD25- T cells expressed the T regulatory (Treg)-associated transcription factor FoxP3, proliferated poorly, and released high levels of IL-10. Interestingly, blockade of surface immunoglobulin-like transcript 3 (ILT3) on HGFMo or neutralization of secreted IL-10 translated into partial restoration of T-cell proliferation. Secondary stimulation of HGFMo-primed CD4+ T cells with immunogenic DCs differentiated with granulocyte-macrophage colony-stimulating factor (GM-CSF) and IL-4 from monocytes of the same donor resulted in measurable T-cell proliferation. HGFMo-primed CD4+ T cells significantly inhibited the proliferation of naive CD4+CD25- T cells in a cell-contact-dependent manner. Finally, DNA microarray analysis revealed a unique gene-expression profile of HGF-activated monocytes. Collectively, our findings point to a novel role for HGF in the regulation of monocyte/DC functions that might be exploited therapeutically.

Standard name | RUTELLA_RESPONSE_TO_HGF_DN
Systematic name | M6413
Organism | Homo sapiens
PMID | 16527888
Authors | Rutella S,Bonanno G,Procoli A,Mariotti A,de Ritis DG,Curti A,Danese S,Pessina G,Pandolfi S,Natoni F,Di Febo A,Scambia G,Manfredini R,Salati S,Ferrari S,Pierelli L,Leone G,Lemoli RM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in peripheral blood monocytes by HGF [GeneID=3082].
Full description | Several hematopoietic growth factors, including interleukin-10 (IL-10) and transforming growth factor-beta1 (TGF-beta1), promote the differentiation of tolerogenic dendritic cells (DCs). Hepatocyte growth factor (HGF) is a pleiotropic cytokine whose effects on human DC differentiation and function have not been investigated. Monocytes cultured with HGF (HGFMo) differentiated into accessory cells with DC-like morphology, released low amounts of IL-12p70 and up-regulated IL-10 both at the mRNA and at the protein level. Upon activation with HGFMo, allogeneic CD4+CD25- T cells expressed the T regulatory (Treg)-associated transcription factor FoxP3, proliferated poorly, and released high levels of IL-10. Interestingly, blockade of surface immunoglobulin-like transcript 3 (ILT3) on HGFMo or neutralization of secreted IL-10 translated into partial restoration of T-cell proliferation. Secondary stimulation of HGFMo-primed CD4+ T cells with immunogenic DCs differentiated with granulocyte-macrophage colony-stimulating factor (GM-CSF) and IL-4 from monocytes of the same donor resulted in measurable T-cell proliferation. HGFMo-primed CD4+ T cells significantly inhibited the proliferation of naive CD4+CD25- T cells in a cell-contact-dependent manner. Finally, DNA microarray analysis revealed a unique gene-expression profile of HGF-activated monocytes. Collectively, our findings point to a novel role for HGF in the regulation of monocyte/DC functions that might be exploited therapeutically.

Standard name | RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_UP
Systematic name | M19971
Organism | Homo sapiens
PMID | 16527888
Authors | Rutella S,Bonanno G,Procoli A,Mariotti A,de Ritis DG,Curti A,Danese S,Pessina G,Pandolfi S,Natoni F,Di Febo A,Scambia G,Manfredini R,Salati S,Ferrari S,Pierelli L,Leone G,Lemoli RM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in peripheral blood mononucleocytes by HGF [GeneID=3082] compared to those regulated by CSF2RB (GM-CSF) and IL4 [GeneID=1437;3565].
Full description | Several hematopoietic growth factors, including interleukin-10 (IL-10) and transforming growth factor-beta1 (TGF-beta1), promote the differentiation of tolerogenic dendritic cells (DCs). Hepatocyte growth factor (HGF) is a pleiotropic cytokine whose effects on human DC differentiation and function have not been investigated. Monocytes cultured with HGF (HGFMo) differentiated into accessory cells with DC-like morphology, released low amounts of IL-12p70 and up-regulated IL-10 both at the mRNA and at the protein level. Upon activation with HGFMo, allogeneic CD4+CD25- T cells expressed the T regulatory (Treg)-associated transcription factor FoxP3, proliferated poorly, and released high levels of IL-10. Interestingly, blockade of surface immunoglobulin-like transcript 3 (ILT3) on HGFMo or neutralization of secreted IL-10 translated into partial restoration of T-cell proliferation. Secondary stimulation of HGFMo-primed CD4+ T cells with immunogenic DCs differentiated with granulocyte-macrophage colony-stimulating factor (GM-CSF) and IL-4 from monocytes of the same donor resulted in measurable T-cell proliferation. HGFMo-primed CD4+ T cells significantly inhibited the proliferation of naive CD4+CD25- T cells in a cell-contact-dependent manner. Finally, DNA microarray analysis revealed a unique gene-expression profile of HGF-activated monocytes. Collectively, our findings point to a novel role for HGF in the regulation of monocyte/DC functions that might be exploited therapeutically.

Standard name | RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_DN
Systematic name | M13333
Organism | Homo sapiens
PMID | 16527888
Authors | Rutella S,Bonanno G,Procoli A,Mariotti A,de Ritis DG,Curti A,Danese S,Pessina G,Pandolfi S,Natoni F,Di Febo A,Scambia G,Manfredini R,Salati S,Ferrari S,Pierelli L,Leone G,Lemoli RM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in peripheral blood mononucleocytes by HGF [GeneID=3082] compared to those regulated by CSF2RB (GM-CSF) and IL4 [GeneID=1437;3565].
Full description | Several hematopoietic growth factors, including interleukin-10 (IL-10) and transforming growth factor-beta1 (TGF-beta1), promote the differentiation of tolerogenic dendritic cells (DCs). Hepatocyte growth factor (HGF) is a pleiotropic cytokine whose effects on human DC differentiation and function have not been investigated. Monocytes cultured with HGF (HGFMo) differentiated into accessory cells with DC-like morphology, released low amounts of IL-12p70 and up-regulated IL-10 both at the mRNA and at the protein level. Upon activation with HGFMo, allogeneic CD4+CD25- T cells expressed the T regulatory (Treg)-associated transcription factor FoxP3, proliferated poorly, and released high levels of IL-10. Interestingly, blockade of surface immunoglobulin-like transcript 3 (ILT3) on HGFMo or neutralization of secreted IL-10 translated into partial restoration of T-cell proliferation. Secondary stimulation of HGFMo-primed CD4+ T cells with immunogenic DCs differentiated with granulocyte-macrophage colony-stimulating factor (GM-CSF) and IL-4 from monocytes of the same donor resulted in measurable T-cell proliferation. HGFMo-primed CD4+ T cells significantly inhibited the proliferation of naive CD4+CD25- T cells in a cell-contact-dependent manner. Finally, DNA microarray analysis revealed a unique gene-expression profile of HGF-activated monocytes. Collectively, our findings point to a novel role for HGF in the regulation of monocyte/DC functions that might be exploited therapeutically.

Standard name | SCHRAETS_MLL_TARGETS_UP
Systematic name | M1902
Organism | Mus musculus
PMID | 12789274
Authors | Schraets D,Lehmann T,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in fibroblasts from MLL [GeneID=4297] knockout mice.
Full description | The human mixed lineage leukemia (MLL) gene is involved in about 50 different chromosomal translocations, associated with the disease phenotype of acute leukemia. However, the normal function of MLL is less understood. Homozygous knockouts of murine Mll were embryonal lethal, while heterozygous disruption led to aberrant hox gene expression associated with skeletal malformations, growth retardation, and impaired hematopoiesis. To understand MLL functions on the molecular level, gene expression profiling experiments were performed with a pair of murine cell lines (MLL(+/+) and MLL(-/-)). Microarray hybridization experiments revealed 197 potential target genes that are differentially expressed, providing new and important clues about MLL functions.

Standard name | SCHRAETS_MLL_TARGETS_DN
Systematic name | M1904
Organism | Mus musculus
PMID | 12789274
Authors | Schraets D,Lehmann T,Dingermann T,Marschalek R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in fibroblasts from MLL [GeneID=4297] knockout mice.
Full description | The human mixed lineage leukemia (MLL) gene is involved in about 50 different chromosomal translocations, associated with the disease phenotype of acute leukemia. However, the normal function of MLL is less understood. Homozygous knockouts of murine Mll were embryonal lethal, while heterozygous disruption led to aberrant hox gene expression associated with skeletal malformations, growth retardation, and impaired hematopoiesis. To understand MLL functions on the molecular level, gene expression profiling experiments were performed with a pair of murine cell lines (MLL(+/+) and MLL(-/-)). Microarray hybridization experiments revealed 197 potential target genes that are differentially expressed, providing new and important clues about MLL functions.

Standard name | MUELLER_COMMON_TARGETS_OF_AML_FUSIONS_UP
Systematic name | M2289
Organism | Homo sapiens
PMID | 15024077
Authors | Müller-Tidow C,Steffen B,Cauvet T,Tickenbrock L,Ji P,Diederichs S,Sargin B,Köhler G,Stelljes M,Puccetti E,Ruthardt M,deVos S,Hiebert SW,Koeffler HP,Berdel WE,Serve H
Category | C2
Sub-category | CGP
Brief description | Up-regulated target genes shared by acute myeloid leukemia (AML) translocation products PML RARA [GeneID=5371;5914], AML1 ETO [GeneID=861;862], and PLZF RARA [GeneID=5914;7704].
Full description | The acute myeloid leukemia (AML)-associated translocation products AML1-ETO, PML-retinoic acid receptor alpha (RARalpha), and PLZF-RARalpha encode aberrant transcription factors. Several lines of evidence suggest similar pathogenetic mechanisms for these fusion proteins. We used high-density oligonucleotide arrays to identify shared target genes in inducibly transfected U937 cells expressing AML1-ETO, PML-RARalpha, or PLZF-RARalpha. All three fusion proteins significantly repressed the expression of 38 genes and induced the expression of 14 genes. Several of the regulated genes were associated with Wnt signaling. One of these, plakoglobin (gamma-catenin), was induced on the mRNA and protein level by all three fusion proteins. In addition, primary AML blasts carrying one of the fusion proteins significantly overexpressed plakoglobin. The plakoglobin promoter was cloned and shown to be induced by AML1-ETO, with promoter activation depending on the corepressor and histone deacetylase binding domains. The induction of plakoglobin by AML fusion proteins led to downstream signaling and transactivation of TCF- and LEF-dependent promoters, including the c-myc promoter, which was found to be bound by plakoglobin in vivo after AML1-ETO expression. beta-Catenin protein levels and TCF and LEF target genes such as c-myc and cyclin D1 were found to be induced by the fusion proteins. On the functional level, a dominant negative TCF inhibited colony growth of AML1-ETO-positive Kasumi cells, whereas plakoglobin transfection into myeloid 32D cells enhanced proliferation and clonal growth. Injection of plakoglobin-expressing 32D cells into syngeneic mice accelerated the development of leukemia. Transduction of plakoglobin into primitive murine hematopoietic progenitor cells preserved the immature phenotype during colony growth, suggesting enhanced self-renewal. These data provide evidence that activation of Wnt signaling is a common feature of several balanced translocations in AML.

Standard name | MUELLER_COMMON_TARGETS_OF_AML_FUSIONS_DN
Systematic name | M8780
Organism | Homo sapiens
PMID | 15024077
Authors | Müller-Tidow C,Steffen B,Cauvet T,Tickenbrock L,Ji P,Diederichs S,Sargin B,Köhler G,Stelljes M,Puccetti E,Ruthardt M,deVos S,Hiebert SW,Koeffler HP,Berdel WE,Serve H
Category | C2
Sub-category | CGP
Brief description | Down-regulated target genes shared by acute myeloid leukemia (AML) translocation products PML RARA [GeneID=5371;5914], AML1 ETO [GeneID=861;862], and PLZF RARA [GeneID=5914;7704].
Full description | The acute myeloid leukemia (AML)-associated translocation products AML1-ETO, PML-retinoic acid receptor alpha (RARalpha), and PLZF-RARalpha encode aberrant transcription factors. Several lines of evidence suggest similar pathogenetic mechanisms for these fusion proteins. We used high-density oligonucleotide arrays to identify shared target genes in inducibly transfected U937 cells expressing AML1-ETO, PML-RARalpha, or PLZF-RARalpha. All three fusion proteins significantly repressed the expression of 38 genes and induced the expression of 14 genes. Several of the regulated genes were associated with Wnt signaling. One of these, plakoglobin (gamma-catenin), was induced on the mRNA and protein level by all three fusion proteins. In addition, primary AML blasts carrying one of the fusion proteins significantly overexpressed plakoglobin. The plakoglobin promoter was cloned and shown to be induced by AML1-ETO, with promoter activation depending on the corepressor and histone deacetylase binding domains. The induction of plakoglobin by AML fusion proteins led to downstream signaling and transactivation of TCF- and LEF-dependent promoters, including the c-myc promoter, which was found to be bound by plakoglobin in vivo after AML1-ETO expression. beta-Catenin protein levels and TCF and LEF target genes such as c-myc and cyclin D1 were found to be induced by the fusion proteins. On the functional level, a dominant negative TCF inhibited colony growth of AML1-ETO-positive Kasumi cells, whereas plakoglobin transfection into myeloid 32D cells enhanced proliferation and clonal growth. Injection of plakoglobin-expressing 32D cells into syngeneic mice accelerated the development of leukemia. Transduction of plakoglobin into primitive murine hematopoietic progenitor cells preserved the immature phenotype during colony growth, suggesting enhanced self-renewal. These data provide evidence that activation of Wnt signaling is a common feature of several balanced translocations in AML.

Standard name | ROSS_LEUKEMIA_WITH_MLL_FUSIONS
Systematic name | M12695
Organism | Homo sapiens
PMID | 15226186
Authors | Ross ME,Mahfouz R,Onciu M,Liu HC,Zhou X,Song G,Shurtleff SA,Pounds S,Cheng C,Ma J,Ribeiro RC,Rubnitz JE,Girtman K,Williams WK,Raimondi SC,Liang DC,Shih LY,Pui CH,Downing JR
Category | C2
Sub-category | CGP
Brief description | Top 100 probe sets associated with MLL fusions [GeneID=4297] irrespective of the lineage of the pediatric acute leukemia.
Full description | Contemporary treatment of pediatric acute myeloid leukemia (AML) requires the assignment of patients to specific risk groups. To explore whether expression profiling of leukemic blasts could accurately distinguish between the known risk groups of AML, we analyzed 130 pediatric and 20 adult AML diagnostic bone marrow or peripheral blood samples using the Affymetrix U133A microarray. Class discriminating genes were identified for each of the major prognostic subtypes of pediatric AML, including t(15;17)[PML-RARalpha], t(8;21)[AML1-ETO], inv(16) [CBFbeta-MYH11], MLL chimeric fusion genes, and cases classified as FAB-M7. When subsets of these genes were used in supervised learning algorithms, an overall classification accuracy of more than 93% was achieved. Moreover, we were able to use the expression signatures generated from the pediatric samples to accurately classify adult de novo AMLs with the same genetic lesions. The class discriminating genes also provided novel insights into the molecular pathobiology of these leukemias. Finally, using a combined pediatric data set of 130 AMLs and 137 acute lymphoblastic leukemias, we identified an expression signature for cases with MLL chimeric fusion genes irrespective of lineage. Surprisingly, AMLs containing partial tandem duplications of MLL failed to cluster with MLL chimeric fusion gene cases, suggesting a significant difference in their underlying mechanism of transformation.

Standard name | VANASSE_BCL2_TARGETS_UP
Systematic name | M1906
Organism | Mus musculus
PMID | 15561778
Authors | Vanasse GJ,Winn RK,Rodov S,Zieske AW,Li JT,Tupper JC,Tang J,Raines EW,Peters MA,Yeung KY,Harlan JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary B lymphocytes engineered to overexpress BCL2 [GeneID=12043].
Full description | The t(14;18)(q32;q21), resulting in deregulated expression of B-cell-leukemia/lymphoma-2 (Bcl-2), represents the genetic hallmark in human follicular lymphomas. Substantial evidence supports the hypothesis that the t(14;18) and Bcl-2 overexpression are necessary but not solely responsible for neoplastic transformation and require cooperating genetic derangements for neoplastic transformation to occur. To investigate genes that cooperate with Bcl-2 to influence cellular signaling pathways important for neoplastic transformation, we used oligonucleotide microarrays to determine differential gene expression patterns in CD19+ B cells isolated from Emu-Bcl-2 transgenic mice and wild-type littermate control mice. Fifty-seven genes were induced and 94 genes were repressed by > or =2-fold in Emu-Bcl-2 transgenic mice (P < 0.05). The suppressor of cytokine signaling-3 (SOCS3) gene was found to be overexpressed 5-fold in B cells from Emu-Bcl-2 transgenic mice. Overexpression of Bcl-2 in both mouse embryo fibroblast-1 and hematopoietic cell lines resulted in induction of SOCS3 protein, suggesting a Bcl-2-associated mechanism underlying SOCS3 induction. Immunohistochemistry with SOCS3 antisera on tissue from a cohort of patients with de novo follicular lymphoma revealed marked overexpression of SOCS3 protein that, within the follicular center cell region, was limited to neoplastic follicular lymphoma cells and colocalized with Bcl-2 expression in 9 of 12 de novo follicular lymphoma cases examined. In contrast, SOCS3 protein expression was not detected in the follicular center cell region of benign hyperplastic tonsil tissue. These data suggest that Bcl-2 overexpression leads to the induction of activated signal transducer and activator of transcription 3 (STAT3) and to the induction of SOCS3, which may contribute to the pathogenesis of follicular lymphoma.

Standard name | VANASSE_BCL2_TARGETS_DN
Systematic name | M1910
Organism | Mus musculus
PMID | 15561778
Authors | Vanasse GJ,Winn RK,Rodov S,Zieske AW,Li JT,Tupper JC,Tang J,Raines EW,Peters MA,Yeung KY,Harlan JM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary B lymphocytes engineered to overexpress BCL2 [GeneID=12043].
Full description | The t(14;18)(q32;q21), resulting in deregulated expression of B-cell-leukemia/lymphoma-2 (Bcl-2), represents the genetic hallmark in human follicular lymphomas. Substantial evidence supports the hypothesis that the t(14;18) and Bcl-2 overexpression are necessary but not solely responsible for neoplastic transformation and require cooperating genetic derangements for neoplastic transformation to occur. To investigate genes that cooperate with Bcl-2 to influence cellular signaling pathways important for neoplastic transformation, we used oligonucleotide microarrays to determine differential gene expression patterns in CD19+ B cells isolated from Emu-Bcl-2 transgenic mice and wild-type littermate control mice. Fifty-seven genes were induced and 94 genes were repressed by > or =2-fold in Emu-Bcl-2 transgenic mice (P < 0.05). The suppressor of cytokine signaling-3 (SOCS3) gene was found to be overexpressed 5-fold in B cells from Emu-Bcl-2 transgenic mice. Overexpression of Bcl-2 in both mouse embryo fibroblast-1 and hematopoietic cell lines resulted in induction of SOCS3 protein, suggesting a Bcl-2-associated mechanism underlying SOCS3 induction. Immunohistochemistry with SOCS3 antisera on tissue from a cohort of patients with de novo follicular lymphoma revealed marked overexpression of SOCS3 protein that, within the follicular center cell region, was limited to neoplastic follicular lymphoma cells and colocalized with Bcl-2 expression in 9 of 12 de novo follicular lymphoma cases examined. In contrast, SOCS3 protein expression was not detected in the follicular center cell region of benign hyperplastic tonsil tissue. These data suggest that Bcl-2 overexpression leads to the induction of activated signal transducer and activator of transcription 3 (STAT3) and to the induction of SOCS3, which may contribute to the pathogenesis of follicular lymphoma.

Standard name | VANTVEER_BREAST_CANCER_ESR1_UP
Systematic name | M393
Organism | Homo sapiens
PMID | 11823860
Authors | van 't Veer LJ,Dai H,van de Vijver MJ,He YD,Hart AA,Mao M,Peterse HL,van der Kooy K,Marton MJ,Witteveen AT,Schreiber GJ,Kerkhoven RM,Roberts C,Linsley PS,Bernards R,Friend SH
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the optimal set of 550 markers discriminating breast cancer samples by ESR1 [GeneID=2099] expression: ER(+) vs ER(-) tumors.
Full description | Breast cancer patients with the same stage of disease can have markedly different treatment responses and overall outcome. The strongest predictors for metastases (for example, lymph node status and histological grade) fail to classify accurately breast tumours according to their clinical behaviour. Chemotherapy or hormonal therapy reduces the risk of distant metastases by approximately one-third; however, 70-80% of patients receiving this treatment would have survived without it. None of the signatures of breast cancer gene expression reported to date allow for patient-tailored therapy strategies. Here we used DNA microarray analysis on primary breast tumours of 117 young patients, and applied supervised classification to identify a gene expression signature strongly predictive of a short interval to distant metastases ('poor prognosis' signature) in patients without tumour cells in local lymph nodes at diagnosis (lymph node negative). In addition, we established a signature that identifies tumours of BRCA1 carriers. The poor prognosis signature consists of genes regulating cell cycle, invasion, metastasis and angiogenesis. This gene expression profile will outperform all currently used clinical parameters in predicting disease outcome. Our findings provide a strategy to select patients who would benefit from adjuvant therapy.

Standard name | VANTVEER_BREAST_CANCER_ESR1_DN
Systematic name | M15425
Organism | Homo sapiens
PMID | 11823860
Authors | van 't Veer LJ,Dai H,van de Vijver MJ,He YD,Hart AA,Mao M,Peterse HL,van der Kooy K,Marton MJ,Witteveen AT,Schreiber GJ,Kerkhoven RM,Roberts C,Linsley PS,Bernards R,Friend SH
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the optimal set of 550 markers discriminating breast cancer samples by ESR1 [GeneID=2099] expression: ER(+) vs ER(-) tumors.
Full description | Breast cancer patients with the same stage of disease can have markedly different treatment responses and overall outcome. The strongest predictors for metastases (for example, lymph node status and histological grade) fail to classify accurately breast tumours according to their clinical behaviour. Chemotherapy or hormonal therapy reduces the risk of distant metastases by approximately one-third; however, 70-80% of patients receiving this treatment would have survived without it. None of the signatures of breast cancer gene expression reported to date allow for patient-tailored therapy strategies. Here we used DNA microarray analysis on primary breast tumours of 117 young patients, and applied supervised classification to identify a gene expression signature strongly predictive of a short interval to distant metastases ('poor prognosis' signature) in patients without tumour cells in local lymph nodes at diagnosis (lymph node negative). In addition, we established a signature that identifies tumours of BRCA1 carriers. The poor prognosis signature consists of genes regulating cell cycle, invasion, metastasis and angiogenesis. This gene expression profile will outperform all currently used clinical parameters in predicting disease outcome. Our findings provide a strategy to select patients who would benefit from adjuvant therapy.

Standard name | VANTVEER_BREAST_CANCER_BRCA1_UP
Systematic name | M16737
Organism | Homo sapiens
PMID | 11823860
Authors | van 't Veer LJ,Dai H,van de Vijver MJ,He YD,Hart AA,Mao M,Peterse HL,van der Kooy K,Marton MJ,Witteveen AT,Schreiber GJ,Kerkhoven RM,Roberts C,Linsley PS,Bernards R,Friend SH
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes from the optimal set of 100 markers discriminating ER(-) breast cancer tumors by BRCA1 [GeneID=672] mutation status.
Full description | Breast cancer patients with the same stage of disease can have markedly different treatment responses and overall outcome. The strongest predictors for metastases (for example, lymph node status and histological grade) fail to classify accurately breast tumours according to their clinical behaviour. Chemotherapy or hormonal therapy reduces the risk of distant metastases by approximately one-third; however, 70-80% of patients receiving this treatment would have survived without it. None of the signatures of breast cancer gene expression reported to date allow for patient-tailored therapy strategies. Here we used DNA microarray analysis on primary breast tumours of 117 young patients, and applied supervised classification to identify a gene expression signature strongly predictive of a short interval to distant metastases ('poor prognosis' signature) in patients without tumour cells in local lymph nodes at diagnosis (lymph node negative). In addition, we established a signature that identifies tumours of BRCA1 carriers. The poor prognosis signature consists of genes regulating cell cycle, invasion, metastasis and angiogenesis. This gene expression profile will outperform all currently used clinical parameters in predicting disease outcome. Our findings provide a strategy to select patients who would benefit from adjuvant therapy.

Standard name | VANTVEER_BREAST_CANCER_BRCA1_DN
Systematic name | M3464
Organism | Homo sapiens
PMID | 11823860
Authors | van 't Veer LJ,Dai H,van de Vijver MJ,He YD,Hart AA,Mao M,Peterse HL,van der Kooy K,Marton MJ,Witteveen AT,Schreiber GJ,Kerkhoven RM,Roberts C,Linsley PS,Bernards R,Friend SH
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes from the optimal set of 100 markers discriminating ER(-) breast cancer tumors by BRCA1 [GeneID=672] mutation status.
Full description | Breast cancer patients with the same stage of disease can have markedly different treatment responses and overall outcome. The strongest predictors for metastases (for example, lymph node status and histological grade) fail to classify accurately breast tumours according to their clinical behaviour. Chemotherapy or hormonal therapy reduces the risk of distant metastases by approximately one-third; however, 70-80% of patients receiving this treatment would have survived without it. None of the signatures of breast cancer gene expression reported to date allow for patient-tailored therapy strategies. Here we used DNA microarray analysis on primary breast tumours of 117 young patients, and applied supervised classification to identify a gene expression signature strongly predictive of a short interval to distant metastases ('poor prognosis' signature) in patients without tumour cells in local lymph nodes at diagnosis (lymph node negative). In addition, we established a signature that identifies tumours of BRCA1 carriers. The poor prognosis signature consists of genes regulating cell cycle, invasion, metastasis and angiogenesis. This gene expression profile will outperform all currently used clinical parameters in predicting disease outcome. Our findings provide a strategy to select patients who would benefit from adjuvant therapy.

Standard name | WALLACE_JAK2_TARGETS_UP
Systematic name | M3058
Organism | Homo sapiens
PMID | 15189810
Authors | Wallace TA,VonDerLinden D,He K,Frank SJ,Sayeski PP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated more than 7-fold by expressing JAK2 [GeneID=3717] in the JAK2 null cell line.
Full description | Mice lacking a functional Janus kinase 2 (JAK2) allele die embryonically, indicating the mandatory role of JAK2 in basic developmental cellular transcription. Currently, however, the downstream target genes of JAK2 are largely unknown. Here, in vitro conditions were created using a cell line lacking JAK2 expression. Microarray analysis was then used to identify genes that are differentially expressed as a result of the presence, or absence, of JAK2. The data identified 621 JAK2-dependent genes as having at least a twofold change in expression. Surprisingly, these genes did not require ligand-dependent activation of JAK2 but merely its expression in the cell. Thirty-one of these genes were found to have a greater than sevenfold change in expression levels, and a subset of these were further characterized. These genes represent a diverse cluster of ontological functions including transcription factors, signaling molecules, and cell surface receptors. The expression levels of these genes were validated by Northern blot and/or quantitative RT-PCR analysis in both the JAK2 null cells and cells expressing a JAK2-dominant negative allele. As such, this work demonstrates for the first time that, in addition to being a key mediator of ligand-activated gene transcription, JAK2 can perhaps also be viewed as a critical mediator of basal level gene expression.

Standard name | AGUIRRE_PANCREATIC_CANCER_COPY_NUMBER_UP
Systematic name | M9565
Organism | Homo sapiens
PMID | 15199222
Authors | Aguirre AJ,Brennan C,Bailey G,Sinha R,Feng B,Leo C,Zhang Y,Zhang J,Gans JD,Bardeesy N,Cauwels C,Cordon-Cardo C,Redston MS,DePinho RA,Chin L
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes whose expression correlates with copy number gains in pancreatic adenocarcinoma cell lines and primary tumor specimens.
Full description | The pancreatic adenocarcinoma genome harbors multiple amplifications and deletions, pointing to the existence of numerous oncogenes and tumor suppressor genes driving the genesis and progression of this lethal cancer. Here, array comparative genomic hybridization on a cDNA microarray platform and informatics tools have been used to define the copy number alterations in a panel of 24 pancreatic adenocarcinoma cell lines and 13 primary tumor specimens. This high-resolution genomic analysis has identified all known regional gains and losses as well as many previously uncharacterized highly recurrent copy number alterations. A systematic prioritization scheme has selected 64 focal minimal common regions (MCRs) of recurrent copy number change. These MCRs possess a median size of 2.7 megabases (Mb), with 21 (33%) MCRs spanning 1 Mb or less (median of 0.33 Mb) and possessing an average of 15 annotated genes. Furthermore, complementary expression profile analysis of a significant fraction of the genes residing within these 64 prioritized MCRs has enabled the identification of a subset of candidates with statistically significant association between gene dosage and mRNA expression. Thus, the integration of DNA and RNA profiles provides a highly productive entry point for the discovery of genes involved in the pathogenesis of pancreatic adenocarcinoma.

Standard name | AGUIRRE_PANCREATIC_CANCER_COPY_NUMBER_DN
Systematic name | M8897
Organism | Homo sapiens
PMID | 15199222
Authors | Aguirre AJ,Brennan C,Bailey G,Sinha R,Feng B,Leo C,Zhang Y,Zhang J,Gans JD,Bardeesy N,Cauwels C,Cordon-Cardo C,Redston MS,DePinho RA,Chin L
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes whose expression correlates with copy number losses in pancreatic adenocarcinoma cell lines and primary tumor specimens.
Full description | The pancreatic adenocarcinoma genome harbors multiple amplifications and deletions, pointing to the existence of numerous oncogenes and tumor suppressor genes driving the genesis and progression of this lethal cancer. Here, array comparative genomic hybridization on a cDNA microarray platform and informatics tools have been used to define the copy number alterations in a panel of 24 pancreatic adenocarcinoma cell lines and 13 primary tumor specimens. This high-resolution genomic analysis has identified all known regional gains and losses as well as many previously uncharacterized highly recurrent copy number alterations. A systematic prioritization scheme has selected 64 focal minimal common regions (MCRs) of recurrent copy number change. These MCRs possess a median size of 2.7 megabases (Mb), with 21 (33%) MCRs spanning 1 Mb or less (median of 0.33 Mb) and possessing an average of 15 annotated genes. Furthermore, complementary expression profile analysis of a significant fraction of the genes residing within these 64 prioritized MCRs has enabled the identification of a subset of candidates with statistically significant association between gene dosage and mRNA expression. Thus, the integration of DNA and RNA profiles provides a highly productive entry point for the discovery of genes involved in the pathogenesis of pancreatic adenocarcinoma.

Standard name | SWEET_LUNG_CANCER_KRAS_UP
Systematic name | M19097
Organism | Mus musculus
PMID | 15608639
Authors | Sweet-Cordero A,Mukherjee S,Subramanian A,You H,Roix JJ,Ladd-Acosta C,Mesirov J,Golub TR,Jacks T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the Kras2LA mouse lung cancer model with mutated KRAS [GeneID=3845].
Full description | Using advanced gene targeting methods, generating mouse models of cancer that accurately reproduce the genetic alterations present in human tumors is now relatively straightforward. The challenge is to determine to what extent such models faithfully mimic human disease with respect to the underlying molecular mechanisms that accompany tumor progression. Here we describe a method for comparing mouse models of cancer with human tumors using gene-expression profiling. We applied this method to the analysis of a model of Kras2-mediated lung cancer and found a good relationship to human lung adenocarcinoma, thereby validating the model. Furthermore, we found that whereas a gene-expression signature of KRAS2 activation was not identifiable when analyzing human tumors with known KRAS2 mutation status alone, integrating mouse and human data uncovered a gene-expression signature of KRAS2 mutation in human lung cancer. We confirmed the importance of this signature by gene-expression analysis of short hairpin RNA-mediated inhibition of oncogenic Kras2. These experiments identified both a pattern of gene expression indicative of KRAS2 mutation and potential effectors of oncogenic KRAS2 activity in human cancer. This approach provides a strategy for using genomic analysis of animal models to probe human disease.

Standard name | SWEET_LUNG_CANCER_KRAS_DN
Systematic name | M7396
Organism | Mus musculus
PMID | 15608639
Authors | Sweet-Cordero A,Mukherjee S,Subramanian A,You H,Roix JJ,Ladd-Acosta C,Mesirov J,Golub TR,Jacks T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the Kras2LA mouse lung cancer model with mutated KRAS [GeneID=3845].
Full description | Using advanced gene targeting methods, generating mouse models of cancer that accurately reproduce the genetic alterations present in human tumors is now relatively straightforward. The challenge is to determine to what extent such models faithfully mimic human disease with respect to the underlying molecular mechanisms that accompany tumor progression. Here we describe a method for comparing mouse models of cancer with human tumors using gene-expression profiling. We applied this method to the analysis of a model of Kras2-mediated lung cancer and found a good relationship to human lung adenocarcinoma, thereby validating the model. Furthermore, we found that whereas a gene-expression signature of KRAS2 activation was not identifiable when analyzing human tumors with known KRAS2 mutation status alone, integrating mouse and human data uncovered a gene-expression signature of KRAS2 mutation in human lung cancer. We confirmed the importance of this signature by gene-expression analysis of short hairpin RNA-mediated inhibition of oncogenic Kras2. These experiments identified both a pattern of gene expression indicative of KRAS2 mutation and potential effectors of oncogenic KRAS2 activity in human cancer. This approach provides a strategy for using genomic analysis of animal models to probe human disease.

Standard name | SWEET_KRAS_ONCOGENIC_SIGNATURE
Systematic name | M10573
Organism | Homo sapiens
PMID | 15608639
Authors | Sweet-Cordero A,Mukherjee S,Subramanian A,You H,Roix JJ,Ladd-Acosta C,Mesirov J,Golub TR,Jacks T
Category | C2
Sub-category | CGP
Brief description | Genes that contributed maximally to the GSEA score of the up-regulated gene set from the KrasLA mouse model in two human lung cancer expression data sets comparing mutant vs normal KRAS [GeneID=3845].
Full description | Using advanced gene targeting methods, generating mouse models of cancer that accurately reproduce the genetic alterations present in human tumors is now relatively straightforward. The challenge is to determine to what extent such models faithfully mimic human disease with respect to the underlying molecular mechanisms that accompany tumor progression. Here we describe a method for comparing mouse models of cancer with human tumors using gene-expression profiling. We applied this method to the analysis of a model of Kras2-mediated lung cancer and found a good relationship to human lung adenocarcinoma, thereby validating the model. Furthermore, we found that whereas a gene-expression signature of KRAS2 activation was not identifiable when analyzing human tumors with known KRAS2 mutation status alone, integrating mouse and human data uncovered a gene-expression signature of KRAS2 mutation in human lung cancer. We confirmed the importance of this signature by gene-expression analysis of short hairpin RNA-mediated inhibition of oncogenic Kras2. These experiments identified both a pattern of gene expression indicative of KRAS2 mutation and potential effectors of oncogenic KRAS2 activity in human cancer. This approach provides a strategy for using genomic analysis of animal models to probe human disease.

Standard name | HINATA_NFKB_TARGETS_KERATINOCYTE_UP
Systematic name | M11951
Organism | Homo sapiens
PMID | 12673201
Authors | Hinata K,Gervin AM,Jennifer Zhang Y,Khavari PA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary keratinocytes by expression of p50 (NFKB1) and p65 (RELA) [GeneID=4790;5970] components of NFKB.
Full description | NF-kappa B regulates normal and pathological processes, including neoplasia, in a tissue-context-dependent manner. In skin, NF-kappa B is implicated in epidermal homeostasis as well as in the pathogenesis of squamous cell carcinoma; however, its function in the underlying mesenchymal dermis has been unclear. To gain insight into NF-kappa B roles in these two adjacent cutaneous tissue compartments, NF-kappa B effects on expression of 12 435 genes were determined in epidermal keratinocytes and dermal fibroblasts. Although NF-kappa B induced proinflammatory and antiapoptotic genes in both settings, it exhibited divergent effects on growth regulatory genes. In keratinocytes, but not in fibroblasts, NF-kappa B induced p21(CIP1), which was sufficient to inhibit growth of both cell types. Levels of growth inhibitory factor (GIF), in contrast, were increased by NF-kappa B in both settings but inhibited growth only in keratinocytes. These findings indicate that transcription factors such as NF-kappa B can program tissue-selective effects via both differential target gene induction as well as by inducing common targets that exert differing effects depending on cellular lineage.

Standard name | HINATA_NFKB_TARGETS_KERATINOCYTE_DN
Systematic name | M1959
Organism | Homo sapiens
PMID | 12673201
Authors | Hinata K,Gervin AM,Jennifer Zhang Y,Khavari PA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary keratinocytes by expression of p50 (NFKB1) and p65 (RELA) [GeneID=4790;5970] components of NFKB.
Full description | NF-kappa B regulates normal and pathological processes, including neoplasia, in a tissue-context-dependent manner. In skin, NF-kappa B is implicated in epidermal homeostasis as well as in the pathogenesis of squamous cell carcinoma; however, its function in the underlying mesenchymal dermis has been unclear. To gain insight into NF-kappa B roles in these two adjacent cutaneous tissue compartments, NF-kappa B effects on expression of 12 435 genes were determined in epidermal keratinocytes and dermal fibroblasts. Although NF-kappa B induced proinflammatory and antiapoptotic genes in both settings, it exhibited divergent effects on growth regulatory genes. In keratinocytes, but not in fibroblasts, NF-kappa B induced p21(CIP1), which was sufficient to inhibit growth of both cell types. Levels of growth inhibitory factor (GIF), in contrast, were increased by NF-kappa B in both settings but inhibited growth only in keratinocytes. These findings indicate that transcription factors such as NF-kappa B can program tissue-selective effects via both differential target gene induction as well as by inducing common targets that exert differing effects depending on cellular lineage.

Standard name | HINATA_NFKB_TARGETS_FIBROBLAST_UP
Systematic name | M4151
Organism | Homo sapiens
PMID | 12673201
Authors | Hinata K,Gervin AM,Jennifer Zhang Y,Khavari PA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cells by expression of p50 (NFKB1) and p65 (RELA) [GeneID=4790;5970] components of NFKB.
Full description | NF-kappa B regulates normal and pathological processes, including neoplasia, in a tissue-context-dependent manner. In skin, NF-kappa B is implicated in epidermal homeostasis as well as in the pathogenesis of squamous cell carcinoma; however, its function in the underlying mesenchymal dermis has been unclear. To gain insight into NF-kappa B roles in these two adjacent cutaneous tissue compartments, NF-kappa B effects on expression of 12 435 genes were determined in epidermal keratinocytes and dermal fibroblasts. Although NF-kappa B induced proinflammatory and antiapoptotic genes in both settings, it exhibited divergent effects on growth regulatory genes. In keratinocytes, but not in fibroblasts, NF-kappa B induced p21(CIP1), which was sufficient to inhibit growth of both cell types. Levels of growth inhibitory factor (GIF), in contrast, were increased by NF-kappa B in both settings but inhibited growth only in keratinocytes. These findings indicate that transcription factors such as NF-kappa B can program tissue-selective effects via both differential target gene induction as well as by inducing common targets that exert differing effects depending on cellular lineage.

Standard name | HOFFMANN_PRE_BI_TO_LARGE_PRE_BII_LYMPHOCYTE_UP
Systematic name | M5589
Organism | Mus musculus
PMID | 11779835
Authors | Hoffmann R,Seidl T,Neeb M,Rolink A,Melchers F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during differentiation from pre-BI to large pre-BII lymphocyte.
Full description | Gene expression profiles of five consecutive stages of mouse B cell development were generated with high-density oligonucleotide arrays from as few as 2 x 10(4) ex vivo isolated and flow-cytometrically purified cells. Between 2.8% and 6.8% of all genes change on differentiation from one cellular stage to the next by at least twofold. The entire pathway involves differential expression of 10.7% of all genes. Previously known expression patterns of 15 genes (like surrogate light chain, RAG-1/2, MHC class II, mel-14 antigen) are confirmed. The gene expression patterns of the proliferating pre-BI and large pre-BII cells on the one hand, and the resting immature and mature B cells on the other hand, are most similar to each other. Small pre-BII cells display a pattern that is transitional between these two groups. Most of the genes expressed in early precursors are involved in general processes, like protein folding or cell cycle regulation, whereas more mature precursors express genes involved in more specific molecular programs (cell surface receptors, secreted factors, and adhesion molecules, among others). Between 19 and 139 genes share a given expression pattern. Combining knowledge about gene function and expression pattern allows identification of novel candidate genes potentially involved in self-maintenance of pre-BI cells, allelic exclusion and pre-B cell receptor signaling in large pre BII cells, cell-cycle arrest of small pre-BII cells, propensity toward apoptosis or anergization in immature B cells, propensity toward cell division and activation in mature B cells, and stage-specific interactions with stromal cells in the bone marrow.

Standard name | HOFFMANN_PRE_BI_TO_LARGE_PRE_BII_LYMPHOCYTE_DN
Systematic name | M7405
Organism | Mus musculus
PMID | 11779835
Authors | Hoffmann R,Seidl T,Neeb M,Rolink A,Melchers F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during differentiation from pre-BI to large pre-BII lymphocyte.
Full description | Gene expression profiles of five consecutive stages of mouse B cell development were generated with high-density oligonucleotide arrays from as few as 2 x 10(4) ex vivo isolated and flow-cytometrically purified cells. Between 2.8% and 6.8% of all genes change on differentiation from one cellular stage to the next by at least twofold. The entire pathway involves differential expression of 10.7% of all genes. Previously known expression patterns of 15 genes (like surrogate light chain, RAG-1/2, MHC class II, mel-14 antigen) are confirmed. The gene expression patterns of the proliferating pre-BI and large pre-BII cells on the one hand, and the resting immature and mature B cells on the other hand, are most similar to each other. Small pre-BII cells display a pattern that is transitional between these two groups. Most of the genes expressed in early precursors are involved in general processes, like protein folding or cell cycle regulation, whereas more mature precursors express genes involved in more specific molecular programs (cell surface receptors, secreted factors, and adhesion molecules, among others). Between 19 and 139 genes share a given expression pattern. Combining knowledge about gene function and expression pattern allows identification of novel candidate genes potentially involved in self-maintenance of pre-BI cells, allelic exclusion and pre-B cell receptor signaling in large pre BII cells, cell-cycle arrest of small pre-BII cells, propensity toward apoptosis or anergization in immature B cells, propensity toward cell division and activation in mature B cells, and stage-specific interactions with stromal cells in the bone marrow.

Standard name | HOFFMANN_LARGE_TO_SMALL_PRE_BII_LYMPHOCYTE_UP
Systematic name | M5588
Organism | Mus musculus
PMID | 11779835
Authors | Hoffmann R,Seidl T,Neeb M,Rolink A,Melchers F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during differentiation from large pre-BII to small pre-BII lymphocyte.
Full description | Gene expression profiles of five consecutive stages of mouse B cell development were generated with high-density oligonucleotide arrays from as few as 2 x 10(4) ex vivo isolated and flow-cytometrically purified cells. Between 2.8% and 6.8% of all genes change on differentiation from one cellular stage to the next by at least twofold. The entire pathway involves differential expression of 10.7% of all genes. Previously known expression patterns of 15 genes (like surrogate light chain, RAG-1/2, MHC class II, mel-14 antigen) are confirmed. The gene expression patterns of the proliferating pre-BI and large pre-BII cells on the one hand, and the resting immature and mature B cells on the other hand, are most similar to each other. Small pre-BII cells display a pattern that is transitional between these two groups. Most of the genes expressed in early precursors are involved in general processes, like protein folding or cell cycle regulation, whereas more mature precursors express genes involved in more specific molecular programs (cell surface receptors, secreted factors, and adhesion molecules, among others). Between 19 and 139 genes share a given expression pattern. Combining knowledge about gene function and expression pattern allows identification of novel candidate genes potentially involved in self-maintenance of pre-BI cells, allelic exclusion and pre-B cell receptor signaling in large pre BII cells, cell-cycle arrest of small pre-BII cells, propensity toward apoptosis or anergization in immature B cells, propensity toward cell division and activation in mature B cells, and stage-specific interactions with stromal cells in the bone marrow.

Standard name | HOFFMANN_LARGE_TO_SMALL_PRE_BII_LYMPHOCYTE_DN
Systematic name | M19523
Organism | Mus musculus
PMID | 11779835
Authors | Hoffmann R,Seidl T,Neeb M,Rolink A,Melchers F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during differentiation from large pre-BII to small pre-BII lymphocyte.
Full description | Gene expression profiles of five consecutive stages of mouse B cell development were generated with high-density oligonucleotide arrays from as few as 2 x 10(4) ex vivo isolated and flow-cytometrically purified cells. Between 2.8% and 6.8% of all genes change on differentiation from one cellular stage to the next by at least twofold. The entire pathway involves differential expression of 10.7% of all genes. Previously known expression patterns of 15 genes (like surrogate light chain, RAG-1/2, MHC class II, mel-14 antigen) are confirmed. The gene expression patterns of the proliferating pre-BI and large pre-BII cells on the one hand, and the resting immature and mature B cells on the other hand, are most similar to each other. Small pre-BII cells display a pattern that is transitional between these two groups. Most of the genes expressed in early precursors are involved in general processes, like protein folding or cell cycle regulation, whereas more mature precursors express genes involved in more specific molecular programs (cell surface receptors, secreted factors, and adhesion molecules, among others). Between 19 and 139 genes share a given expression pattern. Combining knowledge about gene function and expression pattern allows identification of novel candidate genes potentially involved in self-maintenance of pre-BI cells, allelic exclusion and pre-B cell receptor signaling in large pre BII cells, cell-cycle arrest of small pre-BII cells, propensity toward apoptosis or anergization in immature B cells, propensity toward cell division and activation in mature B cells, and stage-specific interactions with stromal cells in the bone marrow.

Standard name | HOFFMANN_SMALL_PRE_BII_TO_IMMATURE_B_LYMPHOCYTE_UP
Systematic name | M13760
Organism | Mus musculus
PMID | 11779835
Authors | Hoffmann R,Seidl T,Neeb M,Rolink A,Melchers F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during differentiation from small pre-BII to immature B lymphocyte.
Full description | Gene expression profiles of five consecutive stages of mouse B cell development were generated with high-density oligonucleotide arrays from as few as 2 x 10(4) ex vivo isolated and flow-cytometrically purified cells. Between 2.8% and 6.8% of all genes change on differentiation from one cellular stage to the next by at least twofold. The entire pathway involves differential expression of 10.7% of all genes. Previously known expression patterns of 15 genes (like surrogate light chain, RAG-1/2, MHC class II, mel-14 antigen) are confirmed. The gene expression patterns of the proliferating pre-BI and large pre-BII cells on the one hand, and the resting immature and mature B cells on the other hand, are most similar to each other. Small pre-BII cells display a pattern that is transitional between these two groups. Most of the genes expressed in early precursors are involved in general processes, like protein folding or cell cycle regulation, whereas more mature precursors express genes involved in more specific molecular programs (cell surface receptors, secreted factors, and adhesion molecules, among others). Between 19 and 139 genes share a given expression pattern. Combining knowledge about gene function and expression pattern allows identification of novel candidate genes potentially involved in self-maintenance of pre-BI cells, allelic exclusion and pre-B cell receptor signaling in large pre BII cells, cell-cycle arrest of small pre-BII cells, propensity toward apoptosis or anergization in immature B cells, propensity toward cell division and activation in mature B cells, and stage-specific interactions with stromal cells in the bone marrow.

Standard name | HOFFMANN_SMALL_PRE_BII_TO_IMMATURE_B_LYMPHOCYTE_DN
Systematic name | M10487
Organism | Mus musculus
PMID | 11779835
Authors | Hoffmann R,Seidl T,Neeb M,Rolink A,Melchers F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during differentiation from small pre-BII to immature B lymphocyte.
Full description | Gene expression profiles of five consecutive stages of mouse B cell development were generated with high-density oligonucleotide arrays from as few as 2 x 10(4) ex vivo isolated and flow-cytometrically purified cells. Between 2.8% and 6.8% of all genes change on differentiation from one cellular stage to the next by at least twofold. The entire pathway involves differential expression of 10.7% of all genes. Previously known expression patterns of 15 genes (like surrogate light chain, RAG-1/2, MHC class II, mel-14 antigen) are confirmed. The gene expression patterns of the proliferating pre-BI and large pre-BII cells on the one hand, and the resting immature and mature B cells on the other hand, are most similar to each other. Small pre-BII cells display a pattern that is transitional between these two groups. Most of the genes expressed in early precursors are involved in general processes, like protein folding or cell cycle regulation, whereas more mature precursors express genes involved in more specific molecular programs (cell surface receptors, secreted factors, and adhesion molecules, among others). Between 19 and 139 genes share a given expression pattern. Combining knowledge about gene function and expression pattern allows identification of novel candidate genes potentially involved in self-maintenance of pre-BI cells, allelic exclusion and pre-B cell receptor signaling in large pre BII cells, cell-cycle arrest of small pre-BII cells, propensity toward apoptosis or anergization in immature B cells, propensity toward cell division and activation in mature B cells, and stage-specific interactions with stromal cells in the bone marrow.

Standard name | HOFFMANN_IMMATURE_TO_MATURE_B_LYMPHOCYTE_UP
Systematic name | M19976
Organism | Mus musculus
PMID | 11779835
Authors | Hoffmann R,Seidl T,Neeb M,Rolink A,Melchers F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during differentiation of immature to mature B lymphocyte.
Full description | Gene expression profiles of five consecutive stages of mouse B cell development were generated with high-density oligonucleotide arrays from as few as 2 x 10(4) ex vivo isolated and flow-cytometrically purified cells. Between 2.8% and 6.8% of all genes change on differentiation from one cellular stage to the next by at least twofold. The entire pathway involves differential expression of 10.7% of all genes. Previously known expression patterns of 15 genes (like surrogate light chain, RAG-1/2, MHC class II, mel-14 antigen) are confirmed. The gene expression patterns of the proliferating pre-BI and large pre-BII cells on the one hand, and the resting immature and mature B cells on the other hand, are most similar to each other. Small pre-BII cells display a pattern that is transitional between these two groups. Most of the genes expressed in early precursors are involved in general processes, like protein folding or cell cycle regulation, whereas more mature precursors express genes involved in more specific molecular programs (cell surface receptors, secreted factors, and adhesion molecules, among others). Between 19 and 139 genes share a given expression pattern. Combining knowledge about gene function and expression pattern allows identification of novel candidate genes potentially involved in self-maintenance of pre-BI cells, allelic exclusion and pre-B cell receptor signaling in large pre BII cells, cell-cycle arrest of small pre-BII cells, propensity toward apoptosis or anergization in immature B cells, propensity toward cell division and activation in mature B cells, and stage-specific interactions with stromal cells in the bone marrow.

Standard name | HOFFMANN_IMMATURE_TO_MATURE_B_LYMPHOCYTE_DN
Systematic name | M4655
Organism | Mus musculus
PMID | 11779835
Authors | Hoffmann R,Seidl T,Neeb M,Rolink A,Melchers F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during differentiation of immature to mature B lymphocyte.
Full description | Gene expression profiles of five consecutive stages of mouse B cell development were generated with high-density oligonucleotide arrays from as few as 2 x 10(4) ex vivo isolated and flow-cytometrically purified cells. Between 2.8% and 6.8% of all genes change on differentiation from one cellular stage to the next by at least twofold. The entire pathway involves differential expression of 10.7% of all genes. Previously known expression patterns of 15 genes (like surrogate light chain, RAG-1/2, MHC class II, mel-14 antigen) are confirmed. The gene expression patterns of the proliferating pre-BI and large pre-BII cells on the one hand, and the resting immature and mature B cells on the other hand, are most similar to each other. Small pre-BII cells display a pattern that is transitional between these two groups. Most of the genes expressed in early precursors are involved in general processes, like protein folding or cell cycle regulation, whereas more mature precursors express genes involved in more specific molecular programs (cell surface receptors, secreted factors, and adhesion molecules, among others). Between 19 and 139 genes share a given expression pattern. Combining knowledge about gene function and expression pattern allows identification of novel candidate genes potentially involved in self-maintenance of pre-BI cells, allelic exclusion and pre-B cell receptor signaling in large pre BII cells, cell-cycle arrest of small pre-BII cells, propensity toward apoptosis or anergization in immature B cells, propensity toward cell division and activation in mature B cells, and stage-specific interactions with stromal cells in the bone marrow.

Standard name | HOFMANN_MYELODYSPLASTIC_SYNDROM_LOW_RISK_UP
Systematic name | M6868
Organism | Homo sapiens
PMID | 12411319
Authors | Hofmann WK,de Vos S,Komor M,Hoelzer D,Wachsman W,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in bone marrow hematopoietic stem cells (HSC, CD34+ [GeneID=947]) from patients with low risk of myelodysplastic syndrome (MDS) compared with healthy controls.
Full description | Gene patterns of expression in purified CD34(+) bone marrow cells from 7 patients with low-risk myelodysplastic syndrome (MDS) and 4 patients with high-risk MDS were compared with expression data from CD34(+) bone marrow cells from 4 healthy control subjects. CD34(+) cells were isolated by magnetic cell separation, and high-density oligonucleotide microarray analysis was performed. For confirmation, the expression of selected genes was analyzed by real-time polymerase chain reaction. Class membership prediction analysis selected 11 genes. Using the expression profile of these genes, we were able to discriminate patients with low-risk from patients with high-risk MDS and both patient groups from the control group by hierarchical clustering (Spearman confidence). The power of these 11 genes was verified by applying the algorithm to an unknown test set containing expression data from 8 additional patients with MDS (3 at low risk, 5 at high risk). Patients at low risk could be distinguished from those at high risk by clustering analysis. In low-risk MDS, we found that the retinoic-acid-induced gene (RAI3), the radiation-inducible, immediate-early response gene (IEX1), and the stress-induced phosphoprotein 1 (STIP1) were down-regulated. These data suggest that CD34(+) cells from patients with low-risk MDS lack defensive proteins, resulting in their susceptibility to cell damage. In summary, we propose that gene expression profiling may have clinical relevance for risk evaluation in MDS at the time of initial diagnosis. Furthermore, this study provides evidence that in MDS, hematopoietic stem cells accumulate defects that prevent normal hematopoiesis.

Standard name | HOFMANN_MYELODYSPLASTIC_SYNDROM_LOW_RISK_DN
Systematic name | M19472
Organism | Homo sapiens
PMID | 12411319
Authors | Hofmann WK,de Vos S,Komor M,Hoelzer D,Wachsman W,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in bone marrow hematopoietic stem cells (HSC, CD34+ [GeneID=947]) from patients with low risk of myelodysplastic syndrome (MDS) compared with healthy controls.
Full description | Gene patterns of expression in purified CD34(+) bone marrow cells from 7 patients with low-risk myelodysplastic syndrome (MDS) and 4 patients with high-risk MDS were compared with expression data from CD34(+) bone marrow cells from 4 healthy control subjects. CD34(+) cells were isolated by magnetic cell separation, and high-density oligonucleotide microarray analysis was performed. For confirmation, the expression of selected genes was analyzed by real-time polymerase chain reaction. Class membership prediction analysis selected 11 genes. Using the expression profile of these genes, we were able to discriminate patients with low-risk from patients with high-risk MDS and both patient groups from the control group by hierarchical clustering (Spearman confidence). The power of these 11 genes was verified by applying the algorithm to an unknown test set containing expression data from 8 additional patients with MDS (3 at low risk, 5 at high risk). Patients at low risk could be distinguished from those at high risk by clustering analysis. In low-risk MDS, we found that the retinoic-acid-induced gene (RAI3), the radiation-inducible, immediate-early response gene (IEX1), and the stress-induced phosphoprotein 1 (STIP1) were down-regulated. These data suggest that CD34(+) cells from patients with low-risk MDS lack defensive proteins, resulting in their susceptibility to cell damage. In summary, we propose that gene expression profiling may have clinical relevance for risk evaluation in MDS at the time of initial diagnosis. Furthermore, this study provides evidence that in MDS, hematopoietic stem cells accumulate defects that prevent normal hematopoiesis.

Standard name | HOFMANN_MYELODYSPLASTIC_SYNDROM_HIGH_RISK_UP
Systematic name | M14215
Organism | Homo sapiens
PMID | 12411319
Authors | Hofmann WK,de Vos S,Komor M,Hoelzer D,Wachsman W,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in bone marrow hematopoietic stem cells (HSC, CD34+ [GeneID=947]) from patients with high risk of myelodysplastic syndrome (MDS) compared with healthy controls.
Full description | Gene patterns of expression in purified CD34(+) bone marrow cells from 7 patients with low-risk myelodysplastic syndrome (MDS) and 4 patients with high-risk MDS were compared with expression data from CD34(+) bone marrow cells from 4 healthy control subjects. CD34(+) cells were isolated by magnetic cell separation, and high-density oligonucleotide microarray analysis was performed. For confirmation, the expression of selected genes was analyzed by real-time polymerase chain reaction. Class membership prediction analysis selected 11 genes. Using the expression profile of these genes, we were able to discriminate patients with low-risk from patients with high-risk MDS and both patient groups from the control group by hierarchical clustering (Spearman confidence). The power of these 11 genes was verified by applying the algorithm to an unknown test set containing expression data from 8 additional patients with MDS (3 at low risk, 5 at high risk). Patients at low risk could be distinguished from those at high risk by clustering analysis. In low-risk MDS, we found that the retinoic-acid-induced gene (RAI3), the radiation-inducible, immediate-early response gene (IEX1), and the stress-induced phosphoprotein 1 (STIP1) were down-regulated. These data suggest that CD34(+) cells from patients with low-risk MDS lack defensive proteins, resulting in their susceptibility to cell damage. In summary, we propose that gene expression profiling may have clinical relevance for risk evaluation in MDS at the time of initial diagnosis. Furthermore, this study provides evidence that in MDS, hematopoietic stem cells accumulate defects that prevent normal hematopoiesis.

Standard name | HOFMANN_MYELODYSPLASTIC_SYNDROM_HIGH_RISK_DN
Systematic name | M5443
Organism | Homo sapiens
PMID | 12411319
Authors | Hofmann WK,de Vos S,Komor M,Hoelzer D,Wachsman W,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in bone marrow hematopoietic stem cells (HSC, CD34+ [GeneID=947]) from patients with high risk of myelodysplastic syndrome (MDS) compared with healthy controls.
Full description | Gene patterns of expression in purified CD34(+) bone marrow cells from 7 patients with low-risk myelodysplastic syndrome (MDS) and 4 patients with high-risk MDS were compared with expression data from CD34(+) bone marrow cells from 4 healthy control subjects. CD34(+) cells were isolated by magnetic cell separation, and high-density oligonucleotide microarray analysis was performed. For confirmation, the expression of selected genes was analyzed by real-time polymerase chain reaction. Class membership prediction analysis selected 11 genes. Using the expression profile of these genes, we were able to discriminate patients with low-risk from patients with high-risk MDS and both patient groups from the control group by hierarchical clustering (Spearman confidence). The power of these 11 genes was verified by applying the algorithm to an unknown test set containing expression data from 8 additional patients with MDS (3 at low risk, 5 at high risk). Patients at low risk could be distinguished from those at high risk by clustering analysis. In low-risk MDS, we found that the retinoic-acid-induced gene (RAI3), the radiation-inducible, immediate-early response gene (IEX1), and the stress-induced phosphoprotein 1 (STIP1) were down-regulated. These data suggest that CD34(+) cells from patients with low-risk MDS lack defensive proteins, resulting in their susceptibility to cell damage. In summary, we propose that gene expression profiling may have clinical relevance for risk evaluation in MDS at the time of initial diagnosis. Furthermore, this study provides evidence that in MDS, hematopoietic stem cells accumulate defects that prevent normal hematopoiesis.

Standard name | HOFMANN_MYELODYSPLASTIC_SYNDROM_RISK_UP
Systematic name | M14742
Organism | Homo sapiens
PMID | 12411319
Authors | Hofmann WK,de Vos S,Komor M,Hoelzer D,Wachsman W,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in bone marrow hematopoietic stem cells (HSC, CD34+ [GeneID=947]) from patients with high risk of myelodysplastic syndrom (MDS) compared to the low risk patients.
Full description | Gene patterns of expression in purified CD34(+) bone marrow cells from 7 patients with low-risk myelodysplastic syndrome (MDS) and 4 patients with high-risk MDS were compared with expression data from CD34(+) bone marrow cells from 4 healthy control subjects. CD34(+) cells were isolated by magnetic cell separation, and high-density oligonucleotide microarray analysis was performed. For confirmation, the expression of selected genes was analyzed by real-time polymerase chain reaction. Class membership prediction analysis selected 11 genes. Using the expression profile of these genes, we were able to discriminate patients with low-risk from patients with high-risk MDS and both patient groups from the control group by hierarchical clustering (Spearman confidence). The power of these 11 genes was verified by applying the algorithm to an unknown test set containing expression data from 8 additional patients with MDS (3 at low risk, 5 at high risk). Patients at low risk could be distinguished from those at high risk by clustering analysis. In low-risk MDS, we found that the retinoic-acid-induced gene (RAI3), the radiation-inducible, immediate-early response gene (IEX1), and the stress-induced phosphoprotein 1 (STIP1) were down-regulated. These data suggest that CD34(+) cells from patients with low-risk MDS lack defensive proteins, resulting in their susceptibility to cell damage. In summary, we propose that gene expression profiling may have clinical relevance for risk evaluation in MDS at the time of initial diagnosis. Furthermore, this study provides evidence that in MDS, hematopoietic stem cells accumulate defects that prevent normal hematopoiesis.

Standard name | HOFMANN_MYELODYSPLASTIC_SYNDROM_RISK_DN
Systematic name | M12153
Organism | Homo sapiens
PMID | 12411319
Authors | Hofmann WK,de Vos S,Komor M,Hoelzer D,Wachsman W,Koeffler HP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in bone marrow hematopoietic stem cells (HSC, CD34+ [GeneID=947]) from patients with high risk of myelodysplastic syndrom (MDS) compared to the low risk patients.
Full description | Gene patterns of expression in purified CD34(+) bone marrow cells from 7 patients with low-risk myelodysplastic syndrome (MDS) and 4 patients with high-risk MDS were compared with expression data from CD34(+) bone marrow cells from 4 healthy control subjects. CD34(+) cells were isolated by magnetic cell separation, and high-density oligonucleotide microarray analysis was performed. For confirmation, the expression of selected genes was analyzed by real-time polymerase chain reaction. Class membership prediction analysis selected 11 genes. Using the expression profile of these genes, we were able to discriminate patients with low-risk from patients with high-risk MDS and both patient groups from the control group by hierarchical clustering (Spearman confidence). The power of these 11 genes was verified by applying the algorithm to an unknown test set containing expression data from 8 additional patients with MDS (3 at low risk, 5 at high risk). Patients at low risk could be distinguished from those at high risk by clustering analysis. In low-risk MDS, we found that the retinoic-acid-induced gene (RAI3), the radiation-inducible, immediate-early response gene (IEX1), and the stress-induced phosphoprotein 1 (STIP1) were down-regulated. These data suggest that CD34(+) cells from patients with low-risk MDS lack defensive proteins, resulting in their susceptibility to cell damage. In summary, we propose that gene expression profiling may have clinical relevance for risk evaluation in MDS at the time of initial diagnosis. Furthermore, this study provides evidence that in MDS, hematopoietic stem cells accumulate defects that prevent normal hematopoiesis.

Standard name | LEE_EARLY_T_LYMPHOCYTE_UP
Systematic name | M7357
Organism | Homo sapiens
PMID | 15210650
Authors | Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated at early stages of progenitor T lymphocyte maturation compared to the late stages.
Full description | To develop a comprehensive catalogue of phenotypic and functional parameters of human CD4(+) T cell differentiation stages, we have performed microarray gene expression profiling on subpopulations of human thymocytes and circulating naive CD4(+) T cells, including CD3(-)CD4(+)CD8(-) intrathymic T progenitor cells, CD3(int)CD4(+)CD8(+) 'double positive' thymocytes, CD3(high)CD4(+)CD8(-) 'single positive' thymocytes, CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from cord blood and CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from adult blood. These subpopulations were sort-purified to >98% purity and their expressed RNAs were analyzed on Affymetrix Human Genome U133 arrays. Comparison of gene expression signals between these subpopulations and with early passage fetal thymic stromal cultures identify: (i) transcripts that are preferentially expressed in human CD4(+) T cell subpopulations and not in thymic stromal cells; (ii) major shifts in gene expression as progenitor T cells mature into progeny; (iii) preferential expression of transcripts at the progenitor cell stage with plausible relevance to the regulation of expansion and differentiation of these cells; and (iv) preferential expression of potential markers of recent thymic emigrants in naive-phenotype CD4(+) T cells from cord blood. Further evaluation of these findings may lead to a better definition of human thymopoiesis as well as to improved approaches to monitor and to augment the function of this important organ of T cell production.

Standard name | LEE_EARLY_T_LYMPHOCYTE_DN
Systematic name | M13767
Organism | Homo sapiens
PMID | 15210650
Authors | Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated at early stages of progenitor T lymphocyte maturation compared to the late stages.
Full description | To develop a comprehensive catalogue of phenotypic and functional parameters of human CD4(+) T cell differentiation stages, we have performed microarray gene expression profiling on subpopulations of human thymocytes and circulating naive CD4(+) T cells, including CD3(-)CD4(+)CD8(-) intrathymic T progenitor cells, CD3(int)CD4(+)CD8(+) 'double positive' thymocytes, CD3(high)CD4(+)CD8(-) 'single positive' thymocytes, CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from cord blood and CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from adult blood. These subpopulations were sort-purified to >98% purity and their expressed RNAs were analyzed on Affymetrix Human Genome U133 arrays. Comparison of gene expression signals between these subpopulations and with early passage fetal thymic stromal cultures identify: (i) transcripts that are preferentially expressed in human CD4(+) T cell subpopulations and not in thymic stromal cells; (ii) major shifts in gene expression as progenitor T cells mature into progeny; (iii) preferential expression of transcripts at the progenitor cell stage with plausible relevance to the regulation of expansion and differentiation of these cells; and (iv) preferential expression of potential markers of recent thymic emigrants in naive-phenotype CD4(+) T cells from cord blood. Further evaluation of these findings may lead to a better definition of human thymopoiesis as well as to improved approaches to monitor and to augment the function of this important organ of T cell production.

Standard name | LEE_INTRATHYMIC_T_PROGENITOR
Systematic name | M8213
Organism | Homo sapiens
PMID | 15210650
Authors | Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM
Category | C2
Sub-category | CGP
Brief description | Genes enriched in the intrathymic T progenitor (ITTP) cells compared to all other T lymphocyte differentiation stages.
Full description | To develop a comprehensive catalogue of phenotypic and functional parameters of human CD4(+) T cell differentiation stages, we have performed microarray gene expression profiling on subpopulations of human thymocytes and circulating naive CD4(+) T cells, including CD3(-)CD4(+)CD8(-) intrathymic T progenitor cells, CD3(int)CD4(+)CD8(+) 'double positive' thymocytes, CD3(high)CD4(+)CD8(-) 'single positive' thymocytes, CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from cord blood and CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from adult blood. These subpopulations were sort-purified to >98% purity and their expressed RNAs were analyzed on Affymetrix Human Genome U133 arrays. Comparison of gene expression signals between these subpopulations and with early passage fetal thymic stromal cultures identify: (i) transcripts that are preferentially expressed in human CD4(+) T cell subpopulations and not in thymic stromal cells; (ii) major shifts in gene expression as progenitor T cells mature into progeny; (iii) preferential expression of transcripts at the progenitor cell stage with plausible relevance to the regulation of expansion and differentiation of these cells; and (iv) preferential expression of potential markers of recent thymic emigrants in naive-phenotype CD4(+) T cells from cord blood. Further evaluation of these findings may lead to a better definition of human thymopoiesis as well as to improved approaches to monitor and to augment the function of this important organ of T cell production.

Standard name | LEE_DOUBLE_POLAR_THYMOCYTE
Systematic name | M17534
Organism | Homo sapiens
PMID | 15210650
Authors | Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM
Category | C2
Sub-category | CGP
Brief description | Genes enriched in the double polar (DP) thymocyte compared to all other T lymphocyte differentiation stages.
Full description | To develop a comprehensive catalogue of phenotypic and functional parameters of human CD4(+) T cell differentiation stages, we have performed microarray gene expression profiling on subpopulations of human thymocytes and circulating naive CD4(+) T cells, including CD3(-)CD4(+)CD8(-) intrathymic T progenitor cells, CD3(int)CD4(+)CD8(+) 'double positive' thymocytes, CD3(high)CD4(+)CD8(-) 'single positive' thymocytes, CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from cord blood and CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from adult blood. These subpopulations were sort-purified to >98% purity and their expressed RNAs were analyzed on Affymetrix Human Genome U133 arrays. Comparison of gene expression signals between these subpopulations and with early passage fetal thymic stromal cultures identify: (i) transcripts that are preferentially expressed in human CD4(+) T cell subpopulations and not in thymic stromal cells; (ii) major shifts in gene expression as progenitor T cells mature into progeny; (iii) preferential expression of transcripts at the progenitor cell stage with plausible relevance to the regulation of expansion and differentiation of these cells; and (iv) preferential expression of potential markers of recent thymic emigrants in naive-phenotype CD4(+) T cells from cord blood. Further evaluation of these findings may lead to a better definition of human thymopoiesis as well as to improved approaches to monitor and to augment the function of this important organ of T cell production.

Standard name | LEE_SP4_THYMOCYTE
Systematic name | M10158
Organism | Homo sapiens
PMID | 15210650
Authors | Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM
Category | C2
Sub-category | CGP
Brief description | Genes enriched in the single positive 4 (SP4) thymocytes compared to all other T lymphocyte differentiation stages.
Full description | To develop a comprehensive catalogue of phenotypic and functional parameters of human CD4(+) T cell differentiation stages, we have performed microarray gene expression profiling on subpopulations of human thymocytes and circulating naive CD4(+) T cells, including CD3(-)CD4(+)CD8(-) intrathymic T progenitor cells, CD3(int)CD4(+)CD8(+) 'double positive' thymocytes, CD3(high)CD4(+)CD8(-) 'single positive' thymocytes, CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from cord blood and CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from adult blood. These subpopulations were sort-purified to >98% purity and their expressed RNAs were analyzed on Affymetrix Human Genome U133 arrays. Comparison of gene expression signals between these subpopulations and with early passage fetal thymic stromal cultures identify: (i) transcripts that are preferentially expressed in human CD4(+) T cell subpopulations and not in thymic stromal cells; (ii) major shifts in gene expression as progenitor T cells mature into progeny; (iii) preferential expression of transcripts at the progenitor cell stage with plausible relevance to the regulation of expansion and differentiation of these cells; and (iv) preferential expression of potential markers of recent thymic emigrants in naive-phenotype CD4(+) T cells from cord blood. Further evaluation of these findings may lead to a better definition of human thymopoiesis as well as to improved approaches to monitor and to augment the function of this important organ of T cell production.

Standard name | LEE_RECENT_THYMIC_EMIGRANT
Systematic name | M17496
Organism | Homo sapiens
PMID | 15210650
Authors | Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM
Category | C2
Sub-category | CGP
Brief description | Candidate genes specific for recent thymic emigrants (RTEs).
Full description | To develop a comprehensive catalogue of phenotypic and functional parameters of human CD4(+) T cell differentiation stages, we have performed microarray gene expression profiling on subpopulations of human thymocytes and circulating naive CD4(+) T cells, including CD3(-)CD4(+)CD8(-) intrathymic T progenitor cells, CD3(int)CD4(+)CD8(+) 'double positive' thymocytes, CD3(high)CD4(+)CD8(-) 'single positive' thymocytes, CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from cord blood and CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from adult blood. These subpopulations were sort-purified to >98% purity and their expressed RNAs were analyzed on Affymetrix Human Genome U133 arrays. Comparison of gene expression signals between these subpopulations and with early passage fetal thymic stromal cultures identify: (i) transcripts that are preferentially expressed in human CD4(+) T cell subpopulations and not in thymic stromal cells; (ii) major shifts in gene expression as progenitor T cells mature into progeny; (iii) preferential expression of transcripts at the progenitor cell stage with plausible relevance to the regulation of expansion and differentiation of these cells; and (iv) preferential expression of potential markers of recent thymic emigrants in naive-phenotype CD4(+) T cells from cord blood. Further evaluation of these findings may lead to a better definition of human thymopoiesis as well as to improved approaches to monitor and to augment the function of this important organ of T cell production.

Standard name | LEE_NAIVE_T_LYMPHOCYTE
Systematic name | M12367
Organism | Homo sapiens
PMID | 15210650
Authors | Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM
Category | C2
Sub-category | CGP
Brief description | Genes enriched in the naive circulating T lymphocytes compared to the earlier differentiation stages.
Full description | To develop a comprehensive catalogue of phenotypic and functional parameters of human CD4(+) T cell differentiation stages, we have performed microarray gene expression profiling on subpopulations of human thymocytes and circulating naive CD4(+) T cells, including CD3(-)CD4(+)CD8(-) intrathymic T progenitor cells, CD3(int)CD4(+)CD8(+) 'double positive' thymocytes, CD3(high)CD4(+)CD8(-) 'single positive' thymocytes, CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from cord blood and CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from adult blood. These subpopulations were sort-purified to >98% purity and their expressed RNAs were analyzed on Affymetrix Human Genome U133 arrays. Comparison of gene expression signals between these subpopulations and with early passage fetal thymic stromal cultures identify: (i) transcripts that are preferentially expressed in human CD4(+) T cell subpopulations and not in thymic stromal cells; (ii) major shifts in gene expression as progenitor T cells mature into progeny; (iii) preferential expression of transcripts at the progenitor cell stage with plausible relevance to the regulation of expansion and differentiation of these cells; and (iv) preferential expression of potential markers of recent thymic emigrants in naive-phenotype CD4(+) T cells from cord blood. Further evaluation of these findings may lead to a better definition of human thymopoiesis as well as to improved approaches to monitor and to augment the function of this important organ of T cell production.

Standard name | LEE_DIFFERENTIATING_T_LYMPHOCYTE
Systematic name | M2200
Organism | Homo sapiens
PMID | 15210650
Authors | Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM
Category | C2
Sub-category | CGP
Brief description | Genes enriched at every T lymphocyte differentiation stage compared to the early passage fetal thymic stromal cultures (TSC).
Full description | To develop a comprehensive catalogue of phenotypic and functional parameters of human CD4(+) T cell differentiation stages, we have performed microarray gene expression profiling on subpopulations of human thymocytes and circulating naive CD4(+) T cells, including CD3(-)CD4(+)CD8(-) intrathymic T progenitor cells, CD3(int)CD4(+)CD8(+) 'double positive' thymocytes, CD3(high)CD4(+)CD8(-) 'single positive' thymocytes, CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from cord blood and CD3(+)CD4(+)CD8(-) CD45RA(+)CD62L(+) naive T cells from adult blood. These subpopulations were sort-purified to >98% purity and their expressed RNAs were analyzed on Affymetrix Human Genome U133 arrays. Comparison of gene expression signals between these subpopulations and with early passage fetal thymic stromal cultures identify: (i) transcripts that are preferentially expressed in human CD4(+) T cell subpopulations and not in thymic stromal cells; (ii) major shifts in gene expression as progenitor T cells mature into progeny; (iii) preferential expression of transcripts at the progenitor cell stage with plausible relevance to the regulation of expansion and differentiation of these cells; and (iv) preferential expression of potential markers of recent thymic emigrants in naive-phenotype CD4(+) T cells from cord blood. Further evaluation of these findings may lead to a better definition of human thymopoiesis as well as to improved approaches to monitor and to augment the function of this important organ of T cell production.

Standard name | LI_WILMS_TUMOR
Systematic name | M10773
Organism | Homo sapiens
PMID | 12057921
Authors | Li CM,Guo M,Borczuk A,Powell CA,Wei M,Thaker HM,Friedman R,Klein U,Tycko B
Category | C2
Sub-category | CGP
Brief description | 'Wilm's tumor signature': genes highly expressed in Wilm's tumor samples compared to normal fetal kidney and a heterologous tumor, Burkit lymphoma.
Full description | Wilms' tumor (WT) has been considered a prototype for arrested cellular differentiation in cancer, but previous studies have relied on selected markers. We have now performed an unbiased survey of gene expression in WTs using oligonucleotide microarrays. Statistical criteria identified 357 genes as differentially expressed between WTs and fetal kidneys. This set contained 124 matches to genes on a microarray used by Stuart and colleagues (Stuart RO, Bush KT, Nigam SK: Changes in global gene expression patterns during development and maturation of the rat kidney. Proc Natl Acad Sci USA 2001, 98:5649-5654) to establish genes with stage-specific expression in the developing rat kidney. Mapping between the two data sets showed that WTs systematically overexpressed genes corresponding to the earliest stage of metanephric development, and underexpressed genes corresponding to later stages. Automated clustering identified a smaller group of 27 genes that were highly expressed in WTs compared to fetal kidney and heterologous tumor and normal tissues. This signature set was enriched in genes encoding transcription factors. Four of these, PAX2, EYA1, HBF2, and HOXA11, are essential for cell survival and proliferation in early metanephric development, whereas others, including SIX1, MOX1, and SALL2, are predicted to act at this stage. SIX1 and SALL2 proteins were expressed in the condensing mesenchyme in normal human fetal kidneys, but were absent (SIX1) or reduced (SALL2) in cells at other developmental stages. These data imply that the blastema in WTs has progressed to the committed stage in the mesenchymal-epithelial transition, where it is partially arrested in differentiation. The WT-signature set also contained the Wnt receptor FZD7, the tumor antigen PRAME, the imprinted gene NNAT and the metastasis-associated transcription factor E1AF.

Standard name | FINAK_BREAST_CANCER_SDPP_SIGNATURE
Systematic name | M12461
Organism | Homo sapiens
PMID | 18438415
Authors | Finak G,Bertos N,Pepin F,Sadekova S,Souleimanova M,Zhao H,Chen H,Omeroglu G,Meterissian S,Omeroglu A,Hallett M,Park M
Category | C2
Sub-category | CGP
Brief description | Genes in the stroma-derived prognostic predictor of breast cancer disease outcome.
Full description | Although it is increasingly evident that cancer is influenced by signals emanating from tumor stroma, little is known regarding how changes in stromal gene expression affect epithelial tumor progression. We used laser capture microdissection to compare gene expression profiles of tumor stroma from 53 primary breast tumors and derived signatures strongly associated with clinical outcome. We present a new stroma-derived prognostic predictor (SDPP) that stratifies disease outcome independently of standard clinical prognostic factors and published expression-based predictors. The SDPP predicts outcome in several published whole tumor-derived expression data sets, identifies poor-outcome individuals from multiple clinical subtypes, including lymph node-negative tumors, and shows increased accuracy with respect to previously published predictors, especially for HER2-positive tumors. Prognostic power increases substantially when the predictor is combined with existing outcome predictors. Genes represented in the SDPP reveal the strong prognostic capacity of differential immune responses as well as angiogenic and hypoxic responses, highlighting the importance of stromal biology in tumor progression.

Standard name | SHEDDEN_LUNG_CANCER_POOR_SURVIVAL_A6
Systematic name | M8520
Organism | Homo sapiens
PMID | 18641660
Authors | Director's Challenge Consortium for the Molecular Classification of Lung Adenocarcinoma,Shedden K,Taylor JM,Enkemann SA,Tsao MS,Yeatman TJ,Gerald WL,Eschrich S,Jurisica I,Giordano TJ,Misek DE,Chang AC,Zhu CQ,Strumpf D,Hanash S,Shepherd FA,Ding K,Seymour L,Naoki K,Pennell N,Weir B,Verhaak R,Ladd-Acosta C,Golub T,Gruidl M,Sharma A,Szoke J,Zakowski M,Rusch V,Kris M,Viale A,Motoi N,Travis W,Conley B,Seshan VE,Meyerson M,Kuick R,Dobbin KK,Lively T,Jacobson JW,Beer DG
Category | C2
Sub-category | CGP
Brief description | Cluster 6 of method A: up-regulation of these genes in patients with non-small cell lung cancer (NSCLC) predicts poor survival outcome.
Full description | Although prognostic gene expression signatures for survival in early-stage lung cancer have been proposed, for clinical application, it is critical to establish their performance across different subject populations and in different laboratories. Here we report a large, training-testing, multi-site, blinded validation study to characterize the performance of several prognostic models based on gene expression for 442 lung adenocarcinomas. The hypotheses proposed examined whether microarray measurements of gene expression either alone or combined with basic clinical covariates (stage, age, sex) could be used to predict overall survival in lung cancer subjects. Several models examined produced risk scores that substantially correlated with actual subject outcome. Most methods performed better with clinical data, supporting the combined use of clinical and molecular information when building prognostic models for early-stage lung cancer. This study also provides the largest available set of microarray data with extensive pathological and clinical annotation for lung adenocarcinomas.

Standard name | SHEDDEN_LUNG_CANCER_GOOD_SURVIVAL_A4
Systematic name | M12824
Organism | Homo sapiens
PMID | 18641660
Authors | Director's Challenge Consortium for the Molecular Classification of Lung Adenocarcinoma,Shedden K,Taylor JM,Enkemann SA,Tsao MS,Yeatman TJ,Gerald WL,Eschrich S,Jurisica I,Giordano TJ,Misek DE,Chang AC,Zhu CQ,Strumpf D,Hanash S,Shepherd FA,Ding K,Seymour L,Naoki K,Pennell N,Weir B,Verhaak R,Ladd-Acosta C,Golub T,Gruidl M,Sharma A,Szoke J,Zakowski M,Rusch V,Kris M,Viale A,Motoi N,Travis W,Conley B,Seshan VE,Meyerson M,Kuick R,Dobbin KK,Lively T,Jacobson JW,Beer DG
Category | C2
Sub-category | CGP
Brief description | Cluster 4 of method A: up-regulation of these genes in patients with non-small cell lung cancer (NSCLC) predicts good survival outcome.
Full description | Although prognostic gene expression signatures for survival in early-stage lung cancer have been proposed, for clinical application, it is critical to establish their performance across different subject populations and in different laboratories. Here we report a large, training-testing, multi-site, blinded validation study to characterize the performance of several prognostic models based on gene expression for 442 lung adenocarcinomas. The hypotheses proposed examined whether microarray measurements of gene expression either alone or combined with basic clinical covariates (stage, age, sex) could be used to predict overall survival in lung cancer subjects. Several models examined produced risk scores that substantially correlated with actual subject outcome. Most methods performed better with clinical data, supporting the combined use of clinical and molecular information when building prognostic models for early-stage lung cancer. This study also provides the largest available set of microarray data with extensive pathological and clinical annotation for lung adenocarcinomas.

Standard name | BRUNEAU_SEPTATION_ATRIAL
Systematic name | M5223
Organism | Homo sapiens
PMID | 18288184
Authors | Bruneau BG
Category | C2
Sub-category | CGP
Brief description | Genes for which mutations result in atrial septation defects, a major class of congenital heart disease.
Full description | Congenital heart disease is the leading cause of infant morbidity in the Western world, but only in the past ten years has its aetiology been understood. Recent studies have uncovered the genetic basis for some common forms of the disease and provide new insight into how the heart develops and how dysregulation of heart development leads to disease.

Standard name | SHEDDEN_LUNG_CANCER_GOOD_SURVIVAL_A5
Systematic name | M12001
Organism | Homo sapiens
PMID | 18641660
Authors | Director's Challenge Consortium for the Molecular Classification of Lung Adenocarcinoma,Shedden K,Taylor JM,Enkemann SA,Tsao MS,Yeatman TJ,Gerald WL,Eschrich S,Jurisica I,Giordano TJ,Misek DE,Chang AC,Zhu CQ,Strumpf D,Hanash S,Shepherd FA,Ding K,Seymour L,Naoki K,Pennell N,Weir B,Verhaak R,Ladd-Acosta C,Golub T,Gruidl M,Sharma A,Szoke J,Zakowski M,Rusch V,Kris M,Viale A,Motoi N,Travis W,Conley B,Seshan VE,Meyerson M,Kuick R,Dobbin KK,Lively T,Jacobson JW,Beer DG
Category | C2
Sub-category | CGP
Brief description | Cluster 5 of method A: up-regulation of these genes in patients with non-small cell lung cancer (NSCLC) predicts good survival outcome.
Full description | Although prognostic gene expression signatures for survival in early-stage lung cancer have been proposed, for clinical application, it is critical to establish their performance across different subject populations and in different laboratories. Here we report a large, training-testing, multi-site, blinded validation study to characterize the performance of several prognostic models based on gene expression for 442 lung adenocarcinomas. The hypotheses proposed examined whether microarray measurements of gene expression either alone or combined with basic clinical covariates (stage, age, sex) could be used to predict overall survival in lung cancer subjects. Several models examined produced risk scores that substantially correlated with actual subject outcome. Most methods performed better with clinical data, supporting the combined use of clinical and molecular information when building prognostic models for early-stage lung cancer. This study also provides the largest available set of microarray data with extensive pathological and clinical annotation for lung adenocarcinomas.

Standard name | BRUNEAU_SEPTATION_VENTRICULAR
Systematic name | M11865
Organism | Homo sapiens
PMID | 18288184
Authors | Bruneau BG
Category | C2
Sub-category | CGP
Brief description | Genes for which mutations result in developmental defects in ventricular septation and atrioventricular cushion formation, a major class of congenital heart disease.
Full description | Congenital heart disease is the leading cause of infant morbidity in the Western world, but only in the past ten years has its aetiology been understood. Recent studies have uncovered the genetic basis for some common forms of the disease and provide new insight into how the heart develops and how dysregulation of heart development leads to disease.

Standard name | BRUNEAU_HEART_GREAT_VESSELS_AND_VALVULOGENESIS
Systematic name | M9884
Organism | Homo sapiens
PMID | 18288184
Authors | Bruneau BG
Category | C2
Sub-category | CGP
Brief description | Genes for which mutations result in developmental defects in the great vessels formation and valvulogenesis, a major class of congenital heart disease.
Full description | Congenital heart disease is the leading cause of infant morbidity in the Western world, but only in the past ten years has its aetiology been understood. Recent studies have uncovered the genetic basis for some common forms of the disease and provide new insight into how the heart develops and how dysregulation of heart development leads to disease.

Standard name | MELLMAN_TUT1_TARGETS_UP
Systematic name | M18377
Organism | Homo sapiens
PMID | 18288197
Authors | Mellman DL,Gonzales ML,Song C,Barlow CA,Wang P,Kendziorski C,Anderson RA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HEK293 cells (embryo kidney) after knockdown of TUT1 [GeneID=64852] by RNAi.
Full description | Phosphoinositides are a family of lipid signalling molecules that regulate many cellular functions in eukaryotes. Phosphatidylinositol-4,5-bisphosphate (PtdIns4,5P2), the central component in the phosphoinositide signalling circuitry, is generated primarily by type I phosphatidylinositol 4-phosphate 5-kinases (PIPKIalpha, PIPKIbeta and PIPKIgamma). In addition to functions in the cytosol, phosphoinositides are present in the nucleus, where they modulate several functions; however, the mechanism by which they directly regulate nuclear functions remains unknown. PIPKIs regulate cellular functions through interactions with protein partners, often PtdIns4,5P2 effectors, that target PIPKIs to discrete subcellular compartments, resulting in the spatial and temporal generation of PtdIns4,5P2 required for the regulation of specific signalling pathways. Therefore, to determine roles for nuclear PtdIns4,5P2 we set out to identify proteins that interacted with the nuclear PIPK, PIPKIalpha. Here we show that PIPKIalpha co-localizes at nuclear speckles and interacts with a newly identified non-canonical poly(A) polymerase, which we have termed Star-PAP (nuclear speckle targeted PIPKIalpha regulated-poly(A) polymerase) and that the activity of Star-PAP can be specifically regulated by PtdIns4,5P2. Star-PAP and PIPKIalpha function together in a complex to control the expression of select mRNAs, including the transcript encoding the key cytoprotective enzyme haem oxygenase-1 (refs 8, 9) and other oxidative stress response genes by regulating the 3'-end formation of their mRNAs. Taken together, the data demonstrate a model by which phosphoinositide signalling works in tandem with complement pathways to regulate the activity of Star-PAP and the subsequent biosynthesis of its target mRNA. The results reveal a mechanism for the integration of nuclear phosphoinositide signals and a method for regulating gene expression.

Standard name | MELLMAN_TUT1_TARGETS_DN
Systematic name | M16335
Organism | Homo sapiens
PMID | 18288197
Authors | Mellman DL,Gonzales ML,Song C,Barlow CA,Wang P,Kendziorski C,Anderson RA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HEK293 cells (embryo kidney) after knockdown of TUT1 [GeneID=64852] by RNAi.
Full description | Phosphoinositides are a family of lipid signalling molecules that regulate many cellular functions in eukaryotes. Phosphatidylinositol-4,5-bisphosphate (PtdIns4,5P2), the central component in the phosphoinositide signalling circuitry, is generated primarily by type I phosphatidylinositol 4-phosphate 5-kinases (PIPKIalpha, PIPKIbeta and PIPKIgamma). In addition to functions in the cytosol, phosphoinositides are present in the nucleus, where they modulate several functions; however, the mechanism by which they directly regulate nuclear functions remains unknown. PIPKIs regulate cellular functions through interactions with protein partners, often PtdIns4,5P2 effectors, that target PIPKIs to discrete subcellular compartments, resulting in the spatial and temporal generation of PtdIns4,5P2 required for the regulation of specific signalling pathways. Therefore, to determine roles for nuclear PtdIns4,5P2 we set out to identify proteins that interacted with the nuclear PIPK, PIPKIalpha. Here we show that PIPKIalpha co-localizes at nuclear speckles and interacts with a newly identified non-canonical poly(A) polymerase, which we have termed Star-PAP (nuclear speckle targeted PIPKIalpha regulated-poly(A) polymerase) and that the activity of Star-PAP can be specifically regulated by PtdIns4,5P2. Star-PAP and PIPKIalpha function together in a complex to control the expression of select mRNAs, including the transcript encoding the key cytoprotective enzyme haem oxygenase-1 (refs 8, 9) and other oxidative stress response genes by regulating the 3'-end formation of their mRNAs. Taken together, the data demonstrate a model by which phosphoinositide signalling works in tandem with complement pathways to regulate the activity of Star-PAP and the subsequent biosynthesis of its target mRNA. The results reveal a mechanism for the integration of nuclear phosphoinositide signals and a method for regulating gene expression.

Standard name | HAN_SATB1_TARGETS_UP
Systematic name | M9639
Organism | Homo sapiens
PMID | 18337816
Authors | Han HJ,Russo J,Kohwi Y,Kohwi-Shigematsu T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MDA-MB-231 cells (breast cancer) after knockdown of SATB1 [GeneID=6304] by RNAi.
Full description | Mechanisms underlying global changes in gene expression during tumour progression are poorly understood. SATB1 is a genome organizer that tethers multiple genomic loci and recruits chromatin-remodelling enzymes to regulate chromatin structure and gene expression. Here we show that SATB1 is expressed by aggressive breast cancer cells and its expression level has high prognostic significance (P < 0.0001), independent of lymph-node status. RNA-interference-mediated knockdown of SATB1 in highly aggressive (MDA-MB-231) cancer cells altered the expression of >1,000 genes, reversing tumorigenesis by restoring breast-like acinar polarity and inhibiting tumour growth and metastasis in vivo. Conversely, ectopic SATB1 expression in non-aggressive (SKBR3) cells led to gene expression patterns consistent with aggressive-tumour phenotypes, acquiring metastatic activity in vivo. SATB1 delineates specific epigenetic modifications at target gene loci, directly upregulating metastasis-associated genes while downregulating tumour-suppressor genes. SATB1 reprogrammes chromatin organization and the transcription profiles of breast tumours to promote growth and metastasis; this is a new mechanism of tumour progression.

Standard name | HAN_SATB1_TARGETS_DN
Systematic name | M15491
Organism | Homo sapiens
PMID | 18337816
Authors | Han HJ,Russo J,Kohwi Y,Kohwi-Shigematsu T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MDA-MB-231 cells (breast cancer) after knockdown of SATB1 [GeneID=6304] by RNAi.
Full description | Mechanisms underlying global changes in gene expression during tumour progression are poorly understood. SATB1 is a genome organizer that tethers multiple genomic loci and recruits chromatin-remodelling enzymes to regulate chromatin structure and gene expression. Here we show that SATB1 is expressed by aggressive breast cancer cells and its expression level has high prognostic significance (P < 0.0001), independent of lymph-node status. RNA-interference-mediated knockdown of SATB1 in highly aggressive (MDA-MB-231) cancer cells altered the expression of >1,000 genes, reversing tumorigenesis by restoring breast-like acinar polarity and inhibiting tumour growth and metastasis in vivo. Conversely, ectopic SATB1 expression in non-aggressive (SKBR3) cells led to gene expression patterns consistent with aggressive-tumour phenotypes, acquiring metastatic activity in vivo. SATB1 delineates specific epigenetic modifications at target gene loci, directly upregulating metastasis-associated genes while downregulating tumour-suppressor genes. SATB1 reprogrammes chromatin organization and the transcription profiles of breast tumours to promote growth and metastasis; this is a new mechanism of tumour progression.

Standard name | SHEDDEN_LUNG_CANCER_GOOD_SURVIVAL_A12
Systematic name | M2429
Organism | Homo sapiens
PMID | 18641660
Authors | Director's Challenge Consortium for the Molecular Classification of Lung Adenocarcinoma,Shedden K,Taylor JM,Enkemann SA,Tsao MS,Yeatman TJ,Gerald WL,Eschrich S,Jurisica I,Giordano TJ,Misek DE,Chang AC,Zhu CQ,Strumpf D,Hanash S,Shepherd FA,Ding K,Seymour L,Naoki K,Pennell N,Weir B,Verhaak R,Ladd-Acosta C,Golub T,Gruidl M,Sharma A,Szoke J,Zakowski M,Rusch V,Kris M,Viale A,Motoi N,Travis W,Conley B,Seshan VE,Meyerson M,Kuick R,Dobbin KK,Lively T,Jacobson JW,Beer DG
Category | C2
Sub-category | CGP
Brief description | Cluster 12 of method A: up-regulation of these genes in patients with non-small cell lung cancer (NSCLC) predicts good survival outcome.
Full description | Although prognostic gene expression signatures for survival in early-stage lung cancer have been proposed, for clinical application, it is critical to establish their performance across different subject populations and in different laboratories. Here we report a large, training-testing, multi-site, blinded validation study to characterize the performance of several prognostic models based on gene expression for 442 lung adenocarcinomas. The hypotheses proposed examined whether microarray measurements of gene expression either alone or combined with basic clinical covariates (stage, age, sex) could be used to predict overall survival in lung cancer subjects. Several models examined produced risk scores that substantially correlated with actual subject outcome. Most methods performed better with clinical data, supporting the combined use of clinical and molecular information when building prognostic models for early-stage lung cancer. This study also provides the largest available set of microarray data with extensive pathological and clinical annotation for lung adenocarcinomas.

Standard name | COLINA_TARGETS_OF_4EBP1_AND_4EBP2
Systematic name | M1919
Organism | Mus musculus
PMID | 18272964
Authors | Colina R,Costa-Mattioli M,Dowling RJ,Jaramillo M,Tai LH,Breitbach CJ,Martineau Y,Larsson O,Rong L,Svitkin YV,Makrigiannis AP,Bell JC,Sonenberg N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) with double knockout of the translation repressors 4EBP1 [GeneID=1978] and 4EBP2 [GeneID=1979].
Full description | Transcriptional activation of cytokines, such as type-I interferons (interferon (IFN)-alpha and IFN-beta), constitutes the first line of antiviral defence. Here we show that translational control is critical for induction of type-I IFN production. In mouse embryonic fibroblasts lacking the translational repressors 4E-BP1 and 4E-BP2, the threshold for eliciting type-I IFN production is lowered. Consequently, replication of encephalomyocarditis virus, vesicular stomatitis virus, influenza virus and Sindbis virus is markedly suppressed. Furthermore, mice with both 4E- and 4E-BP2 genes (also known as Eif4ebp1 and Eif4ebp2, respectively) knocked out are resistant to vesicular stomatitis virus infection, and this correlates with an enhanced type-I IFN production in plasmacytoid dendritic cells and the expression of IFN-regulated genes in the lungs. The enhanced type-I IFN response in 4E-BP1-/- 4E-BP2-/- double knockout mouse embryonic fibroblasts is caused by upregulation of interferon regulatory factor 7 (Irf7) messenger RNA translation. These findings highlight the role of 4E-BPs as negative regulators of type-I IFN production, via translational repression of Irf7 mRNA.

Standard name | CHEN_METABOLIC_SYNDROM_NETWORK
Systematic name | M1920
Organism | Mus musculus
PMID | 18344982
Authors | Chen Y,Zhu J,Lum PY,Yang X,Pinto S,MacNeil DJ,Zhang C,Lamb J,Edwards S,Sieberts SK,Leonardson A,Castellini LW,Wang S,Champy MF,Zhang B,Emilsson V,Doss S,Ghazalpour A,Horvath S,Drake TA,Lusis AJ,Schadt EE
Category | C2
Sub-category | CGP
Brief description | Genes forming the macrophage-enriched metabolic network (MEMN) claimed to have a causal relationship with the metabolic syndrom traits.
Full description | Identifying variations in DNA that increase susceptibility to disease is one of the primary aims of genetic studies using a forward genetics approach. However, identification of disease-susceptibility genes by means of such studies provides limited functional information on how genes lead to disease. In fact, in most cases there is an absence of functional information altogether, preventing a definitive identification of the susceptibility gene or genes. Here we develop an alternative to the classic forward genetics approach for dissecting complex disease traits where, instead of identifying susceptibility genes directly affected by variations in DNA, we identify gene networks that are perturbed by susceptibility loci and that in turn lead to disease. Application of this method to liver and adipose gene expression data generated from a segregating mouse population results in the identification of a macrophage-enriched network supported as having a causal relationship with disease traits associated with metabolic syndrome. Three genes in this network, lipoprotein lipase (Lpl), lactamase beta (Lactb) and protein phosphatase 1-like (Ppm1l), are validated as previously unknown obesity genes, strengthening the association between this network and metabolic disease traits. Our analysis provides direct experimental support that complex traits such as obesity are emergent properties of molecular networks that are modulated by complex genetic loci and environmental factors.

Standard name | MCMURRAY_TP53_HRAS_COOPERATION_RESPONSE_UP
Systematic name | M7034
Organism | Mus musculus
PMID | 18500333
Authors | McMurray HR,Sampson ER,Compitello G,Kinsey C,Newman L,Smith B,Chen SR,Klebanov L,Salzman P,Yakovlev A,Land H
Category | C2
Sub-category | CGP
Brief description | Up-regulated 'cooperation response genes': responded synergystically to the combination of mutant TP53 and HRAS [GeneID=7157;3265] in YAMC cells (colon).
Full description | Understanding the molecular underpinnings of cancer is of critical importance to the development of targeted intervention strategies. Identification of such targets, however, is notoriously difficult and unpredictable. Malignant cell transformation requires the cooperation of a few oncogenic mutations that cause substantial reorganization of many cell features and induce complex changes in gene expression patterns. Genes critical to this multifaceted cellular phenotype have therefore only been identified after signalling pathway analysis or on an ad hoc basis. Our observations that cell transformation by cooperating oncogenic lesions depends on synergistic modulation of downstream signalling circuitry suggest that malignant transformation is a highly cooperative process, involving synergy at multiple levels of regulation, including gene expression. Here we show that a large proportion of genes controlled synergistically by loss-of-function p53 and Ras activation are critical to the malignant state of murine and human colon cells. Notably, 14 out of 24 'cooperation response genes' were found to contribute to tumour formation in gene perturbation experiments. In contrast, only 1 in 14 perturbations of the genes responding in a non-synergistic manner had a similar effect. Synergistic control of gene expression by oncogenic mutations thus emerges as an underlying key to malignancy, and provides an attractive rationale for identifying intervention targets in gene networks downstream of oncogenic gain- and loss-of-function mutations.

Standard name | MCMURRAY_TP53_HRAS_COOPERATION_RESPONSE_DN
Systematic name | M9325
Organism | Mus musculus
PMID | 18500333
Authors | McMurray HR,Sampson ER,Compitello G,Kinsey C,Newman L,Smith B,Chen SR,Klebanov L,Salzman P,Yakovlev A,Land H
Category | C2
Sub-category | CGP
Brief description | Down-regulated 'cooperation response genes': responded synergystically to the combination of mutant TP53 and HRAS [GeneID=7157;3265] in YAMC cells (colon).
Full description | Understanding the molecular underpinnings of cancer is of critical importance to the development of targeted intervention strategies. Identification of such targets, however, is notoriously difficult and unpredictable. Malignant cell transformation requires the cooperation of a few oncogenic mutations that cause substantial reorganization of many cell features and induce complex changes in gene expression patterns. Genes critical to this multifaceted cellular phenotype have therefore only been identified after signalling pathway analysis or on an ad hoc basis. Our observations that cell transformation by cooperating oncogenic lesions depends on synergistic modulation of downstream signalling circuitry suggest that malignant transformation is a highly cooperative process, involving synergy at multiple levels of regulation, including gene expression. Here we show that a large proportion of genes controlled synergistically by loss-of-function p53 and Ras activation are critical to the malignant state of murine and human colon cells. Notably, 14 out of 24 'cooperation response genes' were found to contribute to tumour formation in gene perturbation experiments. In contrast, only 1 in 14 perturbations of the genes responding in a non-synergistic manner had a similar effect. Synergistic control of gene expression by oncogenic mutations thus emerges as an underlying key to malignancy, and provides an attractive rationale for identifying intervention targets in gene networks downstream of oncogenic gain- and loss-of-function mutations.

Standard name | MIKKELSEN_PLURIPOTENT_STATE_UP
Systematic name | M1922
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the induced pluripotent cells (iPS) and embryonic stem cells (ES) compared to the parental lineage-committed and partially reprogrammed cell lines.
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_PLURIPOTENT_STATE_DN
Systematic name | M1923
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the induced pluripotent cells (iPS) and embryonic stem cells (ES) compared to the parental lineage-committed and partially reprogrammed cell lines.
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_DEDIFFERENTIATED_STATE_UP
Systematic name | M1924
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in partially reprogrammed and pluripotent cell populations (induced, iPS; and embryonic stem cells, ES) compared to parental lineage-commited cell lines.
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_DEDIFFERENTIATED_STATE_DN
Systematic name | M1927
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in partially reprogrammed and pluripotent cell populations (induced, iPS; and embryonic stem cells, ES) compared to parental lineage-commited cell lines.
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_PARTIALLY_REPROGRAMMED_TO_PLURIPOTENCY
Systematic name | M1928
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in cells that have been partially reprogrammed to pluripotency: comparison with the parental lineage-committed cell lines, fully reprogrammed stem cells, and embryonic stem cells.
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | ELLWOOD_MYC_TARGETS_UP
Systematic name | M2607
Organism | Mus musculus
PMID | 14522256
Authors | Ellwood-Yen K,Graeber TG,Wongvipat J,Iruela-Arispe ML,Zhang J,Matusik R,Thomas GV,Sawyers CL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in transgenic mice expressing human MYC [GeneID=4609] in prostate.
Full description | Increased Myc gene copy number is observed in human prostate cancer. To define Myc's functional role, we generated transgenic mice expressing human c-Myc in the mouse prostate. All mice developed murine prostatic intraepithelial neoplasia followed by invasive adenocarcinoma. Microarray-based expression profiling identified a Myc prostate cancer expression signature, which included the putative human tumor suppressor NXK3.1. Human prostate tumor databases revealed modules of human genes that varied in concert with the Myc prostate cancer signature. This module includes the Pim-1 kinase, a gene known to cooperate with Myc in tumorigenesis, and defines a subset of human, Myc-like human cancers. This approach illustrates how genomic technologies can be applied to mouse cancer models to guide evaluation of human tumor databases.

Standard name | ELLWOOD_MYC_TARGETS_DN
Systematic name | M6951
Organism | Mus musculus
PMID | 14522256
Authors | Ellwood-Yen K,Graeber TG,Wongvipat J,Iruela-Arispe ML,Zhang J,Matusik R,Thomas GV,Sawyers CL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in transgenic mice expressing human MYC [GeneID=4609] in prostate.
Full description | Increased Myc gene copy number is observed in human prostate cancer. To define Myc's functional role, we generated transgenic mice expressing human c-Myc in the mouse prostate. All mice developed murine prostatic intraepithelial neoplasia followed by invasive adenocarcinoma. Microarray-based expression profiling identified a Myc prostate cancer expression signature, which included the putative human tumor suppressor NXK3.1. Human prostate tumor databases revealed modules of human genes that varied in concert with the Myc prostate cancer signature. This module includes the Pim-1 kinase, a gene known to cooperate with Myc in tumorigenesis, and defines a subset of human, Myc-like human cancers. This approach illustrates how genomic technologies can be applied to mouse cancer models to guide evaluation of human tumor databases.

Standard name | SHAFFER_IRF4_MULTIPLE_MYELOMA_PROGRAM
Systematic name | M16679
Organism | Homo sapiens
PMID | 18568025
Authors | Shaffer AL,Emre NC,Lamy L,Ngo VN,Wright G,Xiao W,Powell J,Dave S,Yu X,Zhao H,Zeng Y,Chen B,Epstein J,Staudt LM
Category | C2
Sub-category | CGP
Brief description | Direct targets of IRF4 [GeneID=3662] that constitute a multiple myeloma program.
Full description | The transcription factor IRF4 (interferon regulatory factor 4) is required during an immune response for lymphocyte activation and the generation of immunoglobulin-secreting plasma cells. Multiple myeloma, a malignancy of plasma cells, has a complex molecular aetiology with several subgroups defined by gene expression profiling and recurrent chromosomal translocations. Moreover, the malignant clone can sustain multiple oncogenic lesions, accumulating genetic damage as the disease progresses. Current therapies for myeloma can extend survival but are not curative. Hence, new therapeutic strategies are needed that target molecular pathways shared by all subtypes of myeloma. Here we show, using a loss-of-function, RNA-interference-based genetic screen, that IRF4 inhibition is toxic to myeloma cell lines, regardless of transforming oncogenic mechanism. Gene expression profiling and genome-wide chromatin immunoprecipitation analysis uncovered an extensive network of IRF4 target genes and identified MYC as a direct target of IRF4 in activated B cells and myeloma. Unexpectedly, IRF4 was itself a direct target of MYC transactivation, generating an autoregulatory circuit in myeloma cells. Although IRF4 is not genetically altered in most myelomas, they are nonetheless addicted to an aberrant IRF4 regulatory network that fuses the gene expression programmes of normal plasma cells and activated B cells.

Standard name | SHAFFER_IRF4_TARGETS_IN_MYELOMA_VS_MATURE_B_LYMPHOCYTE
Systematic name | M5784
Organism | Homo sapiens
PMID | 18568025
Authors | Shaffer AL,Emre NC,Lamy L,Ngo VN,Wright G,Xiao W,Powell J,Dave S,Yu X,Zhao H,Zeng Y,Chen B,Epstein J,Staudt LM
Category | C2
Sub-category | CGP
Brief description | IRF4 [GeneID=3662] target genes up-regulated in primary myeloma vs. mature B lymphocytes.
Full description | The transcription factor IRF4 (interferon regulatory factor 4) is required during an immune response for lymphocyte activation and the generation of immunoglobulin-secreting plasma cells. Multiple myeloma, a malignancy of plasma cells, has a complex molecular aetiology with several subgroups defined by gene expression profiling and recurrent chromosomal translocations. Moreover, the malignant clone can sustain multiple oncogenic lesions, accumulating genetic damage as the disease progresses. Current therapies for myeloma can extend survival but are not curative. Hence, new therapeutic strategies are needed that target molecular pathways shared by all subtypes of myeloma. Here we show, using a loss-of-function, RNA-interference-based genetic screen, that IRF4 inhibition is toxic to myeloma cell lines, regardless of transforming oncogenic mechanism. Gene expression profiling and genome-wide chromatin immunoprecipitation analysis uncovered an extensive network of IRF4 target genes and identified MYC as a direct target of IRF4 in activated B cells and myeloma. Unexpectedly, IRF4 was itself a direct target of MYC transactivation, generating an autoregulatory circuit in myeloma cells. Although IRF4 is not genetically altered in most myelomas, they are nonetheless addicted to an aberrant IRF4 regulatory network that fuses the gene expression programmes of normal plasma cells and activated B cells.

Standard name | SHAFFER_IRF4_TARGETS_IN_PLASMA_CELL_VS_MATURE_B_LYMPHOCYTE
Systematic name | M12037
Organism | Homo sapiens
PMID | 18568025
Authors | Shaffer AL,Emre NC,Lamy L,Ngo VN,Wright G,Xiao W,Powell J,Dave S,Yu X,Zhao H,Zeng Y,Chen B,Epstein J,Staudt LM
Category | C2
Sub-category | CGP
Brief description | IRF4 [GeneID=3662] target genes up-regulated in plasma cells compared to mature B lymphocytes.
Full description | The transcription factor IRF4 (interferon regulatory factor 4) is required during an immune response for lymphocyte activation and the generation of immunoglobulin-secreting plasma cells. Multiple myeloma, a malignancy of plasma cells, has a complex molecular aetiology with several subgroups defined by gene expression profiling and recurrent chromosomal translocations. Moreover, the malignant clone can sustain multiple oncogenic lesions, accumulating genetic damage as the disease progresses. Current therapies for myeloma can extend survival but are not curative. Hence, new therapeutic strategies are needed that target molecular pathways shared by all subtypes of myeloma. Here we show, using a loss-of-function, RNA-interference-based genetic screen, that IRF4 inhibition is toxic to myeloma cell lines, regardless of transforming oncogenic mechanism. Gene expression profiling and genome-wide chromatin immunoprecipitation analysis uncovered an extensive network of IRF4 target genes and identified MYC as a direct target of IRF4 in activated B cells and myeloma. Unexpectedly, IRF4 was itself a direct target of MYC transactivation, generating an autoregulatory circuit in myeloma cells. Although IRF4 is not genetically altered in most myelomas, they are nonetheless addicted to an aberrant IRF4 regulatory network that fuses the gene expression programmes of normal plasma cells and activated B cells.

Standard name | SHAFFER_IRF4_TARGETS_IN_ACTIVATED_B_LYMPHOCYTE
Systematic name | M11189
Organism | Homo sapiens
PMID | 18568025
Authors | Shaffer AL,Emre NC,Lamy L,Ngo VN,Wright G,Xiao W,Powell J,Dave S,Yu X,Zhao H,Zeng Y,Chen B,Epstein J,Staudt LM
Category | C2
Sub-category | CGP
Brief description | IRF4 [GeneID=3662] target genes induced after activation of primary B lymphocytes by anti-IgM crosslinking.
Full description | The transcription factor IRF4 (interferon regulatory factor 4) is required during an immune response for lymphocyte activation and the generation of immunoglobulin-secreting plasma cells. Multiple myeloma, a malignancy of plasma cells, has a complex molecular aetiology with several subgroups defined by gene expression profiling and recurrent chromosomal translocations. Moreover, the malignant clone can sustain multiple oncogenic lesions, accumulating genetic damage as the disease progresses. Current therapies for myeloma can extend survival but are not curative. Hence, new therapeutic strategies are needed that target molecular pathways shared by all subtypes of myeloma. Here we show, using a loss-of-function, RNA-interference-based genetic screen, that IRF4 inhibition is toxic to myeloma cell lines, regardless of transforming oncogenic mechanism. Gene expression profiling and genome-wide chromatin immunoprecipitation analysis uncovered an extensive network of IRF4 target genes and identified MYC as a direct target of IRF4 in activated B cells and myeloma. Unexpectedly, IRF4 was itself a direct target of MYC transactivation, generating an autoregulatory circuit in myeloma cells. Although IRF4 is not genetically altered in most myelomas, they are nonetheless addicted to an aberrant IRF4 regulatory network that fuses the gene expression programmes of normal plasma cells and activated B cells.

Standard name | SHAFFER_IRF4_TARGETS_IN_ACTIVATED_DENDRITIC_CELL
Systematic name | M14970
Organism | Homo sapiens
PMID | 18568025
Authors | Shaffer AL,Emre NC,Lamy L,Ngo VN,Wright G,Xiao W,Powell J,Dave S,Yu X,Zhao H,Zeng Y,Chen B,Epstein J,Staudt LM
Category | C2
Sub-category | CGP
Brief description | IRF4 [GeneID=3662] target genes up-regulated in plasmacytoid dendritic cells compared to monocytes.
Full description | The transcription factor IRF4 (interferon regulatory factor 4) is required during an immune response for lymphocyte activation and the generation of immunoglobulin-secreting plasma cells. Multiple myeloma, a malignancy of plasma cells, has a complex molecular aetiology with several subgroups defined by gene expression profiling and recurrent chromosomal translocations. Moreover, the malignant clone can sustain multiple oncogenic lesions, accumulating genetic damage as the disease progresses. Current therapies for myeloma can extend survival but are not curative. Hence, new therapeutic strategies are needed that target molecular pathways shared by all subtypes of myeloma. Here we show, using a loss-of-function, RNA-interference-based genetic screen, that IRF4 inhibition is toxic to myeloma cell lines, regardless of transforming oncogenic mechanism. Gene expression profiling and genome-wide chromatin immunoprecipitation analysis uncovered an extensive network of IRF4 target genes and identified MYC as a direct target of IRF4 in activated B cells and myeloma. Unexpectedly, IRF4 was itself a direct target of MYC transactivation, generating an autoregulatory circuit in myeloma cells. Although IRF4 is not genetically altered in most myelomas, they are nonetheless addicted to an aberrant IRF4 regulatory network that fuses the gene expression programmes of normal plasma cells and activated B cells.

Standard name | HSIAO_HOUSEKEEPING_GENES
Systematic name | M11197
Organism | Homo sapiens
PMID | 11773596
Authors | Hsiao LL,Dangond F,Yoshida T,Hong R,Jensen RV,Misra J,Dillon W,Lee KF,Clark KE,Haverty P,Weng Z,Mutter GL,Frosch MP,Macdonald ME,Milford EL,Crum CP,Bueno R,Pratt RE,Mahadevappa M,Warrington JA,Stephanopoulos G,Gullans SR
Category | C2
Sub-category | CGP
Brief description | Housekeeping genes identified as expressed across 19 normal tissues.
Full description | This study creates a compendium of gene expression in normal human tissues suitable as a reference for defining basic organ systems biology. Using oligonucleotide microarrays, we analyze 59 samples representing 19 distinct tissue types. Of approximately 7,000 genes analyzed, 451 genes are expressed in all tissue types and designated as housekeeping genes. These genes display significant variation in expression levels among tissues and are sufficient for discerning tissue-specific expression signatures, indicative of fundamental differences in biochemical processes. In addition, subsets of tissue-selective genes are identified that define key biological processes characterizing each organ. This compendium highlights similarities and differences among organ systems and different individuals and also provides a publicly available resource (Human Gene Expression Index, the HuGE Index, http://www.hugeindex.org) for future studies of pathophysiology.

Standard name | MEISSNER_ES_ICP_WITH_H3K4ME3
Systematic name | M1929
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing histone H3 trimethylation mark at K4 (H3K4me3) in ES cells (embryonic stem).
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_ES_ICP_WITH_H3K4ME3_AND_H3K27ME3
Systematic name | M1931
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing histone trimethylation marks at K4 (H3K4me3) and K27 (H3K27me3)ES cells (embryonic stem).
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_NPC_HCP_WITH_H3K27ME3
Systematic name | M1932
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing the H3K27 tri-methylation (H3K27me3) mark in neural precursor cells (NPC).
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_NPC_ICP_WITH_H3K4ME3
Systematic name | M1934
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing histone H3 trimethylation mark at K4 (H3K4me3) in neural precursor cells (NPC).
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_NPC_HCP_WITH_H3K4ME3_AND_H3K27ME3
Systematic name | M1935
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing histone H3 trimethylation marks at k4 (H3K4me3) and K27 ((H3K27me3) in neural precursor cells (NPC).
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_NPC_HCP_WITH_H3_UNMETHYLATED
Systematic name | M1936
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) that have no histone H3 methylation marks in neural precursor cells (NPC).
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_NPC_ICP_WITH_H3_UNMETHYLATED
Systematic name | M1937
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) that have no histone H3 methylation marks in neural precursor cells (NPC).
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_BRAIN_HCP_WITH_H3K27ME3
Systematic name | M1938
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing the H3K27 tri-methylation (H3K27me3) mark in brain.
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_BRAIN_ICP_WITH_H3K4ME3
Systematic name | M1939
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing histone H3 trimethylation mark at K4 (H3K4me3) in brain.
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_BRAIN_HCP_WITH_H3K4ME3_AND_H3K27ME3
Systematic name | M1941
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing histone H3 dimethylation at K4 (H3K4me2) and trimethylation at K27 (H3K27me3) in brain.
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_BRAIN_HCP_WITH_H3_UNMETHYLATED
Systematic name | M1942
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) that have no histone H3 methylation marks in brain.
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | TAVAZOIE_METASTASIS
Systematic name | M2778
Organism | Homo sapiens
PMID | 18185580
Authors | Tavazoie SF,Alarcón C,Oskarsson T,Padua D,Wang Q,Bos PD,Gerald WL,Massagué J
Category | C2
Sub-category | CGP
Brief description | Putative metastasis genes: up-regulated in metastatic cell lines LM2 (lung) and BoM2 (bone) relative to the parental MDA-MB-231 line (breast adenocarcinoma).
Full description | A search for general regulators of cancer metastasis has yielded a set of microRNAs for which expression is specifically lost as human breast cancer cells develop metastatic potential. Here we show that restoring the expression of these microRNAs in malignant cells suppresses lung and bone metastasis by human cancer cells in vivo. Of these microRNAs, miR-126 restoration reduces overall tumour growth and proliferation, whereas miR-335 inhibits metastatic cell invasion. miR-335 regulates a set of genes whose collective expression in a large cohort of human tumours is associated with risk of distal metastasis. miR-335 suppresses metastasis and migration through targeting of the progenitor cell transcription factor SOX4 and extracellular matrix component tenascin C. Expression of miR-126 and miR-335 is lost in the majority of primary breast tumours from patients who relapse, and the loss of expression of either microRNA is associated with poor distal metastasis-free survival. miR-335 and miR-126 are thus identified as metastasis suppressor microRNAs in human breast cancer.

Standard name | WENDT_COHESIN_TARGETS_UP
Systematic name | M10024
Organism | Homo sapiens
PMID | 18235444
Authors | Wendt KS,Yoshida K,Itoh T,Bando M,Koch B,Schirghuber E,Tsutsumi S,Nagae G,Ishihara K,Mishiro T,Yahata K,Imamoto F,Aburatani H,Nakao M,Imamoto N,Maeshima K,Shirahige K,Peters JM
Category | C2
Sub-category | CGP
Brief description | Cohesin targets identified by ChIP-chip which were up-regulated after knockdown of CTCF and RAD21 [GeneID=10664;5885] by RNAi.
Full description | Cohesin complexes mediate sister-chromatid cohesion in dividing cells but may also contribute to gene regulation in postmitotic cells. How cohesin regulates gene expression is not known. Here we describe cohesin-binding sites in the human genome and show that most of these are associated with the CCCTC-binding factor (CTCF), a zinc-finger protein required for transcriptional insulation. CTCF is dispensable for cohesin loading onto DNA, but is needed to enrich cohesin at specific binding sites. Cohesin enables CTCF to insulate promoters from distant enhancers and controls transcription at the H19/IGF2 (insulin-like growth factor 2) locus. This role of cohesin seems to be independent of its role in cohesion. We propose that cohesin functions as a transcriptional insulator, and speculate that subtle deficiencies in this function contribute to 'cohesinopathies' such as Cornelia de Lange syndrome.

Standard name | FERRANDO_HOX11_NEIGHBORS
Systematic name | M2059
Organism | Homo sapiens
PMID | 12086890
Authors | Ferrando AA,Neuberg DS,Staunton J,Loh ML,Huard C,Raimondi SC,Behm FG,Pui CH,Downing JR,Gilliland DG,Lander ES,Golub TR,Look AT
Category | C2
Sub-category | CGP
Brief description | Nearest neighbors of HOX11 [GeneID=3195], based on the close agreement of their expression profiles with that of HOX11 in pediatric T cell acute lymphoblastic leukemia (T-ALL).
Full description | Human T cell leukemias can arise from oncogenes activated by specific chromosomal translocations involving the T cell receptor genes. Here we show that five different T cell oncogenes (HOX11, TAL1, LYL1, LMO1, and LMO2) are often aberrantly expressed in the absence of chromosomal abnormalities. Using oligonucleotide microarrays, we identified several gene expression signatures that were indicative of leukemic arrest at specific stages of normal thymocyte development: LYL1+ signature (pro-T), HOX11+ (early cortical thymocyte), and TAL1+ (late cortical thymocyte). Hierarchical clustering analysis of gene expression signatures grouped samples according to their shared oncogenic pathways and identified HOX11L2 activation as a novel event in T cell leukemogenesis. These findings have clinical importance, since HOX11 activation is significantly associated with a favorable prognosis, while expression of TAL1, LYL1, or, surprisingly, HOX11L2 confers a much worse response to treatment. Our results illustrate the power of gene expression profiles to elucidate transformation pathways relevant to human leukemia.

Standard name | CHEOK_RESPONSE_TO_MERCAPTOPURINE_AND_HD_MTX_UP
Systematic name | M5076
Organism | Homo sapiens
PMID | 12704389
Authors | Cheok MH,Yang W,Pui CH,Downing JR,Cheng C,Naeve CW,Relling MV,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes specifically up-regulated in pediatric acute lymphoblastic leukemia (ALL) patients by mercaptopurine [PubChem=667490] and high dose methotrexate (HDMTX) [PubChem=4112].
Full description | To elucidate the genomics of cellular responses to cancer treatment, we analyzed the expression of over 9,600 human genes in acute lymphoblastic leukemia cells before and after in vivo treatment with methotrexate and mercaptopurine given alone or in combination. Based on changes in gene expression, we identified 124 genes that accurately discriminated among the four treatments. Discriminating genes included those involved in apoptosis, mismatch repair, cell cycle control and stress response. Only 14% of genes that changed when these medications were given as single agents also changed when they were given together. These data indicate that lymphoid leukemia cells of different molecular subtypes share common pathways of genomic response to the same treatment, that changes in gene expression are treatment-specific and that gene expression can illuminate differences in cellular response to drug combinations versus single agents.

Standard name | CHEOK_RESPONSE_TO_MERCAPTOPURINE_AND_HD_MTX_DN
Systematic name | M7910
Organism | Homo sapiens
PMID | 12704389
Authors | Cheok MH,Yang W,Pui CH,Downing JR,Cheng C,Naeve CW,Relling MV,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes specifically down-regulated in pediatric acute lymphoblastic leukemia (ALL) patients by mercaptopurine [PubChem=667490] and high dose methotrexate (HDMTX) [PubChem=4112].
Full description | To elucidate the genomics of cellular responses to cancer treatment, we analyzed the expression of over 9,600 human genes in acute lymphoblastic leukemia cells before and after in vivo treatment with methotrexate and mercaptopurine given alone or in combination. Based on changes in gene expression, we identified 124 genes that accurately discriminated among the four treatments. Discriminating genes included those involved in apoptosis, mismatch repair, cell cycle control and stress response. Only 14% of genes that changed when these medications were given as single agents also changed when they were given together. These data indicate that lymphoid leukemia cells of different molecular subtypes share common pathways of genomic response to the same treatment, that changes in gene expression are treatment-specific and that gene expression can illuminate differences in cellular response to drug combinations versus single agents.

Standard name | ZHAN_EARLY_DIFFERENTIATION_GENES_UP
Systematic name | M16256
Organism | Homo sapiens
PMID | 12393520
Authors | Zhan F,Tian E,Bumm K,Smith R,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | B lymphocyte early differentiation genes (EDG): top genes up-regulated in tonsil B lymphocytes (TBC) compared to the tonsil plasma cells (TPC).
Full description | To identify genes linked to normal plasma cell (PC) differentiation and to classify multiple myeloma (MM) with respect to the expression patterns of these genes, we analyzed global mRNA expression in CD19-enriched B cells (BCs) from 7 tonsils, CD138-enriched PCs from 11 tonsils, 31 normal bone marrow samples, and 74 MM bone marrow samples using microarrays interrogating 6800 genes. Hierarchical clustering analyses with 3288 genes clearly segregated the 4 cell types, and chi-square and Wilcoxin rank sum tests (P <.0005) identified 359 and 500 previously defined and novel genes that distinguish tonsil BCs from tonsil PCs (early differentiation genes [EDGs]), and tonsil PCs from bone marrow PCs (late differentiation genes [LDGs]), respectively. MM as a whole was found to have dramatically variable expression of EDGs and LDGs, and one-way analysis of variance (ANOVA) was used to identify the most variable EDGs (vEDGs) and LDGs (v1LDG and v2LDG). Hierarchical cluster analysis with these genes revealed that previously defined MM gene expression subgroups (MM1-MM4) could be linked to one of the 3 normal cell types. Clustering with 30 vEDGs revealed that 13 of 18 MM4 cases clustered with tonsil BCs (P =.000 05), whereas 14 of 15 MM3 cases clustered with tonsil PCs when using 50 v1LDG (P =.000 008), and 14 of 20 MM2 cases clustered with bone marrow PCs when using 50 v2LDG (P =.000 09). MM1 showed no significant linkage with normal cell types studied. Thus, genes whose expression is linked to distinct transitions in late-stage B-cell differentiation can be used to classify MM.

Standard name | ZHAN_EARLY_DIFFERENTIATION_GENES_DN
Systematic name | M1476
Organism | Homo sapiens
PMID | 12393520
Authors | Zhan F,Tian E,Bumm K,Smith R,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | B lymphocyte early differentiation genes (EDG): top genes down-regulated in tonsil B lymphocytes (TBC) compared to the tonsil plasma cells (TPC).
Full description | To identify genes linked to normal plasma cell (PC) differentiation and to classify multiple myeloma (MM) with respect to the expression patterns of these genes, we analyzed global mRNA expression in CD19-enriched B cells (BCs) from 7 tonsils, CD138-enriched PCs from 11 tonsils, 31 normal bone marrow samples, and 74 MM bone marrow samples using microarrays interrogating 6800 genes. Hierarchical clustering analyses with 3288 genes clearly segregated the 4 cell types, and chi-square and Wilcoxin rank sum tests (P <.0005) identified 359 and 500 previously defined and novel genes that distinguish tonsil BCs from tonsil PCs (early differentiation genes [EDGs]), and tonsil PCs from bone marrow PCs (late differentiation genes [LDGs]), respectively. MM as a whole was found to have dramatically variable expression of EDGs and LDGs, and one-way analysis of variance (ANOVA) was used to identify the most variable EDGs (vEDGs) and LDGs (v1LDG and v2LDG). Hierarchical cluster analysis with these genes revealed that previously defined MM gene expression subgroups (MM1-MM4) could be linked to one of the 3 normal cell types. Clustering with 30 vEDGs revealed that 13 of 18 MM4 cases clustered with tonsil BCs (P =.000 05), whereas 14 of 15 MM3 cases clustered with tonsil PCs when using 50 v1LDG (P =.000 008), and 14 of 20 MM2 cases clustered with bone marrow PCs when using 50 v2LDG (P =.000 09). MM1 showed no significant linkage with normal cell types studied. Thus, genes whose expression is linked to distinct transitions in late-stage B-cell differentiation can be used to classify MM.

Standard name | MILI_PSEUDOPODIA
Systematic name | M17507
Organism | Mus musculus
PMID | 18451862
Authors | Mili S,Moissoglu K,Macara IG
Category | C2
Sub-category | CGP
Brief description | Transcripts significantly enriched in pseudopodia of NIH/3T3 cells (fibroblast) in response to both chemotactic (lysophosphatidic acid, LPA [PubChem=3988]) and haptotactic (fibronectin, FN1 [GeneID=2335) migratory stimuli.
Full description | RNA localization is important for the establishment and maintenance of polarity in multiple cell types. Localized RNAs are usually transported along microtubules or actin filaments and become anchored at their destination to some underlying subcellular structure. Retention commonly involves actin or actin-associated proteins, although cytokeratin filaments and dynein anchor certain RNAs. RNA localization is important for diverse processes ranging from cell fate determination to synaptic plasticity; however, so far there have been few comprehensive studies of localized RNAs in mammalian cells. Here we have addressed this issue, focusing on migrating fibroblasts that polarize to form a leading edge and a tail in a process that involves asymmetric distribution of RNAs. We used a fractionation scheme combined with microarrays to identify, on a genome-wide scale, RNAs that localize in protruding pseudopodia of mouse fibroblasts in response to migratory stimuli. We find that a diverse group of RNAs accumulates in such pseudopodial protrusions. Through their 3' untranslated regions these transcripts are anchored in granules concentrated at the plus ends of detyrosinated microtubules. RNAs in the granules associate with the adenomatous polyposis coli (APC) tumour suppressor and the fragile X mental retardation protein (FMRP). APC is required for the accumulation of transcripts in protrusions. Our results suggest a new type of RNA anchoring mechanism as well as a new, unanticipated function for APC in localizing RNAs.

Standard name | MILI_PSEUDOPODIA_CHEMOTAXIS_UP
Systematic name | M15130
Organism | Mus musculus
PMID | 18451862
Authors | Mili S,Moissoglu K,Macara IG
Category | C2
Sub-category | CGP
Brief description | Transcripts enriched in pseudopodia of NIH/3T3 cells (fibroblast) in response to the chemotactic migration stimulus by lysophosphatidic acid (LPA) [PubChem=3988].
Full description | RNA localization is important for the establishment and maintenance of polarity in multiple cell types. Localized RNAs are usually transported along microtubules or actin filaments and become anchored at their destination to some underlying subcellular structure. Retention commonly involves actin or actin-associated proteins, although cytokeratin filaments and dynein anchor certain RNAs. RNA localization is important for diverse processes ranging from cell fate determination to synaptic plasticity; however, so far there have been few comprehensive studies of localized RNAs in mammalian cells. Here we have addressed this issue, focusing on migrating fibroblasts that polarize to form a leading edge and a tail in a process that involves asymmetric distribution of RNAs. We used a fractionation scheme combined with microarrays to identify, on a genome-wide scale, RNAs that localize in protruding pseudopodia of mouse fibroblasts in response to migratory stimuli. We find that a diverse group of RNAs accumulates in such pseudopodial protrusions. Through their 3' untranslated regions these transcripts are anchored in granules concentrated at the plus ends of detyrosinated microtubules. RNAs in the granules associate with the adenomatous polyposis coli (APC) tumour suppressor and the fragile X mental retardation protein (FMRP). APC is required for the accumulation of transcripts in protrusions. Our results suggest a new type of RNA anchoring mechanism as well as a new, unanticipated function for APC in localizing RNAs.

Standard name | MILI_PSEUDOPODIA_CHEMOTAXIS_DN
Systematic name | M1613
Organism | Mus musculus
PMID | 18451862
Authors | Mili S,Moissoglu K,Macara IG
Category | C2
Sub-category | CGP
Brief description | Transcripts depleted in pseudopodia of NIH/3T3 cells (fibroblast) in response to the chemotactic migration stimulus by lysophosphatidic acid (LPA) [PubChem=3988].
Full description | RNA localization is important for the establishment and maintenance of polarity in multiple cell types. Localized RNAs are usually transported along microtubules or actin filaments and become anchored at their destination to some underlying subcellular structure. Retention commonly involves actin or actin-associated proteins, although cytokeratin filaments and dynein anchor certain RNAs. RNA localization is important for diverse processes ranging from cell fate determination to synaptic plasticity; however, so far there have been few comprehensive studies of localized RNAs in mammalian cells. Here we have addressed this issue, focusing on migrating fibroblasts that polarize to form a leading edge and a tail in a process that involves asymmetric distribution of RNAs. We used a fractionation scheme combined with microarrays to identify, on a genome-wide scale, RNAs that localize in protruding pseudopodia of mouse fibroblasts in response to migratory stimuli. We find that a diverse group of RNAs accumulates in such pseudopodial protrusions. Through their 3' untranslated regions these transcripts are anchored in granules concentrated at the plus ends of detyrosinated microtubules. RNAs in the granules associate with the adenomatous polyposis coli (APC) tumour suppressor and the fragile X mental retardation protein (FMRP). APC is required for the accumulation of transcripts in protrusions. Our results suggest a new type of RNA anchoring mechanism as well as a new, unanticipated function for APC in localizing RNAs.

Standard name | MILI_PSEUDOPODIA_HAPTOTAXIS_UP
Systematic name | M12707
Organism | Mus musculus
PMID | 18451862
Authors | Mili S,Moissoglu K,Macara IG
Category | C2
Sub-category | CGP
Brief description | Transcripts enriched in pseudopodia of NIH/3T3 cells (fibroblast) in response to haptotactic migratory stimulus by fibronectin, FN1 [GeneID=2335].
Full description | RNA localization is important for the establishment and maintenance of polarity in multiple cell types. Localized RNAs are usually transported along microtubules or actin filaments and become anchored at their destination to some underlying subcellular structure. Retention commonly involves actin or actin-associated proteins, although cytokeratin filaments and dynein anchor certain RNAs. RNA localization is important for diverse processes ranging from cell fate determination to synaptic plasticity; however, so far there have been few comprehensive studies of localized RNAs in mammalian cells. Here we have addressed this issue, focusing on migrating fibroblasts that polarize to form a leading edge and a tail in a process that involves asymmetric distribution of RNAs. We used a fractionation scheme combined with microarrays to identify, on a genome-wide scale, RNAs that localize in protruding pseudopodia of mouse fibroblasts in response to migratory stimuli. We find that a diverse group of RNAs accumulates in such pseudopodial protrusions. Through their 3' untranslated regions these transcripts are anchored in granules concentrated at the plus ends of detyrosinated microtubules. RNAs in the granules associate with the adenomatous polyposis coli (APC) tumour suppressor and the fragile X mental retardation protein (FMRP). APC is required for the accumulation of transcripts in protrusions. Our results suggest a new type of RNA anchoring mechanism as well as a new, unanticipated function for APC in localizing RNAs.

Standard name | MILI_PSEUDOPODIA_HAPTOTAXIS_DN
Systematic name | M5314
Organism | Mus musculus
PMID | 18451862
Authors | Mili S,Moissoglu K,Macara IG
Category | C2
Sub-category | CGP
Brief description | Transcripts depleted from pseudopodia of NIH/3T3 cells (fibroblast) in response to haptotactic migratory stimulus by fibronectin, FN1 [GeneID=2335].
Full description | RNA localization is important for the establishment and maintenance of polarity in multiple cell types. Localized RNAs are usually transported along microtubules or actin filaments and become anchored at their destination to some underlying subcellular structure. Retention commonly involves actin or actin-associated proteins, although cytokeratin filaments and dynein anchor certain RNAs. RNA localization is important for diverse processes ranging from cell fate determination to synaptic plasticity; however, so far there have been few comprehensive studies of localized RNAs in mammalian cells. Here we have addressed this issue, focusing on migrating fibroblasts that polarize to form a leading edge and a tail in a process that involves asymmetric distribution of RNAs. We used a fractionation scheme combined with microarrays to identify, on a genome-wide scale, RNAs that localize in protruding pseudopodia of mouse fibroblasts in response to migratory stimuli. We find that a diverse group of RNAs accumulates in such pseudopodial protrusions. Through their 3' untranslated regions these transcripts are anchored in granules concentrated at the plus ends of detyrosinated microtubules. RNAs in the granules associate with the adenomatous polyposis coli (APC) tumour suppressor and the fragile X mental retardation protein (FMRP). APC is required for the accumulation of transcripts in protrusions. Our results suggest a new type of RNA anchoring mechanism as well as a new, unanticipated function for APC in localizing RNAs.

Standard name | LIU_VAV3_PROSTATE_CARCINOGENESIS_UP
Systematic name | M215
Organism | Homo sapiens
PMID | 18676865
Authors | Liu Y,Mo JQ,Hu Q,Boivin G,Levin L,Lu S,Yang D,Dong Z
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated in prostate tumors developed by transgenic mice overexpressing VAV3 [GeneID=10451] in prostate epithelium.
Full description | Our previous study revealed that Vav3 oncogene is overexpressed in human prostate cancer, activates androgen receptor (AR), and stimulates growth in prostate cancer cells. The purpose of this study is to further determine the potential role of Vav3 in prostate cancer development in genetically engineered mouse model. We generated Vav3 transgenic mice by targeted overexpression of a constitutive active Vav3 in the prostatic epithelium. We found that overexpression of Vav3 led to development of mouse prostatic intraepithelial neoplasia and prostate cancer at the age of as early as 3 months. The AR signaling axis and phosphatidylinositol 3-kinase-Akt signaling were elevated in the prostate glands of Vav3 transgenic mice. In addition to prostate cancer, Vav3 transgenic mice developed significant nonbacterial chronic prostatitis in the prostate gland with notable infiltration of lymphomononuclear cells (monocytes, lymphocytes, and plasma cells), which was associated with elevated incidence of prostate cancer. DNA microarray and signaling pathway analysis revealed that the top diseases and disorders were inflammatory diseases and cancer of the prostate gland in Vav3 transgenic mice. In vitro analysis showed that overexpression of Vav3 in prostate cancer cells enhanced nuclear factor-kappaB (NF-kappaB) activity, implicating an underlying mechanism of innate inflammatory response induced by elevated Vav3 activity. These data showed that Vav3 overexpression in the prostate epithelium enhanced both the AR signaling axis and NF-kappaB-mediated pathway, which potentially contributed to the development of nonbacterial prostatitis and prostate cancer.

Standard name | LIU_VAV3_PROSTATE_CARCINOGENESIS_DN
Systematic name | M12393
Organism | Homo sapiens
PMID | 18676865
Authors | Liu Y,Mo JQ,Hu Q,Boivin G,Levin L,Lu S,Yang D,Dong Z
Category | C2
Sub-category | CGP
Brief description | Selected genes down-regulated in prostate tumors developed by transgenic mice overexpressing VAV3 [GeneID=10451] in prostate epithelium.
Full description | Our previous study revealed that Vav3 oncogene is overexpressed in human prostate cancer, activates androgen receptor (AR), and stimulates growth in prostate cancer cells. The purpose of this study is to further determine the potential role of Vav3 in prostate cancer development in genetically engineered mouse model. We generated Vav3 transgenic mice by targeted overexpression of a constitutive active Vav3 in the prostatic epithelium. We found that overexpression of Vav3 led to development of mouse prostatic intraepithelial neoplasia and prostate cancer at the age of as early as 3 months. The AR signaling axis and phosphatidylinositol 3-kinase-Akt signaling were elevated in the prostate glands of Vav3 transgenic mice. In addition to prostate cancer, Vav3 transgenic mice developed significant nonbacterial chronic prostatitis in the prostate gland with notable infiltration of lymphomononuclear cells (monocytes, lymphocytes, and plasma cells), which was associated with elevated incidence of prostate cancer. DNA microarray and signaling pathway analysis revealed that the top diseases and disorders were inflammatory diseases and cancer of the prostate gland in Vav3 transgenic mice. In vitro analysis showed that overexpression of Vav3 in prostate cancer cells enhanced nuclear factor-kappaB (NF-kappaB) activity, implicating an underlying mechanism of innate inflammatory response induced by elevated Vav3 activity. These data showed that Vav3 overexpression in the prostate epithelium enhanced both the AR signaling axis and NF-kappaB-mediated pathway, which potentially contributed to the development of nonbacterial prostatitis and prostate cancer.

Standard name | CROONQUIST_IL6_DEPRIVATION_UP
Systematic name | M8342
Organism | Homo sapiens
PMID | 12791645
Authors | Croonquist PA,Linden MA,Zhao F,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the ANBL-6 cell line (multiple myeloma, MM) after withdrawal of IL6 [GeneID=3569].
Full description | ANBL-6, a myeloma cell line, proliferates in response to interleukin 6 (IL-6) stimulation, coculture with bone marrow stromal cells, and when harboring a constitutively active mutant N-ras gene. Eighteen samples, including 4 IL-6-treated, 3 mutant N-ras-transfected, 3 normal stroma-stimulated, 2 multiple myeloma (MM) stroma-stimulated, and 6 untreated controls were profiled using microarrays interrogating 12 626 genes. Global hierarchical clustering analysis distinguished at least 6 unique expression signatures. Notably, the different stimuli altered distinct functional gene programs. Class comparison analysis (P =.001) revealed 138 genes (54% involved in cell cycle) that distinguished IL-6-stimulated versus nontreated samples. Eighty-seven genes distinguished stroma-stimulated versus IL-6-treated samples (22% encoded for extracellular matrix [ECM] proteins). A total of 130 genes distinguished N-ras transfectants versus IL-6-treated samples (26% involved in metabolism). A total of 157 genes, 20% of these involved in signaling, distinguished N-ras from stroma-interacting samples. All 3 stimuli shared 347 genes, mostly of metabolic function. Genes that distinguished MM1 from MM4 clinical groups were induced at least by one treatment. Notably, only 3 genes (ETV5, DUSP6, and KIAA0735) are uniquely induced in mutant ras-containing cells. We have demonstrated gene expression patterns in myeloma cells that distinguish an intrinsic genetic transformation event and patterns derived from both soluble factors and cell contacts in the bone marrow microenvironment.

Standard name | CROONQUIST_IL6_DEPRIVATION_DN
Systematic name | M18506
Organism | Homo sapiens
PMID | 12791645
Authors | Croonquist PA,Linden MA,Zhao F,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the ANBL-6 cell line (multiple myeloma, MM) after withdrawal of IL6 [GeneID=3569].
Full description | ANBL-6, a myeloma cell line, proliferates in response to interleukin 6 (IL-6) stimulation, coculture with bone marrow stromal cells, and when harboring a constitutively active mutant N-ras gene. Eighteen samples, including 4 IL-6-treated, 3 mutant N-ras-transfected, 3 normal stroma-stimulated, 2 multiple myeloma (MM) stroma-stimulated, and 6 untreated controls were profiled using microarrays interrogating 12 626 genes. Global hierarchical clustering analysis distinguished at least 6 unique expression signatures. Notably, the different stimuli altered distinct functional gene programs. Class comparison analysis (P =.001) revealed 138 genes (54% involved in cell cycle) that distinguished IL-6-stimulated versus nontreated samples. Eighty-seven genes distinguished stroma-stimulated versus IL-6-treated samples (22% encoded for extracellular matrix [ECM] proteins). A total of 130 genes distinguished N-ras transfectants versus IL-6-treated samples (26% involved in metabolism). A total of 157 genes, 20% of these involved in signaling, distinguished N-ras from stroma-interacting samples. All 3 stimuli shared 347 genes, mostly of metabolic function. Genes that distinguished MM1 from MM4 clinical groups were induced at least by one treatment. Notably, only 3 genes (ETV5, DUSP6, and KIAA0735) are uniquely induced in mutant ras-containing cells. We have demonstrated gene expression patterns in myeloma cells that distinguish an intrinsic genetic transformation event and patterns derived from both soluble factors and cell contacts in the bone marrow microenvironment.

Standard name | CROONQUIST_STROMAL_STIMULATION_UP
Systematic name | M5929
Organism | Homo sapiens
PMID | 12791645
Authors | Croonquist PA,Linden MA,Zhao F,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ANBL-6 cell line (multiple myeloma, MM) co-cultured with bone marrow stromal cells compared to those grown in the presence of IL6 [GeneID=3569].
Full description | ANBL-6, a myeloma cell line, proliferates in response to interleukin 6 (IL-6) stimulation, coculture with bone marrow stromal cells, and when harboring a constitutively active mutant N-ras gene. Eighteen samples, including 4 IL-6-treated, 3 mutant N-ras-transfected, 3 normal stroma-stimulated, 2 multiple myeloma (MM) stroma-stimulated, and 6 untreated controls were profiled using microarrays interrogating 12 626 genes. Global hierarchical clustering analysis distinguished at least 6 unique expression signatures. Notably, the different stimuli altered distinct functional gene programs. Class comparison analysis (P =.001) revealed 138 genes (54% involved in cell cycle) that distinguished IL-6-stimulated versus nontreated samples. Eighty-seven genes distinguished stroma-stimulated versus IL-6-treated samples (22% encoded for extracellular matrix [ECM] proteins). A total of 130 genes distinguished N-ras transfectants versus IL-6-treated samples (26% involved in metabolism). A total of 157 genes, 20% of these involved in signaling, distinguished N-ras from stroma-interacting samples. All 3 stimuli shared 347 genes, mostly of metabolic function. Genes that distinguished MM1 from MM4 clinical groups were induced at least by one treatment. Notably, only 3 genes (ETV5, DUSP6, and KIAA0735) are uniquely induced in mutant ras-containing cells. We have demonstrated gene expression patterns in myeloma cells that distinguish an intrinsic genetic transformation event and patterns derived from both soluble factors and cell contacts in the bone marrow microenvironment.

Standard name | CROONQUIST_STROMAL_STIMULATION_DN
Systematic name | M2015
Organism | Homo sapiens
PMID | 12791645
Authors | Croonquist PA,Linden MA,Zhao F,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ANBL-6 cell line (multiple myeloma, MM) co-cultured with bone marrow stromal cells compared to those grown in the presence of IL6 [GeneID=3569].
Full description | ANBL-6, a myeloma cell line, proliferates in response to interleukin 6 (IL-6) stimulation, coculture with bone marrow stromal cells, and when harboring a constitutively active mutant N-ras gene. Eighteen samples, including 4 IL-6-treated, 3 mutant N-ras-transfected, 3 normal stroma-stimulated, 2 multiple myeloma (MM) stroma-stimulated, and 6 untreated controls were profiled using microarrays interrogating 12 626 genes. Global hierarchical clustering analysis distinguished at least 6 unique expression signatures. Notably, the different stimuli altered distinct functional gene programs. Class comparison analysis (P =.001) revealed 138 genes (54% involved in cell cycle) that distinguished IL-6-stimulated versus nontreated samples. Eighty-seven genes distinguished stroma-stimulated versus IL-6-treated samples (22% encoded for extracellular matrix [ECM] proteins). A total of 130 genes distinguished N-ras transfectants versus IL-6-treated samples (26% involved in metabolism). A total of 157 genes, 20% of these involved in signaling, distinguished N-ras from stroma-interacting samples. All 3 stimuli shared 347 genes, mostly of metabolic function. Genes that distinguished MM1 from MM4 clinical groups were induced at least by one treatment. Notably, only 3 genes (ETV5, DUSP6, and KIAA0735) are uniquely induced in mutant ras-containing cells. We have demonstrated gene expression patterns in myeloma cells that distinguish an intrinsic genetic transformation event and patterns derived from both soluble factors and cell contacts in the bone marrow microenvironment.

Standard name | CROONQUIST_NRAS_SIGNALING_UP
Systematic name | M1138
Organism | Homo sapiens
PMID | 12791645
Authors | Croonquist PA,Linden MA,Zhao F,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ANBL-6 cell line (multiple myeloma, MM) expressing a constantly active form of NRAS [GeneID=4893] off a plasmid vector compared to those grown in the presence of IL6 [GeneID=3569].
Full description | ANBL-6, a myeloma cell line, proliferates in response to interleukin 6 (IL-6) stimulation, coculture with bone marrow stromal cells, and when harboring a constitutively active mutant N-ras gene. Eighteen samples, including 4 IL-6-treated, 3 mutant N-ras-transfected, 3 normal stroma-stimulated, 2 multiple myeloma (MM) stroma-stimulated, and 6 untreated controls were profiled using microarrays interrogating 12 626 genes. Global hierarchical clustering analysis distinguished at least 6 unique expression signatures. Notably, the different stimuli altered distinct functional gene programs. Class comparison analysis (P =.001) revealed 138 genes (54% involved in cell cycle) that distinguished IL-6-stimulated versus nontreated samples. Eighty-seven genes distinguished stroma-stimulated versus IL-6-treated samples (22% encoded for extracellular matrix [ECM] proteins). A total of 130 genes distinguished N-ras transfectants versus IL-6-treated samples (26% involved in metabolism). A total of 157 genes, 20% of these involved in signaling, distinguished N-ras from stroma-interacting samples. All 3 stimuli shared 347 genes, mostly of metabolic function. Genes that distinguished MM1 from MM4 clinical groups were induced at least by one treatment. Notably, only 3 genes (ETV5, DUSP6, and KIAA0735) are uniquely induced in mutant ras-containing cells. We have demonstrated gene expression patterns in myeloma cells that distinguish an intrinsic genetic transformation event and patterns derived from both soluble factors and cell contacts in the bone marrow microenvironment.

Standard name | CROONQUIST_NRAS_SIGNALING_DN
Systematic name | M10739
Organism | Homo sapiens
PMID | 12791645
Authors | Croonquist PA,Linden MA,Zhao F,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ANBL-6 cell line (multiple myeloma, MM) expressing a constantly active form of NRAS [GeneID=4893] off a plasmid vector compared to those grown in the presence of IL6 [GeneID=3569].
Full description | ANBL-6, a myeloma cell line, proliferates in response to interleukin 6 (IL-6) stimulation, coculture with bone marrow stromal cells, and when harboring a constitutively active mutant N-ras gene. Eighteen samples, including 4 IL-6-treated, 3 mutant N-ras-transfected, 3 normal stroma-stimulated, 2 multiple myeloma (MM) stroma-stimulated, and 6 untreated controls were profiled using microarrays interrogating 12 626 genes. Global hierarchical clustering analysis distinguished at least 6 unique expression signatures. Notably, the different stimuli altered distinct functional gene programs. Class comparison analysis (P =.001) revealed 138 genes (54% involved in cell cycle) that distinguished IL-6-stimulated versus nontreated samples. Eighty-seven genes distinguished stroma-stimulated versus IL-6-treated samples (22% encoded for extracellular matrix [ECM] proteins). A total of 130 genes distinguished N-ras transfectants versus IL-6-treated samples (26% involved in metabolism). A total of 157 genes, 20% of these involved in signaling, distinguished N-ras from stroma-interacting samples. All 3 stimuli shared 347 genes, mostly of metabolic function. Genes that distinguished MM1 from MM4 clinical groups were induced at least by one treatment. Notably, only 3 genes (ETV5, DUSP6, and KIAA0735) are uniquely induced in mutant ras-containing cells. We have demonstrated gene expression patterns in myeloma cells that distinguish an intrinsic genetic transformation event and patterns derived from both soluble factors and cell contacts in the bone marrow microenvironment.

Standard name | CROONQUIST_NRAS_VS_STROMAL_STIMULATION_UP
Systematic name | M8273
Organism | Homo sapiens
PMID | 12791645
Authors | Croonquist PA,Linden MA,Zhao F,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ANBL-6 cell line (multiple myeloma, MM) expressing an activated form of NRAS [GeneID=4893] off a plasmid vector compared to those co-cultured with bone marrow stromal cells.
Full description | ANBL-6, a myeloma cell line, proliferates in response to interleukin 6 (IL-6) stimulation, coculture with bone marrow stromal cells, and when harboring a constitutively active mutant N-ras gene. Eighteen samples, including 4 IL-6-treated, 3 mutant N-ras-transfected, 3 normal stroma-stimulated, 2 multiple myeloma (MM) stroma-stimulated, and 6 untreated controls were profiled using microarrays interrogating 12 626 genes. Global hierarchical clustering analysis distinguished at least 6 unique expression signatures. Notably, the different stimuli altered distinct functional gene programs. Class comparison analysis (P =.001) revealed 138 genes (54% involved in cell cycle) that distinguished IL-6-stimulated versus nontreated samples. Eighty-seven genes distinguished stroma-stimulated versus IL-6-treated samples (22% encoded for extracellular matrix [ECM] proteins). A total of 130 genes distinguished N-ras transfectants versus IL-6-treated samples (26% involved in metabolism). A total of 157 genes, 20% of these involved in signaling, distinguished N-ras from stroma-interacting samples. All 3 stimuli shared 347 genes, mostly of metabolic function. Genes that distinguished MM1 from MM4 clinical groups were induced at least by one treatment. Notably, only 3 genes (ETV5, DUSP6, and KIAA0735) are uniquely induced in mutant ras-containing cells. We have demonstrated gene expression patterns in myeloma cells that distinguish an intrinsic genetic transformation event and patterns derived from both soluble factors and cell contacts in the bone marrow microenvironment.

Standard name | CROONQUIST_NRAS_VS_STROMAL_STIMULATION_DN
Systematic name | M4491
Organism | Homo sapiens
PMID | 12791645
Authors | Croonquist PA,Linden MA,Zhao F,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ANBL-6 cell line (multiple myeloma, MM) expressing an activated form of NRAS [GeneID=4893] off a plasmid vector compared to those co-cultured with bone marrow stromal cells.
Full description | ANBL-6, a myeloma cell line, proliferates in response to interleukin 6 (IL-6) stimulation, coculture with bone marrow stromal cells, and when harboring a constitutively active mutant N-ras gene. Eighteen samples, including 4 IL-6-treated, 3 mutant N-ras-transfected, 3 normal stroma-stimulated, 2 multiple myeloma (MM) stroma-stimulated, and 6 untreated controls were profiled using microarrays interrogating 12 626 genes. Global hierarchical clustering analysis distinguished at least 6 unique expression signatures. Notably, the different stimuli altered distinct functional gene programs. Class comparison analysis (P =.001) revealed 138 genes (54% involved in cell cycle) that distinguished IL-6-stimulated versus nontreated samples. Eighty-seven genes distinguished stroma-stimulated versus IL-6-treated samples (22% encoded for extracellular matrix [ECM] proteins). A total of 130 genes distinguished N-ras transfectants versus IL-6-treated samples (26% involved in metabolism). A total of 157 genes, 20% of these involved in signaling, distinguished N-ras from stroma-interacting samples. All 3 stimuli shared 347 genes, mostly of metabolic function. Genes that distinguished MM1 from MM4 clinical groups were induced at least by one treatment. Notably, only 3 genes (ETV5, DUSP6, and KIAA0735) are uniquely induced in mutant ras-containing cells. We have demonstrated gene expression patterns in myeloma cells that distinguish an intrinsic genetic transformation event and patterns derived from both soluble factors and cell contacts in the bone marrow microenvironment.

Standard name | IRITANI_MAD1_TARGETS_UP
Systematic name | M1943
Organism | Mus musculus
PMID | 12234922
Authors | Iritani BM,Delrow J,Grandori C,Gomez I,Klacking M,Carlos LS,Eisenman RN
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by overexpression of MAD1 [GeneID=4084] in primary thymocytes from RAG2 [GeneID=5897] knockout mice.
Full description | Activated lymphocytes must increase in size and duplicate their contents (cell growth) before they can divide. The molecular events that control cell growth in proliferating lymphocytes and other metazoan cells are still unclear. Here, we utilized transgenesis to provide evidence suggesting that the basic helix-loop- helix-zipper (bHLHZ) transcriptional repressor Mad1, considered to be an antagonist of Myc function, inhibits lymphocyte expansion, maturation and growth following pre-T-cell receptor (pre-TCR) and TCR stimulation. Furthermore, we utilized cDNA microarray technology to determine that, of the genes repressed by Mad1, the majority (77%) are involved in cell growth, which correlates with a decrease in size of Mad1 transgenic thymocytes. Over 80% of the genes repressed by Mad1 have previously been found to be induced by Myc. These results suggest that a balance between Myc and Mad levels may normally modulate lymphocyte proliferation and development in part by controlling expression of growth-regulating genes.

Standard name | IRITANI_MAD1_TARGETS_DN
Systematic name | M1944
Organism | Mus musculus
PMID | 12234922
Authors | Iritani BM,Delrow J,Grandori C,Gomez I,Klacking M,Carlos LS,Eisenman RN
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by overexpression of MAD1 [GeneID=4084] in primary thymocytes from RAG2 [GeneID=5897] knockout mice.
Full description | Activated lymphocytes must increase in size and duplicate their contents (cell growth) before they can divide. The molecular events that control cell growth in proliferating lymphocytes and other metazoan cells are still unclear. Here, we utilized transgenesis to provide evidence suggesting that the basic helix-loop- helix-zipper (bHLHZ) transcriptional repressor Mad1, considered to be an antagonist of Myc function, inhibits lymphocyte expansion, maturation and growth following pre-T-cell receptor (pre-TCR) and TCR stimulation. Furthermore, we utilized cDNA microarray technology to determine that, of the genes repressed by Mad1, the majority (77%) are involved in cell growth, which correlates with a decrease in size of Mad1 transgenic thymocytes. Over 80% of the genes repressed by Mad1 have previously been found to be induced by Myc. These results suggest that a balance between Myc and Mad levels may normally modulate lymphocyte proliferation and development in part by controlling expression of growth-regulating genes.

Standard name | ZHAN_LATE_DIFFERENTIATION_GENES_UP
Systematic name | M10280
Organism | Homo sapiens
PMID | 12393520
Authors | Zhan F,Tian E,Bumm K,Smith R,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | B lymphocyte late differentiation genes (LDG): top genes up-regulated in plasma cells from tonsils (TPC) compared to those from bone marrow (BPC).
Full description | To identify genes linked to normal plasma cell (PC) differentiation and to classify multiple myeloma (MM) with respect to the expression patterns of these genes, we analyzed global mRNA expression in CD19-enriched B cells (BCs) from 7 tonsils, CD138-enriched PCs from 11 tonsils, 31 normal bone marrow samples, and 74 MM bone marrow samples using microarrays interrogating 6800 genes. Hierarchical clustering analyses with 3288 genes clearly segregated the 4 cell types, and chi-square and Wilcoxin rank sum tests (P <.0005) identified 359 and 500 previously defined and novel genes that distinguish tonsil BCs from tonsil PCs (early differentiation genes [EDGs]), and tonsil PCs from bone marrow PCs (late differentiation genes [LDGs]), respectively. MM as a whole was found to have dramatically variable expression of EDGs and LDGs, and one-way analysis of variance (ANOVA) was used to identify the most variable EDGs (vEDGs) and LDGs (v1LDG and v2LDG). Hierarchical cluster analysis with these genes revealed that previously defined MM gene expression subgroups (MM1-MM4) could be linked to one of the 3 normal cell types. Clustering with 30 vEDGs revealed that 13 of 18 MM4 cases clustered with tonsil BCs (P =.000 05), whereas 14 of 15 MM3 cases clustered with tonsil PCs when using 50 v1LDG (P =.000 008), and 14 of 20 MM2 cases clustered with bone marrow PCs when using 50 v2LDG (P =.000 09). MM1 showed no significant linkage with normal cell types studied. Thus, genes whose expression is linked to distinct transitions in late-stage B-cell differentiation can be used to classify MM.

Standard name | ZHAN_LATE_DIFFERENTIATION_GENES_DN
Systematic name | M4230
Organism | Homo sapiens
PMID | 12393520
Authors | Zhan F,Tian E,Bumm K,Smith R,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | B lymphocyte late differentiation genes (LDG): top genes down-regulated in plasma cells from tonsils (TPC) compared to those from bone marrow (BPC).
Full description | To identify genes linked to normal plasma cell (PC) differentiation and to classify multiple myeloma (MM) with respect to the expression patterns of these genes, we analyzed global mRNA expression in CD19-enriched B cells (BCs) from 7 tonsils, CD138-enriched PCs from 11 tonsils, 31 normal bone marrow samples, and 74 MM bone marrow samples using microarrays interrogating 6800 genes. Hierarchical clustering analyses with 3288 genes clearly segregated the 4 cell types, and chi-square and Wilcoxin rank sum tests (P <.0005) identified 359 and 500 previously defined and novel genes that distinguish tonsil BCs from tonsil PCs (early differentiation genes [EDGs]), and tonsil PCs from bone marrow PCs (late differentiation genes [LDGs]), respectively. MM as a whole was found to have dramatically variable expression of EDGs and LDGs, and one-way analysis of variance (ANOVA) was used to identify the most variable EDGs (vEDGs) and LDGs (v1LDG and v2LDG). Hierarchical cluster analysis with these genes revealed that previously defined MM gene expression subgroups (MM1-MM4) could be linked to one of the 3 normal cell types. Clustering with 30 vEDGs revealed that 13 of 18 MM4 cases clustered with tonsil BCs (P =.000 05), whereas 14 of 15 MM3 cases clustered with tonsil PCs when using 50 v1LDG (P =.000 008), and 14 of 20 MM2 cases clustered with bone marrow PCs when using 50 v2LDG (P =.000 09). MM1 showed no significant linkage with normal cell types studied. Thus, genes whose expression is linked to distinct transitions in late-stage B-cell differentiation can be used to classify MM.

Standard name | ZHAN_VARIABLE_EARLY_DIFFERENTIATION_GENES_UP
Systematic name | M1717
Organism | Homo sapiens
PMID | 12393520
Authors | Zhan F,Tian E,Bumm K,Smith R,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | The vEDG up-regulated set: most variable early differentiation genes (EDG) with similar expression patterns in tonsil B lymphocytes (TBC) and multiple myeloma (MM) cells compared to the plasma cells from tonsil (TPC) and bone marrow (BPC).
Full description | To identify genes linked to normal plasma cell (PC) differentiation and to classify multiple myeloma (MM) with respect to the expression patterns of these genes, we analyzed global mRNA expression in CD19-enriched B cells (BCs) from 7 tonsils, CD138-enriched PCs from 11 tonsils, 31 normal bone marrow samples, and 74 MM bone marrow samples using microarrays interrogating 6800 genes. Hierarchical clustering analyses with 3288 genes clearly segregated the 4 cell types, and chi-square and Wilcoxin rank sum tests (P <.0005) identified 359 and 500 previously defined and novel genes that distinguish tonsil BCs from tonsil PCs (early differentiation genes [EDGs]), and tonsil PCs from bone marrow PCs (late differentiation genes [LDGs]), respectively. MM as a whole was found to have dramatically variable expression of EDGs and LDGs, and one-way analysis of variance (ANOVA) was used to identify the most variable EDGs (vEDGs) and LDGs (v1LDG and v2LDG). Hierarchical cluster analysis with these genes revealed that previously defined MM gene expression subgroups (MM1-MM4) could be linked to one of the 3 normal cell types. Clustering with 30 vEDGs revealed that 13 of 18 MM4 cases clustered with tonsil BCs (P =.000 05), whereas 14 of 15 MM3 cases clustered with tonsil PCs when using 50 v1LDG (P =.000 008), and 14 of 20 MM2 cases clustered with bone marrow PCs when using 50 v2LDG (P =.000 09). MM1 showed no significant linkage with normal cell types studied. Thus, genes whose expression is linked to distinct transitions in late-stage B-cell differentiation can be used to classify MM.

Standard name | ZHAN_VARIABLE_EARLY_DIFFERENTIATION_GENES_DN
Systematic name | M16104
Organism | Homo sapiens
PMID | 12393520
Authors | Zhan F,Tian E,Bumm K,Smith R,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | The vEDG down-regulated set: most variable early differentiation genes (EDG) with similar expression patterns in tonsil B lymphocytes (TBC) and multiple myeloma (MM) cells compared to the plasma cells from tonsil (TPC) and bone marrow (BPC).
Full description | To identify genes linked to normal plasma cell (PC) differentiation and to classify multiple myeloma (MM) with respect to the expression patterns of these genes, we analyzed global mRNA expression in CD19-enriched B cells (BCs) from 7 tonsils, CD138-enriched PCs from 11 tonsils, 31 normal bone marrow samples, and 74 MM bone marrow samples using microarrays interrogating 6800 genes. Hierarchical clustering analyses with 3288 genes clearly segregated the 4 cell types, and chi-square and Wilcoxin rank sum tests (P <.0005) identified 359 and 500 previously defined and novel genes that distinguish tonsil BCs from tonsil PCs (early differentiation genes [EDGs]), and tonsil PCs from bone marrow PCs (late differentiation genes [LDGs]), respectively. MM as a whole was found to have dramatically variable expression of EDGs and LDGs, and one-way analysis of variance (ANOVA) was used to identify the most variable EDGs (vEDGs) and LDGs (v1LDG and v2LDG). Hierarchical cluster analysis with these genes revealed that previously defined MM gene expression subgroups (MM1-MM4) could be linked to one of the 3 normal cell types. Clustering with 30 vEDGs revealed that 13 of 18 MM4 cases clustered with tonsil BCs (P =.000 05), whereas 14 of 15 MM3 cases clustered with tonsil PCs when using 50 v1LDG (P =.000 008), and 14 of 20 MM2 cases clustered with bone marrow PCs when using 50 v2LDG (P =.000 09). MM1 showed no significant linkage with normal cell types studied. Thus, genes whose expression is linked to distinct transitions in late-stage B-cell differentiation can be used to classify MM.

Standard name | ZHAN_V1_LATE_DIFFERENTIATION_GENES_UP
Systematic name | M13608
Organism | Homo sapiens
PMID | 12393520
Authors | Zhan F,Tian E,Bumm K,Smith R,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | The v1LDG up-regulated set: most variable late differentiation genes (LDG) with similar expression patterns in tonsil plasma cells (TPC) and multiple myeloma (MM) samples.
Full description | To identify genes linked to normal plasma cell (PC) differentiation and to classify multiple myeloma (MM) with respect to the expression patterns of these genes, we analyzed global mRNA expression in CD19-enriched B cells (BCs) from 7 tonsils, CD138-enriched PCs from 11 tonsils, 31 normal bone marrow samples, and 74 MM bone marrow samples using microarrays interrogating 6800 genes. Hierarchical clustering analyses with 3288 genes clearly segregated the 4 cell types, and chi-square and Wilcoxin rank sum tests (P <.0005) identified 359 and 500 previously defined and novel genes that distinguish tonsil BCs from tonsil PCs (early differentiation genes [EDGs]), and tonsil PCs from bone marrow PCs (late differentiation genes [LDGs]), respectively. MM as a whole was found to have dramatically variable expression of EDGs and LDGs, and one-way analysis of variance (ANOVA) was used to identify the most variable EDGs (vEDGs) and LDGs (v1LDG and v2LDG). Hierarchical cluster analysis with these genes revealed that previously defined MM gene expression subgroups (MM1-MM4) could be linked to one of the 3 normal cell types. Clustering with 30 vEDGs revealed that 13 of 18 MM4 cases clustered with tonsil BCs (P =.000 05), whereas 14 of 15 MM3 cases clustered with tonsil PCs when using 50 v1LDG (P =.000 008), and 14 of 20 MM2 cases clustered with bone marrow PCs when using 50 v2LDG (P =.000 09). MM1 showed no significant linkage with normal cell types studied. Thus, genes whose expression is linked to distinct transitions in late-stage B-cell differentiation can be used to classify MM.

Standard name | ZHAN_V1_LATE_DIFFERENTIATION_GENES_DN
Systematic name | M13806
Organism | Homo sapiens
PMID | 12393520
Authors | Zhan F,Tian E,Bumm K,Smith R,Barlogie B,Shaughnessy J Jr
Category | C2
Sub-category | CGP
Brief description | The v1LDG down-regulated set: most variable late differentiation genes (LDG) with similar expression patterns in tonsil plasma cells (TPC) and multiple myeloma (MM) samples.
Full description | To identify genes linked to normal plasma cell (PC) differentiation and to classify multiple myeloma (MM) with respect to the expression patterns of these genes, we analyzed global mRNA expression in CD19-enriched B cells (BCs) from 7 tonsils, CD138-enriched PCs from 11 tonsils, 31 normal bone marrow samples, and 74 MM bone marrow samples using microarrays interrogating 6800 genes. Hierarchical clustering analyses with 3288 genes clearly segregated the 4 cell types, and chi-square and Wilcoxin rank sum tests (P <.0005) identified 359 and 500 previously defined and novel genes that distinguish tonsil BCs from tonsil PCs (early differentiation genes [EDGs]), and tonsil PCs from bone marrow PCs (late differentiation genes [LDGs]), respectively. MM as a whole was found to have dramatically variable expression of EDGs and LDGs, and one-way analysis of variance (ANOVA) was used to identify the most variable EDGs (vEDGs) and LDGs (v1LDG and v2LDG). Hierarchical cluster analysis with these genes revealed that previously defined MM gene expression subgroups (MM1-MM4) could be linked to one of the 3 normal cell types. Clustering with 30 vEDGs revealed that 13 of 18 MM4 cases clustered with tonsil BCs (P =.000 05), whereas 14 of 15 MM3 cases clustered with tonsil PCs when using 50 v1LDG (P =.000 008), and 14 of 20 MM2 cases clustered with bone marrow PCs when using 50 v2LDG (P =.000 09). MM1 showed no significant linkage with normal cell types studied. Thus, genes whose expression is linked to distinct transitions in late-stage B-cell differentiation can be used to classify MM.

Standard name | ISHIDA_E2F_TARGETS
Systematic name | M1945
Organism | Mus musculus
PMID | 11416145
Authors | Ishida S,Huang E,Zuzan H,Spang R,Leone G,West M,Nevins JR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) after expression of E2F1 or E2F2 [GeneID=1869;1870].
Full description | We have used high-density DNA microarrays to provide an analysis of gene regulation during the mammalian cell cycle and the role of E2F in this process. Cell cycle analysis was facilitated by a combined examination of gene control in serum-stimulated fibroblasts and cells synchronized at G(1)/S by hydroxyurea block that were then released to proceed through the cell cycle. The latter approach (G(1)/S synchronization) is critical for rigorously maintaining cell synchrony for unambiguous analysis of gene regulation in later stages of the cell cycle. Analysis of these samples identified seven distinct clusters of genes that exhibit unique patterns of expression. Genes tend to cluster within these groups based on common function and the time during the cell cycle that the activity is required. Placed in this context, the analysis of genes induced by E2F proteins identified genes or expressed sequence tags not previously described as regulated by E2F proteins; surprisingly, many of these encode proteins known to function during mitosis. A comparison of the E2F-induced genes with the patterns of cell growth-regulated gene expression revealed that virtually all of the E2F-induced genes are found in only two of the cell cycle clusters; one group was regulated at G(1)/S, and the second group, which included the mitotic activities, was regulated at G(2). The activation of the G(2) genes suggests a broader role for E2F in the control of both DNA replication and mitotic activities.

Standard name | VALK_AML_CLUSTER_1
Systematic name | M19844
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 1 of acute myeloid leukemia (AML) expression profile; 57% of the samples are FAB M1 subtype, 43% have 11q23 abnormalities, and 36% have up-regulated EVI1 [GeneID=2122] expression.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_2
Systematic name | M1464
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 2 of acute myeloid leukemia (AML) expression profile; 71% of the samples are FAB M4 or M5 subtypes, and 82% bear internal tundem duplications in FLT3 [GeneID=2322].
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_3
Systematic name | M9858
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 3 of acute myeloid leukemia (AML) expression profile; 84% of the samples are FAB M1 or M2 subtypes, 52% bear intern tandem duplication in FLT3 [GeneID=2322].
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_4
Systematic name | M4253
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 4 of acute myeloid leukemia (AML) expression profile; 87% of the samples are FAB M1 subtype, 53% bear mutations in CEBPA [GeneID=1050].
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_5
Systematic name | M14437
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 5 of acute myeloid leukemia (AML) expression profile; 96% of the samples are FAB M4 or M5 subtype.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_6
Systematic name | M4965
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 6 of acute myeloid leukemia (AML) expression profile; all samples are FAB M1 or M2 subtypes and all samples have internal tundem duplication of FLT3 [GeneID=2322].
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_7
Systematic name | M8696
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 7 of acute myeloid leukemia (AML) expression profile; 61% of the samples are FAB M1 or M2 subtype.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_8
Systematic name | M6241
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 8 of aculte myeloid leukemia (AML) expression profile; 69% of the samples are FAB M2 subtype.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_9
Systematic name | M9326
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 9 of acute myeloid leukemia (AML) expression profile; 87% of the samples are FAB M4 or M5 subtype, all have inv(16) inversion producing the CBFB-MYH11 fusion [GeneID=865;4629]; indicate good survival.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_10
Systematic name | M18784
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 10 of acute myeloid leukemia (AML) expression profile; 41% of the samples are FAB M1 subtype, 45% have up-regulated EVI1 [GeneID=2122] expression; indicate poor survival.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_11
Systematic name | M9334
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 11 of acute myeloid leukemia (AML) expression profile; 67% of the samples are FAB M4 or M5.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_12
Systematic name | M5516
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 12 of acute myeloid leukemia (AML) expression profile; 89% of the samples are FAB M3 subtype, 95% bear the t(15;17) translocation, all have the PML-RARA fusion [GeneID=5371;5914]; indicate good survival.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_13
Systematic name | M2603
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 13 of acute myeloid leukemia (AML) expression profile; 91% of the samples are FAB M2 subtype, all bear the t(8;21) translocation producing the AML1-ETO fusion [GeneID=861;862]; indicate good survival.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_15
Systematic name | M15545
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 15 of acute myeloid leukemia (AML) expression profile; 88% of the samples are FAB M1 or M2 subtype, 63% have mutations in CEBPA [GeneID=1050].
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_CLUSTER_16
Systematic name | M16673
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Top 40 genes from cluster 16 of acute myeloid leukemia (AML) expression profile; 81% of the samples are FAB M5 subtype, 45% have 11q23 abnormalities.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_WITH_T_8_21_TRANSLOCATION
Systematic name | M17966
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Genes that best predicted acute myeloid leukemia (AML) with the t(8;21) translocation producing the AML1-ETO fusion [GeneID=861;862].
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_WITH_11Q23_REARRANGED
Systematic name | M9270
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Genes that best predicted acute myeloid leukemia (AML) with the 11q23 rearrangements.
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_WITH_EVI1
Systematic name | M5200
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Genes that best predicted acute myeloid leukemia (AML) with the up-regulated expression of EVI1 [GeneID=2122].
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_WITH_CEBPA
Systematic name | M19586
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Genes that best predicted acute myeloid leukemia (AML) with mutations in CEBPA [GeneID=1050].
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | VALK_AML_WITH_FLT3_ITD
Systematic name | M10010
Organism | Homo sapiens
PMID | 15084694
Authors | Valk PJ,Verhaak RG,Beijen MA,Erpelinck CA,Doorn-Khosrovani van Waalwijk van Barjesteh S,Boer JM,Beverloo HB,Moorhouse MJ,Spek der van PJ,Löwenberg B,Delwel R
Category | C2
Sub-category | CGP
Brief description | Genes that best predicted acute myeloid leukemia (AML) with internal tandem duplications (IDT) in FLT3 [GeneID=2322].
Full description | BACKGROUND: In patients with acute myeloid leukemia (AML) a combination of methods must be used to classify the disease, make therapeutic decisions, and determine the prognosis. However, this combined approach provides correct therapeutic and prognostic information in only 50 percent of cases. METHODS: We determined the gene-expression profiles in samples of peripheral blood or bone marrow from 285 patients with AML using Affymetrix U133A GeneChips containing approximately 13,000 unique genes or expression-signature tags. Data analyses were carried out with Omniviz, significance analysis of microarrays, and prediction analysis of microarrays software. Statistical analyses were performed to determine the prognostic significance of cases of AML with specific molecular signatures. RESULTS: Unsupervised cluster analyses identified 16 groups of patients with AML on the basis of molecular signatures. We identified the genes that defined these clusters and determined the minimal numbers of genes needed to identify prognostically important clusters with a high degree of accuracy. The clustering was driven by the presence of chromosomal lesions (e.g., t(8;21), t(15;17), and inv(16)), particular genetic mutations (CEBPA), and abnormal oncogene expression (EVI1). We identified several novel clusters, some consisting of specimens with normal karyotypes. A unique cluster with a distinctive gene-expression signature included cases of AML with a poor treatment outcome. CONCLUSIONS: Gene-expression profiling allows a comprehensive classification of AML that includes previously identified genetically defined subgroups and a novel cluster with an adverse prognosis.

Standard name | JISON_SICKLE_CELL_DISEASE_UP
Systematic name | M8467
Organism | Homo sapiens
PMID | 15031206
Authors | Jison ML,Munson PJ,Barb JJ,Suffredini AF,Talwar S,Logun C,Raghavachari N,Beigel JH,Shelhamer JH,Danner RL,Gladwin MT
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in peripheral blood mononuclear cells (PBMC) from sickle cell disease patients compared to those from healthy subjects.
Full description | In sickle cell disease, deoxygenation of intra-erythrocytic hemoglobin S leads to hemoglobin polymerization, erythrocyte rigidity, hemolysis, and microvascular occlusion. Ischemia-reperfusion injury, plasma hemoglobin-mediated nitric oxide consumption, and free radical generation activate systemic inflammatory responses. To characterize the role of circulating leukocytes in sickle cell pathogenesis we performed global transcriptional analysis of blood mononuclear cells from 27 patients in steady-state sickle cell disease (10 patients treated and 17 patients untreated with hydroxyurea) compared with 13 control subjects. We used gender-specific gene expression to validate human microarray experiments. Patients with sickle cell disease demonstrated differential gene expression of 112 genes involved in heme metabolism, cell-cycle regulation, antioxidant and stress responses, inflammation, and angiogenesis. Inducible heme oxygenase-1 and downstream proteins biliverdin reductase and p21, a cyclin-dependent kinase, were up-regulated, potentially contributing to phenotypic heterogeneity and absence of atherosclerosis in patients with sickle cell disease despite endothelial dysfunction and vascular inflammation. Hydroxyurea therapy did not significantly affect leukocyte gene expression, suggesting that such therapy has limited direct anti-inflammatory activity beyond leukoreduction. Global transcriptional analysis of circulating leukocytes highlights the intense oxidant and inflammatory nature of steady-state sickle cell disease and provides insight into the broad compensatory responses to vascular injury.

Standard name | JISON_SICKLE_CELL_DISEASE_DN
Systematic name | M4911
Organism | Homo sapiens
PMID | 15031206
Authors | Jison ML,Munson PJ,Barb JJ,Suffredini AF,Talwar S,Logun C,Raghavachari N,Beigel JH,Shelhamer JH,Danner RL,Gladwin MT
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in peripheral blood mononuclear cells (PBMC) from sickle cell disease patients compared to those from healthy subjects.
Full description | In sickle cell disease, deoxygenation of intra-erythrocytic hemoglobin S leads to hemoglobin polymerization, erythrocyte rigidity, hemolysis, and microvascular occlusion. Ischemia-reperfusion injury, plasma hemoglobin-mediated nitric oxide consumption, and free radical generation activate systemic inflammatory responses. To characterize the role of circulating leukocytes in sickle cell pathogenesis we performed global transcriptional analysis of blood mononuclear cells from 27 patients in steady-state sickle cell disease (10 patients treated and 17 patients untreated with hydroxyurea) compared with 13 control subjects. We used gender-specific gene expression to validate human microarray experiments. Patients with sickle cell disease demonstrated differential gene expression of 112 genes involved in heme metabolism, cell-cycle regulation, antioxidant and stress responses, inflammation, and angiogenesis. Inducible heme oxygenase-1 and downstream proteins biliverdin reductase and p21, a cyclin-dependent kinase, were up-regulated, potentially contributing to phenotypic heterogeneity and absence of atherosclerosis in patients with sickle cell disease despite endothelial dysfunction and vascular inflammation. Hydroxyurea therapy did not significantly affect leukocyte gene expression, suggesting that such therapy has limited direct anti-inflammatory activity beyond leukoreduction. Global transcriptional analysis of circulating leukocytes highlights the intense oxidant and inflammatory nature of steady-state sickle cell disease and provides insight into the broad compensatory responses to vascular injury.

Standard name | POOLA_INVASIVE_BREAST_CANCER_UP
Systematic name | M5369
Organism | Homo sapiens
PMID | 15864312
Authors | Poola I,DeWitty RL,Marshalleck JJ,Bhatnagar R,Abraham J,Leffall LD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in atypical ductal hyperplastic tissues from patients with (ADHC) breast cancer vs those without the cancer (ADH).
Full description | Breast cancer is the second leading cause of cancer death for women in the United States. In 2005, about 215,000 cases of invasive breast cancer (IBC) and 50,000 cases of ductal carcinoma in situ will be diagnosed and 40,000 women will die of IBC in the US. Yet there is presently no molecular marker that can be used to detect a precancerous state or identify which premalignant lesions will develop into invasive breast cancer. Here we report the gene expression analysis of atypical ductal hyperplastic tissues from patients with and without a history of breast cancer. We identify MMP-1 as a candidate marker that may be useful for identification of breast lesions that can develop into cancer.

Standard name | POOLA_INVASIVE_BREAST_CANCER_DN
Systematic name | M6767
Organism | Homo sapiens
PMID | 15864312
Authors | Poola I,DeWitty RL,Marshalleck JJ,Bhatnagar R,Abraham J,Leffall LD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in atypical ductal hyperplastic tissues from patients with (ADHC) breast cancer vs those without the cancer (ADH).
Full description | Breast cancer is the second leading cause of cancer death for women in the United States. In 2005, about 215,000 cases of invasive breast cancer (IBC) and 50,000 cases of ductal carcinoma in situ will be diagnosed and 40,000 women will die of IBC in the US. Yet there is presently no molecular marker that can be used to detect a precancerous state or identify which premalignant lesions will develop into invasive breast cancer. Here we report the gene expression analysis of atypical ductal hyperplastic tissues from patients with and without a history of breast cancer. We identify MMP-1 as a candidate marker that may be useful for identification of breast lesions that can develop into cancer.

Standard name | DING_LUNG_CANCER_MUTATED_RECURRENTLY
Systematic name | M14019
Organism | Homo sapiens
PMID | 18948947
Authors | Ding L,Getz G,Wheeler DA,Mardis ER,McLellan MD,Cibulskis K,Sougnez C,Greulich H,Muzny DM,Morgan MB,Fulton L,Fulton RS,Zhang Q,Wendl MC,Lawrence MS,Larson DE,Chen K,Dooling DJ,Sabo A,Hawes AC,Shen H,Jhangiani SN,Lewis LR,Hall O,Zhu Y,Mathew T,Ren Y,Yao J,Scherer SE,Clerc K,Metcalf GA,Ng B,Milosavljevic A,Gonzalez-Garay ML,Osborne JR,Meyer R,Shi X,Tang Y,Koboldt DC,Lin L,Abbott R,Miner TL,Pohl C,Fewell G,Haipek C,Schmidt H,Dunford-Shore BH,Kraja A,Crosby SD,Sawyer CS,Vickery T,Sander S,Robinson J,Winckler W,Baldwin J,Chirieac LR,Dutt A,Fennell T,Hanna M,Johnson BE,Onofrio RC,Thomas RK,Tonon G,Weir BA,Zhao X,Ziaugra L,Zody MC,Giordano T,Orringer MB,Roth JA,Spitz MR,Wistuba II,Ozenberger B,Good PJ,Chang AC,Beer DG,Watson MA,Ladanyi M,Broderick S,Yoshizawa A,Travis WD,Pao W,Province MA,Weinstock GM,Varmus HE,Gabriel SB,Lander ES,Gibbs RA,Meyerson M,Wilson RK
Category | C2
Sub-category | CGP
Brief description | The lung adenocarcinoma TSP (tumor sequencing project) genes bearing recurrent somatic mutations.
Full description | Determining the genetic basis of cancer requires comprehensive analyses of large collections of histopathologically well-classified primary tumours. Here we report the results of a collaborative study to discover somatic mutations in 188 human lung adenocarcinomas. DNA sequencing of 623 genes with known or potential relationships to cancer revealed more than 1,000 somatic mutations across the samples. Our analysis identified 26 genes that are mutated at significantly high frequencies and thus are probably involved in carcinogenesis. The frequently mutated genes include tyrosine kinases, among them the EGFR homologue ERBB4; multiple ephrin receptor genes, notably EPHA3; vascular endothelial growth factor receptor KDR; and NTRK genes. These data provide evidence of somatic mutations in primary lung adenocarcinoma for several tumour suppressor genes involved in other cancers--including NF1, APC, RB1 and ATM--and for sequence changes in PTPRD as well as the frequently deleted gene LRP1B. The observed mutational profiles correlate with clinical features, smoking status and DNA repair defects. These results are reinforced by data integration including single nucleotide polymorphism array and gene expression array. Our findings shed further light on several important signalling pathways involved in lung adenocarcinoma, and suggest new molecular targets for treatment.

Standard name | DING_LUNG_CANCER_BY_MUTATION_RATE
Systematic name | M1189
Organism | Homo sapiens
PMID | 18948947
Authors | Ding L,Getz G,Wheeler DA,Mardis ER,McLellan MD,Cibulskis K,Sougnez C,Greulich H,Muzny DM,Morgan MB,Fulton L,Fulton RS,Zhang Q,Wendl MC,Lawrence MS,Larson DE,Chen K,Dooling DJ,Sabo A,Hawes AC,Shen H,Jhangiani SN,Lewis LR,Hall O,Zhu Y,Mathew T,Ren Y,Yao J,Scherer SE,Clerc K,Metcalf GA,Ng B,Milosavljevic A,Gonzalez-Garay ML,Osborne JR,Meyer R,Shi X,Tang Y,Koboldt DC,Lin L,Abbott R,Miner TL,Pohl C,Fewell G,Haipek C,Schmidt H,Dunford-Shore BH,Kraja A,Crosby SD,Sawyer CS,Vickery T,Sander S,Robinson J,Winckler W,Baldwin J,Chirieac LR,Dutt A,Fennell T,Hanna M,Johnson BE,Onofrio RC,Thomas RK,Tonon G,Weir BA,Zhao X,Ziaugra L,Zody MC,Giordano T,Orringer MB,Roth JA,Spitz MR,Wistuba II,Ozenberger B,Good PJ,Chang AC,Beer DG,Watson MA,Ladanyi M,Broderick S,Yoshizawa A,Travis WD,Pao W,Province MA,Weinstock GM,Varmus HE,Gabriel SB,Lander ES,Gibbs RA,Meyerson M,Wilson RK
Category | C2
Sub-category | CGP
Brief description | The lung adenocarcinoma TSP (tumor sequencing project) genes mutations in which show positive correlation with the higher overall mutation rate.
Full description | Determining the genetic basis of cancer requires comprehensive analyses of large collections of histopathologically well-classified primary tumours. Here we report the results of a collaborative study to discover somatic mutations in 188 human lung adenocarcinomas. DNA sequencing of 623 genes with known or potential relationships to cancer revealed more than 1,000 somatic mutations across the samples. Our analysis identified 26 genes that are mutated at significantly high frequencies and thus are probably involved in carcinogenesis. The frequently mutated genes include tyrosine kinases, among them the EGFR homologue ERBB4; multiple ephrin receptor genes, notably EPHA3; vascular endothelial growth factor receptor KDR; and NTRK genes. These data provide evidence of somatic mutations in primary lung adenocarcinoma for several tumour suppressor genes involved in other cancers--including NF1, APC, RB1 and ATM--and for sequence changes in PTPRD as well as the frequently deleted gene LRP1B. The observed mutational profiles correlate with clinical features, smoking status and DNA repair defects. These results are reinforced by data integration including single nucleotide polymorphism array and gene expression array. Our findings shed further light on several important signalling pathways involved in lung adenocarcinoma, and suggest new molecular targets for treatment.

Standard name | TCGA_GLIOBLASTOMA_MUTATED
Systematic name | M19387
Organism | Homo sapiens
PMID | 18772890
Authors | Cancer Genome Atlas Research Network
Category | C2
Sub-category | CGP
Brief description | Genes significantly mutated in 91 glioblastoma samples.
Full description | Human cancer cells typically harbour multiple chromosomal aberrations, nucleotide substitutions and epigenetic modifications that drive malignant transformation. The Cancer Genome Atlas (TCGA) pilot project aims to assess the value of large-scale multi-dimensional analysis of these molecular characteristics in human cancer and to provide the data rapidly to the research community. Here we report the interim integrative analysis of DNA copy number, gene expression and DNA methylation aberrations in 206 glioblastomas--the most common type of adult brain cancer--and nucleotide sequence aberrations in 91 of the 206 glioblastomas. This analysis provides new insights into the roles of ERBB2, NF1 and TP53, uncovers frequent mutations of the phosphatidylinositol-3-OH kinase regulatory subunit gene PIK3R1, and provides a network view of the pathways altered in the development of glioblastoma. Furthermore, integration of mutation, DNA methylation and clinical treatment data reveals a link between MGMT promoter methylation and a hypermutator phenotype consequent to mismatch repair deficiency in treated glioblastomas, an observation with potential clinical implications. Together, these findings establish the feasibility and power of TCGA, demonstrating that it can rapidly expand knowledge of the molecular basis of cancer.

Standard name | CHEN_LIVER_METABOLISM_QTL_CIS
Systematic name | M1947
Organism | Mus musculus
PMID | 18344982
Authors | Chen Y,Zhu J,Lum PY,Yang X,Pinto S,MacNeil DJ,Zhang C,Lamb J,Edwards S,Sieberts SK,Leonardson A,Castellini LW,Wang S,Champy MF,Zhang B,Emilsson V,Doss S,Ghazalpour A,Horvath S,Drake TA,Lusis AJ,Schadt EE
Category | C2
Sub-category | CGP
Brief description | Cis-regulated expression quantitative loci (cis-eQTL) in the liver that contribute to metabolic quantitative traits (weight, fat mass, and plasma glucose and cholesterol levels).
Full description | Identifying variations in DNA that increase susceptibility to disease is one of the primary aims of genetic studies using a forward genetics approach. However, identification of disease-susceptibility genes by means of such studies provides limited functional information on how genes lead to disease. In fact, in most cases there is an absence of functional information altogether, preventing a definitive identification of the susceptibility gene or genes. Here we develop an alternative to the classic forward genetics approach for dissecting complex disease traits where, instead of identifying susceptibility genes directly affected by variations in DNA, we identify gene networks that are perturbed by susceptibility loci and that in turn lead to disease. Application of this method to liver and adipose gene expression data generated from a segregating mouse population results in the identification of a macrophage-enriched network supported as having a causal relationship with disease traits associated with metabolic syndrome. Three genes in this network, lipoprotein lipase (Lpl), lactamase beta (Lactb) and protein phosphatase 1-like (Ppm1l), are validated as previously unknown obesity genes, strengthening the association between this network and metabolic disease traits. Our analysis provides direct experimental support that complex traits such as obesity are emergent properties of molecular networks that are modulated by complex genetic loci and environmental factors.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G1_UP
Systematic name | M14146
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in hepatocellular carcinoma (HCC) subclass G1, defined by unsupervised clustering
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G1_DN
Systematic name | M1883
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in hepatocellular carcinoma (HCC) subclass G1, defined by unsupervised clustering
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G2
Systematic name | M10953
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Genes in hepatocellular carcinoma (HCC) subclass G2, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G3_UP
Systematic name | M18436
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in hepatocellular carcinoma (HCC) subclass G3, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G3_DN
Systematic name | M4090
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in hepatocellular carcinoma (HCC) subclass G3, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G5_DN
Systematic name | M9343
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in hepatocellular carcinoma (HCC) subclass G5, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G6_UP
Systematic name | M4342
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in hepatocellular carcinoma (HCC) subclass G6, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G6_DN
Systematic name | M14414
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in hepatocellular carcinoma (HCC) subclass G6, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G12_UP
Systematic name | M15147
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in hepatocellular carcinoma (HCC) subclass G12, defined by unsupervised clustering
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G12_DN
Systematic name | M12228
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in hepatocellular carcinoma (HCC) subclass G12, defined by unsupervised clustering
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G23_UP
Systematic name | M4448
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in hepatocellular carcinoma (HCC) subclass G23, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G23_DN
Systematic name | M12809
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in hepatocellular carcinoma (HCC) subclass G23, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G56_UP
Systematic name | M1925
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in hepatocellular carcinoma (HCC) subclass G56, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G56_DN
Systematic name | M10544
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in hepatocellular carcinoma (HCC) subclass G56, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G123_UP
Systematic name | M13831
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in hepatocellular carcinoma (HCC) subclass G123, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | BOYAULT_LIVER_CANCER_SUBCLASS_G123_DN
Systematic name | M2218
Organism | Homo sapiens
PMID | 17187432
Authors | Boyault S,Rickman DS,Reyniès de A,Balabaud C,Rebouissou S,Jeannot E,Hérault A,Saric J,Belghiti J,Franco D,Bioulac-Sage P,Laurent-Puig P,Zucman-Rossi J
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in hepatocellular carcinoma (HCC) subclass G123, defined by unsupervised clustering.
Full description | Hepatocellular carcinomas (HCCs) are a heterogeneous group of tumors that differ in risk factors and genetic alterations. We further investigated transcriptome-genotype-phenotype correlations in HCC. Global transcriptome analyses were performed on 57 HCCs and 3 hepatocellular adenomas and validated by quantitative RT-PCR using 63 additional HCCs. We determined loss of heterozygosity, gene mutations, promoter methylation of CDH1 and CDKN2A, and HBV DNA copy number for each tumor. Unsupervised transcriptome analysis identified 6 robust subgroups of HCC (G1-G6) associated with clinical and genetic characteristics. G1 tumors were associated with low copy number of HBV and overexpression of genes expressed in fetal liver and controlled by parental imprinting. G2 included HCCs infected with a high copy number of HBV and mutations in PIK3CA and TP53. In these first groups, we detected specific activation of the AKT pathway. G3 tumors were typified by mutation of TP53 and overexpression of genes controlling the cell cycle. G4 was a heterogeneous subgroup of tumors including TCF1-mutated hepatocellular adenomas and carcinomas. G5 and G6 were strongly related to beta-catenin mutations that lead to Wnt pathway activation; in particular, G6 tumors were characterized by satellite nodules, higher activation of the Wnt pathway, and E-cadherin underexpression. CONCLUSION: These results have furthered our understanding of the genetic diversity of human HCC and have provided specific identifiers for classifying tumors. In addition, our classification has potential therapeutic implications because 50% of the tumors were related to WNT or AKT pathway activation, which potentially could be targeted by specific inhibiting therapies.

Standard name | CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_UP
Systematic name | M16496
Organism | Homo sapiens
PMID | 18701503
Authors | Chiang DY,Villanueva A,Hoshida Y,Peix J,Newell P,Minguez B,LeBlanc AC,Donovan DJ,Thung SN,Solé M,Tovar V,Alsinet C,Ramos AH,Barretina J,Roayaie S,Schwartz M,Waxman S,Bruix J,Mazzaferro V,Ligon AH,Najfeld V,Friedman SL,Sellers WR,Meyerson M,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Top 200 marker genes up-regulated in the 'CTNNB1' subclass of hepatocellular carcinoma (HCC); characterized by activated CTNNB1 [GeneID=1499].
Full description | Hepatocellular carcinomas represent the third leading cause of cancer-related deaths worldwide. The vast majority of cases arise in the context of chronic liver injury due to hepatitis B virus or hepatitis C virus infection. To identify genetic mechanisms of hepatocarcinogenesis, we characterized copy number alterations and gene expression profiles from the same set of tumors associated with hepatitis C virus. Most tumors harbored 1q gain, 8q gain, or 8p loss, with occasional alterations in 13 additional chromosome arms. In addition to amplifications at 11q13 in 6 of 103 tumors, 4 tumors harbored focal gains at 6p21 incorporating vascular endothelial growth factor A (VEGFA). Fluorescence in situ hybridization on an independent validation set of 210 tumors found 6p21 high-level gains in 14 tumors, as well as 2 tumors with 6p21 amplifications. Strikingly, this locus overlapped with copy gains in 4 of 371 lung adenocarcinomas. Overexpression of VEGFA via 6p21 gain in hepatocellular carcinomas suggested a novel, non-cell-autonomous mechanism of oncogene activation. Hierarchical clustering of gene expression among 91 of these tumors identified five classes, including CTNNB1, proliferation, IFN-related, a novel class defined by polysomy of chromosome 7, and an unannotated class. These class labels were further supported by molecular data; mutations in CTNNB1 were enriched in the CTNNB1 class, whereas insulin-like growth factor I receptor and RPS6 phosphorylation were enriched in the proliferation class. The enrichment of signaling pathway alterations in gene expression classes provides insights on hepatocellular carcinoma pathogenesis. Furthermore, the prevalence of VEGFA high-level gains in multiple tumor types suggests indications for clinical trials of antiangiogenic therapies.

Standard name | CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_DN
Systematic name | M8689
Organism | Homo sapiens
PMID | 18701503
Authors | Chiang DY,Villanueva A,Hoshida Y,Peix J,Newell P,Minguez B,LeBlanc AC,Donovan DJ,Thung SN,Solé M,Tovar V,Alsinet C,Ramos AH,Barretina J,Roayaie S,Schwartz M,Waxman S,Bruix J,Mazzaferro V,Ligon AH,Najfeld V,Friedman SL,Sellers WR,Meyerson M,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Top 200 marker genes down-regulated in the 'CTNNB1' subclass of hepatocellular carcinoma (HCC); characterized by activated CTNNB1 [GeneID=1499].
Full description | Hepatocellular carcinomas represent the third leading cause of cancer-related deaths worldwide. The vast majority of cases arise in the context of chronic liver injury due to hepatitis B virus or hepatitis C virus infection. To identify genetic mechanisms of hepatocarcinogenesis, we characterized copy number alterations and gene expression profiles from the same set of tumors associated with hepatitis C virus. Most tumors harbored 1q gain, 8q gain, or 8p loss, with occasional alterations in 13 additional chromosome arms. In addition to amplifications at 11q13 in 6 of 103 tumors, 4 tumors harbored focal gains at 6p21 incorporating vascular endothelial growth factor A (VEGFA). Fluorescence in situ hybridization on an independent validation set of 210 tumors found 6p21 high-level gains in 14 tumors, as well as 2 tumors with 6p21 amplifications. Strikingly, this locus overlapped with copy gains in 4 of 371 lung adenocarcinomas. Overexpression of VEGFA via 6p21 gain in hepatocellular carcinomas suggested a novel, non-cell-autonomous mechanism of oncogene activation. Hierarchical clustering of gene expression among 91 of these tumors identified five classes, including CTNNB1, proliferation, IFN-related, a novel class defined by polysomy of chromosome 7, and an unannotated class. These class labels were further supported by molecular data; mutations in CTNNB1 were enriched in the CTNNB1 class, whereas insulin-like growth factor I receptor and RPS6 phosphorylation were enriched in the proliferation class. The enrichment of signaling pathway alterations in gene expression classes provides insights on hepatocellular carcinoma pathogenesis. Furthermore, the prevalence of VEGFA high-level gains in multiple tumor types suggests indications for clinical trials of antiangiogenic therapies.

Standard name | CHIANG_LIVER_CANCER_SUBCLASS_PROLIFERATION_UP
Systematic name | M3268
Organism | Homo sapiens
PMID | 18701503
Authors | Chiang DY,Villanueva A,Hoshida Y,Peix J,Newell P,Minguez B,LeBlanc AC,Donovan DJ,Thung SN,Solé M,Tovar V,Alsinet C,Ramos AH,Barretina J,Roayaie S,Schwartz M,Waxman S,Bruix J,Mazzaferro V,Ligon AH,Najfeld V,Friedman SL,Sellers WR,Meyerson M,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Top 200 marker genes up-regulated in the 'proliferation' subclass of hepatocellular carcinoma (HCC); characterized by increased proliferation, high levels of serum AFP [GeneID=174], and chromosomal instability.
Full description | Hepatocellular carcinomas represent the third leading cause of cancer-related deaths worldwide. The vast majority of cases arise in the context of chronic liver injury due to hepatitis B virus or hepatitis C virus infection. To identify genetic mechanisms of hepatocarcinogenesis, we characterized copy number alterations and gene expression profiles from the same set of tumors associated with hepatitis C virus. Most tumors harbored 1q gain, 8q gain, or 8p loss, with occasional alterations in 13 additional chromosome arms. In addition to amplifications at 11q13 in 6 of 103 tumors, 4 tumors harbored focal gains at 6p21 incorporating vascular endothelial growth factor A (VEGFA). Fluorescence in situ hybridization on an independent validation set of 210 tumors found 6p21 high-level gains in 14 tumors, as well as 2 tumors with 6p21 amplifications. Strikingly, this locus overlapped with copy gains in 4 of 371 lung adenocarcinomas. Overexpression of VEGFA via 6p21 gain in hepatocellular carcinomas suggested a novel, non-cell-autonomous mechanism of oncogene activation. Hierarchical clustering of gene expression among 91 of these tumors identified five classes, including CTNNB1, proliferation, IFN-related, a novel class defined by polysomy of chromosome 7, and an unannotated class. These class labels were further supported by molecular data; mutations in CTNNB1 were enriched in the CTNNB1 class, whereas insulin-like growth factor I receptor and RPS6 phosphorylation were enriched in the proliferation class. The enrichment of signaling pathway alterations in gene expression classes provides insights on hepatocellular carcinoma pathogenesis. Furthermore, the prevalence of VEGFA high-level gains in multiple tumor types suggests indications for clinical trials of antiangiogenic therapies.

Standard name | CHIANG_LIVER_CANCER_SUBCLASS_PROLIFERATION_DN
Systematic name | M16932
Organism | Homo sapiens
PMID | 18701503
Authors | Chiang DY,Villanueva A,Hoshida Y,Peix J,Newell P,Minguez B,LeBlanc AC,Donovan DJ,Thung SN,Solé M,Tovar V,Alsinet C,Ramos AH,Barretina J,Roayaie S,Schwartz M,Waxman S,Bruix J,Mazzaferro V,Ligon AH,Najfeld V,Friedman SL,Sellers WR,Meyerson M,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Top 200 marker genes down-regulated in the 'proliferation' subclass of hepatocellular carcinoma (HCC); characterized by increased proliferation, high levels of serum AFP [GeneID=174], and chromosomal instability.
Full description | Hepatocellular carcinomas represent the third leading cause of cancer-related deaths worldwide. The vast majority of cases arise in the context of chronic liver injury due to hepatitis B virus or hepatitis C virus infection. To identify genetic mechanisms of hepatocarcinogenesis, we characterized copy number alterations and gene expression profiles from the same set of tumors associated with hepatitis C virus. Most tumors harbored 1q gain, 8q gain, or 8p loss, with occasional alterations in 13 additional chromosome arms. In addition to amplifications at 11q13 in 6 of 103 tumors, 4 tumors harbored focal gains at 6p21 incorporating vascular endothelial growth factor A (VEGFA). Fluorescence in situ hybridization on an independent validation set of 210 tumors found 6p21 high-level gains in 14 tumors, as well as 2 tumors with 6p21 amplifications. Strikingly, this locus overlapped with copy gains in 4 of 371 lung adenocarcinomas. Overexpression of VEGFA via 6p21 gain in hepatocellular carcinomas suggested a novel, non-cell-autonomous mechanism of oncogene activation. Hierarchical clustering of gene expression among 91 of these tumors identified five classes, including CTNNB1, proliferation, IFN-related, a novel class defined by polysomy of chromosome 7, and an unannotated class. These class labels were further supported by molecular data; mutations in CTNNB1 were enriched in the CTNNB1 class, whereas insulin-like growth factor I receptor and RPS6 phosphorylation were enriched in the proliferation class. The enrichment of signaling pathway alterations in gene expression classes provides insights on hepatocellular carcinoma pathogenesis. Furthermore, the prevalence of VEGFA high-level gains in multiple tumor types suggests indications for clinical trials of antiangiogenic therapies.

Standard name | CHIANG_LIVER_CANCER_SUBCLASS_INTERFERON_UP
Systematic name | M16141
Organism | Homo sapiens
PMID | 18701503
Authors | Chiang DY,Villanueva A,Hoshida Y,Peix J,Newell P,Minguez B,LeBlanc AC,Donovan DJ,Thung SN,Solé M,Tovar V,Alsinet C,Ramos AH,Barretina J,Roayaie S,Schwartz M,Waxman S,Bruix J,Mazzaferro V,Ligon AH,Najfeld V,Friedman SL,Sellers WR,Meyerson M,Llovet JM
Category | C2
Sub-category | CGP
Brief description | All marker genes up-regulated in the 'interferon' subclass of hepatocellular carcinoma (HCC).
Full description | Hepatocellular carcinomas represent the third leading cause of cancer-related deaths worldwide. The vast majority of cases arise in the context of chronic liver injury due to hepatitis B virus or hepatitis C virus infection. To identify genetic mechanisms of hepatocarcinogenesis, we characterized copy number alterations and gene expression profiles from the same set of tumors associated with hepatitis C virus. Most tumors harbored 1q gain, 8q gain, or 8p loss, with occasional alterations in 13 additional chromosome arms. In addition to amplifications at 11q13 in 6 of 103 tumors, 4 tumors harbored focal gains at 6p21 incorporating vascular endothelial growth factor A (VEGFA). Fluorescence in situ hybridization on an independent validation set of 210 tumors found 6p21 high-level gains in 14 tumors, as well as 2 tumors with 6p21 amplifications. Strikingly, this locus overlapped with copy gains in 4 of 371 lung adenocarcinomas. Overexpression of VEGFA via 6p21 gain in hepatocellular carcinomas suggested a novel, non-cell-autonomous mechanism of oncogene activation. Hierarchical clustering of gene expression among 91 of these tumors identified five classes, including CTNNB1, proliferation, IFN-related, a novel class defined by polysomy of chromosome 7, and an unannotated class. These class labels were further supported by molecular data; mutations in CTNNB1 were enriched in the CTNNB1 class, whereas insulin-like growth factor I receptor and RPS6 phosphorylation were enriched in the proliferation class. The enrichment of signaling pathway alterations in gene expression classes provides insights on hepatocellular carcinoma pathogenesis. Furthermore, the prevalence of VEGFA high-level gains in multiple tumor types suggests indications for clinical trials of antiangiogenic therapies.

Standard name | CHIANG_LIVER_CANCER_SUBCLASS_INTERFERON_DN
Systematic name | M14353
Organism | Homo sapiens
PMID | 18701503
Authors | Chiang DY,Villanueva A,Hoshida Y,Peix J,Newell P,Minguez B,LeBlanc AC,Donovan DJ,Thung SN,Solé M,Tovar V,Alsinet C,Ramos AH,Barretina J,Roayaie S,Schwartz M,Waxman S,Bruix J,Mazzaferro V,Ligon AH,Najfeld V,Friedman SL,Sellers WR,Meyerson M,Llovet JM
Category | C2
Sub-category | CGP
Brief description | All marker genes down-regulated in the 'interferon' subclass of hepatocellular carcinoma (HCC).
Full description | Hepatocellular carcinomas represent the third leading cause of cancer-related deaths worldwide. The vast majority of cases arise in the context of chronic liver injury due to hepatitis B virus or hepatitis C virus infection. To identify genetic mechanisms of hepatocarcinogenesis, we characterized copy number alterations and gene expression profiles from the same set of tumors associated with hepatitis C virus. Most tumors harbored 1q gain, 8q gain, or 8p loss, with occasional alterations in 13 additional chromosome arms. In addition to amplifications at 11q13 in 6 of 103 tumors, 4 tumors harbored focal gains at 6p21 incorporating vascular endothelial growth factor A (VEGFA). Fluorescence in situ hybridization on an independent validation set of 210 tumors found 6p21 high-level gains in 14 tumors, as well as 2 tumors with 6p21 amplifications. Strikingly, this locus overlapped with copy gains in 4 of 371 lung adenocarcinomas. Overexpression of VEGFA via 6p21 gain in hepatocellular carcinomas suggested a novel, non-cell-autonomous mechanism of oncogene activation. Hierarchical clustering of gene expression among 91 of these tumors identified five classes, including CTNNB1, proliferation, IFN-related, a novel class defined by polysomy of chromosome 7, and an unannotated class. These class labels were further supported by molecular data; mutations in CTNNB1 were enriched in the CTNNB1 class, whereas insulin-like growth factor I receptor and RPS6 phosphorylation were enriched in the proliferation class. The enrichment of signaling pathway alterations in gene expression classes provides insights on hepatocellular carcinoma pathogenesis. Furthermore, the prevalence of VEGFA high-level gains in multiple tumor types suggests indications for clinical trials of antiangiogenic therapies.

Standard name | CHIANG_LIVER_CANCER_SUBCLASS_POLYSOMY7_UP
Systematic name | M834
Organism | Homo sapiens
PMID | 18701503
Authors | Chiang DY,Villanueva A,Hoshida Y,Peix J,Newell P,Minguez B,LeBlanc AC,Donovan DJ,Thung SN,Solé M,Tovar V,Alsinet C,Ramos AH,Barretina J,Roayaie S,Schwartz M,Waxman S,Bruix J,Mazzaferro V,Ligon AH,Najfeld V,Friedman SL,Sellers WR,Meyerson M,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Marker genes up-regulated in the 'chromosome 7 polysomy' subclass of hepatocellular carcinoma (HCC); characterized by polysomy of chromosome 7 and by a lack of gains of chromosome 8q.
Full description | Hepatocellular carcinomas represent the third leading cause of cancer-related deaths worldwide. The vast majority of cases arise in the context of chronic liver injury due to hepatitis B virus or hepatitis C virus infection. To identify genetic mechanisms of hepatocarcinogenesis, we characterized copy number alterations and gene expression profiles from the same set of tumors associated with hepatitis C virus. Most tumors harbored 1q gain, 8q gain, or 8p loss, with occasional alterations in 13 additional chromosome arms. In addition to amplifications at 11q13 in 6 of 103 tumors, 4 tumors harbored focal gains at 6p21 incorporating vascular endothelial growth factor A (VEGFA). Fluorescence in situ hybridization on an independent validation set of 210 tumors found 6p21 high-level gains in 14 tumors, as well as 2 tumors with 6p21 amplifications. Strikingly, this locus overlapped with copy gains in 4 of 371 lung adenocarcinomas. Overexpression of VEGFA via 6p21 gain in hepatocellular carcinomas suggested a novel, non-cell-autonomous mechanism of oncogene activation. Hierarchical clustering of gene expression among 91 of these tumors identified five classes, including CTNNB1, proliferation, IFN-related, a novel class defined by polysomy of chromosome 7, and an unannotated class. These class labels were further supported by molecular data; mutations in CTNNB1 were enriched in the CTNNB1 class, whereas insulin-like growth factor I receptor and RPS6 phosphorylation were enriched in the proliferation class. The enrichment of signaling pathway alterations in gene expression classes provides insights on hepatocellular carcinoma pathogenesis. Furthermore, the prevalence of VEGFA high-level gains in multiple tumor types suggests indications for clinical trials of antiangiogenic therapies.

Standard name | CHIANG_LIVER_CANCER_SUBCLASS_POLYSOMY7_DN
Systematic name | M7678
Organism | Homo sapiens
PMID | 18701503
Authors | Chiang DY,Villanueva A,Hoshida Y,Peix J,Newell P,Minguez B,LeBlanc AC,Donovan DJ,Thung SN,Solé M,Tovar V,Alsinet C,Ramos AH,Barretina J,Roayaie S,Schwartz M,Waxman S,Bruix J,Mazzaferro V,Ligon AH,Najfeld V,Friedman SL,Sellers WR,Meyerson M,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Marker genes down-regulated in the 'chromosome 7 polysomy' subclass of hepatocellular carcinoma (HCC); characterized by polysomy of chromosome 7 and by a lack of gains of chromosome 8q.
Full description | Hepatocellular carcinomas represent the third leading cause of cancer-related deaths worldwide. The vast majority of cases arise in the context of chronic liver injury due to hepatitis B virus or hepatitis C virus infection. To identify genetic mechanisms of hepatocarcinogenesis, we characterized copy number alterations and gene expression profiles from the same set of tumors associated with hepatitis C virus. Most tumors harbored 1q gain, 8q gain, or 8p loss, with occasional alterations in 13 additional chromosome arms. In addition to amplifications at 11q13 in 6 of 103 tumors, 4 tumors harbored focal gains at 6p21 incorporating vascular endothelial growth factor A (VEGFA). Fluorescence in situ hybridization on an independent validation set of 210 tumors found 6p21 high-level gains in 14 tumors, as well as 2 tumors with 6p21 amplifications. Strikingly, this locus overlapped with copy gains in 4 of 371 lung adenocarcinomas. Overexpression of VEGFA via 6p21 gain in hepatocellular carcinomas suggested a novel, non-cell-autonomous mechanism of oncogene activation. Hierarchical clustering of gene expression among 91 of these tumors identified five classes, including CTNNB1, proliferation, IFN-related, a novel class defined by polysomy of chromosome 7, and an unannotated class. These class labels were further supported by molecular data; mutations in CTNNB1 were enriched in the CTNNB1 class, whereas insulin-like growth factor I receptor and RPS6 phosphorylation were enriched in the proliferation class. The enrichment of signaling pathway alterations in gene expression classes provides insights on hepatocellular carcinoma pathogenesis. Furthermore, the prevalence of VEGFA high-level gains in multiple tumor types suggests indications for clinical trials of antiangiogenic therapies.

Standard name | CHIANG_LIVER_CANCER_SUBCLASS_UNANNOTATED_UP
Systematic name | M19610
Organism | Homo sapiens
PMID | 18701503
Authors | Chiang DY,Villanueva A,Hoshida Y,Peix J,Newell P,Minguez B,LeBlanc AC,Donovan DJ,Thung SN,Solé M,Tovar V,Alsinet C,Ramos AH,Barretina J,Roayaie S,Schwartz M,Waxman S,Bruix J,Mazzaferro V,Ligon AH,Najfeld V,Friedman SL,Sellers WR,Meyerson M,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Marker genes up-regulated in the 'unannotated' subclass of hepatocellular carcinoma (HCC) samples.
Full description | Hepatocellular carcinomas represent the third leading cause of cancer-related deaths worldwide. The vast majority of cases arise in the context of chronic liver injury due to hepatitis B virus or hepatitis C virus infection. To identify genetic mechanisms of hepatocarcinogenesis, we characterized copy number alterations and gene expression profiles from the same set of tumors associated with hepatitis C virus. Most tumors harbored 1q gain, 8q gain, or 8p loss, with occasional alterations in 13 additional chromosome arms. In addition to amplifications at 11q13 in 6 of 103 tumors, 4 tumors harbored focal gains at 6p21 incorporating vascular endothelial growth factor A (VEGFA). Fluorescence in situ hybridization on an independent validation set of 210 tumors found 6p21 high-level gains in 14 tumors, as well as 2 tumors with 6p21 amplifications. Strikingly, this locus overlapped with copy gains in 4 of 371 lung adenocarcinomas. Overexpression of VEGFA via 6p21 gain in hepatocellular carcinomas suggested a novel, non-cell-autonomous mechanism of oncogene activation. Hierarchical clustering of gene expression among 91 of these tumors identified five classes, including CTNNB1, proliferation, IFN-related, a novel class defined by polysomy of chromosome 7, and an unannotated class. These class labels were further supported by molecular data; mutations in CTNNB1 were enriched in the CTNNB1 class, whereas insulin-like growth factor I receptor and RPS6 phosphorylation were enriched in the proliferation class. The enrichment of signaling pathway alterations in gene expression classes provides insights on hepatocellular carcinoma pathogenesis. Furthermore, the prevalence of VEGFA high-level gains in multiple tumor types suggests indications for clinical trials of antiangiogenic therapies.

Standard name | CHIANG_LIVER_CANCER_SUBCLASS_UNANNOTATED_DN
Systematic name | M10986
Organism | Homo sapiens
PMID | 18701503
Authors | Chiang DY,Villanueva A,Hoshida Y,Peix J,Newell P,Minguez B,LeBlanc AC,Donovan DJ,Thung SN,Solé M,Tovar V,Alsinet C,Ramos AH,Barretina J,Roayaie S,Schwartz M,Waxman S,Bruix J,Mazzaferro V,Ligon AH,Najfeld V,Friedman SL,Sellers WR,Meyerson M,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Marker genes down-regulated in the 'unannotated' subclass of hepatocellular carcinoma (HCC) samples.
Full description | Hepatocellular carcinomas represent the third leading cause of cancer-related deaths worldwide. The vast majority of cases arise in the context of chronic liver injury due to hepatitis B virus or hepatitis C virus infection. To identify genetic mechanisms of hepatocarcinogenesis, we characterized copy number alterations and gene expression profiles from the same set of tumors associated with hepatitis C virus. Most tumors harbored 1q gain, 8q gain, or 8p loss, with occasional alterations in 13 additional chromosome arms. In addition to amplifications at 11q13 in 6 of 103 tumors, 4 tumors harbored focal gains at 6p21 incorporating vascular endothelial growth factor A (VEGFA). Fluorescence in situ hybridization on an independent validation set of 210 tumors found 6p21 high-level gains in 14 tumors, as well as 2 tumors with 6p21 amplifications. Strikingly, this locus overlapped with copy gains in 4 of 371 lung adenocarcinomas. Overexpression of VEGFA via 6p21 gain in hepatocellular carcinomas suggested a novel, non-cell-autonomous mechanism of oncogene activation. Hierarchical clustering of gene expression among 91 of these tumors identified five classes, including CTNNB1, proliferation, IFN-related, a novel class defined by polysomy of chromosome 7, and an unannotated class. These class labels were further supported by molecular data; mutations in CTNNB1 were enriched in the CTNNB1 class, whereas insulin-like growth factor I receptor and RPS6 phosphorylation were enriched in the proliferation class. The enrichment of signaling pathway alterations in gene expression classes provides insights on hepatocellular carcinoma pathogenesis. Furthermore, the prevalence of VEGFA high-level gains in multiple tumor types suggests indications for clinical trials of antiangiogenic therapies.

Standard name | COULOUARN_TEMPORAL_TGFB1_SIGNATURE_UP
Systematic name | M18762
Organism | Homo sapiens
PMID | 18506891
Authors | Coulouarn C,Factor VM,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | 'Late-TGFB1 signature': genes overexpressed in primary hepatocytes at a late phase of TGFB1 [GeneID=7040] treatment; is associated with a more invasive phenotype.
Full description | Hepatocellular carcinoma (HCC) is one of the most common cancers in the world. The clinical heterogeneity of HCC, and the lack of good diagnostic markers and treatment strategies, has rendered the disease a major challenge. Patients with HCC have a highly variable clinical course, indicating that HCC comprises several biologically distinctive subgroups reflecting a molecular heterogeneity of the tumors. Transforming growth factor beta (TGF-beta) is known to exhibit tumor stage dependent suppressive (that is, growth inhibition) and oncogenic (that is, invasiveness) properties. Here, we asked if a TGF-beta specific gene expression signature could refine the classification and prognostic predictions for HCC patients. Applying a comparative functional genomics approach we demonstrated that a temporal TGF-beta gene expression signature established in mouse primary hepatocytes successfully discriminated distinct subgroups of HCC. The TGF-beta positive cluster included two novel homogeneous groups of HCC associated with early and late TGF-beta signatures. Kaplan-Meier plots and log-rank statistics indicated that the patients with a late TGF-beta signature showed significantly (P < 0.005) shortened mean survival time (16.2 +/- 5.3 months) compared to the patients with an early (60.7 +/- 16.1 months) TGF-beta signature. Also, tumors expressing late TGF-beta-responsive genes displayed invasive phenotype and increased tumor recurrence. We also showed that the late TGF-beta signature accurately predicted liver metastasis and discriminated HCC cell lines by degree of invasiveness. Finally, we established that the TGF-beta gene expression signature possessed a predictive value for tumors other than HCC. CONCLUSION: These data demonstrate the clinical significance of the genes embedded in TGF-beta expression signature for the molecular classification of HCC.

Standard name | COULOUARN_TEMPORAL_TGFB1_SIGNATURE_DN
Systematic name | M19245
Organism | Homo sapiens
PMID | 18506891
Authors | Coulouarn C,Factor VM,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | 'Early-TGFB1 signature': genes overexpressed in primary hepatocytes at an early phase of TGFB1 [GeneID=7040] treatment; is associated with a less invasive phenotype.
Full description | Hepatocellular carcinoma (HCC) is one of the most common cancers in the world. The clinical heterogeneity of HCC, and the lack of good diagnostic markers and treatment strategies, has rendered the disease a major challenge. Patients with HCC have a highly variable clinical course, indicating that HCC comprises several biologically distinctive subgroups reflecting a molecular heterogeneity of the tumors. Transforming growth factor beta (TGF-beta) is known to exhibit tumor stage dependent suppressive (that is, growth inhibition) and oncogenic (that is, invasiveness) properties. Here, we asked if a TGF-beta specific gene expression signature could refine the classification and prognostic predictions for HCC patients. Applying a comparative functional genomics approach we demonstrated that a temporal TGF-beta gene expression signature established in mouse primary hepatocytes successfully discriminated distinct subgroups of HCC. The TGF-beta positive cluster included two novel homogeneous groups of HCC associated with early and late TGF-beta signatures. Kaplan-Meier plots and log-rank statistics indicated that the patients with a late TGF-beta signature showed significantly (P < 0.005) shortened mean survival time (16.2 +/- 5.3 months) compared to the patients with an early (60.7 +/- 16.1 months) TGF-beta signature. Also, tumors expressing late TGF-beta-responsive genes displayed invasive phenotype and increased tumor recurrence. We also showed that the late TGF-beta signature accurately predicted liver metastasis and discriminated HCC cell lines by degree of invasiveness. Finally, we established that the TGF-beta gene expression signature possessed a predictive value for tumors other than HCC. CONCLUSION: These data demonstrate the clinical significance of the genes embedded in TGF-beta expression signature for the molecular classification of HCC.

Standard name | HOSHIDA_LIVER_CANCER_LATE_RECURRENCE_UP
Systematic name | M6176
Organism | Homo sapiens
PMID | 18923165
Authors | Hoshida Y,Villanueva A,Kobayashi M,Peix J,Chiang DY,Camargo A,Gupta S,Moore J,Wrobel MJ,Lerner J,Reich M,Chan JA,Glickman JN,Ikeda K,Hashimoto M,Watanabe G,Daidone MG,Roayaie S,Schwartz M,Thung S,Salvesen HB,Gabriel S,Mazzaferro V,Bruix J,Friedman SL,Kumada H,Llovet JM,Golub TR
Category | C2
Sub-category | CGP
Brief description | Genes whose expression correlated with higher risk of late recurrence of hepatocellular carcinoma (HCC).
Full description | BACKGROUND: It is a challenge to identify patients who, after undergoing potentially curative treatment for hepatocellular carcinoma, are at greatest risk for recurrence. Such high-risk patients could receive novel interventional measures. An obstacle to the development of genome-based predictors of outcome in patients with hepatocellular carcinoma has been the lack of a means to carry out genomewide expression profiling of fixed, as opposed to frozen, tissue. METHODS: We aimed to demonstrate the feasibility of gene-expression profiling of more than 6000 human genes in formalin-fixed, paraffin-embedded tissues. We applied the method to tissues from 307 patients with hepatocellular carcinoma, from four series of patients, to discover and validate a gene-expression signature associated with survival. RESULTS: The expression-profiling method for formalin-fixed, paraffin-embedded tissue was highly effective: samples from 90% of the patients yielded data of high quality, including samples that had been archived for more than 24 years. Gene-expression profiles of tumor tissue failed to yield a significant association with survival. In contrast, profiles of the surrounding nontumoral liver tissue were highly correlated with survival in a training set of tissue samples from 82 Japanese patients, and the signature was validated in tissues from an independent group of 225 patients from the United States and Europe (P=0.04). CONCLUSIONS: We have demonstrated the feasibility of genomewide expression profiling of formalin-fixed, paraffin-embedded tissues and have shown that a reproducible gene-expression signature correlated with survival is present in liver tissue adjacent to the tumor in patients with hepatocellular carcinoma.

Standard name | HOSHIDA_LIVER_CANCER_LATE_RECURRENCE_DN
Systematic name | M13658
Organism | Homo sapiens
PMID | 18923165
Authors | Hoshida Y,Villanueva A,Kobayashi M,Peix J,Chiang DY,Camargo A,Gupta S,Moore J,Wrobel MJ,Lerner J,Reich M,Chan JA,Glickman JN,Ikeda K,Hashimoto M,Watanabe G,Daidone MG,Roayaie S,Schwartz M,Thung S,Salvesen HB,Gabriel S,Mazzaferro V,Bruix J,Friedman SL,Kumada H,Llovet JM,Golub TR
Category | C2
Sub-category | CGP
Brief description | Genes whose expression correlated with lower risk of late recurrence of hepatocellular carcinoma (HCC).
Full description | BACKGROUND: It is a challenge to identify patients who, after undergoing potentially curative treatment for hepatocellular carcinoma, are at greatest risk for recurrence. Such high-risk patients could receive novel interventional measures. An obstacle to the development of genome-based predictors of outcome in patients with hepatocellular carcinoma has been the lack of a means to carry out genomewide expression profiling of fixed, as opposed to frozen, tissue. METHODS: We aimed to demonstrate the feasibility of gene-expression profiling of more than 6000 human genes in formalin-fixed, paraffin-embedded tissues. We applied the method to tissues from 307 patients with hepatocellular carcinoma, from four series of patients, to discover and validate a gene-expression signature associated with survival. RESULTS: The expression-profiling method for formalin-fixed, paraffin-embedded tissue was highly effective: samples from 90% of the patients yielded data of high quality, including samples that had been archived for more than 24 years. Gene-expression profiles of tumor tissue failed to yield a significant association with survival. In contrast, profiles of the surrounding nontumoral liver tissue were highly correlated with survival in a training set of tissue samples from 82 Japanese patients, and the signature was validated in tissues from an independent group of 225 patients from the United States and Europe (P=0.04). CONCLUSIONS: We have demonstrated the feasibility of genomewide expression profiling of formalin-fixed, paraffin-embedded tissues and have shown that a reproducible gene-expression signature correlated with survival is present in liver tissue adjacent to the tumor in patients with hepatocellular carcinoma.

Standard name | HOSHIDA_LIVER_CANCER_SURVIVAL_UP
Systematic name | M6939
Organism | Homo sapiens
PMID | 18923165
Authors | Hoshida Y,Villanueva A,Kobayashi M,Peix J,Chiang DY,Camargo A,Gupta S,Moore J,Wrobel MJ,Lerner J,Reich M,Chan JA,Glickman JN,Ikeda K,Hashimoto M,Watanabe G,Daidone MG,Roayaie S,Schwartz M,Thung S,Salvesen HB,Gabriel S,Mazzaferro V,Bruix J,Friedman SL,Kumada H,Llovet JM,Golub TR
Category | C2
Sub-category | CGP
Brief description | Survival signature genes defined in adjacent liver tissue: genes correlated with poor survival of hepatocellular carcinoma (HCC) patients.
Full description | BACKGROUND: It is a challenge to identify patients who, after undergoing potentially curative treatment for hepatocellular carcinoma, are at greatest risk for recurrence. Such high-risk patients could receive novel interventional measures. An obstacle to the development of genome-based predictors of outcome in patients with hepatocellular carcinoma has been the lack of a means to carry out genomewide expression profiling of fixed, as opposed to frozen, tissue. METHODS: We aimed to demonstrate the feasibility of gene-expression profiling of more than 6000 human genes in formalin-fixed, paraffin-embedded tissues. We applied the method to tissues from 307 patients with hepatocellular carcinoma, from four series of patients, to discover and validate a gene-expression signature associated with survival. RESULTS: The expression-profiling method for formalin-fixed, paraffin-embedded tissue was highly effective: samples from 90% of the patients yielded data of high quality, including samples that had been archived for more than 24 years. Gene-expression profiles of tumor tissue failed to yield a significant association with survival. In contrast, profiles of the surrounding nontumoral liver tissue were highly correlated with survival in a training set of tissue samples from 82 Japanese patients, and the signature was validated in tissues from an independent group of 225 patients from the United States and Europe (P=0.04). CONCLUSIONS: We have demonstrated the feasibility of genomewide expression profiling of formalin-fixed, paraffin-embedded tissues and have shown that a reproducible gene-expression signature correlated with survival is present in liver tissue adjacent to the tumor in patients with hepatocellular carcinoma.

Standard name | HOSHIDA_LIVER_CANCER_SURVIVAL_DN
Systematic name | M5451
Organism | Homo sapiens
PMID | 18923165
Authors | Hoshida Y,Villanueva A,Kobayashi M,Peix J,Chiang DY,Camargo A,Gupta S,Moore J,Wrobel MJ,Lerner J,Reich M,Chan JA,Glickman JN,Ikeda K,Hashimoto M,Watanabe G,Daidone MG,Roayaie S,Schwartz M,Thung S,Salvesen HB,Gabriel S,Mazzaferro V,Bruix J,Friedman SL,Kumada H,Llovet JM,Golub TR
Category | C2
Sub-category | CGP
Brief description | Survival signature genes defined in adjacent liver tissue: genes correlated with good survival of hepatocellular carcinoma (HCC) patients.
Full description | BACKGROUND: It is a challenge to identify patients who, after undergoing potentially curative treatment for hepatocellular carcinoma, are at greatest risk for recurrence. Such high-risk patients could receive novel interventional measures. An obstacle to the development of genome-based predictors of outcome in patients with hepatocellular carcinoma has been the lack of a means to carry out genomewide expression profiling of fixed, as opposed to frozen, tissue. METHODS: We aimed to demonstrate the feasibility of gene-expression profiling of more than 6000 human genes in formalin-fixed, paraffin-embedded tissues. We applied the method to tissues from 307 patients with hepatocellular carcinoma, from four series of patients, to discover and validate a gene-expression signature associated with survival. RESULTS: The expression-profiling method for formalin-fixed, paraffin-embedded tissue was highly effective: samples from 90% of the patients yielded data of high quality, including samples that had been archived for more than 24 years. Gene-expression profiles of tumor tissue failed to yield a significant association with survival. In contrast, profiles of the surrounding nontumoral liver tissue were highly correlated with survival in a training set of tissue samples from 82 Japanese patients, and the signature was validated in tissues from an independent group of 225 patients from the United States and Europe (P=0.04). CONCLUSIONS: We have demonstrated the feasibility of genomewide expression profiling of formalin-fixed, paraffin-embedded tissues and have shown that a reproducible gene-expression signature correlated with survival is present in liver tissue adjacent to the tumor in patients with hepatocellular carcinoma.

Standard name | KAPOSI_LIVER_CANCER_MET_UP
Systematic name | M5755
Organism | Homo sapiens
PMID | 16710476
Authors | Kaposi-Novak P,Lee JS,Gòmez-Quiroz L,Coulouarn C,Factor VM,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Selected up-regulated MET [GeneID=4233] target genes from a classifier of hepatocellular carcinoma (HCC) cases; associated with poor survival.
Full description | Identification of specific gene expression signatures characteristic of oncogenic pathways is an important step toward molecular classification of human malignancies. Aberrant activation of the Met signaling pathway is frequently associated with tumor progression and metastasis. In this study, we defined the Met-dependent gene expression signature using global gene expression profiling of WT and Met-deficient primary mouse hepatocytes. Newly identified transcriptional targets of the Met pathway included genes involved in the regulation of oxidative stress responses as well as cell motility, cytoskeletal organization, and angiogenesis. To assess the importance of a Met-regulated gene expression signature, a comparative functional genomic approach was applied to 242 human hepatocellular carcinomas (HCCs) and 7 metastatic liver lesions. Cluster analysis revealed that a subset of human HCCs and all liver metastases shared the Met-induced expression signature. Furthermore, the presence of the Met signature showed significant correlation with increased vascular invasion rate and microvessel density as well as with decreased mean survival time of HCC patients. We conclude that the genetically defined gene expression signatures in combination with comparative functional genomics constitute an attractive paradigm for defining both the function of oncogenic pathways and the clinically relevant subgroups of human cancers.

Standard name | KAPOSI_LIVER_CANCER_MET_DN
Systematic name | M2184
Organism | Homo sapiens
PMID | 16710476
Authors | Kaposi-Novak P,Lee JS,Gòmez-Quiroz L,Coulouarn C,Factor VM,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Selected down-regulated MET [GeneID=4233] target genes from a classifier of hepatocellular carcinoma (HCC) cases; associated with poor survival.
Full description | Identification of specific gene expression signatures characteristic of oncogenic pathways is an important step toward molecular classification of human malignancies. Aberrant activation of the Met signaling pathway is frequently associated with tumor progression and metastasis. In this study, we defined the Met-dependent gene expression signature using global gene expression profiling of WT and Met-deficient primary mouse hepatocytes. Newly identified transcriptional targets of the Met pathway included genes involved in the regulation of oxidative stress responses as well as cell motility, cytoskeletal organization, and angiogenesis. To assess the importance of a Met-regulated gene expression signature, a comparative functional genomic approach was applied to 242 human hepatocellular carcinomas (HCCs) and 7 metastatic liver lesions. Cluster analysis revealed that a subset of human HCCs and all liver metastases shared the Met-induced expression signature. Furthermore, the presence of the Met signature showed significant correlation with increased vascular invasion rate and microvessel density as well as with decreased mean survival time of HCC patients. We conclude that the genetically defined gene expression signatures in combination with comparative functional genomics constitute an attractive paradigm for defining both the function of oncogenic pathways and the clinically relevant subgroups of human cancers.

Standard name | YAMASHITA_LIVER_CANCER_WITH_EPCAM_UP
Systematic name | M16542
Organism | Homo sapiens
PMID | 18316609
Authors | Yamashita T,Forgues M,Wang W,Kim JW,Ye Q,Jia H,Budhu A,Zanetti KA,Chen Y,Qin LX,Tang ZY,Wang XW
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes distinguishing hepatocellular carcinoma (HCC) samples positive for EPCAM [GeneID=4072] from the negative ones.
Full description | The heterogeneous nature of hepatocellular carcinoma (HCC) and the lack of appropriate biomarkers have hampered patient prognosis and treatment stratification. Recently, we have identified that a hepatic stem cell marker, epithelial cell adhesion molecule (EpCAM), may serve as an early biomarker of HCC because its expression is highly elevated in premalignant hepatic tissues and in a subset of HCC. In this study, we aimed to identify novel HCC subtypes that resemble certain stages of liver lineages by searching for EpCAM-coexpressed genes. A unique signature of EpCAM-positive HCCs was identified by cDNA microarray analysis of 40 HCC cases and validated by oligonucleotide microarray analysis of 238 independent HCC cases, which was further confirmed by immunohistochemical analysis of an additional 101 HCC cases. EpCAM-positive HCC displayed a distinct molecular signature with features of hepatic progenitor cells including the presence of known stem/progenitor markers such as cytokeratin 19, c-Kit, EpCAM, and activated Wnt-beta-catenin signaling, whereas EpCAM-negative HCC displayed genes with features of mature hepatocytes. Moreover, EpCAM-positive and EpCAM-negative HCC could be further subclassified into four groups with prognostic implication by determining the level of alpha-fetoprotein (AFP). These four subtypes displayed distinct gene expression patterns with features resembling certain stages of hepatic lineages. Taken together, we proposed an easy classification system defined by EpCAM and AFP to reveal HCC subtypes similar to hepatic cell maturation lineages, which may enable prognostic stratification and assessment of HCC patients with adjuvant therapy and provide new insights into the potential cellular origin of HCC and its activated molecular pathways.

Standard name | YAMASHITA_LIVER_CANCER_WITH_EPCAM_DN
Systematic name | M9914
Organism | Homo sapiens
PMID | 18316609
Authors | Yamashita T,Forgues M,Wang W,Kim JW,Ye Q,Jia H,Budhu A,Zanetti KA,Chen Y,Qin LX,Tang ZY,Wang XW
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes distinguishing hepatocellular carcinoma (HCC) samples positive for EPCAM [GeneID=4072] from the negative ones.
Full description | The heterogeneous nature of hepatocellular carcinoma (HCC) and the lack of appropriate biomarkers have hampered patient prognosis and treatment stratification. Recently, we have identified that a hepatic stem cell marker, epithelial cell adhesion molecule (EpCAM), may serve as an early biomarker of HCC because its expression is highly elevated in premalignant hepatic tissues and in a subset of HCC. In this study, we aimed to identify novel HCC subtypes that resemble certain stages of liver lineages by searching for EpCAM-coexpressed genes. A unique signature of EpCAM-positive HCCs was identified by cDNA microarray analysis of 40 HCC cases and validated by oligonucleotide microarray analysis of 238 independent HCC cases, which was further confirmed by immunohistochemical analysis of an additional 101 HCC cases. EpCAM-positive HCC displayed a distinct molecular signature with features of hepatic progenitor cells including the presence of known stem/progenitor markers such as cytokeratin 19, c-Kit, EpCAM, and activated Wnt-beta-catenin signaling, whereas EpCAM-negative HCC displayed genes with features of mature hepatocytes. Moreover, EpCAM-positive and EpCAM-negative HCC could be further subclassified into four groups with prognostic implication by determining the level of alpha-fetoprotein (AFP). These four subtypes displayed distinct gene expression patterns with features resembling certain stages of hepatic lineages. Taken together, we proposed an easy classification system defined by EpCAM and AFP to reveal HCC subtypes similar to hepatic cell maturation lineages, which may enable prognostic stratification and assessment of HCC patients with adjuvant therapy and provide new insights into the potential cellular origin of HCC and its activated molecular pathways.

Standard name | YAMASHITA_LIVER_CANCER_STEM_CELL_UP
Systematic name | M16956
Organism | Homo sapiens
PMID | 19150350
Authors | Yamashita T,Ji J,Budhu A,Forgues M,Yang W,Wang HY,Jia H,Ye Q,Qin LX,Wauthier E,Reid LM,Minato H,Honda M,Kaneko S,Tang ZY,Wang XW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) cells with hepatic stem cell properties.
Full description | BACKGROUND & AIMS: Cancer progression/metastases and embryonic development share many properties including cellular plasticity, dynamic cell motility, and integral interaction with the microenvironment. We hypothesized that the heterogeneous nature of hepatocellular carcinoma (HCC), in part, may be owing to the presence of hepatic cancer cells with stem/progenitor features. METHODS: Gene expression profiling and immunohistochemistry analyses were used to analyze 235 tumor specimens derived from 2 recently identified HCC subtypes (EpCAM(+) alpha-fetoprotein [AFP(+)] HCC and EpCAM(-) AFP(-) HCC). These subtypes differed in their expression of AFP, a molecule produced in the developing embryo, and EpCAM, a cell surface hepatic stem cell marker. Fluorescence-activated cell sorting was used to isolate EpCAM(+) HCC cells, which were tested for hepatic stem/progenitor cell properties. RESULTS: Gene expression and pathway analyses revealed that the EpCAM(+) AFP(+) HCC subtype had features of hepatic stem/progenitor cells. Indeed, the fluorescence-activated cell sorting-isolated EpCAM(+) HCC cells displayed hepatic cancer stem cell-like traits including the abilities to self-renew and differentiate. Moreover, these cells were capable of initiating highly invasive HCC in nonobese diabetic, severe combined immunodeficient mice. Activation of Wnt/beta-catenin signaling enriched the EpCAM(+) cell population, whereas RNA interference-based blockage of EpCAM, a Wnt/beta-catenin signaling target, attenuated the activities of these cells. CONCLUSIONS: Taken together, our results suggest that HCC growth and invasiveness is dictated by a subset of EpCAM(+) cells, opening a new avenue for HCC cancer cell eradication by targeting Wnt/beta-catenin signaling components such as EpCAM.

Standard name | YAMASHITA_LIVER_CANCER_STEM_CELL_DN
Systematic name | M9206
Organism | Homo sapiens
PMID | 19150350
Authors | Yamashita T,Ji J,Budhu A,Forgues M,Yang W,Wang HY,Jia H,Ye Q,Qin LX,Wauthier E,Reid LM,Minato H,Honda M,Kaneko S,Tang ZY,Wang XW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma (HCC) cells with hepatic stem cell properties.
Full description | BACKGROUND & AIMS: Cancer progression/metastases and embryonic development share many properties including cellular plasticity, dynamic cell motility, and integral interaction with the microenvironment. We hypothesized that the heterogeneous nature of hepatocellular carcinoma (HCC), in part, may be owing to the presence of hepatic cancer cells with stem/progenitor features. METHODS: Gene expression profiling and immunohistochemistry analyses were used to analyze 235 tumor specimens derived from 2 recently identified HCC subtypes (EpCAM(+) alpha-fetoprotein [AFP(+)] HCC and EpCAM(-) AFP(-) HCC). These subtypes differed in their expression of AFP, a molecule produced in the developing embryo, and EpCAM, a cell surface hepatic stem cell marker. Fluorescence-activated cell sorting was used to isolate EpCAM(+) HCC cells, which were tested for hepatic stem/progenitor cell properties. RESULTS: Gene expression and pathway analyses revealed that the EpCAM(+) AFP(+) HCC subtype had features of hepatic stem/progenitor cells. Indeed, the fluorescence-activated cell sorting-isolated EpCAM(+) HCC cells displayed hepatic cancer stem cell-like traits including the abilities to self-renew and differentiate. Moreover, these cells were capable of initiating highly invasive HCC in nonobese diabetic, severe combined immunodeficient mice. Activation of Wnt/beta-catenin signaling enriched the EpCAM(+) cell population, whereas RNA interference-based blockage of EpCAM, a Wnt/beta-catenin signaling target, attenuated the activities of these cells. CONCLUSIONS: Taken together, our results suggest that HCC growth and invasiveness is dictated by a subset of EpCAM(+) cells, opening a new avenue for HCC cancer cell eradication by targeting Wnt/beta-catenin signaling components such as EpCAM.

Standard name | LEE_LIVER_CANCER_HEPATOBLAST
Systematic name | M13123
Organism | Homo sapiens
PMID | 16532004
Authors | Lee JS,Heo J,Libbrecht L,Chu IS,Kaposi-Novak P,Calvisi DF,Mikaelyan A,Roberts LR,Demetris AJ,Sun Z,Nevens F,Roskams T,Thorgeirsson SS
Category | C2
Sub-category | CGP
Brief description | Fig.5, Supplementary Fig.2 Genes overexpressed in human hepatocellular carcinoma with hepatoblast property
Full description | The variability in the prognosis of individuals with hepatocellular carcinoma (HCC) suggests that HCC may comprise several distinct biological phenotypes. These phenotypes may result from activation of different oncogenic pathways during tumorigenesis and/or from a different cell of origin. Here we address whether the transcriptional characteristics of HCC can provide insight into the cellular origin of the tumor. We integrated gene expression data from rat fetal hepatoblasts and adult hepatocytes with HCC from human and mouse models. Individuals with HCC who shared a gene expression pattern with fetal hepatoblasts had a poor prognosis. The gene expression program that distinguished this subtype from other types of HCC included markers of hepatic oval cells, suggesting that HCC of this subtype may arise from hepatic progenitor cells. Analyses of gene networks showed that activation of AP-1 transcription factors in this newly identified HCC subtype might have key roles in tumor development.

Standard name | WANG_RECURRENT_LIVER_CANCER_UP
Systematic name | M10922
Organism | Homo sapiens
PMID | 17975138
Authors | Wang SM,Ooi LL,Hui KM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in samples from patients with recurrent hepatocellular carcinoma (HCC).
Full description | PURPOSE: To improve the clinical management of human hepatocellular carcinoma (HCC) by accurate identification, at diagnosis, of patients at risk of recurrence after primary treatment for HCC. EXPERIMENTAL DESIGN: Two clinicopathologic variables available at diagnosis, vascular invasion and cirrhosis, together with molecular profiling using Affymetrix human HG-U133A and HG-U133B oligonucleotide probe arrays, were used to identify recurrent HCC disease. RESULTS: HCC patients presented clinically at diagnosis with vascular invasion and cirrhosis showed a high rate (78-83%) of developing recurrent disease within 6 to 35 months. In comparison, most of the HCC patients (80-100%) without vascular invasion and cirrhosis remained disease-free. However, the risk of recurrent disease for HCC patients with either vascular invasion or cirrhosis could not be accurately ascertained. Using a pool of 23 HCC patients with either vascular invasion or cirrhosis as training set, a 57-gene signature was derived and could predict recurrent disease at diagnosis, with 84% (sensitivity 86%, specificity 82%) accuracy, for a totally independent test set of 25 HCC patients with either vascular invasion or cirrhosis. On further analysis, the disease-free rate was significantly different between patients that were predicted to recur or not to recur in the test group (P = 0.002). CONCLUSION: We have presented data to show that by incorporating the status of vascular invasion and cirrhosis available at diagnosis for patients with HCC after partial curative hepatectomy and a novel 57-member gene signature, we could accurately stratify HCC patients with different risks of recurrence.

Standard name | WANG_RECURRENT_LIVER_CANCER_DN
Systematic name | M13077
Organism | Homo sapiens
PMID | 17975138
Authors | Wang SM,Ooi LL,Hui KM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in samples from patients with recurrent hepatocellular carcinoma (HCC).
Full description | PURPOSE: To improve the clinical management of human hepatocellular carcinoma (HCC) by accurate identification, at diagnosis, of patients at risk of recurrence after primary treatment for HCC. EXPERIMENTAL DESIGN: Two clinicopathologic variables available at diagnosis, vascular invasion and cirrhosis, together with molecular profiling using Affymetrix human HG-U133A and HG-U133B oligonucleotide probe arrays, were used to identify recurrent HCC disease. RESULTS: HCC patients presented clinically at diagnosis with vascular invasion and cirrhosis showed a high rate (78-83%) of developing recurrent disease within 6 to 35 months. In comparison, most of the HCC patients (80-100%) without vascular invasion and cirrhosis remained disease-free. However, the risk of recurrent disease for HCC patients with either vascular invasion or cirrhosis could not be accurately ascertained. Using a pool of 23 HCC patients with either vascular invasion or cirrhosis as training set, a 57-gene signature was derived and could predict recurrent disease at diagnosis, with 84% (sensitivity 86%, specificity 82%) accuracy, for a totally independent test set of 25 HCC patients with either vascular invasion or cirrhosis. On further analysis, the disease-free rate was significantly different between patients that were predicted to recur or not to recur in the test group (P = 0.002). CONCLUSION: We have presented data to show that by incorporating the status of vascular invasion and cirrhosis available at diagnosis for patients with HCC after partial curative hepatectomy and a novel 57-member gene signature, we could accurately stratify HCC patients with different risks of recurrence.

Standard name | WOO_LIVER_CANCER_RECURRENCE_UP
Systematic name | M12602
Organism | Homo sapiens
PMID | 18381945
Authors | Woo HG,Park ES,Cheon JH,Kim JH,Lee JS,Park BJ,Kim W,Park SC,Chung YJ,Kim BG,Yoon JH,Lee HS,Kim CY,Yi NJ,Suh KS,Lee KU,Chu IS,Roskams T,Thorgeirsson SS,Kim YJ
Category | C2
Sub-category | CGP
Brief description | Genes positively correlated with recurrence free survival in patients with hepatitis B-related (HBV) hepatocellular carcinoma (HCC).
Full description | PURPOSE: The poor prognosis of hepatocellular carcinoma (HCC) is, in part, due to the high rate of recurrence even after curative resection of tumors. Therefore, it is axiomatic that the development of an effective prognostic prediction model for HCC recurrence after surgery would, at minimum, help to identify in advance those who would most benefit from the treatment, and at best, provide new therapeutic strategies for patients with a high risk of early recurrence. EXPERIMENTAL DESIGN: For the prediction of the recurrence time in patients with HCC, gene expression profiles were generated in 65 HCC patients with hepatitis B infections. RESULT: Recurrence-associated gene expression signatures successfully discriminated between patients at high-risk and low-risk of early recurrence (P=1.9 x 10(-6), log-rank test). To test the consistency and robustness of the recurrence signature, we validated its prognostic power in an independent HCC microarray data set. CD24 was identified as a putative biomarker for the prediction of early recurrence. Genetic network analysis suggested that SP1 and peroxisome proliferator-activated receptor-alpha might have regulatory roles for the early recurrence of HCC. CONCLUSION: We have identified a gene expression signature that effectively predicted early recurrence of HCC independent of microarray platforms and cohorts, and provided novel biological insights into the mechanisms of tumor recurrence.

Standard name | WOO_LIVER_CANCER_RECURRENCE_DN
Systematic name | M9911
Organism | Homo sapiens
PMID | 18381945
Authors | Woo HG,Park ES,Cheon JH,Kim JH,Lee JS,Park BJ,Kim W,Park SC,Chung YJ,Kim BG,Yoon JH,Lee HS,Kim CY,Yi NJ,Suh KS,Lee KU,Chu IS,Roskams T,Thorgeirsson SS,Kim YJ
Category | C2
Sub-category | CGP
Brief description | Genes negatively correlated with recurrence free survival in patients with hepatitis B-related (HBV) hepatocellular carcinoma (HCC).
Full description | PURPOSE: The poor prognosis of hepatocellular carcinoma (HCC) is, in part, due to the high rate of recurrence even after curative resection of tumors. Therefore, it is axiomatic that the development of an effective prognostic prediction model for HCC recurrence after surgery would, at minimum, help to identify in advance those who would most benefit from the treatment, and at best, provide new therapeutic strategies for patients with a high risk of early recurrence. EXPERIMENTAL DESIGN: For the prediction of the recurrence time in patients with HCC, gene expression profiles were generated in 65 HCC patients with hepatitis B infections. RESULT: Recurrence-associated gene expression signatures successfully discriminated between patients at high-risk and low-risk of early recurrence (P=1.9 x 10(-6), log-rank test). To test the consistency and robustness of the recurrence signature, we validated its prognostic power in an independent HCC microarray data set. CD24 was identified as a putative biomarker for the prediction of early recurrence. Genetic network analysis suggested that SP1 and peroxisome proliferator-activated receptor-alpha might have regulatory roles for the early recurrence of HCC. CONCLUSION: We have identified a gene expression signature that effectively predicted early recurrence of HCC independent of microarray platforms and cohorts, and provided novel biological insights into the mechanisms of tumor recurrence.

Standard name | YAMANAKA_GLIOBLASTOMA_SURVIVAL_UP
Systematic name | M5457
Organism | Homo sapiens
PMID | 16652150
Authors | Yamanaka R,Arao T,Yajima N,Tsuchiya N,Homma J,Tanaka R,Sano M,Oide A,Sekijima M,Nishio K
Category | C2
Sub-category | CGP
Brief description | Genes whose expression most strongly and consistently associated with the long term survival of patients with high grade glioma tumors.
Full description | Better understanding of the underlying biology of malignant gliomas is critical for the development of early detection strategies and new therapeutics. This study aimed to define genes associated with survival. We investigated whether genes coupled with a class prediction model could be used to define subgroups of high-grade gliomas in a more objective manner than standard pathology. RNAs from 29 malignant gliomas were analysed using Agilent microarrays. We identified 21 genes whose expression was most strongly and consistently related to patient survival based on univariate proportional hazards models. In six out of 10 genes, changes in gene expression were validated by quantitative real-time PCR. After adjusting for clinical covariates based on a multivariate analysis, we finally obtained a statistical significance level for DDR1 (discoidin domain receptor family, member 1), DYRK3 (dual-specificity tyrosine-(Y)-phosphorylation-regulated kinase 3) and KSP37 (Ksp37 protein). In independent samples, it was confirmed that DDR1 protein expression was also correlated to the prognosis of glioma patients detected by immunohistochemical staining. Furthermore, we analysed the efficacy of the short interfering RNA (siRNA)-mediated inhibition of DDR1 mRNA synthesis in glioma cell lines. Cell proliferation and invasion were significantly suppressed by siRNA against DDR1. Thus, DDR1 can be a novel molecular target of therapy as well as an important predictive marker for survival in patients with glioma. Our method was effective at classifying high-grade gliomas objectively, and provided a more accurate predictor of prognosis than histological grading.

Standard name | YAMANAKA_GLIOBLASTOMA_SURVIVAL_DN
Systematic name | M1948
Organism | Homo sapiens
PMID | 16652150
Authors | Yamanaka R,Arao T,Yajima N,Tsuchiya N,Homma J,Tanaka R,Sano M,Oide A,Sekijima M,Nishio K
Category | C2
Sub-category | CGP
Brief description | Genes whose expression most strongly and consistently associated with the short term survival of patients with high grade glioma tumors.
Full description | Better understanding of the underlying biology of malignant gliomas is critical for the development of early detection strategies and new therapeutics. This study aimed to define genes associated with survival. We investigated whether genes coupled with a class prediction model could be used to define subgroups of high-grade gliomas in a more objective manner than standard pathology. RNAs from 29 malignant gliomas were analysed using Agilent microarrays. We identified 21 genes whose expression was most strongly and consistently related to patient survival based on univariate proportional hazards models. In six out of 10 genes, changes in gene expression were validated by quantitative real-time PCR. After adjusting for clinical covariates based on a multivariate analysis, we finally obtained a statistical significance level for DDR1 (discoidin domain receptor family, member 1), DYRK3 (dual-specificity tyrosine-(Y)-phosphorylation-regulated kinase 3) and KSP37 (Ksp37 protein). In independent samples, it was confirmed that DDR1 protein expression was also correlated to the prognosis of glioma patients detected by immunohistochemical staining. Furthermore, we analysed the efficacy of the short interfering RNA (siRNA)-mediated inhibition of DDR1 mRNA synthesis in glioma cell lines. Cell proliferation and invasion were significantly suppressed by siRNA against DDR1. Thus, DDR1 can be a novel molecular target of therapy as well as an important predictive marker for survival in patients with glioma. Our method was effective at classifying high-grade gliomas objectively, and provided a more accurate predictor of prognosis than histological grading.

Standard name | MONTERO_THYROID_CANCER_POOR_SURVIVAL_UP
Systematic name | M11629
Organism | Homo sapiens
PMID | 17873908
Authors | Montero-Conde C,Martín-Campos JM,Lerma E,Gimenez G,Martínez-Guitarte JL,Combalía N,Montaner D,Matías-Guiu X,Dopazo J,Leiva de A,Robledo M,Mauricio D
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes predicting poor survival of patients with thyroid carcinoma.
Full description | Undifferentiated and poorly differentiated thyroid tumors are responsible for more than half of thyroid cancer patient deaths in spite of their low incidence. Conventional treatments do not obtain substantial benefits, and the lack of alternative approaches limits patient survival. Additionally, the absence of prognostic markers for well-differentiated tumors complicates patient-specific treatments and favors the progression of recurrent forms. In order to recognize the molecular basis involved in tumor dedifferentiation and identify potential markers for thyroid cancer prognosis prediction, we analysed the expression profile of 44 thyroid primary tumors with different degrees of dedifferentiation and aggressiveness using cDNA microarrays. Transcriptome comparison of dedifferentiated and well-differentiated thyroid tumors identified 1031 genes with >2-fold difference in absolute values and false discovery rate of <0.15. According to known molecular interaction and reaction networks, the products of these genes were mainly clustered in the MAPkinase signaling pathway, the TGF-beta signaling pathway, focal adhesion and cell motility, activation of actin polymerization and cell cycle. An exhaustive search in several databases allowed us to identify various members of the matrix metalloproteinase, melanoma antigen A and collagen gene families within the upregulated gene set. We also identified a prognosis classifier comprising just 30 transcripts with an overall accuracy of 95%. These findings may clarify the molecular mechanisms involved in thyroid tumor dedifferentiation and provide a potential prognosis predictor as well as targets for new therapies.

Standard name | MONTERO_THYROID_CANCER_POOR_SURVIVAL_DN
Systematic name | M6972
Organism | Homo sapiens
PMID | 17873908
Authors | Montero-Conde C,Martín-Campos JM,Lerma E,Gimenez G,Martínez-Guitarte JL,Combalía N,Montaner D,Matías-Guiu X,Dopazo J,Leiva de A,Robledo M,Mauricio D
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes predicting poor survival of patients with thyroid carcinoma.
Full description | Undifferentiated and poorly differentiated thyroid tumors are responsible for more than half of thyroid cancer patient deaths in spite of their low incidence. Conventional treatments do not obtain substantial benefits, and the lack of alternative approaches limits patient survival. Additionally, the absence of prognostic markers for well-differentiated tumors complicates patient-specific treatments and favors the progression of recurrent forms. In order to recognize the molecular basis involved in tumor dedifferentiation and identify potential markers for thyroid cancer prognosis prediction, we analysed the expression profile of 44 thyroid primary tumors with different degrees of dedifferentiation and aggressiveness using cDNA microarrays. Transcriptome comparison of dedifferentiated and well-differentiated thyroid tumors identified 1031 genes with >2-fold difference in absolute values and false discovery rate of <0.15. According to known molecular interaction and reaction networks, the products of these genes were mainly clustered in the MAPkinase signaling pathway, the TGF-beta signaling pathway, focal adhesion and cell motility, activation of actin polymerization and cell cycle. An exhaustive search in several databases allowed us to identify various members of the matrix metalloproteinase, melanoma antigen A and collagen gene families within the upregulated gene set. We also identified a prognosis classifier comprising just 30 transcripts with an overall accuracy of 95%. These findings may clarify the molecular mechanisms involved in thyroid tumor dedifferentiation and provide a potential prognosis predictor as well as targets for new therapies.

Standard name | YAGI_AML_WITH_T_8_21_TRANSLOCATION
Systematic name | M19261
Organism | Homo sapiens
PMID | 12738660
Authors | Yagi T,Morimoto A,Eguchi M,Hibi S,Sako M,Ishii E,Mizutani S,Imashuku S,Ohki M,Ichikawa H
Category | C2
Sub-category | CGP
Brief description | Genes specifically expressed in samples from patients with pediatric AML (acute myeloid leukemia ) bearing t(8;21) translocation.
Full description | Most patients with acute myeloid leukemia (AML) enter complete remission (CR) after treatment with chemotherapy, but a large number of them experience relapse with resistant disease. To identify genes that are associated with their prognoses, we analyzed gene expression in 54 pediatric patients with AML using an oligonucleotide microarray that contained 12 566 probe sets. A supervised approach using the Student t test selected a prognostic set of 35 genes, some of which are associated with the regulation of cell cycle and apoptosis. Most of these genes had not previously been reported to be associated with prognosis and were not correlated with morphologically classified French-American-British (FAB) subtypes or with karyotypes. These results indicate the existence of prognosis-associated genes that are independent of cell lineage and cytogenetic abnormalities, and they can provide therapeutic direction for individual risk-adapted therapy for pediatric AML patients.

Standard name | YAGI_AML_WITH_INV_16_TRANSLOCATION
Systematic name | M1047
Organism | Homo sapiens
PMID | 12738660
Authors | Yagi T,Morimoto A,Eguchi M,Hibi S,Sako M,Ishii E,Mizutani S,Imashuku S,Ohki M,Ichikawa H
Category | C2
Sub-category | CGP
Brief description | Genes specifically expressed in samples from patients with pediatric acute myeloid leukemia (AML) bearing inv(16) translocation.
Full description | Most patients with acute myeloid leukemia (AML) enter complete remission (CR) after treatment with chemotherapy, but a large number of them experience relapse with resistant disease. To identify genes that are associated with their prognoses, we analyzed gene expression in 54 pediatric patients with AML using an oligonucleotide microarray that contained 12 566 probe sets. A supervised approach using the Student t test selected a prognostic set of 35 genes, some of which are associated with the regulation of cell cycle and apoptosis. Most of these genes had not previously been reported to be associated with prognosis and were not correlated with morphologically classified French-American-British (FAB) subtypes or with karyotypes. These results indicate the existence of prognosis-associated genes that are independent of cell lineage and cytogenetic abnormalities, and they can provide therapeutic direction for individual risk-adapted therapy for pediatric AML patients.

Standard name | YAGI_AML_WITH_T_9_11_TRANSLOCATION
Systematic name | M16922
Organism | Homo sapiens
PMID | 12738660
Authors | Yagi T,Morimoto A,Eguchi M,Hibi S,Sako M,Ishii E,Mizutani S,Imashuku S,Ohki M,Ichikawa H
Category | C2
Sub-category | CGP
Brief description | Genes specifically expressed in samples from patients with pediatric acute myeloid leukemia (AML) bearing t(9;11) translocation.
Full description | Most patients with acute myeloid leukemia (AML) enter complete remission (CR) after treatment with chemotherapy, but a large number of them experience relapse with resistant disease. To identify genes that are associated with their prognoses, we analyzed gene expression in 54 pediatric patients with AML using an oligonucleotide microarray that contained 12 566 probe sets. A supervised approach using the Student t test selected a prognostic set of 35 genes, some of which are associated with the regulation of cell cycle and apoptosis. Most of these genes had not previously been reported to be associated with prognosis and were not correlated with morphologically classified French-American-British (FAB) subtypes or with karyotypes. These results indicate the existence of prognosis-associated genes that are independent of cell lineage and cytogenetic abnormalities, and they can provide therapeutic direction for individual risk-adapted therapy for pediatric AML patients.

Standard name | YAGI_AML_WITH_11Q23_REARRANGED
Systematic name | M17123
Organism | Homo sapiens
PMID | 12738660
Authors | Yagi T,Morimoto A,Eguchi M,Hibi S,Sako M,Ishii E,Mizutani S,Imashuku S,Ohki M,Ichikawa H
Category | C2
Sub-category | CGP
Brief description | Genes specifically expressed in samples from patients with pediatric acute myeloid leukemia (AML) bearing 11q23 rearrangements.
Full description | Most patients with acute myeloid leukemia (AML) enter complete remission (CR) after treatment with chemotherapy, but a large number of them experience relapse with resistant disease. To identify genes that are associated with their prognoses, we analyzed gene expression in 54 pediatric patients with AML using an oligonucleotide microarray that contained 12 566 probe sets. A supervised approach using the Student t test selected a prognostic set of 35 genes, some of which are associated with the regulation of cell cycle and apoptosis. Most of these genes had not previously been reported to be associated with prognosis and were not correlated with morphologically classified French-American-British (FAB) subtypes or with karyotypes. These results indicate the existence of prognosis-associated genes that are independent of cell lineage and cytogenetic abnormalities, and they can provide therapeutic direction for individual risk-adapted therapy for pediatric AML patients.

Standard name | MEISSNER_NPC_HCP_WITH_H3K4ME2_AND_H3K27ME3
Systematic name | M1949
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing histone H3 dimethylation mark at K4 (H3K4me2) and trimethylation mark at K27 (H3K27me3) in neural precursor cells (NPC).
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_BRAIN_HCP_WITH_H3K4ME2_AND_H3K27ME3
Systematic name | M1950
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing bivalent histone H3 dimethylation mark at K4 (H3K4me2) and trimethlation mark at K27 (H3K27me3) in brain.
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_NPC_HCP_WITH_H3K4ME2
Systematic name | M1951
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing histone H3 dimethylation mark at K4 (H3K4me2) in neural precursor cells (NPC).
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MEISSNER_BRAIN_HCP_WITH_H3K4ME2
Systematic name | M1952
Organism | Mus musculus
PMID | 18600261
Authors | Meissner A,Mikkelsen TS,Gu H,Wernig M,Hanna J,Sivachenko A,Zhang X,Bernstein BE,Nusbaum C,Jaffe DB,Gnirke A,Jaenisch R,Lander ES
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing histone H3 dimethylation mark (H3K4me2) in brain.
Full description | DNA methylation is essential for normal development and has been implicated in many pathologies including cancer. Our knowledge about the genome-wide distribution of DNA methylation, how it changes during cellular differentiation and how it relates to histone methylation and other chromatin modifications in mammals remains limited. Here we report the generation and analysis of genome-scale DNA methylation profiles at nucleotide resolution in mammalian cells. Using high-throughput reduced representation bisulphite sequencing and single-molecule-based sequencing, we generated DNA methylation maps covering most CpG islands, and a representative sampling of conserved non-coding elements, transposons and other genomic features, for mouse embryonic stem cells, embryonic-stem-cell-derived and primary neural cells, and eight other primary tissues. Several key findings emerge from the data. First, DNA methylation patterns are better correlated with histone methylation patterns than with the underlying genome sequence context. Second, methylation of CpGs are dynamic epigenetic marks that undergo extensive changes during cellular differentiation, particularly in regulatory regions outside of core promoters. Third, analysis of embryonic-stem-cell-derived and primary cells reveals that 'weak' CpG islands associated with a specific set of developmentally regulated genes undergo aberrant hypermethylation during extended proliferation in vitro, in a pattern reminiscent of that reported in some primary tumours. More generally, the results establish reduced representation bisulphite sequencing as a powerful technology for epigenetic profiling of cell populations relevant to developmental biology, cancer and regenerative medicine.

Standard name | MIKKELSEN_MCV6_HCP_WITH_H3K27ME3
Systematic name | M1954
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing the tri-methylation mark at H3K27 (H3K27me3) in MCV6 cells (embryonic fibroblasts trapped in a differentiated state).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_MCV6_ICP_WITH_H3K4ME3_AND_H3K27ME3
Systematic name | M1955
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing the bivalent trimethylation marks at H3K4 (H3K4me3) and H3K27 (H3K27me3) in MCV6 cells (embryonic fibroblasts trapped in a differentiated state).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_MCV6_ICP_WITH_H3K27ME3
Systematic name | M1956
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing the tri-methylation mark at H3K27 (H3K27me3) in MCV6 cells (embryonic fibroblasts trapped in a differentiated state).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_MCV6_LCP_WITH_H3K27ME3
Systematic name | M1957
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters (LCP) bearing the tri-methylation mark at H3K27 (H3K27me3) in MCV6 cells (embryonic fibroblasts trapped in a differentiated state).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_MCV6_LCP_WITH_H3K4ME3
Systematic name | M1960
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters (LCP) bearing the tri-methylation mark at H3K4 (H3K4me3) in MCV6 cells (embryonic fibroblasts trapped in a differentiated state).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_MEF_ICP_WITH_H3K4ME3_AND_H3K27ME3
Systematic name | M1962
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing the bivalent tri-methylation marks at H3K4 (H3K4me3) and H3K27 (H3K27me3) in MEF cells (embryonic fibroblasts).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_MEF_ICP_WITH_H3K27ME3
Systematic name | M1963
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing the tri-methylation mark at H3K27 (H3K27me3) in MEF cells (embryonic fibroblasts).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_MEF_LCP_WITH_H3K27ME3
Systematic name | M1965
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters (LCP) bearing the tri-methylation mark at H3K27 (H3K27me3) in MEF cells (embryonic fibroblasts).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_MEF_LCP_WITH_H3K4ME3
Systematic name | M1966
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters (LCP) bearing tri-methylation mark at H3K4 (H3K4me3) in MEF cells (embryonic fibroblasts).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_IPS_WITH_HCP_H3K27ME3
Systematic name | M1967
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing the tri-methylation mark at H3K27 (H3K27me3) in MCV8.1 (induced pluripotent cells, iPS).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_IPS_HCP_WITH_H3_UNMETHYLATED
Systematic name | M1968
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) without H3 methylation marks at either H3K4 or H3K27 in MCV8.1 cells (induced pluripotent cells, iPS).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_IPS_ICP_WITH_H3K4ME3_AND_H327ME3
Systematic name | M1969
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing the bivalent tri-methylation marks at H3K4 (H3K4me3) and H3K27 (H3K27me3) in MCV8.1 cells (induced pluripotent cells, iPS).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_IPS_ICP_WITH_H3K27ME3
Systematic name | M1970
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing the tri-methylation mark at H3K27 (H3K27me3) in MCV8.1 cells (induced pluripotent cells, iPS).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_IPS_LCP_WITH_H3K4ME3_AND_H3K27ME3
Systematic name | M1972
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters (LCP) bearing the bivalent tri-methylation marks at H3K4 (H3K4me3) and H3K27 (H3K27me3) in MCV8.1 cells (induced pluripotent cells, iPS).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_IPS_LCP_WITH_H3K27ME3
Systematic name | M1974
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters (LCP) bearing the tri-methylation mark at H3K27 (H3K27me3) in MCV8.1 cells (induced pluripotent cells, iPS).
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | MIKKELSEN_IPS_LCP_WITH_H3K4ME3
Systematic name | M1975
Organism | Mus musculus
PMID | 18509334
Authors | Mikkelsen TS,Hanna J,Zhang X,Ku M,Wernig M,Schorderet P,Bernstein BE,Jaenisch R,Lander ES,Meissner A
Category | C2
Sub-category | CGP
Brief description | Table 2S. Genes in MEF, MCV6, MCV8.1 and ES cells by epigenetic mark of their promoter
Full description | Somatic cells can be reprogrammed to a pluripotent state through the ectopic expression of defined transcription factors. Understanding the mechanism and kinetics of this transformation may shed light on the nature of developmental potency and suggest strategies with improved efficiency or safety. Here we report an integrative genomic analysis of reprogramming of mouse fibroblasts and B lymphocytes. Lineage-committed cells show a complex response to the ectopic expression involving induction of genes downstream of individual reprogramming factors. Fully reprogrammed cells show gene expression and epigenetic states that are highly similar to embryonic stem cells. In contrast, stable partially reprogrammed cell lines show reactivation of a distinctive subset of stem-cell-related genes, incomplete repression of lineage-specifying transcription factors, and DNA hypermethylation at pluripotency-related loci. These observations suggest that some cells may become trapped in partially reprogrammed states owing to incomplete repression of transcription factors, and that DNA de-methylation is an inefficient step in the transition to pluripotency. We demonstrate that RNA inhibition of transcription factors can facilitate reprogramming, and that treatment with DNA methyltransferase inhibitors can improve the overall efficiency of the reprogramming process.

Standard name | GLINSKY_CANCER_DEATH_UP
Systematic name | M13007
Organism | Mus musculus
PMID | 15931389
Authors | Glinsky GV,Berezovska O,Glinskii AB
Category | C2
Sub-category | CGP
Brief description | Genes whose over-expression is associated with the risk of death in multiple cancer types
Full description | Activation in transformed cells of normal stem cells' self-renewal pathways might contribute to the survival life cycle of cancer stem cells and promote tumor progression. The BMI-1 oncogene-driven gene expression pathway is essential for the self-renewal of hematopoietic and neural stem cells. We applied a mouse/human comparative translational genomics approach to identify an 11-gene signature that consistently displays a stem cell-resembling expression profile in distant metastatic lesions as revealed by the analysis of metastases and primary tumors from a transgenic mouse model of prostate cancer and cancer patients. To further validate these results, we examined the prognostic power of the 11-gene signature in several independent therapy-outcome sets of clinical samples obtained from 1,153 cancer patients diagnosed with 11 different types of cancer, including 5 epithelial malignancies (prostate, breast, lung, ovarian, and bladder cancers) and 5 nonepithelial malignancies (lymphoma, mesothelioma, medulloblastoma, glioma, and acute myeloid leukemia). Kaplan-Meier analysis demonstrated that a stem cell-like expression profile of the 11-gene signature in primary tumors is a consistent powerful predictor of a short interval to disease recurrence, distant metastasis, and death after therapy in cancer patients diagnosed with 11 distinct types of cancer. These data suggest the presence of a conserved BMI-1-driven pathway, which is similarly engaged in both normal stem cells and a highly malignant subset of human cancers diagnosed in a wide range of organs and uniformly exhibiting a marked propensity toward metastatic dissemination as well as a high probability of unfavorable therapy outcome.

Standard name | KUROKAWA_LIVER_CANCER_EARLY_RECURRENCE_UP
Systematic name | M7700
Organism | Homo sapiens
PMID | 15288478
Authors | Kurokawa Y,Matoba R,Takemasa I,Nagano H,Dono K,Nakamori S,Umeshita K,Sakon M,Ueno N,Oba S,Ishii S,Kato K,Monden M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatocellular carcinoma (HCC) with early recurrence.
Full description | BACKGROUND/AIMS: Hepatocellular carcinoma (HCC) has a very poor prognosis, due to the high incidence of tumor recurrence. As the current morphological indicators are often insufficient for therapeutic decisions, we sought to identify additional biologic indicators for early recurrence. METHODS: We analyzed gene expression using a PCR-based array of 3,072 genes in 100 HCC patients. Informative genes predicting early intrahepatic recurrence were selected by random permutation testing, and a weighted voting prediction method was constructed. Following estimation of prediction accuracy, a multivariate Cox analysis was performed. RESULTS: By permutation testing, we selected 92 genes demonstrated distinct expression patterns differing significantly between recurrence cases and recurrence-free cases. Our prediction method, using the 20 top-ranked genes, correctly predicted the early intrahepatic recurrence for 29 of 40 cases within the validation group, and the odds ratio was 6.8 (95%CI 1.7-27.5, P = 0.010). The 2-year recurrence rates in the patients with the good signature and those with the poor signature were 29.4 and 73.9%, respectively. Multivariate Cox analysis revealed that molecular-signature was an independent indicator for recurrence (hazard ratio 3.82, 95%CI 1.44-10.10, P = 0.007). CONCLUSIONS: Our molecular-based prediction method using 20 genes is clinically useful to predict early recurrence of HCC.

Standard name | KUROKAWA_LIVER_CANCER_EARLY_RECURRENCE_DN
Systematic name | M7182
Organism | Homo sapiens
PMID | 15288478
Authors | Kurokawa Y,Matoba R,Takemasa I,Nagano H,Dono K,Nakamori S,Umeshita K,Sakon M,Ueno N,Oba S,Ishii S,Kato K,Monden M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatocellular carcinoma (HCC) with early recurrence.
Full description | BACKGROUND/AIMS: Hepatocellular carcinoma (HCC) has a very poor prognosis, due to the high incidence of tumor recurrence. As the current morphological indicators are often insufficient for therapeutic decisions, we sought to identify additional biologic indicators for early recurrence. METHODS: We analyzed gene expression using a PCR-based array of 3,072 genes in 100 HCC patients. Informative genes predicting early intrahepatic recurrence were selected by random permutation testing, and a weighted voting prediction method was constructed. Following estimation of prediction accuracy, a multivariate Cox analysis was performed. RESULTS: By permutation testing, we selected 92 genes demonstrated distinct expression patterns differing significantly between recurrence cases and recurrence-free cases. Our prediction method, using the 20 top-ranked genes, correctly predicted the early intrahepatic recurrence for 29 of 40 cases within the validation group, and the odds ratio was 6.8 (95%CI 1.7-27.5, P = 0.010). The 2-year recurrence rates in the patients with the good signature and those with the poor signature were 29.4 and 73.9%, respectively. Multivariate Cox analysis revealed that molecular-signature was an independent indicator for recurrence (hazard ratio 3.82, 95%CI 1.44-10.10, P = 0.007). CONCLUSIONS: Our molecular-based prediction method using 20 genes is clinically useful to predict early recurrence of HCC.

Standard name | MARSON_FOXP3_TARGETS_UP
Systematic name | M14233
Organism | Mus musculus
PMID | 17237765
Authors | Marson A,Kretschmer K,Frampton GM,Jacobsen ES,Polansky JK,MacIsaac KD,Levine SS,Fraenkel E,von Boehmer H,Young RA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by FOXP3 [GeneID=50943] in both ex vivo and hybridoma cells.
Full description | Foxp3+CD4+CD25+ regulatory T (T(reg)) cells are essential for the prevention of autoimmunity. T(reg) cells have an attenuated cytokine response to T-cell receptor stimulation, and can suppress the proliferation and effector function of neighbouring T cells. The forkhead transcription factor Foxp3 (forkhead box P3) is selectively expressed in T(reg) cells, is required for T(reg) development and function, and is sufficient to induce a T(reg) phenotype in conventional CD4+CD25- T cells. Mutations in Foxp3 cause severe, multi-organ autoimmunity in both human and mouse. FOXP3 can cooperate in a DNA-binding complex with NFAT (nuclear factor of activated T cells) to regulate the transcription of several known target genes. However, the global set of genes regulated directly by Foxp3 is not known and consequently, how this transcription factor controls the gene expression programme for T(reg) function is not understood. Here we identify Foxp3 target genes and report that many of these are key modulators of T-cell activation and function. Remarkably, the predominant, although not exclusive, effect of Foxp3 occupancy is to suppress the activation of target genes on T-cell stimulation. Foxp3 suppression of its targets appears to be crucial for the normal function of T(reg) cells, because overactive variants of some target genes are known to be associated with autoimmune disease.

Standard name | MARSON_FOXP3_TARGETS_DN
Systematic name | M2160
Organism | Mus musculus
PMID | 17237765
Authors | Marson A,Kretschmer K,Frampton GM,Jacobsen ES,Polansky JK,MacIsaac KD,Levine SS,Fraenkel E,von Boehmer H,Young RA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by FOXP3 [GeneID=50943] in both ex vivo and hybridoma cells.
Full description | Foxp3+CD4+CD25+ regulatory T (T(reg)) cells are essential for the prevention of autoimmunity. T(reg) cells have an attenuated cytokine response to T-cell receptor stimulation, and can suppress the proliferation and effector function of neighbouring T cells. The forkhead transcription factor Foxp3 (forkhead box P3) is selectively expressed in T(reg) cells, is required for T(reg) development and function, and is sufficient to induce a T(reg) phenotype in conventional CD4+CD25- T cells. Mutations in Foxp3 cause severe, multi-organ autoimmunity in both human and mouse. FOXP3 can cooperate in a DNA-binding complex with NFAT (nuclear factor of activated T cells) to regulate the transcription of several known target genes. However, the global set of genes regulated directly by Foxp3 is not known and consequently, how this transcription factor controls the gene expression programme for T(reg) function is not understood. Here we identify Foxp3 target genes and report that many of these are key modulators of T-cell activation and function. Remarkably, the predominant, although not exclusive, effect of Foxp3 occupancy is to suppress the activation of target genes on T-cell stimulation. Foxp3 suppression of its targets appears to be crucial for the normal function of T(reg) cells, because overactive variants of some target genes are known to be associated with autoimmune disease.

Standard name | ONO_AML1_TARGETS_UP
Systematic name | M1977
Organism | Mus musculus
PMID | 17377532
Authors | Ono M,Yaguchi H,Ohkura N,Kitabayashi I,Nagamura Y,Nomura T,Miyachi Y,Tsukada T,Sakaguchi S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD4+ [GeneID=920] T lymphocytes by expression of AML1 [GeneID=861] off a viral vector.
Full description | Naturally arising CD25+CD4+ regulatory T cells (T(R) cells) are engaged in the maintenance of immunological self-tolerance and immune homeostasis by suppressing aberrant or excessive immune responses, such as autoimmune disease and allergy. T(R) cells specifically express the transcription factor Foxp3, a key regulator of T(R)-cell development and function. Ectopic expression of Foxp3 in conventional T cells is indeed sufficient to confer suppressive activity, repress the production of cytokines such as interleukin-2 (IL-2) and interferon-gamma (IFN-gamma), and upregulate T(R)-cell-associated molecules such as CD25, cytotoxic T-lymphocyte-associated antigen-4, and glucocorticoid-induced TNF-receptor-family-related protein. However, the method by which Foxp3 controls these molecular events has yet to be explained. Here we show that the transcription factor AML1 (acute myeloid leukaemia 1)/Runx1 (Runt-related transcription factor 1), which is crucially required for normal haematopoiesis including thymic T-cell development, activates IL-2 and IFN-gamma gene expression in conventional CD4+ T cells through binding to their respective promoters. In natural T(R) cells, Foxp3 interacts physically with AML1. Several lines of evidence support a model in which the interaction suppresses IL-2 and IFN-gamma production, upregulates T(R)-cell-associated molecules, and exerts suppressive activity. This transcriptional control of T(R)-cell function by an interaction between Foxp3 and AML1 can be exploited to control physiological and pathological T-cell-mediated immune responses.

Standard name | ONO_AML1_TARGETS_DN
Systematic name | M1978
Organism | Mus musculus
PMID | 17377532
Authors | Ono M,Yaguchi H,Ohkura N,Kitabayashi I,Nagamura Y,Nomura T,Miyachi Y,Tsukada T,Sakaguchi S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD4+ [GeneID=920] T lymphocytes by expression of AML1 [GeneID=861] off a viral vector.
Full description | Naturally arising CD25+CD4+ regulatory T cells (T(R) cells) are engaged in the maintenance of immunological self-tolerance and immune homeostasis by suppressing aberrant or excessive immune responses, such as autoimmune disease and allergy. T(R) cells specifically express the transcription factor Foxp3, a key regulator of T(R)-cell development and function. Ectopic expression of Foxp3 in conventional T cells is indeed sufficient to confer suppressive activity, repress the production of cytokines such as interleukin-2 (IL-2) and interferon-gamma (IFN-gamma), and upregulate T(R)-cell-associated molecules such as CD25, cytotoxic T-lymphocyte-associated antigen-4, and glucocorticoid-induced TNF-receptor-family-related protein. However, the method by which Foxp3 controls these molecular events has yet to be explained. Here we show that the transcription factor AML1 (acute myeloid leukaemia 1)/Runx1 (Runt-related transcription factor 1), which is crucially required for normal haematopoiesis including thymic T-cell development, activates IL-2 and IFN-gamma gene expression in conventional CD4+ T cells through binding to their respective promoters. In natural T(R) cells, Foxp3 interacts physically with AML1. Several lines of evidence support a model in which the interaction suppresses IL-2 and IFN-gamma production, upregulates T(R)-cell-associated molecules, and exerts suppressive activity. This transcriptional control of T(R)-cell function by an interaction between Foxp3 and AML1 can be exploited to control physiological and pathological T-cell-mediated immune responses.

Standard name | ONO_FOXP3_TARGETS_UP
Systematic name | M1981
Organism | Mus musculus
PMID | 17377532
Authors | Ono M,Yaguchi H,Ohkura N,Kitabayashi I,Nagamura Y,Nomura T,Miyachi Y,Tsukada T,Sakaguchi S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD4+ [GeneID=920] T lymphocytes transduced with FOXP3 [GeneID=50943].
Full description | Naturally arising CD25+CD4+ regulatory T cells (T(R) cells) are engaged in the maintenance of immunological self-tolerance and immune homeostasis by suppressing aberrant or excessive immune responses, such as autoimmune disease and allergy. T(R) cells specifically express the transcription factor Foxp3, a key regulator of T(R)-cell development and function. Ectopic expression of Foxp3 in conventional T cells is indeed sufficient to confer suppressive activity, repress the production of cytokines such as interleukin-2 (IL-2) and interferon-gamma (IFN-gamma), and upregulate T(R)-cell-associated molecules such as CD25, cytotoxic T-lymphocyte-associated antigen-4, and glucocorticoid-induced TNF-receptor-family-related protein. However, the method by which Foxp3 controls these molecular events has yet to be explained. Here we show that the transcription factor AML1 (acute myeloid leukaemia 1)/Runx1 (Runt-related transcription factor 1), which is crucially required for normal haematopoiesis including thymic T-cell development, activates IL-2 and IFN-gamma gene expression in conventional CD4+ T cells through binding to their respective promoters. In natural T(R) cells, Foxp3 interacts physically with AML1. Several lines of evidence support a model in which the interaction suppresses IL-2 and IFN-gamma production, upregulates T(R)-cell-associated molecules, and exerts suppressive activity. This transcriptional control of T(R)-cell function by an interaction between Foxp3 and AML1 can be exploited to control physiological and pathological T-cell-mediated immune responses.

Standard name | ONO_FOXP3_TARGETS_DN
Systematic name | M1982
Organism | Mus musculus
PMID | 17377532
Authors | Ono M,Yaguchi H,Ohkura N,Kitabayashi I,Nagamura Y,Nomura T,Miyachi Y,Tsukada T,Sakaguchi S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD4+ [GeneID=920] T lymphocytes transduced with FOXP3 [GeneID=50943].
Full description | Naturally arising CD25+CD4+ regulatory T cells (T(R) cells) are engaged in the maintenance of immunological self-tolerance and immune homeostasis by suppressing aberrant or excessive immune responses, such as autoimmune disease and allergy. T(R) cells specifically express the transcription factor Foxp3, a key regulator of T(R)-cell development and function. Ectopic expression of Foxp3 in conventional T cells is indeed sufficient to confer suppressive activity, repress the production of cytokines such as interleukin-2 (IL-2) and interferon-gamma (IFN-gamma), and upregulate T(R)-cell-associated molecules such as CD25, cytotoxic T-lymphocyte-associated antigen-4, and glucocorticoid-induced TNF-receptor-family-related protein. However, the method by which Foxp3 controls these molecular events has yet to be explained. Here we show that the transcription factor AML1 (acute myeloid leukaemia 1)/Runx1 (Runt-related transcription factor 1), which is crucially required for normal haematopoiesis including thymic T-cell development, activates IL-2 and IFN-gamma gene expression in conventional CD4+ T cells through binding to their respective promoters. In natural T(R) cells, Foxp3 interacts physically with AML1. Several lines of evidence support a model in which the interaction suppresses IL-2 and IFN-gamma production, upregulates T(R)-cell-associated molecules, and exerts suppressive activity. This transcriptional control of T(R)-cell function by an interaction between Foxp3 and AML1 can be exploited to control physiological and pathological T-cell-mediated immune responses.

Standard name | SETLUR_PROSTATE_CANCER_TMPRSS2_ERG_FUSION_UP
Systematic name | M3695
Organism | Homo sapiens
PMID | 18505969
Authors | Setlur SR,Mertz KD,Hoshida Y,Demichelis F,Lupien M,Perner S,Sboner A,Pawitan Y,Andrén O,Johnson LA,Tang J,Adami HO,Calza S,Chinnaiyan AM,Rhodes D,Tomlins S,Fall K,Mucci LA,Kantoff PW,Stampfer MJ,Andersson SO,Varenhorst E,Johansson JE,Brown M,Golub TR,Rubin MA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in prostate cancer samples bearing the fusion of TMPRSS2 with ERG [GeneID=7113;2078].
Full description | BACKGROUND: The majority of prostate cancers harbor gene fusions of the 5'-untranslated region of the androgen-regulated transmembrane protease serine 2 (TMPRSS2) promoter with erythroblast transformation-specific transcription factor family members. The common fusion between TMPRESS2 and v-ets erythroblastosis virus E26 oncogene homolog (avian) (ERG) is associated with a more aggressive clinical phenotype, implying the existence of a distinct subclass of prostate cancer defined by this fusion. METHODS: We used complementary DNA-mediated annealing, selection, ligation, and extension to determine the expression profiles of 6144 transcriptionally informative genes in archived biopsy samples from 455 prostate cancer patients in the Swedish Watchful Waiting cohort (1987-1999) and the United States-based Physicians(') Health Study cohort (1983-2003). A gene expression signature for prostate cancers with the TMPRSS2-ERG fusion was determined using partitioning and classification models and used in computational functional analysis. Cell proliferation and TMPRSS2-ERG expression in androgen receptor-negative (NCI-H660) prostate cancer cells after treatment with vehicle or estrogenic compounds were assessed by viability assays and quantitative polymerase chain reaction, respectively. All statistical tests were two-sided. RESULTS: We identified an 87-gene expression signature that distinguishes TMPRSS2-ERG fusion prostate cancer as a discrete molecular entity (area under the curve = 0.80, 95% confidence interval [CI] = 0.792 to 0.81; P < .001). Computational analysis suggested that this fusion signature was associated with estrogen receptor (ER) signaling. Viability of NCI-H660 cells decreased after treatment with estrogen (viability normalized to day 0, estrogen vs vehicle at day 8, mean = 2.04 vs 3.40, difference = 1.36, 95% CI = 1.12 to 1.62) or ERbeta agonist (ERbeta agonist vs vehicle at day 8, mean = 1.86 vs 3.40, difference = 1.54, 95% CI = 1.39 to 1.69) but increased after ERalpha agonist treatment (ERalpha agonist vs vehicle at day 8, mean = 4.36 vs 3.40, difference = 0.96, 95% CI = 0.68 to 1.23). Similarly, expression of TMPRSS2-ERG decreased after ERbeta agonist treatment (fold change over internal control, ERbeta agonist vs vehicle at 24 hours, NCI-H660, mean = 0.57- vs 1.0-fold, difference = 0.43-fold, 95% CI = 0.29- to 0.57-fold) and increased after ERalpha agonist treatment (ERalpha agonist vs vehicle at 24 hours, mean = 5.63- vs 1.0-fold, difference = 4.63-fold, 95% CI = 4.34- to 4.92-fold). CONCLUSIONS: TMPRSS2-ERG fusion prostate cancer is a distinct molecular subclass. TMPRSS2-ERG expression is regulated by a novel ER-dependent mechanism.

Standard name | SETLUR_PROSTATE_CANCER_TMPRSS2_ERG_FUSION_DN
Systematic name | M12596
Organism | Homo sapiens
PMID | 18505969
Authors | Setlur SR,Mertz KD,Hoshida Y,Demichelis F,Lupien M,Perner S,Sboner A,Pawitan Y,Andrén O,Johnson LA,Tang J,Adami HO,Calza S,Chinnaiyan AM,Rhodes D,Tomlins S,Fall K,Mucci LA,Kantoff PW,Stampfer MJ,Andersson SO,Varenhorst E,Johansson JE,Brown M,Golub TR,Rubin MA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in prostate cancer samples bearing the fusion of TMPRSS2 with ERG [GeneID=7113;2078].
Full description | BACKGROUND: The majority of prostate cancers harbor gene fusions of the 5'-untranslated region of the androgen-regulated transmembrane protease serine 2 (TMPRSS2) promoter with erythroblast transformation-specific transcription factor family members. The common fusion between TMPRESS2 and v-ets erythroblastosis virus E26 oncogene homolog (avian) (ERG) is associated with a more aggressive clinical phenotype, implying the existence of a distinct subclass of prostate cancer defined by this fusion. METHODS: We used complementary DNA-mediated annealing, selection, ligation, and extension to determine the expression profiles of 6144 transcriptionally informative genes in archived biopsy samples from 455 prostate cancer patients in the Swedish Watchful Waiting cohort (1987-1999) and the United States-based Physicians(') Health Study cohort (1983-2003). A gene expression signature for prostate cancers with the TMPRSS2-ERG fusion was determined using partitioning and classification models and used in computational functional analysis. Cell proliferation and TMPRSS2-ERG expression in androgen receptor-negative (NCI-H660) prostate cancer cells after treatment with vehicle or estrogenic compounds were assessed by viability assays and quantitative polymerase chain reaction, respectively. All statistical tests were two-sided. RESULTS: We identified an 87-gene expression signature that distinguishes TMPRSS2-ERG fusion prostate cancer as a discrete molecular entity (area under the curve = 0.80, 95% confidence interval [CI] = 0.792 to 0.81; P < .001). Computational analysis suggested that this fusion signature was associated with estrogen receptor (ER) signaling. Viability of NCI-H660 cells decreased after treatment with estrogen (viability normalized to day 0, estrogen vs vehicle at day 8, mean = 2.04 vs 3.40, difference = 1.36, 95% CI = 1.12 to 1.62) or ERbeta agonist (ERbeta agonist vs vehicle at day 8, mean = 1.86 vs 3.40, difference = 1.54, 95% CI = 1.39 to 1.69) but increased after ERalpha agonist treatment (ERalpha agonist vs vehicle at day 8, mean = 4.36 vs 3.40, difference = 0.96, 95% CI = 0.68 to 1.23). Similarly, expression of TMPRSS2-ERG decreased after ERbeta agonist treatment (fold change over internal control, ERbeta agonist vs vehicle at 24 hours, NCI-H660, mean = 0.57- vs 1.0-fold, difference = 0.43-fold, 95% CI = 0.29- to 0.57-fold) and increased after ERalpha agonist treatment (ERalpha agonist vs vehicle at 24 hours, mean = 5.63- vs 1.0-fold, difference = 4.63-fold, 95% CI = 4.34- to 4.92-fold). CONCLUSIONS: TMPRSS2-ERG fusion prostate cancer is a distinct molecular subclass. TMPRSS2-ERG expression is regulated by a novel ER-dependent mechanism.

Standard name | SCHOEN_NFKB_SIGNALING
Systematic name | M1983
Organism | Homo sapiens
PMID | 18544741
Authors | Schön M,Wienrich BG,Kneitz S,Sennefelder H,Amschler K,Vöhringer V,Weber O,Stiewe T,Ziegelbauer K,Schön MP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A375 cells (melanoma) treated with KINK-1, a small molecule inhibitor of NFKB.
Full description | BACKGROUND: Increasing the efficacy of chemotherapeutics by reducing chemoresistance may be a useful strategy in cancer therapy. Constitutive activation of nuclear factor-kappa B (NF-kappaB) is a hallmark of various cancers, including melanoma, which is almost universally resistant to chemotherapy. NF-kappaB is regulated by inhibitory kappaB (IkappaB) proteins, which are in turn phosphorylated by the IkappaB kinase (IKK) complex. METHODS: The effect on NF-kappaB activity of a novel small-molecule inhibitor of the beta subunit of IKK (KINK-1; kinase inhibitor of nuclear factor-kappaB-1) was assessed by measuring phosphorylation of the alpha subunit of IkappaB by immunoblotting, DNA binding by electrophoretic mobility shift assays, and nuclear translocation of NF-kappaB using immunofluorescence. Regulation of NF-kappaB-dependent gene expression was determined by microarray analysis, real-time and semiquantitative reverse transcription polymerase chain reaction (RT-PCR), and Western blot analyses. The effects of KINK-1 (alone and in combination with cytostatic agents) on melanoma cells were characterized by assessing proliferation, soft agar colony formation, and markers of apoptosis. The antitumoral efficacy of KINK-1 in combination with the cytostatic agents doxorubicin or camptothecin (all injected intraperitoneally) was tested in vivo by measuring lung weight and counting metastases in C57BL6 mice (groups of six) bearing metastases of melanoma cells. All statistical tests were two-sided. Results KINK-1 strongly suppressed both constitutive and induced NF-kappaB activity in melanoma cells. It reduced the expression of NF-kappaB-dependent gene products that regulate proliferation, cytokine production, and antiapoptotic responses but exhibited little antiproliferative or proapoptotic activity at the cellular level. However, KINK-1 markedly increased the activities of some cytostatic agents in vitro and abrogated doxorubicin-induced NF-kappaB activation. Combined treatment of C57BL6 mice that had been injected with melanoma cells with KINK-1 and doxorubicin or camptothecin reduced metastases and pulmonary tumor mass compared with either treatment alone (mean lung weight 19 days after injection of melanoma cells of mice treated with 3 mg/kg KINK-1 alone, 1 mg/kg doxorubicin alone, and 1 mg/kg doxorubicin plus 3 mg/kg KINK-1 = 260 mg, 95% confidence interval (CI) = 216 to 305 mg; 268 mg, 95% CI = 224 to 313 mg; and 181 mg, 95% CI = 171 to 192 mg, respectively, P < .001 from t tests comparing mean lung weight of double-treated mice to that in mice treated with either compound alone). CONCLUSION: Inhibition of constitutive and induced IKKbeta-activity through treatment with KINK-1 might increase tumor susceptibility to chemotherapy.

Standard name | NGO_MALIGNANT_GLIOMA_1P_LOH
Systematic name | M19965
Organism | Homo sapiens
PMID | 17440165
Authors | Ngo TT,Peng T,Liang XJ,Akeju O,Pastorino S,Zhang W,Kotliarov Y,Zenklusen JC,Fine HA,Maric D,Wen PY,De Girolami U,Black PM,Wu WW,Shen RF,Jeffries NO,Kang DW,Park JK
Category | C2
Sub-category | CGP
Brief description | Proteins with reduced expression in mulignant glioma cell line (A172) which bears loss of heterozygosity (LOH) in the 1p region.
Full description | BACKGROUND: Malignant gliomas are generally resistant to all conventional therapies. Notable exceptions are anaplastic oligodendrogliomas with loss of heterozygosity on chromosome 1p (1p+/-). Patients with 1p+/- anaplastic oligodendroglioma frequently respond to procarbazine, 1-(2-chloroethyl)-3-cyclohexyl-l-nitrosourea, and vincristine. Because the underlying biologic basis for this clinical finding is unclear, we evaluated differentially expressed 1p-encoded proteins in 1p+/- and 1p+/+ malignant glioma cell lines and then examined whether their expression was associated with outcome of patients with anaplastic oligodendroglioma. METHODS: We used a comparative proteomic screen of A172 (1p+/-) and U251 (1p+/+) malignant glioma cell lines to identify differentially expressed 1p-encoded proteins, including stathmin, a microtubule-associated protein. 1p+/- and 1p+/+ anaplastic oligodendroglioma specimens from 24 patients were assessed for stathmin expression by immunohistochemistry. The relationship between stathmin expression and clinical outcome was assessed with Kaplan-Meier analyses. RNA inhibition and cDNA transfection experiments tested effects of stathmin under- and overexpression, respectively, on the in vitro and in vivo resistance of malignant glioma cells to treatment with nitrosourea. For in vivo resistance studies, 36 mice with intracranial and 16 mice with subcutaneous xenograft tumor implants were used (one tumor per mouse). Flow cytometry was used for cell cycle analysis. Immunoblotting was used to assess protein expression. All statistical tests were two-sided. RESULTS: Decreased stathmin expression in tumors was statistically significantly associated with loss of heterozygosity in 1p (P<.001) and increased recurrence-free survival (P<.001). The median recurrence-free survival times for patients with tumors expressing low, intermediate, or high stathmin levels were 45 months (95% confidence interval [CI] = 0 to 90 months), 17 months (95% CI = 10.6 to 23.4 months), and 6 months (95% CI = 1.7 to 10.3 months), respectively. Expression of stathmin was inversely associated with overall survival of nitrosourea-treated mice carrying xenograft tumors. Median survival of mice with stathmin+/- tumors was 95 days (95% CI = 68.7 to 121.3 days) and that of mice with stathmin+/+ tumors was 64 days (95% CI = 58.2 to 69.8 days) (difference = 31 days, 95% CI = 4.1 to 57.9 days; P<.001, log-rank test). Nitrosoureas induced mitotic arrest in malignant glioma cells, and this effect was greater in cells with decreased stathmin expression. CONCLUSIONS: Loss of heterozygosity for the stathmin gene may be associated with improved outcomes of patients with 1p+/- anaplastic oligodendroglioma tumors.

Standard name | YANAGISAWA_LUNG_CANCER_RECURRENCE
Systematic name | M13596
Organism | Homo sapiens
PMID | 17551146
Authors | Yanagisawa K,Tomida S,Shimada Y,Yatabe Y,Mitsudomi T,Takahashi T
Category | C2
Sub-category | CGP
Brief description | Genes defining a 25-signal proteomic signature associated with a high risk of cancer recurrence and poor survival of NSCLC (non-small cell lung cancer) patients.
Full description | BACKGROUND: Among patients with non-small-cell lung cancer (NSCLC), those with poor prognosis cannot be distinguished from those with good prognosis. METHODS: Matrix-assisted laser desorption-ionization mass spectrometry was used to analyze protein profiles of 174 specimens from NSCLC tumors and 27 specimens from normal lung tissue and to derive a prognosis-associated proteomic signature. Frozen resected tissue specimens were randomly divided into a training set (116 NSCLC and 20 normal lung specimens) and an independent, blinded validation set (58 NSCLC and seven normal lung specimens). Mass spectrometry signals from training set specimens that were differentially associated with specimens from patients with a high risk of recurrence (i.e., who died within 5 years of surgical treatment because of relapse) compared with those from patients with a low risk of recurrence (i.e., alive with no symptoms of relapse after a median follow-up of 89 months) were selected by use of the Fisher's exact test, the Kruskal-Wallis test, and the significance analysis of microarray test. These signals were used to build an individualized, weighted voting-based prognostic signature. The signature was then validated in the independent dataset. Survival was assessed by multivariable Cox regression analysis. Proteins corresponding to individual signals were identified by ion-trap mass spectrometry coupled with high-performance liquid chromatography. All statistical tests were two-sided. RESULTS: From 2630 mass spectrometry signals from specimens in the training cohort, we derived a signature of 25 signals that was associated with both relapse-free survival and overall survival. Among stage I NSCLC patients in the validation set, the signature was statistically significantly associated with both overall survival (hazard ratio [HR] of death for patients in the high-risk group compared with those in the low-risk group = 61.1, 95% confidence interval [CI] = 8.9 to 419.2, P<.001) and relapse-free survival (HR of relapse = 11.7, 95% CI = 3.1 to 44.8, P<.001). Proteins corresponding to signals in the signature were identified that had various cellular functions, including ribosomal protein L26-like 1, acylphosphatase, and phosphoprotein enriched in astrocytes 15. CONCLUSIONS: We defined a mass spectrometry signature that was associated with survival among NSCLC patients and appeared to distinguish those with poor prognosis from those with good prognosis.

Standard name | KESHELAVA_MULTIPLE_DRUG_RESISTANCE
Systematic name | M12618
Organism | Homo sapiens
PMID | 17623797
Authors | Keshelava N,Davicioni E,Wan Z,Ji L,Sposto R,Triche TJ,Reynolds CP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in multiple drug resistant neuroblastoma cell lines.
Full description | BACKGROUND: Genes that are overexpressed in multidrug-resistant neuroblastomas relative to drug-sensitive neuroblastomas may provide targets for modulating drug resistance. METHODS: We used microarrays to compare the gene expression profile of two drug-sensitive neuroblastoma cell lines with that of three multidrug-resistant neuroblastoma cell lines. RNA expression of selected overexpressed genes was quantified in 17 neuroblastoma cell lines by reverse transcription-polymerase chain reaction (RT-PCR). Small-interfering RNAs (siRNAs) were used for silencing gene expression. Cytotoxicity of melphalan, carboplatin, etoposide, and vincristine and cytotoxic synergy (expressed as combination index calculated by CalcuSyn software, where combination index < 1 indicates synergy and > 1 indicates antagonism) were measured in cell lines with a fluorescence-based assay of cell viability. All statistical tests were two-sided. RESULTS: A total of 94 genes were overexpressed in the multidrug-resistant cell lines relative to the drug-sensitive cell lines. Nine genes were selected for RT-PCR analysis, of which four displayed higher mRNA expression in the multidrug-resistant lines than in the drug-sensitive lines: histone deacetylase 1 (HDAC1; 2.3-fold difference, 95% confidence interval [CI] = 1.0-fold to 3.5-fold, P = .025), nuclear transport factor 2-like export factor (4.2-fold difference, 95% CI = 1.7-fold to 7.6-fold, P = .0018), heat shock 27-kDa protein 1 (2.5-fold difference, 95% CI = 1.0-fold to 87.7-fold, P = .028), and TAF12 RNA polymerase II, TATA box-binding protein-associated factor, 20 kDa (2.2-fold, 95% CI = 0.9-fold to 6.0-fold, P = .051). siRNA knockdown of HDAC1 gene expression sensitized CHLA-136 neuroblastoma cells to etoposide up to fivefold relative to the parental cell line or scrambled siRNA-transfected cells (P<.001). Cytotoxicity of the histone deacetylase inhibitor depsipeptide was tested in combination with melphalan, carboplatin, etoposide, or vincristine in five multidrug-resistant neuroblastoma cell lines, and synergistic cytotoxicity was demonstrated at a 90% cell kill of treated cells (combination index < 0.8) in all cell lines. CONCLUSION: High HDAC1 mRNA expression was associated with multidrug resistance in neuroblastoma cell lines, and inhibition of HDAC1 expression or activity enhanced the cytotoxicity of chemotherapeutic drugs in multidrug-resistant neuroblastoma cell lines. Thus, HDAC1 is a potential therapeutic target in multidrug-resistant neuroblastoma.

Standard name | WINNEPENNINCKX_MELANOMA_METASTASIS_DN
Systematic name | M18320
Organism | Homo sapiens
PMID | 16595783
Authors | Winnepenninckx V,Lazar V,Michiels S,Dessen P,Stas M,Alonso SR,Avril MF,Ortiz Romero PL,Robert T,Balacescu O,Eggermont AM,Lenoir G,Sarasin A,Tursz T,van den Oord JJ,Spatz A,Melanoma Group of the European Organization for Research and Treatment of Cancer
Category | C2
Sub-category | CGP
Brief description | Genes from the 254-gene classifier which were down-regulated in melanoma patients with a reported distant metastasis within 4 years.
Full description | BACKGROUND: Gene expression profiling data for human primary cutaneous melanomas are scarce because of the lack of retrospective collections of frozen tumors. To identify differentially expressed genes that may be involved in melanoma progression and prognosis, we investigated the relationship between gene expression profiles and clinical outcome in a cohort of patients with primary melanoma. METHODS: Labeled complementary RNA (cRNA) from each tissue sample was hybridized to a pangenomic 44K 60-mer oligonucleotide microarray. Class comparison and class prediction analyses were performed to identify genes whose expression in primary melanomas was associated with 4-year distant metastasis-free survival among 58 patients with at least 4 years of follow-up, distant metastasis, or death. Results were validated immunohistochemically at the protein level in 176 independent primary melanomas from patients with a median clinical follow-up of 8.5 years. Survival was analyzed with a Cox multivariable model and stratified log-rank test. All statistical tests were two-sided. RESULTS: We identified 254 genes that were associated with distant metastasis-free survival of patients with primary melanoma. These 254 genes include genes involved in activating DNA replication origins, such as minichromosome maintenance genes and geminin. Twenty-three of these genes were studied at the protein level; expression of five (MCM4, P = .002; MCM3, P = .030; MCM6, P = .004; KPNA2, P = .021; and geminin, P = .004) was statistically significantly associated with overall survival in the validation set. In a multivariable Cox model adjusted for tumor thickness, ulceration, age, and sex, expression of MCM4 (hazard ratio [HR] of death = 4.04, 95% confidence interval [CI] = 1.39 to 11.76; P = .010) and MCM6 (HR of death = 7.42, 95% CI = 1.99 to 27.64; P = .003) proteins was still statistically significantly associated with overall survival. CONCLUSION: We identified 254 genes whose expression was associated with metastatic dissemination of cutaneous melanomas. These genes may shed light on the molecular mechanisms underlying poor prognosis in melanoma patients.

Standard name | TSAI_DNAJB4_TARGETS_UP
Systematic name | M13669
Organism | Homo sapiens
PMID | 16788156
Authors | Tsai MF,Wang CC,Chang GC,Chen CY,Chen HY,Cheng CL,Yang YP,Wu CY,Shih FY,Liu CC,Lin HP,Jou YS,Lin SC,Lin CW,Chen WJ,Chan WK,Chen JJ,Yang PC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CL1-5 cells (lung cancer) overexpressing DNAJB4 [GeneID=11080] off a plasmid vector.
Full description | BACKGROUND: We previously identified DnaJ-like heat shock protein (HLJ1) as a gene associated with tumor invasion. Here, we investigated the clinical significance of HLJ1 expression in non-small-cell lung cancer (NSCLC) patients and its role in cancer progression. METHODS: We induced HLJ1 overexpression or knockdown in human lung adenocarcinoma CL1-5 cells and analyzed cell proliferation, anchorage-independent growth, in vivo tumorigenesis, cell motility, invasion, and cell cycle progression. Expression of genes that act downstream of HLJ1 was examined by DNA microarray analysis, pathway analysis, and western blotting. We measured HLJ1 expression in tumors and adjacent normal tissues of 71 NSCLC patients by quantitative reverse transcription-polymerase chain reaction. Associations between HLJ1 expression and disease-free and overall survival were determined using the log-rank test and multivariable Cox proportional hazards regression analysis. Validation was performed in an independent cohort of 56 NSCLC patients. Loss of heterozygosity (LOH) mapping of the HLJ1 locus was analyzed in 48 paired microdissected NSCLC tumors. All statistical tests were two-sided. RESULTS: HLJ1 expression inhibited lung cancer cell proliferation, anchorage-independent growth, tumorigenesis, cell motility, and invasion, and slowed cell cycle progression through a novel STAT1/P21(WAF1) pathway that is independent of P53 and interferon. HLJ1 expression was lower in tumors than in adjacent normal tissue in 55 of 71 patients studied. NSCLC patients with high HLJI expressing tumors had reduced cancer recurrence (hazard ratio [HR] = 0.47; 95% confidence interval [CI] = 0.23 to 0.93; P = .03) and longer overall survival (HR = 0.38; 95% CI = 0.16 to 0.89; P = .03) than those with low-expressing tumors. Validation in the independent patient cohort confirmed the association between HLJ1 expression and patient outcome. LOH mapping revealed high frequencies (66.7% and 70.8%) of allelic loss and microsatellite instability (87.5% and 95.2%) of the HLJ1 locus at chromosome 1p31.1. CONCLUSIONS: HLJ1 is a novel tumor suppressor in NSCLC, and high HLJ1 expression is associated with reduced cancer recurrence and prolonged survival of NSCLC patients.

Standard name | TSAI_DNAJB4_TARGETS_DN
Systematic name | M12315
Organism | Homo sapiens
PMID | 16788156
Authors | Tsai MF,Wang CC,Chang GC,Chen CY,Chen HY,Cheng CL,Yang YP,Wu CY,Shih FY,Liu CC,Lin HP,Jou YS,Lin SC,Lin CW,Chen WJ,Chan WK,Chen JJ,Yang PC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CL1-5 cells (lung cancer) overexpressing DNAJB4 [GeneID=11080] off a plasmid vector.
Full description | BACKGROUND: We previously identified DnaJ-like heat shock protein (HLJ1) as a gene associated with tumor invasion. Here, we investigated the clinical significance of HLJ1 expression in non-small-cell lung cancer (NSCLC) patients and its role in cancer progression. METHODS: We induced HLJ1 overexpression or knockdown in human lung adenocarcinoma CL1-5 cells and analyzed cell proliferation, anchorage-independent growth, in vivo tumorigenesis, cell motility, invasion, and cell cycle progression. Expression of genes that act downstream of HLJ1 was examined by DNA microarray analysis, pathway analysis, and western blotting. We measured HLJ1 expression in tumors and adjacent normal tissues of 71 NSCLC patients by quantitative reverse transcription-polymerase chain reaction. Associations between HLJ1 expression and disease-free and overall survival were determined using the log-rank test and multivariable Cox proportional hazards regression analysis. Validation was performed in an independent cohort of 56 NSCLC patients. Loss of heterozygosity (LOH) mapping of the HLJ1 locus was analyzed in 48 paired microdissected NSCLC tumors. All statistical tests were two-sided. RESULTS: HLJ1 expression inhibited lung cancer cell proliferation, anchorage-independent growth, tumorigenesis, cell motility, and invasion, and slowed cell cycle progression through a novel STAT1/P21(WAF1) pathway that is independent of P53 and interferon. HLJ1 expression was lower in tumors than in adjacent normal tissue in 55 of 71 patients studied. NSCLC patients with high HLJI expressing tumors had reduced cancer recurrence (hazard ratio [HR] = 0.47; 95% confidence interval [CI] = 0.23 to 0.93; P = .03) and longer overall survival (HR = 0.38; 95% CI = 0.16 to 0.89; P = .03) than those with low-expressing tumors. Validation in the independent patient cohort confirmed the association between HLJ1 expression and patient outcome. LOH mapping revealed high frequencies (66.7% and 70.8%) of allelic loss and microsatellite instability (87.5% and 95.2%) of the HLJ1 locus at chromosome 1p31.1. CONCLUSIONS: HLJ1 is a novel tumor suppressor in NSCLC, and high HLJ1 expression is associated with reduced cancer recurrence and prolonged survival of NSCLC patients.

Standard name | ASGHARZADEH_NEUROBLASTOMA_POOR_SURVIVAL_DN
Systematic name | M17794
Organism | Homo sapiens
PMID | 16954472
Authors | Asgharzadeh S,Pique-Regi R,Sposto R,Wang H,Yang Y,Shimada H,Matthay K,Buckley J,Ortega A,Seeger RC
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes associated with poor survival prognosis of patients with metastatic neuroblastoma that lack MYCN [GeneID=4613] amplification.
Full description | BACKGROUND: The aggressiveness of metastatic neuroblastomas that lack MYCN gene amplification varies with age--they are least aggressive when diagnosed in patients younger than 12 months and most aggressive when diagnosed in patients older than 24 months. However, age at diagnosis is not always associated with patient survival. We examined whether molecular classification of metastatic neuroblastomas without MYCN gene amplification at diagnosis using gene expression profiling could improve the prediction of risk of disease progression. METHODS: We used Affymetrix microarrays to determine the gene expression profiles of 102 untreated primary neuroblastomas without MYCN gene amplification obtained from children whose ages at diagnosis ranged from 0.1 to 151 months. A supervised method using diagonal linear discriminant analysis was devised to build a multigene model for predicting risk of disease progression. The accuracy of the model was evaluated using nested cross-validations, permutation analyses, and gene expression data from 15 additional tumors obtained at disease progression. RESULTS: An expression profile model using 55 genes defined a tumor signature that distinguished two groups of patients from among those older than 12 months at diagnosis and clinically classified as having high-risk disease, those with a progression-free survival (PFS) rate of 16% (95% confidence interval [CI] = 8% to 28%), and those with a PFS rate of 79% (95% CI = 57% to 91%) (P<.01). These tumor signatures also identified two groups of patients with PFS of 15% (95% CI = 7% to 27%) and 69% (95% CI = 40% to 86%) (P<.01) from among patients who were older than 18 months at diagnosis. The gene expression signature of untreated molecular high-risk tumors was also present in progressively growing tumors. CONCLUSION: Gene expression signatures of tumors obtained at diagnosis from patients with clinically indistinguishable high-risk, metastatic neuroblastomas identify subgroups with different outcomes. Accurate identification of these subgroups with gene expression profiles may facilitate development, implementation, and analysis of clinical trials aimed at improving outcome.

Standard name | LI_PROSTATE_CANCER_EPIGENETIC
Systematic name | M10861
Organism | Homo sapiens
PMID | 15657340
Authors | Li LC,Carroll PR,Dahiya R
Category | C2
Sub-category | CGP
Brief description | Genes affected by epigenetic aberrations in prostate cancer.
Full description | Prostate cancer is the most common noncutaneous malignancy and the second leading cause of cancer death among men in the United States. DNA methylation and histone modifications are important epigenetic mechanisms of gene regulation and play essential roles both independently and cooperatively in tumor initiation and progression. Aberrant epigenetic events such as DNA hypo- and hypermethylation and altered histone acetylation have both been observed in prostate cancer, in which they affect a large number of genes. Although the list of aberrantly epigenetically regulated genes continues to grow, only a few genes have, so far, given promising results as potential tumor biomarkers for early diagnosis and risk assessment of prostate cancer. Thus, large-scale screening of aberrant epigenetic events such as DNA hypermethylation is needed to identify prostate cancer-specific epigenetic fingerprints. The reversibility of epigenetic aberrations has made them attractive targets for cancer treatment with modulators that demethylate DNA and inhibit histone deacetylases, leading to reactivation of silenced genes. More studies into the mechanism and consequence of demethylation are required before the cancer epigenome can be safely manipulated with therapeutics as a treatment modality. In this review, we examine the current literature on epigenetic changes in prostate cancer and discuss the clinical potential of cancer epigenetics for the diagnosis and treatment of this disease.

Standard name | UROSEVIC_RESPONSE_TO_IMIQUIMOD
Systematic name | M4857
Organism | Homo sapiens
PMID | 16077073
Authors | Urosevic M,Dummer R,Conrad C,Beyeler M,Laine E,Burg G,Gilliet M
Category | C2
Sub-category | CGP
Brief description | Interferon cluster genes up-regulated in skin tumors treated with imiquimod [PubChem=57469].
Full description | BACKGROUND: Imiquimod, an immune response modifier that is used topically to treat different types of skin cancer, induces the production of proinflammatory cytokines that stimulate an antitumor immune response. We assessed characteristics of the imiquimod-induced immune activation in epithelial and lymphoproliferative neoplasias of human skin. We focused on plasmacytoid predendritic cells (PDCs), the primary producer of interferon alpha (IFN-alpha) after imiquimod activation in vitro. METHODS: We used Affymetrix oligonucleotide arrays to compare gene expression profiles from tumors from 16 patients, 10 with superficial basal cell carcinomas (sBCCs), five with cutaneous T-cell lymphomas (CTCLs), and one with Bowen's disease, before and after topical imiquimod treatment. We used quantitative immunohistochemistry with PDC-specific antibodies against BDCA-2 and CD123 to characterize the PDC population before and after imiquimod treatment in these specimens. Activation status of PDCs from four sBCC patients was assessed by intracellular IFN-alpha staining and flow cytometry. RESULTS: Expression of various IFN-alpha-inducible genes (e.g., CIG5, G1P2, OASL, IFIT1, STAT1, IFI35, OAS1, ISG20, MxA, and IRF7), the so-called IFN-alpha signature, was increased similarly in both sBCC and CTCL lesions after imiquimod treatment. PDCs were recruited and activated in both lesion types, and they produced IFN-alpha after imiquimod treatment in vivo (mean percentage of PDCs producing IFN-alpha = 14.5%, 95% confidence interval [CI] = 4.9% to 24%; range = 3.3%-27%, n = 4 lesions). Imiquimod induced similar immune activation patterns in all three diseases, and these patterns were associated with the number of PDCs recruited to the treatment site. Two imiquimod-treated sBCC patients who did not mount an inflammatory response to imiquimod and whose lesions lacked the IFN-alpha signature after treatment had fewer PDCs in treated lesions compared with other treated patients with such a response. CONCLUSIONS: Imiquimod induces immune activation patterns that relate to the number of the PDCs recruited to the treatment site, thus supporting the role of PDC in responsiveness to imiquimod in humans.

Standard name | KUROZUMI_RESPONSE_TO_ONCOCYTIC_VIRUS
Systematic name | M1985
Organism | Rattus norvegicus
PMID | 18042934
Authors | Kurozumi K,Hardcastle J,Thakur R,Yang M,Christoforidis G,Fulci G,Hochberg FH,Weissleder R,Carson W,Chiocca EA,Kaur B
Category | C2
Sub-category | CGP
Brief description | Inflammatory cytokines and their receptors modulated in brain tumors after treatment with an oncocytic virus, a potential anticancer therapy.
Full description | BACKGROUND: The tumor microenvironment is being increasingly recognized as an important determinant of tumor progression as well as of therapeutic response. We investigated oncolytic virus (OV) therapy-induced changes in tumor blood vessels and the impact of modulating tumor vasculature on the efficacy of oncolytic virus therapy. METHODS: Rat glioma cells (D74/HveC) were implanted intracranially in immune-competent rats. Seven days later, the rats (groups of 3-7 rats) were treated with oncolytic virus (hrR3), and, 3 days later, brains were harvested for evaluation. Some rats were treated with angiostatic cRGD peptide 4 days before oncolytic virus treatment. Some rats were treated with cyclophosphamide (CPA), an immunosuppressant, 2 days before oncolytic virus treatment. Changes in tumor vascular perfusion were evaluated by magnetic resonance imaging of live rats and by fluorescence microscopy of tumor sections from rats perfused with Texas red-conjugated lectin immediately before euthanasia. Leukocyte infiltration in tumors was evaluated by anti-CD45 immunohistochemistry, and the presence of oncolytic virus in tumors was evaluated by viral titration. Changes in cytokine gene expression in tumors were measured by quantitative real-time polymerase chain reaction-based microarrays. Survival was analyzed by the Kaplan-Meier method. All statistical tests were two-sided. RESULTS: Oncolytic virus treatment of experimental rat gliomas increased tumor vascular permeability, host leukocyte infiltration into tumors, and intratumoral expression of inflammatory cytokine genes, including interferon gamma (IFN-gamma). The increase in vascular permeability was suppressed in rats pretreated with cyclophosphamide. Compared with rats treated with hrR3 alone, rats pretreated with a single dose of cRGD peptide before hrR3 treatment had reduced tumor vascular permeability, leukocyte infiltration, and IFN-gamma protein levels (mean IFN-gamma level for hrR3 versus hrR3 + cRGD = 203 versus 65.6 microg/mg, difference = 137 microg/mg, 95% confidence interval = 72.7 to 202.9 microg/mg, P = .006); increased viral titers in tumor tissue; and longer median survival (21 days versus 17 days, P<.001). CONCLUSIONS: A single dose of angiostatic cRGD peptide treatment before oncolytic virus treatment enhanced the antitumor efficacy of oncolytic virus.

Standard name | KUROZUMI_RESPONSE_TO_ONCOCYTIC_VIRUS_AND_CYCLIC_RGD
Systematic name | M1986
Organism | Rattus norvegicus
PMID | 18042934
Authors | Kurozumi K,Hardcastle J,Thakur R,Yang M,Christoforidis G,Fulci G,Hochberg FH,Weissleder R,Carson W,Chiocca EA,Kaur B
Category | C2
Sub-category | CGP
Brief description | Inflammatory cytokines and their receptors moduated in brain tumors in response to treatment with cyclic RGD peptide prior to the oncocytic virus therapy.
Full description | BACKGROUND: The tumor microenvironment is being increasingly recognized as an important determinant of tumor progression as well as of therapeutic response. We investigated oncolytic virus (OV) therapy-induced changes in tumor blood vessels and the impact of modulating tumor vasculature on the efficacy of oncolytic virus therapy. METHODS: Rat glioma cells (D74/HveC) were implanted intracranially in immune-competent rats. Seven days later, the rats (groups of 3-7 rats) were treated with oncolytic virus (hrR3), and, 3 days later, brains were harvested for evaluation. Some rats were treated with angiostatic cRGD peptide 4 days before oncolytic virus treatment. Some rats were treated with cyclophosphamide (CPA), an immunosuppressant, 2 days before oncolytic virus treatment. Changes in tumor vascular perfusion were evaluated by magnetic resonance imaging of live rats and by fluorescence microscopy of tumor sections from rats perfused with Texas red-conjugated lectin immediately before euthanasia. Leukocyte infiltration in tumors was evaluated by anti-CD45 immunohistochemistry, and the presence of oncolytic virus in tumors was evaluated by viral titration. Changes in cytokine gene expression in tumors were measured by quantitative real-time polymerase chain reaction-based microarrays. Survival was analyzed by the Kaplan-Meier method. All statistical tests were two-sided. RESULTS: Oncolytic virus treatment of experimental rat gliomas increased tumor vascular permeability, host leukocyte infiltration into tumors, and intratumoral expression of inflammatory cytokine genes, including interferon gamma (IFN-gamma). The increase in vascular permeability was suppressed in rats pretreated with cyclophosphamide. Compared with rats treated with hrR3 alone, rats pretreated with a single dose of cRGD peptide before hrR3 treatment had reduced tumor vascular permeability, leukocyte infiltration, and IFN-gamma protein levels (mean IFN-gamma level for hrR3 versus hrR3 + cRGD = 203 versus 65.6 microg/mg, difference = 137 microg/mg, 95% confidence interval = 72.7 to 202.9 microg/mg, P = .006); increased viral titers in tumor tissue; and longer median survival (21 days versus 17 days, P<.001). CONCLUSIONS: A single dose of angiostatic cRGD peptide treatment before oncolytic virus treatment enhanced the antitumor efficacy of oncolytic virus.

Standard name | FONTAINE_FOLLICULAR_THYROID_ADENOMA_UP
Systematic name | M4605
Organism | Homo sapiens
PMID | 17968324
Authors | Fontaine JF,Mirebeau-Prunier D,Franc B,Triau S,Rodien P,Houlgatte R,Malthièry Y,Savagner F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in follicular thyroid adenoma (FTA) compared to other thyroid tumors.
Full description | Conventional histology failed to classify part of non-medullary thyroid lesions as either benign or malignant. The group of tumours of uncertain malignancy (T-UM) concerns either atypical follicular adenomas or the recently called 'tumours of uncertain malignant potential'. To refine this classification we analysed microarray data from 93 follicular thyroid tumours: 10 T-UM, 3 follicular carcinomas, 13 papillary thyroid carcinomas and 67 follicular adenomas, compared to 73 control thyroid tissue samples. The diagnosis potential of 16 selected genes was validated by real-time quantitative RT-PCR on 6 additional T-UM. The gene expression profiles in several groups were examined with reference to the mutational status of the RET/PTC, BRAF and RAS genes. A pathological score (histological and immunohistochemical) was estimate for each of the T-UM involved in the study. The correlation between the T-UM gene profiles and the pathological score allowed a separation of the samples in two groups of benign or malignant tumours. Our analysis confirms the heterogeneity of T-UM and highlighted the molecular similarities between some cases and true carcinomas. We demonstrated the ability of few marker genes to serve as diagnosis tools and the need of a T-UM pathological scoring.

Standard name | FONTAINE_FOLLICULAR_THYROID_ADENOMA_DN
Systematic name | M5370
Organism | Homo sapiens
PMID | 17968324
Authors | Fontaine JF,Mirebeau-Prunier D,Franc B,Triau S,Rodien P,Houlgatte R,Malthièry Y,Savagner F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in follicular thyroid adenoma (FTA) compared to other thyroid tumors.
Full description | Conventional histology failed to classify part of non-medullary thyroid lesions as either benign or malignant. The group of tumours of uncertain malignancy (T-UM) concerns either atypical follicular adenomas or the recently called 'tumours of uncertain malignant potential'. To refine this classification we analysed microarray data from 93 follicular thyroid tumours: 10 T-UM, 3 follicular carcinomas, 13 papillary thyroid carcinomas and 67 follicular adenomas, compared to 73 control thyroid tissue samples. The diagnosis potential of 16 selected genes was validated by real-time quantitative RT-PCR on 6 additional T-UM. The gene expression profiles in several groups were examined with reference to the mutational status of the RET/PTC, BRAF and RAS genes. A pathological score (histological and immunohistochemical) was estimate for each of the T-UM involved in the study. The correlation between the T-UM gene profiles and the pathological score allowed a separation of the samples in two groups of benign or malignant tumours. Our analysis confirms the heterogeneity of T-UM and highlighted the molecular similarities between some cases and true carcinomas. We demonstrated the ability of few marker genes to serve as diagnosis tools and the need of a T-UM pathological scoring.

Standard name | FONTAINE_THYROID_TUMOR_UNCERTAIN_MALIGNANCY_UP
Systematic name | M4957
Organism | Homo sapiens
PMID | 17968324
Authors | Fontaine JF,Mirebeau-Prunier D,Franc B,Triau S,Rodien P,Houlgatte R,Malthièry Y,Savagner F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in thyroid tumors of uncertain malignancy (T-UM) compared to other thyroid tumors.
Full description | Conventional histology failed to classify part of non-medullary thyroid lesions as either benign or malignant. The group of tumours of uncertain malignancy (T-UM) concerns either atypical follicular adenomas or the recently called 'tumours of uncertain malignant potential'. To refine this classification we analysed microarray data from 93 follicular thyroid tumours: 10 T-UM, 3 follicular carcinomas, 13 papillary thyroid carcinomas and 67 follicular adenomas, compared to 73 control thyroid tissue samples. The diagnosis potential of 16 selected genes was validated by real-time quantitative RT-PCR on 6 additional T-UM. The gene expression profiles in several groups were examined with reference to the mutational status of the RET/PTC, BRAF and RAS genes. A pathological score (histological and immunohistochemical) was estimate for each of the T-UM involved in the study. The correlation between the T-UM gene profiles and the pathological score allowed a separation of the samples in two groups of benign or malignant tumours. Our analysis confirms the heterogeneity of T-UM and highlighted the molecular similarities between some cases and true carcinomas. We demonstrated the ability of few marker genes to serve as diagnosis tools and the need of a T-UM pathological scoring.

Standard name | FONTAINE_THYROID_TUMOR_UNCERTAIN_MALIGNANCY_DN
Systematic name | M18834
Organism | Homo sapiens
PMID | 17968324
Authors | Fontaine JF,Mirebeau-Prunier D,Franc B,Triau S,Rodien P,Houlgatte R,Malthièry Y,Savagner F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in thyroid tumors of uncertain malignancy (T-UM) compared to other thyroid tumors.
Full description | Conventional histology failed to classify part of non-medullary thyroid lesions as either benign or malignant. The group of tumours of uncertain malignancy (T-UM) concerns either atypical follicular adenomas or the recently called 'tumours of uncertain malignant potential'. To refine this classification we analysed microarray data from 93 follicular thyroid tumours: 10 T-UM, 3 follicular carcinomas, 13 papillary thyroid carcinomas and 67 follicular adenomas, compared to 73 control thyroid tissue samples. The diagnosis potential of 16 selected genes was validated by real-time quantitative RT-PCR on 6 additional T-UM. The gene expression profiles in several groups were examined with reference to the mutational status of the RET/PTC, BRAF and RAS genes. A pathological score (histological and immunohistochemical) was estimate for each of the T-UM involved in the study. The correlation between the T-UM gene profiles and the pathological score allowed a separation of the samples in two groups of benign or malignant tumours. Our analysis confirms the heterogeneity of T-UM and highlighted the molecular similarities between some cases and true carcinomas. We demonstrated the ability of few marker genes to serve as diagnosis tools and the need of a T-UM pathological scoring.

Standard name | FONTAINE_PAPILLARY_THYROID_CARCINOMA_UP
Systematic name | M12353
Organism | Homo sapiens
PMID | 17968324
Authors | Fontaine JF,Mirebeau-Prunier D,Franc B,Triau S,Rodien P,Houlgatte R,Malthièry Y,Savagner F
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in papillary thyroid carcinoma (PTC) compared to other thyroid tumors.
Full description | Conventional histology failed to classify part of non-medullary thyroid lesions as either benign or malignant. The group of tumours of uncertain malignancy (T-UM) concerns either atypical follicular adenomas or the recently called 'tumours of uncertain malignant potential'. To refine this classification we analysed microarray data from 93 follicular thyroid tumours: 10 T-UM, 3 follicular carcinomas, 13 papillary thyroid carcinomas and 67 follicular adenomas, compared to 73 control thyroid tissue samples. The diagnosis potential of 16 selected genes was validated by real-time quantitative RT-PCR on 6 additional T-UM. The gene expression profiles in several groups were examined with reference to the mutational status of the RET/PTC, BRAF and RAS genes. A pathological score (histological and immunohistochemical) was estimate for each of the T-UM involved in the study. The correlation between the T-UM gene profiles and the pathological score allowed a separation of the samples in two groups of benign or malignant tumours. Our analysis confirms the heterogeneity of T-UM and highlighted the molecular similarities between some cases and true carcinomas. We demonstrated the ability of few marker genes to serve as diagnosis tools and the need of a T-UM pathological scoring.

Standard name | FONTAINE_PAPILLARY_THYROID_CARCINOMA_DN
Systematic name | M14275
Organism | Homo sapiens
PMID | 17968324
Authors | Fontaine JF,Mirebeau-Prunier D,Franc B,Triau S,Rodien P,Houlgatte R,Malthièry Y,Savagner F
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in papillary thyroid carcinoma (PTC) compared to other thyroid tumors.
Full description | Conventional histology failed to classify part of non-medullary thyroid lesions as either benign or malignant. The group of tumours of uncertain malignancy (T-UM) concerns either atypical follicular adenomas or the recently called 'tumours of uncertain malignant potential'. To refine this classification we analysed microarray data from 93 follicular thyroid tumours: 10 T-UM, 3 follicular carcinomas, 13 papillary thyroid carcinomas and 67 follicular adenomas, compared to 73 control thyroid tissue samples. The diagnosis potential of 16 selected genes was validated by real-time quantitative RT-PCR on 6 additional T-UM. The gene expression profiles in several groups were examined with reference to the mutational status of the RET/PTC, BRAF and RAS genes. A pathological score (histological and immunohistochemical) was estimate for each of the T-UM involved in the study. The correlation between the T-UM gene profiles and the pathological score allowed a separation of the samples in two groups of benign or malignant tumours. Our analysis confirms the heterogeneity of T-UM and highlighted the molecular similarities between some cases and true carcinomas. We demonstrated the ability of few marker genes to serve as diagnosis tools and the need of a T-UM pathological scoring.

Standard name | LIANG_HEMATOPOIESIS_STEM_CELL_NUMBER_QTL
Systematic name | M3903
Organism | Mus musculus
PMID | 17220891
Authors | Liang Y,Jansen M,Aronow B,Geiger H,Van Zant G
Category | C2
Sub-category | CGP
Brief description | Genes changed in LSK cells (bone marrow) as a function of a QTL for the size of hematopoietic stem cell (HSC) population: comparison of reciprocal congenic strains D.B. Chr3 (DB), B.D. Chr3 (BD) and the parental strains B6 and D2.
Full description | We mapped quantitative trait loci that accounted for the variation in hematopoietic stem cell (HSC) numbers between young adult C57BL/6 (B6) and DBA/2 (D2) mice. In reciprocal chromosome 3 congenic mice, introgressed D2 alleles increased HSC numbers owing to enhanced proliferation and self-renewal and reduced apoptosis, whereas B6 alleles had the opposite effects. Using oligonucleotide arrays, real-time PCR and protein blots, we identified latexin (Lxn), a gene whose differential transcription and expression was associated with the allelic differences. Expression was inversely correlated with the number of HSCs; therefore, ectopic expression of Lxn using a retroviral vector decreased stem cell population size. We identified clusters of SNPs upstream of the Lxn transcriptional start site, at least two of which are associated with potential binding sites for transcription factors regulating stem cells. Thus, promoter polymorphisms between the B6 and D2 alleles may affect Lxn gene expression and consequently influence the population size of hematopoietic stem cells.

Standard name | WEBER_METHYLATED_LCP_IN_FIBROBLAST_UP
Systematic name | M4123
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Methylated germline-specific genes with low-CpG-density promoters (LCP) in primary fibroblasts.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | WEBER_METHYLATED_LCP_IN_FIBROBLAST_DN
Systematic name | M13611
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Unmethylated germline-specific genes with low-CpG-density promoters (LCP) in primary fibroblasts.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | WEBER_METHYLATED_ICP_IN_FIBROBLAST
Systematic name | M731
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Germline-specific genes with intermediate-CpG-density promoters (ICP) that are methylated in primary fibroblasts.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | WEBER_METHYLATED_ICP_IN_SPERM_UP
Systematic name | M3977
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Methylated germline-specific genes with intermediate-CpG-density promoters (ICP) in sperm.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | WEBER_METHYLATED_ICP_IN_SPERM_DN
Systematic name | M16399
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Unmethylated germline-specific genes with intermediate-CpG-density promoters (ICP) in sperm.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | WEBER_METHYLATED_LCP_IN_SPERM_UP
Systematic name | M14547
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Methylated germline-specific genes with low-CpG-density promoters (LCP) in sperm.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | WEBER_METHYLATED_LCP_IN_SPERM_DN
Systematic name | M4762
Organism | Homo sapiens
PMID | 17334365
Authors | Weber M,Hellmann I,Stadler MB,Ramos L,Pääbo S,Rebhan M,Schübeler D
Category | C2
Sub-category | CGP
Brief description | Unmethylated germline-specific genes with low-CpG-density promoters (LCP) in sperm.
Full description | To gain insight into the function of DNA methylation at cis-regulatory regions and its impact on gene expression, we measured methylation, RNA polymerase occupancy and histone modifications at 16,000 promoters in primary human somatic and germline cells. We find CpG-poor promoters hypermethylated in somatic cells, which does not preclude their activity. This methylation is present in male gametes and results in evolutionary loss of CpG dinucleotides, as measured by divergence between humans and primates. In contrast, strong CpG island promoters are mostly unmethylated, even when inactive. Weak CpG island promoters are distinct, as they are preferential targets for de novo methylation in somatic cells. Notably, most germline-specific genes are methylated in somatic cells, suggesting additional functional selection. These results show that promoter sequence and gene function are major predictors of promoter methylation states. Moreover, we observe that inactive unmethylated CpG island promoters show elevated levels of dimethylation of Lys4 of histone H3, suggesting that this chromatin mark may protect DNA from methylation.

Standard name | PUJANA_BREAST_CANCER_WITH_BRCA1_MUTATED_UP
Systematic name | M2180
Organism | Homo sapiens
PMID | 17922014
Authors | Pujana MA,Han JD,Starita LM,Stevens KN,Tewari M,Ahn JS,Rennert G,Moreno V,Kirchhoff T,Gold B,Assmann V,Elshamy WM,Rual JF,Levine D,Rozek LS,Gelman RS,Gunsalus KC,Greenberg RA,Sobhian B,Bertin N,Venkatesan K,Ayivi-Guedehoussou N,Solé X,Hernández P,Lázaro C,Nathanson KL,Weber BL,Cusick ME,Hill DE,Offit K,Livingston DM,Gruber SB,Parvin JD,Vidal M
Category | C2
Sub-category | CGP
Brief description | The XPRSS-Int network genes up-regulated in breast tumors from patients with germline mutations in BRCA1 [GeneID=672] compared to those with the wild type allele.
Full description | Many cancer-associated genes remain to be identified to clarify the underlying molecular mechanisms of cancer susceptibility and progression. Better understanding is also required of how mutations in cancer genes affect their products in the context of complex cellular networks. Here we have used a network modeling strategy to identify genes potentially associated with higher risk of breast cancer. Starting with four known genes encoding tumor suppressors of breast cancer, we combined gene expression profiling with functional genomic and proteomic (or 'omic') data from various species to generate a network containing 118 genes linked by 866 potential functional associations. This network shows higher connectivity than expected by chance, suggesting that its components function in biologically related pathways. One of the components of the network is HMMR, encoding a centrosome subunit, for which we demonstrate previously unknown functional associations with the breast cancer-associated gene BRCA1. Two case-control studies of incident breast cancer indicate that the HMMR locus is associated with higher risk of breast cancer in humans. Our network modeling strategy should be useful for the discovery of additional cancer-associated genes.

Standard name | PUJANA_BREAST_CANCER_WITH_BRCA1_MUTATED_DN
Systematic name | M376
Organism | Homo sapiens
PMID | 17922014
Authors | Pujana MA,Han JD,Starita LM,Stevens KN,Tewari M,Ahn JS,Rennert G,Moreno V,Kirchhoff T,Gold B,Assmann V,Elshamy WM,Rual JF,Levine D,Rozek LS,Gelman RS,Gunsalus KC,Greenberg RA,Sobhian B,Bertin N,Venkatesan K,Ayivi-Guedehoussou N,Solé X,Hernández P,Lázaro C,Nathanson KL,Weber BL,Cusick ME,Hill DE,Offit K,Livingston DM,Gruber SB,Parvin JD,Vidal M
Category | C2
Sub-category | CGP
Brief description | The XPRSS-Int network genes down-regulated in breast tumors from patients with germline mutations in BRCA1 [GeneID=672] compared to those with the wild type allele.
Full description | Many cancer-associated genes remain to be identified to clarify the underlying molecular mechanisms of cancer susceptibility and progression. Better understanding is also required of how mutations in cancer genes affect their products in the context of complex cellular networks. Here we have used a network modeling strategy to identify genes potentially associated with higher risk of breast cancer. Starting with four known genes encoding tumor suppressors of breast cancer, we combined gene expression profiling with functional genomic and proteomic (or 'omic') data from various species to generate a network containing 118 genes linked by 866 potential functional associations. This network shows higher connectivity than expected by chance, suggesting that its components function in biologically related pathways. One of the components of the network is HMMR, encoding a centrosome subunit, for which we demonstrate previously unknown functional associations with the breast cancer-associated gene BRCA1. Two case-control studies of incident breast cancer indicate that the HMMR locus is associated with higher risk of breast cancer in humans. Our network modeling strategy should be useful for the discovery of additional cancer-associated genes.

Standard name | GYORFFY_DOXORUBICIN_RESISTANCE
Systematic name | M1987
Organism | Homo sapiens
PMID | 16044152
Authors | Györffy B,Serra V,Jürchott K,Abdul-Ghani R,Garber M,Stein U,Petersen I,Lage H,Dietel M,Schäfer R
Category | C2
Sub-category | CGP
Brief description | Genes associated with resistance to doxorubicin [PubChem=31703].
Full description | Up to date clinical tests for predicting cancer chemotherapy response are not available and individual markers have shown little predictive value. We hypothesized that gene expression patterns attributable to chemotherapy-resistant cells can predict response and cancer prognosis. We contrasted the expression profiles of 13 different human tumor cell lines of gastric (EPG85-257), pancreatic (EPP85-181), colon (HT29) and breast (MCF7 and MDA-MB-231) origin and their counterparts resistant to the topoisomerase inhibitors daunorubicin, doxorubicin or mitoxantrone. We interrogated cDNA arrays with 43 000 cDNA clones ( approximately 30 000 unique genes) to study the expression pattern of these cell lines. We divided gene expression profiles into two sets: we compared the expression patterns of the daunorubicin/doxorubicin-resistant cell lines and the mitoxantrone-resistant cell lines independently to the parental cell lines. For identifying predictive genes, the Prediction Analysis for Mircorarrays algorithm was used. The analysis revealed 79 genes best correlated with doxorubicin resistance and 70 genes with mitoxantrone resistance. In an independent classification experiment, we applied our model of resistance for predicting the sensitivity of 44 previously characterized breast cancer samples. The patient group characterized by the gene expression profile similar to those of doxorubicin-sensitive cell lines exhibited longer survival (49.7+/-26.1 months, n=21, P=0.034) than the resistant group (32.9+/-18.7 months, n=23). The application of gene expression signatures derived from doxorubicin-resistant and -sensitive cell lines allowed to predict effectively clinical survival after doxorubicin monotherapy. Our approach demonstrates the significance of in vitro experiments in the development of new strategies for cancer response prediction.

Standard name | GYORFFY_MITOXANTRONE_RESISTANCE
Systematic name | M1988
Organism | Homo sapiens
PMID | 16044152
Authors | Györffy B,Serra V,Jürchott K,Abdul-Ghani R,Garber M,Stein U,Petersen I,Lage H,Dietel M,Schäfer R
Category | C2
Sub-category | CGP
Brief description | Genes associated with resistance to mitoxantrone [PubChem=4212].
Full description | Up to date clinical tests for predicting cancer chemotherapy response are not available and individual markers have shown little predictive value. We hypothesized that gene expression patterns attributable to chemotherapy-resistant cells can predict response and cancer prognosis. We contrasted the expression profiles of 13 different human tumor cell lines of gastric (EPG85-257), pancreatic (EPP85-181), colon (HT29) and breast (MCF7 and MDA-MB-231) origin and their counterparts resistant to the topoisomerase inhibitors daunorubicin, doxorubicin or mitoxantrone. We interrogated cDNA arrays with 43 000 cDNA clones ( approximately 30 000 unique genes) to study the expression pattern of these cell lines. We divided gene expression profiles into two sets: we compared the expression patterns of the daunorubicin/doxorubicin-resistant cell lines and the mitoxantrone-resistant cell lines independently to the parental cell lines. For identifying predictive genes, the Prediction Analysis for Mircorarrays algorithm was used. The analysis revealed 79 genes best correlated with doxorubicin resistance and 70 genes with mitoxantrone resistance. In an independent classification experiment, we applied our model of resistance for predicting the sensitivity of 44 previously characterized breast cancer samples. The patient group characterized by the gene expression profile similar to those of doxorubicin-sensitive cell lines exhibited longer survival (49.7+/-26.1 months, n=21, P=0.034) than the resistant group (32.9+/-18.7 months, n=23). The application of gene expression signatures derived from doxorubicin-resistant and -sensitive cell lines allowed to predict effectively clinical survival after doxorubicin monotherapy. Our approach demonstrates the significance of in vitro experiments in the development of new strategies for cancer response prediction.

Standard name | SYED_ESTRADIOL_RESPONSE
Systematic name | M13262
Organism | Homo sapiens
PMID | 16116479
Authors | Syed V,Zhang X,Lau KM,Cheng R,Mukherjee K,Ho SM
Category | C2
Sub-category | CGP
Brief description | Genes responsive to estradiol [PubChem=5757] both in normal and cancer ovarian cell lines.
Full description | Estrogens regulate normal ovarian surface epithelium (OSE) cell functions but also affect epithelial ovarian cancer (OCa) development. Little is known about how estrogens play such opposing roles. Transcriptional profiling using a cDNA microarray containing 2400 named genes identified 155 genes whose expression was altered by estradiol-17beta (E2) in three immortalized normal human ovarian surface epithelial (HOSE) cell lines and 315 genes whose expression was affected by the hormone in three established OCa (OVCA) cell lines. All but 19 of the genes in these two sets were different. Among the 19 overlapping genes, five were found to show discordant responses between HOSE and OVCA cell lines. The five genes are those that encode clone 5.1 RNA-binding protein (RNPS1), erythrocyte adducin alpha subunit (ADD1), plexin A3 (PLXNA3 or the SEX gene), nuclear protein SkiP (SKIIP), and Rap-2 (rap-2). RNPS1, ADD1, rap-2, and SKIIP were upregulated by E2 in HOSE cells but downregulated by estrogen in OVCA cells, whereas PLXNA3 showed the reverse pattern of regulation. The estrogen effects was observed within 6-18 h of treatment. In silicon analyses revealed presence of estrogen response elements in the proximal promoters of all five genes. RNPS1, ADD1, and PLXNA3 were underexpressed in OVCA cell lines compared to HOSE cell lines, while the opposite was true for rap-2 and SKIIP. Functional studies showed that RNPS1 and ADD1 exerted multiple antitumor actions in OVCA cells, while PLXNA3 only inhibited cell invasiveness. In contrast, rap-2 was found to cause significant oncogenic effects in OVCA cells, while SKIIP promotes only anchorage-independent growth. In sum, gene profiling data reveal that (1) E2 exerts different actions on HOSE cells than on OVCA cells by affecting two distinct transcriptomes with few overlapping genes and (2) among the overlapping genes, a set of putative oncogenes/tumor suppressors have been identified due to their differential responses to E2 between the two cell types. These findings may explain the paradoxical roles of estrogens in regulating normal and malignant OSE cell functions.

Standard name | WORSCHECH_TUMOR_EVASION_AND_TOLEROGENICITY_UP
Systematic name | M1989
Organism | Mus musculus
PMID | 18381452
Authors | Worschech A,Kmieciak M,Knutson KL,Bear HD,Szalay AA,Wang E,Marincola FM,Manjili MH
Category | C2
Sub-category | CGP
Brief description | Selected genes with immunologic function which were reciprocally changed in evasion and tolerogenic tumor models.
Full description | We have previously shown T-cell-mediated rejection of the neu-overexpressing mammary carcinoma cells (MMC) in wild-type FVB mice. However, following rejection of primary tumors, a fraction of animals experienced a recurrence of a neu antigen-negative variant (ANV) of MMC (tumor evasion model) after a long latency period. In the present study, we determined that T cells derived from wild-type FVB mice can specifically recognize MMC by secreting IFN-gamma and can induce apoptosis of MMC in vitro. Neu transgenic (FVBN202) mice develop spontaneous tumors and cannot reject it (tumor tolerance model). To dissect the mechanisms associated with rejection or tolerance of MMC tumors, we compared transcriptional patterns within the tumor microenvironment of MMC undergoing rejection with those that resisted it either because of tumor evasion/antigen loss recurrence (ANV tumors) or because of intrinsic tolerance mechanisms displayed by the transgenic mice. Gene profiling confirmed that immune rejection is primarily mediated through activation of IFN-stimulated genes and T-cell effector mechanisms. The tumor evasion model showed combined activation of Th1 and Th2 with a deviation toward Th2 and humoral immune responses that failed to achieve rejection likely because of lack of target antigen. Interestingly, the tumor tolerance model instead displayed immune suppression pathways through activation of regulatory mechanisms that included in particular the overexpression of interleukin-10 (IL-10), IL-10 receptor, and suppressor of cytokine signaling (SOCS)-1 and SOCS-3. These data provide a road map for the identification of novel biomarkers of immune responsiveness in clinical trials.

Standard name | WORSCHECH_TUMOR_EVASION_AND_TOLEROGENICITY_DN
Systematic name | M1990
Organism | Mus musculus
PMID | 18381452
Authors | Worschech A,Kmieciak M,Knutson KL,Bear HD,Szalay AA,Wang E,Marincola FM,Manjili MH
Category | C2
Sub-category | CGP
Brief description | Selected genes with immunologic function which were reciprocally changed in evasion and tolerogenic tumor models.
Full description | We have previously shown T-cell-mediated rejection of the neu-overexpressing mammary carcinoma cells (MMC) in wild-type FVB mice. However, following rejection of primary tumors, a fraction of animals experienced a recurrence of a neu antigen-negative variant (ANV) of MMC (tumor evasion model) after a long latency period. In the present study, we determined that T cells derived from wild-type FVB mice can specifically recognize MMC by secreting IFN-gamma and can induce apoptosis of MMC in vitro. Neu transgenic (FVBN202) mice develop spontaneous tumors and cannot reject it (tumor tolerance model). To dissect the mechanisms associated with rejection or tolerance of MMC tumors, we compared transcriptional patterns within the tumor microenvironment of MMC undergoing rejection with those that resisted it either because of tumor evasion/antigen loss recurrence (ANV tumors) or because of intrinsic tolerance mechanisms displayed by the transgenic mice. Gene profiling confirmed that immune rejection is primarily mediated through activation of IFN-stimulated genes and T-cell effector mechanisms. The tumor evasion model showed combined activation of Th1 and Th2 with a deviation toward Th2 and humoral immune responses that failed to achieve rejection likely because of lack of target antigen. Interestingly, the tumor tolerance model instead displayed immune suppression pathways through activation of regulatory mechanisms that included in particular the overexpression of interleukin-10 (IL-10), IL-10 receptor, and suppressor of cytokine signaling (SOCS)-1 and SOCS-3. These data provide a road map for the identification of novel biomarkers of immune responsiveness in clinical trials.

Standard name | STEIN_ESR1_TARGETS
Systematic name | M9678
Organism | Homo sapiens
PMID | 18974123
Authors | Stein RA,Chang CY,Kazmin DA,Way J,Schroeder T,Wergin M,Dewhirst MW,McDonnell DP
Category | C2
Sub-category | CGP
Brief description | Genes regulated by ESR1 [GeneID=2099] in MCF-7 cells (breast cancer).
Full description | Expression of estrogen-related receptor alpha (ERRalpha) has recently been shown to carry negative prognostic significance in breast and ovarian cancers. The specific role of this orphan nuclear receptor in tumor growth and progression, however, is yet to be fully understood. The significant homology between estrogen receptor alpha (ERalpha) and ERRalpha initially suggested that these receptors may have similar transcriptional targets. Using the well-characterized ERalpha-positive MCF-7 breast cancer cell line, we sought to gain a genome-wide picture of ERalpha-ERRalpha cross-talk using an unbiased microarray approach. In addition to generating a host of novel ERRalpha target genes, this study yielded the surprising result that most ERRalpha-regulated genes are unrelated to estrogen signaling. The relatively small number of genes regulated by both ERalpha and ERRalpha led us to expand our study to the more aggressive and less clinically treatable ERalpha-negative class of breast cancers. In this setting, we found that ERRalpha expression is required for the basal level of expression of many known and novel ERRalpha target genes. Introduction of a small interfering RNA directed to ERRalpha into the highly aggressive breast carcinoma MDA-MB-231 cell line dramatically reduced the migratory potential of these cells. Although stable knockdown of ERRalpha expression in MDA-MB-231 cells had no effect on in vitro cell proliferation, a significant reduction of tumor growth rate was observed when these cells were implanted as xenografts. Our results confirm a role for ERRalpha in breast cancer growth and highlight it as a potential therapeutic target for estrogen receptor-negative breast cancer.

Standard name | STEIN_ESRRA_TARGETS
Systematic name | M843
Organism | Homo sapiens
PMID | 18974123
Authors | Stein RA,Chang CY,Kazmin DA,Way J,Schroeder T,Wergin M,Dewhirst MW,McDonnell DP
Category | C2
Sub-category | CGP
Brief description | Genes regulated by ESRRA [GeneID=2101] in MCF-7 cells (breast cancer).
Full description | Expression of estrogen-related receptor alpha (ERRalpha) has recently been shown to carry negative prognostic significance in breast and ovarian cancers. The specific role of this orphan nuclear receptor in tumor growth and progression, however, is yet to be fully understood. The significant homology between estrogen receptor alpha (ERalpha) and ERRalpha initially suggested that these receptors may have similar transcriptional targets. Using the well-characterized ERalpha-positive MCF-7 breast cancer cell line, we sought to gain a genome-wide picture of ERalpha-ERRalpha cross-talk using an unbiased microarray approach. In addition to generating a host of novel ERRalpha target genes, this study yielded the surprising result that most ERRalpha-regulated genes are unrelated to estrogen signaling. The relatively small number of genes regulated by both ERalpha and ERRalpha led us to expand our study to the more aggressive and less clinically treatable ERalpha-negative class of breast cancers. In this setting, we found that ERRalpha expression is required for the basal level of expression of many known and novel ERRalpha target genes. Introduction of a small interfering RNA directed to ERRalpha into the highly aggressive breast carcinoma MDA-MB-231 cell line dramatically reduced the migratory potential of these cells. Although stable knockdown of ERRalpha expression in MDA-MB-231 cells had no effect on in vitro cell proliferation, a significant reduction of tumor growth rate was observed when these cells were implanted as xenografts. Our results confirm a role for ERRalpha in breast cancer growth and highlight it as a potential therapeutic target for estrogen receptor-negative breast cancer.

Standard name | STEIN_ESTROGEN_RESPONSE_NOT_VIA_ESRRA
Systematic name | M8583
Organism | Homo sapiens
PMID | 18974123
Authors | Stein RA,Chang CY,Kazmin DA,Way J,Schroeder T,Wergin M,Dewhirst MW,McDonnell DP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by estradiol [PubChem=5757] and not modulated by ESRRA [GeneID=2101] in MCF-7 cells (breast cancer).
Full description | Expression of estrogen-related receptor alpha (ERRalpha) has recently been shown to carry negative prognostic significance in breast and ovarian cancers. The specific role of this orphan nuclear receptor in tumor growth and progression, however, is yet to be fully understood. The significant homology between estrogen receptor alpha (ERalpha) and ERRalpha initially suggested that these receptors may have similar transcriptional targets. Using the well-characterized ERalpha-positive MCF-7 breast cancer cell line, we sought to gain a genome-wide picture of ERalpha-ERRalpha cross-talk using an unbiased microarray approach. In addition to generating a host of novel ERRalpha target genes, this study yielded the surprising result that most ERRalpha-regulated genes are unrelated to estrogen signaling. The relatively small number of genes regulated by both ERalpha and ERRalpha led us to expand our study to the more aggressive and less clinically treatable ERalpha-negative class of breast cancers. In this setting, we found that ERRalpha expression is required for the basal level of expression of many known and novel ERRalpha target genes. Introduction of a small interfering RNA directed to ERRalpha into the highly aggressive breast carcinoma MDA-MB-231 cell line dramatically reduced the migratory potential of these cells. Although stable knockdown of ERRalpha expression in MDA-MB-231 cells had no effect on in vitro cell proliferation, a significant reduction of tumor growth rate was observed when these cells were implanted as xenografts. Our results confirm a role for ERRalpha in breast cancer growth and highlight it as a potential therapeutic target for estrogen receptor-negative breast cancer.

Standard name | SAKAI_CHRONIC_HEPATITIS_VS_LIVER_CANCER_UP
Systematic name | M9224
Organism | Homo sapiens
PMID | 19074895
Authors | Sakai Y,Honda M,Fujinaga H,Tatsumi I,Mizukoshi E,Nakamoto Y,Kaneko S
Category | C2
Sub-category | CGP
Brief description | Selected genes up-regulated in peripheral blood monocytes (PBMC) of patients with hepatocellular carcinoma (HCC) compared to those with chronic hepatitis.
Full description | Hepatocellular carcinoma (HCC) is frequently associated with infiltrating mononuclear inflammatory cells. We performed laser capture microdissection of HCC-infiltrating and noncancerous liver-infiltrating mononuclear inflammatory cells in patients with chronic hepatitis C (CH-C) and examined gene expression profiles. HCC-infiltrating mononuclear inflammatory cells had an expression profile distinct from noncancerous liver-infiltrating mononuclear inflammatory cells; they differed with regard to genes involved in biological processes, such as antigen presentation, ubiquitin-proteasomal proteolysis, and responses to hypoxia and oxidative stress. Immunohistochemical analysis and gene expression databases suggested that the up-regulated genes involved macrophages and Th1 and Th2 CD4 cells. We next examined the gene expression profile of peripheral blood mononuclear cells (PBMC) obtained from CH-C patients with or without HCC. The expression profiles of PBMCs from patients with HCC differed significantly from those of patients without HCC (P < 0.0005). Many of the up-regulated genes in HCC-infiltrating mononuclear inflammatory cells were also differentially expressed by PBMCs of HCC patients. Analysis of the commonly up-regulated or down-regulated genes in HCC-infiltrating mononuclear inflammatory cells and PBMCs of HCC patients showed networks of nucleophosmin, SMAD3, and proliferating cell nuclear antigen that are involved with redox status, the cell cycle, and the proteasome system, along with immunologic genes, suggesting regulation of anticancer immunity. Thus, exploring the gene expression profile of PBMCs may be a surrogate approach for the assessment of local HCC-infiltrating mononuclear inflammatory cells.

Standard name | LOPEZ_EPITHELIOID_MESOTHELIOMA
Systematic name | M409
Organism | Homo sapiens
PMID | 16540645
Authors | López-Ríos F,Chuai S,Flores R,Shimizu S,Ohno T,Wakahara K,Illei PB,Hussain S,Krug L,Zakowski MF,Rusch V,Olshen AB,Ladanyi M
Category | C2
Sub-category | CGP
Brief description | Top 20 genes expressed higher in epithelioid than in sarcomatoid mesothelioma samples.
Full description | Most gene expression profiling studies of mesothelioma have been based on relatively small sample numbers, limiting their statistical power. We did Affymetrix U133A microarray analysis on 99 pleural mesotheliomas, in which multivariate analysis showed advanced-stage, sarcomatous histology and P16/CDKN2A homozygous deletion to be significant independent adverse prognostic factors. Comparison of the expression profiles of epithelioid versus sarcomatous mesotheliomas identified many genes significantly overexpressed among the former, including previously unrecognized ones, such as uroplakins and kallikrein 11, both confirmed by immunohistochemistry. Examination of the gene expression correlates of survival showed that more aggressive mesotheliomas expressed higher levels of Aurora kinases A and B and functionally related genes involved in mitosis and cell cycle control. Independent confirmation of the negative effect of Aurora kinase B was obtained by immunohistochemistry in a separate patient cohort. A role for Aurora kinases in the aggressive behavior of mesotheliomas is of potential clinical interest because of the recent development of small-molecule inhibitors. We then used our data to develop microarray-based predictors of 1 year survival; these achieved a maximal accuracy of 68% in cross-validation. However, this was inferior to prognostic prediction based on standard clinicopathologic variables and P16/CDNK2A status (accuracy, 73%), and adding the microarray model to the latter did not improve overall accuracy. Finally, we evaluated three recently published microarray-based outcome prediction models, but their accuracies ranged from 63% to 67%, consistently lower than reported. Gene expression profiling of mesotheliomas is an important discovery tool, but its power in clinical prognostication has been overestimated.

Standard name | LOPEZ_MESOTHELIOMA_SURVIVAL_OVERALL_UP
Systematic name | M10759
Organism | Homo sapiens
PMID | 16540645
Authors | López-Ríos F,Chuai S,Flores R,Shimizu S,Ohno T,Wakahara K,Illei PB,Hussain S,Krug L,Zakowski MF,Rusch V,Olshen AB,Ladanyi M
Category | C2
Sub-category | CGP
Brief description | Top genes associated with favorable overall survival of mesothelioma patients after surgery.
Full description | Most gene expression profiling studies of mesothelioma have been based on relatively small sample numbers, limiting their statistical power. We did Affymetrix U133A microarray analysis on 99 pleural mesotheliomas, in which multivariate analysis showed advanced-stage, sarcomatous histology and P16/CDKN2A homozygous deletion to be significant independent adverse prognostic factors. Comparison of the expression profiles of epithelioid versus sarcomatous mesotheliomas identified many genes significantly overexpressed among the former, including previously unrecognized ones, such as uroplakins and kallikrein 11, both confirmed by immunohistochemistry. Examination of the gene expression correlates of survival showed that more aggressive mesotheliomas expressed higher levels of Aurora kinases A and B and functionally related genes involved in mitosis and cell cycle control. Independent confirmation of the negative effect of Aurora kinase B was obtained by immunohistochemistry in a separate patient cohort. A role for Aurora kinases in the aggressive behavior of mesotheliomas is of potential clinical interest because of the recent development of small-molecule inhibitors. We then used our data to develop microarray-based predictors of 1 year survival; these achieved a maximal accuracy of 68% in cross-validation. However, this was inferior to prognostic prediction based on standard clinicopathologic variables and P16/CDNK2A status (accuracy, 73%), and adding the microarray model to the latter did not improve overall accuracy. Finally, we evaluated three recently published microarray-based outcome prediction models, but their accuracies ranged from 63% to 67%, consistently lower than reported. Gene expression profiling of mesotheliomas is an important discovery tool, but its power in clinical prognostication has been overestimated.

Standard name | LOPEZ_MESOTHELIOMA_SURVIVAL_OVERALL_DN
Systematic name | M16003
Organism | Homo sapiens
PMID | 16540645
Authors | López-Ríos F,Chuai S,Flores R,Shimizu S,Ohno T,Wakahara K,Illei PB,Hussain S,Krug L,Zakowski MF,Rusch V,Olshen AB,Ladanyi M
Category | C2
Sub-category | CGP
Brief description | Top genes associated with unfavorable overall survival of mesothelioma patients after surgery.
Full description | Most gene expression profiling studies of mesothelioma have been based on relatively small sample numbers, limiting their statistical power. We did Affymetrix U133A microarray analysis on 99 pleural mesotheliomas, in which multivariate analysis showed advanced-stage, sarcomatous histology and P16/CDKN2A homozygous deletion to be significant independent adverse prognostic factors. Comparison of the expression profiles of epithelioid versus sarcomatous mesotheliomas identified many genes significantly overexpressed among the former, including previously unrecognized ones, such as uroplakins and kallikrein 11, both confirmed by immunohistochemistry. Examination of the gene expression correlates of survival showed that more aggressive mesotheliomas expressed higher levels of Aurora kinases A and B and functionally related genes involved in mitosis and cell cycle control. Independent confirmation of the negative effect of Aurora kinase B was obtained by immunohistochemistry in a separate patient cohort. A role for Aurora kinases in the aggressive behavior of mesotheliomas is of potential clinical interest because of the recent development of small-molecule inhibitors. We then used our data to develop microarray-based predictors of 1 year survival; these achieved a maximal accuracy of 68% in cross-validation. However, this was inferior to prognostic prediction based on standard clinicopathologic variables and P16/CDNK2A status (accuracy, 73%), and adding the microarray model to the latter did not improve overall accuracy. Finally, we evaluated three recently published microarray-based outcome prediction models, but their accuracies ranged from 63% to 67%, consistently lower than reported. Gene expression profiling of mesotheliomas is an important discovery tool, but its power in clinical prognostication has been overestimated.

Standard name | LOPEZ_MESOTHELIOMA_SURVIVAL_UP
Systematic name | M16161
Organism | Homo sapiens
PMID | 16540645
Authors | López-Ríos F,Chuai S,Flores R,Shimizu S,Ohno T,Wakahara K,Illei PB,Hussain S,Krug L,Zakowski MF,Rusch V,Olshen AB,Ladanyi M
Category | C2
Sub-category | CGP
Brief description | Top genes associated with favorable survival after surgery of patients with epithelioid mesothelioma.
Full description | Most gene expression profiling studies of mesothelioma have been based on relatively small sample numbers, limiting their statistical power. We did Affymetrix U133A microarray analysis on 99 pleural mesotheliomas, in which multivariate analysis showed advanced-stage, sarcomatous histology and P16/CDKN2A homozygous deletion to be significant independent adverse prognostic factors. Comparison of the expression profiles of epithelioid versus sarcomatous mesotheliomas identified many genes significantly overexpressed among the former, including previously unrecognized ones, such as uroplakins and kallikrein 11, both confirmed by immunohistochemistry. Examination of the gene expression correlates of survival showed that more aggressive mesotheliomas expressed higher levels of Aurora kinases A and B and functionally related genes involved in mitosis and cell cycle control. Independent confirmation of the negative effect of Aurora kinase B was obtained by immunohistochemistry in a separate patient cohort. A role for Aurora kinases in the aggressive behavior of mesotheliomas is of potential clinical interest because of the recent development of small-molecule inhibitors. We then used our data to develop microarray-based predictors of 1 year survival; these achieved a maximal accuracy of 68% in cross-validation. However, this was inferior to prognostic prediction based on standard clinicopathologic variables and P16/CDNK2A status (accuracy, 73%), and adding the microarray model to the latter did not improve overall accuracy. Finally, we evaluated three recently published microarray-based outcome prediction models, but their accuracies ranged from 63% to 67%, consistently lower than reported. Gene expression profiling of mesotheliomas is an important discovery tool, but its power in clinical prognostication has been overestimated.

Standard name | LOPEZ_MESOTHELIOMA_SURVIVAL_DN
Systematic name | M10263
Organism | Homo sapiens
PMID | 16540645
Authors | López-Ríos F,Chuai S,Flores R,Shimizu S,Ohno T,Wakahara K,Illei PB,Hussain S,Krug L,Zakowski MF,Rusch V,Olshen AB,Ladanyi M
Category | C2
Sub-category | CGP
Brief description | Top genes associated with unfavorable survival after surgery of patients with epithelioid mesothelioma.
Full description | Most gene expression profiling studies of mesothelioma have been based on relatively small sample numbers, limiting their statistical power. We did Affymetrix U133A microarray analysis on 99 pleural mesotheliomas, in which multivariate analysis showed advanced-stage, sarcomatous histology and P16/CDKN2A homozygous deletion to be significant independent adverse prognostic factors. Comparison of the expression profiles of epithelioid versus sarcomatous mesotheliomas identified many genes significantly overexpressed among the former, including previously unrecognized ones, such as uroplakins and kallikrein 11, both confirmed by immunohistochemistry. Examination of the gene expression correlates of survival showed that more aggressive mesotheliomas expressed higher levels of Aurora kinases A and B and functionally related genes involved in mitosis and cell cycle control. Independent confirmation of the negative effect of Aurora kinase B was obtained by immunohistochemistry in a separate patient cohort. A role for Aurora kinases in the aggressive behavior of mesotheliomas is of potential clinical interest because of the recent development of small-molecule inhibitors. We then used our data to develop microarray-based predictors of 1 year survival; these achieved a maximal accuracy of 68% in cross-validation. However, this was inferior to prognostic prediction based on standard clinicopathologic variables and P16/CDNK2A status (accuracy, 73%), and adding the microarray model to the latter did not improve overall accuracy. Finally, we evaluated three recently published microarray-based outcome prediction models, but their accuracies ranged from 63% to 67%, consistently lower than reported. Gene expression profiling of mesotheliomas is an important discovery tool, but its power in clinical prognostication has been overestimated.

Standard name | KORKOLA_CORRELATED_WITH_POU5F1
Systematic name | M4967
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Genes whose expression pattern in adult male germ cell tumors (GCT) correlates with POU5F1 [GeneID=5460].
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | KORKOLA_EMBRYONIC_CARCINOMA_VS_SEMINOMA_UP
Systematic name | M7346
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Top 25 most highly expressed genes in embryonic carcinoma relative to seminoma tumors.
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | KORKOLA_EMBRYONIC_CARCINOMA_VS_SEMINOMA_DN
Systematic name | M15380
Organism | Homo sapiens
PMID | 16424014
Authors | Korkola JE,Houldsworth J,Chadalavada RS,Olshen AB,Dobrzynski D,Reuter VE,Bosl GJ,Chaganti RS
Category | C2
Sub-category | CGP
Brief description | Top 25 most highly expressed genes in seminoma relative to embryonic carcinoma tumors.
Full description | Adult male germ cell tumors (GCTs) comprise distinct groups: seminomas and nonseminomas, which include pluripotent embryonal carcinomas as well as other histologic subtypes exhibiting various stages of differentiation. Almost all GCTs show 12p gain, but the target genes have not been clearly defined. To identify 12p target genes, we examined Affymetrix (Santa Clara, CA) U133A+B microarray ( approximately 83% coverage of 12p genes) expression profiles of 17 seminomas, 84 nonseminoma GCTs, and 5 normal testis samples. Seventy-three genes on 12p were significantly overexpressed, including GLUT3 and REA (overexpressed in all GCTs) and CCND2 and FLJ22028 (overexpressed in all GCTs, except choriocarcinomas). We characterized a 200-kb gene cluster at 12p13.31 that exhibited coordinated overexpression in embryonal carcinomas and seminomas, which included the known stem cell genes NANOG, STELLA, and GDF3 and two previously uncharacterized genes. A search for other coordinately regulated genomic clusters of stem cell genes did not reveal any genomic regions similar to that at 12p13.31. Comparison of embryonal carcinoma with seminomas revealed relative overexpression of several stem cell-associated genes in embryonal carcinoma, including several core stemness genes (EBAF, TDGF1, and SOX2) and several downstream targets of WNT, NODAL, and FGF signaling (FGF4, NODAL, and ZFP42). Our results indicate that 12p gain is a functionally relevant change leading to activation of proliferation and reestablishment/maintenance of stem cell function through activation of key stem cell genes. Furthermore, the differential expression of core stem cell genes may explain the differences in pluripotency between embryonal carcinomas and seminomas.

Standard name | KOBAYASHI_EGFR_SIGNALING_24HR_UP
Systematic name | M10290
Organism | Homo sapiens
PMID | 17145885
Authors | Kobayashi S,Shimamura T,Monti S,Steidl U,Hetherington CJ,Lowell AM,Golub T,Meyerson M,Tenen DG,Shapiro GI,Halmos B
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in H1975 cells (non-small cell lung cancer, NSCLC) resistant to gefitinib [PubChem=123631] after treatment with EGFR inhibitor CL-387785 [PubChem=2776] for 24h.
Full description | Activating mutations in the epidermal growth factor receptor (EGFR) tyrosine kinase domain determine responsiveness to EGFR tyrosine kinase inhibitors in patients with advanced non-small cell lung cancer (NSCLC). The modulation of transcriptional pathways by mutant EGFR signaling is not fully understood. Previously, we and others identified a single base pair change leading to a threonine to methionine (T790M) amino acid alteration in the ATP-binding pocket of the EGFR as a common mechanism of acquired resistance. The gefitinib-resistant, T790M-mutant H1975 NSCLC cell line undergoes prominent growth arrest and apoptosis when treated with the irreversible EGFR inhibitor, CL-387,785. We did a transcriptional profiling study of mutant EGFR target genes that are differentially expressed in the resistant gefitinib-treated and the sensitive CL387,785-treated H1975 cells to identify the pivotal transcriptional changes in NSCLC with EGFR-activating mutations. We identified a small subset of early gene changes, including significant reduction of cyclin D1 as a result of EGFR inhibition by CL-387,785 but not by gefitinib. The reduction in cyclin D1 transcription was associated with subsequent suppression of E2F-responsive genes, consistent with proliferation arrest. Furthermore, cyclin D1 expression was higher in EGFR-mutant lung cancer cells compared with cells with wild-type EGFR. EGFR-mutant cells were routinely sensitive to the cyclin-dependent kinase inhibitor flavopiridol, confirming the functional relevance of the cyclin D axis. These studies suggest that cyclin D1 may contribute to the emergence of EGFR-driven tumorigenesis and can be an alternative target of therapy.

Standard name | KOBAYASHI_EGFR_SIGNALING_24HR_DN
Systematic name | M16010
Organism | Homo sapiens
PMID | 17145885
Authors | Kobayashi S,Shimamura T,Monti S,Steidl U,Hetherington CJ,Lowell AM,Golub T,Meyerson M,Tenen DG,Shapiro GI,Halmos B
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in H1975 cells (non-small cell lung cancer, NSCLC) resistant to gefitinib [PubChem=123631] after treatment with EGFR inhibitor CL-387785 [PubChem=2776] for 24h.
Full description | Activating mutations in the epidermal growth factor receptor (EGFR) tyrosine kinase domain determine responsiveness to EGFR tyrosine kinase inhibitors in patients with advanced non-small cell lung cancer (NSCLC). The modulation of transcriptional pathways by mutant EGFR signaling is not fully understood. Previously, we and others identified a single base pair change leading to a threonine to methionine (T790M) amino acid alteration in the ATP-binding pocket of the EGFR as a common mechanism of acquired resistance. The gefitinib-resistant, T790M-mutant H1975 NSCLC cell line undergoes prominent growth arrest and apoptosis when treated with the irreversible EGFR inhibitor, CL-387,785. We did a transcriptional profiling study of mutant EGFR target genes that are differentially expressed in the resistant gefitinib-treated and the sensitive CL387,785-treated H1975 cells to identify the pivotal transcriptional changes in NSCLC with EGFR-activating mutations. We identified a small subset of early gene changes, including significant reduction of cyclin D1 as a result of EGFR inhibition by CL-387,785 but not by gefitinib. The reduction in cyclin D1 transcription was associated with subsequent suppression of E2F-responsive genes, consistent with proliferation arrest. Furthermore, cyclin D1 expression was higher in EGFR-mutant lung cancer cells compared with cells with wild-type EGFR. EGFR-mutant cells were routinely sensitive to the cyclin-dependent kinase inhibitor flavopiridol, confirming the functional relevance of the cyclin D axis. These studies suggest that cyclin D1 may contribute to the emergence of EGFR-driven tumorigenesis and can be an alternative target of therapy.

Standard name | FOURNIER_ACINAR_DEVELOPMENT_LATE_2
Systematic name | M4077
Organism | Homo sapiens
PMID | 16849555
Authors | Fournier MV,Martin KJ,Kenny PA,Xhaja K,Bosch I,Yaswen P,Bissell MJ
Category | C2
Sub-category | CGP
Brief description | Genes identified by method 2 as coordinately down-regulated late in HMEC cells (mammary epithelium) during acinar development in vitro.
Full description | Nonmalignant human mammary epithelial cells (HMEC) seeded in laminin-rich extracellular matrix (lrECM) form polarized acini and, in doing so, transit from a disorganized proliferating state to an organized growth-arrested state. We hypothesized that the gene expression pattern of organized and growth-arrested HMECs would share similarities with breast tumors with good prognoses. Using Affymetrix HG-U133A microarrays, we analyzed the expression of 22,283 gene transcripts in 184 (finite life span) and HMT3522 S1 (immortal nonmalignant) HMECs on successive days after seeding in a lrECM assay. Both HMECs underwent growth arrest in G0-G1 and differentiated into polarized acini between days 5 and 7. We identified gene expression changes with the same temporal pattern in both lines and examined the expression of these genes in a previously published panel of microarray data for 295 breast cancer samples. We show that genes that are significantly lower in the organized, growth-arrested HMEC than in their proliferating counterparts can be used to classify breast cancer patients into poor and good prognosis groups with high accuracy. This study represents a novel unsupervised approach to identifying breast cancer markers that may be of use clinically.

Standard name | BOYLAN_MULTIPLE_MYELOMA_PCA1_UP
Systematic name | M9399
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Top up-regulated genes from principal component 1 (PCA1) which captures variation between normal plasma cells and tumors arising from aberrant expression of BCL2L1 and MYC [GeneID=598;4609].
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_PCA1_DN
Systematic name | M1038
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Top down-regulated genes from principal component 1 (PCA1) which captures variation between normal plasma cells and tumors arising from aberrant expression of BCL2L1 and MYC [GeneID=598;4609].
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_PCA3_UP
Systematic name | M18227
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Top up-regulated genes from principal component 3 (PCA3) which captures variation among different plasma cell tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609].
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | BOYLAN_MULTIPLE_MYELOMA_PCA3_DN
Systematic name | M9544
Organism | Mus musculus
PMID | 17483317
Authors | Boylan KL,Gosse MA,Staggs SE,Janz S,Grindle S,Kansas GS,Van Ness BG
Category | C2
Sub-category | CGP
Brief description | Top down-regulated genes from principal component 3 (PCA3) which captures variation among different plasma cell tumors arising from overexpression of BCL2L1 and MYC [GeneID=598;4609].
Full description | Multiple myeloma is an incurable plasma cell malignancy for which existing animal models are limited. We have previously shown that the targeted expression of the transgenes c-Myc and Bcl-X(L) in murine plasma cells produces malignancy that displays features of human myeloma, such as localization of tumor cells to the bone marrow and lytic bone lesions. We have isolated and characterized in vitro cultures and adoptive transfers of tumors from Bcl-xl/Myc transgenic mice. Tumors have a plasmablastic morphology and variable expression of CD138, CD45, CD38, and CD19. Spectral karyotyping analysis of metaphase chromosomes from primary tumor cell cultures shows that the Bcl-xl/Myc tumors contain a variety of chromosomal abnormalities, including trisomies, translocations, and deletions. The most frequently aberrant chromosomes are 12 and 16. Three sites for recurring translocations were also identified on chromosomes 4D, 12F, and 16C. Gene expression profiling was used to identify differences in gene expression between tumor cells and normal plasma cells (NPC) and to cluster the tumors into two groups (tumor groups C and D), with distinct gene expression profiles. Four hundred and ninety-five genes were significantly different between both tumor groups and NPCs, whereas 124 genes were uniquely different from NPCs in tumor group C and 204 genes were uniquely different from NPCs in tumor group D. Similar to human myeloma, the cyclin D genes are differentially dysregulated in the mouse tumor groups. These data suggest the Bcl-xl/Myc tumors are similar to a subset of plasmablastic human myelomas and provide insight into the specific genes and pathways underlying the human disease.

Standard name | HOSHIDA_LIVER_CANCER_SUBCLASS_S1
Systematic name | M5311
Organism | Homo sapiens
PMID | 19723656
Authors | Hoshida Y,Nijman SM,Kobayashi M,Chan JA,Brunet JP,Chiang DY,Villanueva A,Newell P,Ikeda K,Hashimoto M,Watanabe G,Gabriel S,Friedman SL,Kumada H,Llovet JM,Golub TR
Category | C2
Sub-category | CGP
Brief description | Genes from 'subtype S1' signature of hepatocellular carcinoma (HCC): aberrant activation of the WNT signaling pathway.
Full description | Hepatocellular carcinoma (HCC) is a highly heterogeneous disease, and prior attempts to develop genomic-based classification for HCC have yielded highly divergent results, indicating difficulty in identifying unified molecular anatomy. We performed a meta-analysis of gene expression profiles in data sets from eight independent patient cohorts across the world. In addition, aiming to establish the real world applicability of a classification system, we profiled 118 formalin-fixed, paraffin-embedded tissues from an additional patient cohort. A total of 603 patients were analyzed, representing the major etiologies of HCC (hepatitis B and C) collected from Western and Eastern countries. We observed three robust HCC subclasses (termed S1, S2, and S3), each correlated with clinical parameters such as tumor size, extent of cellular differentiation, and serum alpha-fetoprotein levels. An analysis of the components of the signatures indicated that S1 reflected aberrant activation of the WNT signaling pathway, S2 was characterized by proliferation as well as MYC and AKT activation, and S3 was associated with hepatocyte differentiation. Functional studies indicated that the WNT pathway activation signature characteristic of S1 tumors was not simply the result of beta-catenin mutation but rather was the result of transforming growth factor-beta activation, thus representing a new mechanism of WNT pathway activation in HCC. These experiments establish the first consensus classification framework for HCC based on gene expression profiles and highlight the power of integrating multiple data sets to define a robust molecular taxonomy of the disease.

Standard name | HOSHIDA_LIVER_CANCER_SUBCLASS_S2
Systematic name | M7995
Organism | Homo sapiens
PMID | 19723656
Authors | Hoshida Y,Nijman SM,Kobayashi M,Chan JA,Brunet JP,Chiang DY,Villanueva A,Newell P,Ikeda K,Hashimoto M,Watanabe G,Gabriel S,Friedman SL,Kumada H,Llovet JM,Golub TR
Category | C2
Sub-category | CGP
Brief description | Genes from 'subtype S2' signature of hepatocellular carcinoma (HCC): proliferation, MYC and AKT1 [GeneID=4609;207] activation.
Full description | Hepatocellular carcinoma (HCC) is a highly heterogeneous disease, and prior attempts to develop genomic-based classification for HCC have yielded highly divergent results, indicating difficulty in identifying unified molecular anatomy. We performed a meta-analysis of gene expression profiles in data sets from eight independent patient cohorts across the world. In addition, aiming to establish the real world applicability of a classification system, we profiled 118 formalin-fixed, paraffin-embedded tissues from an additional patient cohort. A total of 603 patients were analyzed, representing the major etiologies of HCC (hepatitis B and C) collected from Western and Eastern countries. We observed three robust HCC subclasses (termed S1, S2, and S3), each correlated with clinical parameters such as tumor size, extent of cellular differentiation, and serum alpha-fetoprotein levels. An analysis of the components of the signatures indicated that S1 reflected aberrant activation of the WNT signaling pathway, S2 was characterized by proliferation as well as MYC and AKT activation, and S3 was associated with hepatocyte differentiation. Functional studies indicated that the WNT pathway activation signature characteristic of S1 tumors was not simply the result of beta-catenin mutation but rather was the result of transforming growth factor-beta activation, thus representing a new mechanism of WNT pathway activation in HCC. These experiments establish the first consensus classification framework for HCC based on gene expression profiles and highlight the power of integrating multiple data sets to define a robust molecular taxonomy of the disease. [Cancer Res 2009;69(18):7385-92].

Standard name | HOSHIDA_LIVER_CANCER_SUBCLASS_S3
Systematic name | M1286
Organism | Homo sapiens
PMID | 19723656
Authors | Hoshida Y,Nijman SM,Kobayashi M,Chan JA,Brunet JP,Chiang DY,Villanueva A,Newell P,Ikeda K,Hashimoto M,Watanabe G,Gabriel S,Friedman SL,Kumada H,Llovet JM,Golub TR
Category | C2
Sub-category | CGP
Brief description | Genes from 'subtype S3' signature of hepatocellular carcinoma (HCC): hepatocyte differentiation.
Full description | Hepatocellular carcinoma (HCC) is a highly heterogeneous disease, and prior attempts to develop genomic-based classification for HCC have yielded highly divergent results, indicating difficulty in identifying unified molecular anatomy. We performed a meta-analysis of gene expression profiles in data sets from eight independent patient cohorts across the world. In addition, aiming to establish the real world applicability of a classification system, we profiled 118 formalin-fixed, paraffin-embedded tissues from an additional patient cohort. A total of 603 patients were analyzed, representing the major etiologies of HCC (hepatitis B and C) collected from Western and Eastern countries. We observed three robust HCC subclasses (termed S1, S2, and S3), each correlated with clinical parameters such as tumor size, extent of cellular differentiation, and serum alpha-fetoprotein levels. An analysis of the components of the signatures indicated that S1 reflected aberrant activation of the WNT signaling pathway, S2 was characterized by proliferation as well as MYC and AKT activation, and S3 was associated with hepatocyte differentiation. Functional studies indicated that the WNT pathway activation signature characteristic of S1 tumors was not simply the result of beta-catenin mutation but rather was the result of transforming growth factor-beta activation, thus representing a new mechanism of WNT pathway activation in HCC. These experiments establish the first consensus classification framework for HCC based on gene expression profiles and highlight the power of integrating multiple data sets to define a robust molecular taxonomy of the disease. [Cancer Res 2009;69(18):7385-92].

Standard name | PYEON_CANCER_HEAD_AND_NECK_VS_CERVICAL_UP
Systematic name | M13736
Organism | Homo sapiens
PMID | 17510386
Authors | Pyeon D,Newton MA,Lambert PF,den Boon JA,Sengupta S,Marsit CJ,Woodworth CD,Connor JP,Haugen TH,Smith EM,Kelsey KT,Turek LP,Ahlquist P
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in head and neck cancer compared to cervical carcinoma samples.
Full description | Human papillomaviruses (HPV) are associated with nearly all cervical cancers, 20% to 30% of head and neck cancers (HNC), and other cancers. Because HNCs also arise in HPV-negative patients, this type of cancer provides unique opportunities to define similarities and differences of HPV-positive versus HPV-negative cancers arising in the same tissue. Here, we describe genome-wide expression profiling of 84 HNCs, cervical cancers, and site-matched normal epithelial samples in which we used laser capture microdissection to enrich samples for tumor-derived versus normal epithelial cells. This analysis revealed that HPV(+) HNCs and cervical cancers differed in their patterns of gene expression yet shared many changes compared with HPV(-) HNCs. Some of these shared changes were predicted, but many others were not. Notably, HPV(+) HNCs and cervical cancers were found to be up-regulated in their expression of a distinct and larger subset of cell cycle genes than that observed in HPV(-) HNC. Moreover, HPV(+) cancers overexpressed testis-specific genes that are normally expressed only in meiotic cells. Many, although not all, of the hallmark differences between HPV(+) HNC and HPV(-) HNC were a direct consequence of HPV and in particular the viral E6 and E7 oncogenes. This included a novel association of HPV oncogenes with testis-specific gene expression. These findings in primary human tumors provide novel biomarkers for early detection of HPV(+) and HPV(-) cancers, and emphasize the potential value of targeting E6 and E7 function, alone or combined with radiation and/or traditional chemotherapy, in the treatment of HPV(+) cancers.

Standard name | PYEON_CANCER_HEAD_AND_NECK_VS_CERVICAL_DN
Systematic name | M5126
Organism | Homo sapiens
PMID | 17510386
Authors | Pyeon D,Newton MA,Lambert PF,den Boon JA,Sengupta S,Marsit CJ,Woodworth CD,Connor JP,Haugen TH,Smith EM,Kelsey KT,Turek LP,Ahlquist P
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in head and neck cancer compared to cervical carcinoma samples.
Full description | Human papillomaviruses (HPV) are associated with nearly all cervical cancers, 20% to 30% of head and neck cancers (HNC), and other cancers. Because HNCs also arise in HPV-negative patients, this type of cancer provides unique opportunities to define similarities and differences of HPV-positive versus HPV-negative cancers arising in the same tissue. Here, we describe genome-wide expression profiling of 84 HNCs, cervical cancers, and site-matched normal epithelial samples in which we used laser capture microdissection to enrich samples for tumor-derived versus normal epithelial cells. This analysis revealed that HPV(+) HNCs and cervical cancers differed in their patterns of gene expression yet shared many changes compared with HPV(-) HNCs. Some of these shared changes were predicted, but many others were not. Notably, HPV(+) HNCs and cervical cancers were found to be up-regulated in their expression of a distinct and larger subset of cell cycle genes than that observed in HPV(-) HNC. Moreover, HPV(+) cancers overexpressed testis-specific genes that are normally expressed only in meiotic cells. Many, although not all, of the hallmark differences between HPV(+) HNC and HPV(-) HNC were a direct consequence of HPV and in particular the viral E6 and E7 oncogenes. This included a novel association of HPV oncogenes with testis-specific gene expression. These findings in primary human tumors provide novel biomarkers for early detection of HPV(+) and HPV(-) cancers, and emphasize the potential value of targeting E6 and E7 function, alone or combined with radiation and/or traditional chemotherapy, in the treatment of HPV(+) cancers.

Standard name | CAIRO_HEPATOBLASTOMA_UP
Systematic name | M14601
Organism | Homo sapiens
PMID | 19061838
Authors | Cairo S,Armengol C,Reyniès De A,Wei Y,Thomas E,Renard CA,Goga A,Balakrishnan A,Semeraro M,Gresh L,Pontoglio M,Strick-Marchand H,Levillayer F,Nouet Y,Rickman D,Gauthier F,Branchereau S,Brugières L,Laithier V,Bouvier R,Boman F,Basso G,Michiels JF,Hofman P,Arbez-Gindre F,Jouan H,Rousselet-Chapeau MC,Berrebi D,Marcellin L,Plenat F,Zachar D,Joubert M,Selves J,Pasquier D,Bioulac-Sage P,Grotzer M,Childs M,Fabre M,Buendia MA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hepatoblastoma samples compared to normal liver tissue.
Full description | Hepatoblastoma, the most common pediatric liver cancer, is tightly linked to excessive Wnt/beta-catenin signaling. Here, we used microarray analysis to identify two tumor subclasses resembling distinct phases of liver development and a discriminating 16-gene signature. beta-catenin activated different transcriptional programs in the two tumor types, with distinctive expression of hepatic stem/progenitor markers in immature tumors. This highly proliferating subclass was typified by gains of chromosomes 8q and 2p and upregulated Myc signaling. Myc-induced hepatoblastoma-like tumors in mice strikingly resembled the human immature subtype, and Myc downregulation in hepatoblastoma cells impaired tumorigenesis in vivo. Remarkably, the 16-gene signature discriminated invasive and metastatic hepatoblastomas and predicted prognosis with high accuracy.

Standard name | CAIRO_HEPATOBLASTOMA_DN
Systematic name | M13449
Organism | Homo sapiens
PMID | 19061838
Authors | Cairo S,Armengol C,Reyniès De A,Wei Y,Thomas E,Renard CA,Goga A,Balakrishnan A,Semeraro M,Gresh L,Pontoglio M,Strick-Marchand H,Levillayer F,Nouet Y,Rickman D,Gauthier F,Branchereau S,Brugières L,Laithier V,Bouvier R,Boman F,Basso G,Michiels JF,Hofman P,Arbez-Gindre F,Jouan H,Rousselet-Chapeau MC,Berrebi D,Marcellin L,Plenat F,Zachar D,Joubert M,Selves J,Pasquier D,Bioulac-Sage P,Grotzer M,Childs M,Fabre M,Buendia MA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hepatoblastoma samples compared to normal liver tissue.
Full description | Hepatoblastoma, the most common pediatric liver cancer, is tightly linked to excessive Wnt/beta-catenin signaling. Here, we used microarray analysis to identify two tumor subclasses resembling distinct phases of liver development and a discriminating 16-gene signature. beta-catenin activated different transcriptional programs in the two tumor types, with distinctive expression of hepatic stem/progenitor markers in immature tumors. This highly proliferating subclass was typified by gains of chromosomes 8q and 2p and upregulated Myc signaling. Myc-induced hepatoblastoma-like tumors in mice strikingly resembled the human immature subtype, and Myc downregulation in hepatoblastoma cells impaired tumorigenesis in vivo. Remarkably, the 16-gene signature discriminated invasive and metastatic hepatoblastomas and predicted prognosis with high accuracy.

Standard name | CAIRO_HEPATOBLASTOMA_CLASSES_UP
Systematic name | M4772
Organism | Homo sapiens
PMID | 19061838
Authors | Cairo S,Armengol C,Reyniès De A,Wei Y,Thomas E,Renard CA,Goga A,Balakrishnan A,Semeraro M,Gresh L,Pontoglio M,Strick-Marchand H,Levillayer F,Nouet Y,Rickman D,Gauthier F,Branchereau S,Brugières L,Laithier V,Bouvier R,Boman F,Basso G,Michiels JF,Hofman P,Arbez-Gindre F,Jouan H,Rousselet-Chapeau MC,Berrebi D,Marcellin L,Plenat F,Zachar D,Joubert M,Selves J,Pasquier D,Bioulac-Sage P,Grotzer M,Childs M,Fabre M,Buendia MA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in robust Cluster 2 (rC2) of hepatoblastoma samples compared to those in the robust Cluster 1 (rC1).
Full description | Hepatoblastoma, the most common pediatric liver cancer, is tightly linked to excessive Wnt/beta-catenin signaling. Here, we used microarray analysis to identify two tumor subclasses resembling distinct phases of liver development and a discriminating 16-gene signature. beta-catenin activated different transcriptional programs in the two tumor types, with distinctive expression of hepatic stem/progenitor markers in immature tumors. This highly proliferating subclass was typified by gains of chromosomes 8q and 2p and upregulated Myc signaling. Myc-induced hepatoblastoma-like tumors in mice strikingly resembled the human immature subtype, and Myc downregulation in hepatoblastoma cells impaired tumorigenesis in vivo. Remarkably, the 16-gene signature discriminated invasive and metastatic hepatoblastomas and predicted prognosis with high accuracy.

Standard name | CAIRO_HEPATOBLASTOMA_CLASSES_DN
Systematic name | M12176
Organism | Homo sapiens
PMID | 19061838
Authors | Cairo S,Armengol C,Reyniès De A,Wei Y,Thomas E,Renard CA,Goga A,Balakrishnan A,Semeraro M,Gresh L,Pontoglio M,Strick-Marchand H,Levillayer F,Nouet Y,Rickman D,Gauthier F,Branchereau S,Brugières L,Laithier V,Bouvier R,Boman F,Basso G,Michiels JF,Hofman P,Arbez-Gindre F,Jouan H,Rousselet-Chapeau MC,Berrebi D,Marcellin L,Plenat F,Zachar D,Joubert M,Selves J,Pasquier D,Bioulac-Sage P,Grotzer M,Childs M,Fabre M,Buendia MA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in robust Cluster 2 (rC2) of hepatoblastoma samples compared to those in the robust Cluster 1 (rC1).
Full description | Hepatoblastoma, the most common pediatric liver cancer, is tightly linked to excessive Wnt/beta-catenin signaling. Here, we used microarray analysis to identify two tumor subclasses resembling distinct phases of liver development and a discriminating 16-gene signature. beta-catenin activated different transcriptional programs in the two tumor types, with distinctive expression of hepatic stem/progenitor markers in immature tumors. This highly proliferating subclass was typified by gains of chromosomes 8q and 2p and upregulated Myc signaling. Myc-induced hepatoblastoma-like tumors in mice strikingly resembled the human immature subtype, and Myc downregulation in hepatoblastoma cells impaired tumorigenesis in vivo. Remarkably, the 16-gene signature discriminated invasive and metastatic hepatoblastomas and predicted prognosis with high accuracy.

Standard name | CAIRO_LIVER_DEVELOPMENT_UP
Systematic name | M17163
Organism | Mus musculus
PMID | 19061838
Authors | Cairo S,Armengol C,Reyniès De A,Wei Y,Thomas E,Renard CA,Goga A,Balakrishnan A,Semeraro M,Gresh L,Pontoglio M,Strick-Marchand H,Levillayer F,Nouet Y,Rickman D,Gauthier F,Branchereau S,Brugières L,Laithier V,Bouvier R,Boman F,Basso G,Michiels JF,Hofman P,Arbez-Gindre F,Jouan H,Rousselet-Chapeau MC,Berrebi D,Marcellin L,Plenat F,Zachar D,Joubert M,Selves J,Pasquier D,Bioulac-Sage P,Grotzer M,Childs M,Fabre M,Buendia MA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated at early fetal liver stage (embryonic days E11.5 - E12.5) compared to the late fetal liver stage (embryonic days E14.5 - E16.5).
Full description | Hepatoblastoma, the most common pediatric liver cancer, is tightly linked to excessive Wnt/beta-catenin signaling. Here, we used microarray analysis to identify two tumor subclasses resembling distinct phases of liver development and a discriminating 16-gene signature. beta-catenin activated different transcriptional programs in the two tumor types, with distinctive expression of hepatic stem/progenitor markers in immature tumors. This highly proliferating subclass was typified by gains of chromosomes 8q and 2p and upregulated Myc signaling. Myc-induced hepatoblastoma-like tumors in mice strikingly resembled the human immature subtype, and Myc downregulation in hepatoblastoma cells impaired tumorigenesis in vivo. Remarkably, the 16-gene signature discriminated invasive and metastatic hepatoblastomas and predicted prognosis with high accuracy.

Standard name | CAIRO_LIVER_DEVELOPMENT_DN
Systematic name | M6175
Organism | Mus musculus
PMID | 19061838
Authors | Cairo S,Armengol C,Reyniès De A,Wei Y,Thomas E,Renard CA,Goga A,Balakrishnan A,Semeraro M,Gresh L,Pontoglio M,Strick-Marchand H,Levillayer F,Nouet Y,Rickman D,Gauthier F,Branchereau S,Brugières L,Laithier V,Bouvier R,Boman F,Basso G,Michiels JF,Hofman P,Arbez-Gindre F,Jouan H,Rousselet-Chapeau MC,Berrebi D,Marcellin L,Plenat F,Zachar D,Joubert M,Selves J,Pasquier D,Bioulac-Sage P,Grotzer M,Childs M,Fabre M,Buendia MA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated at early fetal liver stage (embryonic days E11.5 - E12.5) compared to the late fetal liver stage (embryonic days E14.5 - E16.5).
Full description | Hepatoblastoma, the most common pediatric liver cancer, is tightly linked to excessive Wnt/beta-catenin signaling. Here, we used microarray analysis to identify two tumor subclasses resembling distinct phases of liver development and a discriminating 16-gene signature. beta-catenin activated different transcriptional programs in the two tumor types, with distinctive expression of hepatic stem/progenitor markers in immature tumors. This highly proliferating subclass was typified by gains of chromosomes 8q and 2p and upregulated Myc signaling. Myc-induced hepatoblastoma-like tumors in mice strikingly resembled the human immature subtype, and Myc downregulation in hepatoblastoma cells impaired tumorigenesis in vivo. Remarkably, the 16-gene signature discriminated invasive and metastatic hepatoblastomas and predicted prognosis with high accuracy.

Standard name | CAIRO_HEPATOBLASTOMA_POOR_SURVIVAL
Systematic name | M2650
Organism | Homo sapiens
PMID | 19061838
Authors | Cairo S,Armengol C,Reyniès De A,Wei Y,Thomas E,Renard CA,Goga A,Balakrishnan A,Semeraro M,Gresh L,Pontoglio M,Strick-Marchand H,Levillayer F,Nouet Y,Rickman D,Gauthier F,Branchereau S,Brugières L,Laithier V,Bouvier R,Boman F,Basso G,Michiels JF,Hofman P,Arbez-Gindre F,Jouan H,Rousselet-Chapeau MC,Berrebi D,Marcellin L,Plenat F,Zachar D,Joubert M,Selves J,Pasquier D,Bioulac-Sage P,Grotzer M,Childs M,Fabre M,Buendia MA
Category | C2
Sub-category | CGP
Brief description | Genes whose expression classifies hepatoblastoma tumors as belonging to either rC1 or rC2 subtypes and whose expression predicts poor survival.
Full description | Hepatoblastoma, the most common pediatric liver cancer, is tightly linked to excessive Wnt/beta-catenin signaling. Here, we used microarray analysis to identify two tumor subclasses resembling distinct phases of liver development and a discriminating 16-gene signature. beta-catenin activated different transcriptional programs in the two tumor types, with distinctive expression of hepatic stem/progenitor markers in immature tumors. This highly proliferating subclass was typified by gains of chromosomes 8q and 2p and upregulated Myc signaling. Myc-induced hepatoblastoma-like tumors in mice strikingly resembled the human immature subtype, and Myc downregulation in hepatoblastoma cells impaired tumorigenesis in vivo. Remarkably, the 16-gene signature discriminated invasive and metastatic hepatoblastomas and predicted prognosis with high accuracy.

Standard name | GUTIERREZ_CHRONIC_LYMPHOCYTIC_LEUKEMIA_UP
Systematic name | M885
Organism | Homo sapiens
PMID | 17252022
Authors | Gutiérrez NC,Ocio EM,Rivas Las de J,Maiso P,Delgado M,Fermiñán E,Arcos MJ,Sánchez ML,Hernández JM,Miguel San JF
Category | C2
Sub-category | CGP
Brief description | Genes exclusively up-regulated in B lymphocytes from CLL (chronic lymphocytic leukemia) patients but with a similiar expression pattern in the normal cells and in the cells from WM (Waldenstroem's macroblobulinemia) patients.
Full description | The tumoral clone of Waldenström's macroglobulinemia (WM) shows a wide morphological heterogeneity, which ranges from B lymphocytes (BL) to plasma cells (PC). By means of genome-wide expression profiling we have been able to identify genes exclusively deregulated in BL and PC from WM, but with a similar expression pattern in their corresponding cell counterparts from chronic lymphocytic leukemia (CLL) and multiple myeloma (MM), as well as normal individuals. The differentially expressed genes have important functions in B-cell differentiation and oncogenesis. Thus, two of the genes downregulated in WM-BL were IL4R, which plays a relevant role in CLL B-cell survival, and BACH2, which participates in the development of class-switched PC. Interestingly, one of the upregulated genes in WM-BL was IL6. A set of four genes was able to discriminate clonal BL from WM and CLL: LEF1 (WNT/beta-catenin pathway), MARCKS, ATXN1 and FMOD. We also found deregulation of genes involved in plasma cell differentiation such as PAX5, which was overexpressed in WM-PC, and IRF4 and BLIMP1, which were underexpressed. In addition, three of the target genes activated by PAX5 - CD79, BLNK and SYK - were upregulated in WM-PC. In summary, these results indicate that both PC and BL from WM are genetically different from the MM and CLL cell counterpart.

Standard name | GUTIERREZ_CHRONIC_LYMPHOCYTIC_LEUKEMIA_DN
Systematic name | M19492
Organism | Homo sapiens
PMID | 17252022
Authors | Gutiérrez NC,Ocio EM,Rivas Las de J,Maiso P,Delgado M,Fermiñán E,Arcos MJ,Sánchez ML,Hernández JM,Miguel San JF
Category | C2
Sub-category | CGP
Brief description | Genes exclusively down-regulated in B lymphocytes from CLL (chronic lymphocytic leukemia) patients but with a similiar expression pattern in the normal cells and in the cells from WM (Waldenstroem's macroblobulinemia) patients.
Full description | The tumoral clone of Waldenström's macroglobulinemia (WM) shows a wide morphological heterogeneity, which ranges from B lymphocytes (BL) to plasma cells (PC). By means of genome-wide expression profiling we have been able to identify genes exclusively deregulated in BL and PC from WM, but with a similar expression pattern in their corresponding cell counterparts from chronic lymphocytic leukemia (CLL) and multiple myeloma (MM), as well as normal individuals. The differentially expressed genes have important functions in B-cell differentiation and oncogenesis. Thus, two of the genes downregulated in WM-BL were IL4R, which plays a relevant role in CLL B-cell survival, and BACH2, which participates in the development of class-switched PC. Interestingly, one of the upregulated genes in WM-BL was IL6. A set of four genes was able to discriminate clonal BL from WM and CLL: LEF1 (WNT/beta-catenin pathway), MARCKS, ATXN1 and FMOD. We also found deregulation of genes involved in plasma cell differentiation such as PAX5, which was overexpressed in WM-PC, and IRF4 and BLIMP1, which were underexpressed. In addition, three of the target genes activated by PAX5 - CD79, BLNK and SYK - were upregulated in WM-PC. In summary, these results indicate that both PC and BL from WM are genetically different from the MM and CLL cell counterpart.

Standard name | GUTIERREZ_WALDENSTROEMS_MACROGLOBULINEMIA_1_UP
Systematic name | M13976
Organism | Homo sapiens
PMID | 17252022
Authors | Gutiérrez NC,Ocio EM,Rivas Las de J,Maiso P,Delgado M,Fermiñán E,Arcos MJ,Sánchez ML,Hernández JM,Miguel San JF
Category | C2
Sub-category | CGP
Brief description | Genes exclusively up-regulated in B lymphocytes from WM (Waldenstroem's macroblobulinemia) patients but with a similiar expression pattern in the normal cells and in the cells from CLL (chronic lymphocytic leukemia) patients.
Full description | The tumoral clone of Waldenström's macroglobulinemia (WM) shows a wide morphological heterogeneity, which ranges from B lymphocytes (BL) to plasma cells (PC). By means of genome-wide expression profiling we have been able to identify genes exclusively deregulated in BL and PC from WM, but with a similar expression pattern in their corresponding cell counterparts from chronic lymphocytic leukemia (CLL) and multiple myeloma (MM), as well as normal individuals. The differentially expressed genes have important functions in B-cell differentiation and oncogenesis. Thus, two of the genes downregulated in WM-BL were IL4R, which plays a relevant role in CLL B-cell survival, and BACH2, which participates in the development of class-switched PC. Interestingly, one of the upregulated genes in WM-BL was IL6. A set of four genes was able to discriminate clonal BL from WM and CLL: LEF1 (WNT/beta-catenin pathway), MARCKS, ATXN1 and FMOD. We also found deregulation of genes involved in plasma cell differentiation such as PAX5, which was overexpressed in WM-PC, and IRF4 and BLIMP1, which were underexpressed. In addition, three of the target genes activated by PAX5 - CD79, BLNK and SYK - were upregulated in WM-PC. In summary, these results indicate that both PC and BL from WM are genetically different from the MM and CLL cell counterpart.

Standard name | GUTIERREZ_WALDENSTROEMS_MACROGLOBULINEMIA_1_DN
Systematic name | M11733
Organism | Homo sapiens
PMID | 17252022
Authors | Gutiérrez NC,Ocio EM,Rivas Las de J,Maiso P,Delgado M,Fermiñán E,Arcos MJ,Sánchez ML,Hernández JM,Miguel San JF
Category | C2
Sub-category | CGP
Brief description | Genes exclusively down-regulated in B lymphocytes from WM (Waldenstroem's macroblobulinemia) patients but with a similiar expression pattern in the normal cells and in the cells from CLL (chronic lymphocytic leukemia) patients.
Full description | The tumoral clone of Waldenström's macroglobulinemia (WM) shows a wide morphological heterogeneity, which ranges from B lymphocytes (BL) to plasma cells (PC). By means of genome-wide expression profiling we have been able to identify genes exclusively deregulated in BL and PC from WM, but with a similar expression pattern in their corresponding cell counterparts from chronic lymphocytic leukemia (CLL) and multiple myeloma (MM), as well as normal individuals. The differentially expressed genes have important functions in B-cell differentiation and oncogenesis. Thus, two of the genes downregulated in WM-BL were IL4R, which plays a relevant role in CLL B-cell survival, and BACH2, which participates in the development of class-switched PC. Interestingly, one of the upregulated genes in WM-BL was IL6. A set of four genes was able to discriminate clonal BL from WM and CLL: LEF1 (WNT/beta-catenin pathway), MARCKS, ATXN1 and FMOD. We also found deregulation of genes involved in plasma cell differentiation such as PAX5, which was overexpressed in WM-PC, and IRF4 and BLIMP1, which were underexpressed. In addition, three of the target genes activated by PAX5 - CD79, BLNK and SYK - were upregulated in WM-PC. In summary, these results indicate that both PC and BL from WM are genetically different from the MM and CLL cell counterpart.

Standard name | GUTIERREZ_MULTIPLE_MYELOMA_UP
Systematic name | M19443
Organism | Homo sapiens
PMID | 17252022
Authors | Gutiérrez NC,Ocio EM,Rivas Las de J,Maiso P,Delgado M,Fermiñán E,Arcos MJ,Sánchez ML,Hernández JM,Miguel San JF
Category | C2
Sub-category | CGP
Brief description | Genes exclusively up-regulated in plasma cells from MM (multiple myeloma) patients but with a similiar expression pattern in the normal cells and in the cells from WM (Waldenstroem's macroblobulinemia) patients.
Full description | The tumoral clone of Waldenström's macroglobulinemia (WM) shows a wide morphological heterogeneity, which ranges from B lymphocytes (BL) to plasma cells (PC). By means of genome-wide expression profiling we have been able to identify genes exclusively deregulated in BL and PC from WM, but with a similar expression pattern in their corresponding cell counterparts from chronic lymphocytic leukemia (CLL) and multiple myeloma (MM), as well as normal individuals. The differentially expressed genes have important functions in B-cell differentiation and oncogenesis. Thus, two of the genes downregulated in WM-BL were IL4R, which plays a relevant role in CLL B-cell survival, and BACH2, which participates in the development of class-switched PC. Interestingly, one of the upregulated genes in WM-BL was IL6. A set of four genes was able to discriminate clonal BL from WM and CLL: LEF1 (WNT/beta-catenin pathway), MARCKS, ATXN1 and FMOD. We also found deregulation of genes involved in plasma cell differentiation such as PAX5, which was overexpressed in WM-PC, and IRF4 and BLIMP1, which were underexpressed. In addition, three of the target genes activated by PAX5 - CD79, BLNK and SYK - were upregulated in WM-PC. In summary, these results indicate that both PC and BL from WM are genetically different from the MM and CLL cell counterpart.

Standard name | GUTIERREZ_WALDENSTROEMS_MACROGLOBULINEMIA_2
Systematic name | M17096
Organism | Homo sapiens
PMID | 17252022
Authors | Gutiérrez NC,Ocio EM,Rivas Las de J,Maiso P,Delgado M,Fermiñán E,Arcos MJ,Sánchez ML,Hernández JM,Miguel San JF
Category | C2
Sub-category | CGP
Brief description | Genes exclusively up-regulated in B lymphocytes from WM (Waldenstroem's macroglobulinemia) but with a similar expression profile in MM (macroglobulinemia) and normal cells.
Full description | The tumoral clone of Waldenström's macroglobulinemia (WM) shows a wide morphological heterogeneity, which ranges from B lymphocytes (BL) to plasma cells (PC). By means of genome-wide expression profiling we have been able to identify genes exclusively deregulated in BL and PC from WM, but with a similar expression pattern in their corresponding cell counterparts from chronic lymphocytic leukemia (CLL) and multiple myeloma (MM), as well as normal individuals. The differentially expressed genes have important functions in B-cell differentiation and oncogenesis. Thus, two of the genes downregulated in WM-BL were IL4R, which plays a relevant role in CLL B-cell survival, and BACH2, which participates in the development of class-switched PC. Interestingly, one of the upregulated genes in WM-BL was IL6. A set of four genes was able to discriminate clonal BL from WM and CLL: LEF1 (WNT/beta-catenin pathway), MARCKS, ATXN1 and FMOD. We also found deregulation of genes involved in plasma cell differentiation such as PAX5, which was overexpressed in WM-PC, and IRF4 and BLIMP1, which were underexpressed. In addition, three of the target genes activated by PAX5 - CD79, BLNK and SYK - were upregulated in WM-PC. In summary, these results indicate that both PC and BL from WM are genetically different from the MM and CLL cell counterpart.

Standard name | WINNEPENNINCKX_MELANOMA_METASTASIS_UP
Systematic name | M6387
Organism | Homo sapiens
PMID | 16595783
Authors | Winnepenninckx V,Lazar V,Michiels S,Dessen P,Stas M,Alonso SR,Avril MF,Ortiz Romero PL,Robert T,Balacescu O,Eggermont AM,Lenoir G,Sarasin A,Tursz T,van den Oord JJ,Spatz A,Melanoma Group of the European Organization for Research and Treatment of Cancer
Category | C2
Sub-category | CGP
Brief description | Genes from the 254-gene classifier which were up-regulated in melanoma patients with a reported distant metastasis within 4 years.
Full description | BACKGROUND: Gene expression profiling data for human primary cutaneous melanomas are scarce because of the lack of retrospective collections of frozen tumors. To identify differentially expressed genes that may be involved in melanoma progression and prognosis, we investigated the relationship between gene expression profiles and clinical outcome in a cohort of patients with primary melanoma. METHODS: Labeled complementary RNA (cRNA) from each tissue sample was hybridized to a pangenomic 44K 60-mer oligonucleotide microarray. Class comparison and class prediction analyses were performed to identify genes whose expression in primary melanomas was associated with 4-year distant metastasis-free survival among 58 patients with at least 4 years of follow-up, distant metastasis, or death. Results were validated immunohistochemically at the protein level in 176 independent primary melanomas from patients with a median clinical follow-up of 8.5 years. Survival was analyzed with a Cox multivariable model and stratified log-rank test. All statistical tests were two-sided. RESULTS: We identified 254 genes that were associated with distant metastasis-free survival of patients with primary melanoma. These 254 genes include genes involved in activating DNA replication origins, such as minichromosome maintenance genes and geminin. Twenty-three of these genes were studied at the protein level; expression of five (MCM4, P = .002; MCM3, P = .030; MCM6, P = .004; KPNA2, P = .021; and geminin, P = .004) was statistically significantly associated with overall survival in the validation set. In a multivariable Cox model adjusted for tumor thickness, ulceration, age, and sex, expression of MCM4 (hazard ratio [HR] of death = 4.04, 95% confidence interval [CI] = 1.39 to 11.76; P = .010) and MCM6 (HR of death = 7.42, 95% CI = 1.99 to 27.64; P = .003) proteins was still statistically significantly associated with overall survival. CONCLUSION: We identified 254 genes whose expression was associated with metastatic dissemination of cutaneous melanomas. These genes may shed light on the molecular mechanisms underlying poor prognosis in melanoma patients.

Standard name | HAHTOLA_CTCL_CUTANEOUS
Systematic name | M2804
Organism | Homo sapiens
PMID | 16914566
Authors | Hahtola S,Tuomela S,Elo L,Häkkinen T,Karenko L,Nedoszytko B,Heikkilä H,Saarialho-Kere U,Roszkiewicz J,Aittokallio T,Lahesmaa R,Ranki A
Category | C2
Sub-category | CGP
Brief description | Genes showing similar expression profiles in all subtypes of cutaneous T cell lymphoma (CTCL).
Full description | PURPOSE: Increased production of Th2 cytokines characterizes Sezary syndrome, the leukemic form of cutaneous T-cell lymphomas (CTCL). To identify the molecular background and to study whether shared by the most common CTCL subtype, mycosis fungoides, we analyzed the gene expression profiles in both subtypes. EXPERIMENTAL DESIGN: Freshly isolated cells from 30 samples, representing skin, blood, and enriched CD4(+) cell populations of mycosis fungoides and Sezary syndrome, were analyzed with Affymetrix (Santa Clara, CA) oligonucleotide microarrays, quantitative PCR, or immunohistochemistry. The gene expression profiles were combined with findings of comparative genomic hybridization of the same samples to identify chromosomal changes affecting the aberrant gene expression. RESULTS: We identified a set of Th1-specific genes [e.g., TBX21 (T-bet), NKG7, and SCYA5 (RANTES)] to be down-regulated in Sezary syndrome as well as in a proportion of mycosis fungoides samples. In both Sezary syndrome and mycosis fungoides blood samples, the S100P and LIR9 gene expression was up-regulated. In lesional skin, IL7R and CD52 were up-regulated. Integration of comparative genomic hybridization and transcriptomic data identified chromosome arms 1q, 3p, 3q, 4q, 12q, 16p, and 16q as likely targets for new CTCL-associated gene aberrations. CONCLUSIONS: Our findings revealed several new genes involved in CTCL pathogenesis and potential therapeutic targets. Down-regulation of a set of genes involved in Th1 polarization, including the major Th1-polarizing factor, TBX21, was for the first time associated with CTCL. In addition, a plausible explanation for the proliferative response of CTCL cells to locally produced interleukin-7 was revealed.

Standard name | HAHTOLA_CTCL_PATHOGENESIS
Systematic name | M1416
Organism | Homo sapiens
PMID | 16914566
Authors | Hahtola S,Tuomela S,Elo L,Häkkinen T,Karenko L,Nedoszytko B,Heikkilä H,Saarialho-Kere U,Roszkiewicz J,Aittokallio T,Lahesmaa R,Ranki A
Category | C2
Sub-category | CGP
Brief description | Differentially expressed genes relevant to pathogenesis of cutaneous T cell lymphoma (CTCL).
Full description | PURPOSE: Increased production of Th2 cytokines characterizes Sezary syndrome, the leukemic form of cutaneous T-cell lymphomas (CTCL). To identify the molecular background and to study whether shared by the most common CTCL subtype, mycosis fungoides, we analyzed the gene expression profiles in both subtypes. EXPERIMENTAL DESIGN: Freshly isolated cells from 30 samples, representing skin, blood, and enriched CD4(+) cell populations of mycosis fungoides and Sezary syndrome, were analyzed with Affymetrix (Santa Clara, CA) oligonucleotide microarrays, quantitative PCR, or immunohistochemistry. The gene expression profiles were combined with findings of comparative genomic hybridization of the same samples to identify chromosomal changes affecting the aberrant gene expression. RESULTS: We identified a set of Th1-specific genes [e.g., TBX21 (T-bet), NKG7, and SCYA5 (RANTES)] to be down-regulated in Sezary syndrome as well as in a proportion of mycosis fungoides samples. In both Sezary syndrome and mycosis fungoides blood samples, the S100P and LIR9 gene expression was up-regulated. In lesional skin, IL7R and CD52 were up-regulated. Integration of comparative genomic hybridization and transcriptomic data identified chromosome arms 1q, 3p, 3q, 4q, 12q, 16p, and 16q as likely targets for new CTCL-associated gene aberrations. CONCLUSIONS: Our findings revealed several new genes involved in CTCL pathogenesis and potential therapeutic targets. Down-regulation of a set of genes involved in Th1 polarization, including the major Th1-polarizing factor, TBX21, was for the first time associated with CTCL. In addition, a plausible explanation for the proliferative response of CTCL cells to locally produced interleukin-7 was revealed.

Standard name | UZONYI_RESPONSE_TO_LEUKOTRIENE_AND_THROMBIN
Systematic name | M9162
Organism | Homo sapiens
PMID | 16606835
Authors | Uzonyi B,Lötzer K,Jahn S,Kramer C,Hildner M,Bretschneider E,Radke D,Beer M,Vollandt R,Evans JF,Funk CD,Habenicht AJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HUVEC cells (primary endothelium) after stimulation with leukotriene LTD4 [PubChem=3908] or thrombin (F2) [GeneID=2147] for 1 h.
Full description | Cysteinyl leukotrienes (cysLT), i.e., LTC4, LTD4, and LTE4, are lipid mediators derived from the 5-lipoxygenase pathway, and the cysLT receptors cysLT1-R/cysLT2-R mediate inflammatory tissue reactions. Although endothelial cells (ECs) predominantly express cysLT2-Rs, their role in vascular biology remains to be fully understood. To delineate cysLT2-R actions, we stimulated human umbilical vein EC with LTD4 and determined early induced genes. We also compared LTD4 effects with those induced by thrombin that binds to protease-activated receptor (PAR)-1. Stringent filters yielded 37 cysLT2-R- and 34 PAR-1-up-regulated genes (>2.5-fold stimulation). Most LTD4-regulated genes were also induced by thrombin. Moreover, LTD4 plus thrombin augmented gene expression when compared with each agonist alone. Strongly induced genes were studied in detail: Early growth response (EGR) and nuclear receptor subfamily 4 group A transcription factors; E-selectin; CXC ligand 2; IL-8; a disintegrin-like and metalloprotease (reprolysin type) with thrombospondin type 1 motif 1 (ADAMTS1); Down syndrome critical region gene 1 (DSCR1); tissue factor (TF); and cyclooxygenase 2. Transcripts peaked at approximately 60 min, were unaffected by a cysLT1-R antagonist, and were superinduced by cycloheximide. The EC phenotype was markedly altered: LTD4 induced de novo synthesis of EGR1 protein and EGR1 localized in the nucleus; LTD4 up-regulated IL-8 formation and secretion; and LTD4 raised TF protein and TF-dependent EC procoagulant activity. These data show that cysLT2-R activation results in a proinflammatory EC phenotype. Because LTD4 and thrombin are likely to be formed concomitantly in vivo, cysLT2-R and PAR-1 may cooperate to augment vascular injury.

Standard name | VANTVEER_BREAST_CANCER_POOR_PROGNOSIS
Systematic name | M14693
Organism | Homo sapiens
PMID | 11823860
Authors | van 't Veer LJ,Dai H,van de Vijver MJ,He YD,Hart AA,Mao M,Peterse HL,van der Kooy K,Marton MJ,Witteveen AT,Schreiber GJ,Kerkhoven RM,Roberts C,Linsley PS,Bernards R,Friend SH
Category | C2
Sub-category | CGP
Brief description | The optimal set of 70 prognostic markers predicting poor breast cancer clinical outcome (defined as developing metastases with 5 years).
Full description | Breast cancer patients with the same stage of disease can have markedly different treatment responses and overall outcome. The strongest predictors for metastases (for example, lymph node status and histological grade) fail to classify accurately breast tumours according to their clinical behaviour. Chemotherapy or hormonal therapy reduces the risk of distant metastases by approximately one-third; however, 70-80% of patients receiving this treatment would have survived without it. None of the signatures of breast cancer gene expression reported to date allow for patient-tailored therapy strategies. Here we used DNA microarray analysis on primary breast tumours of 117 young patients, and applied supervised classification to identify a gene expression signature strongly predictive of a short interval to distant metastases ('poor prognosis' signature) in patients without tumour cells in local lymph nodes at diagnosis (lymph node negative). In addition, we established a signature that identifies tumours of BRCA1 carriers. The poor prognosis signature consists of genes regulating cell cycle, invasion, metastasis and angiogenesis. This gene expression profile will outperform all currently used clinical parameters in predicting disease outcome. Our findings provide a strategy to select patients who would benefit from adjuvant therapy.

Standard name | KYNG_WERNER_SYNDROM_AND_NORMAL_AGING_UP
Systematic name | M1992
Organism | Homo sapiens
PMID | 14527998
Authors | Kyng KJ,May A,Kølvraa S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated similarly in primary fibroblast cultures from Werner syndrom patients and normal old donors compared to those from normal young donors.
Full description | Werner syndrome (WS) is a premature aging disorder, displaying defects in DNA replication, recombination, repair, and transcription. It has been hypothesized that several WS phenotypes are secondary consequences of aberrant gene expression and that a transcription defect may be crucial to the development of the syndrome. We used cDNA microarrays to characterize the expression of 6,912 genes and ESTs across a panel of 15 primary human fibroblast cell lines derived from young donors, old donors, and WS patients. Of the analyzed genes, 6.3% displayed significant differences in expression when either WS or old donor cells were compared with young donor cells. This result demonstrates that the WS transcription defect is specific to certain genes. Transcription alterations in WS were strikingly similar to those in normal aging: 91% of annotated genes displayed similar expression changes in WS and in normal aging, 3% were unique to WS, and 6% were unique to normal aging. We propose that a defect in the transcription of the genes as identified in this study could produce many of the complex clinical features of WS. The remarkable similarity between WS and normal aging suggests that WS causes the acceleration of a normal aging mechanism. This finding supports the use of WS as an aging model and implies that the transcription alterations common to WS and normal aging represent general events in the aging process.

Standard name | KYNG_WERNER_SYNDROM_AND_NORMAL_AGING_DN
Systematic name | M1993
Organism | Homo sapiens
PMID | 14527998
Authors | Kyng KJ,May A,Kølvraa S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated similarly in primary fibroblast cultures from Werner syndrom patients and normal old donors compared to those from normal young donors.
Full description | Werner syndrome (WS) is a premature aging disorder, displaying defects in DNA replication, recombination, repair, and transcription. It has been hypothesized that several WS phenotypes are secondary consequences of aberrant gene expression and that a transcription defect may be crucial to the development of the syndrome. We used cDNA microarrays to characterize the expression of 6,912 genes and ESTs across a panel of 15 primary human fibroblast cell lines derived from young donors, old donors, and WS patients. Of the analyzed genes, 6.3% displayed significant differences in expression when either WS or old donor cells were compared with young donor cells. This result demonstrates that the WS transcription defect is specific to certain genes. Transcription alterations in WS were strikingly similar to those in normal aging: 91% of annotated genes displayed similar expression changes in WS and in normal aging, 3% were unique to WS, and 6% were unique to normal aging. We propose that a defect in the transcription of the genes as identified in this study could produce many of the complex clinical features of WS. The remarkable similarity between WS and normal aging suggests that WS causes the acceleration of a normal aging mechanism. This finding supports the use of WS as an aging model and implies that the transcription alterations common to WS and normal aging represent general events in the aging process.

Standard name | KYNG_NORMAL_AGING_UP
Systematic name | M1994
Organism | Homo sapiens
PMID | 14527998
Authors | Kyng KJ,May A,Kølvraa S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes distinctly up-regulated in primary fibroblast cultures from normal old donors compared to those from normal young donors.
Full description | Werner syndrome (WS) is a premature aging disorder, displaying defects in DNA replication, recombination, repair, and transcription. It has been hypothesized that several WS phenotypes are secondary consequences of aberrant gene expression and that a transcription defect may be crucial to the development of the syndrome. We used cDNA microarrays to characterize the expression of 6,912 genes and ESTs across a panel of 15 primary human fibroblast cell lines derived from young donors, old donors, and WS patients. Of the analyzed genes, 6.3% displayed significant differences in expression when either WS or old donor cells were compared with young donor cells. This result demonstrates that the WS transcription defect is specific to certain genes. Transcription alterations in WS were strikingly similar to those in normal aging: 91% of annotated genes displayed similar expression changes in WS and in normal aging, 3% were unique to WS, and 6% were unique to normal aging. We propose that a defect in the transcription of the genes as identified in this study could produce many of the complex clinical features of WS. The remarkable similarity between WS and normal aging suggests that WS causes the acceleration of a normal aging mechanism. This finding supports the use of WS as an aging model and implies that the transcription alterations common to WS and normal aging represent general events in the aging process.

Standard name | KYNG_NORMAL_AGING_DN
Systematic name | M1995
Organism | Homo sapiens
PMID | 14527998
Authors | Kyng KJ,May A,Kølvraa S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes distinctly down-regulated in primary fibroblast cultures from normal old donors compared to those from normal young donors.
Full description | Werner syndrome (WS) is a premature aging disorder, displaying defects in DNA replication, recombination, repair, and transcription. It has been hypothesized that several WS phenotypes are secondary consequences of aberrant gene expression and that a transcription defect may be crucial to the development of the syndrome. We used cDNA microarrays to characterize the expression of 6,912 genes and ESTs across a panel of 15 primary human fibroblast cell lines derived from young donors, old donors, and WS patients. Of the analyzed genes, 6.3% displayed significant differences in expression when either WS or old donor cells were compared with young donor cells. This result demonstrates that the WS transcription defect is specific to certain genes. Transcription alterations in WS were strikingly similar to those in normal aging: 91% of annotated genes displayed similar expression changes in WS and in normal aging, 3% were unique to WS, and 6% were unique to normal aging. We propose that a defect in the transcription of the genes as identified in this study could produce many of the complex clinical features of WS. The remarkable similarity between WS and normal aging suggests that WS causes the acceleration of a normal aging mechanism. This finding supports the use of WS as an aging model and implies that the transcription alterations common to WS and normal aging represent general events in the aging process.

Standard name | KYNG_WERNER_SYNDROM_UP
Systematic name | M1996
Organism | Homo sapiens
PMID | 14527998
Authors | Kyng KJ,May A,Kølvraa S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes distinctly up-regulated in primary fibroblast cultures from Werner syndrom patients compared to those from normal young donors.
Full description | Werner syndrome (WS) is a premature aging disorder, displaying defects in DNA replication, recombination, repair, and transcription. It has been hypothesized that several WS phenotypes are secondary consequences of aberrant gene expression and that a transcription defect may be crucial to the development of the syndrome. We used cDNA microarrays to characterize the expression of 6,912 genes and ESTs across a panel of 15 primary human fibroblast cell lines derived from young donors, old donors, and WS patients. Of the analyzed genes, 6.3% displayed significant differences in expression when either WS or old donor cells were compared with young donor cells. This result demonstrates that the WS transcription defect is specific to certain genes. Transcription alterations in WS were strikingly similar to those in normal aging: 91% of annotated genes displayed similar expression changes in WS and in normal aging, 3% were unique to WS, and 6% were unique to normal aging. We propose that a defect in the transcription of the genes as identified in this study could produce many of the complex clinical features of WS. The remarkable similarity between WS and normal aging suggests that WS causes the acceleration of a normal aging mechanism. This finding supports the use of WS as an aging model and implies that the transcription alterations common to WS and normal aging represent general events in the aging process.

Standard name | KYNG_WERNER_SYNDROM_DN
Systematic name | M1997
Organism | Homo sapiens
PMID | 14527998
Authors | Kyng KJ,May A,Kølvraa S,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes distinctly down-regulated in primary fibroblast cultures from Werner syndrom patients compared to those from normal young donors.
Full description | Werner syndrome (WS) is a premature aging disorder, displaying defects in DNA replication, recombination, repair, and transcription. It has been hypothesized that several WS phenotypes are secondary consequences of aberrant gene expression and that a transcription defect may be crucial to the development of the syndrome. We used cDNA microarrays to characterize the expression of 6,912 genes and ESTs across a panel of 15 primary human fibroblast cell lines derived from young donors, old donors, and WS patients. Of the analyzed genes, 6.3% displayed significant differences in expression when either WS or old donor cells were compared with young donor cells. This result demonstrates that the WS transcription defect is specific to certain genes. Transcription alterations in WS were strikingly similar to those in normal aging: 91% of annotated genes displayed similar expression changes in WS and in normal aging, 3% were unique to WS, and 6% were unique to normal aging. We propose that a defect in the transcription of the genes as identified in this study could produce many of the complex clinical features of WS. The remarkable similarity between WS and normal aging suggests that WS causes the acceleration of a normal aging mechanism. This finding supports the use of WS as an aging model and implies that the transcription alterations common to WS and normal aging represent general events in the aging process.

Standard name | CHIARETTI_T_ALL_REFRACTORY_TO_THERAPY
Systematic name | M10778
Organism | Homo sapiens
PMID | 14684422
Authors | Chiaretti S,Li X,Gentleman R,Vitale A,Vignetti M,Mandelli F,Ritz J,Foa R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in T cell acute lymphocytic leukemia (T-ALL) patients refractory to chemotherapy treatment.
Full description | Gene expression profiles were examined in 33 adult patients with T-cell acute lymphocytic leukemia (T-ALL). Nonspecific filtering criteria identified 313 genes differentially expressed in the leukemic cells. Hierarchical clustering of samples identified 2 groups that reflected the degree of T-cell differentiation but was not associated with clinical outcome. Comparison between refractory patients and those who responded to induction chemotherapy identified a single gene, interleukin 8 (IL-8), that was highly expressed in refractory T-ALL cells and a set of 30 genes that was highly expressed in leukemic cells from patients who achieved complete remission. We next identified 19 genes that were differentially expressed in T-ALL cells from patients who either had a relapse or remained in continuous complete remission. A model based on the expression of 3 of these genes was predictive of duration of remission. The 3-gene model was validated on a further set of T-ALL samples from 18 additional patients treated on the same clinical protocol. This study demonstrates that gene expression profiling can identify a limited number of genes that are predictive of response to induction therapy and remission duration in adult patients with T-ALL.

Standard name | CHIARETTI_T_ALL_RELAPSE_PROGNOSIS
Systematic name | M17204
Organism | Homo sapiens
PMID | 14684422
Authors | Chiaretti S,Li X,Gentleman R,Vitale A,Vignetti M,Mandelli F,Ritz J,Foa R
Category | C2
Sub-category | CGP
Brief description | Genes whose expression predicted relapse in less than 2 years after chemotherapy for adult patients with T-ALL (T cell lymphoblastic leukemia).
Full description | Gene expression profiles were examined in 33 adult patients with T-cell acute lymphocytic leukemia (T-ALL). Nonspecific filtering criteria identified 313 genes differentially expressed in the leukemic cells. Hierarchical clustering of samples identified 2 groups that reflected the degree of T-cell differentiation but was not associated with clinical outcome. Comparison between refractory patients and those who responded to induction chemotherapy identified a single gene, interleukin 8 (IL-8), that was highly expressed in refractory T-ALL cells and a set of 30 genes that was highly expressed in leukemic cells from patients who achieved complete remission. We next identified 19 genes that were differentially expressed in T-ALL cells from patients who either had a relapse or remained in continuous complete remission. A model based on the expression of 3 of these genes was predictive of duration of remission. The 3-gene model was validated on a further set of T-ALL samples from 18 additional patients treated on the same clinical protocol. This study demonstrates that gene expression profiling can identify a limited number of genes that are predictive of response to induction therapy and remission duration in adult patients with T-ALL.

Standard name | BYSTRYKH_HEMATOPOIESIS_STEM_CELL_IL3RA
Systematic name | M13013
Organism | Mus musculus
PMID | 15711547
Authors | Bystrykh L,Weersing E,Dontje B,Sutton S,Pletcher MT,Wiltshire T,Su AI,Vellenga E,Wang J,Manly KF,Lu L,Chesler EJ,Alberts R,Jansen RC,Williams RW,Cooke MP,de Haan G
Category | C2
Sub-category | CGP
Brief description | Genes whose expression is coregulated with that of IL3RA [GeneID=3563] in hematopoietic stem cells (HSC).
Full description | We combined large-scale mRNA expression analysis and gene mapping to identify genes and loci that control hematopoietic stem cell (HSC) function. We measured mRNA expression levels in purified HSCs isolated from a panel of densely genotyped recombinant inbred mouse strains. We mapped quantitative trait loci (QTLs) associated with variation in expression of thousands of transcripts. By comparing the physical transcript position with the location of the controlling QTL, we identified polymorphic cis-acting stem cell genes. We also identified multiple trans-acting control loci that modify expression of large numbers of genes. These groups of coregulated transcripts identify pathways that specify variation in stem cells. We illustrate this concept with the identification of candidate genes involved with HSC turnover. We compared expression QTLs in HSCs and brain from the same mice and identified both shared and tissue-specific QTLs. Our data are accessible through WebQTL, a web-based interface that allows custom genetic linkage analysis and identification of coregulated transcripts.

Standard name | BYSTRYKH_HEMATOPOIESIS_STEM_CELL_SCP2_QTL_TRANS
Systematic name | M1998
Organism | Mus musculus
PMID | 15711547
Authors | Bystrykh L,Weersing E,Dontje B,Sutton S,Pletcher MT,Wiltshire T,Su AI,Vellenga E,Wang J,Manly KF,Lu L,Chesler EJ,Alberts R,Jansen RC,Williams RW,Cooke MP,de Haan G
Category | C2
Sub-category | CGP
Brief description | Genes trans-regulated by the hematopoietic stem cell (HSC) proliferation QTL (quantitative trait locus) Scp2.
Full description | We combined large-scale mRNA expression analysis and gene mapping to identify genes and loci that control hematopoietic stem cell (HSC) function. We measured mRNA expression levels in purified HSCs isolated from a panel of densely genotyped recombinant inbred mouse strains. We mapped quantitative trait loci (QTLs) associated with variation in expression of thousands of transcripts. By comparing the physical transcript position with the location of the controlling QTL, we identified polymorphic cis-acting stem cell genes. We also identified multiple trans-acting control loci that modify expression of large numbers of genes. These groups of coregulated transcripts identify pathways that specify variation in stem cells. We illustrate this concept with the identification of candidate genes involved with HSC turnover. We compared expression QTLs in HSCs and brain from the same mice and identified both shared and tissue-specific QTLs. Our data are accessible through WebQTL, a web-based interface that allows custom genetic linkage analysis and identification of coregulated transcripts.

Standard name | ZHAN_MULTIPLE_MYELOMA_CD1_DN
Systematic name | M16530
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 down-regulated genes in cluster CD-1 of multiple myeloma samples with the characteristic expression spike of CCND1 [GeneID=595].
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | ZHAN_MULTIPLE_MYELOMA_CD2_DN
Systematic name | M17523
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 down-regulated genes in cluster CD-2 of multiple myeloma samples with the charachteristic expression spike of CCND3 [GeneID=896].
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | ZHAN_MULTIPLE_MYELOMA_LB_DN
Systematic name | M13569
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 down-regulated genes in cluster LB of multiple myeloma samples belonging to the low bone disease group.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | ZHAN_MULTIPLE_MYELOMA_HP_DN
Systematic name | M4697
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 down-regulated genes in cluster HP of multiple myeloma samples characterized by a hyperploid signature.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | ZHAN_MULTIPLE_MYELOMA_MF_DN
Systematic name | M513
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 down-regulated genes in cluster MF of multiple myeloma samples with characteristic expression spike of MAF family transcription factors.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | ZHAN_MULTIPLE_MYELOMA_MS_DN
Systematic name | M18567
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 down-regulated genes in cluster MS of multiple myeloma samples with characteristic expression spike of WHSC1 [GeneID=7468].
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | ZHAN_MULTIPLE_MYELOMA_PR_DN
Systematic name | M10412
Organism | Homo sapiens
PMID | 16728703
Authors | Zhan F,Huang Y,Colla S,Stewart JP,Hanamura I,Gupta S,Epstein J,Yaccoby S,Sawyer J,Burington B,Anaissie E,Hollmig K,Pineda-Roman M,Tricot G,van Rhee F,Walker R,Zangari M,Crowley J,Barlogie B,Shaughnessy JD Jr
Category | C2
Sub-category | CGP
Brief description | Top 50 down-regulated genes in cluster PR of multiple myeloma samples characterized by increased expression of proliferation and cell cycle genes.
Full description | To better define the molecular basis of multiple myeloma (MM), we performed unsupervised hierarchic clustering of mRNA expression profiles in CD138-enriched plasma cells from 414 newly diagnosed patients who went on to receive high-dose therapy and tandem stem cell transplants. Seven disease subtypes were validated that were strongly influenced by known genetic lesions, such as c-MAF- and MAFB-, CCND1- and CCND3-, and MMSET-activating translocations and hyperdiploidy. Indicative of the deregulation of common pathways by gene orthologs, common gene signatures were observed in cases with c-MAF and MAFB activation and CCND1 and CCND3 activation, the latter consisting of 2 subgroups, one characterized by expression of the early B-cell markers CD20 and PAX5. A low incidence of focal bone disease distinguished one and increased expression of proliferation-associated genes of another novel subgroup. Comprising varying fractions of each of the other 6 subgroups, the proliferation subgroup dominated at relapse, suggesting that this signature is linked to disease progression. Proliferation and MMSET-spike groups were characterized by significant overexpression of genes mapping to chromosome 1q, and both exhibited a poor prognosis relative to the other groups. A subset of cases with a predominating myeloid gene expression signature, excluded from the profiling analyses, had more favorable baseline characteristics and superior prognosis to those lacking this signature.

Standard name | DANG_REGULATED_BY_MYC_UP
Systematic name | M18501
Organism | Homo sapiens
PMID | 14519204
Authors | Zeller KI,Jegga AG,Aronow BJ,O'Donnell KA,Dang CV
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by MYC [GeneID=4609], according to the MYC Target Gene Database.
Full description | We report a database of genes responsive to the Myc oncogenic transcription factor. The database Myc Target Gene prioritizes candidate target genes according to experimental evidence and clusters responsive genes into functional groups. We coupled the prioritization of target genes with phylogenetic sequence comparisons to predict c-Myc target binding sites, which are in turn validated by chromatin immunoprecipitation assays. This database is essential for the understanding of the genetic regulatory networks underlying the genesis of cancers.

Standard name | DANG_REGULATED_BY_MYC_DN
Systematic name | M2310
Organism | Homo sapiens
PMID | 14519204
Authors | Zeller KI,Jegga AG,Aronow BJ,O'Donnell KA,Dang CV
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by MYC [GeneID=4609], according to the MYC Target Gene Database.
Full description | We report a database of genes responsive to the Myc oncogenic transcription factor. The database Myc Target Gene prioritizes candidate target genes according to experimental evidence and clusters responsive genes into functional groups. We coupled the prioritization of target genes with phylogenetic sequence comparisons to predict c-Myc target binding sites, which are in turn validated by chromatin immunoprecipitation assays. This database is essential for the understanding of the genetic regulatory networks underlying the genesis of cancers.

Standard name | DANG_MYC_TARGETS_UP
Systematic name | M6506
Organism | Homo sapiens
PMID | 14519204
Authors | Zeller KI,Jegga AG,Aronow BJ,O'Donnell KA,Dang CV
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by MYC [GeneID=4609] and whose promoters are bound by MYC, according to MYC Target Gene Database.
Full description | We report a database of genes responsive to the Myc oncogenic transcription factor. The database Myc Target Gene prioritizes candidate target genes according to experimental evidence and clusters responsive genes into functional groups. We coupled the prioritization of target genes with phylogenetic sequence comparisons to predict c-Myc target binding sites, which are in turn validated by chromatin immunoprecipitation assays. This database is essential for the understanding of the genetic regulatory networks underlying the genesis of cancers.

Standard name | DANG_MYC_TARGETS_DN
Systematic name | M17557
Organism | Homo sapiens
PMID | 14519204
Authors | Zeller KI,Jegga AG,Aronow BJ,O'Donnell KA,Dang CV
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by MYC [GeneID=4609] and whose promoters are bound by MYC, according to MYC Target Gene Database.
Full description | We report a database of genes responsive to the Myc oncogenic transcription factor. The database Myc Target Gene prioritizes candidate target genes according to experimental evidence and clusters responsive genes into functional groups. We coupled the prioritization of target genes with phylogenetic sequence comparisons to predict c-Myc target binding sites, which are in turn validated by chromatin immunoprecipitation assays. This database is essential for the understanding of the genetic regulatory networks underlying the genesis of cancers.

Standard name | DANG_BOUND_BY_MYC
Systematic name | M15774
Organism | Homo sapiens
PMID | 14519204
Authors | Zeller KI,Jegga AG,Aronow BJ,O'Donnell KA,Dang CV
Category | C2
Sub-category | CGP
Brief description | Genes whose promoters are bound by MYC [GeneID=4609], according to MYC Target Gene Database.
Full description | We report a database of genes responsive to the Myc oncogenic transcription factor. The database Myc Target Gene prioritizes candidate target genes according to experimental evidence and clusters responsive genes into functional groups. We coupled the prioritization of target genes with phylogenetic sequence comparisons to predict c-Myc target binding sites, which are in turn validated by chromatin immunoprecipitation assays. This database is essential for the understanding of the genetic regulatory networks underlying the genesis of cancers.

Standard name | DORN_ADENOVIRUS_INFECTION_12HR_UP
Systematic name | M10668
Organism | Homo sapiens
PMID | 15681441
Authors | Dorn A,Zhao H,Granberg F,Hösel M,Webb D,Svensson C,Pettersson U,Doerfler W
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HeLa cells (cervical carcinoma) 12 h after infection with adenovirus Ad12.
Full description | The infection of human cells by adenoviruses leads to a gradual reduction in the activity of host cell functions while viral gene expression progresses in a regulated way. We used the DNA microarray technique to determine the transcriptional activity profiles of cellular genes upon infection with adenovirus type 12 (Ad12). The microarray data were validated by quantitative real-time PCR for genes which showed significant alterations after Ad12 infection. At 12 h postinfection, there is a striking up-regulation between 10- and 30-fold in the expression of the G1P2, IFIT1, and IFIT2 cellular immune response genes compared to mock-infected cells. At later stages of infection, when the majority of regulated cellular genes has been turned down, a limited number of cellular genes exhibit increased activities by factors of 3 or less. These genes belong to the signal transduction or transcriptional regulator classes or are active in protein degradation, like ANPEP, an aminopeptidase. The SCD and CYP2S1 genes function in lipid metabolism. The eucaryotic translation initiation factor 4 is up-regulated, and one of the major histocompatibility complex genes is diminished in activity. For two of the genes, one up-regulated (CTSF gene) and one down-regulated (CYR61 gene), alterations in gene activity were confirmed at the protein level by Western blotting experiments. Increased genetic activity of cellular genes late in adenovirus infection has not been reported previously and demonstrates that Ad12 has a sustained control of host cell gene expression well into the late phase of infection.

Standard name | DORN_ADENOVIRUS_INFECTION_12HR_DN
Systematic name | M17749
Organism | Homo sapiens
PMID | 15681441
Authors | Dorn A,Zhao H,Granberg F,Hösel M,Webb D,Svensson C,Pettersson U,Doerfler W
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HeLa cells (cervical carcinoma) 12 h after infection with adenovirus Ad12.
Full description | The infection of human cells by adenoviruses leads to a gradual reduction in the activity of host cell functions while viral gene expression progresses in a regulated way. We used the DNA microarray technique to determine the transcriptional activity profiles of cellular genes upon infection with adenovirus type 12 (Ad12). The microarray data were validated by quantitative real-time PCR for genes which showed significant alterations after Ad12 infection. At 12 h postinfection, there is a striking up-regulation between 10- and 30-fold in the expression of the G1P2, IFIT1, and IFIT2 cellular immune response genes compared to mock-infected cells. At later stages of infection, when the majority of regulated cellular genes has been turned down, a limited number of cellular genes exhibit increased activities by factors of 3 or less. These genes belong to the signal transduction or transcriptional regulator classes or are active in protein degradation, like ANPEP, an aminopeptidase. The SCD and CYP2S1 genes function in lipid metabolism. The eucaryotic translation initiation factor 4 is up-regulated, and one of the major histocompatibility complex genes is diminished in activity. For two of the genes, one up-regulated (CTSF gene) and one down-regulated (CYR61 gene), alterations in gene activity were confirmed at the protein level by Western blotting experiments. Increased genetic activity of cellular genes late in adenovirus infection has not been reported previously and demonstrates that Ad12 has a sustained control of host cell gene expression well into the late phase of infection.

Standard name | DORN_ADENOVIRUS_INFECTION_24HR_UP
Systematic name | M9834
Organism | Homo sapiens
PMID | 15681441
Authors | Dorn A,Zhao H,Granberg F,Hösel M,Webb D,Svensson C,Pettersson U,Doerfler W
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HeLa cells (cervical carcinoma) 24 h after infection with adenovirus Ad12.
Full description | The infection of human cells by adenoviruses leads to a gradual reduction in the activity of host cell functions while viral gene expression progresses in a regulated way. We used the DNA microarray technique to determine the transcriptional activity profiles of cellular genes upon infection with adenovirus type 12 (Ad12). The microarray data were validated by quantitative real-time PCR for genes which showed significant alterations after Ad12 infection. At 12 h postinfection, there is a striking up-regulation between 10- and 30-fold in the expression of the G1P2, IFIT1, and IFIT2 cellular immune response genes compared to mock-infected cells. At later stages of infection, when the majority of regulated cellular genes has been turned down, a limited number of cellular genes exhibit increased activities by factors of 3 or less. These genes belong to the signal transduction or transcriptional regulator classes or are active in protein degradation, like ANPEP, an aminopeptidase. The SCD and CYP2S1 genes function in lipid metabolism. The eucaryotic translation initiation factor 4 is up-regulated, and one of the major histocompatibility complex genes is diminished in activity. For two of the genes, one up-regulated (CTSF gene) and one down-regulated (CYR61 gene), alterations in gene activity were confirmed at the protein level by Western blotting experiments. Increased genetic activity of cellular genes late in adenovirus infection has not been reported previously and demonstrates that Ad12 has a sustained control of host cell gene expression well into the late phase of infection.

Standard name | DORN_ADENOVIRUS_INFECTION_24HR_DN
Systematic name | M8825
Organism | Homo sapiens
PMID | 15681441
Authors | Dorn A,Zhao H,Granberg F,Hösel M,Webb D,Svensson C,Pettersson U,Doerfler W
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HeLa cells (cervical carcinoma) 24 h after infection with adenovirus Ad12.
Full description | The infection of human cells by adenoviruses leads to a gradual reduction in the activity of host cell functions while viral gene expression progresses in a regulated way. We used the DNA microarray technique to determine the transcriptional activity profiles of cellular genes upon infection with adenovirus type 12 (Ad12). The microarray data were validated by quantitative real-time PCR for genes which showed significant alterations after Ad12 infection. At 12 h postinfection, there is a striking up-regulation between 10- and 30-fold in the expression of the G1P2, IFIT1, and IFIT2 cellular immune response genes compared to mock-infected cells. At later stages of infection, when the majority of regulated cellular genes has been turned down, a limited number of cellular genes exhibit increased activities by factors of 3 or less. These genes belong to the signal transduction or transcriptional regulator classes or are active in protein degradation, like ANPEP, an aminopeptidase. The SCD and CYP2S1 genes function in lipid metabolism. The eucaryotic translation initiation factor 4 is up-regulated, and one of the major histocompatibility complex genes is diminished in activity. For two of the genes, one up-regulated (CTSF gene) and one down-regulated (CYR61 gene), alterations in gene activity were confirmed at the protein level by Western blotting experiments. Increased genetic activity of cellular genes late in adenovirus infection has not been reported previously and demonstrates that Ad12 has a sustained control of host cell gene expression well into the late phase of infection.

Standard name | DORN_ADENOVIRUS_INFECTION_32HR_UP
Systematic name | M12801
Organism | Homo sapiens
PMID | 15681441
Authors | Dorn A,Zhao H,Granberg F,Hösel M,Webb D,Svensson C,Pettersson U,Doerfler W
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HeLa cells (cervical carcinoma) 32 h after infection with adenovirus Ad12.
Full description | The infection of human cells by adenoviruses leads to a gradual reduction in the activity of host cell functions while viral gene expression progresses in a regulated way. We used the DNA microarray technique to determine the transcriptional activity profiles of cellular genes upon infection with adenovirus type 12 (Ad12). The microarray data were validated by quantitative real-time PCR for genes which showed significant alterations after Ad12 infection. At 12 h postinfection, there is a striking up-regulation between 10- and 30-fold in the expression of the G1P2, IFIT1, and IFIT2 cellular immune response genes compared to mock-infected cells. At later stages of infection, when the majority of regulated cellular genes has been turned down, a limited number of cellular genes exhibit increased activities by factors of 3 or less. These genes belong to the signal transduction or transcriptional regulator classes or are active in protein degradation, like ANPEP, an aminopeptidase. The SCD and CYP2S1 genes function in lipid metabolism. The eucaryotic translation initiation factor 4 is up-regulated, and one of the major histocompatibility complex genes is diminished in activity. For two of the genes, one up-regulated (CTSF gene) and one down-regulated (CYR61 gene), alterations in gene activity were confirmed at the protein level by Western blotting experiments. Increased genetic activity of cellular genes late in adenovirus infection has not been reported previously and demonstrates that Ad12 has a sustained control of host cell gene expression well into the late phase of infection.

Standard name | DORN_ADENOVIRUS_INFECTION_32HR_DN
Systematic name | M15590
Organism | Homo sapiens
PMID | 15681441
Authors | Dorn A,Zhao H,Granberg F,Hösel M,Webb D,Svensson C,Pettersson U,Doerfler W
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HeLa cells (cervical carcinoma) 32 h after infection with adenovirus Ad12.
Full description | The infection of human cells by adenoviruses leads to a gradual reduction in the activity of host cell functions while viral gene expression progresses in a regulated way. We used the DNA microarray technique to determine the transcriptional activity profiles of cellular genes upon infection with adenovirus type 12 (Ad12). The microarray data were validated by quantitative real-time PCR for genes which showed significant alterations after Ad12 infection. At 12 h postinfection, there is a striking up-regulation between 10- and 30-fold in the expression of the G1P2, IFIT1, and IFIT2 cellular immune response genes compared to mock-infected cells. At later stages of infection, when the majority of regulated cellular genes has been turned down, a limited number of cellular genes exhibit increased activities by factors of 3 or less. These genes belong to the signal transduction or transcriptional regulator classes or are active in protein degradation, like ANPEP, an aminopeptidase. The SCD and CYP2S1 genes function in lipid metabolism. The eucaryotic translation initiation factor 4 is up-regulated, and one of the major histocompatibility complex genes is diminished in activity. For two of the genes, one up-regulated (CTSF gene) and one down-regulated (CYR61 gene), alterations in gene activity were confirmed at the protein level by Western blotting experiments. Increased genetic activity of cellular genes late in adenovirus infection has not been reported previously and demonstrates that Ad12 has a sustained control of host cell gene expression well into the late phase of infection.

Standard name | DORN_ADENOVIRUS_INFECTION_48HR_UP
Systematic name | M6181
Organism | Homo sapiens
PMID | 15681441
Authors | Dorn A,Zhao H,Granberg F,Hösel M,Webb D,Svensson C,Pettersson U,Doerfler W
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HeLa cells (cervical carcinoma) 48 h after infection with adenovirus Ad12.
Full description | The infection of human cells by adenoviruses leads to a gradual reduction in the activity of host cell functions while viral gene expression progresses in a regulated way. We used the DNA microarray technique to determine the transcriptional activity profiles of cellular genes upon infection with adenovirus type 12 (Ad12). The microarray data were validated by quantitative real-time PCR for genes which showed significant alterations after Ad12 infection. At 12 h postinfection, there is a striking up-regulation between 10- and 30-fold in the expression of the G1P2, IFIT1, and IFIT2 cellular immune response genes compared to mock-infected cells. At later stages of infection, when the majority of regulated cellular genes has been turned down, a limited number of cellular genes exhibit increased activities by factors of 3 or less. These genes belong to the signal transduction or transcriptional regulator classes or are active in protein degradation, like ANPEP, an aminopeptidase. The SCD and CYP2S1 genes function in lipid metabolism. The eucaryotic translation initiation factor 4 is up-regulated, and one of the major histocompatibility complex genes is diminished in activity. For two of the genes, one up-regulated (CTSF gene) and one down-regulated (CYR61 gene), alterations in gene activity were confirmed at the protein level by Western blotting experiments. Increased genetic activity of cellular genes late in adenovirus infection has not been reported previously and demonstrates that Ad12 has a sustained control of host cell gene expression well into the late phase of infection.

Standard name | DORN_ADENOVIRUS_INFECTION_48HR_DN
Systematic name | M7375
Organism | Homo sapiens
PMID | 15681441
Authors | Dorn A,Zhao H,Granberg F,Hösel M,Webb D,Svensson C,Pettersson U,Doerfler W
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HeLa cells (cervical carcinoma) 48 h after infection with adenovirus Ad12.
Full description | The infection of human cells by adenoviruses leads to a gradual reduction in the activity of host cell functions while viral gene expression progresses in a regulated way. We used the DNA microarray technique to determine the transcriptional activity profiles of cellular genes upon infection with adenovirus type 12 (Ad12). The microarray data were validated by quantitative real-time PCR for genes which showed significant alterations after Ad12 infection. At 12 h postinfection, there is a striking up-regulation between 10- and 30-fold in the expression of the G1P2, IFIT1, and IFIT2 cellular immune response genes compared to mock-infected cells. At later stages of infection, when the majority of regulated cellular genes has been turned down, a limited number of cellular genes exhibit increased activities by factors of 3 or less. These genes belong to the signal transduction or transcriptional regulator classes or are active in protein degradation, like ANPEP, an aminopeptidase. The SCD and CYP2S1 genes function in lipid metabolism. The eucaryotic translation initiation factor 4 is up-regulated, and one of the major histocompatibility complex genes is diminished in activity. For two of the genes, one up-regulated (CTSF gene) and one down-regulated (CYR61 gene), alterations in gene activity were confirmed at the protein level by Western blotting experiments. Increased genetic activity of cellular genes late in adenovirus infection has not been reported previously and demonstrates that Ad12 has a sustained control of host cell gene expression well into the late phase of infection.

Standard name | TIAN_TNF_SIGNALING_VIA_NFKB
Systematic name | M14435
Organism | Homo sapiens
PMID | 15722553
Authors | Tian B,Nowak DE,Jamaluddin M,Wang S,Brasier AR
Category | C2
Sub-category | CGP
Brief description | Genes modulated in HeLa cells (cervical carcinoma) by TNF [GeneID=7124] via NFKB pathway.
Full description | Tumor necrosis factor (TNF) is a pro-inflammatory cytokine that controls expression of inflammatory genetic networks. Although the nuclear factor-kappaB (NF-kappaB) pathway is crucial for mediating cellular TNF responses, the complete spectrum of NF-kappaB-dependent genes is unknown. In this study, we used a tetracycline-regulated cell line expressing an NF-kappaB inhibitor to systematically identify NF-kappaB-dependent genes. A microarray data set generated from a time course of TNF stimulation in the presence or absence of NF-kappaB signaling was analyzed. We identified 50 unique genes that were regulated by TNF (Pr(F)<0.001) and demonstrated a change in signal intensity of+/-3-fold relative to control. Of these, 28 were NF-kappaB-dependent, encoding proteins involved in diverse cellular activities. Quantitative real-time PCR assays of eight characterized NF-kappaB-dependent genes and five genes not previously known to be NF-kappaB-dependent (Gro-beta and-gamma, IkappaBepsilon, interleukin (IL)-7R, and Naf-1) were used to determine whether they were directly or indirectly NF-kappaB regulated. Expression of constitutively active enhanced green fluorescent.NF-kappaB/Rel A fusion protein transactivated all but IL-6 and IL-7R in the absence of TNF stimulation. Moreover, TNF strongly induced all 12 genes in the absence of new protein synthesis. High probability NF-kappaB sites in novel genes were predicted by binding site analysis and confirmed by electrophoretic mobility shift assay. Chromatin immunoprecipitation assays show the endogenous IkappaBalpha/epsilon, Gro-beta/gamma, and Naf-1 promoters directly bound NF-kappaB/Rel A in TNF-stimulated cells. Together, these studies systematically identify the direct NF-kappaB-dependent gene network downstream of TNF signaling, extending our knowledge of biological processes regulated by this pathway.

Standard name | TIAN_TNF_SIGNALING_NOT_VIA_NFKB
Systematic name | M14666
Organism | Homo sapiens
PMID | 15722553
Authors | Tian B,Nowak DE,Jamaluddin M,Wang S,Brasier AR
Category | C2
Sub-category | CGP
Brief description | Genes modulated in HeLa cells (cervical carcinoma) by TNF [GeneID=7124] not via NFKB pathway.
Full description | Tumor necrosis factor (TNF) is a pro-inflammatory cytokine that controls expression of inflammatory genetic networks. Although the nuclear factor-kappaB (NF-kappaB) pathway is crucial for mediating cellular TNF responses, the complete spectrum of NF-kappaB-dependent genes is unknown. In this study, we used a tetracycline-regulated cell line expressing an NF-kappaB inhibitor to systematically identify NF-kappaB-dependent genes. A microarray data set generated from a time course of TNF stimulation in the presence or absence of NF-kappaB signaling was analyzed. We identified 50 unique genes that were regulated by TNF (Pr(F)<0.001) and demonstrated a change in signal intensity of+/-3-fold relative to control. Of these, 28 were NF-kappaB-dependent, encoding proteins involved in diverse cellular activities. Quantitative real-time PCR assays of eight characterized NF-kappaB-dependent genes and five genes not previously known to be NF-kappaB-dependent (Gro-beta and-gamma, IkappaBepsilon, interleukin (IL)-7R, and Naf-1) were used to determine whether they were directly or indirectly NF-kappaB regulated. Expression of constitutively active enhanced green fluorescent.NF-kappaB/Rel A fusion protein transactivated all but IL-6 and IL-7R in the absence of TNF stimulation. Moreover, TNF strongly induced all 12 genes in the absence of new protein synthesis. High probability NF-kappaB sites in novel genes were predicted by binding site analysis and confirmed by electrophoretic mobility shift assay. Chromatin immunoprecipitation assays show the endogenous IkappaBalpha/epsilon, Gro-beta/gamma, and Naf-1 promoters directly bound NF-kappaB/Rel A in TNF-stimulated cells. Together, these studies systematically identify the direct NF-kappaB-dependent gene network downstream of TNF signaling, extending our knowledge of biological processes regulated by this pathway.

Standard name | WONG_EMBRYONIC_STEM_CELL_CORE
Systematic name | M7079
Organism | Homo sapiens
PMID | 18397753
Authors | Wong DJ,Liu H,Ridky TW,Cassarino D,Segal E,Chang HY
Category | C2
Sub-category | CGP
Brief description | The 'core ESC-like gene module': genes coordinately up-regulated in a compendium of mouse embryonic stem cells (ESC) which are shared with the human ESC-like module.
Full description | Self-renewal is a hallmark of stem cells and cancer, but existence of a shared stemness program remains controversial. Here, we construct a gene module map to systematically relate transcriptional programs in embryonic stem cells (ESCs), adult tissue stem cells, and human cancers. This map reveals two predominant gene modules that distinguish ESCs and adult tissue stem cells. The ESC-like transcriptional program is activated in diverse human epithelial cancers and strongly predicts metastasis and death. c-Myc, but not other oncogenes, is sufficient to reactivate the ESC-like program in normal and cancer cells. In primary human keratinocytes transformed by Ras and I kappa B alpha, c-Myc increases the fraction of tumor-initiating cells by 150-fold, enabling tumor formation and serial propagation with as few as 500 cells. c-Myc-enhanced tumor initiation is cell-autonomous and independent of genomic instability. Thus, activation of an ESC-like transcriptional program in differentiated adult cells may induce pathologic self-renewal characteristic of cancer stem cells.

Standard name | WONG_ADULT_TISSUE_STEM_MODULE
Systematic name | M1999
Organism | Mus musculus
PMID | 18397753
Authors | Wong DJ,Liu H,Ridky TW,Cassarino D,Segal E,Chang HY
Category | C2
Sub-category | CGP
Brief description | The 'adult tissue stem' module: genes coordinately up-regulated in a compendium of adult tissue stem cells.
Full description | Self-renewal is a hallmark of stem cells and cancer, but existence of a shared stemness program remains controversial. Here, we construct a gene module map to systematically relate transcriptional programs in embryonic stem cells (ESCs), adult tissue stem cells, and human cancers. This map reveals two predominant gene modules that distinguish ESCs and adult tissue stem cells. The ESC-like transcriptional program is activated in diverse human epithelial cancers and strongly predicts metastasis and death. c-Myc, but not other oncogenes, is sufficient to reactivate the ESC-like program in normal and cancer cells. In primary human keratinocytes transformed by Ras and I kappa B alpha, c-Myc increases the fraction of tumor-initiating cells by 150-fold, enabling tumor formation and serial propagation with as few as 500 cells. c-Myc-enhanced tumor initiation is cell-autonomous and independent of genomic instability. Thus, activation of an ESC-like transcriptional program in differentiated adult cells may induce pathologic self-renewal characteristic of cancer stem cells.

Standard name | NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_UP
Systematic name | M17951
Organism | Homo sapiens
PMID | 17464315
Authors | Nakayama R,Nemoto T,Takahashi H,Ohta T,Kawai A,Seki K,Yoshida T,Toyama Y,Ichikawa H,Hasegawa T
Category | C2
Sub-category | CGP
Brief description | Top 100 probe sets contrubuting to the positive side of the 1st principal component; predominantly associated with spindle cell and pleomorphic sarcoma samples.
Full description | In soft tissue sarcomas, the diagnosis of malignant fibrous histiocytoma (MFH) has been a very controversial issue, and MFH is now considered to be reclassified into pleomorphic subtypes of other sarcomas. To characterize MFH genetically, we used an oligonucleotide microarray to analyze gene expression in 105 samples from 10 types of soft tissue tumors. Spindle cell and pleomorphic sarcomas, such as dedifferentiated liposarcoma, myxofibrosarcoma, leiomyosarcoma, malignant peripheral nerve sheath tumor (MPNST), fibrosarcoma and MFH, showed similar gene expression patterns compared to other tumors. Samples from those five sarcoma types could be classified into respective clusters based on gene expression by excluding MFH samples. We calculated distances between MFH samples and other five sarcoma types (dedifferentiated liposarcoma, myxofibrosarcoma, leiomyosarcoma, MPNST and fibrosarcoma) based on differentially expressed genes and evaluated similarities. Three of the 21 MFH samples showed marked similarities to one of the five sarcoma types, which were supported by histological findings. Although most of the remaining 18 MFH samples showed little or no histological resemblance to one of the five sarcoma types, 12 of them showed moderate similarities in terms of gene expression. These results explain the heterogeneity of MFH and show that the majority of MFHs could be reclassified into pleomorphic subtypes of other sarcomas. Taken together, gene expression profiling could be a useful tool to unveil the difference in the underlying molecular backgrounds, which leads to a rational taxonomy and diagnosis of a diverse group of soft tissue sarcomas.

Standard name | NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_DN
Systematic name | M17937
Organism | Homo sapiens
PMID | 17464315
Authors | Nakayama R,Nemoto T,Takahashi H,Ohta T,Kawai A,Seki K,Yoshida T,Toyama Y,Ichikawa H,Hasegawa T
Category | C2
Sub-category | CGP
Brief description | Top 100 probe sets contrubuting to the negative side of the 1st principal component; predominantly associated with synovial sarcoma and myxoid/round cell liposarcoma samples.
Full description | In soft tissue sarcomas, the diagnosis of malignant fibrous histiocytoma (MFH) has been a very controversial issue, and MFH is now considered to be reclassified into pleomorphic subtypes of other sarcomas. To characterize MFH genetically, we used an oligonucleotide microarray to analyze gene expression in 105 samples from 10 types of soft tissue tumors. Spindle cell and pleomorphic sarcomas, such as dedifferentiated liposarcoma, myxofibrosarcoma, leiomyosarcoma, malignant peripheral nerve sheath tumor (MPNST), fibrosarcoma and MFH, showed similar gene expression patterns compared to other tumors. Samples from those five sarcoma types could be classified into respective clusters based on gene expression by excluding MFH samples. We calculated distances between MFH samples and other five sarcoma types (dedifferentiated liposarcoma, myxofibrosarcoma, leiomyosarcoma, MPNST and fibrosarcoma) based on differentially expressed genes and evaluated similarities. Three of the 21 MFH samples showed marked similarities to one of the five sarcoma types, which were supported by histological findings. Although most of the remaining 18 MFH samples showed little or no histological resemblance to one of the five sarcoma types, 12 of them showed moderate similarities in terms of gene expression. These results explain the heterogeneity of MFH and show that the majority of MFHs could be reclassified into pleomorphic subtypes of other sarcomas. Taken together, gene expression profiling could be a useful tool to unveil the difference in the underlying molecular backgrounds, which leads to a rational taxonomy and diagnosis of a diverse group of soft tissue sarcomas.

Standard name | NAKAYAMA_SOFT_TISSUE_TUMORS_PCA2_UP
Systematic name | M2761
Organism | Homo sapiens
PMID | 17464315
Authors | Nakayama R,Nemoto T,Takahashi H,Ohta T,Kawai A,Seki K,Yoshida T,Toyama Y,Ichikawa H,Hasegawa T
Category | C2
Sub-category | CGP
Brief description | Top 100 probe sets contrubuting to the positive side of the 2nd principal component; associated with adipocytic differentiation.
Full description | In soft tissue sarcomas, the diagnosis of malignant fibrous histiocytoma (MFH) has been a very controversial issue, and MFH is now considered to be reclassified into pleomorphic subtypes of other sarcomas. To characterize MFH genetically, we used an oligonucleotide microarray to analyze gene expression in 105 samples from 10 types of soft tissue tumors. Spindle cell and pleomorphic sarcomas, such as dedifferentiated liposarcoma, myxofibrosarcoma, leiomyosarcoma, malignant peripheral nerve sheath tumor (MPNST), fibrosarcoma and MFH, showed similar gene expression patterns compared to other tumors. Samples from those five sarcoma types could be classified into respective clusters based on gene expression by excluding MFH samples. We calculated distances between MFH samples and other five sarcoma types (dedifferentiated liposarcoma, myxofibrosarcoma, leiomyosarcoma, MPNST and fibrosarcoma) based on differentially expressed genes and evaluated similarities. Three of the 21 MFH samples showed marked similarities to one of the five sarcoma types, which were supported by histological findings. Although most of the remaining 18 MFH samples showed little or no histological resemblance to one of the five sarcoma types, 12 of them showed moderate similarities in terms of gene expression. These results explain the heterogeneity of MFH and show that the majority of MFHs could be reclassified into pleomorphic subtypes of other sarcomas. Taken together, gene expression profiling could be a useful tool to unveil the difference in the underlying molecular backgrounds, which leads to a rational taxonomy and diagnosis of a diverse group of soft tissue sarcomas.

Standard name | NAKAYAMA_SOFT_TISSUE_TUMORS_PCA2_DN
Systematic name | M1451
Organism | Homo sapiens
PMID | 17464315
Authors | Nakayama R,Nemoto T,Takahashi H,Ohta T,Kawai A,Seki K,Yoshida T,Toyama Y,Ichikawa H,Hasegawa T
Category | C2
Sub-category | CGP
Brief description | Top 100 probe sets contrubuting to the negative side of the 2nd principal component; associated with adipocytic differentiation.
Full description | In soft tissue sarcomas, the diagnosis of malignant fibrous histiocytoma (MFH) has been a very controversial issue, and MFH is now considered to be reclassified into pleomorphic subtypes of other sarcomas. To characterize MFH genetically, we used an oligonucleotide microarray to analyze gene expression in 105 samples from 10 types of soft tissue tumors. Spindle cell and pleomorphic sarcomas, such as dedifferentiated liposarcoma, myxofibrosarcoma, leiomyosarcoma, malignant peripheral nerve sheath tumor (MPNST), fibrosarcoma and MFH, showed similar gene expression patterns compared to other tumors. Samples from those five sarcoma types could be classified into respective clusters based on gene expression by excluding MFH samples. We calculated distances between MFH samples and other five sarcoma types (dedifferentiated liposarcoma, myxofibrosarcoma, leiomyosarcoma, MPNST and fibrosarcoma) based on differentially expressed genes and evaluated similarities. Three of the 21 MFH samples showed marked similarities to one of the five sarcoma types, which were supported by histological findings. Although most of the remaining 18 MFH samples showed little or no histological resemblance to one of the five sarcoma types, 12 of them showed moderate similarities in terms of gene expression. These results explain the heterogeneity of MFH and show that the majority of MFHs could be reclassified into pleomorphic subtypes of other sarcomas. Taken together, gene expression profiling could be a useful tool to unveil the difference in the underlying molecular backgrounds, which leads to a rational taxonomy and diagnosis of a diverse group of soft tissue sarcomas.

Standard name | CHANDRAN_METASTASIS_UP
Systematic name | M16036
Organism | Homo sapiens
PMID | 17430594
Authors | Chandran UR,Ma C,Dhir R,Bisceglia M,Lyons-Weiler M,Liang W,Michalopoulos G,Becich M,Monzon FA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in metastatic tumors from the whole panel of patients with prostate cancer.
Full description | BACKGROUND: Prostate cancer is characterized by heterogeneity in the clinical course that often does not correlate with morphologic features of the tumor. Metastasis reflects the most adverse outcome of prostate cancer, and to date there are no reliable morphologic features or serum biomarkers that can reliably predict which patients are at higher risk of developing metastatic disease. Understanding the differences in the biology of metastatic and organ confined primary tumors is essential for developing new prognostic markers and therapeutic targets. METHODS: Using Affymetrix oligonucleotide arrays, we analyzed gene expression profiles of 24 androgen-ablation resistant metastatic samples obtained from 4 patients and a previously published dataset of 64 primary prostate tumor samples. Differential gene expression was analyzed after removing potentially uninformative stromal genes, addressing the differences in cellular content between primary and metastatic tumors. RESULTS: The metastatic samples are highly heterogenous in expression; however, differential expression analysis shows that 415 genes are upregulated and 364 genes are downregulated at least 2 fold in every patient with metastasis. The expression profile of metastatic samples reveals changes in expression of a unique set of genes representing both the androgen ablation related pathways and other metastasis related gene networks such as cell adhesion, bone remodelling and cell cycle. The differentially expressed genes include metabolic enzymes, transcription factors such as Forkhead Box M1 (FoxM1) and cell adhesion molecules such as Osteopontin (SPP1). CONCLUSION: We hypothesize that these genes have a role in the biology of metastatic disease and that they represent potential therapeutic targets for prostate cancer.

Standard name | CHANDRAN_METASTASIS_DN
Systematic name | M11615
Organism | Homo sapiens
PMID | 17430594
Authors | Chandran UR,Ma C,Dhir R,Bisceglia M,Lyons-Weiler M,Liang W,Michalopoulos G,Becich M,Monzon FA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in metastatic tumors from the whole panel of patients with prostate cancer.
Full description | BACKGROUND: Prostate cancer is characterized by heterogeneity in the clinical course that often does not correlate with morphologic features of the tumor. Metastasis reflects the most adverse outcome of prostate cancer, and to date there are no reliable morphologic features or serum biomarkers that can reliably predict which patients are at higher risk of developing metastatic disease. Understanding the differences in the biology of metastatic and organ confined primary tumors is essential for developing new prognostic markers and therapeutic targets. METHODS: Using Affymetrix oligonucleotide arrays, we analyzed gene expression profiles of 24 androgen-ablation resistant metastatic samples obtained from 4 patients and a previously published dataset of 64 primary prostate tumor samples. Differential gene expression was analyzed after removing potentially uninformative stromal genes, addressing the differences in cellular content between primary and metastatic tumors. RESULTS: The metastatic samples are highly heterogenous in expression; however, differential expression analysis shows that 415 genes are upregulated and 364 genes are downregulated at least 2 fold in every patient with metastasis. The expression profile of metastatic samples reveals changes in expression of a unique set of genes representing both the androgen ablation related pathways and other metastasis related gene networks such as cell adhesion, bone remodelling and cell cycle. The differentially expressed genes include metabolic enzymes, transcription factors such as Forkhead Box M1 (FoxM1) and cell adhesion molecules such as Osteopontin (SPP1). CONCLUSION: We hypothesize that these genes have a role in the biology of metastatic disease and that they represent potential therapeutic targets for prostate cancer.

Standard name | MIKKELSEN_ES_HCP_WITH_H3K27ME3
Systematic name | M2000
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing histone H3 K27 trimethylation mark (H327me3) in embryonic stem cells (ES).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_ES_HCP_WITH_H3_UNMETHYLATED
Systematic name | M2002
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) without H3 methylation marks at K4 and K27 in embryonic stem cells (ES).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_ES_ICP_WITH_H3K27ME3
Systematic name | M2003
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing histone H3 K27 trimethylation mark (H3K27me3) in embryonic stem cells (ES).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_ES_ICP_WITH_H3K4ME3
Systematic name | M2004
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density (ICP) promoters bearing histone H3 K4 trimethylation mark (H3K4me3) in embryonic stem cells (ES).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_ES_ICP_WITH_H3K4ME3_AND_H3K27ME3
Systematic name | M2005
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing bivalent histone H3 methylation mark (H3K4me3 and H3K27me3) in embryonic stem cells (ES).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_ES_LCP_WITH_H3K27ME3
Systematic name | M2006
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters bearing H3 trimethylation mark at K27 (H3K27me3) in embryonic stem cells (ES).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_ES_LCP_WITH_H3K4ME3
Systematic name | M2007
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters (LCP) bearing histone H3 trimethylation mark at K4 (H3K4me3) in embryonic stem cells (ES).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_ES_LCP_WITH_H3K4ME3_AND_H3K27ME3
Systematic name | M2008
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters (LCP) bearing the bivalent histone H3 trimethylation mark at K4 and K27 (H3K4me3 and H3K27me3) in embryonic stem cells (ES).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_NPC_HCP_WITH_H3K27ME3
Systematic name | M2009
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing histone H3 trimethylation mark at K27 (H3K27me3) in neural progenitor cells (NPC).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_NPC_HCP_WITH_H3K4ME3_AND_H3K27ME3
Systematic name | M2010
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing the bivalent histone H3 trimethylation mark at K4 and K27 (H3K4me3 and H3K27me3) in neural progenitor cells (NPC).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_NPC_ICP_WITH_H3K27ME3
Systematic name | M2011
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing histone H3 trimethylation mark at K27 (H3K27me3) in neural progenitor cells (NPC).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_NPC_ICP_WITH_H3K4ME3
Systematic name | M2013
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with intermediate-CpG-density promoters (ICP) bearing histone H3 trimethylation mark at K4 (H3K4me3) in neural progenitor cells (NPC).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_NPC_WITH_LCP_H3K27ME3
Systematic name | M2017
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters (LCP) bearing histone H3 trimethylation mark at K27 in neural progenitor cells (NPC).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_NPC_LCP_WITH_H3K4ME3
Systematic name | M2018
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with low-CpG-density promoters (LCP) bearing histone H3 trimethylation mark at K4 (H3K4me3) in neural progenitor cells (NPC).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_MEF_HCP_WITH_H3K27ME3
Systematic name | M2019
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) bearing histone H3 trimethylation mark at K27 (H3K27me3) in MEF cells (embryonic fibroblast).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | MIKKELSEN_MEF_HCP_WITH_H3_UNMETHYLATED
Systematic name | M2020
Organism | Mus musculus
PMID | 17603471
Authors | Mikkelsen TS,Ku M,Jaffe DB,Issac B,Lieberman E,Giannoukos G,Alvarez P,Brockman W,Kim TK,Koche RP,Lee W,Mendenhall E,O'Donovan A,Presser A,Russ C,Xie X,Meissner A,Wernig M,Jaenisch R,Nusbaum C,Lander ES,Bernstein BE
Category | C2
Sub-category | CGP
Brief description | Genes with high-CpG-density promoters (HCP) with unmethylated histone H3 in MEF cells (embryonic fibroblast).
Full description | We report the application of single-molecule-based sequencing technology for high-throughput profiling of histone modifications in mammalian cells. By obtaining over four billion bases of sequence from chromatin immunoprecipitated DNA, we generated genome-wide chromatin-state maps of mouse embryonic stem cells, neural progenitor cells and embryonic fibroblasts. We find that lysine 4 and lysine 27 trimethylation effectively discriminates genes that are expressed, poised for expression, or stably repressed, and therefore reflect cell state and lineage potential. Lysine 36 trimethylation marks primary coding and non-coding transcripts, facilitating gene annotation. Trimethylation of lysine 9 and lysine 20 is detected at satellite, telomeric and active long-terminal repeats, and can spread into proximal unique sequences. Lysine 4 and lysine 9 trimethylation marks imprinting control regions. Finally, we show that chromatin state can be read in an allele-specific manner by using single nucleotide polymorphisms. This study provides a framework for the application of comprehensive chromatin profiling towards characterization of diverse mammalian cell populations.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_0
Systematic name | M15699
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 0.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_1
Systematic name | M1145
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 1.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_2
Systematic name | M2021
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 2.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_3
Systematic name | M12322
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 3.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_4
Systematic name | M16325
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 4.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_5
Systematic name | M16708
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 5.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_6
Systematic name | M13387
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 6.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_7
Systematic name | M17481
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 7.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_8
Systematic name | M16033
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 8.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_9
Systematic name | M18153
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 9.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_10
Systematic name | M1033
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 10.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_11
Systematic name | M19360
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 11.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_12
Systematic name | M19891
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 12.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_13
Systematic name | M13713
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 13.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_14
Systematic name | M8751
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 14.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_15
Systematic name | M2687
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 15.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_16
Systematic name | M18400
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 16.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | YAO_TEMPORAL_RESPONSE_TO_PROGESTERONE_CLUSTER_17
Systematic name | M2336
Organism | Mus musculus
PMID | 12554760
Authors | Yao MW,Lim H,Schust DJ,Choe SE,Farago A,Ding Y,Michaud S,Church GM,Maas RL
Category | C2
Sub-category | CGP
Brief description | Genes co-regulated in uterus during a time course response to progesterone [PubChem=5994]: SOM cluster 17.
Full description | Human infertility and recurrent pregnancy loss caused by implantation defects are poorly understood. Hoxa-10-deficient female mice have severe infertility and recurrent pregnancy loss due to defective uterine implantation. Gene expression profiling experiments reveal that Hoxa-10 is an important regulator of two critical events in implantation: stromal cell proliferation and local immunosuppression. At the time of implantation, Hoxa-10 mediates the progesterone-stimulated proliferation of uterine stromal cells. Hoxa-10 mutants express a stromal cell proliferation defect that is accompanied by quantitative or spatial alterations in the expression of two cyclin-dependent kinase inhibitor genes, p57 and p15. Hoxa-10 deficiency also leads to a severe local immunological disturbance, characterized by a polyclonal proliferation of T cells, that occurs in place of the normal progesterone-mediated immunosuppression in the periimplantation uterus.

Standard name | SENGUPTA_EBNA1_ANTICORRELATED
Systematic name | M18742
Organism | Homo sapiens
PMID | 16912175
Authors | Sengupta S,den Boon JA,Chen IH,Newton MA,Dahl DB,Chen M,Cheng YJ,Westra WH,Chen CJ,Hildesheim A,Sugden B,Ahlquist P
Category | C2
Sub-category | CGP
Brief description | Genes whose reduced expression in nasopharyngeal carinoma (NPC) correlated most with the increased expression of EBNA1 [GeneID=3783774], a latent gene of Epstein-Barr virus (EBV).
Full description | To identify the molecular mechanisms by which EBV-associated epithelial cancers are maintained, we measured the expression of essentially all human genes and all latent EBV genes in a collection of 31 laser-captured, microdissected nasopharyngeal carcinoma (NPC) tissue samples and 10 normal nasopharyngeal tissues. Global gene expression profiles clearly distinguished tumors from normal healthy epithelium. Expression levels of six viral genes (EBNA1, EBNA2, EBNA3A, EBNA3B, LMP1, and LMP2A) were correlated among themselves and strongly inversely correlated with the expression of a large subset of host genes. Among the human genes whose inhibition was most strongly correlated with increased EBV gene expression were multiple MHC class I HLA genes involved in regulating immune response via antigen presentation. The association between EBV gene expression and inhibition of MHC class I HLA expression implies that antigen display is either directly inhibited by EBV, facilitating immune evasion by tumor cells, and/or that tumor cells with inhibited presentation are selected for their ability to sustain higher levels of EBV to take maximum advantage of EBV oncogene-mediated tumor-promoting actions. Our data clearly reflect such tumor promotion, showing that deregulation of key proteins involved in apoptosis (BCL2-related protein A1 and Fas apoptotic inhibitory molecule), cell cycle checkpoints (AKIP, SCYL1, and NIN), and metastasis (matrix metalloproteinase 1) is closely correlated with the levels of EBV gene expression in NPC.

Standard name | YIH_RESPONSE_TO_ARSENITE_C5
Systematic name | M2023
Organism | Homo sapiens
PMID | 12016162
Authors | Yih LH,Peck K,Lee TC
Category | C2
Sub-category | CGP
Brief description | Genes in cluster 5: slowly down-regulated in HFW cells (fibroblast) by sodium arsenite [PubChem=26435].
Full description | Arsenic compounds are widely distributed and arsenic ingestion is associated with many human diseases, including blackfoot disease, atherosclerosis, and cancers. However, the underlying mechanism of arsenic toxicity is not understood. In human fibroblast cells (HFW), arsenite is known to induce oxidative damage, chromosome aberrations, cell cycle arrest, and aneuploidy, and the manifestation of these cellular responses is dependent on changes in gene expression which can be analyzed using the cDNA microarray technique. In this study, cDNA microarray membranes with 568 human genes were used to examine mRNA profile changes in HFW cells treated for 0 to 24 h with 5 microM sodium arsenite. On the basis of the mean value for three independent experiments, 133 target genes were selected for a 2 x 3 self-organizing map cluster analysis; 94 were found to be induced by arsenite treatment, whereas 39 were repressed. These genes were categorized as signal transduction, transcriptional regulation, cell cycle control, stress responses, proteolytic enzymes, and miscellaneous. Significant changes in the signaling-related and transcriptional regulation genes indicated that arsenite induces complex toxicopathological injury.

Standard name | MOOTHA_PYR
Systematic name | M5871
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Genes involved in pyruvate metabolism; based on literature and sequence annotation resources and converted to Affymetrix HG-U133A probe sets.
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | MOOTHA_FFA_OXYDATION
Systematic name | M15531
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Genes involved in free fatty acid oxidation; based on literature and sequence annotation resources and coverted to Affymetrix HG-U133A probe sets.
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | MOOTHA_GLUCONEOGENESIS
Systematic name | M13448
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Genes involved in gluconeogenesis; based on literature and sequence annotation resources and converted to Affymetrix HG-U133A probe sets.
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | MOOTHA_GLYCOGEN_METABOLISM
Systematic name | M10376
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Genes involved in glycogen metabolism; based on literature and sequence annotation resources and converted to Affymetrix HG-U133A probe sets.
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | MOOTHA_GLYCOLYSIS
Systematic name | M16111
Organism | Homo sapiens
PMID | 12808457
Authors | Mootha VK,Lindgren CM,Eriksson KF,Subramanian A,Sihag S,Lehar J,Puigserver P,Carlsson E,Ridderstråle M,Laurila E,Houstis N,Daly MJ,Patterson N,Mesirov JP,Golub TR,Tamayo P,Spiegelman B,Lander ES,Hirschhorn JN,Altshuler D,Groop LC
Category | C2
Sub-category | CGP
Brief description | Genes involved in glycolysis; based on literature and sequence annotation resources and converted to Affymetrix HG-U133A probe sets.
Full description | DNA microarrays can be used to identify gene expression changes characteristic of human disease. This is challenging, however, when relevant differences are subtle at the level of individual genes. We introduce an analytical strategy, Gene Set Enrichment Analysis, designed to detect modest but coordinate changes in the expression of groups of functionally related genes. Using this approach, we identify a set of genes involved in oxidative phosphorylation whose expression is coordinately decreased in human diabetic muscle. Expression of these genes is high at sites of insulin-mediated glucose disposal, activated by PGC-1alpha and correlated with total-body aerobic capacity. Our results associate this gene set with clinically important variation in human metabolism and illustrate the value of pathway relationships in the analysis of genomic profiling experiments.

Standard name | LY_AGING_OLD_UP
Systematic name | M8910
Organism | Homo sapiens
PMID | 10741968
Authors | Ly DH,Lockhart DJ,Lerner RA,Schultz PG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in fibroblasts from old individuals, compared to those from young donors.
Full description | Messenger RNA levels were measured in actively dividing fibroblasts isolated from young, middle-age, and old-age humans and humans with progeria, a rare genetic disorder characterized by accelerated aging. Genes whose expression is associated with age-related phenotypes and diseases were identified. The data also suggest that an underlying mechanism of the aging process involves increasing errors in the mitotic machinery of dividing cells in the postreproductive stage of life. We propose that this dysfunction leads to chromosomal pathologies that result in misregulation of genes involved in the aging process.

Standard name | NAKAMURA_ADIPOGENESIS_EARLY_UP
Systematic name | M2024
Organism | Homo sapiens
PMID | 12646203
Authors | Nakamura T,Shiojima S,Hirai Y,Iwama T,Tsuruzoe N,Hirasawa A,Katsuma S,Tsujimoto G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mesenchymal stem cells during early phase of adipogenesis, defined as days 1 to 5 of culturing with adipogenic hormones.
Full description | Human bone marrow mesenchymal stem cells (hMSCs) give rise to adipocytes in response to adipogenic hormones. An in-house cDNA microarray representing 3400 genes was employed to characterize the modulation of genes involved in this process. A total of 197 genes showed temporal gene expression changes during adipogenesis, including genes encoding transcriptional regulators and signaling molecules. Semi-quantitative RT-PCR analyses confirmed differential expression at the transcriptional level of several genes identified by cDNA microarray screening. Cluster analysis of the genes regulated during the late phase (from day 7 to day 14) of hMSC adipogenesis indicated that these changes are well correlated with data previously reported for murine preadipocytes. However, during the early phase (day 1-day 5), the modulations of genes differed from those reported for the preadipocytes. These data provide novel information on the molecular mechanisms required for lineage commitment and maturation accompanying adipogenesis of hMSC.

Standard name | NAKAMURA_ADIPOGENESIS_EARLY_DN
Systematic name | M2025
Organism | Homo sapiens
PMID | 12646203
Authors | Nakamura T,Shiojima S,Hirai Y,Iwama T,Tsuruzoe N,Hirasawa A,Katsuma S,Tsujimoto G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mesenchymal stem cells during early phase of adipogenesis, defined as days 1 to 5 of culturing with adipogenic hormones.
Full description | Human bone marrow mesenchymal stem cells (hMSCs) give rise to adipocytes in response to adipogenic hormones. An in-house cDNA microarray representing 3400 genes was employed to characterize the modulation of genes involved in this process. A total of 197 genes showed temporal gene expression changes during adipogenesis, including genes encoding transcriptional regulators and signaling molecules. Semi-quantitative RT-PCR analyses confirmed differential expression at the transcriptional level of several genes identified by cDNA microarray screening. Cluster analysis of the genes regulated during the late phase (from day 7 to day 14) of hMSC adipogenesis indicated that these changes are well correlated with data previously reported for murine preadipocytes. However, during the early phase (day 1-day 5), the modulations of genes differed from those reported for the preadipocytes. These data provide novel information on the molecular mechanisms required for lineage commitment and maturation accompanying adipogenesis of hMSC.

Standard name | NAKAMURA_ADIPOGENESIS_LATE_UP
Systematic name | M2026
Organism | Homo sapiens
PMID | 12646203
Authors | Nakamura T,Shiojima S,Hirai Y,Iwama T,Tsuruzoe N,Hirasawa A,Katsuma S,Tsujimoto G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in mesenchymal stem cells during late phase of adipogenesis, defined as days 7 to 14 of culturing with adipogenic hormones.
Full description | Human bone marrow mesenchymal stem cells (hMSCs) give rise to adipocytes in response to adipogenic hormones. An in-house cDNA microarray representing 3400 genes was employed to characterize the modulation of genes involved in this process. A total of 197 genes showed temporal gene expression changes during adipogenesis, including genes encoding transcriptional regulators and signaling molecules. Semi-quantitative RT-PCR analyses confirmed differential expression at the transcriptional level of several genes identified by cDNA microarray screening. Cluster analysis of the genes regulated during the late phase (from day 7 to day 14) of hMSC adipogenesis indicated that these changes are well correlated with data previously reported for murine preadipocytes. However, during the early phase (day 1-day 5), the modulations of genes differed from those reported for the preadipocytes. These data provide novel information on the molecular mechanisms required for lineage commitment and maturation accompanying adipogenesis of hMSC.

Standard name | NAKAMURA_ADIPOGENESIS_LATE_DN
Systematic name | M2030
Organism | Homo sapiens
PMID | 12646203
Authors | Nakamura T,Shiojima S,Hirai Y,Iwama T,Tsuruzoe N,Hirasawa A,Katsuma S,Tsujimoto G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in mesenchymal stem cells during late phase of adipogenesis, defined as days 7 to 14 of culturing with adipogenic hormones.
Full description | Human bone marrow mesenchymal stem cells (hMSCs) give rise to adipocytes in response to adipogenic hormones. An in-house cDNA microarray representing 3400 genes was employed to characterize the modulation of genes involved in this process. A total of 197 genes showed temporal gene expression changes during adipogenesis, including genes encoding transcriptional regulators and signaling molecules. Semi-quantitative RT-PCR analyses confirmed differential expression at the transcriptional level of several genes identified by cDNA microarray screening. Cluster analysis of the genes regulated during the late phase (from day 7 to day 14) of hMSC adipogenesis indicated that these changes are well correlated with data previously reported for murine preadipocytes. However, during the early phase (day 1-day 5), the modulations of genes differed from those reported for the preadipocytes. These data provide novel information on the molecular mechanisms required for lineage commitment and maturation accompanying adipogenesis of hMSC.

Standard name | RAMPON_ENRICHED_LEARNING_ENVIRONMENT_EARLY_DN
Systematic name | M2031
Organism | Mus musculus
PMID | 11070096
Authors | Rampon C,Jiang CH,Dong H,Tang YP,Lockhart DJ,Schultz PG,Tsien JZ,Hu Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the brain cortex of mice that were exposed to an enriched learning environment for one day.
Full description | An enriched environment is known to promote structural changes in the brain and to enhance learning and memory performance in rodents [Hebb, D. O. (1947) Am. Psychol. 2, 306-307]. To better understand the molecular mechanisms underlying these experience-dependent cognitive changes, we have used high-density oligonucleotide microarrays to analyze gene expression in the brain. Expression of a large number of genes changes in response to enrichment training, many of which can be linked to neuronal structure, synaptic plasticity, and transmission. A number of these genes may play important roles in modulating learning and memory capacity.

Standard name | VERRECCHIA_RESPONSE_TO_TGFB1_C6
Systematic name | M15374
Organism | Homo sapiens
PMID | 11279127
Authors | Verrecchia F,Chu ML,Mauviel A
Category | C2
Sub-category | CGP
Brief description | Cluster 6: ECM related genes up-regulated in dermal fibroblasts later than 30 min after TGFB1 [GeneID=7040] addition; slowly increased up to 120 min time point, then reached a plateau.
Full description | Despite major advances in the understanding of the intimate mechanisms of transforming growth factor-beta (TGF-beta) signaling through the Smad pathway, little progress has been made in the identification of direct target genes. In this report, using cDNA microarrays, we have focussed our attention on the characterization of extracellular matrix-related genes rapidly induced by TGF-beta in human dermal fibroblasts and attempted to identify the ones whose up-regulation by TGF-beta is Smad-mediated. For a gene to qualify as a direct Smad target, we postulated that it had to meet the following criteria: (1) rapid (30 min) and significant (at least 2-fold) elevation of steady-state mRNA levels upon TGF-beta stimulation, (2) activation of the promoter by both exogenous TGF-beta and co-transfected Smad3 expression vector, (3) up-regulation of promoter activity by TGF-beta blocked by both dominant-negative Smad3 and inhibitory Smad7 expression vectors, and (4) promoter transactivation by TGF-beta not possible in Smad3(-/-) mouse embryo fibroblasts. Using this stringent approach, we have identified COL1A2, COL3A1, COL6A1, COL6A3, and tissue inhibitor of metalloproteases-1 as definite TGF-beta/Smad3 targets. Extrapolation of this approach to other extracellular matrix-related gene promoters also identified COL1A1 and COL5A2, but not COL6A2, as novel Smad targets. Together, these results represent a significant step toward the identification of novel, early-induced Smad-dependent TGF-beta target genes in fibroblasts.

Standard name | BAUS_TFF2_TARGETS_UP
Systematic name | M2035
Organism | Mus musculus
PMID | 16121031
Authors | Baus-Loncar M,Schmid J,Lalani el-N,Rosewell I,Goodlad RA,Stamp GW,Blin N,Kayademir T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pyloric atrium with knockout of TFF2 [GeneID=7032].
Full description | BACKGROUND AND AIMS: The gastrointestinal trefoil factor family (TFF1, TFF2, TFF3) peptides are considered to play an important role in maintaining the integrity of the mucosa. The physiological role of TFF2 in the protection of the GI tract was investigated in TFF2 deficiency. METHODS: TFF2-/- mice were generated and differential expression of various genes was assessed by using a mouse expression microarray, quantitative real time PCR, Northern blots or immunohistochemistry. RESULTS: On an mRNA level we found 128 differentially expressed genes. We observed modulation of a number of crucial genes involved in innate and adaptive immunity in the TFF2-/- mice. Expression of proteasomal subunits genes (LMP2, LMP7 and PSMB5) involved in the MHC class I presentation pathway were modulated indicating the formation of immunoproteasomes improving antigen presentation. Expression of one subunit of a transporter (TAP1) responsible for importing degraded antigens into ER was increased, similarly to the BAG2 gene that modulates chaperone activity in ER helping proper loading on MHC class I molecules. Several mouse defensin (cryptdin) genes coding important intestinal microbicidal proteins were up-regulated as a consequence of TFF2 deficiency. Normally moderate expression of TFF3 was highly increased in stomach.

Standard name | BAUS_TFF2_TARGETS_DN
Systematic name | M2036
Organism | Mus musculus
PMID | 16121031
Authors | Baus-Loncar M,Schmid J,Lalani el-N,Rosewell I,Goodlad RA,Stamp GW,Blin N,Kayademir T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pyloric atrium with knockout of TFF2 [GeneID=7032].
Full description | BACKGROUND AND AIMS: The gastrointestinal trefoil factor family (TFF1, TFF2, TFF3) peptides are considered to play an important role in maintaining the integrity of the mucosa. The physiological role of TFF2 in the protection of the GI tract was investigated in TFF2 deficiency. METHODS: TFF2-/- mice were generated and differential expression of various genes was assessed by using a mouse expression microarray, quantitative real time PCR, Northern blots or immunohistochemistry. RESULTS: On an mRNA level we found 128 differentially expressed genes. We observed modulation of a number of crucial genes involved in innate and adaptive immunity in the TFF2-/- mice. Expression of proteasomal subunits genes (LMP2, LMP7 and PSMB5) involved in the MHC class I presentation pathway were modulated indicating the formation of immunoproteasomes improving antigen presentation. Expression of one subunit of a transporter (TAP1) responsible for importing degraded antigens into ER was increased, similarly to the BAG2 gene that modulates chaperone activity in ER helping proper loading on MHC class I molecules. Several mouse defensin (cryptdin) genes coding important intestinal microbicidal proteins were up-regulated as a consequence of TFF2 deficiency. Normally moderate expression of TFF3 was highly increased in stomach.

Standard name | KAMMINGA_SENESCENCE
Systematic name | M2037
Organism | Mus musculus
PMID | 16293602
Authors | Kamminga LM,Bystrykh LV,de Boer A,Houwer S,Douma J,Weersing E,Dontje B,de Haan G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated on serial passage of MEF cells (embryonic fibroblast).
Full description | The molecular mechanism responsible for a decline of stem cell functioning after replicative stress remains unknown. We used mouse embryonic fibroblasts (MEFs) and hematopoietic stem cells (HSCs) to identify genes involved in the process of cellular aging. In proliferating and senescent MEFs one of the most differentially expressed transcripts was Enhancer of zeste homolog 2 (Ezh2), a Polycomb group protein (PcG) involved in histone methylation and deacetylation. Retroviral overexpression of Ezh2 in MEFs resulted in bypassing of the senescence program. More importantly, whereas normal HSCs were rapidly exhausted after serial transplantations, overexpression of Ezh2 completely conserved long-term repopulating potential. Animals that were reconstituted with 3 times serially transplanted control bone marrow cells all died due to hematopoietic failure. In contrast, similarly transplanted Ezh2-overexpressing stem cells restored stem cell quality to normal levels. In a genetic genomics screen, we identified novel putative Ezh2 target or partner stem cell genes that are associated with chromatin modification. Our data suggest that stabilization of the chromatin structure preserves HSC potential after replicative stress.

Standard name | HO_LIVER_CANCER_VASCULAR_INVASION
Systematic name | M8773
Organism | Homo sapiens
PMID | 17009164
Authors | Ho MC,Lin JJ,Chen CN,Chen CC,Lee H,Yang CY,Ni YH,Chang KJ,Hsu HC,Hsieh FJ,Lee PH
Category | C2
Sub-category | CGP
Brief description | Gene expression signature of vascular invasion of hepatocellular carcinoma (HCC).
Full description | BACKGROUND: Recurrence after hepatocellular carcinoma (HCC) resection is the major obstacle to improved survival. The presence of vascular invasion (VI) in pathology specimens is a well-known unfavorable prognostic factor for HCC recurrence. Though some VI-related genes have been reported, their association with recurrence-free survival is not known. We hypothesized that a gene expression profile for VI can predict the recurrence of HCC after liver resection. METHODS: Eighteen patients receiving complete HCC resection were included as a training group. Genome-wide gene expression profile was obtained for each tumor using a microarray technique. Datasets were subjected to clustering analysis supervised by the presence or absence of VI to obtain 14 discriminative genes. We then applied those genes to execute pattern recognition using the k-Nearest Neighbor (KNN) classification method, and the best model for this VI gene signature to predict recurrence-free survival in the training group was obtained. The resulting model was then tested in an independent test group of 35 patients. RESULTS: A 14-gene profile was extracted which could accurately separate ten patients with VI and eight patients without VI in the training group. In the test group, significant difference in disease-free survival was found between patients predicted to have and not to have recurrence (P = .02823). In patients with stage_I disease, this model can also predict outcomes (P = .000205). CONCLUSIONS: Using the 14-gene expression profile extracted from microarrays based on the presence of VI can effectively predict recurrence after HCC resection. This approach might facilitate personalized medicine for HCC patients after surgical resection.

Standard name | GERHOLD_RESPONSE_TO_TZD_UP
Systematic name | M2040
Organism | Mus musculus
PMID | 12021175
Authors | Gerhold DL,Liu F,Jiang G,Li Z,Xu J,Lu M,Sachs JR,Bagchi A,Fridman A,Holder DJ,Doebber TW,Berger J,Elbrecht A,Moller DE,Zhang BB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 3T3-L1 cells (fibroblast) induced to differentiate to mature adipocytes and then treated with a TZD derivative AD-5075 [PubChem=128440], a PPARG [GeneID=5468] activator.
Full description | PPAR gamma is an adipocyte-specific nuclear hormone receptor. Agonists of PPAR gamma, such as thiazolidinediones (TZDs), promote adipocyte differentiation and have insulin-sensitizing effects in animals and diabetic patients. Affymetrix oligonucleotide arrays representing 6347 genes were employed to profile the gene expression responses of mature 3T3-L1 adipocytes and differentiating preadipocytes to a TZD PPAR gamma agonist in vitro. The expression of 579 genes was significantly up- or down-regulated by more than 1.5-fold during differentiation and/or by treatment with TZD, and these genes were organized into 32 clusters that demonstrated concerted changes in expression of genes controlling cell growth or lipid metabolism. Quantitative PCR was employed to further characterize gene expression and led to the identification of beta-catenin as a new PPAR gamma target gene. Both mRNA and protein levels for beta-catenin were down-regulated in 3T3-L1 adipocytes compared with fibroblasts and were further decreased by treatment of adipocytes with PPAR gamma agonists. Treatment of db/db mice with a PPAR gamma agonist also resulted in reduction of beta-catenin mRNA levels in adipose tissue. These results suggest that beta-catenin plays an important role in the regulation of adipogenesis. Thus, the transcriptional patterns revealed in this study further the understanding of adipogenesis process and the function of PPAR gamma activation.

Standard name | GERHOLD_RESPONSE_TO_TZD_DN
Systematic name | M2041
Organism | Mus musculus
PMID | 12021175
Authors | Gerhold DL,Liu F,Jiang G,Li Z,Xu J,Lu M,Sachs JR,Bagchi A,Fridman A,Holder DJ,Doebber TW,Berger J,Elbrecht A,Moller DE,Zhang BB
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 3T3-L1 cells (fibroblast) induced to differentiate to mature adipocytes and then treated with a TZD derivative AD-5075 [PubChem=128440], a PPARG [GeneID=5468] activator.
Full description | PPAR gamma is an adipocyte-specific nuclear hormone receptor. Agonists of PPAR gamma, such as thiazolidinediones (TZDs), promote adipocyte differentiation and have insulin-sensitizing effects in animals and diabetic patients. Affymetrix oligonucleotide arrays representing 6347 genes were employed to profile the gene expression responses of mature 3T3-L1 adipocytes and differentiating preadipocytes to a TZD PPAR gamma agonist in vitro. The expression of 579 genes was significantly up- or down-regulated by more than 1.5-fold during differentiation and/or by treatment with TZD, and these genes were organized into 32 clusters that demonstrated concerted changes in expression of genes controlling cell growth or lipid metabolism. Quantitative PCR was employed to further characterize gene expression and led to the identification of beta-catenin as a new PPAR gamma target gene. Both mRNA and protein levels for beta-catenin were down-regulated in 3T3-L1 adipocytes compared with fibroblasts and were further decreased by treatment of adipocytes with PPAR gamma agonists. Treatment of db/db mice with a PPAR gamma agonist also resulted in reduction of beta-catenin mRNA levels in adipose tissue. These results suggest that beta-catenin plays an important role in the regulation of adipogenesis. Thus, the transcriptional patterns revealed in this study further the understanding of adipogenesis process and the function of PPAR gamma activation.

Standard name | MARIADASON_RESPONSE_TO_BUTYRATE_CURCUMIN_SULINDAC_TSA_1
Systematic name | M2045
Organism | Homo sapiens
PMID | 10969808
Authors | Mariadason JM,Corner GA,Augenlicht LH
Category | C2
Sub-category | CGP
Brief description | Cluster 1: genes up-regulated in SW260 cells (colon cancer) by sodium butyrate, curcumin, sulindac and TSA [PubChem=5222465;969516;5352;5562].
Full description | The short-chain fatty acid butyrate, produced by microbial fermentation of dietary fiber in the large intestine, is a physiological regulator of major pathways of colonic epithelial cell maturation: cell cycle arrest, lineage-specific differentiation, and apoptosis. Microarray analysis of 8,063 sequences demonstrated a complex cascade of reprogramming of SW620 colonic epithelial cells upon treatment with butyrate characterized by the progressive recruitment of gene sets as a function of time. Comparison with the effects of trichostatin A, in conjunction with differences in the kinetics of alteration of histone acetylation induced by butyrate and trichostatin A, identified subsets of induced and repressed genes likely coordinately regulated by altered histone acetylation. The butyrate response was also compared in detail with that of sulindac, a nonsteroidal anti-inflammatory drug with significant chemopreventive activity for colon cancer, and curcumin, a component of mustard and curry structurally and functionally related to sulindac that also has chemopreventive activity. Although gene clusters were identified that showed similar responses to butyrate and sulindac, the data were characterized by the extensive differences in the effects of the two agents. This was striking for functional classes of genes involved in signaling pathways and in cell cycle progression, although butyrate and sulindac induce a similar G0-G1 arrest, elevation of beta-catenin-Tcf signaling, and apoptotic cascade. As regards cell cycle arrest, the underlying mechanism in response to butyrate was most similar to that of the Caco-2 cell line that had spontaneously undergone a G0-G1 arrest and least similar to the G2-M arrest stimulated by curcumin. Thus, high-throughput microarray analysis of gene expression profiles can be used to characterize and distinguish the mechanisms of response of colonic epithelial cells to physiological and pharmacological inducers of cell maturation. This has important implications for characterization of chemopreventive agents and recognition of potential toxicity and synergies. The data bases, gene clusters, and analyses are available at http:// sequence.aecom.yu.edu/genome/.

Standard name | MARIADASON_RESPONSE_TO_BUTYRATE_CURCUMIN_SULINDAC_TSA_2
Systematic name | M2046
Organism | Homo sapiens
PMID | 10969808
Authors | Mariadason JM,Corner GA,Augenlicht LH
Category | C2
Sub-category | CGP
Brief description | Cluster 2: genes up-regulated in SW260 cells (colon cancer) by sodium butyrate, curcumin, sulindac and TSA [PubChem=5222465;969516;5352;5562].
Full description | The short-chain fatty acid butyrate, produced by microbial fermentation of dietary fiber in the large intestine, is a physiological regulator of major pathways of colonic epithelial cell maturation: cell cycle arrest, lineage-specific differentiation, and apoptosis. Microarray analysis of 8,063 sequences demonstrated a complex cascade of reprogramming of SW620 colonic epithelial cells upon treatment with butyrate characterized by the progressive recruitment of gene sets as a function of time. Comparison with the effects of trichostatin A, in conjunction with differences in the kinetics of alteration of histone acetylation induced by butyrate and trichostatin A, identified subsets of induced and repressed genes likely coordinately regulated by altered histone acetylation. The butyrate response was also compared in detail with that of sulindac, a nonsteroidal anti-inflammatory drug with significant chemopreventive activity for colon cancer, and curcumin, a component of mustard and curry structurally and functionally related to sulindac that also has chemopreventive activity. Although gene clusters were identified that showed similar responses to butyrate and sulindac, the data were characterized by the extensive differences in the effects of the two agents. This was striking for functional classes of genes involved in signaling pathways and in cell cycle progression, although butyrate and sulindac induce a similar G0-G1 arrest, elevation of beta-catenin-Tcf signaling, and apoptotic cascade. As regards cell cycle arrest, the underlying mechanism in response to butyrate was most similar to that of the Caco-2 cell line that had spontaneously undergone a G0-G1 arrest and least similar to the G2-M arrest stimulated by curcumin. Thus, high-throughput microarray analysis of gene expression profiles can be used to characterize and distinguish the mechanisms of response of colonic epithelial cells to physiological and pharmacological inducers of cell maturation. This has important implications for characterization of chemopreventive agents and recognition of potential toxicity and synergies. The data bases, gene clusters, and analyses are available at http:// sequence.aecom.yu.edu/genome/.

Standard name | MURAKAMI_UV_RESPONSE_1HR_UP
Systematic name | M13308
Organism | Homo sapiens
PMID | 11532376
Authors | Murakami T,Fujimoto M,Ohtsuki M,Nakagawa H
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary keratinocytes at 1 h after UVB irradiation.
Full description | Ultraviolet B irradiation initiates and promotes skin cancers, photo-aging, and immune suppression. In order to elucidate the effect of these processes at the level of gene expression, we used cDNA microarray technology to examine the effect of ultraviolet B irradiation on 588 cancer-related genes in human keratinocytes at 1, 6, and 24 h post-irradiation with a mildly cytotoxic dose of ultraviolet B (170 mJ/cm(2)). The viability of the irradiated keratinocytes was 75% at 24 h post-irradiation. Various cytokeratins and transcription factors were up-regulated within 1 h post-irradiation. After 6 h, expression of a variety of genes related to growth regulation (e.g. p21(WAF1), notch 4, and smoothened), apoptosis (e.g. caspase 10, hTRIP, and CRAF1), DNA repair (ERCC1, XRCC1), cytokines (e.g. IL-6, IL-13, TGF-beta, and endothelin 2), and cell adhesion (e.g. RhoE, and RhoGDI) were altered in human keratinocytes. These data suggest the changes in a cascade of gene expression in human keratinocytes occurring within 24 h after UVB exposure. Although the roles of these cellular genes after UVB-irradiation remain to be elucidated, microarray analysis may provide a new view of gene expression in epidermal keratinocytes following UVB exposure.

Standard name | MURAKAMI_UV_RESPONSE_1HR_DN
Systematic name | M9172
Organism | Homo sapiens
PMID | 11532376
Authors | Murakami T,Fujimoto M,Ohtsuki M,Nakagawa H
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary keratinocytes at 1 h after UVB irradiation.
Full description | Ultraviolet B irradiation initiates and promotes skin cancers, photo-aging, and immune suppression. In order to elucidate the effect of these processes at the level of gene expression, we used cDNA microarray technology to examine the effect of ultraviolet B irradiation on 588 cancer-related genes in human keratinocytes at 1, 6, and 24 h post-irradiation with a mildly cytotoxic dose of ultraviolet B (170 mJ/cm(2)). The viability of the irradiated keratinocytes was 75% at 24 h post-irradiation. Various cytokeratins and transcription factors were up-regulated within 1 h post-irradiation. After 6 h, expression of a variety of genes related to growth regulation (e.g. p21(WAF1), notch 4, and smoothened), apoptosis (e.g. caspase 10, hTRIP, and CRAF1), DNA repair (ERCC1, XRCC1), cytokines (e.g. IL-6, IL-13, TGF-beta, and endothelin 2), and cell adhesion (e.g. RhoE, and RhoGDI) were altered in human keratinocytes. These data suggest the changes in a cascade of gene expression in human keratinocytes occurring within 24 h after UVB exposure. Although the roles of these cellular genes after UVB-irradiation remain to be elucidated, microarray analysis may provide a new view of gene expression in epidermal keratinocytes following UVB exposure.

Standard name | KYNG_RESPONSE_TO_H2O2_VIA_ERCC6_UP
Systematic name | M2047
Organism | Homo sapiens
PMID | 12606941
Authors | Kyng KJ,May A,Brosh RM Jr,Cheng WH,Chen C,Becker KG,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in response to hydorgen peroxyde [PubChem=784] in CS-B cells (Cockaine syndrome fibroblast, CS) with defficient ERCC6 [GeneID=2074].
Full description | Cockayne syndrome (CS) is a human hereditary disease belonging to the group of segmental progerias, and the clinical phenotype is characterized by postnatal growth failure, neurological dysfunction, cachetic dwarfism, photosensitivity, sensorineural hearing loss, and retinal degradation. CS-B cells are defective in transcription-coupled DNA repair, base excision repair, transcription, and chromatin structural organization. Using array analysis, we have examined the expression profile in CS complementation group B (CS-B) fibroblasts after exposure to oxidative stress (H2O2) before and after complete complementation with the CSB gene. The following isogenic cell lines were compared: CS-B cells (CS-B null), CS-B cells complemented with wild-type CSB (CS-B wt), and a stably transformed cell line with a point mutation in the ATPase domain of CSB (CS-B ATPase mutant). In the wt rescued cells, we detected significant induction (two-fold) of 112 genes out of the 6912 analysed. The patterns suggested an induction or upregulation of genes involved in several DNA metabolic processes including DNA repair, transcription, and signal transduction. In both CS-B mutant cell lines, we found a general deficiency in transcription after oxidative stress, suggesting that the CSB protein influenced the regulation of transcription of certain genes. Of the 6912 genes, 122 were differentially regulated by more than two-fold. Evidently, the ATPase function of CSB is biologically important as the deficiencies seen in the ATPase mutant cells are very similar to those observed in the CS-B-null cells. Some major defects are in the transcription of genes involved in DNA repair, signal transduction, and ribosomal functions.

Standard name | KYNG_RESPONSE_TO_H2O2_VIA_ERCC6_DN
Systematic name | M2048
Organism | Homo sapiens
PMID | 12606941
Authors | Kyng KJ,May A,Brosh RM Jr,Cheng WH,Chen C,Becker KG,Bohr VA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in response to hydorgen peroxyde [PubChem=784] in CS-B cells (Cockaine syndrome fibroblast, CS) with defficient ERCC6 [GeneID=2074].
Full description | Cockayne syndrome (CS) is a human hereditary disease belonging to the group of segmental progerias, and the clinical phenotype is characterized by postnatal growth failure, neurological dysfunction, cachetic dwarfism, photosensitivity, sensorineural hearing loss, and retinal degradation. CS-B cells are defective in transcription-coupled DNA repair, base excision repair, transcription, and chromatin structural organization. Using array analysis, we have examined the expression profile in CS complementation group B (CS-B) fibroblasts after exposure to oxidative stress (H2O2) before and after complete complementation with the CSB gene. The following isogenic cell lines were compared: CS-B cells (CS-B null), CS-B cells complemented with wild-type CSB (CS-B wt), and a stably transformed cell line with a point mutation in the ATPase domain of CSB (CS-B ATPase mutant). In the wt rescued cells, we detected significant induction (two-fold) of 112 genes out of the 6912 analysed. The patterns suggested an induction or upregulation of genes involved in several DNA metabolic processes including DNA repair, transcription, and signal transduction. In both CS-B mutant cell lines, we found a general deficiency in transcription after oxidative stress, suggesting that the CSB protein influenced the regulation of transcription of certain genes. Of the 6912 genes, 122 were differentially regulated by more than two-fold. Evidently, the ATPase function of CSB is biologically important as the deficiencies seen in the ATPase mutant cells are very similar to those observed in the CS-B-null cells. Some major defects are in the transcription of genes involved in DNA repair, signal transduction, and ribosomal functions.

Standard name | VISALA_AGING_LYMPHOCYTE_UP
Systematic name | M2050
Organism | Homo sapiens
PMID | 12618007
Authors | Visala Rao D,Boyle GM,Parsons PG,Watson K,Jones GL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in peripheral lymphocytes from old individuals compared to those from young donors.
Full description | Ageing results in a progressive, intrinsic and generalised imbalance of the control of regulatory systems. A key manifestation of this complex biological process includes the attenuation of the universal stress response. Here we provide the first global assessment of the ageing process as it affects the heat shock response, utilising human peripheral lymphocytes and cDNA microarray analysis. The genomic approach employed in our preliminary study was supplemented with a proteomic approach. In addition, the current study correlates the in vivo total antioxidant status with the age-related differential gene expression as well as the translational kinetics of heat shock proteins (hsps). Most of the genes encoding stress response proteins on the 4224 element microarray used in this study were significantly elevated after heat shock treatment of lymphocytes obtained from both young and old individuals albeit to a greater extent in the young. Cell signaling and signal transduction genes as well as some oxidoreductases showed varied response. Results from translational kinetics of induction of major hsps, from 0 to 24 h recovery period were broadly consistent with the differential expression of HSC 70 and HSP 40 genes. Total antioxidant levels in plasma from old individuals were found to be significantly lower by comparison with young, in agreement with the widely acknowledged role of oxidant homeostasis in the ageing process.

Standard name | DAZARD_UV_RESPONSE_CLUSTER_G5
Systematic name | M15114
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Cluster G5: genes up-regulated in NHEK cells (normal keratinocyte) at 3 h and 24 h time points after UV-B irradiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | DAZARD_UV_RESPONSE_CLUSTER_G24
Systematic name | M5002
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Cluster G24: genes induced in NHEK (normal keratinocyte) but not in SCC12B2 cells (squamous cell carcinoma) by UV-B radiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | DAZARD_UV_RESPONSE_CLUSTER_G28
Systematic name | M2055
Organism | Homo sapiens
PMID | 12771951
Authors | Dazard JE,Gal H,Amariglio N,Rechavi G,Domany E,Givol D
Category | C2
Sub-category | CGP
Brief description | Cluster G28: genes differentially up-regulated in NHEK (normal keratinocyte) compared to SCC12B2 cells (squamous cell carcinoma) by UV-B radiation.
Full description | To gain insight into the transformation of epidermal cells into squamous carcinoma cells (SCC), we compared the response to ultraviolet B radiation (UVB) of normal human epidermal keratinocytes (NHEK) versus their transformed counterpart, SCC, using biological and molecular profiling. DNA microarray analyses (Affymetrix), approximately 12000 genes) indicated that the major group of upregulated genes in keratinocytes fall into three categories: (i). antiapoptotic and cell survival factors, including chemokines of the CXC/CC subfamilies (e.g. IL-8, GRO-1, -2, -3, SCYA20), growth factors (e.g. HB-EGF, CTGF, INSL-4), and proinflammatory mediators (e.g. COX-2, S100A9), (ii). DNA repair-related genes (e.g. GADD45, ERCC, BTG-1, Histones), and (iii). ECM proteases (MMP-1, -10). The major downregulated genes are DeltaNp63 and PUMILIO, two potential markers for the maintenance of keratinocyte stem cells. NHEK were found to be more resistant than SCC to UVB-induced apoptosis and this resistance was mainly because of the protection from cell death by secreted survival factors, since it can be transferred from NHEK to SCC cultures by the conditioned medium. Whereas the response of keratinocytes to UVB involved regulation of key checkpoint genes (p53, MDM2, p21(Cip1), DeltaNp63), as well as antiapoptotic and DNA repair-related genes - no or little regulation of these genes was observed in SCC. The effect of UVB on NHEK and SCC resulted in upregulation of 251 and 127 genes, respectively, and downregulation of 322 genes in NHEK and 117 genes in SCC. To further analyse these changes, we used a novel unsupervised coupled two-way clustering method that allowed the identification of groups of genes that clearly partitioned keratinocytes from SCC, including a group of genes whose constitutive expression levels were similar before UVB. This allowed the identification of discriminating genes not otherwise revealed by simple static comparison in the absence of UVB irradiation. The implication of the changes in gene profile in keratinocytes for epithelial cancer is discussed.

Standard name | RUAN_RESPONSE_TO_TROGLITAZONE_DN
Systematic name | M2056
Organism | Homo sapiens
PMID | 12732648
Authors | Ruan H,Pownall HJ,Lodish HF
Category | C2
Sub-category | CGP
Brief description | Adipocyte abundant genes down-regulated in 3T3-L1 cells (fibroblasts induced to differentiate to adipocytes) in response to troglitazone [PubChem=5591].
Full description | Troglitazone (TGZ), a member of the thiazolidinedione class of anti-diabetic compounds and a peroxisome proliferator activator receptor-gamma (PPAR-gamma) agonist, restores systemic insulin sensitivity and improves the full insulin resistance syndrome in vivo. The mechanisms underlying its in vivo function are not understood. Here we investigated the potential functional interaction between PPAR-gamma and NF-kappaB in adipocytes. We show that TGZ selectively blocked tumor necrosis factor-alpha-induced and NF-kappaB-dependent repression of multiple adipocyte-specific genes and induction of growth phase and other genes. This occurs without interfering with NF-kappaB expression, activation, nuclear translocation, or DNA binding and without suppressing NF-kappaB-dependent survival signals. Notably, the expressions of some tumor necrosis factor-alpha-induced genes in adipocytes were unaffected by PPAR-gamma activation. In reporter gene assays in HeLa cells, ectopic expression of PPAR-gamma abolished induction of a NF-kappaB-responsive reporter gene by the p65 subunit (RelA) of NF-kappaB, and the inhibition was further enhanced in the presence of TGZ. Conversely, overexpression of p65 inhibited induction of a PPAR-gamma-responsive reporter gene by activated PPAR-gamma in a dose-dependent manner. The inhibitory effect was independent of the presence of NF-kappaB-binding sites in the promoter region. Other NF-kappaB family members, p50 and c-Rel as well as the S276A mutant of p65, blocked PPAR-gamma-mediated gene transcription less effectively. Thus, p65 antagonizes the transcriptional regulatory activity of PPAR-gamma in adipocytes, and PPAR-gamma activation can at least partially override the inhibitory effects of p65 on the expression of key adipocyte genes. Our data suggest that inhibition of NF-kappaB activity is a mechanism by which PPAR-gamma agonists improve insulin sensitivity in vivo and that adipocyte NF-kappaB is a potential therapeutic target for obesity-linked type 2 diabetes.

Standard name | DASU_IL6_SIGNALING_UP
Systematic name | M14344
Organism | Homo sapiens
PMID | 15095275
Authors | Dasu MR,Hawkins HK,Barrow RE,Xue H,Herndon DN
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in normal fibroblasts in response to IL6 [GeneID=3569].
Full description | The structural rearrangement of collagen fibres in hypertrophic scar causes abnormal contracture, low tensile strength, and raised scars, which cause functional impairment and disfigurement. It is hypothesized that changes in the genes of cytokines, extracellular matrix proteins, and proteins regulating programmed cell death are related to hypertrophic scar formation. To test this hypothesis, fibroblasts were cultured from hypertrophic scars and their response to interleukin-6 (IL-6) stimulation was studied by defining their gene expression profiles. Affymetrix gene chip analysis was used to identify up- or down-regulation in the 12 625 genes present in the affymetrix array. RT-PCR and ELISA assays were used to validate microarray expression profiles further. Comparison of gene profiles showed an increase of 12 genes in hypertrophic scar fibroblasts compared with normal skin fibroblasts, while the expression of 14 genes decreased. Thirty-three genes were affected by IL-6 treatment in the hypertrophic scar fibroblasts, while 57 genes were affected in normal skin fibroblasts. Messenger RNA to beta-actin ratios for matrix metalloproteinase-1 (MMP-1) and MMP-3 were increased with IL-6 in normal skin fibroblasts from 2.43 +/- 0.06 to 5.50 +/- 0.45 and from 0.75 +/- 0.09 to 1.98 +/- 0.01, respectively. No change in these matrix metalloproteinases could be shown with IL-6 stimulation in hypertrophic scar fibroblasts. Secreted protein levels of pro-MMP-1 and MMP-3 were elevated in the supernatants from normal skin fibroblasts from 2.00 +/- 0.09 and 1.72 +/- 0.10 ng/ml to 4.60 +/- 0.12 and 3.41 +/- 0.20 ng/ml, respectively, after treatment with IL-6 (p < 0.05). No changes were observed in hypertrophic scar fibroblasts treated with IL-6. Values are means +/- SEM. The absence of any up-regulation of MMP-1 and MMP-3 in hypertrophic scar fibroblasts, in response to IL-6, suggests that suppression of matrix metalloproteinases may play a role in the excessive accumulation of collagen formed in hypertrophic scars. While the pathogenesis of abnormal hypertrophic scars remains poorly understood, the use of gene expression arrays may prove helpful in identifying the mechanisms responsible for this type of abnormal scar formation and in formulating an effective therapeutic protocol.

Standard name | DASU_IL6_SIGNALING_DN
Systematic name | M17837
Organism | Homo sapiens
PMID | 15095275
Authors | Dasu MR,Hawkins HK,Barrow RE,Xue H,Herndon DN
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in normal fibroblasts in response to IL6 [GeneID=3569].
Full description | The structural rearrangement of collagen fibres in hypertrophic scar causes abnormal contracture, low tensile strength, and raised scars, which cause functional impairment and disfigurement. It is hypothesized that changes in the genes of cytokines, extracellular matrix proteins, and proteins regulating programmed cell death are related to hypertrophic scar formation. To test this hypothesis, fibroblasts were cultured from hypertrophic scars and their response to interleukin-6 (IL-6) stimulation was studied by defining their gene expression profiles. Affymetrix gene chip analysis was used to identify up- or down-regulation in the 12 625 genes present in the affymetrix array. RT-PCR and ELISA assays were used to validate microarray expression profiles further. Comparison of gene profiles showed an increase of 12 genes in hypertrophic scar fibroblasts compared with normal skin fibroblasts, while the expression of 14 genes decreased. Thirty-three genes were affected by IL-6 treatment in the hypertrophic scar fibroblasts, while 57 genes were affected in normal skin fibroblasts. Messenger RNA to beta-actin ratios for matrix metalloproteinase-1 (MMP-1) and MMP-3 were increased with IL-6 in normal skin fibroblasts from 2.43 +/- 0.06 to 5.50 +/- 0.45 and from 0.75 +/- 0.09 to 1.98 +/- 0.01, respectively. No change in these matrix metalloproteinases could be shown with IL-6 stimulation in hypertrophic scar fibroblasts. Secreted protein levels of pro-MMP-1 and MMP-3 were elevated in the supernatants from normal skin fibroblasts from 2.00 +/- 0.09 and 1.72 +/- 0.10 ng/ml to 4.60 +/- 0.12 and 3.41 +/- 0.20 ng/ml, respectively, after treatment with IL-6 (p < 0.05). No changes were observed in hypertrophic scar fibroblasts treated with IL-6. Values are means +/- SEM. The absence of any up-regulation of MMP-1 and MMP-3 in hypertrophic scar fibroblasts, in response to IL-6, suggests that suppression of matrix metalloproteinases may play a role in the excessive accumulation of collagen formed in hypertrophic scars. While the pathogenesis of abnormal hypertrophic scars remains poorly understood, the use of gene expression arrays may prove helpful in identifying the mechanisms responsible for this type of abnormal scar formation and in formulating an effective therapeutic protocol.

Standard name | BANDRES_RESPONSE_TO_CARMUSTIN_WITHOUT_MGMT_24HR_DN
Systematic name | M5407
Organism | Homo sapiens
PMID | 15980968
Authors | Bandres E,Andion E,Escalada A,Honorato B,Catalan V,Cubedo E,Cordeu L,Garcia F,Zarate R,Zabalegui N,Garcia-Foncillas J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A172 cells (glioma, does not express MGMT [GeneID=4255]) by carmustine [PubChem=2578] at 24 h.
Full description | Chemotherapy with the alkylating agent BCNU (1,3-bis (2-chloroethyl)-1-nitrosourea) is the most commonly used chemotherapeutic agent for gliomas. However, the usefulness of this agent is limited because tumor cell resistance to BCNU is frequently found in clinical brain tumor therapy. The O6-methylguanine-DNA methyltransferase protein (MGMT) reverses alkylation at the O6 position of guanine and we have reported the role of MGMT in the response of brain tumors to alkylating agents. However, the different mechanisms underlying the patterns related to MGMT remain unclear. To better understand the molecular mechanism by which BCNU exerts its effect in glioma cell lines according MGMT expression, we used microarray technology to interrogate 3800 known genes and determine the gene expression profiles altered by BCNU treatment. Our results showed that treatment with BCNU alters the expression of a diverse group of genes in a time-dependent manner. A subset of gene changes was found common in both glioma cell lines and other subset is specific of each cell line. After 24 h of BCNU treatment, up-regulation of transcription factors involved in the nucleation of both RNA polymerase II and III transcription initiation complexes was reported. Interestingly, BCNU promoted the expression of actin-dependent regulators of chromatin. Similar effects were found with higher BCNU doses in MGMT+ cell line showing a similar mechanism that in MGMT-deficient cell with standard doses. Our data suggest that human glioma cell lines treated with BCNU, independently of MGMT expression, show changes in the expression of cell cycle and survival-related genes interfering the transcription mechanisms and the chromatin regulation.

Standard name | BANDRES_RESPONSE_TO_CARMUSTIN_MGMT_24HR_UP
Systematic name | M15132
Organism | Homo sapiens
PMID | 15980968
Authors | Bandres E,Andion E,Escalada A,Honorato B,Catalan V,Cubedo E,Cordeu L,Garcia F,Zarate R,Zabalegui N,Garcia-Foncillas J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in T98G cells (glioma, express MGMT [GeneID=4255]) by carmustine [PubChem=2578] at 24 h.
Full description | Chemotherapy with the alkylating agent BCNU (1,3-bis (2-chloroethyl)-1-nitrosourea) is the most commonly used chemotherapeutic agent for gliomas. However, the usefulness of this agent is limited because tumor cell resistance to BCNU is frequently found in clinical brain tumor therapy. The O6-methylguanine-DNA methyltransferase protein (MGMT) reverses alkylation at the O6 position of guanine and we have reported the role of MGMT in the response of brain tumors to alkylating agents. However, the different mechanisms underlying the patterns related to MGMT remain unclear. To better understand the molecular mechanism by which BCNU exerts its effect in glioma cell lines according MGMT expression, we used microarray technology to interrogate 3800 known genes and determine the gene expression profiles altered by BCNU treatment. Our results showed that treatment with BCNU alters the expression of a diverse group of genes in a time-dependent manner. A subset of gene changes was found common in both glioma cell lines and other subset is specific of each cell line. After 24 h of BCNU treatment, up-regulation of transcription factors involved in the nucleation of both RNA polymerase II and III transcription initiation complexes was reported. Interestingly, BCNU promoted the expression of actin-dependent regulators of chromatin. Similar effects were found with higher BCNU doses in MGMT+ cell line showing a similar mechanism that in MGMT-deficient cell with standard doses. Our data suggest that human glioma cell lines treated with BCNU, independently of MGMT expression, show changes in the expression of cell cycle and survival-related genes interfering the transcription mechanisms and the chromatin regulation.

Standard name | HOFFMAN_CLOCK_TARGETS_UP
Systematic name | M2063
Organism | Homo sapiens
PMID | 20124474
Authors | Hoffman AE,Yi CH,Zheng T,Stevens RG,Leaderer D,Zhang Y,Holford TR,Hansen J,Paulson J,Zhu Y
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) upon knockdown of CLOCK [GeneID=9575] by RNAi that also belong to the highest confidence network (according to Ingenuity Pathway Analysis).
Full description | The transcription factors responsible for maintaining circadian rhythm influence a variety of biological processes. Recently, it has been suggested that the core circadian genes may play a role in breast tumorigenesis, possibly by influencing hormone regulation or other pathways relevant to cancer. To evaluate this hypothesis, we conducted a genetic and epigenetic association study, as well as a transcriptional profiling array and a pathway-based network analysis. We report significant correlations between single nucleotide polymorphisms associated with the central circadian regulator CLOCK and breast cancer risk, with apparent effect modification by estrogen receptor/progesterone receptor status. We also found that hypermethylation in the CLOCK promoter reduced the risk of breast cancer, and lower levels of CLOCK expression were documented in healthy controls relative to normal or tumor tissue from patients with breast cancer. Finally, we silenced CLOCK in vitro and performed a whole-genome expression microarray and pathway analysis, which identified a cancer-relevant network of transcripts with altered expression following CLOCK gene knockdown. Our findings support the hypothesis that circadian genes influence tumorigenesis, and identify a set of circadian gene variants as candidate breast cancer susceptibility biomarkers.

Standard name | HOFFMAN_CLOCK_TARGETS_DN
Systematic name | M2065
Organism | Homo sapiens
PMID | 20124474
Authors | Hoffman AE,Yi CH,Zheng T,Stevens RG,Leaderer D,Zhang Y,Holford TR,Hansen J,Paulson J,Zhu Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) upon knockdown of CLOCK [GeneID=9575] by RNAi that also belong to the highest confidence network (according to Ingenuity Pathway Analysis).
Full description | The transcription factors responsible for maintaining circadian rhythm influence a variety of biological processes. Recently, it has been suggested that the core circadian genes may play a role in breast tumorigenesis, possibly by influencing hormone regulation or other pathways relevant to cancer. To evaluate this hypothesis, we conducted a genetic and epigenetic association study, as well as a transcriptional profiling array and a pathway-based network analysis. We report significant correlations between single nucleotide polymorphisms associated with the central circadian regulator CLOCK and breast cancer risk, with apparent effect modification by estrogen receptor/progesterone receptor status. We also found that hypermethylation in the CLOCK promoter reduced the risk of breast cancer, and lower levels of CLOCK expression were documented in healthy controls relative to normal or tumor tissue from patients with breast cancer. Finally, we silenced CLOCK in vitro and performed a whole-genome expression microarray and pathway analysis, which identified a cancer-relevant network of transcripts with altered expression following CLOCK gene knockdown. Our findings support the hypothesis that circadian genes influence tumorigenesis, and identify a set of circadian gene variants as candidate breast cancer susceptibility biomarkers.

Standard name | WHITFIELD_CELL_CYCLE_LITERATURE
Systematic name | M2066
Organism | Homo sapiens
PMID | 12058064
Authors | Whitfield ML,Sherlock G,Saldanha AJ,Murray JI,Ball CA,Alexander KE,Matese JC,Perou CM,Hurt MM,Brown PO,Botstein D
Category | C2
Sub-category | CGP
Brief description | A list of known cell cycle regulated genes that was compiled from the literature by the authors.
Full description | The genome-wide program of gene expression during the cell division cycle in a human cancer cell line (HeLa) was characterized using cDNA microarrays. Transcripts of >850 genes showed periodic variation during the cell cycle. Hierarchical clustering of the expression patterns revealed coexpressed groups of previously well-characterized genes involved in essential cell cycle processes such as DNA replication, chromosome segregation, and cell adhesion along with genes of uncharacterized function. Most of the genes whose expression had previously been reported to correlate with the proliferative state of tumors were found herein also to be periodically expressed during the HeLa cell cycle. However, some of the genes periodically expressed in the HeLa cell cycle do not have a consistent correlation with tumor proliferation. Cell cycle-regulated transcripts of genes involved in fundamental processes such as DNA replication and chromosome segregation seem to be more highly expressed in proliferative tumors simply because they contain more cycling cells. The data in this report provide a comprehensive catalog of cell cycle regulated genes that can serve as a starting point for functional discovery. The full dataset is available at http://genome-www.stanford.edu/Human-CellCycle/HeLa/.

Standard name | JIANG_HYPOXIA_VIA_VHL
Systematic name | M2522
Organism | Homo sapiens
PMID | 12692265
Authors | Jiang Y,Zhang W,Kondo K,Klco JM,St Martin TB,Dufault MR,Madden SL,Kaelin WG Jr,Nacht M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 786-0 cells (renal carcinoma, RCC) by the loss of VHL [GeneID=7428] and in response to hypoxia.
Full description | The von Hippel-Lindau tumor suppressor, pVHL, is a key player in one of the best characterized hypoxia signaling pathways, the VHL-hypoxia-inducible factor (VHL-HIF) pathway. To better understand the role of VHL in the hypoxia signaling pathways of tumor cells, we used serial analysis of gene expression (SAGE) to investigate hypoxia-regulated gene expression in renal carcinoma cells (786-0), with and without VHL. The gene expression profiles of the cancer cells were compared to SAGE profiles from normal renal proximal tubule cells grown under both normoxia and hypoxia. The data suggest that the role of VHL as a tumor suppressor may be more complex than previously thought. Further, the data reveal that renal carcinoma cells have evolved an alternative hypoxia signaling pathway(s) compared with normal renal cells. These alternative hypoxia pathways demonstrate VHL-dependent and VHL-independent regulation. The genes involved in such pathways include those with potential importance in the physiological and pathological regulation of tumor growth and angiogenesis. Some of the genes identified as showing overexpression in the cancer cells, particularly those encoding secreted or membrane-bound proteins, could be potential biomarkers for tumors or targets for rational therapeutics that are dependent on VHL status.

Standard name | WU_APOPTOSIS_BY_CDKN1A_VIA_TP53
Systematic name | M10169
Organism | Homo sapiens
PMID | 12138103
Authors | Wu Q,Kirschmeier P,Hockenberry T,Yang TY,Brassard DL,Wang L,McClanahan T,Black S,Rizzi G,Musco ML,Mirza A,Liu S
Category | C2
Sub-category | CGP
Brief description | Genes downstream of both CDKN1A and TP53 [GeneID=1026;7157] in 2774qw1 cells (ovarian cancer).
Full description | In this study we used adenovirus vector-mediated transduction of either the p53 gene (rAd-p53) or the p21(WAF1/CIP1) gene (rAd-p21) to mimic both p53-dependent and -independent up-regulation of p21(WAF1/CIP1) within a human ovarian cancer cell line, 2774, and the derivative cell lines, 2774qw1 and 2774qw2. We observed that rAd-p53 can induce apoptosis in both 2774 and 2774qw1 cells but not in 2774qw2 cells. Surprisingly, overexpression of p21(WAF1/CIP1) also triggered apoptosis within these two cell lines. Quantitative reverse transcription-PCR analysis revealed that the differential expression of BAX, BCL2, and caspase 3 genes, specific in rAd-p53-induced apoptotic cells, was not altered in rAd-p21-induced apoptotic cells, suggesting p21(WAF1/CIP1)-induced apoptosis through a pathway distinguishable from p53-induced apoptosis. Expression analysis of 2774qw1 cells infected with rAd-p21 on 60,000 cDNA microarrays identified 159 genes in response to p21(WAF1/CIP1) expression in at least one time point with 2.5-fold change as a cutoff. Integration of the data with the parallel microarray experiments with rAd-p53 infection allowed us to extract 66 genes downstream of both p53 and p21(WAF1/CIP1) and 93 genes in response to p21(WAF1/CIP1) expression in a p53-independent pathway. The genes in the former set may play a dual role in both p53-dependent and p53-independent pathways, and the genes in the latter set gave a mechanistic molecular explanation for p53-independent p21(WAF1/CIP1)-induced apoptosis. Furthermore, promoter sequence analysis suggested that transcription factor E2F family is partially responsible for the differential expression of genes following p21(WAF1/CIP1). This study has profound significance toward understanding the role of p21(WAF1/CIP1) in p53-independent apoptosis.

Standard name | WU_APOPTOSIS_BY_CDKN1A_NOT_VIA_TP53
Systematic name | M6312
Organism | Homo sapiens
PMID | 12138103
Authors | Wu Q,Kirschmeier P,Hockenberry T,Yang TY,Brassard DL,Wang L,McClanahan T,Black S,Rizzi G,Musco ML,Mirza A,Liu S
Category | C2
Sub-category | CGP
Brief description | Genes downstream of CDKN1A [GeneID=1026] in a TP53 [GeneID=7157] independent pathway in 2774qw1 cells (ovarian cancer).
Full description | In this study we used adenovirus vector-mediated transduction of either the p53 gene (rAd-p53) or the p21(WAF1/CIP1) gene (rAd-p21) to mimic both p53-dependent and -independent up-regulation of p21(WAF1/CIP1) within a human ovarian cancer cell line, 2774, and the derivative cell lines, 2774qw1 and 2774qw2. We observed that rAd-p53 can induce apoptosis in both 2774 and 2774qw1 cells but not in 2774qw2 cells. Surprisingly, overexpression of p21(WAF1/CIP1) also triggered apoptosis within these two cell lines. Quantitative reverse transcription-PCR analysis revealed that the differential expression of BAX, BCL2, and caspase 3 genes, specific in rAd-p53-induced apoptotic cells, was not altered in rAd-p21-induced apoptotic cells, suggesting p21(WAF1/CIP1)-induced apoptosis through a pathway distinguishable from p53-induced apoptosis. Expression analysis of 2774qw1 cells infected with rAd-p21 on 60,000 cDNA microarrays identified 159 genes in response to p21(WAF1/CIP1) expression in at least one time point with 2.5-fold change as a cutoff. Integration of the data with the parallel microarray experiments with rAd-p53 infection allowed us to extract 66 genes downstream of both p53 and p21(WAF1/CIP1) and 93 genes in response to p21(WAF1/CIP1) expression in a p53-independent pathway. The genes in the former set may play a dual role in both p53-dependent and p53-independent pathways, and the genes in the latter set gave a mechanistic molecular explanation for p53-independent p21(WAF1/CIP1)-induced apoptosis. Furthermore, promoter sequence analysis suggested that transcription factor E2F family is partially responsible for the differential expression of genes following p21(WAF1/CIP1). This study has profound significance toward understanding the role of p21(WAF1/CIP1) in p53-independent apoptosis.

Standard name | ONGUSAHA_BRCA1_TARGETS_UP
Systematic name | M2067
Organism | Mus musculus
PMID | 12802282
Authors | Ongusaha PP,Ouchi T,Kim KT,Nytko E,Kwak JC,Duda RB,Deng CX,Lee SW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) lacking TP53 and BRCA1 [GeneID=7157;672] by expression of BRCA1.
Full description | The tumor suppressor protein BRCA1 has been shown to enhance p53 transcription, whereas activated p53 represses BRCA1 transcription. To further understand the functional interaction of these proteins, we investigated the role of BRCA1 in p53-induced phenotypes. We found that BRCA1 when subjected to forced expression acts synergistically with wild-type p53, resulting in irreversible growth arrest, as shown by VhD mouse fibroblast cells expressing a temperature-sensitive mutant of p53. Furthermore, reintroduction of both BRCA1 and p53 into BRCA1(-/-)/p53(-/-) mouse embryonic fibroblasts markedly increased the senescence phenotype compared to that induced by p53 alone. In particular, we found that BRCA1 expression attenuated p53-mediated cell death in response to gamma-irradiation. Moreover, microarray screening of 11 000 murine genes demonstrated that a set of genes upregulated by p53 is enhanced by coexpression of BRCA1 and p53, suggesting that BRCA1 and p53 exert a promoter selectivity leading to a specific phenotype. Taken together, our results provide evidence that BRCA1 is involved in p53-mediated growth suppression rather than apoptosis.

Standard name | ONGUSAHA_BRCA1_TARGETS_DN
Systematic name | M2068
Organism | Mus musculus
PMID | 12802282
Authors | Ongusaha PP,Ouchi T,Kim KT,Nytko E,Kwak JC,Duda RB,Deng CX,Lee SW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblast) lacking TP53 and BRCA1 [GeneID=7157;672] by expression of BRCA1.
Full description | The tumor suppressor protein BRCA1 has been shown to enhance p53 transcription, whereas activated p53 represses BRCA1 transcription. To further understand the functional interaction of these proteins, we investigated the role of BRCA1 in p53-induced phenotypes. We found that BRCA1 when subjected to forced expression acts synergistically with wild-type p53, resulting in irreversible growth arrest, as shown by VhD mouse fibroblast cells expressing a temperature-sensitive mutant of p53. Furthermore, reintroduction of both BRCA1 and p53 into BRCA1(-/-)/p53(-/-) mouse embryonic fibroblasts markedly increased the senescence phenotype compared to that induced by p53 alone. In particular, we found that BRCA1 expression attenuated p53-mediated cell death in response to gamma-irradiation. Moreover, microarray screening of 11 000 murine genes demonstrated that a set of genes upregulated by p53 is enhanced by coexpression of BRCA1 and p53, suggesting that BRCA1 and p53 exert a promoter selectivity leading to a specific phenotype. Taken together, our results provide evidence that BRCA1 is involved in p53-mediated growth suppression rather than apoptosis.

Standard name | SASSON_RESPONSE_TO_GONADOTROPHINS_UP
Systematic name | M16587
Organism | Homo sapiens
PMID | 15026540
Authors | Sasson R,Rimon E,Dantes A,Cohen T,Shinder V,Land-Bracha A,Amsterdam A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary granulosa cells after stimulation with LH or FSH gonadotrophic hormones for 24 h.
Full description | Gonadotrophins exert a major effect on ovarian development and on the control of fertilization. By stimulating cells with forskolin (FK), it is possible to study which genes are activated by gonadotrophins via the cAMP cascade, and which by alternative pathways. Using RNA isolated from stimulated cells, we found that 59% of the total genes modulated by LH were also modulated by FK, while 69% of the genes modulated exclusively by FSH were also modulated by FK. Gene transcripts involved in steroidogenesis/progesterone production were highly elevated, while 17beta-hydroxysteroid dehydrogenase was down-regulated. This suggests that a decrease in the conversion of androstenedione to testosterone and estrone to estradiol occurs during luteinization. Down-regulation of genes coding for actin cytoskeleton proteins and cytokeratin 18 was observed in response to gonadotrophin and cAMP stimulation. Several of the genes coding for the microtubule network were also modulated, implying that rearrangement of the cytoskeletal proteins permits better coupling between organelles involved in steroidogenesis. A dramatic change in gene transcripts coding for signalling enzymes was observed following LH stimulation. This includes the down-regulation of adenylyl cyclase 7 and 9, elevation of cAMP-dependent phosphodiesterase, and the up-regulation of a negative regulator of G-protein signalling (RGS16) that may negate gonadotrophin signalling via guanine nucleotide binding proteins. Thus luteinized cells, despite increased gene transcripts to LH/chorionic gonadotrophin (CG) receptors, respond inefficiently to gonadotrophin stimulation, due to attenuation of signal transduction in the cAMP cascade at multiple steps. Novel genes involved in the regulation of apoptosis were found for the first time to be up-regulated by gonadotrophin stimulation, including: BAX inhibitor-1, granulysin and apoptosis repressor with caspase recruitment domain (ARC). These proteins may be involved in a unique alternative pathway of ovarian cell death. Such a pathway could temporarily preserve the mitochondria and progesterone production during the initial stages of granulosa cell apoptosis.

Standard name | SASSON_RESPONSE_TO_GONADOTROPHINS_DN
Systematic name | M17143
Organism | Homo sapiens
PMID | 15026540
Authors | Sasson R,Rimon E,Dantes A,Cohen T,Shinder V,Land-Bracha A,Amsterdam A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary granulosa cells after stimulation with LH or FSH gonadotrophic hormones for 24 h.
Full description | Gonadotrophins exert a major effect on ovarian development and on the control of fertilization. By stimulating cells with forskolin (FK), it is possible to study which genes are activated by gonadotrophins via the cAMP cascade, and which by alternative pathways. Using RNA isolated from stimulated cells, we found that 59% of the total genes modulated by LH were also modulated by FK, while 69% of the genes modulated exclusively by FSH were also modulated by FK. Gene transcripts involved in steroidogenesis/progesterone production were highly elevated, while 17beta-hydroxysteroid dehydrogenase was down-regulated. This suggests that a decrease in the conversion of androstenedione to testosterone and estrone to estradiol occurs during luteinization. Down-regulation of genes coding for actin cytoskeleton proteins and cytokeratin 18 was observed in response to gonadotrophin and cAMP stimulation. Several of the genes coding for the microtubule network were also modulated, implying that rearrangement of the cytoskeletal proteins permits better coupling between organelles involved in steroidogenesis. A dramatic change in gene transcripts coding for signalling enzymes was observed following LH stimulation. This includes the down-regulation of adenylyl cyclase 7 and 9, elevation of cAMP-dependent phosphodiesterase, and the up-regulation of a negative regulator of G-protein signalling (RGS16) that may negate gonadotrophin signalling via guanine nucleotide binding proteins. Thus luteinized cells, despite increased gene transcripts to LH/chorionic gonadotrophin (CG) receptors, respond inefficiently to gonadotrophin stimulation, due to attenuation of signal transduction in the cAMP cascade at multiple steps. Novel genes involved in the regulation of apoptosis were found for the first time to be up-regulated by gonadotrophin stimulation, including: BAX inhibitor-1, granulysin and apoptosis repressor with caspase recruitment domain (ARC). These proteins may be involved in a unique alternative pathway of ovarian cell death. Such a pathway could temporarily preserve the mitochondria and progesterone production during the initial stages of granulosa cell apoptosis.

Standard name | SASSON_RESPONSE_TO_FORSKOLIN_UP
Systematic name | M9869
Organism | Homo sapiens
PMID | 15026540
Authors | Sasson R,Rimon E,Dantes A,Cohen T,Shinder V,Land-Bracha A,Amsterdam A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary granulosa cells in response to forskolin [PubChem=47936].
Full description | Gonadotrophins exert a major effect on ovarian development and on the control of fertilization. By stimulating cells with forskolin (FK), it is possible to study which genes are activated by gonadotrophins via the cAMP cascade, and which by alternative pathways. Using RNA isolated from stimulated cells, we found that 59% of the total genes modulated by LH were also modulated by FK, while 69% of the genes modulated exclusively by FSH were also modulated by FK. Gene transcripts involved in steroidogenesis/progesterone production were highly elevated, while 17beta-hydroxysteroid dehydrogenase was down-regulated. This suggests that a decrease in the conversion of androstenedione to testosterone and estrone to estradiol occurs during luteinization. Down-regulation of genes coding for actin cytoskeleton proteins and cytokeratin 18 was observed in response to gonadotrophin and cAMP stimulation. Several of the genes coding for the microtubule network were also modulated, implying that rearrangement of the cytoskeletal proteins permits better coupling between organelles involved in steroidogenesis. A dramatic change in gene transcripts coding for signalling enzymes was observed following LH stimulation. This includes the down-regulation of adenylyl cyclase 7 and 9, elevation of cAMP-dependent phosphodiesterase, and the up-regulation of a negative regulator of G-protein signalling (RGS16) that may negate gonadotrophin signalling via guanine nucleotide binding proteins. Thus luteinized cells, despite increased gene transcripts to LH/chorionic gonadotrophin (CG) receptors, respond inefficiently to gonadotrophin stimulation, due to attenuation of signal transduction in the cAMP cascade at multiple steps. Novel genes involved in the regulation of apoptosis were found for the first time to be up-regulated by gonadotrophin stimulation, including: BAX inhibitor-1, granulysin and apoptosis repressor with caspase recruitment domain (ARC). These proteins may be involved in a unique alternative pathway of ovarian cell death. Such a pathway could temporarily preserve the mitochondria and progesterone production during the initial stages of granulosa cell apoptosis.

Standard name | SASSON_RESPONSE_TO_FORSKOLIN_DN
Systematic name | M12924
Organism | Homo sapiens
PMID | 15026540
Authors | Sasson R,Rimon E,Dantes A,Cohen T,Shinder V,Land-Bracha A,Amsterdam A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary granulosa cells in response to forskolin [PubChem=47936].
Full description | Gonadotrophins exert a major effect on ovarian development and on the control of fertilization. By stimulating cells with forskolin (FK), it is possible to study which genes are activated by gonadotrophins via the cAMP cascade, and which by alternative pathways. Using RNA isolated from stimulated cells, we found that 59% of the total genes modulated by LH were also modulated by FK, while 69% of the genes modulated exclusively by FSH were also modulated by FK. Gene transcripts involved in steroidogenesis/progesterone production were highly elevated, while 17beta-hydroxysteroid dehydrogenase was down-regulated. This suggests that a decrease in the conversion of androstenedione to testosterone and estrone to estradiol occurs during luteinization. Down-regulation of genes coding for actin cytoskeleton proteins and cytokeratin 18 was observed in response to gonadotrophin and cAMP stimulation. Several of the genes coding for the microtubule network were also modulated, implying that rearrangement of the cytoskeletal proteins permits better coupling between organelles involved in steroidogenesis. A dramatic change in gene transcripts coding for signalling enzymes was observed following LH stimulation. This includes the down-regulation of adenylyl cyclase 7 and 9, elevation of cAMP-dependent phosphodiesterase, and the up-regulation of a negative regulator of G-protein signalling (RGS16) that may negate gonadotrophin signalling via guanine nucleotide binding proteins. Thus luteinized cells, despite increased gene transcripts to LH/chorionic gonadotrophin (CG) receptors, respond inefficiently to gonadotrophin stimulation, due to attenuation of signal transduction in the cAMP cascade at multiple steps. Novel genes involved in the regulation of apoptosis were found for the first time to be up-regulated by gonadotrophin stimulation, including: BAX inhibitor-1, granulysin and apoptosis repressor with caspase recruitment domain (ARC). These proteins may be involved in a unique alternative pathway of ovarian cell death. Such a pathway could temporarily preserve the mitochondria and progesterone production during the initial stages of granulosa cell apoptosis.

Standard name | BAE_BRCA1_TARGETS_UP
Systematic name | M2072
Organism | Homo sapiens
PMID | 15520196
Authors | Bae I,Fan S,Meng Q,Rih JK,Kim HJ,Kang HJ,Xu J,Goldberg ID,Jaiswal AK,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes concordantly up-regulated in DU-145 and MCF-7 cells (lprostate, breast cancer) upon expression of BRCA1.
Full description | Mutations of the breast cancer susceptibility gene 1 (BRCA1), a tumor suppressor, confer an increased risk for breast, ovarian, and prostate cancers. To investigate the function of the BRCA1 gene, we performed DNA microarray and confirmatory reverse transcription-PCR analyses to identify BRCA1-regulated gene expression changes. We found that BRCA1 up-regulates the expression of multiple genes involved in the cytoprotective antioxidant response, including glutathione S-transferases, oxidoreductases, and other antioxidant genes. Consistent with these findings, BRCA1 overexpression conferred resistance while BRCA1 deficiency conferred sensitivity to several different oxidizing agents (hydrogen peroxide and paraquat). In addition, in the setting of oxidative stress (due to hydrogen peroxide), BRCA1 shifted the cellular redox balance to a higher ratio of reduced to oxidized glutathione. Finally, BRCA1 stimulated antioxidant response element-driven transcriptional activity and enhanced the activity of the antioxidant response transcription factor nuclear factor erythroid-derived 2 like 2 [also called NRF2 (NFE2L2)]. The ability of BRCA1 to stimulate antioxidant response element-dependent transcription and to protect cells against oxidative stress was attenuated by inhibition of nuclear factor erythroid-derived 2 like 2. These findings suggest a novel function for BRCA1, i.e., to protect cells against oxidative stress. This function would be consistent with the postulated role of BRCA1 as a caretaker gene in preserving genomic integrity.

Standard name | BAE_BRCA1_TARGETS_DN
Systematic name | M2073
Organism | Homo sapiens
PMID | 15520196
Authors | Bae I,Fan S,Meng Q,Rih JK,Kim HJ,Kang HJ,Xu J,Goldberg ID,Jaiswal AK,Rosen EM
Category | C2
Sub-category | CGP
Brief description | Genes concordantly down-regulated in DU-145 and MCF-7 cells (lprostate, breast cancer) upon expression of BRCA1.
Full description | Mutations of the breast cancer susceptibility gene 1 (BRCA1), a tumor suppressor, confer an increased risk for breast, ovarian, and prostate cancers. To investigate the function of the BRCA1 gene, we performed DNA microarray and confirmatory reverse transcription-PCR analyses to identify BRCA1-regulated gene expression changes. We found that BRCA1 up-regulates the expression of multiple genes involved in the cytoprotective antioxidant response, including glutathione S-transferases, oxidoreductases, and other antioxidant genes. Consistent with these findings, BRCA1 overexpression conferred resistance while BRCA1 deficiency conferred sensitivity to several different oxidizing agents (hydrogen peroxide and paraquat). In addition, in the setting of oxidative stress (due to hydrogen peroxide), BRCA1 shifted the cellular redox balance to a higher ratio of reduced to oxidized glutathione. Finally, BRCA1 stimulated antioxidant response element-driven transcriptional activity and enhanced the activity of the antioxidant response transcription factor nuclear factor erythroid-derived 2 like 2 [also called NRF2 (NFE2L2)]. The ability of BRCA1 to stimulate antioxidant response element-dependent transcription and to protect cells against oxidative stress was attenuated by inhibition of nuclear factor erythroid-derived 2 like 2. These findings suggest a novel function for BRCA1, i.e., to protect cells against oxidative stress. This function would be consistent with the postulated role of BRCA1 as a caretaker gene in preserving genomic integrity.

Standard name | BROWNE_HCMV_INFECTION_30MIN_UP
Systematic name | M6977
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture at 30 min time point after infection with HCMV (AD169 strain).
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | BROWNE_HCMV_INFECTION_30MIN_DN
Systematic name | M0
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture at 30 min time point after infection with HCMV (AD169 strain).
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | BROWNE_HCMV_INFECTION_1HR_UP
Systematic name | M5823
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 1 h time point that were not up-regulated at the previous time point, 30 min.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | BROWNE_HCMV_INFECTION_1HR_DN
Systematic name | M9802
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 1 h time point that were not down-regulated at the previous time point, 30 min.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | BROWNE_HCMV_INFECTION_2HR_UP
Systematic name | M3649
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 2 h time point that were not up-regulated at the previous time point, 1 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | BROWNE_HCMV_INFECTION_2HR_DN
Systematic name | M521
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 2 h time point that were not down-regulated at the previous time point, 1 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | BROWNE_HCMV_INFECTION_4HR_UP
Systematic name | M10161
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 4 h time point that were not up-regulated at the previous time point, 2 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | BROWNE_HCMV_INFECTION_4HR_DN
Systematic name | M789
Organism | Homo sapiens
PMID | 11711622
Authors | Browne EP,Wing B,Coleman D,Shenk T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 4 h time point that were not down-regulated at the previous time point, 2 h.
Full description | The effect of human cytomegalovirus (HCMV) infection on cellular mRNA accumulation was analyzed by gene chip technology. During a 48-h time course after infection of human diploid fibroblasts, 1,425 cellular mRNAs were found to be up-regulated or down-regulated by threefold or greater in at least two consecutive time points. Several classes of genes were prominently affected, including interferon response genes, cell cycle regulators, apoptosis regulators, inflammatory pathway genes, and immune regulators. The number of mRNAs that were up-regulated or down-regulated were roughly equal over the complete time course. However, for the first 8 h after infection, the number of up-regulated mRNAs was significantly less than the number of down-regulated mRNAs. By analyzing the mRNA expression profile of cells infected in the presence of cycloheximide, it was found that a minimum of 25 mRNAs were modulated by HCMV in the absence of protein synthesis. These included mRNAs encoded by a small number of interferon-responsive genes, as well as beta interferon itself. Cellular mRNA levels in cytomegalovirus-infected cells were compared to the levels in cells infected with UV-inactivated virus. The inactivated virus caused the up-regulation of a much greater number of mRNAs, many of which encoded proteins with antiviral roles, such as interferon-responsive genes and proinflammatory cytokines. These data argue that one or more newly synthesized viral gene products block the induction of antiviral pathways that are triggered by HCMV binding and entry.

Standard name | WHITFIELD_CELL_CYCLE_G1_S
Systematic name | M2074
Organism | Homo sapiens
PMID | 12058064
Authors | Whitfield ML,Sherlock G,Saldanha AJ,Murray JI,Ball CA,Alexander KE,Matese JC,Perou CM,Hurt MM,Brown PO,Botstein D
Category | C2
Sub-category | CGP
Brief description | Genes periodically expressed in synchronized HeLa cells (cervical carcinoma), with peak during the G1/S phase of cell cycle.
Full description | The genome-wide program of gene expression during the cell division cycle in a human cancer cell line (HeLa) was characterized using cDNA microarrays. Transcripts of >850 genes showed periodic variation during the cell cycle. Hierarchical clustering of the expression patterns revealed coexpressed groups of previously well-characterized genes involved in essential cell cycle processes such as DNA replication, chromosome segregation, and cell adhesion along with genes of uncharacterized function. Most of the genes whose expression had previously been reported to correlate with the proliferative state of tumors were found herein also to be periodically expressed during the HeLa cell cycle. However, some of the genes periodically expressed in the HeLa cell cycle do not have a consistent correlation with tumor proliferation. Cell cycle-regulated transcripts of genes involved in fundamental processes such as DNA replication and chromosome segregation seem to be more highly expressed in proliferative tumors simply because they contain more cycling cells. The data in this report provide a comprehensive catalog of cell cycle regulated genes that can serve as a starting point for functional discovery. The full dataset is available at http://genome-www.stanford.edu/Human-CellCycle/HeLa/.

Standard name | WHITFIELD_CELL_CYCLE_S
Systematic name | M2075
Organism | Homo sapiens
PMID | 12058064
Authors | Whitfield ML,Sherlock G,Saldanha AJ,Murray JI,Ball CA,Alexander KE,Matese JC,Perou CM,Hurt MM,Brown PO,Botstein D
Category | C2
Sub-category | CGP
Brief description | Genes periodically expressed in synchronized HeLa cells (cervical carcinoma), with peak during the S phase of cell cycle.
Full description | The genome-wide program of gene expression during the cell division cycle in a human cancer cell line (HeLa) was characterized using cDNA microarrays. Transcripts of >850 genes showed periodic variation during the cell cycle. Hierarchical clustering of the expression patterns revealed coexpressed groups of previously well-characterized genes involved in essential cell cycle processes such as DNA replication, chromosome segregation, and cell adhesion along with genes of uncharacterized function. Most of the genes whose expression had previously been reported to correlate with the proliferative state of tumors were found herein also to be periodically expressed during the HeLa cell cycle. However, some of the genes periodically expressed in the HeLa cell cycle do not have a consistent correlation with tumor proliferation. Cell cycle-regulated transcripts of genes involved in fundamental processes such as DNA replication and chromosome segregation seem to be more highly expressed in proliferative tumors simply because they contain more cycling cells. The data in this report provide a comprehensive catalog of cell cycle regulated genes that can serve as a starting point for functional discovery. The full dataset is available at http://genome-www.stanford.edu/Human-CellCycle/HeLa/.

Standard name | WHITFIELD_CELL_CYCLE_G2
Systematic name | M2076
Organism | Homo sapiens
PMID | 12058064
Authors | Whitfield ML,Sherlock G,Saldanha AJ,Murray JI,Ball CA,Alexander KE,Matese JC,Perou CM,Hurt MM,Brown PO,Botstein D
Category | C2
Sub-category | CGP
Brief description | Genes periodically expressed in synchronized HeLa cells (cervical carcinoma), with peak during the G2 phase of cell cycle.
Full description | The genome-wide program of gene expression during the cell division cycle in a human cancer cell line (HeLa) was characterized using cDNA microarrays. Transcripts of >850 genes showed periodic variation during the cell cycle. Hierarchical clustering of the expression patterns revealed coexpressed groups of previously well-characterized genes involved in essential cell cycle processes such as DNA replication, chromosome segregation, and cell adhesion along with genes of uncharacterized function. Most of the genes whose expression had previously been reported to correlate with the proliferative state of tumors were found herein also to be periodically expressed during the HeLa cell cycle. However, some of the genes periodically expressed in the HeLa cell cycle do not have a consistent correlation with tumor proliferation. Cell cycle-regulated transcripts of genes involved in fundamental processes such as DNA replication and chromosome segregation seem to be more highly expressed in proliferative tumors simply because they contain more cycling cells. The data in this report provide a comprehensive catalog of cell cycle regulated genes that can serve as a starting point for functional discovery. The full dataset is available at http://genome-www.stanford.edu/Human-CellCycle/HeLa/.

Standard name | WHITFIELD_CELL_CYCLE_G2_M
Systematic name | M2077
Organism | Homo sapiens
PMID | 12058064
Authors | Whitfield ML,Sherlock G,Saldanha AJ,Murray JI,Ball CA,Alexander KE,Matese JC,Perou CM,Hurt MM,Brown PO,Botstein D
Category | C2
Sub-category | CGP
Brief description | Genes periodically expressed in synchronized HeLa cells (cervical carcinoma), with peak during the G2/M phase of cell cycle.
Full description | The genome-wide program of gene expression during the cell division cycle in a human cancer cell line (HeLa) was characterized using cDNA microarrays. Transcripts of >850 genes showed periodic variation during the cell cycle. Hierarchical clustering of the expression patterns revealed coexpressed groups of previously well-characterized genes involved in essential cell cycle processes such as DNA replication, chromosome segregation, and cell adhesion along with genes of uncharacterized function. Most of the genes whose expression had previously been reported to correlate with the proliferative state of tumors were found herein also to be periodically expressed during the HeLa cell cycle. However, some of the genes periodically expressed in the HeLa cell cycle do not have a consistent correlation with tumor proliferation. Cell cycle-regulated transcripts of genes involved in fundamental processes such as DNA replication and chromosome segregation seem to be more highly expressed in proliferative tumors simply because they contain more cycling cells. The data in this report provide a comprehensive catalog of cell cycle regulated genes that can serve as a starting point for functional discovery. The full dataset is available at http://genome-www.stanford.edu/Human-CellCycle/HeLa/.

Standard name | WHITFIELD_CELL_CYCLE_M_G1
Systematic name | M2078
Organism | Homo sapiens
PMID | 12058064
Authors | Whitfield ML,Sherlock G,Saldanha AJ,Murray JI,Ball CA,Alexander KE,Matese JC,Perou CM,Hurt MM,Brown PO,Botstein D
Category | C2
Sub-category | CGP
Brief description | Genes periodically expressed in synchronized HeLa cells (cervical carcinoma), with peak during the M/G1 phase of cell cycle.
Full description | The genome-wide program of gene expression during the cell division cycle in a human cancer cell line (HeLa) was characterized using cDNA microarrays. Transcripts of >850 genes showed periodic variation during the cell cycle. Hierarchical clustering of the expression patterns revealed coexpressed groups of previously well-characterized genes involved in essential cell cycle processes such as DNA replication, chromosome segregation, and cell adhesion along with genes of uncharacterized function. Most of the genes whose expression had previously been reported to correlate with the proliferative state of tumors were found herein also to be periodically expressed during the HeLa cell cycle. However, some of the genes periodically expressed in the HeLa cell cycle do not have a consistent correlation with tumor proliferation. Cell cycle-regulated transcripts of genes involved in fundamental processes such as DNA replication and chromosome segregation seem to be more highly expressed in proliferative tumors simply because they contain more cycling cells. The data in this report provide a comprehensive catalog of cell cycle regulated genes that can serve as a starting point for functional discovery. The full dataset is available at http://genome-www.stanford.edu/Human-CellCycle/HeLa/.

Standard name | RAGHAVACHARI_PLATELET_SPECIFIC_GENES
Systematic name | M7732
Organism | Homo sapiens
PMID | 17353439
Authors | Raghavachari N,Xu X,Harris A,Villagra J,Logun C,Barb J,Solomon MA,Suffredini AF,Danner RL,Kato G,Munson PJ,Morris SM Jr,Gladwin MT
Category | C2
Sub-category | CGP
Brief description | Genes in this set correspond to the most abuntant transcripts that are also specific to platelets.
Full description | BACKGROUND: In sickle cell disease, ischemia-reperfusion injury and intravascular hemolysis produce endothelial dysfunction and vasculopathy characterized by reduced nitric oxide and arginine bioavailability. Recent functional studies of platelets in patients with sickle cell disease reveal a basally activated state, which suggests that pathological platelet activation may contribute to sickle cell disease vasculopathy. METHODS AND RESULTS: Studies were therefore undertaken to examine transcriptional signaling pathways in platelets that may be dysregulated in sickle cell disease. We demonstrate and validate in the present study the feasibility of comparative platelet transcriptome studies on clinical samples from single donors by the application of RNA amplification followed by microarray-based analysis of 54,000 probe sets. Data mining an existing microarray database, we identified 220 highly abundant genes in platelets and a subset of 72 relatively platelet-specific genes, defined by >10-fold increased expression compared with the median of other cell types in the database with amplified transcripts. The highly abundant platelet transcripts found in the present study included 82% or 70% of platelet-abundant genes identified in 2 previous gene expression studies on nonamplified mRNA from pooled or apheresis samples, respectively. On comparing the platelet gene expression profiles in 18 patients with sickle cell disease in steady state to those of 12 black control subjects, at a 3-fold cutoff and 5% false-discovery rate, we identified approximately 100 differentially expressed genes, including multiple genes involved in arginine metabolism and redox homeostasis. Further characterization of these pathways with real-time polymerase chain reaction and biochemical assays revealed increased arginase II expression and activity and decreased platelet polyamine levels. CONCLUSIONS: The present studies suggest a potential pathogenic role for platelet arginase and altered arginine and polyamine metabolism in sickle cell disease and provide a novel framework for the study of disease-specific platelet biology.

Standard name | KARLSSON_TGFB1_TARGETS_UP
Systematic name | M2080
Organism | Mus musculus
PMID | 15769904
Authors | Karlsson G,Liu Y,Larsson J,Goumans MJ,Lee JS,Thorgeirsson SS,Ringnér M,Karlsson S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by TGFB1 [GeneID=7040] in MEF cells (embryonic fibroblast) via TGFB1R [GeneID=7046].
Full description | Transforming growth factor-beta1 (TGF-beta) regulates cellular functions like proliferation, differentiation, and apoptosis. On the cell surface, TGF-beta binds to receptor complexes consisting of TGF-beta receptor type II (TbetaRII) and activin-like kinase receptor-5 (Alk5), and the downstream signaling is transduced by Smad and MAPK proteins. Recent data have shown that alternative receptor combinations aside from the classical pairing of TbetaRII/Alk5 can be relevant for TGF-beta signaling. We have screened for alternative receptors for TGF-beta and also for gene targets of TGF-beta signaling, by performing functional assays and microarray analysis in murine embryonic fibroblast (MEF) cell lines lacking Alk5. Data from TGF-beta-stimulated Alk5(-/-) cells show them to be completely unaffected by TGF-beta. Additionally, 465 downstream targets of Alk5 signaling were identified when comparing Alk5(-/-) or TGF-beta-stimulated Alk5(+/+) MEFs with unstimulated Alk5(+/+) cells. Our results demonstrate that, in MEFs, TGF-beta signals exclusively through complexes involving Alk5, and give insight to its downstream effector genes.

Standard name | KARLSSON_TGFB1_TARGETS_DN
Systematic name | M2081
Organism | Mus musculus
PMID | 15769904
Authors | Karlsson G,Liu Y,Larsson J,Goumans MJ,Lee JS,Thorgeirsson SS,Ringnér M,Karlsson S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by TGFB1 [GeneID=7040] in MEF cells (embryonic fibroblast) via TGFB1R [GeneID=7046].
Full description | Transforming growth factor-beta1 (TGF-beta) regulates cellular functions like proliferation, differentiation, and apoptosis. On the cell surface, TGF-beta binds to receptor complexes consisting of TGF-beta receptor type II (TbetaRII) and activin-like kinase receptor-5 (Alk5), and the downstream signaling is transduced by Smad and MAPK proteins. Recent data have shown that alternative receptor combinations aside from the classical pairing of TbetaRII/Alk5 can be relevant for TGF-beta signaling. We have screened for alternative receptors for TGF-beta and also for gene targets of TGF-beta signaling, by performing functional assays and microarray analysis in murine embryonic fibroblast (MEF) cell lines lacking Alk5. Data from TGF-beta-stimulated Alk5(-/-) cells show them to be completely unaffected by TGF-beta. Additionally, 465 downstream targets of Alk5 signaling were identified when comparing Alk5(-/-) or TGF-beta-stimulated Alk5(+/+) MEFs with unstimulated Alk5(+/+) cells. Our results demonstrate that, in MEFs, TGF-beta signals exclusively through complexes involving Alk5, and give insight to its downstream effector genes.

Standard name | WANG_METASTASIS_OF_BREAST_CANCER_ESR1_UP
Systematic name | M2082
Organism | Homo sapiens
PMID | 15721472
Authors | Wang Y,Klijn JG,Zhang Y,Sieuwerts AM,Look MP,Yang F,Talantov D,Timmermans M,Meijer-van Gelder ME,Yu J,Jatkoe T,Berns EM,Atkins D,Foekens JA
Category | C2
Sub-category | CGP
Brief description | Genes whose expression in primary ER(+) [GeneID=2099] breast cancer tumors positively correlates with developing distant metastases.
Full description | BACKGROUND: Genome-wide measures of gene expression can identify patterns of gene activity that subclassify tumours and might provide a better means than is currently available for individual risk assessment in patients with lymph-node-negative breast cancer. METHODS: We analysed, with Affymetrix Human U133a GeneChips, the expression of 22000 transcripts from total RNA of frozen tumour samples from 286 lymph-node-negative patients who had not received adjuvant systemic treatment. FINDINGS: In a training set of 115 tumours, we identified a 76-gene signature consisting of 60 genes for patients positive for oestrogen receptors (ER) and 16 genes for ER-negative patients. This signature showed 93% sensitivity and 48% specificity in a subsequent independent testing set of 171 lymph-node-negative patients. The gene profile was highly informative in identifying patients who developed distant metastases within 5 years (hazard ratio 5.67 [95% CI 2.59-12.4]), even when corrected for traditional prognostic factors in multivariate analysis (5.55 [2.46-12.5]). The 76-gene profile also represented a strong prognostic factor for the development of metastasis in the subgroups of 84 premenopausal patients (9.60 [2.28-40.5]), 87 postmenopausal patients (4.04 [1.57-10.4]), and 79 patients with tumours of 10-20 mm (14.1 [3.34-59.2]), a group of patients for whom prediction of prognosis is especially difficult. INTERPRETATION: The identified signature provides a powerful tool for identification of patients at high risk of distant recurrence. The ability to identify patients who have a favourable prognosis could, after independent confirmation, allow clinicians to avoid adjuvant systemic therapy or to choose less aggressive therapeutic options.

Standard name | WANG_METASTASIS_OF_BREAST_CANCER_ESR1_DN
Systematic name | M2083
Organism | Homo sapiens
PMID | 15721472
Authors | Wang Y,Klijn JG,Zhang Y,Sieuwerts AM,Look MP,Yang F,Talantov D,Timmermans M,Meijer-van Gelder ME,Yu J,Jatkoe T,Berns EM,Atkins D,Foekens JA
Category | C2
Sub-category | CGP
Brief description | Genes whose expression in primary ER(+) [GeneID=2099] breast cancer tumors negatively correlates with developing distant metastases.
Full description | BACKGROUND: Genome-wide measures of gene expression can identify patterns of gene activity that subclassify tumours and might provide a better means than is currently available for individual risk assessment in patients with lymph-node-negative breast cancer. METHODS: We analysed, with Affymetrix Human U133a GeneChips, the expression of 22000 transcripts from total RNA of frozen tumour samples from 286 lymph-node-negative patients who had not received adjuvant systemic treatment. FINDINGS: In a training set of 115 tumours, we identified a 76-gene signature consisting of 60 genes for patients positive for oestrogen receptors (ER) and 16 genes for ER-negative patients. This signature showed 93% sensitivity and 48% specificity in a subsequent independent testing set of 171 lymph-node-negative patients. The gene profile was highly informative in identifying patients who developed distant metastases within 5 years (hazard ratio 5.67 [95% CI 2.59-12.4]), even when corrected for traditional prognostic factors in multivariate analysis (5.55 [2.46-12.5]). The 76-gene profile also represented a strong prognostic factor for the development of metastasis in the subgroups of 84 premenopausal patients (9.60 [2.28-40.5]), 87 postmenopausal patients (4.04 [1.57-10.4]), and 79 patients with tumours of 10-20 mm (14.1 [3.34-59.2]), a group of patients for whom prediction of prognosis is especially difficult. INTERPRETATION: The identified signature provides a powerful tool for identification of patients at high risk of distant recurrence. The ability to identify patients who have a favourable prognosis could, after independent confirmation, allow clinicians to avoid adjuvant systemic therapy or to choose less aggressive therapeutic options.

Standard name | WANG_METASTASIS_OF_BREAST_CANCER
Systematic name | M2084
Organism | Homo sapiens
PMID | 15721472
Authors | Wang Y,Klijn JG,Zhang Y,Sieuwerts AM,Look MP,Yang F,Talantov D,Timmermans M,Meijer-van Gelder ME,Yu J,Jatkoe T,Berns EM,Atkins D,Foekens JA
Category | C2
Sub-category | CGP
Brief description | Genes whose expression in primary ER(-) [GeneID=2099] breast cancer tumors negatively correlates with developing distant metastases.
Full description | BACKGROUND: Genome-wide measures of gene expression can identify patterns of gene activity that subclassify tumours and might provide a better means than is currently available for individual risk assessment in patients with lymph-node-negative breast cancer. METHODS: We analysed, with Affymetrix Human U133a GeneChips, the expression of 22000 transcripts from total RNA of frozen tumour samples from 286 lymph-node-negative patients who had not received adjuvant systemic treatment. FINDINGS: In a training set of 115 tumours, we identified a 76-gene signature consisting of 60 genes for patients positive for oestrogen receptors (ER) and 16 genes for ER-negative patients. This signature showed 93% sensitivity and 48% specificity in a subsequent independent testing set of 171 lymph-node-negative patients. The gene profile was highly informative in identifying patients who developed distant metastases within 5 years (hazard ratio 5.67 [95% CI 2.59-12.4]), even when corrected for traditional prognostic factors in multivariate analysis (5.55 [2.46-12.5]). The 76-gene profile also represented a strong prognostic factor for the development of metastasis in the subgroups of 84 premenopausal patients (9.60 [2.28-40.5]), 87 postmenopausal patients (4.04 [1.57-10.4]), and 79 patients with tumours of 10-20 mm (14.1 [3.34-59.2]), a group of patients for whom prediction of prognosis is especially difficult. INTERPRETATION: The identified signature provides a powerful tool for identification of patients at high risk of distant recurrence. The ability to identify patients who have a favourable prognosis could, after independent confirmation, allow clinicians to avoid adjuvant systemic therapy or to choose less aggressive therapeutic options.

Standard name | LI_INDUCED_T_TO_NATURAL_KILLER_UP
Systematic name | M2086
Organism | Mus musculus
PMID | 20538915
Authors | Li P,Burke S,Wang J,Chen X,Ortiz M,Lee SC,Lu D,Campos L,Goulding D,Ng BL,Dougan G,Huntly B,Gottgens B,Jenkins NA,Copeland NG,Colucci F,Liu P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ITNK cells (T-lymphocyte progenitors (DN3 cells) reprogrammed to natural killer (NK) cells by ablation of BCL11B [GeneID=64919] gene), compared to the parental DN3 cells.
Full description | T cells develop in the thymus and are critical for adaptive immunity. Natural killer (NK) lymphocytes constitute an essential component of the innate immune system in tumor surveillance, reproduction, and defense against microbes and viruses. Here, we show that the transcription factor Bcl11b was expressed in all T cell compartments and was indispensable for T lineage development. When Bcl11b was deleted, T cells from all developmental stages acquired NK cell properties and concomitantly lost or decreased T cell-associated gene expression. These induced T-to-natural killer (ITNK) cells, which were morphologically and genetically similar to conventional NK cells, killed tumor cells in vitro, and effectively prevented tumor metastasis in vivo. Therefore, ITNKs may represent a new cell source for cell-based therapies.

Standard name | LI_INDUCED_T_TO_NATURAL_KILLER_DN
Systematic name | M2088
Organism | Mus musculus
PMID | 20538915
Authors | Li P,Burke S,Wang J,Chen X,Ortiz M,Lee SC,Lu D,Campos L,Goulding D,Ng BL,Dougan G,Huntly B,Gottgens B,Jenkins NA,Copeland NG,Colucci F,Liu P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ITNK cells (T-lymphocyte progenitors (DN3 cells) reprogrammed to natural killer (NK) cells by ablation of BCL11B [GeneID=64919] gene), compared to the parental DN3 cells.
Full description | T cells develop in the thymus and are critical for adaptive immunity. Natural killer (NK) lymphocytes constitute an essential component of the innate immune system in tumor surveillance, reproduction, and defense against microbes and viruses. Here, we show that the transcription factor Bcl11b was expressed in all T cell compartments and was indispensable for T lineage development. When Bcl11b was deleted, T cells from all developmental stages acquired NK cell properties and concomitantly lost or decreased T cell-associated gene expression. These induced T-to-natural killer (ITNK) cells, which were morphologically and genetically similar to conventional NK cells, killed tumor cells in vitro, and effectively prevented tumor metastasis in vivo. Therefore, ITNKs may represent a new cell source for cell-based therapies.

Standard name | NOUSHMEHR_GBM_SOMATIC_MUTATED
Systematic name | M2089
Organism | Homo sapiens
PMID | 20399149
Authors | Noushmehr H,Weisenberger DJ,Diefes K,Phillips HS,Pujara K,Berman BP,Pan F,Pelloski CE,Sulman EP,Bhat KP,Verhaak RG,Hoadley KA,Hayes DN,Perou CM,Schmidt HK,Ding L,Wilson RK,Van Den Berg D,Shen H,Bengtsson H,Neuvial P,Cope LM,Buckley J,Herman JG,Baylin SB,Laird PW,Aldape K,Cancer Genome Atlas Research Network
Category | C2
Sub-category | CGP
Brief description | Genes showing significantly elevated somatic mutation frequencies in proneural G-CIMP (a CpG island methylator phenotype) GBM (glyoblastoma multiforme) tumors.
Full description | We have profiled promoter DNA methylation alterations in 272 glioblastoma tumors in the context of The Cancer Genome Atlas (TCGA). We found that a distinct subset of samples displays concerted hypermethylation at a large number of loci, indicating the existence of a glioma-CpG island methylator phenotype (G-CIMP). We validated G-CIMP in a set of non-TCGA glioblastomas and low-grade gliomas. G-CIMP tumors belong to the proneural subgroup, are more prevalent among lower-grade gliomas, display distinct copy-number alterations, and are tightly associated with IDH1 somatic mutations. Patients with G-CIMP tumors are younger at the time of diagnosis and experience significantly improved outcome. These findings identify G-CIMP as a distinct subset of human gliomas on molecular and clinical grounds.

Standard name | NOUSHMEHR_GBM_GERMLINE_MUTATED
Systematic name | M2090
Organism | Homo sapiens
PMID | 20399149
Authors | Noushmehr H,Weisenberger DJ,Diefes K,Phillips HS,Pujara K,Berman BP,Pan F,Pelloski CE,Sulman EP,Bhat KP,Verhaak RG,Hoadley KA,Hayes DN,Perou CM,Schmidt HK,Ding L,Wilson RK,Van Den Berg D,Shen H,Bengtsson H,Neuvial P,Cope LM,Buckley J,Herman JG,Baylin SB,Laird PW,Aldape K,Cancer Genome Atlas Research Network
Category | C2
Sub-category | CGP
Brief description | Genes with significantl germline mutation differences in proneural G-CIMP (a CpG island methylator phenotype) GBM (glyoblastoma multiforme) tumors.
Full description | We have profiled promoter DNA methylation alterations in 272 glioblastoma tumors in the context of The Cancer Genome Atlas (TCGA). We found that a distinct subset of samples displays concerted hypermethylation at a large number of loci, indicating the existence of a glioma-CpG island methylator phenotype (G-CIMP). We validated G-CIMP in a set of non-TCGA glioblastomas and low-grade gliomas. G-CIMP tumors belong to the proneural subgroup, are more prevalent among lower-grade gliomas, display distinct copy-number alterations, and are tightly associated with IDH1 somatic mutations. Patients with G-CIMP tumors are younger at the time of diagnosis and experience significantly improved outcome. These findings identify G-CIMP as a distinct subset of human gliomas on molecular and clinical grounds.

Standard name | NOUSHMEHR_GBM_SILENCED_BY_METHYLATION
Systematic name | M2091
Organism | Homo sapiens
PMID | 20399149
Authors | Noushmehr H,Weisenberger DJ,Diefes K,Phillips HS,Pujara K,Berman BP,Pan F,Pelloski CE,Sulman EP,Bhat KP,Verhaak RG,Hoadley KA,Hayes DN,Perou CM,Schmidt HK,Ding L,Wilson RK,Van Den Berg D,Shen H,Bengtsson H,Neuvial P,Cope LM,Buckley J,Herman JG,Baylin SB,Laird PW,Aldape K,Cancer Genome Atlas Research Network
Category | C2
Sub-category | CGP
Brief description | Top 50 most differentially hypermethylated and down-regulated genes in proneural G-CIMP (a CpG island methylator phenotype) GBM (glyoblastoma multiforme) tumors.
Full description | We have profiled promoter DNA methylation alterations in 272 glioblastoma tumors in the context of The Cancer Genome Atlas (TCGA). We found that a distinct subset of samples displays concerted hypermethylation at a large number of loci, indicating the existence of a glioma-CpG island methylator phenotype (G-CIMP). We validated G-CIMP in a set of non-TCGA glioblastomas and low-grade gliomas. G-CIMP tumors belong to the proneural subgroup, are more prevalent among lower-grade gliomas, display distinct copy-number alterations, and are tightly associated with IDH1 somatic mutations. Patients with G-CIMP tumors are younger at the time of diagnosis and experience significantly improved outcome. These findings identify G-CIMP as a distinct subset of human gliomas on molecular and clinical grounds.

Standard name | KAMIKUBO_MYELOID_CEBPA_NETWORK
Systematic name | M2092
Organism | Mus musculus
PMID | 20478528
Authors | Kamikubo Y,Zhao L,Wunderlich M,Corpora T,Hyde RK,Paul TA,Kundu M,Garrett L,Compton S,Huang G,Wolff L,Ito Y,Bushweller J,Mulloy JC,Liu PP
Category | C2
Sub-category | CGP
Brief description | Network of differentially expressed myeloid genes centered around CEBPA [GeneID=1050].
Full description | Dominant RUNX1 inhibition has been proposed as a common pathway for CBF leukemia. CBF beta-SMMHC, a fusion protein in human acute myeloid leukemia (AML), dominantly inhibits RUNX1 largely through its RUNX1 high-affinity binding domain (HABD). However, the type I CBF beta-SMMHC fusion in AML patients lacks HABD. Here, we report that the type I CBF beta-SMMHC protein binds RUNX1 inefficiently. Knockin mice expressing CBF beta-SMMHC with a HABD deletion developed leukemia quickly, even though hematopoietic defects associated with Runx1-inhibition were partially rescued. A larger pool of leukemia-initiating cells, increased MN1 expression, and retention of RUNX1 phosphorylation are potential mechanisms for accelerated leukemia development in these mice. Our data suggest that RUNX1 dominant inhibition may not be a critical step for leukemogenesis by CBF beta-SMMHC.

Standard name | KAMIKUBO_MYELOID_MN1_NETWORK
Systematic name | M2093
Organism | Mus musculus
PMID | 20478528
Authors | Kamikubo Y,Zhao L,Wunderlich M,Corpora T,Hyde RK,Paul TA,Kundu M,Garrett L,Compton S,Huang G,Wolff L,Ito Y,Bushweller J,Mulloy JC,Liu PP
Category | C2
Sub-category | CGP
Brief description | Network of differentially expressed myeloid genes centered around MN1 [GeneID=4330].
Full description | Dominant RUNX1 inhibition has been proposed as a common pathway for CBF leukemia. CBF beta-SMMHC, a fusion protein in human acute myeloid leukemia (AML), dominantly inhibits RUNX1 largely through its RUNX1 high-affinity binding domain (HABD). However, the type I CBF beta-SMMHC fusion in AML patients lacks HABD. Here, we report that the type I CBF beta-SMMHC protein binds RUNX1 inefficiently. Knockin mice expressing CBF beta-SMMHC with a HABD deletion developed leukemia quickly, even though hematopoietic defects associated with Runx1-inhibition were partially rescued. A larger pool of leukemia-initiating cells, increased MN1 expression, and retention of RUNX1 phosphorylation are potential mechanisms for accelerated leukemia development in these mice. Our data suggest that RUNX1 dominant inhibition may not be a critical step for leukemogenesis by CBF beta-SMMHC.

Standard name | MARTENS_BOUND_BY_PML_RARA_FUSION
Systematic name | M2094
Organism | Homo sapiens
PMID | 20159609
Authors | Martens JH,Brinkman AB,Simmer F,Francoijs KJ,Nebbioso A,Ferrara F,Altucci L,Stunnenberg HG
Category | C2
Sub-category | CGP
Brief description | Genes with promoters occupied by PML-RARA fusion [GeneID=5371,5914] protein in acute promyelocytic leukemia(APL) cells NB4 and two APL primary blasts, based on Chip-seq data.
Full description | Many different molecular mechanisms have been associated with PML-RARalpha-dependent transformation of hematopoietic progenitors. Here, we identified high confidence PML-RARalpha binding sites in an acute promyelocytic leukemia (APL) cell line and in two APL primary blasts. We found colocalization of PML-RARalpha with RXR to the vast majority of these binding regions. Genome-wide epigenetic studies revealed that treatment with pharmacological doses of all-trans retinoic acid induces changes in H3 acetylation, but not H3K27me3, H3K9me3, or DNA methylation at the PML-RARalpha/RXR binding sites or at nearby target genes. Our results suggest that PML-RARalpha/RXR functions as a local chromatin modulator and that specific recruitment of histone deacetylase activities to genes important for hematopoietic differentiation, RAR signaling, and epigenetic control is crucial to its transforming potential.

Standard name | MARTENS_TRETINOIN_RESPONSE_UP
Systematic name | M2098
Organism | Homo sapiens
PMID | 20159609
Authors | Martens JH,Brinkman AB,Simmer F,Francoijs KJ,Nebbioso A,Ferrara F,Altucci L,Stunnenberg HG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in NB4 cells (acute promyelocytic leukemia, APL) in response to tretinoin [PubChem=444795]; based on Chip-seq data.
Full description | Many different molecular mechanisms have been associated with PML-RARalpha-dependent transformation of hematopoietic progenitors. Here, we identified high confidence PML-RARalpha binding sites in an acute promyelocytic leukemia (APL) cell line and in two APL primary blasts. We found colocalization of PML-RARalpha with RXR to the vast majority of these binding regions. Genome-wide epigenetic studies revealed that treatment with pharmacological doses of all-trans retinoic acid induces changes in H3 acetylation, but not H3K27me3, H3K9me3, or DNA methylation at the PML-RARalpha/RXR binding sites or at nearby target genes. Our results suggest that PML-RARalpha/RXR functions as a local chromatin modulator and that specific recruitment of histone deacetylase activities to genes important for hematopoietic differentiation, RAR signaling, and epigenetic control is crucial to its transforming potential.

Standard name | MARTENS_TRETINOIN_RESPONSE_DN
Systematic name | M2099
Organism | Homo sapiens
PMID | 20159609
Authors | Martens JH,Brinkman AB,Simmer F,Francoijs KJ,Nebbioso A,Ferrara F,Altucci L,Stunnenberg HG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in NB4 cells (acute promyelocytic leukemia, APL) in response to tretinoin [PubChem=444795]; based on Chip-seq data.
Full description | Many different molecular mechanisms have been associated with PML-RARalpha-dependent transformation of hematopoietic progenitors. Here, we identified high confidence PML-RARalpha binding sites in an acute promyelocytic leukemia (APL) cell line and in two APL primary blasts. We found colocalization of PML-RARalpha with RXR to the vast majority of these binding regions. Genome-wide epigenetic studies revealed that treatment with pharmacological doses of all-trans retinoic acid induces changes in H3 acetylation, but not H3K27me3, H3K9me3, or DNA methylation at the PML-RARalpha/RXR binding sites or at nearby target genes. Our results suggest that PML-RARalpha/RXR functions as a local chromatin modulator and that specific recruitment of histone deacetylase activities to genes important for hematopoietic differentiation, RAR signaling, and epigenetic control is crucial to its transforming potential.

Standard name | STAMBOLSKY_BOUND_BY_MUTATED_TP53
Systematic name | M2100
Organism | Homo sapiens
PMID | 20227041
Authors | Stambolsky P,Tabach Y,Fontemaggi G,Weisz L,Maor-Aloni R,Siegfried Z,Shiff I,Kogan I,Shay M,Kalo E,Blandino G,Simon I,Oren M,Rotter V
Category | C2
Sub-category | CGP
Brief description | Gene promoters preferentially bound by a mutated form of TP53 [GeneID=7157] in SKBR3 cells (breast cancer).
Full description | The p53 gene is mutated in many human tumors. Cells of such tumors often contain abundant mutant p53 (mutp53) protein, which may contribute actively to tumor progression via a gain-of-function mechanism. We applied ChIP-on-chip analysis and identified the vitamin D receptor (VDR) response element as overrepresented in promoter sequences bound by mutp53. We report that mutp53 can interact functionally and physically with VDR. Mutp53 is recruited to VDR-regulated genes and modulates their expression, augmenting the transactivation of some genes and relieving the repression of others. Furthermore, mutp53 increases the nuclear accumulation of VDR. Importantly, mutp53 converts vitamin D into an antiapoptotic agent. Thus, p53 status can determine the biological impact of vitamin D on tumor cells.

Standard name | STAMBOLSKY_TARGETS_OF_MUTATED_TP53_UP
Systematic name | M2101
Organism | Homo sapiens
PMID | 20227041
Authors | Stambolsky P,Tabach Y,Fontemaggi G,Weisz L,Maor-Aloni R,Siegfried Z,Shiff I,Kogan I,Shay M,Kalo E,Blandino G,Simon I,Oren M,Rotter V
Category | C2
Sub-category | CGP
Brief description | Genes induced in SKBR3 cells (breast cancer) by mutated TP53 [GeneID=7157].
Full description | The p53 gene is mutated in many human tumors. Cells of such tumors often contain abundant mutant p53 (mutp53) protein, which may contribute actively to tumor progression via a gain-of-function mechanism. We applied ChIP-on-chip analysis and identified the vitamin D receptor (VDR) response element as overrepresented in promoter sequences bound by mutp53. We report that mutp53 can interact functionally and physically with VDR. Mutp53 is recruited to VDR-regulated genes and modulates their expression, augmenting the transactivation of some genes and relieving the repression of others. Furthermore, mutp53 increases the nuclear accumulation of VDR. Importantly, mutp53 converts vitamin D into an antiapoptotic agent. Thus, p53 status can determine the biological impact of vitamin D on tumor cells.

Standard name | STAMBOLSKY_TARGETS_OF_MUTATED_TP53_DN
Systematic name | M2102
Organism | Homo sapiens
PMID | 20227041
Authors | Stambolsky P,Tabach Y,Fontemaggi G,Weisz L,Maor-Aloni R,Siegfried Z,Shiff I,Kogan I,Shay M,Kalo E,Blandino G,Simon I,Oren M,Rotter V
Category | C2
Sub-category | CGP
Brief description | Genes repressed in SKBR3 cells (breast cancer) by mutated TP53 [GeneID=7157].
Full description | The p53 gene is mutated in many human tumors. Cells of such tumors often contain abundant mutant p53 (mutp53) protein, which may contribute actively to tumor progression via a gain-of-function mechanism. We applied ChIP-on-chip analysis and identified the vitamin D receptor (VDR) response element as overrepresented in promoter sequences bound by mutp53. We report that mutp53 can interact functionally and physically with VDR. Mutp53 is recruited to VDR-regulated genes and modulates their expression, augmenting the transactivation of some genes and relieving the repression of others. Furthermore, mutp53 increases the nuclear accumulation of VDR. Importantly, mutp53 converts vitamin D into an antiapoptotic agent. Thus, p53 status can determine the biological impact of vitamin D on tumor cells.

Standard name | STAMBOLSKY_RESPONSE_TO_VITAMIN_D3_UP
Systematic name | M2103
Organism | Homo sapiens
PMID | 20227041
Authors | Stambolsky P,Tabach Y,Fontemaggi G,Weisz L,Maor-Aloni R,Siegfried Z,Shiff I,Kogan I,Shay M,Kalo E,Blandino G,Simon I,Oren M,Rotter V
Category | C2
Sub-category | CGP
Brief description | Genes induced in SKBR3 cells (breast cancer) by 25-hydroxyvitamin D3 [PubChem=1593].
Full description | The p53 gene is mutated in many human tumors. Cells of such tumors often contain abundant mutant p53 (mutp53) protein, which may contribute actively to tumor progression via a gain-of-function mechanism. We applied ChIP-on-chip analysis and identified the vitamin D receptor (VDR) response element as overrepresented in promoter sequences bound by mutp53. We report that mutp53 can interact functionally and physically with VDR. Mutp53 is recruited to VDR-regulated genes and modulates their expression, augmenting the transactivation of some genes and relieving the repression of others. Furthermore, mutp53 increases the nuclear accumulation of VDR. Importantly, mutp53 converts vitamin D into an antiapoptotic agent. Thus, p53 status can determine the biological impact of vitamin D on tumor cells.

Standard name | STAMBOLSKY_RESPONSE_TO_VITAMIN_D3_DN
Systematic name | M2104
Organism | Homo sapiens
PMID | 20227041
Authors | Stambolsky P,Tabach Y,Fontemaggi G,Weisz L,Maor-Aloni R,Siegfried Z,Shiff I,Kogan I,Shay M,Kalo E,Blandino G,Simon I,Oren M,Rotter V
Category | C2
Sub-category | CGP
Brief description | Genes repressed in SKBR3 cells (breast cancer) by 25-hydroxyvitamin D3 [PubChem=1593].
Full description | The p53 gene is mutated in many human tumors. Cells of such tumors often contain abundant mutant p53 (mutp53) protein, which may contribute actively to tumor progression via a gain-of-function mechanism. We applied ChIP-on-chip analysis and identified the vitamin D receptor (VDR) response element as overrepresented in promoter sequences bound by mutp53. We report that mutp53 can interact functionally and physically with VDR. Mutp53 is recruited to VDR-regulated genes and modulates their expression, augmenting the transactivation of some genes and relieving the repression of others. Furthermore, mutp53 increases the nuclear accumulation of VDR. Importantly, mutp53 converts vitamin D into an antiapoptotic agent. Thus, p53 status can determine the biological impact of vitamin D on tumor cells.

Standard name | KIM_ALL_DISORDERS_OLIGODENDROCYTE_NUMBER_CORR_UP
Systematic name | M2105
Organism | Homo sapiens
PMID | 18762803
Authors | Kim S,Webster MJ
Category | C2
Sub-category | CGP
Brief description | Genes whose expression was significantly and positively correlated with the number of perineuronal oligodendrocytes in the layer III of BA9 brain region.
Full description | Cytoarchitectural abnormalities have been described in the prefrontal cortex of subjects with schizophrenia, bipolar disorder and depression. However, little is known about the gene expression profiles associated with these abnormalities. Genome-wide expression profiling technology provides an unbiased approach to identifying candidate genes and biological processes that may be associated with complex biological traits such as cytoarchitecture. In this study, we explored expression profiles associated with the abnormalities by using publicly available microarray metadata and cytoarchitectural data from post-mortem samples of the frontal cortex from 54 subjects (schizophrenia, n=14; bipolar disorder, n=13; depression, n=12 and controls n=15). Correlation analysis between genome-wide expression levels and cytoarchitectural traits revealed that 818 genes were significantly correlated with a decrease in the number of perineuronal oligodendrocytes across all subjects. A total of 600 genes were significantly correlated with a decrease in density of calbindin-positive interneurons across all subjects. Multiple biological processes including cellular metabolism, central nervous system development, cell motility and programmed cell death were significantly overrepresented in both correlated gene lists. These findings may provide novel insights into the molecular mechanisms that underlie the cytoarchitectural abnormalities of perineuronal oligodendrocytes and calbindin-containing GABAergic interneurons in the prefrontal cortex of the major psychiatric disorders.

Standard name | KIM_ALL_DISORDERS_OLIGODENDROCYTE_NUMBER_CORR_DN
Systematic name | M2106
Organism | Homo sapiens
PMID | 18762803
Authors | Kim S,Webster MJ
Category | C2
Sub-category | CGP
Brief description | Genes whose expression was significantly and negatively correlated with the number of perineuronal oligodendrocytes in the layer III of BA9 brain region.
Full description | Cytoarchitectural abnormalities have been described in the prefrontal cortex of subjects with schizophrenia, bipolar disorder and depression. However, little is known about the gene expression profiles associated with these abnormalities. Genome-wide expression profiling technology provides an unbiased approach to identifying candidate genes and biological processes that may be associated with complex biological traits such as cytoarchitecture. In this study, we explored expression profiles associated with the abnormalities by using publicly available microarray metadata and cytoarchitectural data from post-mortem samples of the frontal cortex from 54 subjects (schizophrenia, n=14; bipolar disorder, n=13; depression, n=12 and controls n=15). Correlation analysis between genome-wide expression levels and cytoarchitectural traits revealed that 818 genes were significantly correlated with a decrease in the number of perineuronal oligodendrocytes across all subjects. A total of 600 genes were significantly correlated with a decrease in density of calbindin-positive interneurons across all subjects. Multiple biological processes including cellular metabolism, central nervous system development, cell motility and programmed cell death were significantly overrepresented in both correlated gene lists. These findings may provide novel insights into the molecular mechanisms that underlie the cytoarchitectural abnormalities of perineuronal oligodendrocytes and calbindin-containing GABAergic interneurons in the prefrontal cortex of the major psychiatric disorders.

Standard name | KIM_BIPOLAR_DISORDER_OLIGODENDROCYTE_DENSITY_CORR_UP
Systematic name | M2107
Organism | Homo sapiens
PMID | 18762803
Authors | Kim S,Webster MJ
Category | C2
Sub-category | CGP
Brief description | Genes whose expression significantly and positively correlated with oligodendrocyte density in layer VI of BA9 brain region in patients with bipolar disorder.
Full description | Cytoarchitectural abnormalities have been described in the prefrontal cortex of subjects with schizophrenia, bipolar disorder and depression. However, little is known about the gene expression profiles associated with these abnormalities. Genome-wide expression profiling technology provides an unbiased approach to identifying candidate genes and biological processes that may be associated with complex biological traits such as cytoarchitecture. In this study, we explored expression profiles associated with the abnormalities by using publicly available microarray metadata and cytoarchitectural data from post-mortem samples of the frontal cortex from 54 subjects (schizophrenia, n=14; bipolar disorder, n=13; depression, n=12 and controls n=15). Correlation analysis between genome-wide expression levels and cytoarchitectural traits revealed that 818 genes were significantly correlated with a decrease in the number of perineuronal oligodendrocytes across all subjects. A total of 600 genes were significantly correlated with a decrease in density of calbindin-positive interneurons across all subjects. Multiple biological processes including cellular metabolism, central nervous system development, cell motility and programmed cell death were significantly overrepresented in both correlated gene lists. These findings may provide novel insights into the molecular mechanisms that underlie the cytoarchitectural abnormalities of perineuronal oligodendrocytes and calbindin-containing GABAergic interneurons in the prefrontal cortex of the major psychiatric disorders.

Standard name | KIM_BIPOLAR_DISORDER_OLIGODENDROCYTE_DENSITY_CORR_DN
Systematic name | M2109
Organism | Homo sapiens
PMID | 18762803
Authors | Kim S,Webster MJ
Category | C2
Sub-category | CGP
Brief description | Genes whose expression significantly and negatively correlated with oligodendrocyte density in layer VI of BA9 brain region in patients with bipolar disorder.
Full description | Cytoarchitectural abnormalities have been described in the prefrontal cortex of subjects with schizophrenia, bipolar disorder and depression. However, little is known about the gene expression profiles associated with these abnormalities. Genome-wide expression profiling technology provides an unbiased approach to identifying candidate genes and biological processes that may be associated with complex biological traits such as cytoarchitecture. In this study, we explored expression profiles associated with the abnormalities by using publicly available microarray metadata and cytoarchitectural data from post-mortem samples of the frontal cortex from 54 subjects (schizophrenia, n=14; bipolar disorder, n=13; depression, n=12 and controls n=15). Correlation analysis between genome-wide expression levels and cytoarchitectural traits revealed that 818 genes were significantly correlated with a decrease in the number of perineuronal oligodendrocytes across all subjects. A total of 600 genes were significantly correlated with a decrease in density of calbindin-positive interneurons across all subjects. Multiple biological processes including cellular metabolism, central nervous system development, cell motility and programmed cell death were significantly overrepresented in both correlated gene lists. These findings may provide novel insights into the molecular mechanisms that underlie the cytoarchitectural abnormalities of perineuronal oligodendrocytes and calbindin-containing GABAergic interneurons in the prefrontal cortex of the major psychiatric disorders.

Standard name | KIM_ALL_DISORDERS_CALB1_CORR_UP
Systematic name | M2110
Organism | Homo sapiens
PMID | 18762803
Authors | Kim S,Webster MJ
Category | C2
Sub-category | CGP
Brief description | Genes whose expression significantly and positively correlated with the density of CALB1-positive [GeneID=793] GABAergic interneurons in the BA9 brain region across all subjects with psychiatric disorders.
Full description | Cytoarchitectural abnormalities have been described in the prefrontal cortex of subjects with schizophrenia, bipolar disorder and depression. However, little is known about the gene expression profiles associated with these abnormalities. Genome-wide expression profiling technology provides an unbiased approach to identifying candidate genes and biological processes that may be associated with complex biological traits such as cytoarchitecture. In this study, we explored expression profiles associated with the abnormalities by using publicly available microarray metadata and cytoarchitectural data from post-mortem samples of the frontal cortex from 54 subjects (schizophrenia, n=14; bipolar disorder, n=13; depression, n=12 and controls n=15). Correlation analysis between genome-wide expression levels and cytoarchitectural traits revealed that 818 genes were significantly correlated with a decrease in the number of perineuronal oligodendrocytes across all subjects. A total of 600 genes were significantly correlated with a decrease in density of calbindin-positive interneurons across all subjects. Multiple biological processes including cellular metabolism, central nervous system development, cell motility and programmed cell death were significantly overrepresented in both correlated gene lists. These findings may provide novel insights into the molecular mechanisms that underlie the cytoarchitectural abnormalities of perineuronal oligodendrocytes and calbindin-containing GABAergic interneurons in the prefrontal cortex of the major psychiatric disorders.

Standard name | KIM_ALL_DISORDERS_CALB1_CORR_DN
Systematic name | M2111
Organism | Homo sapiens
PMID | 18762803
Authors | Kim S,Webster MJ
Category | C2
Sub-category | CGP
Brief description | Genes whose expression significantly and negatively correlated with the density of CALB1-positive [GeneID=793] GABAergic interneurons in the BA9 brain region across all subjects with psychiatric disorders.
Full description | Cytoarchitectural abnormalities have been described in the prefrontal cortex of subjects with schizophrenia, bipolar disorder and depression. However, little is known about the gene expression profiles associated with these abnormalities. Genome-wide expression profiling technology provides an unbiased approach to identifying candidate genes and biological processes that may be associated with complex biological traits such as cytoarchitecture. In this study, we explored expression profiles associated with the abnormalities by using publicly available microarray metadata and cytoarchitectural data from post-mortem samples of the frontal cortex from 54 subjects (schizophrenia, n=14; bipolar disorder, n=13; depression, n=12 and controls n=15). Correlation analysis between genome-wide expression levels and cytoarchitectural traits revealed that 818 genes were significantly correlated with a decrease in the number of perineuronal oligodendrocytes across all subjects. A total of 600 genes were significantly correlated with a decrease in density of calbindin-positive interneurons across all subjects. Multiple biological processes including cellular metabolism, central nervous system development, cell motility and programmed cell death were significantly overrepresented in both correlated gene lists. These findings may provide novel insights into the molecular mechanisms that underlie the cytoarchitectural abnormalities of perineuronal oligodendrocytes and calbindin-containing GABAergic interneurons in the prefrontal cortex of the major psychiatric disorders.

Standard name | KIM_ALL_DISORDERS_DURATION_CORR_UP
Systematic name | M2112
Organism | Homo sapiens
PMID | 18762803
Authors | Kim S,Webster MJ
Category | C2
Sub-category | CGP
Brief description | Genes whose expression in brain significantly and positively correlated with the duration of all psychiatric disorders studied.
Full description | Cytoarchitectural abnormalities have been described in the prefrontal cortex of subjects with schizophrenia, bipolar disorder and depression. However, little is known about the gene expression profiles associated with these abnormalities. Genome-wide expression profiling technology provides an unbiased approach to identifying candidate genes and biological processes that may be associated with complex biological traits such as cytoarchitecture. In this study, we explored expression profiles associated with the abnormalities by using publicly available microarray metadata and cytoarchitectural data from post-mortem samples of the frontal cortex from 54 subjects (schizophrenia, n=14; bipolar disorder, n=13; depression, n=12 and controls n=15). Correlation analysis between genome-wide expression levels and cytoarchitectural traits revealed that 818 genes were significantly correlated with a decrease in the number of perineuronal oligodendrocytes across all subjects. A total of 600 genes were significantly correlated with a decrease in density of calbindin-positive interneurons across all subjects. Multiple biological processes including cellular metabolism, central nervous system development, cell motility and programmed cell death were significantly overrepresented in both correlated gene lists. These findings may provide novel insights into the molecular mechanisms that underlie the cytoarchitectural abnormalities of perineuronal oligodendrocytes and calbindin-containing GABAergic interneurons in the prefrontal cortex of the major psychiatric disorders.

Standard name | KIM_ALL_DISORDERS_DURATION_CORR_DN
Systematic name | M2113
Organism | Homo sapiens
PMID | 18762803
Authors | Kim S,Webster MJ
Category | C2
Sub-category | CGP
Brief description | Genes whose expression in brain significantly and negatively correlated with the duration of all psychiatric disorders studied.
Full description | Cytoarchitectural abnormalities have been described in the prefrontal cortex of subjects with schizophrenia, bipolar disorder and depression. However, little is known about the gene expression profiles associated with these abnormalities. Genome-wide expression profiling technology provides an unbiased approach to identifying candidate genes and biological processes that may be associated with complex biological traits such as cytoarchitecture. In this study, we explored expression profiles associated with the abnormalities by using publicly available microarray metadata and cytoarchitectural data from post-mortem samples of the frontal cortex from 54 subjects (schizophrenia, n=14; bipolar disorder, n=13; depression, n=12 and controls n=15). Correlation analysis between genome-wide expression levels and cytoarchitectural traits revealed that 818 genes were significantly correlated with a decrease in the number of perineuronal oligodendrocytes across all subjects. A total of 600 genes were significantly correlated with a decrease in density of calbindin-positive interneurons across all subjects. Multiple biological processes including cellular metabolism, central nervous system development, cell motility and programmed cell death were significantly overrepresented in both correlated gene lists. These findings may provide novel insights into the molecular mechanisms that underlie the cytoarchitectural abnormalities of perineuronal oligodendrocytes and calbindin-containing GABAergic interneurons in the prefrontal cortex of the major psychiatric disorders.

Standard name | VERHAAK_GLIOBLASTOMA_PRONEURAL
Systematic name | M2115
Organism | Homo sapiens
PMID | 20129251
Authors | Verhaak RG,Hoadley KA,Purdom E,Wang V,Qi Y,Wilkerson MD,Miller CR,Ding L,Golub T,Mesirov JP,Alexe G,Lawrence M,O'Kelly M,Tamayo P,Weir BA,Gabriel S,Winckler W,Gupta S,Jakkula L,Feiler HS,Hodgson JG,James CD,Sarkaria JN,Brennan C,Kahn A,Spellman PT,Wilson RK,Speed TP,Gray JW,Meyerson M,Getz G,Perou CM,Hayes DN,Cancer Genome Atlas Research Network
Category | C2
Sub-category | CGP
Brief description | Genes correlated with proneural type of glioblastoma multiforme tumors.
Full description | The Cancer Genome Atlas Network recently cataloged recurrent genomic abnormalities in glioblastoma multiforme (GBM). We describe a robust gene expression-based molecular classification of GBM into Proneural, Neural, Classical, and Mesenchymal subtypes and integrate multidimensional genomic data to establish patterns of somatic mutations and DNA copy number. Aberrations and gene expression of EGFR, NF1, and PDGFRA/IDH1 each define the Classical, Mesenchymal, and Proneural subtypes, respectively. Gene signatures of normal brain cell types show a strong relationship between subtypes and different neural lineages. Additionally, response to aggressive therapy differs by subtype, with the greatest benefit in the Classical subtype and no benefit in the Proneural subtype. We provide a framework that unifies transcriptomic and genomic dimensions for GBM molecular stratification with important implications for future studies.

Standard name | VERHAAK_GLIOBLASTOMA_NEURAL
Systematic name | M2116
Organism | Homo sapiens
PMID | 20129251
Authors | Verhaak RG,Hoadley KA,Purdom E,Wang V,Qi Y,Wilkerson MD,Miller CR,Ding L,Golub T,Mesirov JP,Alexe G,Lawrence M,O'Kelly M,Tamayo P,Weir BA,Gabriel S,Winckler W,Gupta S,Jakkula L,Feiler HS,Hodgson JG,James CD,Sarkaria JN,Brennan C,Kahn A,Spellman PT,Wilson RK,Speed TP,Gray JW,Meyerson M,Getz G,Perou CM,Hayes DN,Cancer Genome Atlas Research Network
Category | C2
Sub-category | CGP
Brief description | Genes correlated with neural type of glioblastoma multiforme tumors.
Full description | The Cancer Genome Atlas Network recently cataloged recurrent genomic abnormalities in glioblastoma multiforme (GBM). We describe a robust gene expression-based molecular classification of GBM into Proneural, Neural, Classical, and Mesenchymal subtypes and integrate multidimensional genomic data to establish patterns of somatic mutations and DNA copy number. Aberrations and gene expression of EGFR, NF1, and PDGFRA/IDH1 each define the Classical, Mesenchymal, and Proneural subtypes, respectively. Gene signatures of normal brain cell types show a strong relationship between subtypes and different neural lineages. Additionally, response to aggressive therapy differs by subtype, with the greatest benefit in the Classical subtype and no benefit in the Proneural subtype. We provide a framework that unifies transcriptomic and genomic dimensions for GBM molecular stratification with important implications for future studies.

Standard name | VERHAAK_GLIOBLASTOMA_CLASSICAL
Systematic name | M2121
Organism | Homo sapiens
PMID | 20129251
Authors | Verhaak RG,Hoadley KA,Purdom E,Wang V,Qi Y,Wilkerson MD,Miller CR,Ding L,Golub T,Mesirov JP,Alexe G,Lawrence M,O'Kelly M,Tamayo P,Weir BA,Gabriel S,Winckler W,Gupta S,Jakkula L,Feiler HS,Hodgson JG,James CD,Sarkaria JN,Brennan C,Kahn A,Spellman PT,Wilson RK,Speed TP,Gray JW,Meyerson M,Getz G,Perou CM,Hayes DN,Cancer Genome Atlas Research Network
Category | C2
Sub-category | CGP
Brief description | Genes correlated with classical type of glioblastoma multiforme tumors.
Full description | The Cancer Genome Atlas Network recently cataloged recurrent genomic abnormalities in glioblastoma multiforme (GBM). We describe a robust gene expression-based molecular classification of GBM into Proneural, Neural, Classical, and Mesenchymal subtypes and integrate multidimensional genomic data to establish patterns of somatic mutations and DNA copy number. Aberrations and gene expression of EGFR, NF1, and PDGFRA/IDH1 each define the Classical, Mesenchymal, and Proneural subtypes, respectively. Gene signatures of normal brain cell types show a strong relationship between subtypes and different neural lineages. Additionally, response to aggressive therapy differs by subtype, with the greatest benefit in the Classical subtype and no benefit in the Proneural subtype. We provide a framework that unifies transcriptomic and genomic dimensions for GBM molecular stratification with important implications for future studies.

Standard name | VERHAAK_GLIOBLASTOMA_MESENCHYMAL
Systematic name | M2122
Organism | Homo sapiens
PMID | 20129251
Authors | Verhaak RG,Hoadley KA,Purdom E,Wang V,Qi Y,Wilkerson MD,Miller CR,Ding L,Golub T,Mesirov JP,Alexe G,Lawrence M,O'Kelly M,Tamayo P,Weir BA,Gabriel S,Winckler W,Gupta S,Jakkula L,Feiler HS,Hodgson JG,James CD,Sarkaria JN,Brennan C,Kahn A,Spellman PT,Wilson RK,Speed TP,Gray JW,Meyerson M,Getz G,Perou CM,Hayes DN,Cancer Genome Atlas Research Network
Category | C2
Sub-category | CGP
Brief description | Genes correlated with mesenchymal type of glioblastoma multiforme tumors.
Full description | The Cancer Genome Atlas Network recently cataloged recurrent genomic abnormalities in glioblastoma multiforme (GBM). We describe a robust gene expression-based molecular classification of GBM into Proneural, Neural, Classical, and Mesenchymal subtypes and integrate multidimensional genomic data to establish patterns of somatic mutations and DNA copy number. Aberrations and gene expression of EGFR, NF1, and PDGFRA/IDH1 each define the Classical, Mesenchymal, and Proneural subtypes, respectively. Gene signatures of normal brain cell types show a strong relationship between subtypes and different neural lineages. Additionally, response to aggressive therapy differs by subtype, with the greatest benefit in the Classical subtype and no benefit in the Proneural subtype. We provide a framework that unifies transcriptomic and genomic dimensions for GBM molecular stratification with important implications for future studies.

Standard name | HIRSCH_CELLULAR_TRANSFORMATION_SIGNATURE_UP
Systematic name | M2123
Organism | Homo sapiens
PMID | 20385360
Authors | Hirsch HA,Iliopoulos D,Joshi A,Zhang Y,Jaeger SA,Bulyk M,Tsichlis PN,Shirley Liu X,Struhl K
Category | C2
Sub-category | CGP
Brief description | Up-regulated genes in the cancer gene signature, representing a gene signature of cellular transformation.
Full description | Transcriptional profiling of two isogenic models of transformation identifies a gene signature linking cancer with inflammatory and metabolic diseases. In accord with this common transcriptional program, many drugs used for treatment of diabetes and cardiovascular diseases inhibit transformation and tumor growth. Unexpectedly, lipid metabolism genes are important for transformation and are upregulated in cancer tissues. As in atherosclerosis, oxidized LDL and its receptor OLR1 activate the inflammatory pathway through NF-kappaB, leading to transformation. OLR1 is important for maintaining the transformed state in developmentally diverse cancer cell lines and for tumor growth, suggesting a molecular connection between cancer and atherosclerosis. We suggest that the interplay between this common transcriptional program and cell-type-specific factors gives rise to phenotypically disparate human diseases.

Standard name | HIRSCH_CELLULAR_TRANSFORMATION_SIGNATURE_DN
Systematic name | M2124
Organism | Homo sapiens
PMID | 20385360
Authors | Hirsch HA,Iliopoulos D,Joshi A,Zhang Y,Jaeger SA,Bulyk M,Tsichlis PN,Shirley Liu X,Struhl K
Category | C2
Sub-category | CGP
Brief description | Down-regulated genes in the cancer gene signature, representing a gene signature of cellular transformation.
Full description | Transcriptional profiling of two isogenic models of transformation identifies a gene signature linking cancer with inflammatory and metabolic diseases. In accord with this common transcriptional program, many drugs used for treatment of diabetes and cardiovascular diseases inhibit transformation and tumor growth. Unexpectedly, lipid metabolism genes are important for transformation and are upregulated in cancer tissues. As in atherosclerosis, oxidized LDL and its receptor OLR1 activate the inflammatory pathway through NF-kappaB, leading to transformation. OLR1 is important for maintaining the transformed state in developmentally diverse cancer cell lines and for tumor growth, suggesting a molecular connection between cancer and atherosclerosis. We suggest that the interplay between this common transcriptional program and cell-type-specific factors gives rise to phenotypically disparate human diseases.

Standard name | CHICAS_RB1_TARGETS_SENESCENT
Systematic name | M2125
Organism | Homo sapiens
PMID | 20385362
Authors | Chicas A,Wang X,Zhang C,McCurrach M,Zhao Z,Mert O,Dickins RA,Narita M,Zhang M,Lowe SW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in senescent IMR90 cells (fibroblast) after knockdown of RB1 [GeneID=5925] by RNAi.
Full description | The RB protein family (RB, p107, and p130) has overlapping and compensatory functions in cell-cycle control. However, cancer-associated mutations are almost exclusively found in RB, implying that RB has a nonredundant role in tumor suppression. We demonstrate that RB preferentially associates with E2F target genes involved in DNA replication and is uniquely required to repress these genes during senescence but not other growth states. Consequently, RB loss leads to inappropriate DNA synthesis following a senescence trigger and, together with disruption of a p21-mediated cell-cycle checkpoint, enables extensive proliferation and rampant genomic instability. Our results identify a nonredundant RB effector function that may contribute to tumor suppression and reveal how loss of RB and p53 cooperate to bypass senescence.

Standard name | CHICAS_RB1_TARGETS_LOW_SERUM
Systematic name | M2126
Organism | Homo sapiens
PMID | 20385362
Authors | Chicas A,Wang X,Zhang C,McCurrach M,Zhao Z,Mert O,Dickins RA,Narita M,Zhang M,Lowe SW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in IMR90 cells (fibroblast) grown under low serum conditions and after knockdown of RB1 [GeneID=5925] by RNAi.
Full description | The RB protein family (RB, p107, and p130) has overlapping and compensatory functions in cell-cycle control. However, cancer-associated mutations are almost exclusively found in RB, implying that RB has a nonredundant role in tumor suppression. We demonstrate that RB preferentially associates with E2F target genes involved in DNA replication and is uniquely required to repress these genes during senescence but not other growth states. Consequently, RB loss leads to inappropriate DNA synthesis following a senescence trigger and, together with disruption of a p21-mediated cell-cycle checkpoint, enables extensive proliferation and rampant genomic instability. Our results identify a nonredundant RB effector function that may contribute to tumor suppression and reveal how loss of RB and p53 cooperate to bypass senescence.

Standard name | CHICAS_RB1_TARGETS_GROWING
Systematic name | M2128
Organism | Homo sapiens
PMID | 20385362
Authors | Chicas A,Wang X,Zhang C,McCurrach M,Zhao Z,Mert O,Dickins RA,Narita M,Zhang M,Lowe SW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in growing IMR90 cells (fibroblast) after knockdown of RB1 [GeneID=5925] by RNAi.
Full description | The RB protein family (RB, p107, and p130) has overlapping and compensatory functions in cell-cycle control. However, cancer-associated mutations are almost exclusively found in RB, implying that RB has a nonredundant role in tumor suppression. We demonstrate that RB preferentially associates with E2F target genes involved in DNA replication and is uniquely required to repress these genes during senescence but not other growth states. Consequently, RB loss leads to inappropriate DNA synthesis following a senescence trigger and, together with disruption of a p21-mediated cell-cycle checkpoint, enables extensive proliferation and rampant genomic instability. Our results identify a nonredundant RB effector function that may contribute to tumor suppression and reveal how loss of RB and p53 cooperate to bypass senescence.

Standard name | CHICAS_RB1_TARGETS_CONFLUENT
Systematic name | M2129
Organism | Homo sapiens
PMID | 20385362
Authors | Chicas A,Wang X,Zhang C,McCurrach M,Zhao Z,Mert O,Dickins RA,Narita M,Zhang M,Lowe SW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in confluent IMR90 cells (fibroblast) after knockdown of RB1 [GeneID=5925] by RNAi.
Full description | The RB protein family (RB, p107, and p130) has overlapping and compensatory functions in cell-cycle control. However, cancer-associated mutations are almost exclusively found in RB, implying that RB has a nonredundant role in tumor suppression. We demonstrate that RB preferentially associates with E2F target genes involved in DNA replication and is uniquely required to repress these genes during senescence but not other growth states. Consequently, RB loss leads to inappropriate DNA synthesis following a senescence trigger and, together with disruption of a p21-mediated cell-cycle checkpoint, enables extensive proliferation and rampant genomic instability. Our results identify a nonredundant RB effector function that may contribute to tumor suppression and reveal how loss of RB and p53 cooperate to bypass senescence.

Standard name | WANG_RESPONSE_TO_GSK3_INHIBITOR_SB216763_UP
Systematic name | M2131
Organism | Homo sapiens
PMID | 20541704
Authors | Wang Z,Iwasaki M,Ficara F,Lin C,Matheny C,Wong SH,Smith KS,Cleary ML
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RS4;11 cells (MLL, mixed lineage leukemia) in response to SB216763 [PubChem=176158], an inhibitor of GSK3B [GeneID=2932].
Full description | Acute leukemias induced by MLL chimeric oncoproteins are among the subset of cancers distinguished by a paradoxical dependence on GSK-3 kinase activity for sustained proliferation. We demonstrate here that GSK-3 maintains the MLL leukemia stem cell transcriptional program by promoting the conditional association of CREB and its coactivators TORC and CBP with homedomain protein MEIS1, a critical component of the MLL-subordinate program, which in turn facilitates HOX-mediated transcription and transformation. This mechanism also applies to hematopoietic cells transformed by other HOX genes, including CDX2, which is highly expressed in a majority of acute myeloid leukemias, thus providing a molecular approach based on GSK-3 inhibitory strategies to target HOX-associated transcription in a broad spectrum of leukemias.

Standard name | WANG_RESPONSE_TO_GSK3_INHIBITOR_SB216763_DN
Systematic name | M2132
Organism | Homo sapiens
PMID | 20541704
Authors | Wang Z,Iwasaki M,Ficara F,Lin C,Matheny C,Wong SH,Smith KS,Cleary ML
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in RS4;11 cells (MLL, mixed lineage leukemia) in response to SB216763 [PubChem=176158], an inhibitor of GSK3B [GeneID=2932].
Full description | Acute leukemias induced by MLL chimeric oncoproteins are among the subset of cancers distinguished by a paradoxical dependence on GSK-3 kinase activity for sustained proliferation. We demonstrate here that GSK-3 maintains the MLL leukemia stem cell transcriptional program by promoting the conditional association of CREB and its coactivators TORC and CBP with homedomain protein MEIS1, a critical component of the MLL-subordinate program, which in turn facilitates HOX-mediated transcription and transformation. This mechanism also applies to hematopoietic cells transformed by other HOX genes, including CDX2, which is highly expressed in a majority of acute myeloid leukemias, thus providing a molecular approach based on GSK-3 inhibitory strategies to target HOX-associated transcription in a broad spectrum of leukemias.

Standard name | QI_HYPOXIA
Systematic name | M2133
Organism | Mus musculus
PMID | 20609350
Authors | Qi J,Nakayama K,Cardiff RD,Borowsky AD,Kaul K,Williams R,Krajewski S,Mercola D,Carpenter PM,Bowtell D,Ronai ZA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by hypoxia in TRAMP-C cells (prostatic cancer).
Full description | Neuroendocrine (NE) phenotype, seen in >30% of prostate adenocarcinomas (PCa), and NE prostate tumors are implicated in aggressive prostate cancer. Formation of NE prostate tumors in the TRAMP mouse model was suppressed in mice lacking the ubiquitin ligase Siah2, which regulates HIF-1alpha availability. Cooperation between HIF-1alpha and FoxA2, a transcription factor expressed in NE tissue, promotes recruitment of p300 to transactivate select HIF-regulated genes, Hes6, Sox9, and Jmjd1a. These HIF-regulated genes are highly expressed in metastatic PCa and required for hypoxia-mediated NE phenotype, metastasis in PCa, and the formation of NE tumors. Tissue-specific expression of FoxA2 combined with Siah2-dependent HIF-1alpha availability enables a transcriptional program required for NE prostate tumor development and NE phenotype in PCa.

Standard name | QI_HYPOXIA_TARGETS_OF_HIF1A_AND_FOXA2
Systematic name | M2136
Organism | Mus musculus
PMID | 20609350
Authors | Qi J,Nakayama K,Cardiff RD,Borowsky AD,Kaul K,Williams R,Krajewski S,Mercola D,Carpenter PM,Bowtell D,Ronai ZA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated by hypoxia in TRAMP-C cells (prostatic cancer) expressing HIF1A and FOXA2 [GeneID=3091,3170] off plasmid vectors.
Full description | Neuroendocrine (NE) phenotype, seen in >30% of prostate adenocarcinomas (PCa), and NE prostate tumors are implicated in aggressive prostate cancer. Formation of NE prostate tumors in the TRAMP mouse model was suppressed in mice lacking the ubiquitin ligase Siah2, which regulates HIF-1alpha availability. Cooperation between HIF-1alpha and FoxA2, a transcription factor expressed in NE tissue, promotes recruitment of p300 to transactivate select HIF-regulated genes, Hes6, Sox9, and Jmjd1a. These HIF-regulated genes are highly expressed in metastatic PCa and required for hypoxia-mediated NE phenotype, metastasis in PCa, and the formation of NE tumors. Tissue-specific expression of FoxA2 combined with Siah2-dependent HIF-1alpha availability enables a transcriptional program required for NE prostate tumor development and NE phenotype in PCa.

Standard name | GREGORY_SYNTHETIC_LETHAL_WITH_IMATINIB
Systematic name | M2137
Organism | Homo sapiens
PMID | 20609354
Authors | Gregory MA,Phang TL,Neviani P,Alvarez-Calderon F,Eide CA,O'Hare T,Zaberezhnyy V,Williams RT,Druker BJ,Perrotti D,Degregori J
Category | C2
Sub-category | CGP
Brief description | Genes identified as synthetic lethal with imatinib [PubChem=5291] in RNAi screen in K562 cells (CML, chronic myelogenous leukemia).
Full description | Although Bcr-Abl kinase inhibitors have proven effective in the treatment of chronic myeloid leukemia (CML), they generally fail to eradicate Bcr-Abl(+) leukemia cells. To identify genes whose inhibition sensitizes Bcr-Abl(+) leukemias to killing by Bcr-Abl inhibitors, we performed an RNAi-based synthetic lethal screen with imatinib mesylate in CML cells. This screen identified numerous components of a Wnt/Ca(2+)/NFAT signaling pathway. Antagonism of this pathway led to impaired NFAT activity, decreased cytokine production, and enhanced sensitivity to Bcr-Abl inhibition. Furthermore, NFAT inhibition with cyclosporin A facilitated leukemia cell elimination by the Bcr-Abl inhibitor dasatinib and markedly improved survival in a mouse model of Bcr-Abl(+) acute lymphoblastic leukemia (ALL). Targeting this pathway in combination with Bcr-Abl inhibition could improve treatment of Bcr-Abl(+) leukemias.

Standard name | LU_EZH2_TARGETS_UP
Systematic name | M2139
Organism | Homo sapiens
PMID | 20708159
Authors | Lu C,Han HD,Mangala LS,Ali-Fehmi R,Newton CS,Ozbun L,Armaiz-Pena GN,Hu W,Stone RL,Munkarah A,Ravoori MK,Shahzad MM,Lee JW,Mora E,Langley RR,Carroll AR,Matsuo K,Spannuth WA,Schmandt R,Jennings NB,Goodman BW,Jaffe RB,Nick AM,Kim HS,Guven EO,Chen YH,Li LY,Hsu MC,Coleman RL,Calin GA,Denkbas EB,Lim JY,Lee JS,Kundra V,Birrer MJ,Hung MC,Lopez-Berestein G,Sood AK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SKOV3ip1 cells (ovarian cancer) upon knockdown of EZH2 [GeneID=2146] by RNAi.
Full description | Although VEGF-targeted therapies are showing promise, new angiogenesis targets are needed to make additional gains. Here, we show that increased Zeste homolog 2 (EZH2) expression in either tumor cells or in tumor vasculature is predictive of poor clinical outcome. The increase in endothelial EZH2 is a direct result of VEGF stimulation by a paracrine circuit that promotes angiogenesis by methylating and silencing vasohibin1 (vash1). Ezh2 silencing in the tumor-associated endothelial cells inhibited angiogenesis mediated by reactivation of VASH1, and reduced ovarian cancer growth, which is further enhanced in combination with ezh2 silencing in tumor cells. Collectively, these data support the potential for targeting ezh2 as an important therapeutic approach.

Standard name | LU_EZH2_TARGETS_DN
Systematic name | M2140
Organism | Homo sapiens
PMID | 20708159
Authors | Lu C,Han HD,Mangala LS,Ali-Fehmi R,Newton CS,Ozbun L,Armaiz-Pena GN,Hu W,Stone RL,Munkarah A,Ravoori MK,Shahzad MM,Lee JW,Mora E,Langley RR,Carroll AR,Matsuo K,Spannuth WA,Schmandt R,Jennings NB,Goodman BW,Jaffe RB,Nick AM,Kim HS,Guven EO,Chen YH,Li LY,Hsu MC,Coleman RL,Calin GA,Denkbas EB,Lim JY,Lee JS,Kundra V,Birrer MJ,Hung MC,Lopez-Berestein G,Sood AK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SKOV3ip1 cells (ovarian cancer) upon knockdown of EZH2 [GeneID=2146] by RNAi.
Full description | Although VEGF-targeted therapies are showing promise, new angiogenesis targets are needed to make additional gains. Here, we show that increased Zeste homolog 2 (EZH2) expression in either tumor cells or in tumor vasculature is predictive of poor clinical outcome. The increase in endothelial EZH2 is a direct result of VEGF stimulation by a paracrine circuit that promotes angiogenesis by methylating and silencing vasohibin1 (vash1). Ezh2 silencing in the tumor-associated endothelial cells inhibited angiogenesis mediated by reactivation of VASH1, and reduced ovarian cancer growth, which is further enhanced in combination with ezh2 silencing in tumor cells. Collectively, these data support the potential for targeting ezh2 as an important therapeutic approach.

Standard name | HOELZEL_NF1_TARGETS_UP
Systematic name | M2142
Organism | Homo sapiens
PMID | 20655465
Authors | Hölzel M,Huang S,Koster J,Ora I,Lakeman A,Caron H,Nijkamp W,Xie J,Callens T,Asgharzadeh S,Seeger RC,Messiaen L,Versteeg R,Bernards R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in SH-SY5Y cells (neuroblastoma) after knockdown of NF1 [GeneID=4763] by RNAi.
Full description | Retinoic acid (RA) induces differentiation of neuroblastoma cells in vitro and is used with variable success to treat aggressive forms of this disease. This variability in clinical response to RA is enigmatic, as no mutations in components of the RA signaling cascade have been found. Using a large-scale RNAi genetic screen, we identify crosstalk between the tumor suppressor NF1 and retinoic acid-induced differentiation in neuroblastoma. Loss of NF1 activates RAS-MEK signaling, which in turn represses ZNF423, a critical transcriptional coactivator of the retinoic acid receptors. Neuroblastomas with low levels of both NF1 and ZNF423 have extremely poor outcome. We find NF1 mutations in neuroblastoma cell lines and in primary tumors. Inhibition of MEK signaling downstream of NF1 restores responsiveness to RA, suggesting a therapeutic strategy to overcome RA resistance in NF1-deficient neuroblastomas.

Standard name | HOELZEL_NF1_TARGETS_DN
Systematic name | M2143
Organism | Homo sapiens
PMID | 20655465
Authors | Hölzel M,Huang S,Koster J,Ora I,Lakeman A,Caron H,Nijkamp W,Xie J,Callens T,Asgharzadeh S,Seeger RC,Messiaen L,Versteeg R,Bernards R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in SH-SY5Y cells (neuroblastoma) after knockdown of NF1 [GeneID=4763] by RNAi.
Full description | Retinoic acid (RA) induces differentiation of neuroblastoma cells in vitro and is used with variable success to treat aggressive forms of this disease. This variability in clinical response to RA is enigmatic, as no mutations in components of the RA signaling cascade have been found. Using a large-scale RNAi genetic screen, we identify crosstalk between the tumor suppressor NF1 and retinoic acid-induced differentiation in neuroblastoma. Loss of NF1 activates RAS-MEK signaling, which in turn represses ZNF423, a critical transcriptional coactivator of the retinoic acid receptors. Neuroblastomas with low levels of both NF1 and ZNF423 have extremely poor outcome. We find NF1 mutations in neuroblastoma cell lines and in primary tumors. Inhibition of MEK signaling downstream of NF1 restores responsiveness to RA, suggesting a therapeutic strategy to overcome RA resistance in NF1-deficient neuroblastomas.

Standard name | DEMAGALHAES_AGING_UP
Systematic name | M2144
Organism | Homo sapiens
PMID | 19189975
Authors | Magalhães de JP,Curado J,Church GM
Category | C2
Sub-category | CGP
Brief description | Genes consistently overexpressed with age, based on meta-analysis of microarray data.
Full description | MOTIVATION: Numerous microarray studies of aging have been conducted, yet given the noisy nature of gene expression changes with age, elucidating the transcriptional features of aging and how these relate to physiological, biochemical and pathological changes remains a critical problem. RESULTS: We performed a meta-analysis of age-related gene expression profiles using 27 datasets from mice, rats and humans. Our results reveal several common signatures of aging, including 56 genes consistently overexpressed with age, the most significant of which was APOD, and 17 genes underexpressed with age. We characterized the biological processes associated with these signatures and found that age-related gene expression changes most notably involve an overexpression of inflammation and immune response genes and of genes associated with the lysosome. An underexpression of collagen genes and of genes associated with energy metabolism, particularly mitochondrial genes, as well as alterations in the expression of genes related to apoptosis, cell cycle and cellular senescence biomarkers, were also observed. By employing a new method that emphasizes sensitivity, our work further reveals previously unknown transcriptional changes with age in many genes, processes and functions. We suggest these molecular signatures reflect a combination of degenerative processes but also transcriptional responses to the process of aging. Overall, our results help to understand how transcriptional changes relate to the process of aging and could serve as targets for future studies. AVAILABILITY: http://genomics.senescence.info/uarrays/signatures.html. SUPPLEMENTARY INFORMATION: Supplementary data are available at Bioinformatics online.

Standard name | DEMAGALHAES_AGING_DN
Systematic name | M2145
Organism | Homo sapiens
PMID | 19189975
Authors | Magalhães de JP,Curado J,Church GM
Category | C2
Sub-category | CGP
Brief description | Genes consistently underexpressed with age, based on meta-analysis of microarray data.
Full description | MOTIVATION: Numerous microarray studies of aging have been conducted, yet given the noisy nature of gene expression changes with age, elucidating the transcriptional features of aging and how these relate to physiological, biochemical and pathological changes remains a critical problem. RESULTS: We performed a meta-analysis of age-related gene expression profiles using 27 datasets from mice, rats and humans. Our results reveal several common signatures of aging, including 56 genes consistently overexpressed with age, the most significant of which was APOD, and 17 genes underexpressed with age. We characterized the biological processes associated with these signatures and found that age-related gene expression changes most notably involve an overexpression of inflammation and immune response genes and of genes associated with the lysosome. An underexpression of collagen genes and of genes associated with energy metabolism, particularly mitochondrial genes, as well as alterations in the expression of genes related to apoptosis, cell cycle and cellular senescence biomarkers, were also observed. By employing a new method that emphasizes sensitivity, our work further reveals previously unknown transcriptional changes with age in many genes, processes and functions. We suggest these molecular signatures reflect a combination of degenerative processes but also transcriptional responses to the process of aging. Overall, our results help to understand how transcriptional changes relate to the process of aging and could serve as targets for future studies. AVAILABILITY: http://genomics.senescence.info/uarrays/signatures.html. SUPPLEMENTARY INFORMATION: Supplementary data are available at Bioinformatics online.

Standard name | DUTERTRE_ESTRADIOL_RESPONSE_6HR_UP
Systematic name | M2151
Organism | Homo sapiens
PMID | 20406972
Authors | Dutertre M,Gratadou L,Dardenne E,Germann S,Samaan S,Lidereau R,Driouch K,de la Grange P,Auboeuf D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) at 6 h of estradiol [PubChem=5757] treatment.
Full description | Alternative promoters (AP) occur in >30% protein-coding genes and contribute to proteome diversity. However, large-scale analyses of AP regulation are lacking, and little is known about their potential physiopathologic significance. To better understand the transcriptomic effect of estrogens, which play a major role in breast cancer, we analyzed gene and AP regulation by estradiol in MCF7 cells using pan-genomic exon arrays. We thereby identified novel estrogen-regulated genes (ERG) and determined the regulation of AP-encoded transcripts in 150 regulated genes. In <30% cases, APs were regulated in a similar manner by estradiol, whereas in >70% cases, they were regulated differentially. The patterns of AP regulation correlated with the patterns of estrogen receptor alpha (ERalpha) and CCCTC-binding factor (CTCF) binding sites at regulated gene loci. Interestingly, among genes with differentially regulated (DR) APs, we identified cases where estradiol regulated APs in an opposite manner, sometimes without affecting global gene expression levels. This promoter switch was mediated by the DDX5/DDX17 family of ERalpha coregulators. Finally, genes with DR promoters were preferentially involved in specific processes (e.g., cell structure and motility, and cell cycle). We show, in particular, that isoforms encoded by the NET1 gene APs, which are inversely regulated by estradiol, play distinct roles in cell adhesion and cell cycle regulation and that their expression is differentially associated with prognosis in ER(+) breast cancer. Altogether, this study identifies the patterns of AP regulation in ERGs and shows the contribution of AP-encoded isoforms to the estradiol-regulated transcriptome as well as their physiopathologic significance in breast cancer.

Standard name | DUTERTRE_ESTRADIOL_RESPONSE_6HR_DN
Systematic name | M2154
Organism | Homo sapiens
PMID | 20406972
Authors | Dutertre M,Gratadou L,Dardenne E,Germann S,Samaan S,Lidereau R,Driouch K,de la Grange P,Auboeuf D
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) at 6 h of estradiol [PubChem=5757] treatment.
Full description | Alternative promoters (AP) occur in >30% protein-coding genes and contribute to proteome diversity. However, large-scale analyses of AP regulation are lacking, and little is known about their potential physiopathologic significance. To better understand the transcriptomic effect of estrogens, which play a major role in breast cancer, we analyzed gene and AP regulation by estradiol in MCF7 cells using pan-genomic exon arrays. We thereby identified novel estrogen-regulated genes (ERG) and determined the regulation of AP-encoded transcripts in 150 regulated genes. In <30% cases, APs were regulated in a similar manner by estradiol, whereas in >70% cases, they were regulated differentially. The patterns of AP regulation correlated with the patterns of estrogen receptor alpha (ERalpha) and CCCTC-binding factor (CTCF) binding sites at regulated gene loci. Interestingly, among genes with differentially regulated (DR) APs, we identified cases where estradiol regulated APs in an opposite manner, sometimes without affecting global gene expression levels. This promoter switch was mediated by the DDX5/DDX17 family of ERalpha coregulators. Finally, genes with DR promoters were preferentially involved in specific processes (e.g., cell structure and motility, and cell cycle). We show, in particular, that isoforms encoded by the NET1 gene APs, which are inversely regulated by estradiol, play distinct roles in cell adhesion and cell cycle regulation and that their expression is differentially associated with prognosis in ER(+) breast cancer. Altogether, this study identifies the patterns of AP regulation in ERGs and shows the contribution of AP-encoded isoforms to the estradiol-regulated transcriptome as well as their physiopathologic significance in breast cancer.

Standard name | DUTERTRE_ESTRADIOL_RESPONSE_24HR_UP
Systematic name | M2156
Organism | Homo sapiens
PMID | 20406972
Authors | Dutertre M,Gratadou L,Dardenne E,Germann S,Samaan S,Lidereau R,Driouch K,de la Grange P,Auboeuf D
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) at 24 h of estradiol [PubChem=5757] treatment.
Full description | Alternative promoters (AP) occur in >30% protein-coding genes and contribute to proteome diversity. However, large-scale analyses of AP regulation are lacking, and little is known about their potential physiopathologic significance. To better understand the transcriptomic effect of estrogens, which play a major role in breast cancer, we analyzed gene and AP regulation by estradiol in MCF7 cells using pan-genomic exon arrays. We thereby identified novel estrogen-regulated genes (ERG) and determined the regulation of AP-encoded transcripts in 150 regulated genes. In <30% cases, APs were regulated in a similar manner by estradiol, whereas in >70% cases, they were regulated differentially. The patterns of AP regulation correlated with the patterns of estrogen receptor alpha (ERalpha) and CCCTC-binding factor (CTCF) binding sites at regulated gene loci. Interestingly, among genes with differentially regulated (DR) APs, we identified cases where estradiol regulated APs in an opposite manner, sometimes without affecting global gene expression levels. This promoter switch was mediated by the DDX5/DDX17 family of ERalpha coregulators. Finally, genes with DR promoters were preferentially involved in specific processes (e.g., cell structure and motility, and cell cycle). We show, in particular, that isoforms encoded by the NET1 gene APs, which are inversely regulated by estradiol, play distinct roles in cell adhesion and cell cycle regulation and that their expression is differentially associated with prognosis in ER(+) breast cancer. Altogether, this study identifies the patterns of AP regulation in ERGs and shows the contribution of AP-encoded isoforms to the estradiol-regulated transcriptome as well as their physiopathologic significance in breast cancer.

Standard name | DUTERTRE_ESTRADIOL_RESPONSE_24HR_DN
Systematic name | M2157
Organism | Homo sapiens
PMID | 20406972
Authors | Dutertre M,Gratadou L,Dardenne E,Germann S,Samaan S,Lidereau R,Driouch K,de la Grange P,Auboeuf D
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MCF7 cells (breast cancer) at 24 h of estradiol [PubChem=5757] treatment.
Full description | Alternative promoters (AP) occur in >30% protein-coding genes and contribute to proteome diversity. However, large-scale analyses of AP regulation are lacking, and little is known about their potential physiopathologic significance. To better understand the transcriptomic effect of estrogens, which play a major role in breast cancer, we analyzed gene and AP regulation by estradiol in MCF7 cells using pan-genomic exon arrays. We thereby identified novel estrogen-regulated genes (ERG) and determined the regulation of AP-encoded transcripts in 150 regulated genes. In <30% cases, APs were regulated in a similar manner by estradiol, whereas in >70% cases, they were regulated differentially. The patterns of AP regulation correlated with the patterns of estrogen receptor alpha (ERalpha) and CCCTC-binding factor (CTCF) binding sites at regulated gene loci. Interestingly, among genes with differentially regulated (DR) APs, we identified cases where estradiol regulated APs in an opposite manner, sometimes without affecting global gene expression levels. This promoter switch was mediated by the DDX5/DDX17 family of ERalpha coregulators. Finally, genes with DR promoters were preferentially involved in specific processes (e.g., cell structure and motility, and cell cycle). We show, in particular, that isoforms encoded by the NET1 gene APs, which are inversely regulated by estradiol, play distinct roles in cell adhesion and cell cycle regulation and that their expression is differentially associated with prognosis in ER(+) breast cancer. Altogether, this study identifies the patterns of AP regulation in ERGs and shows the contribution of AP-encoded isoforms to the estradiol-regulated transcriptome as well as their physiopathologic significance in breast cancer.

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_1_UP
Systematic name | M2159
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 1 of aberrantly hypermethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_1_DN
Systematic name | M2161
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 1 of aberrantly hypomethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_2_UP
Systematic name | M2162
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 2 of aberrantly hypermethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_2_DN
Systematic name | M2163
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 2 of aberrantly hypomethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_3_UP
Systematic name | M2168
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 3 of aberrantly hypermethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_3_DN
Systematic name | M2169
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 3 of aberrantly hypomethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_4_UP
Systematic name | M2170
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 4 of aberrantly hypermethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_4_DN
Systematic name | M2171
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 4 of aberrantly hypomethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_5_UP
Systematic name | M2172
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 5 of aberrantly hypermethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_5_DN
Systematic name | M2174
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 5 of aberrantly hypomethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_6_UP
Systematic name | M2177
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 6 of aberrantly hypermethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_6_DN
Systematic name | M2178
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 6 of aberrantly hypomethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_7_UP
Systematic name | M2179
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 7 of aberrantly hypermethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | FIGUEROA_AML_METHYLATION_CLUSTER_7_DN
Systematic name | M2181
Organism | Homo sapiens
PMID | 20060365
Authors | Figueroa ME,Lugthart S,Li Y,Erpelinck-Verschueren C,Deng X,Christos PJ,Schifano E,Booth J,Putten van W,Skrabanek L,Campagne F,Mazumdar M,Greally JM,Valk PJ,Löwenberg B,Delwel R,Melnick A
Category | C2
Sub-category | CGP
Brief description | Cluster 7 of aberrantly hypomethylated genes in blasts from AML (acute myeloid leukemia) patients.
Full description | We hypothesized that DNA methylation distributes into specific patterns in cancer cells, which reflect critical biological differences. We therefore examined the methylation profiles of 344 patients with acute myeloid leukemia (AML). Clustering of these patients by methylation data segregated patients into 16 groups. Five of these groups defined new AML subtypes that shared no other known feature. In addition, DNA methylation profiles segregated patients with CEBPA aberrations from other subtypes of leukemia, defined four epigenetically distinct forms of AML with NPM1 mutations, and showed that established AML1-ETO, CBFb-MYH11, and PML-RARA leukemia entities are associated with specific methylation profiles. We report a 15 gene methylation classifier predictive of overall survival in an independent patient cohort (p < 0.001, adjusted for known covariates).

Standard name | WANG_CLASSIC_ADIPOGENIC_TARGETS_OF_PPARG
Systematic name | M2182
Organism | Mus musculus
PMID | 17954559
Authors | Wang H,Qiang L,Farmer SR
Category | C2
Sub-category | CGP
Brief description | Classic adipogenic genes (group 1) that are induced by PPARG [GeneID=5468] during adipogenesis in 3T3-L1 preadipocytes.
Full description | Peroxisome proliferator-activated receptor gamma (PPARgamma) activity is regulated through association with ligands that include the thiazolidinedione class of antidiabetic drugs, as well as derivatives of polyunsaturated fatty acids. Induction of PPARgamma target gene expression involves ligand-dependent reconfiguration of the ligand-binding domain (LBD), followed by recruitment of specific transcriptional coactivators. In this study, we have identified an amino acid (F372) within helix 7 of the LBD that is required for the response of PPARgamma to endogenous ligands. Additionally, the data show that this amino acid is also required for expression of a novel subset of adipocyte genes (group 2), including fibroblast growth factor 21 (FGF21), and that the FGF21 gene is a direct target of PPARgamma. Expression of the group 2 genes is selectively repressed by the NAD-dependent deacetylase SIRT1 in mature 3T3-L1 adipocytes, since knockdown of SIRT1 through the constitutive expression of a corresponding RNA interference enhances their expression without affecting the expression of classic adipogenic genes, such as adiponectin and FABP4/aP2. It appears that many of the group 2 genes repressed by SIRT1 in mature adipocytes correspond to the same set of genes that are selectively activated by treatment of fat cells with the PPARgamma ligand, troglitazone. These data support a role for helix 7 of the LBD of PPARgamma in regulating adipocyte function and suggest that inhibition of SIRT1 in adipocytes induces the same insulin-sensitizing action as PPARgamma ligands.

Standard name | WANG_ADIPOGENIC_GENES_REPRESSED_BY_SIRT1
Systematic name | M2183
Organism | Mus musculus
PMID | 17954559
Authors | Wang H,Qiang L,Farmer SR
Category | C2
Sub-category | CGP
Brief description | Adipogenic genes (group 2) that are selectively repressed by SIRT1 [GeneID=23411] in mature 3T3-L1 adipocytes.
Full description | Peroxisome proliferator-activated receptor gamma (PPARgamma) activity is regulated through association with ligands that include the thiazolidinedione class of antidiabetic drugs, as well as derivatives of polyunsaturated fatty acids. Induction of PPARgamma target gene expression involves ligand-dependent reconfiguration of the ligand-binding domain (LBD), followed by recruitment of specific transcriptional coactivators. In this study, we have identified an amino acid (F372) within helix 7 of the LBD that is required for the response of PPARgamma to endogenous ligands. Additionally, the data show that this amino acid is also required for expression of a novel subset of adipocyte genes (group 2), including fibroblast growth factor 21 (FGF21), and that the FGF21 gene is a direct target of PPARgamma. Expression of the group 2 genes is selectively repressed by the NAD-dependent deacetylase SIRT1 in mature 3T3-L1 adipocytes, since knockdown of SIRT1 through the constitutive expression of a corresponding RNA interference enhances their expression without affecting the expression of classic adipogenic genes, such as adiponectin and FABP4/aP2. It appears that many of the group 2 genes repressed by SIRT1 in mature adipocytes correspond to the same set of genes that are selectively activated by treatment of fat cells with the PPARgamma ligand, troglitazone. These data support a role for helix 7 of the LBD of PPARgamma in regulating adipocyte function and suggest that inhibition of SIRT1 in adipocytes induces the same insulin-sensitizing action as PPARgamma ligands.

Standard name | PANGAS_TUMOR_SUPPRESSION_BY_SMAD1_AND_SMAD5_UP
Systematic name | M2185
Organism | Mus musculus
PMID | 17967875
Authors | Pangas SA,Li X,Umans L,Zwijsen A,Huylebroeck D,Gutierrez C,Wang D,Martin JF,Jamin SP,Behringer RR,Robertson EJ,Matzuk MM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ovarian tumors from mouse models for the BMP SMAD signaling (gonad specific double knockout of SMAD1 and SMAD5 [GeneID=4086, 4090]).
Full description | The transforming growth factor beta (TGFbeta) family has critical roles in the regulation of fertility. In addition, the pathogenesis of some human cancers is attributed to misregulation of TGFbeta function and SMAD2 or SMAD4 mutations. There are limited mouse models for the BMP signaling SMADs (BR-SMADs) 1, 5, and 8 because of embryonic lethality and suspected genetic redundancy. Using tissue-specific ablation in mice, we deleted the BR-SMADs from somatic cells of ovaries and testes. Single conditional knockouts for Smad1 or Smad5 or mice homozygous null for Smad8 are viable and fertile. Female double Smad1 Smad5 and triple Smad1 Smad5 Smad8 conditional knockout mice become infertile and develop metastatic granulosa cell tumors. Male double Smad1 Smad5 conditional knockout mice are fertile but demonstrate metastatic testicular tumor development. Microarray analysis indicated significant alterations in expression of genes related to the TGFbeta pathway, as well as genes involved in infertility and extracellular matrix production. These data strongly implicate the BR-SMADs as part of a critical developmental pathway in ovaries and testis that, when disrupted, leads to malignant transformation.

Standard name | PANGAS_TUMOR_SUPPRESSION_BY_SMAD1_AND_SMAD5_DN
Systematic name | M2186
Organism | Mus musculus
PMID | 17967875
Authors | Pangas SA,Li X,Umans L,Zwijsen A,Huylebroeck D,Gutierrez C,Wang D,Martin JF,Jamin SP,Behringer RR,Robertson EJ,Matzuk MM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ovarian tumors from mouse models for the BMP SMAD signaling (gonad specific double knockout of SMAD1 and SMAD5 [GeneID=4086, 4090]).
Full description | The transforming growth factor beta (TGFbeta) family has critical roles in the regulation of fertility. In addition, the pathogenesis of some human cancers is attributed to misregulation of TGFbeta function and SMAD2 or SMAD4 mutations. There are limited mouse models for the BMP signaling SMADs (BR-SMADs) 1, 5, and 8 because of embryonic lethality and suspected genetic redundancy. Using tissue-specific ablation in mice, we deleted the BR-SMADs from somatic cells of ovaries and testes. Single conditional knockouts for Smad1 or Smad5 or mice homozygous null for Smad8 are viable and fertile. Female double Smad1 Smad5 and triple Smad1 Smad5 Smad8 conditional knockout mice become infertile and develop metastatic granulosa cell tumors. Male double Smad1 Smad5 conditional knockout mice are fertile but demonstrate metastatic testicular tumor development. Microarray analysis indicated significant alterations in expression of genes related to the TGFbeta pathway, as well as genes involved in infertility and extracellular matrix production. These data strongly implicate the BR-SMADs as part of a critical developmental pathway in ovaries and testis that, when disrupted, leads to malignant transformation.

Standard name | TSUTSUMI_FBXW8_TARGETS
Systematic name | M2187
Organism | Mus musculus
PMID | 17998335
Authors | Tsutsumi T,Kuwabara H,Arai T,Xiao Y,Decaprio JA
Category | C2
Sub-category | CGP
Brief description | Genes differentially expressed in E18.5 whole embryos upon knockout of FBXW8 [GeneID=26259].
Full description | CUL7 binds to SKP1, RBX1, and FBXW8 to form a cullin-RING ligase, or an SKP1-cullin-F box protein complex. The targeted disruption of the Cul7 gene in mice results in significant reduction in embryo size and neonatal lethality. In humans, CUL7 was found to be mutated in the 3-M dwarfism syndrome characterized by severe pre- and postnatal growth retardation, indicating that CUL7 is closely associated with human and mouse growth. We generated mice lacking Fbxw8 by gene trapping. Similar to Cul7(-/-) animals, Fbxw8(-/-) embryos and placentas were smaller than wild-type and heterozygous littermates and placentas. Approximately 30% of the expected number of Fbxw8(-/-) mice survived birth, but these mice remained smaller than their wild-type and heterozygous littermates throughout postnatal development. FBXW8 expression was detected in most organs of wild-type mice examined, and the organs in Fbxw8(-/-) mice were smaller than those in wild-type mice. Fbxw8 expression levels were highest in skeletal muscle, cartilage, and lung tissue. Expression profiling revealed elevated levels of insulin-like growth factor binding protein 1 (IGFBP1) transcripts in Fbxw8(-/-) embryos. Furthermore, we observed increased levels of IGFBP2 in Cul7(-/-) as well as Fbxw8(-/-) fibroblasts. These results demonstrate that the FBXW8-CUL7 complex plays a significant role in growth control.

Standard name | LI_DCP2_BOUND_MRNA
Systematic name | M2188
Organism | Homo sapiens
PMID | 18039849
Authors | Li Y,Song MG,Kiledjian M
Category | C2
Sub-category | CGP
Brief description | Genes encoding mRNA transcripts specifically bound by DCP2 [GeneID=167227].
Full description | mRNA decapping is a critical step in the control of mRNA stability and gene expression and is carried out by the Dcp2 decapping enzyme. Dcp2 is an RNA binding protein that must bind RNA in order to recognize the cap for hydrolysis. We demonstrate that human Dcp2 (hDcp2) preferentially binds to a subset of mRNAs and identify sequences at the 5' terminus of the mRNA encoding Rrp41, a core subunit component of the RNA exosome, as a specific hDcp2 substrate. A 60-nucleotide element at the 5' end of Rrp41 mRNA was identified and shown to confer more efficient decapping on a heterologous RNA both in vitro and upon transfection into cells. Moreover, reduction of hDcp2 protein levels in cells resulted in a selective stabilization of the Rrp41 mRNA, confirming it as a downstream target of hDcp2 regulation. These findings demonstrate that hDcp2 can specifically bind to and regulate the stability of a subset of mRNAs, and its intriguing regulation of the 3'-to-5' exonuclease exosome subunit suggests a potential interplay between 5'-end mRNA decapping and 3'-end mRNA decay.

Standard name | WAGSCHAL_EHMT2_TARGETS_UP
Systematic name | M2189
Organism | Mus musculus
PMID | 18039842
Authors | Wagschal A,Sutherland HG,Woodfine K,Henckel A,Chebli K,Schulz R,Oakey RJ,Bickmore WA,Feil R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in placenta of mice with EHMT2 [GeneID=10919] knocked out.
Full description | Whereas DNA methylation is essential for genomic imprinting, the importance of histone methylation in the allelic expression of imprinted genes is unclear. Imprinting control regions (ICRs), however, are marked by histone H3-K9 methylation on their DNA-methylated allele. In the placenta, the paternal silencing along the Kcnq1 domain on distal chromosome 7 also correlates with the presence of H3-K9 methylation, but imprinted repression at these genes is maintained independently of DNA methylation. To explore which histone methyltransferase (HMT) could mediate the allelic H3-K9 methylation on distal chromosome 7, and at ICRs, we generated mouse conceptuses deficient for the SET domain protein G9a. We found that in the embryo and placenta, the differential DNA methylation at ICRs and imprinted genes is maintained in the absence of G9a. Accordingly, in embryos, imprinted gene expression was unchanged at the domains analyzed, in spite of a global loss of H3-K9 dimethylation (H3K9me2). In contrast, the placenta-specific imprinting of genes on distal chromosome 7 is impaired in the absence of G9a, and this correlates with reduced levels of H3K9me2 and H3K9me3. These findings provide the first evidence for the involvement of an HMT and suggest that histone methylation contributes to imprinted gene repression in the trophoblast.

Standard name | SUBTIL_PROGESTIN_TARGETS
Systematic name | M2191
Organism | Homo sapiens
PMID | 18378698
Authors | Subtil-Rodríguez A,Millán-Ariño L,Quiles I,Ballaré C,Beato M,Jordan A
Category | C2
Sub-category | CGP
Brief description | Genes responding to progestin R5020 [PubChem=36709] treatment of T47D-MTVL cells (breast cancer).
Full description | Steroid hormone receptors regulate gene expression, interacting with target DNA sequences but also activating cytoplasmic signaling pathways. Using the human 11beta-hydroxysteroid dehydrogenase type 2 (11beta-HSD2) gene as a model, we have investigated the contributions of both effects on a human progesterone-responsive promoter in breast cancer cells. Chromatin immunoprecipitation has identified two different mechanisms of hormone-induced progesterone receptor (PR) recruitment to the 11beta-HSD2 promoter: (i) direct PR binding to DNA at the proximal promoter, abrogated when PR contains a mutated DNA binding domain (DBD), and (ii) STAT5A (signal transducer and activator of transcription 5A)-mediated recruitment of PR to an upstream distal region, impaired by AG490, a JAK/STAT pathway inhibitor. The JAK/STAT inhibitor, as well as expression of dominant-negative STAT5A, impairs hormone induction of 11beta-HSD2. On the other hand, the DBD-mutated PR fully supports 11beta-HSD2 expression. These results, along with data from a deletion analysis, indicate that the distal region is crucial for hormone regulation of 11beta-HSD2. We show active RNA polymerase II tracking from the distal region upon PR and STAT5A binding, concomitant with synthesis of noncoding, hormone-dependent RNAs, suggesting that this region works as a hormone-dependent transcriptional enhancer. In conclusion, coordination of PR transcriptional effects and cytoplasmic signaling activation, in particular the JAK/STAT pathway, are critical in regulating progestin-induced endogenous 11beta-HSD2 gene expression in breast cancer cells. This is not unique to this promoter, as AG490 also alters the expression of other progesterone-regulated genes.

Standard name | OHGUCHI_LIVER_HNF4A_TARGETS_UP
Systematic name | M2193
Organism | Mus musculus
PMID | 18426912
Authors | Ohguchi H,Tanaka T,Uchida A,Magoori K,Kudo H,Kim I,Daigo K,Sakakibara I,Okamura M,Harigae H,Sasaki T,Osborne TF,Gonzalez FJ,Hamakubo T,Kodama T,Sakai J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in liver samples of liver-specific knockout of HNF4A [GeneID=3172].
Full description | Type 1 iodothyronine deiodinase (Dio1), a selenoenzyme catalyzing the bioactivation of thyroid hormone, is highly expressed in the liver. Dio1 mRNA and enzyme activity levels are markedly reduced in the livers of hepatocyte nuclear factor 4alpha (HNF4alpha)-null mice, thus accounting for its liver-specific expression. Consistent with this deficiency, serum T4 and rT3 concentrations are elevated in these mice compared with those in HNF4alpha-floxed control littermates; however, serum T3 levels are unchanged. Promoter analysis of the mouse Dio1 gene demonstrated that HNF4alpha plays a key role in the transactivation of the mouse Dio1 gene. Deletion and substitution mutation analyses demonstrated that a proximal HNF4alpha site (direct repeat 1 [TGGACAAAGGTGC]; HNF4alpha-RE) is crucial for transactivation of the mouse Dio1 gene by HNF4alpha. Mouse Dio1 is also stimulated by thyroid hormone signaling, but a direct role for thyroid hormone receptor action has not been reported. We also showed that thyroid hormone-inducible Krüppel-like factor 9 (KLF9) stimulates the mouse Dio1 promoter very efficiently through two CACCC sequences that are located on either side of HNF4alpha-RE. Furthermore, KLF9 functions together with HNF4alpha and GATA4 to synergistically activate the mouse Dio1 promoter, suggesting that Dio1 is regulated by thyroid hormone in the mouse through an indirect mechanism requiring prior KLF9 induction. In addition, we showed that physical interactions between the C-terminal zinc finger domain (Cf) of GATA4 and activation function 2 of HNF4alpha and between the basic domain adjacent to Cf of GATA4 and a C-terminal domain of KLF9 are both required for this synergistic response. Taken together, these results suggest that HNF4alpha regulates thyroid hormone homeostasis through transcriptional regulation of the mouse Dio1 gene with GATA4 and KLF9.

Standard name | OHGUCHI_LIVER_HNF4A_TARGETS_DN
Systematic name | M2194
Organism | Mus musculus
PMID | 18426912
Authors | Ohguchi H,Tanaka T,Uchida A,Magoori K,Kudo H,Kim I,Daigo K,Sakakibara I,Okamura M,Harigae H,Sasaki T,Osborne TF,Gonzalez FJ,Hamakubo T,Kodama T,Sakai J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in liver samples of liver-specific knockout of HNF4A [GeneID=3172].
Full description | Type 1 iodothyronine deiodinase (Dio1), a selenoenzyme catalyzing the bioactivation of thyroid hormone, is highly expressed in the liver. Dio1 mRNA and enzyme activity levels are markedly reduced in the livers of hepatocyte nuclear factor 4alpha (HNF4alpha)-null mice, thus accounting for its liver-specific expression. Consistent with this deficiency, serum T4 and rT3 concentrations are elevated in these mice compared with those in HNF4alpha-floxed control littermates; however, serum T3 levels are unchanged. Promoter analysis of the mouse Dio1 gene demonstrated that HNF4alpha plays a key role in the transactivation of the mouse Dio1 gene. Deletion and substitution mutation analyses demonstrated that a proximal HNF4alpha site (direct repeat 1 [TGGACAAAGGTGC]; HNF4alpha-RE) is crucial for transactivation of the mouse Dio1 gene by HNF4alpha. Mouse Dio1 is also stimulated by thyroid hormone signaling, but a direct role for thyroid hormone receptor action has not been reported. We also showed that thyroid hormone-inducible Krüppel-like factor 9 (KLF9) stimulates the mouse Dio1 promoter very efficiently through two CACCC sequences that are located on either side of HNF4alpha-RE. Furthermore, KLF9 functions together with HNF4alpha and GATA4 to synergistically activate the mouse Dio1 promoter, suggesting that Dio1 is regulated by thyroid hormone in the mouse through an indirect mechanism requiring prior KLF9 induction. In addition, we showed that physical interactions between the C-terminal zinc finger domain (Cf) of GATA4 and activation function 2 of HNF4alpha and between the basic domain adjacent to Cf of GATA4 and a C-terminal domain of KLF9 are both required for this synergistic response. Taken together, these results suggest that HNF4alpha regulates thyroid hormone homeostasis through transcriptional regulation of the mouse Dio1 gene with GATA4 and KLF9.

Standard name | GABRIELY_MIR21_TARGETS
Systematic name | M2196
Organism | Homo sapiens
PMID | 18591254
Authors | Gabriely G,Wurdinger T,Kesari S,Esau CC,Burchard J,Linsley PS,Krichevsky AM
Category | C2
Sub-category | CGP
Brief description | Genes significantly de-regulated (p < 0.05) by MIR21 [GeneID=406991] in A172 cells (glioma).
Full description | Substantial data indicate that microRNA 21 (miR-21) is significantly elevated in glioblastoma (GBM) and in many other tumors of various origins. This microRNA has been implicated in various aspects of carcinogenesis, including cellular proliferation, apoptosis, and migration. We demonstrate that miR-21 regulates multiple genes associated with glioma cell apoptosis, migration, and invasiveness, including the RECK and TIMP3 genes, which are suppressors of malignancy and inhibitors of matrix metalloproteinases (MMPs). Specific inhibition of miR-21 with antisense oligonucleotides leads to elevated levels of RECK and TIMP3 and therefore reduces MMP activities in vitro and in a human model of gliomas in nude mice. Moreover, downregulation of miR-21 in glioma cells leads to decreases of their migratory and invasion abilities. Our data suggest that miR-21 contributes to glioma malignancy by downregulation of MMP inhibitors, which leads to activation of MMPs, thus promoting invasiveness of cancer cells. Our results also indicate that inhibition of a single oncomir, like miR-21, with specific antisense molecules can provide a novel therapeutic approach for physiological modulation of multiple proteins whose expression is deregulated in cancer.

Standard name | THILLAINADESAN_ZNF217_TARGETS_UP
Systematic name | M2197
Organism | Homo sapiens
PMID | 18625718
Authors | Thillainadesan G,Isovic M,Loney E,Andrews J,Tini M,Torchia J
Category | C2
Sub-category | CGP
Brief description | Genes bound and activated by ZNF217 [GeneID=7764] in MCF7 cells (breast cancer).
Full description | The ZNF217 oncoprotein is a constituent of a core transcriptional complex that includes CoREST, histone deacetylase 1/2, lysine demethylase 1, and the C-terminal binding protein 1/2. We have combined genome-wide expression profiling and chromatin immunoprecipitation with directed selection and ligation (ChIP-DSL) to identify a subset of genes directly regulated by ZNF217. Our results establish p15(ink4b) as a direct target of the ZNF217 complex. Downregulation of ZNF217 in MCF-7 breast cancer cells resulted in a dramatic increase in p15(ink4b) expression and coincided with increases in dimethylation of H3-K4 and, surprisingly, a decrease in K9/K14-H3 acetylation. Stimulation of HaCaT cells with transforming growth factor beta (TGF-beta) resulted in a release of ZNF217 and a concomitant binding of SMAD2 to the proximal promoter, which preceded increases in ink4b protein expression. Furthermore, the changes in chromatin marks at the p15(ink4b) promoter following TGF-beta stimulation were similar to those observed following ZNF217 downregulation. Collectively, these results establish the ZNF217 complex as a novel negative regulator of the p15(ink4b) gene and may constitute an important link between amplification of ZNF217 and the loss of TGF-beta responsiveness in breast cancer.

Standard name | THILLAINADESAN_ZNF217_TARGETS_DN
Systematic name | M2199
Organism | Homo sapiens
PMID | 18625718
Authors | Thillainadesan G,Isovic M,Loney E,Andrews J,Tini M,Torchia J
Category | C2
Sub-category | CGP
Brief description | Genes bound and repressed by ZNF217 [GeneID=7764] in MCF7 cells (breast cancer).
Full description | The ZNF217 oncoprotein is a constituent of a core transcriptional complex that includes CoREST, histone deacetylase 1/2, lysine demethylase 1, and the C-terminal binding protein 1/2. We have combined genome-wide expression profiling and chromatin immunoprecipitation with directed selection and ligation (ChIP-DSL) to identify a subset of genes directly regulated by ZNF217. Our results establish p15(ink4b) as a direct target of the ZNF217 complex. Downregulation of ZNF217 in MCF-7 breast cancer cells resulted in a dramatic increase in p15(ink4b) expression and coincided with increases in dimethylation of H3-K4 and, surprisingly, a decrease in K9/K14-H3 acetylation. Stimulation of HaCaT cells with transforming growth factor beta (TGF-beta) resulted in a release of ZNF217 and a concomitant binding of SMAD2 to the proximal promoter, which preceded increases in ink4b protein expression. Furthermore, the changes in chromatin marks at the p15(ink4b) promoter following TGF-beta stimulation were similar to those observed following ZNF217 downregulation. Collectively, these results establish the ZNF217 complex as a novel negative regulator of the p15(ink4b) gene and may constitute an important link between amplification of ZNF217 and the loss of TGF-beta responsiveness in breast cancer.

Standard name | PHESSE_TARGETS_OF_APC_AND_MBD2_UP
Systematic name | M2201
Organism | Mus musculus
PMID | 18644872
Authors | Phesse TJ,Parry L,Reed KR,Ewan KB,Dale TC,Sansom OJ,Clarke AR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in small intestine upon loss of both APC and MBD2 [GeneID=324, 8932].
Full description | We have previously shown that deficiency of the methyl binding domain protein Mbd2 dramatically reduces adenoma burden on an Apc(Min/+) background. To investigate the mechanism underlying this phenomenon, we have determined the effect of Mbd2 deficiency upon the phenotypes imposed by the conditional deletion of Apc in the small intestine. Microarray analysis demonstrated a partial suppression of the Wnt pathway in the absence of Mbd2. Mbd2 deficiency also influenced one immediate cellular consequence of Apc loss, with normalization of Paneth cell positioning. From a mechanistic perspective, we show that deficiency of Mbd2 elevates levels of the known Wnt target Lect2, and we confirm here that Mbd2 binds the Lect2 promoter in association with NuRD. Furthermore, we show that Lect2 is capable of functioning as a Wnt pathway repressor. These results therefore provide a mechanistic basis for the epigenetic control of adenoma formation mediated through Mbd2.

Standard name | PHESSE_TARGETS_OF_APC_AND_MBD2_DN
Systematic name | M2203
Organism | Mus musculus
PMID | 18644872
Authors | Phesse TJ,Parry L,Reed KR,Ewan KB,Dale TC,Sansom OJ,Clarke AR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in small intestine upon loss of both APC and MBD2 [GeneID=324, 8932].
Full description | We have previously shown that deficiency of the methyl binding domain protein Mbd2 dramatically reduces adenoma burden on an Apc(Min/+) background. To investigate the mechanism underlying this phenomenon, we have determined the effect of Mbd2 deficiency upon the phenotypes imposed by the conditional deletion of Apc in the small intestine. Microarray analysis demonstrated a partial suppression of the Wnt pathway in the absence of Mbd2. Mbd2 deficiency also influenced one immediate cellular consequence of Apc loss, with normalization of Paneth cell positioning. From a mechanistic perspective, we show that deficiency of Mbd2 elevates levels of the known Wnt target Lect2, and we confirm here that Mbd2 binds the Lect2 promoter in association with NuRD. Furthermore, we show that Lect2 is capable of functioning as a Wnt pathway repressor. These results therefore provide a mechanistic basis for the epigenetic control of adenoma formation mediated through Mbd2.

Standard name | CHYLA_CBFA2T3_TARGETS_UP
Systematic name | M2205
Organism | Mus musculus
PMID | 18710942
Authors | Chyla BJ,Moreno-Miralles I,Steapleton MA,Thompson MA,Bhaskara S,Engel M,Hiebert SW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in immature bone marrow progenitor cells upon knock out of CBFA2T3 [GeneID=863].
Full description | While a number of DNA binding transcription factors have been identified that control hematopoietic cell fate decisions, only a limited number of transcriptional corepressors (e.g., the retinoblastoma protein [pRB] and the nuclear hormone corepressor [N-CoR]) have been linked to these functions. Here, we show that the transcriptional corepressor Mtg16 (myeloid translocation gene on chromosome 16), which is targeted by t(16;21) in acute myeloid leukemia, is required for hematopoietic progenitor cell fate decisions and for early progenitor cell proliferation. Inactivation of Mtg16 skewed early myeloid progenitor cells toward the granulocytic/macrophage lineage while reducing the numbers of megakaryocyte-erythroid progenitor cells. In addition, inactivation of Mtg16 impaired the rapid expansion of short-term stem cells, multipotent progenitor cells, and megakaryocyte-erythroid progenitor cells that is required under hematopoietic stress/emergency. This impairment appears to be a failure to proliferate rather than an induction of cell death, as expression of c-Myc, but not Bcl2, complemented the Mtg16(-/-) defect.

Standard name | CHYLA_CBFA2T3_TARGETS_DN
Systematic name | M2206
Organism | Mus musculus
PMID | 18710942
Authors | Chyla BJ,Moreno-Miralles I,Steapleton MA,Thompson MA,Bhaskara S,Engel M,Hiebert SW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in immature bone marrow progenitor cells upon knock out of CBFA2T3 [GeneID=863].
Full description | While a number of DNA binding transcription factors have been identified that control hematopoietic cell fate decisions, only a limited number of transcriptional corepressors (e.g., the retinoblastoma protein [pRB] and the nuclear hormone corepressor [N-CoR]) have been linked to these functions. Here, we show that the transcriptional corepressor Mtg16 (myeloid translocation gene on chromosome 16), which is targeted by t(16;21) in acute myeloid leukemia, is required for hematopoietic progenitor cell fate decisions and for early progenitor cell proliferation. Inactivation of Mtg16 skewed early myeloid progenitor cells toward the granulocytic/macrophage lineage while reducing the numbers of megakaryocyte-erythroid progenitor cells. In addition, inactivation of Mtg16 impaired the rapid expansion of short-term stem cells, multipotent progenitor cells, and megakaryocyte-erythroid progenitor cells that is required under hematopoietic stress/emergency. This impairment appears to be a failure to proliferate rather than an induction of cell death, as expression of c-Myc, but not Bcl2, complemented the Mtg16(-/-) defect.

Standard name | FUKUSHIMA_TNFSF11_TARGETS
Systematic name | M2207
Organism | Mus musculus
PMID | 18710934
Authors | Fukushima H,Nakao A,Okamoto F,Shin M,Kajiya H,Sakano S,Bigas A,Jimi E,Okabe K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RAW 264.7 cells (macrophage) upon stimulation with TNFSF11 [GeneID=8600].
Full description | Notch signaling plays a key role in various cell differentiation processes including bone homeostasis. However, the specific involvement of Notch in regulating osteoclastogenesis is still controversial. In the present study, we show that RANKL induces expression of Jagged1 and Notch2 in bone marrow macrophages during osteoclast differentiation. Suppression of Notch signaling by a selective gamma-secretase inhibitor or Notch2 short hairpin RNA suppresses RANKL-induced osteoclastogenesis. In contrast, induction of Notch signaling by Jagged1 or by ectopic expression of intracellular Notch2 enhances NFATc1 promoter activity and expression and promotes osteoclastogenesis. Finally, we found that Notch2 and p65 interact in the nuclei of RANKL-stimulated cells and that both proteins are recruited to the NFATc1 promoter, driving its expression. Taken together, our results show a new molecular cross talk between Notch and NF-kappaB pathways that is relevant in osteoclastogenesis.

Standard name | CARD_MIR302A_TARGETS
Systematic name | M2208
Organism | Homo sapiens
PMID | 18710938
Authors | Card DA,Hebbar PB,Li L,Trotter KW,Komatsu Y,Mishina Y,Archer TK
Category | C2
Sub-category | CGP
Brief description | Potential targets of MIR302A [GeneID=407028].
Full description | Oct4 and Sox2 are transcription factors required for pluripotency during early embryogenesis and for the maintenance of embryonic stem cell (ESC) identity. Functional mechanisms contributing to pluripotency are expected to be associated with genes transcriptionally activated by these factors. Here, we show that Oct4 and Sox2 bind to a conserved promoter region of miR-302, a cluster of eight microRNAs expressed specifically in ESCs and pluripotent cells. The expression of miR-302a is dependent on Oct4/Sox2 in human ESCs (hESCs), and miR-302a is expressed at the same developmental stages and in the same tissues as Oct4 during embryogenesis. miR-302a is predicted to target many cell cycle regulators, and the expression of miR-302a in primary and transformed cell lines promotes an increase in S-phase and a decrease in G(1)-phase cells, reminiscent of an ESC-like cell cycle profile. Correspondingly, the inhibition of miR-302 causes hESCs to accumulate in G(1) phase. Moreover, we show that miR-302a represses the productive translation of an important G(1) regulator, cyclin D1, in hESCs. The transcriptional activation of miR-302 and the translational repression of its targets, such as cyclin D1, may provide a link between Oct4/Sox2 and cell cycle regulation in pluripotent cells.

Standard name | WIERENGA_STAT5A_TARGETS_UP
Systematic name | M2210
Organism | Homo sapiens
PMID | 18779318
Authors | Wierenga AT,Vellenga E,Schuringa JJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in CD34+ [GeneID=947] cells by intermediate activity levels of STAT5A [GeneID=6776]; predominant long-term growth and self-renewal phenotype.
Full description | The level of transcription factor activity critically regulates cell fate decisions, such as hematopoietic stem cell (HSC) self-renewal and differentiation. We introduced STAT5A transcriptional activity into human HSCs/progenitor cells in a dose-dependent manner by overexpression of a tamoxifen-inducible STAT5A(1*6)-estrogen receptor fusion protein. Induction of STAT5A activity in CD34(+) cells resulted in impaired myelopoiesis and induction of erythropoiesis, which was most pronounced at the highest STAT5A transactivation levels. In contrast, intermediate STAT5A activity levels resulted in the most pronounced proliferative advantage of CD34(+) cells. This coincided with increased cobblestone area-forming cell and long-term-culture-initiating cell frequencies, which were predominantly elevated at intermediate STAT5A activity levels but not at high STAT5A levels. Self-renewal of progenitors was addressed by serial replating of CFU, and only progenitors containing intermediate STAT5A activity levels contained self-renewal capacity. By extensive gene expression profiling we could identify gene expression patterns of STAT5 target genes that predominantly associated with a self-renewal and long-term expansion phenotype versus those that identified a predominant differentiation phenotype.

Standard name | WIERENGA_STAT5A_TARGETS_DN
Systematic name | M2213
Organism | Homo sapiens
PMID | 18779318
Authors | Wierenga AT,Vellenga E,Schuringa JJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in CD34+ [GeneID=947] cells by intermediate activity levels of STAT5A [GeneID=6776]; predominant long-term growth and self-renewal phenotype.
Full description | The level of transcription factor activity critically regulates cell fate decisions, such as hematopoietic stem cell (HSC) self-renewal and differentiation. We introduced STAT5A transcriptional activity into human HSCs/progenitor cells in a dose-dependent manner by overexpression of a tamoxifen-inducible STAT5A(1*6)-estrogen receptor fusion protein. Induction of STAT5A activity in CD34(+) cells resulted in impaired myelopoiesis and induction of erythropoiesis, which was most pronounced at the highest STAT5A transactivation levels. In contrast, intermediate STAT5A activity levels resulted in the most pronounced proliferative advantage of CD34(+) cells. This coincided with increased cobblestone area-forming cell and long-term-culture-initiating cell frequencies, which were predominantly elevated at intermediate STAT5A activity levels but not at high STAT5A levels. Self-renewal of progenitors was addressed by serial replating of CFU, and only progenitors containing intermediate STAT5A activity levels contained self-renewal capacity. By extensive gene expression profiling we could identify gene expression patterns of STAT5 target genes that predominantly associated with a self-renewal and long-term expansion phenotype versus those that identified a predominant differentiation phenotype.

Standard name | WIERENGA_STAT5A_TARGETS_GROUP1
Systematic name | M2215
Organism | Homo sapiens
PMID | 18779318
Authors | Wierenga AT,Vellenga E,Schuringa JJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated to their maximal levels in CD34+ [GeneID=947] cells by intermediate activity levels of STAT5A [GeneID=6776]; predominant long-term growth and self-renewal phenotype.
Full description | The level of transcription factor activity critically regulates cell fate decisions, such as hematopoietic stem cell (HSC) self-renewal and differentiation. We introduced STAT5A transcriptional activity into human HSCs/progenitor cells in a dose-dependent manner by overexpression of a tamoxifen-inducible STAT5A(1*6)-estrogen receptor fusion protein. Induction of STAT5A activity in CD34(+) cells resulted in impaired myelopoiesis and induction of erythropoiesis, which was most pronounced at the highest STAT5A transactivation levels. In contrast, intermediate STAT5A activity levels resulted in the most pronounced proliferative advantage of CD34(+) cells. This coincided with increased cobblestone area-forming cell and long-term-culture-initiating cell frequencies, which were predominantly elevated at intermediate STAT5A activity levels but not at high STAT5A levels. Self-renewal of progenitors was addressed by serial replating of CFU, and only progenitors containing intermediate STAT5A activity levels contained self-renewal capacity. By extensive gene expression profiling we could identify gene expression patterns of STAT5 target genes that predominantly associated with a self-renewal and long-term expansion phenotype versus those that identified a predominant differentiation phenotype.

Standard name | WIERENGA_STAT5A_TARGETS_GROUP2
Systematic name | M2216
Organism | Homo sapiens
PMID | 18779318
Authors | Wierenga AT,Vellenga E,Schuringa JJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in a linear fashion in CD34+ [GeneID=947] cells upon increasing activity levels of STAT5A [GeneID=6776]; predominant long-term growth and self-renewal phenotype.
Full description | The level of transcription factor activity critically regulates cell fate decisions, such as hematopoietic stem cell (HSC) self-renewal and differentiation. We introduced STAT5A transcriptional activity into human HSCs/progenitor cells in a dose-dependent manner by overexpression of a tamoxifen-inducible STAT5A(1*6)-estrogen receptor fusion protein. Induction of STAT5A activity in CD34(+) cells resulted in impaired myelopoiesis and induction of erythropoiesis, which was most pronounced at the highest STAT5A transactivation levels. In contrast, intermediate STAT5A activity levels resulted in the most pronounced proliferative advantage of CD34(+) cells. This coincided with increased cobblestone area-forming cell and long-term-culture-initiating cell frequencies, which were predominantly elevated at intermediate STAT5A activity levels but not at high STAT5A levels. Self-renewal of progenitors was addressed by serial replating of CFU, and only progenitors containing intermediate STAT5A activity levels contained self-renewal capacity. By extensive gene expression profiling we could identify gene expression patterns of STAT5 target genes that predominantly associated with a self-renewal and long-term expansion phenotype versus those that identified a predominant differentiation phenotype.

Standard name | WIERENGA_PML_INTERACTOME
Systematic name | M2219
Organism | Homo sapiens
PMID | 18779318
Authors | Wierenga AT,Vellenga E,Schuringa JJ
Category | C2
Sub-category | CGP
Brief description | Proteins identified in complex with PML [GeneID=5371] in K562 cells (lymphoblast).
Full description | The level of transcription factor activity critically regulates cell fate decisions, such as hematopoietic stem cell (HSC) self-renewal and differentiation. We introduced STAT5A transcriptional activity into human HSCs/progenitor cells in a dose-dependent manner by overexpression of a tamoxifen-inducible STAT5A(1*6)-estrogen receptor fusion protein. Induction of STAT5A activity in CD34(+) cells resulted in impaired myelopoiesis and induction of erythropoiesis, which was most pronounced at the highest STAT5A transactivation levels. In contrast, intermediate STAT5A activity levels resulted in the most pronounced proliferative advantage of CD34(+) cells. This coincided with increased cobblestone area-forming cell and long-term-culture-initiating cell frequencies, which were predominantly elevated at intermediate STAT5A activity levels but not at high STAT5A levels. Self-renewal of progenitors was addressed by serial replating of CFU, and only progenitors containing intermediate STAT5A activity levels contained self-renewal capacity. By extensive gene expression profiling we could identify gene expression patterns of STAT5 target genes that predominantly associated with a self-renewal and long-term expansion phenotype versus those that identified a predominant differentiation phenotype.

Standard name | ACOSTA_PROLIFERATION_INDEPENDENT_MYC_TARGETS_UP
Systematic name | M2221
Organism | Homo sapiens
PMID | 18838534
Authors | Acosta JC,Ferrándiz N,Bretones G,Torrano V,Blanco R,Richard C,O'Connell B,Sedivy J,Delgado MD,León J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in K562 cells (lymphoblast) by MYC [GeneID=4609] in the presence of CKN1B [GeneID=1027].
Full description | Inhibition of differentiation has been proposed as an important mechanism for Myc-induced tumorigenesis, but the mechanisms involved are unclear. We have established a genetically defined differentiation model in human leukemia K562 cells by conditional expression of the cyclin-dependent kinase (Cdk) inhibitor p27 (inducible by Zn(2+)) and Myc (activatable by 4-hydroxy-tamoxifen). Induction of p27 resulted in erythroid differentiation, accompanied by Cdk inhibition and G(1) arrest. Interestingly, activation of Myc inhibited p27-mediated erythroid differentiation without affecting p27-mediated proliferation arrest. Microarray-based gene expression indicated that, in the presence of p27, Myc blocked the upregulation of several erythroid-cell-specific genes, including NFE2, JUNB, and GATA1 (transcription factors with a pivotal role in erythropoiesis). Moreover, Myc also blocked the upregulation of Mad1, a transcriptional antagonist of Myc that is able to induce erythroid differentiation. Cotransfection experiments demonstrated that Myc-mediated inhibition of differentiation is partly dependent on the repression of Mad1 and GATA1. In conclusion, this model demonstrates that Myc-mediated inhibition of differentiation depends on the regulation of a specific gene program, whereas it is independent of p27-mediated cell cycle arrest. Our results support the hypothesis that differentiation inhibition is an important Myc tumorigenic mechanism that is independent of cell proliferation.

Standard name | ACOSTA_PROLIFERATION_INDEPENDENT_MYC_TARGETS_DN
Systematic name | M2222
Organism | Homo sapiens
PMID | 18838534
Authors | Acosta JC,Ferrándiz N,Bretones G,Torrano V,Blanco R,Richard C,O'Connell B,Sedivy J,Delgado MD,León J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in K562 cells (lymphoblast) by MYC [GeneID=4609] in the presence of CKN1B [GeneID=1027].
Full description | Inhibition of differentiation has been proposed as an important mechanism for Myc-induced tumorigenesis, but the mechanisms involved are unclear. We have established a genetically defined differentiation model in human leukemia K562 cells by conditional expression of the cyclin-dependent kinase (Cdk) inhibitor p27 (inducible by Zn(2+)) and Myc (activatable by 4-hydroxy-tamoxifen). Induction of p27 resulted in erythroid differentiation, accompanied by Cdk inhibition and G(1) arrest. Interestingly, activation of Myc inhibited p27-mediated erythroid differentiation without affecting p27-mediated proliferation arrest. Microarray-based gene expression indicated that, in the presence of p27, Myc blocked the upregulation of several erythroid-cell-specific genes, including NFE2, JUNB, and GATA1 (transcription factors with a pivotal role in erythropoiesis). Moreover, Myc also blocked the upregulation of Mad1, a transcriptional antagonist of Myc that is able to induce erythroid differentiation. Cotransfection experiments demonstrated that Myc-mediated inhibition of differentiation is partly dependent on the repression of Mad1 and GATA1. In conclusion, this model demonstrates that Myc-mediated inhibition of differentiation depends on the regulation of a specific gene program, whereas it is independent of p27-mediated cell cycle arrest. Our results support the hypothesis that differentiation inhibition is an important Myc tumorigenic mechanism that is independent of cell proliferation.

Standard name | KANG_AR_TARGETS_UP
Systematic name | M2223
Organism | Mus musculus
PMID | 18838539
Authors | Kang HY,Shyr CR,Huang CK,Tsai MY,Orimo H,Lin PC,Chang C,Huang KE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in osteoblasts from wild type male mice compared to those with AR [GeneID=367] knockout.
Full description | While androgen receptor (AR)-deficient mice developed osteopenia in endochondral bones due to the high bone turnover with increased bone resorption by osteoclasts, little is known about the mechanism of intramembranous bone loss contributed by AR in osteoblasts. Here, we discovered a dramatic decrease in the area of calcification, new bone, and the number of osteocytes in calvaria from AR-deficient mice related to a reduction in mineralization caused, in part, by the diminished activity of AR-deficient osteoblasts. Enforced AR expression in differentiated osteoblasts boosts mineralization while knockdown of AR expression prevents androgen-induced mineralization. We identified the tissue-nonspecific alkaline phosphatase (TNSALP) and several members of small integrin binding ligand N-linked glycoprotein (SIBLING) gene family as androgen target genes required for AR-mediated bone formation. We show that inorganic phosphate (P(i)) levels and TNSALP activity increased in response to androgen/AR and P(i) signals increase the expression and translocation of AR. The ectopic expression of TNSALP or P(i) partially rescued the bone loss due to AR deficiency. Thus, androgen/AR signaling plays an essential role in bone formation by coordinating the expression of genes associated with phosphate regulation.

Standard name | KANG_AR_TARGETS_DN
Systematic name | M2225
Organism | Mus musculus
PMID | 18838539
Authors | Kang HY,Shyr CR,Huang CK,Tsai MY,Orimo H,Lin PC,Chang C,Huang KE
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in osteoblasts from wild type male mice compared to those with AR [GeneID=367] knockout.
Full description | While androgen receptor (AR)-deficient mice developed osteopenia in endochondral bones due to the high bone turnover with increased bone resorption by osteoclasts, little is known about the mechanism of intramembranous bone loss contributed by AR in osteoblasts. Here, we discovered a dramatic decrease in the area of calcification, new bone, and the number of osteocytes in calvaria from AR-deficient mice related to a reduction in mineralization caused, in part, by the diminished activity of AR-deficient osteoblasts. Enforced AR expression in differentiated osteoblasts boosts mineralization while knockdown of AR expression prevents androgen-induced mineralization. We identified the tissue-nonspecific alkaline phosphatase (TNSALP) and several members of small integrin binding ligand N-linked glycoprotein (SIBLING) gene family as androgen target genes required for AR-mediated bone formation. We show that inorganic phosphate (P(i)) levels and TNSALP activity increased in response to androgen/AR and P(i) signals increase the expression and translocation of AR. The ectopic expression of TNSALP or P(i) partially rescued the bone loss due to AR deficiency. Thus, androgen/AR signaling plays an essential role in bone formation by coordinating the expression of genes associated with phosphate regulation.

Standard name | PILON_KLF1_TARGETS_UP
Systematic name | M2226
Organism | Mus musculus
PMID | 18852285
Authors | Pilon AM,Arcasoy MO,Dressman HK,Vayda SE,Maksimova YD,Sangerman JI,Gallagher PG,Bodine DM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in erythroid progenitor cells from fetal livers of E13.5 embryos with KLF1 [GeneID=10661] knockout compared to those from the wild type embryos.
Full description | Erythroid Krüppel-like factor (EKLF) is a Krüppel-like transcription factor identified as a transcriptional activator and chromatin modifier in erythroid cells. EKLF-deficient (Eklf(-/-)) mice die at day 14.5 of gestation from severe anemia. In this study, we demonstrate that early progenitor cells fail to undergo terminal erythroid differentiation in Eklf(-/-) embryos. To discover potential EKLF target genes responsible for the failure of erythropoiesis, transcriptional profiling was performed with RNA from wild-type and Eklf(-/-) early erythroid progenitor cells. These analyses identified significant perturbation of a network of genes involved in cell cycle regulation, with the critical regulator of the cell cycle, E2f2, at a hub. E2f2 mRNA and protein levels were markedly decreased in Eklf(-/-) early erythroid progenitor cells, which showed a delay in the G(1)-to-S-phase transition. Chromatin immunoprecipitation analysis demonstrated EKLF occupancy at the proximal E2f2 promoter in vivo. Consistent with the role of EKLF as a chromatin modifier, EKLF binding sites in the E2f2 promoter were located in a region of EKLF-dependent DNase I sensitivity in early erythroid progenitor cells. We propose a model in which EKLF-dependent activation and modification of the E2f2 locus is required for cell cycle progression preceding terminal erythroid differentiation.

Standard name | BHAT_ESR1_TARGETS_NOT_VIA_AKT1_UP
Systematic name | M2230
Organism | Homo sapiens
PMID | 18838536
Authors | Bhat-Nakshatri P,Wang G,Appaiah H,Luktuke N,Carroll JS,Geistlinger TR,Brown M,Badve S,Liu Y,Nakshatri H
Category | C2
Sub-category | CGP
Brief description | Genes bound by ESR1 [GeneID=2099] and up-regulated by estradiol [PubChem=5757] in MCF-7 cells (breast cancer).
Full description | Estrogen regulates several biological processes through estrogen receptor alpha (ERalpha) and ERbeta. ERalpha-estrogen signaling is additionally controlled by extracellular signal activated kinases such as AKT. In this study, we analyzed the effect of AKT on genome-wide ERalpha binding in MCF-7 breast cancer cells. Parental and AKT-overexpressing cells displayed 4,349 and 4,359 ERalpha binding sites, respectively, with approximately 60% overlap. In both cell types, approximately 40% of estrogen-regulated genes associate with ERalpha binding sites; a similar percentage of estrogen-regulated genes are differentially expressed in two cell types. Based on pathway analysis, these differentially estrogen-regulated genes are linked to transforming growth factor beta (TGF-beta), NF-kappaB, and E2F pathways. Consistent with this, the two cell types responded differently to TGF-beta treatment: parental cells, but not AKT-overexpressing cells, required estrogen to overcome growth inhibition. Combining the ERalpha DNA-binding pattern with gene expression data from primary tumors revealed specific effects of AKT on ERalpha binding and estrogen-regulated expression of genes that define prognostic subgroups and tamoxifen sensitivity of ERalpha-positive breast cancer. These results suggest a unique role of AKT in modulating estrogen signaling in ERalpha-positive breast cancers and highlights how extracellular signal activated kinases can change the landscape of transcription factor binding to the genome.

Standard name | BHAT_ESR1_TARGETS_NOT_VIA_AKT1_DN
Systematic name | M2232
Organism | Homo sapiens
PMID | 18838536
Authors | Bhat-Nakshatri P,Wang G,Appaiah H,Luktuke N,Carroll JS,Geistlinger TR,Brown M,Badve S,Liu Y,Nakshatri H
Category | C2
Sub-category | CGP
Brief description | Genes bound by ESR1 [GeneID=2099] and down-regulated by estradiol [PubChem=5757] in MCF-7 cells (breast cancer).
Full description | Estrogen regulates several biological processes through estrogen receptor alpha (ERalpha) and ERbeta. ERalpha-estrogen signaling is additionally controlled by extracellular signal activated kinases such as AKT. In this study, we analyzed the effect of AKT on genome-wide ERalpha binding in MCF-7 breast cancer cells. Parental and AKT-overexpressing cells displayed 4,349 and 4,359 ERalpha binding sites, respectively, with approximately 60% overlap. In both cell types, approximately 40% of estrogen-regulated genes associate with ERalpha binding sites; a similar percentage of estrogen-regulated genes are differentially expressed in two cell types. Based on pathway analysis, these differentially estrogen-regulated genes are linked to transforming growth factor beta (TGF-beta), NF-kappaB, and E2F pathways. Consistent with this, the two cell types responded differently to TGF-beta treatment: parental cells, but not AKT-overexpressing cells, required estrogen to overcome growth inhibition. Combining the ERalpha DNA-binding pattern with gene expression data from primary tumors revealed specific effects of AKT on ERalpha binding and estrogen-regulated expression of genes that define prognostic subgroups and tamoxifen sensitivity of ERalpha-positive breast cancer. These results suggest a unique role of AKT in modulating estrogen signaling in ERalpha-positive breast cancers and highlights how extracellular signal activated kinases can change the landscape of transcription factor binding to the genome.

Standard name | BHAT_ESR1_TARGETS_VIA_AKT1_UP
Systematic name | M2234
Organism | Homo sapiens
PMID | 18838536
Authors | Bhat-Nakshatri P,Wang G,Appaiah H,Luktuke N,Carroll JS,Geistlinger TR,Brown M,Badve S,Liu Y,Nakshatri H
Category | C2
Sub-category | CGP
Brief description | Genes bound by ESR1 [GeneID=2099] and up-regulated by estradiol [PubChem=5757] in MCF-7 cells (breast cancer) expressing constitutevly active form of AKT1 [GeneID=207].
Full description | Estrogen regulates several biological processes through estrogen receptor alpha (ERalpha) and ERbeta. ERalpha-estrogen signaling is additionally controlled by extracellular signal activated kinases such as AKT. In this study, we analyzed the effect of AKT on genome-wide ERalpha binding in MCF-7 breast cancer cells. Parental and AKT-overexpressing cells displayed 4,349 and 4,359 ERalpha binding sites, respectively, with approximately 60% overlap. In both cell types, approximately 40% of estrogen-regulated genes associate with ERalpha binding sites; a similar percentage of estrogen-regulated genes are differentially expressed in two cell types. Based on pathway analysis, these differentially estrogen-regulated genes are linked to transforming growth factor beta (TGF-beta), NF-kappaB, and E2F pathways. Consistent with this, the two cell types responded differently to TGF-beta treatment: parental cells, but not AKT-overexpressing cells, required estrogen to overcome growth inhibition. Combining the ERalpha DNA-binding pattern with gene expression data from primary tumors revealed specific effects of AKT on ERalpha binding and estrogen-regulated expression of genes that define prognostic subgroups and tamoxifen sensitivity of ERalpha-positive breast cancer. These results suggest a unique role of AKT in modulating estrogen signaling in ERalpha-positive breast cancers and highlights how extracellular signal activated kinases can change the landscape of transcription factor binding to the genome.

Standard name | BHAT_ESR1_TARGETS_VIA_AKT1_DN
Systematic name | M2235
Organism | Homo sapiens
PMID | 18838536
Authors | Bhat-Nakshatri P,Wang G,Appaiah H,Luktuke N,Carroll JS,Geistlinger TR,Brown M,Badve S,Liu Y,Nakshatri H
Category | C2
Sub-category | CGP
Brief description | Genes bound by ESR1 [GeneID=2099] and down-regulated by estradiol [PubChem=5757] in MCF-7 cells (breast cancer) expressing constitutevly active form of AKT1 [GeneID=207].
Full description | Estrogen regulates several biological processes through estrogen receptor alpha (ERalpha) and ERbeta. ERalpha-estrogen signaling is additionally controlled by extracellular signal activated kinases such as AKT. In this study, we analyzed the effect of AKT on genome-wide ERalpha binding in MCF-7 breast cancer cells. Parental and AKT-overexpressing cells displayed 4,349 and 4,359 ERalpha binding sites, respectively, with approximately 60% overlap. In both cell types, approximately 40% of estrogen-regulated genes associate with ERalpha binding sites; a similar percentage of estrogen-regulated genes are differentially expressed in two cell types. Based on pathway analysis, these differentially estrogen-regulated genes are linked to transforming growth factor beta (TGF-beta), NF-kappaB, and E2F pathways. Consistent with this, the two cell types responded differently to TGF-beta treatment: parental cells, but not AKT-overexpressing cells, required estrogen to overcome growth inhibition. Combining the ERalpha DNA-binding pattern with gene expression data from primary tumors revealed specific effects of AKT on ERalpha binding and estrogen-regulated expression of genes that define prognostic subgroups and tamoxifen sensitivity of ERalpha-positive breast cancer. These results suggest a unique role of AKT in modulating estrogen signaling in ERalpha-positive breast cancers and highlights how extracellular signal activated kinases can change the landscape of transcription factor binding to the genome.

Standard name | JOHNSTONE_PARVB_TARGETS_1_UP
Systematic name | M2236
Organism | Homo sapiens
PMID | 17998334
Authors | Johnstone CN,Mongroo PS,Rich AS,Schupp M,Bowser MJ,Delemos AS,Tobias JW,Liu Y,Hannigan GE,Rustgi AK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MDA-MB-231 cells (breast cancer) upon overexpression of PARVB [GeneID=29780] under all three culture conditions.
Full description | Parvin-beta is a focal adhesion protein downregulated in human breast cancer cells. Loss of Parvin-beta contributes to increased integrin-linked kinase activity, cell-matrix adhesion, and invasion through the extracellular matrix in vitro. The effect of ectopic Parvin-beta expression on the transcriptional profile of MDA-MB-231 breast cancer cells, which normally do not express Parvin-beta, was evaluated. Particular emphasis was placed upon propagating MDA-MB-231 breast cancer cells in three-dimensional culture matrices. Interestingly, Parvin-beta reexpression in MDA-MB-231 cells increased the mRNA expression, serine 82 phosphorylation (mediated by CDK9), and activity of the nuclear hormone receptor peroxisome proliferator-activated receptor gamma (PPARgamma), and there was a concomitant increase in lipogenic gene expression as a downstream effector of PPARgamma. Importantly, Parvin-beta suppressed breast cancer growth in vivo, with associated decreased proliferation. These data suggest that Parvin-beta might influence breast cancer progression.

Standard name | JOHNSTONE_PARVB_TARGETS_1_DN
Systematic name | M2237
Organism | Homo sapiens
PMID | 17998334
Authors | Johnstone CN,Mongroo PS,Rich AS,Schupp M,Bowser MJ,Delemos AS,Tobias JW,Liu Y,Hannigan GE,Rustgi AK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MDA-MB-231 cells (breast cancer) upon overexpression of PARVB [GeneID=29780] under all three culture conditions.
Full description | Parvin-beta is a focal adhesion protein downregulated in human breast cancer cells. Loss of Parvin-beta contributes to increased integrin-linked kinase activity, cell-matrix adhesion, and invasion through the extracellular matrix in vitro. The effect of ectopic Parvin-beta expression on the transcriptional profile of MDA-MB-231 breast cancer cells, which normally do not express Parvin-beta, was evaluated. Particular emphasis was placed upon propagating MDA-MB-231 breast cancer cells in three-dimensional culture matrices. Interestingly, Parvin-beta reexpression in MDA-MB-231 cells increased the mRNA expression, serine 82 phosphorylation (mediated by CDK9), and activity of the nuclear hormone receptor peroxisome proliferator-activated receptor gamma (PPARgamma), and there was a concomitant increase in lipogenic gene expression as a downstream effector of PPARgamma. Importantly, Parvin-beta suppressed breast cancer growth in vivo, with associated decreased proliferation. These data suggest that Parvin-beta might influence breast cancer progression.

Standard name | JOHNSTONE_PARVB_TARGETS_2_UP
Systematic name | M2238
Organism | Homo sapiens
PMID | 17998334
Authors | Johnstone CN,Mongroo PS,Rich AS,Schupp M,Bowser MJ,Delemos AS,Tobias JW,Liu Y,Hannigan GE,Rustgi AK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated upon overexpression of PARVB [GeneID=29780] in MDA-MB-231 cells (breast cancer) cultured in 3D collagen I and 3D Matrigel only.
Full description | Parvin-beta is a focal adhesion protein downregulated in human breast cancer cells. Loss of Parvin-beta contributes to increased integrin-linked kinase activity, cell-matrix adhesion, and invasion through the extracellular matrix in vitro. The effect of ectopic Parvin-beta expression on the transcriptional profile of MDA-MB-231 breast cancer cells, which normally do not express Parvin-beta, was evaluated. Particular emphasis was placed upon propagating MDA-MB-231 breast cancer cells in three-dimensional culture matrices. Interestingly, Parvin-beta reexpression in MDA-MB-231 cells increased the mRNA expression, serine 82 phosphorylation (mediated by CDK9), and activity of the nuclear hormone receptor peroxisome proliferator-activated receptor gamma (PPARgamma), and there was a concomitant increase in lipogenic gene expression as a downstream effector of PPARgamma. Importantly, Parvin-beta suppressed breast cancer growth in vivo, with associated decreased proliferation. These data suggest that Parvin-beta might influence breast cancer progression.

Standard name | JOHNSTONE_PARVB_TARGETS_2_DN
Systematic name | M2239
Organism | Homo sapiens
PMID | 17998334
Authors | Johnstone CN,Mongroo PS,Rich AS,Schupp M,Bowser MJ,Delemos AS,Tobias JW,Liu Y,Hannigan GE,Rustgi AK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated upon overexpression of PARVB [GeneID=29780] in MDA-MB-231 cells (breast cancer) cultured in 3D collagen I and 3D Matrigel only.
Full description | Parvin-beta is a focal adhesion protein downregulated in human breast cancer cells. Loss of Parvin-beta contributes to increased integrin-linked kinase activity, cell-matrix adhesion, and invasion through the extracellular matrix in vitro. The effect of ectopic Parvin-beta expression on the transcriptional profile of MDA-MB-231 breast cancer cells, which normally do not express Parvin-beta, was evaluated. Particular emphasis was placed upon propagating MDA-MB-231 breast cancer cells in three-dimensional culture matrices. Interestingly, Parvin-beta reexpression in MDA-MB-231 cells increased the mRNA expression, serine 82 phosphorylation (mediated by CDK9), and activity of the nuclear hormone receptor peroxisome proliferator-activated receptor gamma (PPARgamma), and there was a concomitant increase in lipogenic gene expression as a downstream effector of PPARgamma. Importantly, Parvin-beta suppressed breast cancer growth in vivo, with associated decreased proliferation. These data suggest that Parvin-beta might influence breast cancer progression.

Standard name | JOHNSTONE_PARVB_TARGETS_3_UP
Systematic name | M2240
Organism | Homo sapiens
PMID | 17998334
Authors | Johnstone CN,Mongroo PS,Rich AS,Schupp M,Bowser MJ,Delemos AS,Tobias JW,Liu Y,Hannigan GE,Rustgi AK
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated upon overexpression of PARVB [GeneID=29780] in MDA-MB-231 cells (breast cancer) cultured in 3D Matrigel only.
Full description | Parvin-beta is a focal adhesion protein downregulated in human breast cancer cells. Loss of Parvin-beta contributes to increased integrin-linked kinase activity, cell-matrix adhesion, and invasion through the extracellular matrix in vitro. The effect of ectopic Parvin-beta expression on the transcriptional profile of MDA-MB-231 breast cancer cells, which normally do not express Parvin-beta, was evaluated. Particular emphasis was placed upon propagating MDA-MB-231 breast cancer cells in three-dimensional culture matrices. Interestingly, Parvin-beta reexpression in MDA-MB-231 cells increased the mRNA expression, serine 82 phosphorylation (mediated by CDK9), and activity of the nuclear hormone receptor peroxisome proliferator-activated receptor gamma (PPARgamma), and there was a concomitant increase in lipogenic gene expression as a downstream effector of PPARgamma. Importantly, Parvin-beta suppressed breast cancer growth in vivo, with associated decreased proliferation. These data suggest that Parvin-beta might influence breast cancer progression.

Standard name | JOHNSTONE_PARVB_TARGETS_3_DN
Systematic name | M2241
Organism | Homo sapiens
PMID | 17998334
Authors | Johnstone CN,Mongroo PS,Rich AS,Schupp M,Bowser MJ,Delemos AS,Tobias JW,Liu Y,Hannigan GE,Rustgi AK
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated upon overexpression of PARVB [GeneID=29780] in MDA-MB-231 cells (breast cancer) cultured in 3D Matrigel only.
Full description | Parvin-beta is a focal adhesion protein downregulated in human breast cancer cells. Loss of Parvin-beta contributes to increased integrin-linked kinase activity, cell-matrix adhesion, and invasion through the extracellular matrix in vitro. The effect of ectopic Parvin-beta expression on the transcriptional profile of MDA-MB-231 breast cancer cells, which normally do not express Parvin-beta, was evaluated. Particular emphasis was placed upon propagating MDA-MB-231 breast cancer cells in three-dimensional culture matrices. Interestingly, Parvin-beta reexpression in MDA-MB-231 cells increased the mRNA expression, serine 82 phosphorylation (mediated by CDK9), and activity of the nuclear hormone receptor peroxisome proliferator-activated receptor gamma (PPARgamma), and there was a concomitant increase in lipogenic gene expression as a downstream effector of PPARgamma. Importantly, Parvin-beta suppressed breast cancer growth in vivo, with associated decreased proliferation. These data suggest that Parvin-beta might influence breast cancer progression.

Standard name | BRUINS_UVC_RESPONSE_VIA_TP53_GROUP_A
Systematic name | M2242
Organism | Mus musculus
PMID | 18195040
Authors | Bruins W,Bruning O,Jonker MJ,Zwart E,van der Hoeven TV,Pennings JL,Rauwerda H,de Vries A,Breit TM
Category | C2
Sub-category | CGP
Brief description | Category A genes: p53-dependent genes whose expression in the absence of S389 phosphorylation is similar to loss of TP53 [GeneID=7157] in MEF (embryonic fibroblast) cells in response to UV-C irradiation.
Full description | Phosphorylation is important in p53-mediated DNA damage responses. After UV irradiation, p53 is phosphorylated specifically at murine residue Ser389. Phosphorylation mutant p53.S389A cells and mice show reduced apoptosis and compromised tumor suppression after UV irradiation. We investigated the underlying cellular processes by time-series analysis of UV-induced gene expression responses in wild-type, p53.S389A, and p53(-/-) mouse embryonic fibroblasts. The absence of p53.S389 phosphorylation already causes small endogenous gene expression changes for 2,253, mostly p53-dependent, genes. These genes showed basal gene expression levels intermediate to the wild type and p53(-/-), possibly to readjust the p53 network. Overall, the p53.S389A mutation lifts p53-dependent gene repression to a level similar to that of p53(-/-) but has lesser effect on p53-dependently induced genes. In the wild type, the response of 6,058 genes to UV irradiation was strictly biphasic. The early stress response, from 0 to 3 h, results in the activation of processes to prevent the accumulation of DNA damage in cells, whereas the late response, from 12 to 24 h, relates more to reentering the cell cycle. Although the p53.S389A UV gene response was only subtly changed, many cellular processes were significantly affected. The early response was affected the most, and many cellular processes were phase-specifically lost, gained, or altered, e.g., induction of apoptosis, cell division, and DNA repair, respectively. Altogether, p53.S389 phosphorylation seems essential for many p53 target genes and p53-dependent processes.

Standard name | BRUINS_UVC_RESPONSE_VIA_TP53_GROUP_B
Systematic name | M2244
Organism | Mus musculus
PMID | 18195040
Authors | Bruins W,Bruning O,Jonker MJ,Zwart E,van der Hoeven TV,Pennings JL,Rauwerda H,de Vries A,Breit TM
Category | C2
Sub-category | CGP
Brief description | Category B genes: p53-dependent genes whose expression in the absence of S389 phosphorylation is dissimilar to loss of TP53 [GeneID=7157] in MEF (embryonic fibroblast) cells in response to UV-C irradiation.
Full description | Phosphorylation is important in p53-mediated DNA damage responses. After UV irradiation, p53 is phosphorylated specifically at murine residue Ser389. Phosphorylation mutant p53.S389A cells and mice show reduced apoptosis and compromised tumor suppression after UV irradiation. We investigated the underlying cellular processes by time-series analysis of UV-induced gene expression responses in wild-type, p53.S389A, and p53(-/-) mouse embryonic fibroblasts. The absence of p53.S389 phosphorylation already causes small endogenous gene expression changes for 2,253, mostly p53-dependent, genes. These genes showed basal gene expression levels intermediate to the wild type and p53(-/-), possibly to readjust the p53 network. Overall, the p53.S389A mutation lifts p53-dependent gene repression to a level similar to that of p53(-/-) but has lesser effect on p53-dependently induced genes. In the wild type, the response of 6,058 genes to UV irradiation was strictly biphasic. The early stress response, from 0 to 3 h, results in the activation of processes to prevent the accumulation of DNA damage in cells, whereas the late response, from 12 to 24 h, relates more to reentering the cell cycle. Although the p53.S389A UV gene response was only subtly changed, many cellular processes were significantly affected. The early response was affected the most, and many cellular processes were phase-specifically lost, gained, or altered, e.g., induction of apoptosis, cell division, and DNA repair, respectively. Altogether, p53.S389 phosphorylation seems essential for many p53 target genes and p53-dependent processes.

Standard name | BRUINS_UVC_RESPONSE_VIA_TP53_GROUP_C
Systematic name | M2245
Organism | Mus musculus
PMID | 18195040
Authors | Bruins W,Bruning O,Jonker MJ,Zwart E,van der Hoeven TV,Pennings JL,Rauwerda H,de Vries A,Breit TM
Category | C2
Sub-category | CGP
Brief description | Category C genes: p53-independent genes whose expression in the absence of S389 phosphorylation is dissimilar to loss of TP53 [GeneID=7157] in MEF (embryonic fibroblast) cells in response to UV-C irradiation.
Full description | Phosphorylation is important in p53-mediated DNA damage responses. After UV irradiation, p53 is phosphorylated specifically at murine residue Ser389. Phosphorylation mutant p53.S389A cells and mice show reduced apoptosis and compromised tumor suppression after UV irradiation. We investigated the underlying cellular processes by time-series analysis of UV-induced gene expression responses in wild-type, p53.S389A, and p53(-/-) mouse embryonic fibroblasts. The absence of p53.S389 phosphorylation already causes small endogenous gene expression changes for 2,253, mostly p53-dependent, genes. These genes showed basal gene expression levels intermediate to the wild type and p53(-/-), possibly to readjust the p53 network. Overall, the p53.S389A mutation lifts p53-dependent gene repression to a level similar to that of p53(-/-) but has lesser effect on p53-dependently induced genes. In the wild type, the response of 6,058 genes to UV irradiation was strictly biphasic. The early stress response, from 0 to 3 h, results in the activation of processes to prevent the accumulation of DNA damage in cells, whereas the late response, from 12 to 24 h, relates more to reentering the cell cycle. Although the p53.S389A UV gene response was only subtly changed, many cellular processes were significantly affected. The early response was affected the most, and many cellular processes were phase-specifically lost, gained, or altered, e.g., induction of apoptosis, cell division, and DNA repair, respectively. Altogether, p53.S389 phosphorylation seems essential for many p53 target genes and p53-dependent processes.

Standard name | BRUINS_UVC_RESPONSE_VIA_TP53_GROUP_D
Systematic name | M2246
Organism | Mus musculus
PMID | 18195040
Authors | Bruins W,Bruning O,Jonker MJ,Zwart E,van der Hoeven TV,Pennings JL,Rauwerda H,de Vries A,Breit TM
Category | C2
Sub-category | CGP
Brief description | Category D genes: p53-independent genes whose expression in the absence of S389 phosphorylation is similar to loss of TP53 [GeneID=7157] in MEF (embryonic fibroblast) cells in response to UV-C irradiation.
Full description | Phosphorylation is important in p53-mediated DNA damage responses. After UV irradiation, p53 is phosphorylated specifically at murine residue Ser389. Phosphorylation mutant p53.S389A cells and mice show reduced apoptosis and compromised tumor suppression after UV irradiation. We investigated the underlying cellular processes by time-series analysis of UV-induced gene expression responses in wild-type, p53.S389A, and p53(-/-) mouse embryonic fibroblasts. The absence of p53.S389 phosphorylation already causes small endogenous gene expression changes for 2,253, mostly p53-dependent, genes. These genes showed basal gene expression levels intermediate to the wild type and p53(-/-), possibly to readjust the p53 network. Overall, the p53.S389A mutation lifts p53-dependent gene repression to a level similar to that of p53(-/-) but has lesser effect on p53-dependently induced genes. In the wild type, the response of 6,058 genes to UV irradiation was strictly biphasic. The early stress response, from 0 to 3 h, results in the activation of processes to prevent the accumulation of DNA damage in cells, whereas the late response, from 12 to 24 h, relates more to reentering the cell cycle. Although the p53.S389A UV gene response was only subtly changed, many cellular processes were significantly affected. The early response was affected the most, and many cellular processes were phase-specifically lost, gained, or altered, e.g., induction of apoptosis, cell division, and DNA repair, respectively. Altogether, p53.S389 phosphorylation seems essential for many p53 target genes and p53-dependent processes.

Standard name | BRUINS_UVC_RESPONSE_LATE
Systematic name | M2247
Organism | Mus musculus
PMID | 18195040
Authors | Bruins W,Bruning O,Jonker MJ,Zwart E,van der Hoeven TV,Pennings JL,Rauwerda H,de Vries A,Breit TM
Category | C2
Sub-category | CGP
Brief description | Late response genes: differentially expressed only 12 h after UV-C irradiation of MEF cells (embryonic fibroblast).
Full description | Phosphorylation is important in p53-mediated DNA damage responses. After UV irradiation, p53 is phosphorylated specifically at murine residue Ser389. Phosphorylation mutant p53.S389A cells and mice show reduced apoptosis and compromised tumor suppression after UV irradiation. We investigated the underlying cellular processes by time-series analysis of UV-induced gene expression responses in wild-type, p53.S389A, and p53(-/-) mouse embryonic fibroblasts. The absence of p53.S389 phosphorylation already causes small endogenous gene expression changes for 2,253, mostly p53-dependent, genes. These genes showed basal gene expression levels intermediate to the wild type and p53(-/-), possibly to readjust the p53 network. Overall, the p53.S389A mutation lifts p53-dependent gene repression to a level similar to that of p53(-/-) but has lesser effect on p53-dependently induced genes. In the wild type, the response of 6,058 genes to UV irradiation was strictly biphasic. The early stress response, from 0 to 3 h, results in the activation of processes to prevent the accumulation of DNA damage in cells, whereas the late response, from 12 to 24 h, relates more to reentering the cell cycle. Although the p53.S389A UV gene response was only subtly changed, many cellular processes were significantly affected. The early response was affected the most, and many cellular processes were phase-specifically lost, gained, or altered, e.g., induction of apoptosis, cell division, and DNA repair, respectively. Altogether, p53.S389 phosphorylation seems essential for many p53 target genes and p53-dependent processes.

Standard name | BRUINS_UVC_RESPONSE_EARLY_LATE
Systematic name | M2248
Organism | Mus musculus
PMID | 18195040
Authors | Bruins W,Bruning O,Jonker MJ,Zwart E,van der Hoeven TV,Pennings JL,Rauwerda H,de Vries A,Breit TM
Category | C2
Sub-category | CGP
Brief description | Early-late response genes: differentially expressed in the first 3 h and after 12 h following UV-C irradiation of MEF cells (embryonic fibroblast).
Full description | Phosphorylation is important in p53-mediated DNA damage responses. After UV irradiation, p53 is phosphorylated specifically at murine residue Ser389. Phosphorylation mutant p53.S389A cells and mice show reduced apoptosis and compromised tumor suppression after UV irradiation. We investigated the underlying cellular processes by time-series analysis of UV-induced gene expression responses in wild-type, p53.S389A, and p53(-/-) mouse embryonic fibroblasts. The absence of p53.S389 phosphorylation already causes small endogenous gene expression changes for 2,253, mostly p53-dependent, genes. These genes showed basal gene expression levels intermediate to the wild type and p53(-/-), possibly to readjust the p53 network. Overall, the p53.S389A mutation lifts p53-dependent gene repression to a level similar to that of p53(-/-) but has lesser effect on p53-dependently induced genes. In the wild type, the response of 6,058 genes to UV irradiation was strictly biphasic. The early stress response, from 0 to 3 h, results in the activation of processes to prevent the accumulation of DNA damage in cells, whereas the late response, from 12 to 24 h, relates more to reentering the cell cycle. Although the p53.S389A UV gene response was only subtly changed, many cellular processes were significantly affected. The early response was affected the most, and many cellular processes were phase-specifically lost, gained, or altered, e.g., induction of apoptosis, cell division, and DNA repair, respectively. Altogether, p53.S389 phosphorylation seems essential for many p53 target genes and p53-dependent processes.

Standard name | BRUINS_UVC_RESPONSE_MIDDLE
Systematic name | M2249
Organism | Mus musculus
PMID | 18195040
Authors | Bruins W,Bruning O,Jonker MJ,Zwart E,van der Hoeven TV,Pennings JL,Rauwerda H,de Vries A,Breit TM
Category | C2
Sub-category | CGP
Brief description | Middle response genes: differentially expressed in the period between 3 h and 12 h after UV-C irradiation of MEF cells (embryonic fibroblast).
Full description | Phosphorylation is important in p53-mediated DNA damage responses. After UV irradiation, p53 is phosphorylated specifically at murine residue Ser389. Phosphorylation mutant p53.S389A cells and mice show reduced apoptosis and compromised tumor suppression after UV irradiation. We investigated the underlying cellular processes by time-series analysis of UV-induced gene expression responses in wild-type, p53.S389A, and p53(-/-) mouse embryonic fibroblasts. The absence of p53.S389 phosphorylation already causes small endogenous gene expression changes for 2,253, mostly p53-dependent, genes. These genes showed basal gene expression levels intermediate to the wild type and p53(-/-), possibly to readjust the p53 network. Overall, the p53.S389A mutation lifts p53-dependent gene repression to a level similar to that of p53(-/-) but has lesser effect on p53-dependently induced genes. In the wild type, the response of 6,058 genes to UV irradiation was strictly biphasic. The early stress response, from 0 to 3 h, results in the activation of processes to prevent the accumulation of DNA damage in cells, whereas the late response, from 12 to 24 h, relates more to reentering the cell cycle. Although the p53.S389A UV gene response was only subtly changed, many cellular processes were significantly affected. The early response was affected the most, and many cellular processes were phase-specifically lost, gained, or altered, e.g., induction of apoptosis, cell division, and DNA repair, respectively. Altogether, p53.S389 phosphorylation seems essential for many p53 target genes and p53-dependent processes.

Standard name | CERIBELLI_PROMOTERS_INACTIVE_AND_BOUND_BY_NFY
Systematic name | M2252
Organism | Homo sapiens
PMID | 18212061
Authors | Ceribelli M,Dolfini D,Merico D,Gatta R,Viganò AM,Pavesi G,Mantovani R
Category | C2
Sub-category | CGP
Brief description | Transcriptionally inactive genes whose promoters (regions between -2 kb to +0.5 kb relative to trascription start sites) where bound by NF-Y transcription factor.
Full description | NF-Y is a trimeric transcription factor containing H2A/H2B-like subunits, which specifically binds to the CCAAT box, a common eukaryotic promoter element. To gain insights into NF-Y-dependent transcriptional regulation, we assessed its relationships with positive histone marks by chromatin immunoprecipitation-on-chip and correlative-profiling studies. Unbiased identification of binding sites shows that the majority of genes are bound by NF-Y in the promoter and/or within the coding region. Parallel analysis of H3K9-14ac and H3K4me3 sites indicates that NF-Y loci can be divided in two distinct clusters: (i) a large cohort contains H3K9-14ac and H3K4me3 marks and correlates with expression and (ii) a sizeable group is devoid of these marks and is found on transcriptionally silent genes. Within this class, we find that NF-Y binding is associated with negative histone marks, such as H4K20me3 and H3K27me3. NF-Y removal by a dominant negative NF-YA leads to a decrease in the transcription of expressed genes associated with H3K4me3 and H3K9-14ac, while increasing the levels of many inactive genes. These data indicate that NF-Y is embedded in positive as well as in negative methyl histone marks, serving a dual function in transcriptional regulation, as an activator or as a repressor.

Standard name | CERIBELLI_GENES_INACTIVE_AND_BOUND_BY_NFY
Systematic name | M2254
Organism | Homo sapiens
PMID | 18212061
Authors | Ceribelli M,Dolfini D,Merico D,Gatta R,Viganò AM,Pavesi G,Mantovani R
Category | C2
Sub-category | CGP
Brief description | Transcriptionally inactive genes which where bound by NF-Y transcription factor.
Full description | NF-Y is a trimeric transcription factor containing H2A/H2B-like subunits, which specifically binds to the CCAAT box, a common eukaryotic promoter element. To gain insights into NF-Y-dependent transcriptional regulation, we assessed its relationships with positive histone marks by chromatin immunoprecipitation-on-chip and correlative-profiling studies. Unbiased identification of binding sites shows that the majority of genes are bound by NF-Y in the promoter and/or within the coding region. Parallel analysis of H3K9-14ac and H3K4me3 sites indicates that NF-Y loci can be divided in two distinct clusters: (i) a large cohort contains H3K9-14ac and H3K4me3 marks and correlates with expression and (ii) a sizeable group is devoid of these marks and is found on transcriptionally silent genes. Within this class, we find that NF-Y binding is associated with negative histone marks, such as H4K20me3 and H3K27me3. NF-Y removal by a dominant negative NF-YA leads to a decrease in the transcription of expressed genes associated with H3K4me3 and H3K9-14ac, while increasing the levels of many inactive genes. These data indicate that NF-Y is embedded in positive as well as in negative methyl histone marks, serving a dual function in transcriptional regulation, as an activator or as a repressor.

Standard name | MIYAGAWA_TARGETS_OF_EWSR1_ETS_FUSIONS_UP
Systematic name | M2255
Organism | Homo sapiens
PMID | 18212050
Authors | Miyagawa Y,Okita H,Nakaijima H,Horiuchi Y,Sato B,Taguchi T,Toyoda M,Katagiri YU,Fujimoto J,Hata J,Umezawa A,Kiyokawa N
Category | C2
Sub-category | CGP
Brief description | Genes commonly up-regulated in UET-13 cells (mesenchymal progenitor) by expression of EWSR1 [GeneID=2130] fusions with ETS transcription factors FLI1 and ERG [GeneID=2313 ,2078].
Full description | Ewing's family tumor (EFT) is a rare pediatric tumor of unclear origin that occurs in bone and soft tissue. Specific chromosomal translocations found in EFT cause EWS to fuse to a subset of ets transcription factor genes (ETS), generating chimeric EWS/ETS proteins. These proteins are believed to play a crucial role in the onset and progression of EFT. However, the mechanisms responsible for the EWS/ETS-mediated onset remain unclear. Here we report the establishment of a tetracycline-controlled EWS/ETS-inducible system in human bone marrow-derived mesenchymal progenitor cells (MPCs). Ectopic expression of both EWS/FLI1 and EWS/ERG proteins resulted in a dramatic change of morphology, i.e., from a mesenchymal spindle shape to a small round-to-polygonal cell, one of the characteristics of EFT. EWS/ETS also induced immunophenotypic changes in MPCs, including the disappearance of the mesenchyme-positive markers CD10 and CD13 and the up-regulation of the EFT-positive markers CD54, CD99, CD117, and CD271. Furthermore, a prominent shift from the gene expression profile of MPCs to that of EFT was observed in the presence of EWS/ETS. Together with the observation that EWS/ETS enhances the ability of cells to invade Matrigel, these results suggest that EWS/ETS proteins contribute to alterations of cellular features and confer an EFT-like phenotype to human MPCs.

Standard name | MIYAGAWA_TARGETS_OF_EWSR1_ETS_FUSIONS_DN
Systematic name | M2256
Organism | Homo sapiens
PMID | 18212050
Authors | Miyagawa Y,Okita H,Nakaijima H,Horiuchi Y,Sato B,Taguchi T,Toyoda M,Katagiri YU,Fujimoto J,Hata J,Umezawa A,Kiyokawa N
Category | C2
Sub-category | CGP
Brief description | Genes commonly down-regulated in UET-13 cells (mesenchymal progenitor) by expression of EWSR1 [GeneID=2130] fusions with ETS transcription factors FLI1 and ERG [GeneID=2313 ,2078].
Full description | Ewing's family tumor (EFT) is a rare pediatric tumor of unclear origin that occurs in bone and soft tissue. Specific chromosomal translocations found in EFT cause EWS to fuse to a subset of ets transcription factor genes (ETS), generating chimeric EWS/ETS proteins. These proteins are believed to play a crucial role in the onset and progression of EFT. However, the mechanisms responsible for the EWS/ETS-mediated onset remain unclear. Here we report the establishment of a tetracycline-controlled EWS/ETS-inducible system in human bone marrow-derived mesenchymal progenitor cells (MPCs). Ectopic expression of both EWS/FLI1 and EWS/ERG proteins resulted in a dramatic change of morphology, i.e., from a mesenchymal spindle shape to a small round-to-polygonal cell, one of the characteristics of EFT. EWS/ETS also induced immunophenotypic changes in MPCs, including the disappearance of the mesenchyme-positive markers CD10 and CD13 and the up-regulation of the EFT-positive markers CD54, CD99, CD117, and CD271. Furthermore, a prominent shift from the gene expression profile of MPCs to that of EFT was observed in the presence of EWS/ETS. Together with the observation that EWS/ETS enhances the ability of cells to invade Matrigel, these results suggest that EWS/ETS proteins contribute to alterations of cellular features and confer an EFT-like phenotype to human MPCs.

Standard name | IVANOVSKA_MIR106B_TARGETS
Systematic name | M2258
Organism | Homo sapiens
PMID | 18212054
Authors | Ivanovska I,Ball AS,Diaz RL,Magnus JF,Kibukawa M,Schelter JM,Kobayashi SV,Lim L,Burchard J,Jackson AL,Linsley PS,Cleary MA
Category | C2
Sub-category | CGP
Brief description | A consensus set of genes that were significantly down-regulated by MIR106B [GeneID=406900].
Full description | microRNAs in the miR-106b family are overexpressed in multiple tumor types and are correlated with the expression of genes that regulate the cell cycle. Consistent with these observations, miR-106b family gain of function promotes cell cycle progression, whereas loss of function reverses this phenotype. Microarray profiling uncovers multiple targets of the family, including the cyclin-dependent kinase inhibitor p21/CDKN1A. We show that p21 is a direct target of miR-106b and that its silencing plays a key role in miR-106b-induced cell cycle phenotypes. We also show that miR-106b overrides a doxorubicin-induced DNA damage checkpoint. Thus, miR-106b family members contribute to tumor cell proliferation in part by regulating cell cycle progression and by modulating checkpoint functions.

Standard name | KIM_GLIS2_TARGETS_UP
Systematic name | M2259
Organism | Mus musculus
PMID | 18227149
Authors | Kim YS,Kang HS,Herbert R,Beak JY,Collins JB,Grissom SF,Jetten AM
Category | C2
Sub-category | CGP
Brief description | Partial list of genes up-regulated in the kidney of GLIS2 [GeneID=84662] knockout mice compared to the wild type.
Full description | To obtain insight into the physiological functions of the Krüppel-like zinc finger protein Gli-similar 2 (Glis2), mice deficient in Glis2 expression were generated. Glis2 mutant (Glis2(mut)) mice exhibit significantly shorter life spans than do littermate wild-type (WT) mice due to the development of progressive chronic kidney disease with features resembling nephronophthisis. Glis2(mut) mice develop severe renal atrophy involving increased cell death and basement membrane thickening in the proximal convoluted tubules. This development is accompanied by infiltration of lymphocytic inflammatory cells and interstitial/glomerular fibrosis. The severity of the fibrosis, inflammatory infiltrates, and glomerular and tubular changes progresses with age. Blood urea nitrogen and creatinine increase, and Glis2(mut) mice develop proteinuria and ultimately die prematurely of renal failure. A comparison of the gene expression profiles of kidneys from 25-day-old/60-day-old WT and Glis2(mut) mice by microarray analysis showed increased expressions of many genes involved in immune responses/inflammation and fibrosis/tissue remodeling in kidneys of Glis2(mut) mice, including several cytokines and adhesion and extracellular matrix proteins. Our data demonstrate that a deficiency in Glis2 expression leads to tubular atrophy and progressive fibrosis, similar to nephronophthisis, that ultimately results in renal failure. Our study indicates that Glis2 plays a critical role in the maintenance of normal kidney architecture and functions.

Standard name | KIM_GLIS2_TARGETS_DN
Systematic name | M2262
Organism | Mus musculus
PMID | 18227149
Authors | Kim YS,Kang HS,Herbert R,Beak JY,Collins JB,Grissom SF,Jetten AM
Category | C2
Sub-category | CGP
Brief description | Partial list of genes down-regulated in the kidney of GLIS2 [GeneID=84662] knockout mice compared to the wild type.
Full description | To obtain insight into the physiological functions of the Krüppel-like zinc finger protein Gli-similar 2 (Glis2), mice deficient in Glis2 expression were generated. Glis2 mutant (Glis2(mut)) mice exhibit significantly shorter life spans than do littermate wild-type (WT) mice due to the development of progressive chronic kidney disease with features resembling nephronophthisis. Glis2(mut) mice develop severe renal atrophy involving increased cell death and basement membrane thickening in the proximal convoluted tubules. This development is accompanied by infiltration of lymphocytic inflammatory cells and interstitial/glomerular fibrosis. The severity of the fibrosis, inflammatory infiltrates, and glomerular and tubular changes progresses with age. Blood urea nitrogen and creatinine increase, and Glis2(mut) mice develop proteinuria and ultimately die prematurely of renal failure. A comparison of the gene expression profiles of kidneys from 25-day-old/60-day-old WT and Glis2(mut) mice by microarray analysis showed increased expressions of many genes involved in immune responses/inflammation and fibrosis/tissue remodeling in kidneys of Glis2(mut) mice, including several cytokines and adhesion and extracellular matrix proteins. Our data demonstrate that a deficiency in Glis2 expression leads to tubular atrophy and progressive fibrosis, similar to nephronophthisis, that ultimately results in renal failure. Our study indicates that Glis2 plays a critical role in the maintenance of normal kidney architecture and functions.

Standard name | MIKHAYLOVA_OXIDATIVE_STRESS_RESPONSE_VIA_VHL_UP
Systematic name | M2263
Organism | Homo sapiens
PMID | 18285459
Authors | Mikhaylova O,Ignacak ML,Barankiewicz TJ,Harbaugh SV,Yi Y,Maxwell PH,Schneider M,Van Geyte K,Carmeliet P,Revelo MP,Wyder M,Greis KD,Meller J,Czyzyk-Krzeska MF
Category | C2
Sub-category | CGP
Brief description | Proteins significantly induced by oxidative stress (hydrogen peroxide [PubChem=784] in 786-O cells (renal clear cell carcinoma, RCC) expressing VHL [GeneID=7428].
Full description | Human renal clear cell carcinoma (RCC) is frequently associated with loss of the von Hippel-Lindau (VHL) tumor suppressor (pVHL), which inhibits ubiquitylation and degradation of the alpha subunits of hypoxia-inducible transcription factor. pVHL also ubiquitylates the large subunit of RNA polymerase II, Rpb1, phosphorylated on serine 5 (Ser5) within the C-terminal domain (CTD). A hydroxylated proline 1465 within an LXXLAP motif located N-terminal to the CTD allows the interaction of Rpb1 with pVHL. Here we report that in RCC cells, pVHL regulates expression of Rpb1 and is necessary for low-grade oxidative-stress-induced recruitment of Rpb1 to the DNA-engaged fraction and for its P1465 hydroxylation, phosphorylation, and nondegradative ubiquitylation. Egln-9-type prolyl hydroxylases, PHD1 and PHD2, coimmunoprecipitated with Rpb1 in the chromatin fraction of VHL(+) RCC cells in response to oxidative stress, and PHD1 was necessary for P1465 hydroxylation while PHD2 had an inhibitory effect. P1465 hydroxylation was required for oxidative-stress-induced Ser5 phosphorylation of Rpb1. Importantly, overexpression of wild-type Rpb1 stimulated formation of kidney tumors by VHL(+) cells, and this effect was abolished by P1465A mutation of Rpb1. These data indicate that through this novel pathway involving P1465 hydroxylation and Ser5 phosphorylation of Rbp1, pVHL may regulate tumor growth.

Standard name | MIKHAYLOVA_OXIDATIVE_STRESS_RESPONSE_VIA_VHL_DN
Systematic name | M2269
Organism | Homo sapiens
PMID | 18285459
Authors | Mikhaylova O,Ignacak ML,Barankiewicz TJ,Harbaugh SV,Yi Y,Maxwell PH,Schneider M,Van Geyte K,Carmeliet P,Revelo MP,Wyder M,Greis KD,Meller J,Czyzyk-Krzeska MF
Category | C2
Sub-category | CGP
Brief description | Proteins significantly repressed by oxidative stress (hydrogen peroxide [PubChem=784] in 786-O cells (renal clear cell carcinoma, RCC) expressing VHL [GeneID=7428].
Full description | Human renal clear cell carcinoma (RCC) is frequently associated with loss of the von Hippel-Lindau (VHL) tumor suppressor (pVHL), which inhibits ubiquitylation and degradation of the alpha subunits of hypoxia-inducible transcription factor. pVHL also ubiquitylates the large subunit of RNA polymerase II, Rpb1, phosphorylated on serine 5 (Ser5) within the C-terminal domain (CTD). A hydroxylated proline 1465 within an LXXLAP motif located N-terminal to the CTD allows the interaction of Rpb1 with pVHL. Here we report that in RCC cells, pVHL regulates expression of Rpb1 and is necessary for low-grade oxidative-stress-induced recruitment of Rpb1 to the DNA-engaged fraction and for its P1465 hydroxylation, phosphorylation, and nondegradative ubiquitylation. Egln-9-type prolyl hydroxylases, PHD1 and PHD2, coimmunoprecipitated with Rpb1 in the chromatin fraction of VHL(+) RCC cells in response to oxidative stress, and PHD1 was necessary for P1465 hydroxylation while PHD2 had an inhibitory effect. P1465 hydroxylation was required for oxidative-stress-induced Ser5 phosphorylation of Rpb1. Importantly, overexpression of wild-type Rpb1 stimulated formation of kidney tumors by VHL(+) cells, and this effect was abolished by P1465A mutation of Rpb1. These data indicate that through this novel pathway involving P1465 hydroxylation and Ser5 phosphorylation of Rbp1, pVHL may regulate tumor growth.

Standard name | STEGER_ADIPOGENESIS_UP
Systematic name | M2270
Organism | Mus musculus
PMID | 18285465
Authors | Steger DJ,Lefterova MI,Ying L,Stonestrom AJ,Schupp M,Zhuo D,Vakoc AL,Kim JE,Chen J,Lazar MA,Blobel GA,Vakoc CR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during adipogenesis of 3T3-L1 cells (fibroblast).
Full description | The histone H3 lysine 79 methyltransferase DOT1L/KMT4 can promote an oncogenic pattern of gene expression through binding with several MLL fusion partners found in acute leukemia. However, the normal function of DOT1L in mammalian gene regulation is poorly understood. Here we report that DOT1L recruitment is ubiquitously coupled with active transcription in diverse mammalian cell types. DOT1L preferentially occupies the proximal transcribed region of active genes, correlating with enrichment of H3K79 di- and trimethylation. Furthermore, Dot1l mutant fibroblasts lacked H3K79 di- and trimethylation at all sites examined, indicating that DOT1L is the sole enzyme responsible for these marks. Importantly, we identified chromatin immunoprecipitation (ChIP) assay conditions necessary for reliable H3K79 methylation detection. ChIP-chip tiling arrays revealed that levels of all degrees of genic H3K79 methylation correlate with mRNA abundance and dynamically respond to changes in gene activity. Conversion of H3K79 monomethylation into di- and trimethylation correlated with the transition from low- to high-level gene transcription. We also observed enrichment of H3K79 monomethylation at intergenic regions occupied by DNA-binding transcriptional activators. Our findings highlight several similarities between the patterning of H3K4 methylation and that of H3K79 methylation in mammalian chromatin, suggesting a widespread mechanism for parallel or sequential recruitment of DOT1L and MLL to genes in their normal on state.

Standard name | STEGER_ADIPOGENESIS_DN
Systematic name | M2271
Organism | Mus musculus
PMID | 18285465
Authors | Steger DJ,Lefterova MI,Ying L,Stonestrom AJ,Schupp M,Zhuo D,Vakoc AL,Kim JE,Chen J,Lazar MA,Blobel GA,Vakoc CR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during adipogenesis of 3T3-L1 cells (fibroblast).
Full description | The histone H3 lysine 79 methyltransferase DOT1L/KMT4 can promote an oncogenic pattern of gene expression through binding with several MLL fusion partners found in acute leukemia. However, the normal function of DOT1L in mammalian gene regulation is poorly understood. Here we report that DOT1L recruitment is ubiquitously coupled with active transcription in diverse mammalian cell types. DOT1L preferentially occupies the proximal transcribed region of active genes, correlating with enrichment of H3K79 di- and trimethylation. Furthermore, Dot1l mutant fibroblasts lacked H3K79 di- and trimethylation at all sites examined, indicating that DOT1L is the sole enzyme responsible for these marks. Importantly, we identified chromatin immunoprecipitation (ChIP) assay conditions necessary for reliable H3K79 methylation detection. ChIP-chip tiling arrays revealed that levels of all degrees of genic H3K79 methylation correlate with mRNA abundance and dynamically respond to changes in gene activity. Conversion of H3K79 monomethylation into di- and trimethylation correlated with the transition from low- to high-level gene transcription. We also observed enrichment of H3K79 monomethylation at intergenic regions occupied by DNA-binding transcriptional activators. Our findings highlight several similarities between the patterning of H3K4 methylation and that of H3K79 methylation in mammalian chromatin, suggesting a widespread mechanism for parallel or sequential recruitment of DOT1L and MLL to genes in their normal on state.

Standard name | ZHU_SKIL_TARGETS_UP
Systematic name | M2273
Organism | Homo sapiens
PMID | 17074815
Authors | Zhu Q,Krakowski AR,Dunham EE,Wang L,Bandyopadhyay A,Berdeaux R,Martin GS,Sun L,Luo K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in A549 cells (lung adenocarcinoma) upon SKIL [GeneID=6498] knockdown by RNAi.
Full description | SnoN is an important negative regulator of transforming growth factor beta signaling through its ability to interact with and repress the activity of Smad proteins. It was originally identified as an oncoprotein based on its ability to induce anchorage-independent growth in chicken embryo fibroblasts. However, the roles of SnoN in mammalian epithelial carcinogenesis have not been well defined. Here we show for the first time that SnoN plays an important but complex role in human cancer. SnoN expression is highly elevated in many human cancer cell lines, and this high level of SnoN promotes mitogenic transformation of breast and lung cancer cell lines in vitro and tumor growth in vivo, consistent with its proposed pro-oncogenic role. However, this high level of SnoN expression also inhibits epithelial-to-mesenchymal transdifferentiation. Breast and lung cancer cells expressing the shRNA for SnoN exhibited an increase in cell motility, actin stress fiber formation, metalloprotease activity, and extracellular matrix production as well as a reduction in adherens junction proteins. Supporting this observation, in an in vivo breast cancer metastasis model, reducing SnoN expression was found to moderately enhance metastasis of human breast cancer cells to bone and lung. Thus, SnoN plays both pro-tumorigenic and antitumorigenic roles at different stages of mammalian malignant progression. The growth-promoting activity of SnoN appears to require its ability to bind to and repress the Smad proteins, while the antitumorigenic activity can be mediated by both Smad-dependent and Smad-independent pathways and requires the activity of small GTPase RhoA. Our study has established the importance of SnoN in mammalian epithelial carcinogenesis and revealed a novel aspect of SnoN function in malignant progression.

Standard name | ZHU_SKIL_TARGETS_DN
Systematic name | M2275
Organism | Homo sapiens
PMID | 17074815
Authors | Zhu Q,Krakowski AR,Dunham EE,Wang L,Bandyopadhyay A,Berdeaux R,Martin GS,Sun L,Luo K
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in A549 cells (lung adenocarcinoma) upon SKIL [GeneID=6498] knockdown by RNAi.
Full description | SnoN is an important negative regulator of transforming growth factor beta signaling through its ability to interact with and repress the activity of Smad proteins. It was originally identified as an oncoprotein based on its ability to induce anchorage-independent growth in chicken embryo fibroblasts. However, the roles of SnoN in mammalian epithelial carcinogenesis have not been well defined. Here we show for the first time that SnoN plays an important but complex role in human cancer. SnoN expression is highly elevated in many human cancer cell lines, and this high level of SnoN promotes mitogenic transformation of breast and lung cancer cell lines in vitro and tumor growth in vivo, consistent with its proposed pro-oncogenic role. However, this high level of SnoN expression also inhibits epithelial-to-mesenchymal transdifferentiation. Breast and lung cancer cells expressing the shRNA for SnoN exhibited an increase in cell motility, actin stress fiber formation, metalloprotease activity, and extracellular matrix production as well as a reduction in adherens junction proteins. Supporting this observation, in an in vivo breast cancer metastasis model, reducing SnoN expression was found to moderately enhance metastasis of human breast cancer cells to bone and lung. Thus, SnoN plays both pro-tumorigenic and antitumorigenic roles at different stages of mammalian malignant progression. The growth-promoting activity of SnoN appears to require its ability to bind to and repress the Smad proteins, while the antitumorigenic activity can be mediated by both Smad-dependent and Smad-independent pathways and requires the activity of small GTPase RhoA. Our study has established the importance of SnoN in mammalian epithelial carcinogenesis and revealed a novel aspect of SnoN function in malignant progression.

Standard name | KIM_PTEN_TARGETS_UP
Systematic name | M2276
Organism | Homo sapiens
PMID | 17060456
Authors | Kim JS,Lee C,Bonifant CL,Ressom H,Waldman T
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HCT116 cells (colorectal carcinoma) upon knockout of PTEN [GeneID=5728].
Full description | In an effort to identify genes whose expression is regulated by activated phosphatidylinositol 3-kinase (PI3K) signaling, we performed microarray analysis and subsequent quantitative reverse transcription-PCR on an isogenic set of PTEN gene-targeted human cancer cells. Numerous p53 effectors were upregulated following PTEN deletion, including p21, GDF15, PIG3, NOXA, and PLK2. Stable depletion of p53 led to reversion of the gene expression program. Western blots revealed that p53 was stabilized in HCT116 PTEN(-/-) cells via an Akt1-dependent and p14(ARF)-independent mechanism. Stable depletion of PTEN in untransformed human fibroblasts and epithelial cells also led to upregulation of p53 and senescence-like growth arrest. Simultaneous depletion of p53 rescued this phenotype, enabling PTEN-depleted cells to continue proliferating. Next, we tested whether oncogenic PIK3CA, like inactivated PTEN, could activate p53. Retroviral expression of oncogenic human PIK3CA in MCF10A cells led to activation of p53 and upregulation of p53-regulated genes. Stable depletion of p53 reversed these PIK3CA-induced expression changes and synergized with oncogenic PIK3CA in inducing anchorage-independent growth. Finally, targeted deletion of an endogenous allele of oncogenic, but not wild-type, PIK3CA in a human cancer cell line led to a reduction in p53 levels and a decrease in the expression of p53-regulated genes. These studies demonstrate that activation of PI3K signaling by mutations in PTEN or PIK3CA can lead to activation of p53-mediated growth suppression in human cells, indicating that p53 can function as a brake on phosphatidylinositol (3,4,5)-triphosphate-induced mitogenesis during human cancer pathogenesis.

Standard name | KIM_PTEN_TARGETS_DN
Systematic name | M2277
Organism | Homo sapiens
PMID | 17060456
Authors | Kim JS,Lee C,Bonifant CL,Ressom H,Waldman T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HCT116 cells (colorectal carcinoma) upon knockout of PTEN [GeneID=5728].
Full description | In an effort to identify genes whose expression is regulated by activated phosphatidylinositol 3-kinase (PI3K) signaling, we performed microarray analysis and subsequent quantitative reverse transcription-PCR on an isogenic set of PTEN gene-targeted human cancer cells. Numerous p53 effectors were upregulated following PTEN deletion, including p21, GDF15, PIG3, NOXA, and PLK2. Stable depletion of p53 led to reversion of the gene expression program. Western blots revealed that p53 was stabilized in HCT116 PTEN(-/-) cells via an Akt1-dependent and p14(ARF)-independent mechanism. Stable depletion of PTEN in untransformed human fibroblasts and epithelial cells also led to upregulation of p53 and senescence-like growth arrest. Simultaneous depletion of p53 rescued this phenotype, enabling PTEN-depleted cells to continue proliferating. Next, we tested whether oncogenic PIK3CA, like inactivated PTEN, could activate p53. Retroviral expression of oncogenic human PIK3CA in MCF10A cells led to activation of p53 and upregulation of p53-regulated genes. Stable depletion of p53 reversed these PIK3CA-induced expression changes and synergized with oncogenic PIK3CA in inducing anchorage-independent growth. Finally, targeted deletion of an endogenous allele of oncogenic, but not wild-type, PIK3CA in a human cancer cell line led to a reduction in p53 levels and a decrease in the expression of p53-regulated genes. These studies demonstrate that activation of PI3K signaling by mutations in PTEN or PIK3CA can lead to activation of p53-mediated growth suppression in human cells, indicating that p53 can function as a brake on phosphatidylinositol (3,4,5)-triphosphate-induced mitogenesis during human cancer pathogenesis.

Standard name | ISHIDA_TARGETS_OF_SYT_SSX_FUSIONS
Systematic name | M2278
Organism | Homo sapiens
PMID | 17101797
Authors | Ishida M,Miyamoto M,Naitoh S,Tatsuda D,Hasegawa T,Nemoto T,Yokozeki H,Nishioka K,Matsukage A,Ohki M,Ohta T
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in synovial sarcoma samples with SYT-SSX fusions resulting from translocation of SS18 [GeneID=SS18] to one of the SSX genes.
Full description | Chromosomal translocations are frequently associated with soft-tissue sarcomas. Fusion proteins generated by such translocations often play critical roles in tumorigenesis. Therefore, it is important to understand the function of the fusion protein to develop therapeutic interventions. The t(X;18)(p11.2;q11.2) translocation found in synovial sarcomas results in a fusion between the SYT gene on chromosome 18 and an SSX gene on the X chromosome. Although SYT-SSX fusion proteins appear to trigger synovial sarcoma development, little is known about the downstream targets of SYT-SSX. We found that the SYT-SSX fusion protein produces a dominant-negative function for SYT, which is a transcriptional coactivator. We then analyzed the gene expression profiles of SYT-SSX1-expressing HeLa cells using oligonucleotide microarrays and found that the SYT-SSX1 fusion protein directly down-regulated the expression of COM1, a regulator of cell proliferation. COM1 was found to be expressed at relatively low levels in synovial sarcoma tissues and cell lines. We then investigated the impact of conditional COM1 expression in the synovial sarcoma cell line. Increased COM1 expression resulted in induced apoptosis and in reduced cell growth and colony formation activity. Our results suggested that restoration of COM1 expression may be of therapeutic benefit in synovial sarcoma.

Standard name | MAEKAWA_ATF2_TARGETS
Systematic name | M2279
Organism | Mus musculus
PMID | 17189429
Authors | Maekawa T,Shinagawa T,Sano Y,Sakuma T,Nomura S,Nagasaki K,Miki Y,Saito-Ohara F,Inazawa J,Kohno T,Yokota J,Ishii S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblast) upon knockout of ATF2 [GeneID=1386].
Full description | Transcription factor ATF-2 is a nuclear target of stress-activated protein kinases, such as p38, which are activated by various extracellular stresses, including UV light. Here, we show that ATF-2 plays a critical role in hypoxia- and high-cell-density-induced apoptosis and the development of mammary tumors. Compared to wild-type cells, Atf-2(-/-) mouse embryonic fibroblasts (MEFs) were more resistant to hypoxia- and anisomycin-induced apoptosis but remained equally susceptible to other stresses, including UV. Atf-2(-/-) and Atf-2(+/-) MEFs could not express a group of genes, such as Gadd45alpha, whose overexpression can induce apoptosis, in response to hypoxia. Atf-2(-/-) MEFs also had a higher saturation density than wild-type cells and expressed lower levels of Maspin, the breast cancer tumor suppressor, which is also known to enhance cellular sensitivity to apoptotic stimuli. Atf-2(-/-) MEFs underwent a lower degree of apoptosis at high cell density than wild-type cells. Atf-2(+/-) mice were highly prone to mammary tumors that expressed reduced levels of Gadd45alpha and Maspin. The ATF-2 mRNA levels in human breast cancers were lower than those in normal breast tissue. Thus, ATF-2 acts as a tumor susceptibility gene of mammary tumors, at least partly, by activating a group of target genes, including Maspin and Gadd45alpha.

Standard name | ISSAEVA_MLL2_TARGETS
Systematic name | M2281
Organism | Homo sapiens
PMID | 17178841
Authors | Issaeva I,Zonis Y,Rozovskaia T,Orlovsky K,Croce CM,Nakamura T,Mazo A,Eisenbach L,Canaani E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HeLa cells upon knockdown of MLL2 [GeneID=8085] by RNAi.
Full description | ALR (MLL2) is a member of the human MLL family, which belongs to a larger SET1 family of histone methyltransferases. We found that ALR is present within a stable multiprotein complex containing a cohort of proteins shared with other SET1 family complexes and several unique components, such as PTIP and the jumonji family member UTX. Like other complexes formed by SET1 family members, the ALR complex exhibited strong H3K4 methyltransferase activity, conferred by the ALR SET domain. By generating ALR knockdown cell lines and comparing their expression profiles to that of control cells, we identified a set of genes whose expression is activated by ALR. Some of these genes were identified by chromatin immunoprecipitation as direct ALR targets. The ALR complex was found to associate in an ALR-dependent fashion with promoters and transcription initiation sites of target genes and to induce H3K4 trimethylation. The most characteristic features of the ALR knockdown cells were changes in the dynamics and mode of cell spreading/polarization, reduced migration capacity, impaired anchorage-dependent and -independent growth, and decreased tumorigenicity in mice. Taken together, our results suggest that ALR is a transcriptional activator that induces the transcription of target genes by covalent histone modification. ALR appears to be involved in the regulation of adhesion-related cytoskeletal events, which might affect cell growth and survival.

Standard name | LINSLEY_MIR16_TARGETS
Systematic name | M2284
Organism | Homo sapiens
PMID | 17242205
Authors | Linsley PS,Schelter J,Burchard J,Kibukawa M,Martin MM,Bartz SR,Johnson JM,Cummins JM,Raymond CK,Dai H,Chau N,Cleary M,Jackson AL,Carleton M,Lim L
Category | C2
Sub-category | CGP
Brief description | Transcripts down-regulated by overexpression of MIR16 family of microRNA molecules in DLD-1 and HCT116 (colon cancer) cells hypomorphic for DICER1 [GeneID=23405].
Full description | microRNAs (miRNAs) are abundant, approximately 21-nucleotide, noncoding regulatory RNAs. Each miRNA may regulate hundreds of mRNA targets, but the identities of these targets and the processes they regulate are poorly understood. Here we have explored the use of microarray profiling and functional screening to identify targets and biological processes triggered by the transfection of human cells with miRNAs. We demonstrate that a family of miRNAs sharing sequence identity with miRNA-16 (miR-16) negatively regulates cellular growth and cell cycle progression. miR-16-down-regulated transcripts were enriched with genes whose silencing by small interfering RNAs causes an accumulation of cells in G(0)/G(1). Simultaneous silencing of these genes was more effective at blocking cell cycle progression than disruption of the individual genes. Thus, miR-16 coordinately regulates targets that may act in concert to control cell cycle progression.

Standard name | CHENG_TAF7L_TARGETS
Systematic name | M2285
Organism | Mus musculus
PMID | 17242199
Authors | Cheng Y,Buffone MG,Kouadio M,Goodheart M,Page DC,Gerton GL,Davidson I,Wang PJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in testis tissues upon knockout of TAF7L [GeneID=54457].
Full description | TFIID is a general transcription factor required for transcription of most protein-coding genes by RNA polymerase II. TAF7L is an X-linked germ cell-specific paralogue of TAF7, which is a generally expressed component of TFIID. Here, we report the generation of Taf7l mutant mice by homologous recombination in embryonic stem cells by using the Cre-loxP strategy. While spermatogenesis was completed in Taf7l(-/Y) mice, the weight of Taf7l(-/Y) testis decreased and the amount of sperm in the epididymides was sharply reduced. Mutant epididymal sperm exhibited abnormal morphology, including folded tails. Sperm motility was significantly reduced, and Taf7l(-/Y) males were fertile with reduced litter size. Microarray profiling revealed that the abundance of six gene transcripts (including Fscn1) in Taf7l(-/Y) testes decreased more than twofold. In particular, FSCN1 is an F-action-bundling protein and thus may be critical for normal sperm morphology and sperm motility. Although deficiency of Taf7l may be compensated in part by Taf7, Taf7l has apparently evolved new specialized functions in the gene-selective transcription in male germ cell differentiation. Our mouse studies suggest that mutations in the human TAF7L gene might be implicated in X-linked oligozoospermia in men.

Standard name | CHANGOLKAR_H2AFY_TARGETS_UP
Systematic name | M2287
Organism | Mus musculus
PMID | 17242180
Authors | Changolkar LN,Costanzi C,Leu NA,Chen D,McLaughlin KJ,Pehrson JR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in liver tissue upon knockout of H2AFY [GeneID=9555].
Full description | macroH2A histone variants have been implicated to function in gene silencing by several studies, including ones showing a preferential association of macroH2A on the inactive X chromosome. To examine macroH2A function in vivo, we knocked out macroH2A1. macroH2A1 knockout mice are viable and fertile. A broad screen of liver gene expression showed no evidence of defects in X inactivation but did identify genes that have increased expression levels in macroH2A1 knockouts. macroH2A1-containing nucleosomes are enriched on the coding and/or upstream regions of these genes, suggesting that their increased expression levels are a direct effect of the absence of macroH2A1. The concentrations of macroH2A1 nucleosomes on these genes are low in the livers of newborn mice, and the macroH2A1 knockout had little effect on the expression levels of these genes in newborn liver. Our results indicate that an increase in liver macroH2A1 during the transition from newborn to young-adult status contributes to a decrease in the expression levels of these genes. These genes cluster in the area of lipid metabolism, and we observed metabolic effects in macroH2A1 knockouts. Our results indicate that the function of macroH2A1 histones is not restricted to gene silencing but also involves fine tuning the expression of specific genes.

Standard name | CHANGOLKAR_H2AFY_TARGETS_DN
Systematic name | M2290
Organism | Mus musculus
PMID | 17242180
Authors | Changolkar LN,Costanzi C,Leu NA,Chen D,McLaughlin KJ,Pehrson JR
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in liver tissue upon knockout of H2AFY [GeneID=9555].
Full description | macroH2A histone variants have been implicated to function in gene silencing by several studies, including ones showing a preferential association of macroH2A on the inactive X chromosome. To examine macroH2A function in vivo, we knocked out macroH2A1. macroH2A1 knockout mice are viable and fertile. A broad screen of liver gene expression showed no evidence of defects in X inactivation but did identify genes that have increased expression levels in macroH2A1 knockouts. macroH2A1-containing nucleosomes are enriched on the coding and/or upstream regions of these genes, suggesting that their increased expression levels are a direct effect of the absence of macroH2A1. The concentrations of macroH2A1 nucleosomes on these genes are low in the livers of newborn mice, and the macroH2A1 knockout had little effect on the expression levels of these genes in newborn liver. Our results indicate that an increase in liver macroH2A1 during the transition from newborn to young-adult status contributes to a decrease in the expression levels of these genes. These genes cluster in the area of lipid metabolism, and we observed metabolic effects in macroH2A1 knockouts. Our results indicate that the function of macroH2A1 histones is not restricted to gene silencing but also involves fine tuning the expression of specific genes.

Standard name | PASINI_SUZ12_TARGETS_UP
Systematic name | M2291
Organism | Mus musculus
PMID | 17339329
Authors | Pasini D,Bracken AP,Hansen JB,Capillo M,Helin K
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ES (embryonic stem cells) with defficient SUZ12 [GeneID=23512].
Full description | Polycomb group (PcG) proteins form multiprotein complexes, called Polycomb repressive complexes (PRCs). PRC2 contains the PcG proteins EZH2, SUZ12, and EED and represses transcription through methylation of lysine (K) 27 of histone H3 (H3). Suz12 is essential for PRC2 activity and its inactivation results in early lethality of mouse embryos. Here, we demonstrate that Suz12(-/-) mouse embryonic stem (ES) cells can be established and expanded in tissue culture. The Suz12(-/-) ES cells are characterized by global loss of H3K27 trimethylation (H3K27me3) and higher expression levels of differentiation-specific genes. Moreover, Suz12(-/-) ES cells are impaired in proper differentiation, resulting in a lack of repression of ES cell markers as well as activation of differentiation-specific genes. Finally, we demonstrate that the PcGs are actively recruited to several genes during ES cell differentiation, which despite an increase in H3K27me3 levels is not always sufficient to prevent transcriptional activation. In summary, we demonstrate that Suz12 is required for the establishment of specific expression programs required for ES cell differentiation. Furthermore, we provide evidence that PcGs have different mechanisms to regulate transcription during cellular differentiation.

Standard name | PASINI_SUZ12_TARGETS_DN
Systematic name | M2293
Organism | Mus musculus
PMID | 17339329
Authors | Pasini D,Bracken AP,Hansen JB,Capillo M,Helin K
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ES (embryonic stem cells) with defficient SUZ12 [GeneID=23512].
Full description | Polycomb group (PcG) proteins form multiprotein complexes, called Polycomb repressive complexes (PRCs). PRC2 contains the PcG proteins EZH2, SUZ12, and EED and represses transcription through methylation of lysine (K) 27 of histone H3 (H3). Suz12 is essential for PRC2 activity and its inactivation results in early lethality of mouse embryos. Here, we demonstrate that Suz12(-/-) mouse embryonic stem (ES) cells can be established and expanded in tissue culture. The Suz12(-/-) ES cells are characterized by global loss of H3K27 trimethylation (H3K27me3) and higher expression levels of differentiation-specific genes. Moreover, Suz12(-/-) ES cells are impaired in proper differentiation, resulting in a lack of repression of ES cell markers as well as activation of differentiation-specific genes. Finally, we demonstrate that the PcGs are actively recruited to several genes during ES cell differentiation, which despite an increase in H3K27me3 levels is not always sufficient to prevent transcriptional activation. In summary, we demonstrate that Suz12 is required for the establishment of specific expression programs required for ES cell differentiation. Furthermore, we provide evidence that PcGs have different mechanisms to regulate transcription during cellular differentiation.

Standard name | BAKKER_FOXO3_TARGETS_UP
Systematic name | M2294
Organism | Mus musculus
PMID | 17353275
Authors | Bakker WJ,Dijk van TB,Amelsvoort Parren-van M,Kolbus A,Yamamoto K,Steinlein P,Verhaak RG,Mak TW,Beug H,Löwenberg B,Lindern von M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in I/11 erythroblast cells upon expression of an activated form of FOXO3 [GeneID=2309].
Full description | The cooperation of stem cell factor (SCF) and erythropoietin (Epo) is required to induce renewal divisions in erythroid progenitors, whereas differentiation to mature erythrocytes requires the presence of Epo only. Epo and SCF activate common signaling pathways such as the activation of protein kinase B (PKB) and the subsequent phosphorylation and inactivation of Foxo3a. In contrast, only Epo activates Stat5. Both Foxo3a and Stat5 promote erythroid differentiation. To understand the interplay of SCF and Epo in maintaining the balance between renewal and differentiation during erythroid development, we investigated differential Foxo3a target regulation by Epo and SCF. Expression profiling revealed that a subset of Foxo3a targets was not inhibited but was activated by Epo. One of these genes was Cited2. Transcriptional control of Epo/Foxo3a-induced Cited2 was studied and compared with that of the Epo-repressed Foxo3a target Btg1. We show that in response to Epo, the allegedly growth-inhibitory factor Foxo3a associates with the allegedly growth-stimulatory factor Stat5 in the nucleus, which is required for Epo-induced Cited2 expression. In contrast, Btg1 expression is controlled by the cooperation of Foxo3a with cyclic AMP- and Jun kinase-dependent Creb family members. Thus, Foxo3a not only is an effector of PKB but also integrates distinct signals to regulate gene expression in erythropoiesis.

Standard name | BAKKER_FOXO3_TARGETS_DN
Systematic name | M2295
Organism | Mus musculus
PMID | 17353275
Authors | Bakker WJ,Dijk van TB,Amelsvoort Parren-van M,Kolbus A,Yamamoto K,Steinlein P,Verhaak RG,Mak TW,Beug H,Löwenberg B,Lindern von M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in I/11 erythroblast cells upon expression of an activated form of FOXO3 [GeneID=2309].
Full description | The cooperation of stem cell factor (SCF) and erythropoietin (Epo) is required to induce renewal divisions in erythroid progenitors, whereas differentiation to mature erythrocytes requires the presence of Epo only. Epo and SCF activate common signaling pathways such as the activation of protein kinase B (PKB) and the subsequent phosphorylation and inactivation of Foxo3a. In contrast, only Epo activates Stat5. Both Foxo3a and Stat5 promote erythroid differentiation. To understand the interplay of SCF and Epo in maintaining the balance between renewal and differentiation during erythroid development, we investigated differential Foxo3a target regulation by Epo and SCF. Expression profiling revealed that a subset of Foxo3a targets was not inhibited but was activated by Epo. One of these genes was Cited2. Transcriptional control of Epo/Foxo3a-induced Cited2 was studied and compared with that of the Epo-repressed Foxo3a target Btg1. We show that in response to Epo, the allegedly growth-inhibitory factor Foxo3a associates with the allegedly growth-stimulatory factor Stat5 in the nucleus, which is required for Epo-induced Cited2 expression. In contrast, Btg1 expression is controlled by the cooperation of Foxo3a with cyclic AMP- and Jun kinase-dependent Creb family members. Thus, Foxo3a not only is an effector of PKB but also integrates distinct signals to regulate gene expression in erythropoiesis.

Standard name | BERGER_MBD2_TARGETS
Systematic name | M2296
Organism | Mus musculus
PMID | 17353267
Authors | Berger J,Sansom O,Clarke A,Bird A
Category | C2
Sub-category | CGP
Brief description | Genes strongly up-regulated in colon tissue upon MBD2 [GeneID=8932] knockout.
Full description | Gene expression in the gut is segmentally regulated, but little is known of the molecular origin of patterning. Analysis of gene expression in colons from mice lacking the methyl-CpG binding repressor MBD2 revealed frequent activation of genes that are normally only expressed in the exocrine pancreas and duodenum. Reduced DNA methylation activated the same gene set in the colon. No significant differences in DNA methylation between the colon and duodenum were detected, but MBD2 was significantly more abundant in the colon. The relevance of MBD2 concentration was tested in a human colon cancer cell line. Depletion of MBD2 was again found to activate exocrine pancreatic genes. Gene activation in this cell culture model was accompanied by loss of promoter-bound MBD2 and increased histone acetylation. The results suggest that modulation of MBD2 during gut development establishes a region-specific gene expression pattern that is essential for establishing correct segmental character.

Standard name | VANDESLUIS_COMMD1_TARGETS_GROUP_2_UP
Systematic name | M2298
Organism | Mus musculus
PMID | 17371845
Authors | van de Sluis B,Muller P,Duran K,Chen A,Groot AJ,Klomp LW,Liu PP,Wijmenga C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 9.5 days post coitus (dpc) embryos with COMMD1 [GeneID=150684] knockout compared to normal 8.5 dpc and 9.5 dpc embryos.
Full description | COMMD1 (previously known as MURR1) belongs to a novel family of proteins termed the copper metabolism gene MURR1 domain (COMMD) family. The 10 COMMD family members are well conserved between vertebrates, but the functions of most of the COMMD proteins are unknown. We recently established that COMMD1 is associated with the hepatic copper overload disorder copper toxicosis in Bedlington terriers. Recent in vitro studies indicate that COMMD1 has multiple functions, including sodium transport and NF-kappaB signaling. To elucidate the function of Commd1 in vivo, we generated homozygous Commd1 null (Commd1(-/-)) mice. Commd1(-/-) embryos died in utero between 9.5 and 10.5 days postcoitum (dpc), their development was generally retarded, and placenta vascularization was absent. Microarray analysis identified transcriptional upregulation of hypoxia-inducible factor 1 (HIF-1) target genes in 9.5-dpc Commd1(-/-) embryos compared to normal embryos, a feature that was associated with increased Hif-1alpha stability. Consistent with these observations, COMMD1 physically associates with HIF-1alpha and inhibits HIF-1alpha stability and HIF-1 transactivation in vitro. Thus, this study identifies COMMD1 as a novel regulator of HIF-1 activity and shows that Commd1 deficiency in mice leads to embryonic lethality associated with dysregulated placenta vascularization.

Standard name | VANDESLUIS_COMMD1_TARGETS_GROUP_3_UP
Systematic name | M2299
Organism | Mus musculus
PMID | 17371845
Authors | van de Sluis B,Muller P,Duran K,Chen A,Groot AJ,Klomp LW,Liu PP,Wijmenga C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 9.5 days post coitus (dpc) embryos with COMMD1 [GeneID=150684] knockout compared to normal 9.5 dpc embryos.
Full description | COMMD1 (previously known as MURR1) belongs to a novel family of proteins termed the copper metabolism gene MURR1 domain (COMMD) family. The 10 COMMD family members are well conserved between vertebrates, but the functions of most of the COMMD proteins are unknown. We recently established that COMMD1 is associated with the hepatic copper overload disorder copper toxicosis in Bedlington terriers. Recent in vitro studies indicate that COMMD1 has multiple functions, including sodium transport and NF-kappaB signaling. To elucidate the function of Commd1 in vivo, we generated homozygous Commd1 null (Commd1(-/-)) mice. Commd1(-/-) embryos died in utero between 9.5 and 10.5 days postcoitum (dpc), their development was generally retarded, and placenta vascularization was absent. Microarray analysis identified transcriptional upregulation of hypoxia-inducible factor 1 (HIF-1) target genes in 9.5-dpc Commd1(-/-) embryos compared to normal embryos, a feature that was associated with increased Hif-1alpha stability. Consistent with these observations, COMMD1 physically associates with HIF-1alpha and inhibits HIF-1alpha stability and HIF-1 transactivation in vitro. Thus, this study identifies COMMD1 as a novel regulator of HIF-1 activity and shows that Commd1 deficiency in mice leads to embryonic lethality associated with dysregulated placenta vascularization.

Standard name | VANDESLUIS_COMMD1_TARGETS_GROUP_3_DN
Systematic name | M2300
Organism | Mus musculus
PMID | 17371845
Authors | van de Sluis B,Muller P,Duran K,Chen A,Groot AJ,Klomp LW,Liu PP,Wijmenga C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 9.5 days post coitus (dpc) embryos with COMMD1 [GeneID=150684] knockout compared to normal 9.5 dpc embryos.
Full description | COMMD1 (previously known as MURR1) belongs to a novel family of proteins termed the copper metabolism gene MURR1 domain (COMMD) family. The 10 COMMD family members are well conserved between vertebrates, but the functions of most of the COMMD proteins are unknown. We recently established that COMMD1 is associated with the hepatic copper overload disorder copper toxicosis in Bedlington terriers. Recent in vitro studies indicate that COMMD1 has multiple functions, including sodium transport and NF-kappaB signaling. To elucidate the function of Commd1 in vivo, we generated homozygous Commd1 null (Commd1(-/-)) mice. Commd1(-/-) embryos died in utero between 9.5 and 10.5 days postcoitum (dpc), their development was generally retarded, and placenta vascularization was absent. Microarray analysis identified transcriptional upregulation of hypoxia-inducible factor 1 (HIF-1) target genes in 9.5-dpc Commd1(-/-) embryos compared to normal embryos, a feature that was associated with increased Hif-1alpha stability. Consistent with these observations, COMMD1 physically associates with HIF-1alpha and inhibits HIF-1alpha stability and HIF-1 transactivation in vitro. Thus, this study identifies COMMD1 as a novel regulator of HIF-1 activity and shows that Commd1 deficiency in mice leads to embryonic lethality associated with dysregulated placenta vascularization.

Standard name | VANDESLUIS_COMMD1_TARGETS_GROUP_4_UP
Systematic name | M2301
Organism | Mus musculus
PMID | 17371845
Authors | van de Sluis B,Muller P,Duran K,Chen A,Groot AJ,Klomp LW,Liu PP,Wijmenga C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in 9.5 days post coitus (dpc) embryos with COMMD1 [GeneID=150684] knockout and in normal 8.5 dpc embryos compared to normal 9.5 dpc embryos.
Full description | COMMD1 (previously known as MURR1) belongs to a novel family of proteins termed the copper metabolism gene MURR1 domain (COMMD) family. The 10 COMMD family members are well conserved between vertebrates, but the functions of most of the COMMD proteins are unknown. We recently established that COMMD1 is associated with the hepatic copper overload disorder copper toxicosis in Bedlington terriers. Recent in vitro studies indicate that COMMD1 has multiple functions, including sodium transport and NF-kappaB signaling. To elucidate the function of Commd1 in vivo, we generated homozygous Commd1 null (Commd1(-/-)) mice. Commd1(-/-) embryos died in utero between 9.5 and 10.5 days postcoitum (dpc), their development was generally retarded, and placenta vascularization was absent. Microarray analysis identified transcriptional upregulation of hypoxia-inducible factor 1 (HIF-1) target genes in 9.5-dpc Commd1(-/-) embryos compared to normal embryos, a feature that was associated with increased Hif-1alpha stability. Consistent with these observations, COMMD1 physically associates with HIF-1alpha and inhibits HIF-1alpha stability and HIF-1 transactivation in vitro. Thus, this study identifies COMMD1 as a novel regulator of HIF-1 activity and shows that Commd1 deficiency in mice leads to embryonic lethality associated with dysregulated placenta vascularization.

Standard name | VANDESLUIS_COMMD1_TARGETS_GROUP_4_DN
Systematic name | M2302
Organism | Mus musculus
PMID | 17371845
Authors | van de Sluis B,Muller P,Duran K,Chen A,Groot AJ,Klomp LW,Liu PP,Wijmenga C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in 9.5 days post coitus (dpc) embryos with COMMD1 [GeneID=150684] knockout and in normal 8.5 dpc embryos compared to normal 9.5 dpc embryos.
Full description | COMMD1 (previously known as MURR1) belongs to a novel family of proteins termed the copper metabolism gene MURR1 domain (COMMD) family. The 10 COMMD family members are well conserved between vertebrates, but the functions of most of the COMMD proteins are unknown. We recently established that COMMD1 is associated with the hepatic copper overload disorder copper toxicosis in Bedlington terriers. Recent in vitro studies indicate that COMMD1 has multiple functions, including sodium transport and NF-kappaB signaling. To elucidate the function of Commd1 in vivo, we generated homozygous Commd1 null (Commd1(-/-)) mice. Commd1(-/-) embryos died in utero between 9.5 and 10.5 days postcoitum (dpc), their development was generally retarded, and placenta vascularization was absent. Microarray analysis identified transcriptional upregulation of hypoxia-inducible factor 1 (HIF-1) target genes in 9.5-dpc Commd1(-/-) embryos compared to normal embryos, a feature that was associated with increased Hif-1alpha stability. Consistent with these observations, COMMD1 physically associates with HIF-1alpha and inhibits HIF-1alpha stability and HIF-1 transactivation in vitro. Thus, this study identifies COMMD1 as a novel regulator of HIF-1 activity and shows that Commd1 deficiency in mice leads to embryonic lethality associated with dysregulated placenta vascularization.

Standard name | VANDESLUIS_NORMAL_EMBRYOS_UP
Systematic name | M2303
Organism | Mus musculus
PMID | 17371845
Authors | van de Sluis B,Muller P,Duran K,Chen A,Groot AJ,Klomp LW,Liu PP,Wijmenga C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in normal 9.5 days post coitus (dpc) embryos compared to normal 8.5 dpc and 9.5 dpc embryos.
Full description | COMMD1 (previously known as MURR1) belongs to a novel family of proteins termed the copper metabolism gene MURR1 domain (COMMD) family. The 10 COMMD family members are well conserved between vertebrates, but the functions of most of the COMMD proteins are unknown. We recently established that COMMD1 is associated with the hepatic copper overload disorder copper toxicosis in Bedlington terriers. Recent in vitro studies indicate that COMMD1 has multiple functions, including sodium transport and NF-kappaB signaling. To elucidate the function of Commd1 in vivo, we generated homozygous Commd1 null (Commd1(-/-)) mice. Commd1(-/-) embryos died in utero between 9.5 and 10.5 days postcoitum (dpc), their development was generally retarded, and placenta vascularization was absent. Microarray analysis identified transcriptional upregulation of hypoxia-inducible factor 1 (HIF-1) target genes in 9.5-dpc Commd1(-/-) embryos compared to normal embryos, a feature that was associated with increased Hif-1alpha stability. Consistent with these observations, COMMD1 physically associates with HIF-1alpha and inhibits HIF-1alpha stability and HIF-1 transactivation in vitro. Thus, this study identifies COMMD1 as a novel regulator of HIF-1 activity and shows that Commd1 deficiency in mice leads to embryonic lethality associated with dysregulated placenta vascularization.

Standard name | VANDESLUIS_NORMAL_EMBRYOS_DN
Systematic name | M2304
Organism | Mus musculus
PMID | 17371845
Authors | van de Sluis B,Muller P,Duran K,Chen A,Groot AJ,Klomp LW,Liu PP,Wijmenga C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in normal 9.5 days post coitus (dpc) embryos compared to normal 8.5 dpc and 9.5 dpc embryos.
Full description | COMMD1 (previously known as MURR1) belongs to a novel family of proteins termed the copper metabolism gene MURR1 domain (COMMD) family. The 10 COMMD family members are well conserved between vertebrates, but the functions of most of the COMMD proteins are unknown. We recently established that COMMD1 is associated with the hepatic copper overload disorder copper toxicosis in Bedlington terriers. Recent in vitro studies indicate that COMMD1 has multiple functions, including sodium transport and NF-kappaB signaling. To elucidate the function of Commd1 in vivo, we generated homozygous Commd1 null (Commd1(-/-)) mice. Commd1(-/-) embryos died in utero between 9.5 and 10.5 days postcoitum (dpc), their development was generally retarded, and placenta vascularization was absent. Microarray analysis identified transcriptional upregulation of hypoxia-inducible factor 1 (HIF-1) target genes in 9.5-dpc Commd1(-/-) embryos compared to normal embryos, a feature that was associated with increased Hif-1alpha stability. Consistent with these observations, COMMD1 physically associates with HIF-1alpha and inhibits HIF-1alpha stability and HIF-1 transactivation in vitro. Thus, this study identifies COMMD1 as a novel regulator of HIF-1 activity and shows that Commd1 deficiency in mice leads to embryonic lethality associated with dysregulated placenta vascularization.

Standard name | SUMI_HNF4A_TARGETS
Systematic name | M2306
Organism | Homo sapiens
PMID | 17403900
Authors | Sumi K,Tanaka T,Uchida A,Magoori K,Urashima Y,Ohashi R,Ohguchi H,Okamura M,Kudo H,Daigo K,Maejima T,Kojima N,Sakakibara I,Jiang S,Hasegawa G,Kim I,Osborne TF,Naito M,Gonzalez FJ,Hamakubo T,Kodama T,Sakai J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HepG2 cells (hepatocellular carcinoma, HCC) upon expression of HNF4A [GeneID=3172] and down-regulated upon knockdown of HNF4A [GeneID=3172] in these cells by RNAi.
Full description | Cholesterol homeostasis is maintained by coordinate regulation of cholesterol synthesis and its conversion to bile acids in the liver. The excretion of cholesterol from liver and intestine is regulated by ATP-binding cassette half-transporters ABCG5 and ABCG8. The genes for these two proteins are closely linked and divergently transcribed from a common intergenic promoter region. Here, we identified a binding site for hepatocyte nuclear factor 4alpha (HNF4alpha) in the ABCG5/ABCG8 intergenic promoter, through which HNF4alpha strongly activated the expression of a reporter gene in both directions. The HNF4alpha-responsive element is flanked by two conserved GATA boxes that were also required for stimulation by HNF4alpha. GATA4 and GATA6 bind to the GATA boxes, coexpression of GATA4 and HNF4alpha leads to a striking synergistic activation of both the ABCG5 and the ABCG8 promoters, and binding sites for HNF4alpha and GATA were essential for maximal synergism. We also show that HNF4alpha, GATA4, and GATA6 colocalize in the nuclei of HepG2 cells and that a physical interaction between HNF4alpha and GATA4 is critical for the synergistic response. This is the first demonstration that HNF4alpha acts synergistically with GATA factors to activate gene expression in a bidirectional fashion.

Standard name | WANG_NFKB_TARGETS
Systematic name | M2307
Organism | Mus musculus
PMID | 17438126
Authors | Wang H,Hertlein E,Bakkar N,Sun H,Acharyya S,Wang J,Carathers M,Davuluri R,Guttridge DC
Category | C2
Sub-category | CGP
Brief description | Representative genes up-regulated in C2C12 cells (myoblast) lacking NFkB activity due to expression of a super repressor form of NFKBIA [GeneID=4792].
Full description | NF-kappaB signaling is implicated as an important regulator of skeletal muscle homeostasis, but the mechanisms by which this transcription factor contributes to muscle maturation and turnover remain unclear. To gain insight into these mechanisms, gene expression profiling was examined in C2C12 myoblasts devoid of NF-kappaB activity. Interestingly, even in proliferating myoblasts, the absence of NF-kappaB caused the pronounced induction of several myofibrillar genes, suggesting that NF-kappaB functions as a negative regulator of late-stage muscle differentiation. Although several myofibrillar promoters contain predicted NF-kappaB binding sites, functional analysis using the troponin-I2 gene as a model revealed that NF-kappaB-mediated repression does not occur through direct DNA binding. In the search for an indirect mediator, the transcriptional repressor YinYang1 (YY1) was identified. While inducers of NF-kappaB stimulated YY1 expression in multiple cell types, genetic ablation of the RelA/p65 subunit of NF-kappaB in both cultured cells and adult skeletal muscle correlated with reduced YY1 transcripts and protein. NF-kappaB regulation of YY1 occurred at the transcriptional level, mediated by direct binding of the p50/p65 heterodimer complex to the YY1 promoter. Furthermore, YY1 was found associated with multiple myofibrillar promoters in C2C12 myoblasts containing NF-kappaB activity. Based on these results, we propose that NF-kappaB regulation of YY1 and transcriptional silencing of myofibrillar genes represent a new mechanism by which NF-kappaB functions in myoblasts to modulate skeletal muscle differentiation.

Standard name | WANG_TNF_TARGETS
Systematic name | M2308
Organism | Mus musculus
PMID | 17438126
Authors | Wang H,Hertlein E,Bakkar N,Sun H,Acharyya S,Wang J,Carathers M,Davuluri R,Guttridge DC
Category | C2
Sub-category | CGP
Brief description | Representative genes up-regulated in MEF cells (embryonic fibroblast) in response to TNF [GeneID=7124].
Full description | NF-kappaB signaling is implicated as an important regulator of skeletal muscle homeostasis, but the mechanisms by which this transcription factor contributes to muscle maturation and turnover remain unclear. To gain insight into these mechanisms, gene expression profiling was examined in C2C12 myoblasts devoid of NF-kappaB activity. Interestingly, even in proliferating myoblasts, the absence of NF-kappaB caused the pronounced induction of several myofibrillar genes, suggesting that NF-kappaB functions as a negative regulator of late-stage muscle differentiation. Although several myofibrillar promoters contain predicted NF-kappaB binding sites, functional analysis using the troponin-I2 gene as a model revealed that NF-kappaB-mediated repression does not occur through direct DNA binding. In the search for an indirect mediator, the transcriptional repressor YinYang1 (YY1) was identified. While inducers of NF-kappaB stimulated YY1 expression in multiple cell types, genetic ablation of the RelA/p65 subunit of NF-kappaB in both cultured cells and adult skeletal muscle correlated with reduced YY1 transcripts and protein. NF-kappaB regulation of YY1 occurred at the transcriptional level, mediated by direct binding of the p50/p65 heterodimer complex to the YY1 promoter. Furthermore, YY1 was found associated with multiple myofibrillar promoters in C2C12 myoblasts containing NF-kappaB activity. Based on these results, we propose that NF-kappaB regulation of YY1 and transcriptional silencing of myofibrillar genes represent a new mechanism by which NF-kappaB functions in myoblasts to modulate skeletal muscle differentiation.

Standard name | AZARE_NEOPLASTIC_TRANSFORMATION_BY_STAT3_UP
Systematic name | M2309
Organism | Homo sapiens
PMID | 17438134
Authors | Azare J,Leslie K,Al-Ahmadie H,Gerald W,Weinreb PH,Violette SM,Bromberg J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RWPE-1 cells (prostate cancer) upon expression of constitutively active form of STAT3 [GeneID=6774].
Full description | The persistent activation of signal transducer and activator of transcription 3 (Stat3) is a common feature of prostate cancer. However, little is known about the Stat3 targets that may mediate prostate tumorigenesis. The introduction of an activating mutant form of Stat3 (Stat3-C) into immortalized prostate epithelial cells resulted in tumorigenesis. Stat3-C-expressing cells had decreased E-cadherin levels, increased numbers of lamellipodia and stress fibers, and enhanced migratory capacities compared to vector control-expressing cells, with a concomitant increase in the expression of integrin beta6 and its ligand, fibronectin (FN). Exogenously added FN increased cellular migration, with a concomitant loss of E-cadherin expression. The blockade of integrin alphavbeta6 in Stat3-C-expressing cells inhibited migration, increased E-cadherin levels, and reduced colony formation in soft agar. These results demonstrate the sufficiency of constitutively activated Stat3 in mediating prostate tumorigenesis and identify novel Stat3 targets that are involved in promoting cell migration and transformation.

Standard name | AZARE_NEOPLASTIC_TRANSFORMATION_BY_STAT3_DN
Systematic name | M2311
Organism | Homo sapiens
PMID | 17438134
Authors | Azare J,Leslie K,Al-Ahmadie H,Gerald W,Weinreb PH,Violette SM,Bromberg J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in RWPE-1 cells (prostate cancer) upon expression of constitutively active form of STAT3 [GeneID=6774].
Full description | The persistent activation of signal transducer and activator of transcription 3 (Stat3) is a common feature of prostate cancer. However, little is known about the Stat3 targets that may mediate prostate tumorigenesis. The introduction of an activating mutant form of Stat3 (Stat3-C) into immortalized prostate epithelial cells resulted in tumorigenesis. Stat3-C-expressing cells had decreased E-cadherin levels, increased numbers of lamellipodia and stress fibers, and enhanced migratory capacities compared to vector control-expressing cells, with a concomitant increase in the expression of integrin beta6 and its ligand, fibronectin (FN). Exogenously added FN increased cellular migration, with a concomitant loss of E-cadherin expression. The blockade of integrin alphavbeta6 in Stat3-C-expressing cells inhibited migration, increased E-cadherin levels, and reduced colony formation in soft agar. These results demonstrate the sufficiency of constitutively activated Stat3 in mediating prostate tumorigenesis and identify novel Stat3 targets that are involved in promoting cell migration and transformation.

Standard name | AZARE_STAT3_TARGETS
Systematic name | M2312
Organism | Homo sapiens
PMID | 17438134
Authors | Azare J,Leslie K,Al-Ahmadie H,Gerald W,Weinreb PH,Violette SM,Bromberg J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in RPWE-1 cells by activated STAT3 [GeneID=6774].
Full description | The persistent activation of signal transducer and activator of transcription 3 (Stat3) is a common feature of prostate cancer. However, little is known about the Stat3 targets that may mediate prostate tumorigenesis. The introduction of an activating mutant form of Stat3 (Stat3-C) into immortalized prostate epithelial cells resulted in tumorigenesis. Stat3-C-expressing cells had decreased E-cadherin levels, increased numbers of lamellipodia and stress fibers, and enhanced migratory capacities compared to vector control-expressing cells, with a concomitant increase in the expression of integrin beta6 and its ligand, fibronectin (FN). Exogenously added FN increased cellular migration, with a concomitant loss of E-cadherin expression. The blockade of integrin alphavbeta6 in Stat3-C-expressing cells inhibited migration, increased E-cadherin levels, and reduced colony formation in soft agar. These results demonstrate the sufficiency of constitutively activated Stat3 in mediating prostate tumorigenesis and identify novel Stat3 targets that are involved in promoting cell migration and transformation.

Standard name | DELPUECH_FOXO3_TARGETS_UP
Systematic name | M2313
Organism | Homo sapiens
PMID | 17452451
Authors | Delpuech O,Griffiths B,East P,Essafi A,Lam EW,Burgering B,Downward J,Schulze A
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DL23 cells (colon cancer) upon expression of an activated form of FOXO3 [GeneID=2309].
Full description | Forkhead transcription factors of the O class (FOXOs) are important targets of the phosphatidylinositol 3-kinase (PI3-kinase)/Akt pathway. FOXOs have been implicated in the regulation of cell cycle progression, oxidative stress resistance, and apoptosis. Using DNA microarrays, we analyzed the transcriptional response to FOXO3a activation by gene expression analysis in DLD-1 colon cancer cells stably expressing a FOXO3a.A3-ER fusion protein. We found that activation of FOXO3a resulted in repression of a number of previously identified Myc target genes. Furthermore, FOXO3a activation induced expression of several members of the Mad/Mxd family of transcriptional repressors, most notably Mxi1. The induction of Mxi1 by FOXO3a was specific to the Mxi1-SR alpha isoform and was mediated by three highly conserved FOXO binding sites within the first intron of the gene. Activation of FOXO3a in response to inhibition of Akt also resulted in activation of Mxi1-SR alpha expression. Silencing of Mxi1 by small interfering RNA (siRNA) reduced FOXO3a-mediated repression of a number of Myc target genes. We also observed that FOXO3a activation induced a switch in promoter occupancy from Myc to Mxi1 on the E-box containing promoter regions of two Myc target genes, APEX and FOXM1. siRNA-mediated transient silencing of Mxi1 or all Mad/Mxd proteins reduced exit from S phase in response to FOXO3a activation, and stable silencing of Mxi1 or Mad1 reduced the growth inhibitory effect of FOXO3a. We conclude that induction of Mad/Mxd proteins contributes to the inhibition of proliferation in response to FOXO3a activation. Our results provide evidence of direct regulation of Mxi1 by FOXO3a and imply an additional mechanism through which the PI3-kinase/Akt/FOXO pathway can modulate Myc function.

Standard name | DELPUECH_FOXO3_TARGETS_DN
Systematic name | M2314
Organism | Homo sapiens
PMID | 17452451
Authors | Delpuech O,Griffiths B,East P,Essafi A,Lam EW,Burgering B,Downward J,Schulze A
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in DL23 cells (colon cancer) upon expression of an activated form of FOXO3 [GeneID=2309].
Full description | Forkhead transcription factors of the O class (FOXOs) are important targets of the phosphatidylinositol 3-kinase (PI3-kinase)/Akt pathway. FOXOs have been implicated in the regulation of cell cycle progression, oxidative stress resistance, and apoptosis. Using DNA microarrays, we analyzed the transcriptional response to FOXO3a activation by gene expression analysis in DLD-1 colon cancer cells stably expressing a FOXO3a.A3-ER fusion protein. We found that activation of FOXO3a resulted in repression of a number of previously identified Myc target genes. Furthermore, FOXO3a activation induced expression of several members of the Mad/Mxd family of transcriptional repressors, most notably Mxi1. The induction of Mxi1 by FOXO3a was specific to the Mxi1-SR alpha isoform and was mediated by three highly conserved FOXO binding sites within the first intron of the gene. Activation of FOXO3a in response to inhibition of Akt also resulted in activation of Mxi1-SR alpha expression. Silencing of Mxi1 by small interfering RNA (siRNA) reduced FOXO3a-mediated repression of a number of Myc target genes. We also observed that FOXO3a activation induced a switch in promoter occupancy from Myc to Mxi1 on the E-box containing promoter regions of two Myc target genes, APEX and FOXM1. siRNA-mediated transient silencing of Mxi1 or all Mad/Mxd proteins reduced exit from S phase in response to FOXO3a activation, and stable silencing of Mxi1 or Mad1 reduced the growth inhibitory effect of FOXO3a. We conclude that induction of Mad/Mxd proteins contributes to the inhibition of proliferation in response to FOXO3a activation. Our results provide evidence of direct regulation of Mxi1 by FOXO3a and imply an additional mechanism through which the PI3-kinase/Akt/FOXO pathway can modulate Myc function.

Standard name | WIEDERSCHAIN_TARGETS_OF_BMI1_AND_PCGF2
Systematic name | M2316
Organism | Homo sapiens
PMID | 17452456
Authors | Wiederschain D,Chen L,Johnson B,Bettano K,Jackson D,Taraszka J,Wang YK,Jones MD,Morrissey M,Deeds J,Mosher R,Fordjour P,Lengauer C,Benson JD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DAOY cells (medulloblastoma) upon knockdown of both BMI1 and PCGF2 [GeneID=648, 7703] by RNAi.
Full description | Bmi-1 and Mel-18 are structural homologues that belong to the Polycomb group of transcriptional regulators and are believed to stably maintain repression of gene expression by altering the state of chromatin at specific promoters. While a number of clinical and experimental observations have implicated Bmi-1 in human tumorigenesis, the role of Mel-18 in cancer cell growth has not been investigated. We report here that short hairpin RNA-mediated knockdown of either Bmi-1 or Mel-18 in human medulloblastoma DAOY cells results in the inhibition of proliferation, loss of clonogenic survival, anchorage-independent growth, and suppression of tumor formation in nude mice. Furthermore, overexpression of both Bmi-1 and Mel-18 significantly increases the clonogenic survival of Rat1 fibroblasts. In contrast, stable downregulation of Bmi-1 or Mel-18 alone does not affect the growth of normal human WI38 fibroblasts. Proteomics-based characterization of Bmi-1 and Mel-18 protein complexes isolated from cancer cells revealed substantial similarities in their respective compositions. Finally, gene expression analysis identified a number of cancer-relevant pathways that may be controlled by Bmi-1 and Mel-18 and also showed that these Polycomb proteins regulate a set of common gene targets. Taken together, these results suggest that Bmi-1 and Mel-18 may have overlapping functions in cancer cell growth.

Standard name | KASLER_HDAC7_TARGETS_1_UP
Systematic name | M2317
Organism | Mus musculus
PMID | 17470548
Authors | Kasler HG,Verdin E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DO11.10 cells (hybridoma) by expression of transciptionally activating form of HDAC7 [GeneID=51564] and down-regulated by its transcriptionally repressing form.
Full description | Histone deacetylase 7 (HDAC7) is highly expressed in CD4(+)/CD8(+) thymocytes and functions as a signal-dependent repressor of gene transcription during T-cell development. In this study, we expressed HDAC7 mutant proteins in a T-cell line and use DNA microarrays to identify transcriptional targets of HDAC7 in T cells. The changes in gene expression levels were compared to differential gene expression profiles associated with positive and negative thymic selection. This analysis reveals that HDAC7 regulates an extensive set of genes that are differentially expressed during both positive and negative thymic selection. Many of these genes play important functional roles in thymic selection, primarily via modulating the coupling between antigen receptor engagement and downstream signaling events. Consistent with the model that HDAC7 may play an important role in both positive and negative thymic selection, the expression of distinct HDAC7 mutants or the abrogation of HDAC7 expression can either enhance or inhibit the signal-dependent differentiation of a CD4(+)/CD8(+) cell line.

Standard name | KASLER_HDAC7_TARGETS_1_DN
Systematic name | M2318
Organism | Mus musculus
PMID | 17470548
Authors | Kasler HG,Verdin E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in DO11.10 cells (hybridoma) by expression of transciptionally activating form of HDAC7 [GeneID=51564] and up-regulated by its transcriptionally repressing form.
Full description | Histone deacetylase 7 (HDAC7) is highly expressed in CD4(+)/CD8(+) thymocytes and functions as a signal-dependent repressor of gene transcription during T-cell development. In this study, we expressed HDAC7 mutant proteins in a T-cell line and use DNA microarrays to identify transcriptional targets of HDAC7 in T cells. The changes in gene expression levels were compared to differential gene expression profiles associated with positive and negative thymic selection. This analysis reveals that HDAC7 regulates an extensive set of genes that are differentially expressed during both positive and negative thymic selection. Many of these genes play important functional roles in thymic selection, primarily via modulating the coupling between antigen receptor engagement and downstream signaling events. Consistent with the model that HDAC7 may play an important role in both positive and negative thymic selection, the expression of distinct HDAC7 mutants or the abrogation of HDAC7 expression can either enhance or inhibit the signal-dependent differentiation of a CD4(+)/CD8(+) cell line.

Standard name | KASLER_HDAC7_TARGETS_2_UP
Systematic name | M2319
Organism | Mus musculus
PMID | 17470548
Authors | Kasler HG,Verdin E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in DO11.10 cells (hybridoma) by expression of transciptionally activating and by transcriptionally repressive forms of HDAC7 [GeneID=51564].
Full description | Histone deacetylase 7 (HDAC7) is highly expressed in CD4(+)/CD8(+) thymocytes and functions as a signal-dependent repressor of gene transcription during T-cell development. In this study, we expressed HDAC7 mutant proteins in a T-cell line and use DNA microarrays to identify transcriptional targets of HDAC7 in T cells. The changes in gene expression levels were compared to differential gene expression profiles associated with positive and negative thymic selection. This analysis reveals that HDAC7 regulates an extensive set of genes that are differentially expressed during both positive and negative thymic selection. Many of these genes play important functional roles in thymic selection, primarily via modulating the coupling between antigen receptor engagement and downstream signaling events. Consistent with the model that HDAC7 may play an important role in both positive and negative thymic selection, the expression of distinct HDAC7 mutants or the abrogation of HDAC7 expression can either enhance or inhibit the signal-dependent differentiation of a CD4(+)/CD8(+) cell line.

Standard name | KASLER_HDAC7_TARGETS_2_DN
Systematic name | M2322
Organism | Mus musculus
PMID | 17470548
Authors | Kasler HG,Verdin E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in DO11.10 cells (hybridoma) by expression of transciptionally activating and by transcriptionally repressive forms of HDAC7 [GeneID=51564].
Full description | Histone deacetylase 7 (HDAC7) is highly expressed in CD4(+)/CD8(+) thymocytes and functions as a signal-dependent repressor of gene transcription during T-cell development. In this study, we expressed HDAC7 mutant proteins in a T-cell line and use DNA microarrays to identify transcriptional targets of HDAC7 in T cells. The changes in gene expression levels were compared to differential gene expression profiles associated with positive and negative thymic selection. This analysis reveals that HDAC7 regulates an extensive set of genes that are differentially expressed during both positive and negative thymic selection. Many of these genes play important functional roles in thymic selection, primarily via modulating the coupling between antigen receptor engagement and downstream signaling events. Consistent with the model that HDAC7 may play an important role in both positive and negative thymic selection, the expression of distinct HDAC7 mutants or the abrogation of HDAC7 expression can either enhance or inhibit the signal-dependent differentiation of a CD4(+)/CD8(+) cell line.

Standard name | DORMOY_ELAVL1_TARGETS
Systematic name | M2323
Organism | Homo sapiens
PMID | 17548472
Authors | Dormoy-Raclet V,Ménard I,Clair E,Kurban G,Mazroui R,Marco Di S,Roretz von C,Pause A,Gallouzi IE
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HeLa cells upon knockdown of ELAVL1 [GeneID=1994] by RNAi.
Full description | A high expression level of the beta-actin protein is required for important biological mechanisms, such as maintaining cell shape, growth, and motility. Although the elevated cellular level of the beta-actin protein is directly linked to the long half-life of its mRNA, the molecular mechanisms responsible for this effect are unknown. Here we show that the RNA-binding protein HuR stabilizes the beta-actin mRNA by associating with a uridine-rich element within its 3' untranslated region. Using RNA interference to knock down the expression of HuR in HeLa cells, we demonstrate that HuR plays an important role in the stabilization but not in the nuclear/cytoplasmic distribution of the beta-actin mRNA. HuR depletion in HeLa cells alters key beta-actin-based cytoskeleton functions, such as cell adhesion, migration, and invasion, and these defects correlate with a loss of the actin stress fiber network. Together our data establish that the posttranscriptional event involving HuR-mediated beta-actin mRNA stabilization could be a part of the regulatory mechanisms responsible for maintaining cell integrity, which is a prerequisite for avoiding transformation and tumor formation.

Standard name | LEE_BMP2_TARGETS_UP
Systematic name | M2324
Organism | Mus musculus
PMID | 17515606
Authors | Lee KY,Jeong JW,Wang J,Ma L,Martin JF,Tsai SY,Lydon JP,DeMayo FJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in uterus upon knockout of BMP2 [GeneID=650].
Full description | The process of implantation, necessary for all viviparous birth, consists of tightly regulated events, including apposition of the blastocyst, attachment to the uterine lumen, and differentiation of the uterine stroma. In rodents and primates the uterine stroma undergoes a process called decidualization. Decidualization, the process by which the uterine endometrial stroma proliferates and differentiates into large epithelioid decidual cells, is critical to the establishment of fetal-maternal communication and the progression of implantation. The role of bone morphogenetic protein 2 (Bmp2) in regulating the transformation of the uterine stroma during embryo implantation in the mouse was investigated by the conditional ablation of Bmp2 in the uterus using the (PR-cre) mouse. Bmp2 gene ablation was confirmed by real-time PCR analysis in the PR-cre; Bmp2fl/fl (termed Bmp2d/d) uterus. While littermate controls average 0.9 litter of 6.2+/-0.7 pups per month, Bmp2d/d females are completely infertile. Analysis of the infertility indicates that whereas embryo attachment is normal in the Bmp2d/d as in control mice, the uterine stroma is incapable of undergoing the decidual reaction to support further embryonic development. Recombinant human BMP2 can partially rescue the decidual response, suggesting that the observed phenotypes are not due to a developmental consequence of Bmp2 ablation. Microarray analysis demonstrates that ablation of Bmp2 leads to specific gene changes, including disruption of the Wnt signaling pathway, Progesterone receptor (PR) signaling, and the induction of prostaglandin synthase 2 (Ptgs2). Taken together, these data demonstrate that Bmp2 is a critical regulator of gene expression and function in the murine uterus.

Standard name | LEE_BMP2_TARGETS_DN
Systematic name | M2325
Organism | Mus musculus
PMID | 17515606
Authors | Lee KY,Jeong JW,Wang J,Ma L,Martin JF,Tsai SY,Lydon JP,DeMayo FJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in uterus upon knockout of BMP2 [GeneID=650].
Full description | The process of implantation, necessary for all viviparous birth, consists of tightly regulated events, including apposition of the blastocyst, attachment to the uterine lumen, and differentiation of the uterine stroma. In rodents and primates the uterine stroma undergoes a process called decidualization. Decidualization, the process by which the uterine endometrial stroma proliferates and differentiates into large epithelioid decidual cells, is critical to the establishment of fetal-maternal communication and the progression of implantation. The role of bone morphogenetic protein 2 (Bmp2) in regulating the transformation of the uterine stroma during embryo implantation in the mouse was investigated by the conditional ablation of Bmp2 in the uterus using the (PR-cre) mouse. Bmp2 gene ablation was confirmed by real-time PCR analysis in the PR-cre; Bmp2fl/fl (termed Bmp2d/d) uterus. While littermate controls average 0.9 litter of 6.2+/-0.7 pups per month, Bmp2d/d females are completely infertile. Analysis of the infertility indicates that whereas embryo attachment is normal in the Bmp2d/d as in control mice, the uterine stroma is incapable of undergoing the decidual reaction to support further embryonic development. Recombinant human BMP2 can partially rescue the decidual response, suggesting that the observed phenotypes are not due to a developmental consequence of Bmp2 ablation. Microarray analysis demonstrates that ablation of Bmp2 leads to specific gene changes, including disruption of the Wnt signaling pathway, Progesterone receptor (PR) signaling, and the induction of prostaglandin synthase 2 (Ptgs2). Taken together, these data demonstrate that Bmp2 is a critical regulator of gene expression and function in the murine uterus.

Standard name | BILANGES_SERUM_SENSITIVE_GENES
Systematic name | M2327
Organism | Mus musculus
PMID | 17562867
Authors | Bilanges B,Argonza-Barrett R,Kolesnichenko M,Skinner C,Nair M,Chen M,Stokoe D
Category | C2
Sub-category | CGP
Brief description | Genes translationally regulated in MEF cells (embryonic fibroblasts) in response to serum starvation but not by rapamycin (sirolimus) [PubChem=6610346].
Full description | The tuberous sclerosis complex (TSC) proteins TSC1 and TSC2 regulate protein translation by inhibiting the serine/threonine kinase mTORC1 (for mammalian target of rapamycin complex 1). However, how TSC1 and TSC2 control overall protein synthesis and the translation of specific mRNAs in response to different mitogenic and nutritional stimuli is largely unknown. We show here that serum withdrawal inhibits mTORC1 signaling, causes disassembly of translation initiation complexes, and causes mRNA redistribution from polysomes to subpolysomes in wild-type mouse embryo fibroblasts (MEFs). In contrast, these responses are defective in Tsc1(-/-) or Tsc2(-/-) MEFs. Microarray analysis of polysome- and subpolysome-associated mRNAs uncovered specific mRNAs that are translationally regulated by serum, 90% of which are TSC1 and TSC2 dependent. Surprisingly, the mTORC1 inhibitor, rapamycin, abolished mTORC1 activity but only affected approximately 40% of the serum-regulated mRNAs. Serum-dependent signaling through mTORC1 and polysome redistribution of global and individual mRNAs were restored upon re-expression of TSC1 and TSC2. Serum-responsive mRNAs that are sensitive to inhibition by rapamycin are highly enriched for terminal oligopyrimidine and for very short 5' and 3' untranslated regions. These data demonstrate that the TSC1/TSC2 complex regulates protein translation through mainly mTORC1-dependent mechanisms and implicates a discrete profile of deregulated mRNA translation in tuberous sclerosis pathology.

Standard name | BILANGES_SERUM_AND_RAPAMYCIN_SENSITIVE_GENES
Systematic name | M2328
Organism | Mus musculus
PMID | 17562867
Authors | Bilanges B,Argonza-Barrett R,Kolesnichenko M,Skinner C,Nair M,Chen M,Stokoe D
Category | C2
Sub-category | CGP
Brief description | Genes translationally regulated in MEF cells (embryonic fibroblasts) in response to serum starvation and by rapamycin (sirolimus) [PubChem=6610346].
Full description | The tuberous sclerosis complex (TSC) proteins TSC1 and TSC2 regulate protein translation by inhibiting the serine/threonine kinase mTORC1 (for mammalian target of rapamycin complex 1). However, how TSC1 and TSC2 control overall protein synthesis and the translation of specific mRNAs in response to different mitogenic and nutritional stimuli is largely unknown. We show here that serum withdrawal inhibits mTORC1 signaling, causes disassembly of translation initiation complexes, and causes mRNA redistribution from polysomes to subpolysomes in wild-type mouse embryo fibroblasts (MEFs). In contrast, these responses are defective in Tsc1(-/-) or Tsc2(-/-) MEFs. Microarray analysis of polysome- and subpolysome-associated mRNAs uncovered specific mRNAs that are translationally regulated by serum, 90% of which are TSC1 and TSC2 dependent. Surprisingly, the mTORC1 inhibitor, rapamycin, abolished mTORC1 activity but only affected approximately 40% of the serum-regulated mRNAs. Serum-dependent signaling through mTORC1 and polysome redistribution of global and individual mRNAs were restored upon re-expression of TSC1 and TSC2. Serum-responsive mRNAs that are sensitive to inhibition by rapamycin are highly enriched for terminal oligopyrimidine and for very short 5' and 3' untranslated regions. These data demonstrate that the TSC1/TSC2 complex regulates protein translation through mainly mTORC1-dependent mechanisms and implicates a discrete profile of deregulated mRNA translation in tuberous sclerosis pathology.

Standard name | BILANGES_RAPAMYCIN_SENSITIVE_GENES
Systematic name | M2329
Organism | Mus musculus
PMID | 17562867
Authors | Bilanges B,Argonza-Barrett R,Kolesnichenko M,Skinner C,Nair M,Chen M,Stokoe D
Category | C2
Sub-category | CGP
Brief description | Genes translationally regulated in MEF cells (embryonic fibroblasts) by rapamycin (sirolimus) [PubChem=6610346] but not in response to serum deprivation.
Full description | The tuberous sclerosis complex (TSC) proteins TSC1 and TSC2 regulate protein translation by inhibiting the serine/threonine kinase mTORC1 (for mammalian target of rapamycin complex 1). However, how TSC1 and TSC2 control overall protein synthesis and the translation of specific mRNAs in response to different mitogenic and nutritional stimuli is largely unknown. We show here that serum withdrawal inhibits mTORC1 signaling, causes disassembly of translation initiation complexes, and causes mRNA redistribution from polysomes to subpolysomes in wild-type mouse embryo fibroblasts (MEFs). In contrast, these responses are defective in Tsc1(-/-) or Tsc2(-/-) MEFs. Microarray analysis of polysome- and subpolysome-associated mRNAs uncovered specific mRNAs that are translationally regulated by serum, 90% of which are TSC1 and TSC2 dependent. Surprisingly, the mTORC1 inhibitor, rapamycin, abolished mTORC1 activity but only affected approximately 40% of the serum-regulated mRNAs. Serum-dependent signaling through mTORC1 and polysome redistribution of global and individual mRNAs were restored upon re-expression of TSC1 and TSC2. Serum-responsive mRNAs that are sensitive to inhibition by rapamycin are highly enriched for terminal oligopyrimidine and for very short 5' and 3' untranslated regions. These data demonstrate that the TSC1/TSC2 complex regulates protein translation through mainly mTORC1-dependent mechanisms and implicates a discrete profile of deregulated mRNA translation in tuberous sclerosis pathology.

Standard name | BILANGES_RAPAMYCIN_SENSITIVE_VIA_TSC1_AND_TSC2
Systematic name | M2331
Organism | Mus musculus
PMID | 17562867
Authors | Bilanges B,Argonza-Barrett R,Kolesnichenko M,Skinner C,Nair M,Chen M,Stokoe D
Category | C2
Sub-category | CGP
Brief description | Genes translationally repressed by rapamycin (sirolimus) [PubChem=6610346] in MEF cells (embryonic fibroblast) lacking either TSC1 or TSC2 [GeneID=7248, 7249] but not in the wild type cells.
Full description | The tuberous sclerosis complex (TSC) proteins TSC1 and TSC2 regulate protein translation by inhibiting the serine/threonine kinase mTORC1 (for mammalian target of rapamycin complex 1). However, how TSC1 and TSC2 control overall protein synthesis and the translation of specific mRNAs in response to different mitogenic and nutritional stimuli is largely unknown. We show here that serum withdrawal inhibits mTORC1 signaling, causes disassembly of translation initiation complexes, and causes mRNA redistribution from polysomes to subpolysomes in wild-type mouse embryo fibroblasts (MEFs). In contrast, these responses are defective in Tsc1(-/-) or Tsc2(-/-) MEFs. Microarray analysis of polysome- and subpolysome-associated mRNAs uncovered specific mRNAs that are translationally regulated by serum, 90% of which are TSC1 and TSC2 dependent. Surprisingly, the mTORC1 inhibitor, rapamycin, abolished mTORC1 activity but only affected approximately 40% of the serum-regulated mRNAs. Serum-dependent signaling through mTORC1 and polysome redistribution of global and individual mRNAs were restored upon re-expression of TSC1 and TSC2. Serum-responsive mRNAs that are sensitive to inhibition by rapamycin are highly enriched for terminal oligopyrimidine and for very short 5' and 3' untranslated regions. These data demonstrate that the TSC1/TSC2 complex regulates protein translation through mainly mTORC1-dependent mechanisms and implicates a discrete profile of deregulated mRNA translation in tuberous sclerosis pathology.

Standard name | BILANGES_SERUM_SENSITIVE_VIA_TSC1
Systematic name | M2332
Organism | Mus musculus
PMID | 17562867
Authors | Bilanges B,Argonza-Barrett R,Kolesnichenko M,Skinner C,Nair M,Chen M,Stokoe D
Category | C2
Sub-category | CGP
Brief description | Genes translationally up-regulated by serum in MEF cells (embryonic fibroblast) lacking TSC1 [GeneID=7248].
Full description | The tuberous sclerosis complex (TSC) proteins TSC1 and TSC2 regulate protein translation by inhibiting the serine/threonine kinase mTORC1 (for mammalian target of rapamycin complex 1). However, how TSC1 and TSC2 control overall protein synthesis and the translation of specific mRNAs in response to different mitogenic and nutritional stimuli is largely unknown. We show here that serum withdrawal inhibits mTORC1 signaling, causes disassembly of translation initiation complexes, and causes mRNA redistribution from polysomes to subpolysomes in wild-type mouse embryo fibroblasts (MEFs). In contrast, these responses are defective in Tsc1(-/-) or Tsc2(-/-) MEFs. Microarray analysis of polysome- and subpolysome-associated mRNAs uncovered specific mRNAs that are translationally regulated by serum, 90% of which are TSC1 and TSC2 dependent. Surprisingly, the mTORC1 inhibitor, rapamycin, abolished mTORC1 activity but only affected approximately 40% of the serum-regulated mRNAs. Serum-dependent signaling through mTORC1 and polysome redistribution of global and individual mRNAs were restored upon re-expression of TSC1 and TSC2. Serum-responsive mRNAs that are sensitive to inhibition by rapamycin are highly enriched for terminal oligopyrimidine and for very short 5' and 3' untranslated regions. These data demonstrate that the TSC1/TSC2 complex regulates protein translation through mainly mTORC1-dependent mechanisms and implicates a discrete profile of deregulated mRNA translation in tuberous sclerosis pathology.

Standard name | BILANGES_SERUM_SENSITIVE_VIA_TSC2
Systematic name | M2334
Organism | Mus musculus
PMID | 17562867
Authors | Bilanges B,Argonza-Barrett R,Kolesnichenko M,Skinner C,Nair M,Chen M,Stokoe D
Category | C2
Sub-category | CGP
Brief description | Genes translationally up-regulated by serum in MEF cells (embryonic fibroblast) lacking TSC2 [GeneID=7249].
Full description | The tuberous sclerosis complex (TSC) proteins TSC1 and TSC2 regulate protein translation by inhibiting the serine/threonine kinase mTORC1 (for mammalian target of rapamycin complex 1). However, how TSC1 and TSC2 control overall protein synthesis and the translation of specific mRNAs in response to different mitogenic and nutritional stimuli is largely unknown. We show here that serum withdrawal inhibits mTORC1 signaling, causes disassembly of translation initiation complexes, and causes mRNA redistribution from polysomes to subpolysomes in wild-type mouse embryo fibroblasts (MEFs). In contrast, these responses are defective in Tsc1(-/-) or Tsc2(-/-) MEFs. Microarray analysis of polysome- and subpolysome-associated mRNAs uncovered specific mRNAs that are translationally regulated by serum, 90% of which are TSC1 and TSC2 dependent. Surprisingly, the mTORC1 inhibitor, rapamycin, abolished mTORC1 activity but only affected approximately 40% of the serum-regulated mRNAs. Serum-dependent signaling through mTORC1 and polysome redistribution of global and individual mRNAs were restored upon re-expression of TSC1 and TSC2. Serum-responsive mRNAs that are sensitive to inhibition by rapamycin are highly enriched for terminal oligopyrimidine and for very short 5' and 3' untranslated regions. These data demonstrate that the TSC1/TSC2 complex regulates protein translation through mainly mTORC1-dependent mechanisms and implicates a discrete profile of deregulated mRNA translation in tuberous sclerosis pathology.

Standard name | BILANGES_SERUM_RESPONSE_TRANSLATION
Systematic name | M2337
Organism | Mus musculus
PMID | 17562867
Authors | Bilanges B,Argonza-Barrett R,Kolesnichenko M,Skinner C,Nair M,Chen M,Stokoe D
Category | C2
Sub-category | CGP
Brief description | Genes translationally repressed upon serum deprivation in MEF cells (embryonic fibroblast).
Full description | The tuberous sclerosis complex (TSC) proteins TSC1 and TSC2 regulate protein translation by inhibiting the serine/threonine kinase mTORC1 (for mammalian target of rapamycin complex 1). However, how TSC1 and TSC2 control overall protein synthesis and the translation of specific mRNAs in response to different mitogenic and nutritional stimuli is largely unknown. We show here that serum withdrawal inhibits mTORC1 signaling, causes disassembly of translation initiation complexes, and causes mRNA redistribution from polysomes to subpolysomes in wild-type mouse embryo fibroblasts (MEFs). In contrast, these responses are defective in Tsc1(-/-) or Tsc2(-/-) MEFs. Microarray analysis of polysome- and subpolysome-associated mRNAs uncovered specific mRNAs that are translationally regulated by serum, 90% of which are TSC1 and TSC2 dependent. Surprisingly, the mTORC1 inhibitor, rapamycin, abolished mTORC1 activity but only affected approximately 40% of the serum-regulated mRNAs. Serum-dependent signaling through mTORC1 and polysome redistribution of global and individual mRNAs were restored upon re-expression of TSC1 and TSC2. Serum-responsive mRNAs that are sensitive to inhibition by rapamycin are highly enriched for terminal oligopyrimidine and for very short 5' and 3' untranslated regions. These data demonstrate that the TSC1/TSC2 complex regulates protein translation through mainly mTORC1-dependent mechanisms and implicates a discrete profile of deregulated mRNA translation in tuberous sclerosis pathology.

Standard name | KIM_TIAL1_TARGETS
Systematic name | M2338
Organism | Homo sapiens
PMID | 17682065
Authors | Kim HS,Kuwano Y,Zhan M,Pullmann R Jr,Mazan-Mamczarz K,Li H,Kedersha N,Anderson P,Wilce MC,Gorospe M,Wilce JA
Category | C2
Sub-category | CGP
Brief description | Top scoring genes whose transcripts bound TIAR1 [GeneID=7073] in extracts from RKO cells (colon cancer).
Full description | The RNA-binding protein TIAR (related to TIA-1 [T-cell-restricted intracellular antigen 1]) was shown to associate with subsets of mRNAs bearing U-rich sequences in their 3' untranslated regions. TIAR can function as a translational repressor, particularly in response to cytotoxic agents. Using unstressed colon cancer cells, collections of mRNAs associated with TIAR were isolated by immunoprecipitation (IP) of (TIAR-RNA) ribonucleoprotein (RNP) complexes, identified by microarray analysis, and used to elucidate a common signature motif present among TIAR target transcripts. The predicted TIAR motif was an unexpectedly cytosine-rich, 28- to 32-nucleotide-long element forming a stem and a loop of variable size with an additional side loop. The ability of TIAR to bind an RNA oligonucleotide with a representative C-rich TIAR motif sequence was verified in vitro using surface plasmon resonance. By this analysis, TIAR containing two or three RNA recognition domains (TIAR12 and TIAR123) showed low but significant binding to the C-rich sequence. In vivo, insertion of the C-rich motif into a heterologous reporter strongly suppressed its translation in cultured cells. Using this signature motif, an additional approximately 2,209 UniGene targets were identified (2.0% of the total UniGene database). A subset of specific mRNAs were validated by RNP IP analysis. Interestingly, in response to treatment with short-wavelength UV light (UVC), a stress agent causing DNA damage, each of these target mRNAs bearing C-rich motifs dissociated from TIAR. In turn, expression of the encoded proteins was elevated in a TIAR-dependent manner. In sum, we report the identification of a C-rich signature motif present in TIAR target mRNAs whose association with TIAR decreases following exposure to a stress-causing agent.

Standard name | DUAN_PRDM5_TARGETS
Systematic name | M2339
Organism | Homo sapiens
PMID | 17636019
Authors | Duan Z,Person RE,Lee HH,Huang S,Donadieu J,Badolato R,Grimes HL,Papayannopoulou T,Horwitz MS
Category | C2
Sub-category | CGP
Brief description | Direct targets of PRDM5 [GeneID=11107].
Full description | Gfi1 transcriptionally governs hematopoiesis, and its mutations produce neutropenia. In an effort to identify Gfi1-interacting proteins and also to generate new candidate genes causing neutropenia, we performed a yeast two-hybrid screen with Gfi1. Among other Gfi1-interacting proteins, we identified a previously uncharacterized member of the PR domain-containing family of tumor suppressors, PRDM5. PRDM5 has 16 zinc fingers, and we show that it acts as a sequence-specific, DNA binding transcription factor that targets hematopoiesis-associated protein-coding and microRNA genes, including many that are also targets of Gfi1. PRDM5 epigenetically regulates transcription similarly to Gfi1: it recruits the histone methyltransferase G9a and class I histone deacetylases to its target gene promoters and demonstrates repressor activity on synthetic reporters; on endogenous target genes, however, it functions as an activator, in addition to a repressor. Interestingly, genes that PRDM5 activates, as opposed to those it represses, are also targets of Gfi1, suggesting a competitive mechanism through which two repressors could cooperate in order to become transcriptional activators. In neutropenic patients, we identified PRDM5 protein sequence variants perturbing transcriptional function, suggesting a potentially important role in hematopoiesis.

Standard name | DALESSIO_TSA_RESPONSE
Systematic name | M2340
Organism | Homo sapiens
PMID | 17709385
Authors | D'Alessio AC,Weaver IC,Szyf M
Category | C2
Sub-category | CGP
Brief description | Top genes up-regulated in HEK293 cells (fibroblast) in response to trichostatin A (TSA) [PubChem=5562].
Full description | A hallmark of vertebrate genes is that actively transcribed genes are hypomethylated in critical regulatory sequences. However, the mechanisms that link gene transcription and DNA hypomethylation are unclear. Using a trichostatin A (TSA)-induced replication-independent demethylation assay with HEK 293 cells, we show that RNA transcription is required for DNA demethylation. Histone acetylation precedes but is not sufficient to trigger DNA demethylation. Following histone acetylation, RNA polymerase II (RNAP II) interacts with the methylated promoter. Inhibition of RNAP II transcription with actinomycin D, alpha-amanitin, or CDK7-specific small interfering RNA inhibits DNA demethylation. H3 trimethyl lysine 4 methylation, a marker of actively transcribed genes, was associated with the cytomegalovirus promoter only after demethylation. TSA-induced demethylation of the endogenous cancer testis gene GAGE follows a similar sequence of events and is dependent on RNA transcription as well. These data suggest that DNA demethylation follows rather than precedes early transcription and point towards a novel function for DNA demethylation as a memory of actively transcribed genes.

Standard name | FEVR_CTNNB1_TARGETS_UP
Systematic name | M2342
Organism | Homo sapiens
PMID | 17785439
Authors | Fevr T,Robine S,Louvard D,Huelsken J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in intestinal crypt cells upon deletion of CTNNB1 [GeneID=1499].
Full description | The Wnt signaling pathway is deregulated in over 90% of human colorectal cancers. beta-Catenin, the central signal transducer of the Wnt pathway, can directly modulate gene expression by interacting with transcription factors of the TCF/LEF family. In the present study we investigate the role of Wnt signaling in the homeostasis of intestinal epithelium by using tissue-specific, inducible beta-catenin gene ablation in adult mice. Block of Wnt/beta-catenin signaling resulted in rapid loss of transient-amplifying cells and crypt structures. Importantly, intestinal stem cells were induced to terminally differentiate upon deletion of beta-catenin, resulting in a complete block of intestinal homeostasis and fatal loss of intestinal function. Transcriptional profiling of mutant crypt mRNA isolated by laser capture microdissection confirmed those observations and allowed us to identify genes potentially responsible for the functional preservation of intestinal stem cells. Our data demonstrate an essential requirement of Wnt/beta-catenin signaling for the maintenance of the intestinal epithelium in the adult organism. This challenges attempts to target aberrant Wnt signaling as a new therapeutic strategy to treat colorectal cancer.

Standard name | FEVR_CTNNB1_TARGETS_DN
Systematic name | M2343
Organism | Homo sapiens
PMID | 17785439
Authors | Fevr T,Robine S,Louvard D,Huelsken J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in intestinal crypt cells upon deletion of CTNNB1 [GeneID=1499].
Full description | The Wnt signaling pathway is deregulated in over 90% of human colorectal cancers. beta-Catenin, the central signal transducer of the Wnt pathway, can directly modulate gene expression by interacting with transcription factors of the TCF/LEF family. In the present study we investigate the role of Wnt signaling in the homeostasis of intestinal epithelium by using tissue-specific, inducible beta-catenin gene ablation in adult mice. Block of Wnt/beta-catenin signaling resulted in rapid loss of transient-amplifying cells and crypt structures. Importantly, intestinal stem cells were induced to terminally differentiate upon deletion of beta-catenin, resulting in a complete block of intestinal homeostasis and fatal loss of intestinal function. Transcriptional profiling of mutant crypt mRNA isolated by laser capture microdissection confirmed those observations and allowed us to identify genes potentially responsible for the functional preservation of intestinal stem cells. Our data demonstrate an essential requirement of Wnt/beta-catenin signaling for the maintenance of the intestinal epithelium in the adult organism. This challenges attempts to target aberrant Wnt signaling as a new therapeutic strategy to treat colorectal cancer.

Standard name | FARDIN_HYPOXIA_9
Systematic name | M2344
Organism | Homo sapiens
PMID | 19832978
Authors | Fardin P,Barla A,Mosci S,Rosasco L,Verri A,Varesio L
Category | C2
Sub-category | CGP
Brief description | Genes in the hypoxia signature, based on analysis of nine neuroblastoma cell lines in hypoxia and normal oxygen conditions.
Full description | Gene expression signatures are clusters of genes discriminating different statuses of the cells and their definition is critical for understanding the molecular bases of diseases. The identification of a gene signature is complicated by the high dimensional nature of the data and by the genetic heterogeneity of the responding cells. The l1-l2 regularization is an embedded feature selection technique that fulfills all the desirable properties of a variable selection algorithm and has the potential to generate a specific signature even in biologically complex settings. We studied the application of this algorithm to detect the signature characterizing the transcriptional response of neuroblastoma tumor cell lines to hypoxia, a condition of low oxygen tension that occurs in the tumor microenvironment.

Standard name | FARDIN_HYPOXIA_11
Systematic name | M2345
Organism | Homo sapiens
PMID | 20624283
Authors | Fardin P,Barla A,Mosci S,Rosasco L,Verri A,Versteeg R,Caron HN,Molenaar JJ,Ora I,Eva A,Puppo M,Varesio L
Category | C2
Sub-category | CGP
Brief description | Genes in the hypoxia signature, based on analysis of 11 neuroblastoma cell lines in hypoxia and normal oxygen conditions.
Full description | Hypoxia is a condition of low oxygen tension occurring in the tumor microenvironment and it is related to poor prognosis in human cancer. To examine the relationship between hypoxia and neuroblastoma, we generated and tested an in vitro derived hypoxia gene signature for its ability to predict patients' outcome.

Standard name | TORCHIA_TARGETS_OF_EWSR1_FLI1_FUSION_TOP20_UP
Systematic name | M2346
Organism | Mus musculus
PMID | 17875932
Authors | Torchia EC,Boyd K,Rehg JE,Qu C,Baker SJ
Category | C2
Sub-category | CGP
Brief description | Top 20 up-regulated genes in leukemic progenitor cells expressing activated fusion of ESWR1 and FLI1 [GeneID=2130, 2313] compared to normal hematopoetic progenitors.
Full description | EWS/FLI-1 is a chimeric oncogene generated by chromosomal translocation in Ewing tumors, a family of poorly differentiated pediatric tumors arising predominantly in bone but also in soft tissue. The fusion gene combines sequences encoding a strong transactivating domain from the EWS protein with the DNA binding domain of FLI-1, an ETS transcription factor. A related fusion, TLS/ERG, has been found in myeloid leukemia. To determine EWS/FLI-1 function in vivo, we engineered mice with Cre-inducible expression of EWS/FLI-1 from the ubiquitous Rosa26 locus. When crossed with Mx1-cre mice, Cre-mediated activation of EWS/FLI-1 resulted in the rapid development of myeloid/erythroid leukemia characterized by expansion of primitive mononuclear cells causing hepatomegaly, splenomegaly, severe anemia, and death. The disease could be transplanted serially into naïve recipients. Gene expression profiles of primary and transplanted animals were highly similar, suggesting that activation of EWS/FLI-1 was the primary event leading to disease in this model. The Cre-inducible EWS/FLI-1 mouse provides a novel model system to study the contribution of this oncogene to malignant disease in vivo.

Standard name | TORCHIA_TARGETS_OF_EWSR1_FLI1_FUSION_TOP20_DN
Systematic name | M2347
Organism | Mus musculus
PMID | 17875932
Authors | Torchia EC,Boyd K,Rehg JE,Qu C,Baker SJ
Category | C2
Sub-category | CGP
Brief description | Top 20 down-regulated genes in leukemic progenitor cells expressing activated fusion of ESWR1 and FLI1 [GeneID=2130, 2313] compared to normal hematopoetic progenitors.
Full description | EWS/FLI-1 is a chimeric oncogene generated by chromosomal translocation in Ewing tumors, a family of poorly differentiated pediatric tumors arising predominantly in bone but also in soft tissue. The fusion gene combines sequences encoding a strong transactivating domain from the EWS protein with the DNA binding domain of FLI-1, an ETS transcription factor. A related fusion, TLS/ERG, has been found in myeloid leukemia. To determine EWS/FLI-1 function in vivo, we engineered mice with Cre-inducible expression of EWS/FLI-1 from the ubiquitous Rosa26 locus. When crossed with Mx1-cre mice, Cre-mediated activation of EWS/FLI-1 resulted in the rapid development of myeloid/erythroid leukemia characterized by expansion of primitive mononuclear cells causing hepatomegaly, splenomegaly, severe anemia, and death. The disease could be transplanted serially into naïve recipients. Gene expression profiles of primary and transplanted animals were highly similar, suggesting that activation of EWS/FLI-1 was the primary event leading to disease in this model. The Cre-inducible EWS/FLI-1 mouse provides a novel model system to study the contribution of this oncogene to malignant disease in vivo.

Standard name | TORCHIA_TARGETS_OF_EWSR1_FLI1_FUSION_UP
Systematic name | M2348
Organism | Mus musculus
PMID | 17875932
Authors | Torchia EC,Boyd K,Rehg JE,Qu C,Baker SJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in leukemic progenitor cells expressing activated fusion of ESWR1 and FLI1 [GeneID=2130, 2313] compared to normal hematopoetic progenitors.
Full description | EWS/FLI-1 is a chimeric oncogene generated by chromosomal translocation in Ewing tumors, a family of poorly differentiated pediatric tumors arising predominantly in bone but also in soft tissue. The fusion gene combines sequences encoding a strong transactivating domain from the EWS protein with the DNA binding domain of FLI-1, an ETS transcription factor. A related fusion, TLS/ERG, has been found in myeloid leukemia. To determine EWS/FLI-1 function in vivo, we engineered mice with Cre-inducible expression of EWS/FLI-1 from the ubiquitous Rosa26 locus. When crossed with Mx1-cre mice, Cre-mediated activation of EWS/FLI-1 resulted in the rapid development of myeloid/erythroid leukemia characterized by expansion of primitive mononuclear cells causing hepatomegaly, splenomegaly, severe anemia, and death. The disease could be transplanted serially into naïve recipients. Gene expression profiles of primary and transplanted animals were highly similar, suggesting that activation of EWS/FLI-1 was the primary event leading to disease in this model. The Cre-inducible EWS/FLI-1 mouse provides a novel model system to study the contribution of this oncogene to malignant disease in vivo.

Standard name | TORCHIA_TARGETS_OF_EWSR1_FLI1_FUSION_DN
Systematic name | M2351
Organism | Mus musculus
PMID | 17875932
Authors | Torchia EC,Boyd K,Rehg JE,Qu C,Baker SJ
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in leukemic progenitor cells expressing activated fusion of ESWR1 and FLI1 [GeneID=2130, 2313] compared to normal hematopoetic progenitors.
Full description | EWS/FLI-1 is a chimeric oncogene generated by chromosomal translocation in Ewing tumors, a family of poorly differentiated pediatric tumors arising predominantly in bone but also in soft tissue. The fusion gene combines sequences encoding a strong transactivating domain from the EWS protein with the DNA binding domain of FLI-1, an ETS transcription factor. A related fusion, TLS/ERG, has been found in myeloid leukemia. To determine EWS/FLI-1 function in vivo, we engineered mice with Cre-inducible expression of EWS/FLI-1 from the ubiquitous Rosa26 locus. When crossed with Mx1-cre mice, Cre-mediated activation of EWS/FLI-1 resulted in the rapid development of myeloid/erythroid leukemia characterized by expansion of primitive mononuclear cells causing hepatomegaly, splenomegaly, severe anemia, and death. The disease could be transplanted serially into naïve recipients. Gene expression profiles of primary and transplanted animals were highly similar, suggesting that activation of EWS/FLI-1 was the primary event leading to disease in this model. The Cre-inducible EWS/FLI-1 mouse provides a novel model system to study the contribution of this oncogene to malignant disease in vivo.

Standard name | WINZEN_DEGRADED_VIA_KHSRP
Systematic name | M2352
Organism | Homo sapiens
PMID | 17908789
Authors | Winzen R,Thakur BK,Dittrich-Breiholz O,Shah M,Redich N,Dhamija S,Kracht M,Holtmann H
Category | C2
Sub-category | CGP
Brief description | Transcripts (mRNA molecules) rapidly degraded upon interaction with KHSRP [GeneID=8570].
Full description | mRNA stability is a major determinant of inflammatory gene expression. Rapid degradation of interleukin-8 (IL-8) mRNA is imposed by a bipartite AU-rich element (ARE) in the 3' untranslated region (R. Winzen et al., Mol. Cell. Biol. 24:4835-4847, 2004). Small interfering RNA-mediated knockdown of the ARE-binding protein KSRP resulted in stabilization of IL-8 mRNA or of a beta-globin reporter mRNA containing the IL-8 ARE. Rapid deadenylation was impaired, indicating a crucial role for KSRP in this step of mRNA degradation. The two IL-8 ARE domains both contribute to interaction with KSRP, corresponding to the importance of both domains for rapid degradation. Exposure to the inflammatory cytokine IL-1 has been shown to stabilize IL-8 mRNA through p38 mitogen-activated protein (MAP) kinase and MK2. IL-1 treatment impaired the interaction of KSRP with the IL-8 ARE in a manner dependent on p38 MAP kinase but apparently independent of MK2. Instead, evidence that TTP, a target of MK2, can also destabilize the IL-8 ARE reporter mRNA is presented. In a comprehensive approach to identify mRNAs controlled by KSRP, two criteria were evaluated by microarray analysis of (i) association of mRNAs with KSRP in pulldown assays and (ii) increased amounts in KSRP knockdown cells. According to both criteria, a group of 100 mRNAs is controlled by KSRP, many of which are unstable and encode proteins involved in inflammation. These results indicate that KSRP functions as a limiting factor in inflammatory gene expression.

Standard name | VANLOO_SP3_TARGETS_UP
Systematic name | M2353
Organism | Mus musculus
PMID | 17923686
Authors | van Loo PF,Mahtab EA,Wisse LJ,Hou J,Grosveld F,Suske G,Philipsen S,Gittenberger-de Groot AC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in E12.5 hearts from mice with SP3 [GeneID=6670] knockout compared to the wild type organ.
Full description | Mice lacking the zinc finger transcription factor specificity protein 3 (Sp3) die prenatally in the C57BL/6 background. To elucidate the cause of mortality we analyzed the potential role of Sp3 in embryonic heart development. Sp3 null hearts display defective looping at embryonic day 10.5 (E10.5), and at E14.5 the Sp3 null mutants have developed a range of severe cardiac malformations. In an attempt to position Sp3 in the cardiac developmental hierarchy, we analyzed the expression patterns of >15 marker genes in Sp3 null hearts. Expression of cardiac ankyrin repeat protein (Carp) was downregulated prematurely after E12.5, while expression of the other marker genes was not affected. Chromatin immunoprecipitation analysis revealed that Sp3 is bound to the Carp promoter region in vivo. Microarray analysis indicates that small-molecule metabolism and cell-cell interactions are the most significantly affected biological processes in E12.5 Sp3 null myocardium. Since the epicardium showed distension from the myocardium, we studied expression of Wt1, a marker for epicardial cells. Wt1 expression was diminished in epicardium-derived cells in the myocardium of Sp3 null hearts. We conclude that Sp3 is required for normal cardiac development and suggest that it has a crucial role in myocardial differentiation.

Standard name | VANLOO_SP3_TARGETS_DN
Systematic name | M2354
Organism | Mus musculus
PMID | 17923686
Authors | van Loo PF,Mahtab EA,Wisse LJ,Hou J,Grosveld F,Suske G,Philipsen S,Gittenberger-de Groot AC
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in E12.5 hearts from mice with SP3 [GeneID=6670] knockout compared to the wild type organ.
Full description | Mice lacking the zinc finger transcription factor specificity protein 3 (Sp3) die prenatally in the C57BL/6 background. To elucidate the cause of mortality we analyzed the potential role of Sp3 in embryonic heart development. Sp3 null hearts display defective looping at embryonic day 10.5 (E10.5), and at E14.5 the Sp3 null mutants have developed a range of severe cardiac malformations. In an attempt to position Sp3 in the cardiac developmental hierarchy, we analyzed the expression patterns of >15 marker genes in Sp3 null hearts. Expression of cardiac ankyrin repeat protein (Carp) was downregulated prematurely after E12.5, while expression of the other marker genes was not affected. Chromatin immunoprecipitation analysis revealed that Sp3 is bound to the Carp promoter region in vivo. Microarray analysis indicates that small-molecule metabolism and cell-cell interactions are the most significantly affected biological processes in E12.5 Sp3 null myocardium. Since the epicardium showed distension from the myocardium, we studied expression of Wt1, a marker for epicardial cells. Wt1 expression was diminished in epicardium-derived cells in the myocardium of Sp3 null hearts. We conclude that Sp3 is required for normal cardiac development and suggest that it has a crucial role in myocardial differentiation.

Standard name | YUAN_ZNF143_PARTNERS
Systematic name | M2355
Organism | Homo sapiens
PMID | 17938208
Authors | Yuan CC,Zhao X,Florens L,Swanson SK,Washburn MP,Hernandez N
Category | C2
Sub-category | CGP
Brief description | Proteins associated with ZNF143 [GeneID=7702] in HeLa cells, based on MudPIT analysis.
Full description | Chromatin remodeling and histone modification are essential for eukaryotic transcription regulation, but little is known about chromatin-modifying activities acting on RNA polymerase III (Pol III)-transcribed genes. The human U6 small nuclear RNA promoter, located 5' of the transcription start site, consists of a core region directing basal transcription and an activating region that recruits the transcription factors Oct-1 and Staf (ZNF143). Oct-1 activates transcription in part by helping recruit core binding factors, but nothing is known about the mechanisms of transcription activation by Staf. We show that Staf activates U6 transcription from a preassembled chromatin template in vitro and associates with several proteins linked to chromatin modification, among them chromodomain-helicase-DNA binding protein 8 (CHD8). CHD8 binds to histone H3 di- and trimethylated on lysine 4. It resides on the human U6 promoter as well as the mRNA IRF3 promoter in vivo and contributes to efficient transcription from both these promoters. Thus, Pol III transcription from type 3 promoters uses some of the same factors used for chromatin remodeling at Pol II promoters.

Standard name | KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3
Systematic name | M2356
Organism | Homo sapiens
PMID | 18955504
Authors | Koinuma D,Tsutsumi S,Kamimura N,Taniguchi H,Miyazawa K,Sunamura M,Imamura T,Miyazono K,Aburatani H
Category | C2
Sub-category | CGP
Brief description | Genes with promoters occupied by SMAD2 or SMAD3 [GeneID=4087, 4088] in HaCaT cells (keratinocyte) according to a ChIP-chip analysis.
Full description | The Smad2 and Smad3 (Smad2/3) proteins are principally involved in the transmission of transforming growth factor beta (TGF-beta) signaling from the plasma membrane to the nucleus. Many transcription factors have been shown to cooperate with the Smad2/3 proteins in regulating the transcription of target genes, enabling appropriate gene expression by cells. Here we identified 1,787 Smad2/3 binding sites in the promoter regions of over 25,500 genes by chromatin immunoprecipitation on microarray in HaCaT keratinocytes. Binding elements for the v-ets erythroblastosis virus E26 oncogene homolog (ETS) and transcription factor AP-2 (TFAP2) were significantly enriched in Smad2/3 binding sites, and knockdown of either ETS1 or TFAP2A resulted in overall alteration of TGF-beta-induced transcription, suggesting general roles for ETS1 and TFAP2A in the transcription induced by TGF-beta-Smad pathways. We identified novel Smad binding sites in the CDKN1A gene where Smad2/3 binding was regulated by ETS1 and TFAP2A. Moreover, we showed that small interfering RNAs for ETS1 and TFAP2A affected TGF-beta-induced cytostasis. We also analyzed Smad2- or Smad3-specific target genes regulated by TGF-beta and found that their specificity did not appear to be solely determined by the amounts of the Smad2/3 proteins bound to the promoters. These findings reveal novel regulatory mechanisms of Smad2/3-induced transcription and provide an essential resource for understanding their roles.

Standard name | RAFFEL_VEGFA_TARGETS_UP
Systematic name | M2357
Organism | Mus musculus
PMID | 18981216
Authors | Raffel GD,Chu GC,Jesneck JL,Cullen DE,Bronson RT,Bernard OA,Gilliland DG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hearts of E18.5 embryos upon knockout of VEGFA [GeneID=7422].
Full description | The infant leukemia-associated gene Ott1 (Rbm15) has broad regulatory effects within murine hematopoiesis. However, germ line Ott1 deletion results in fetal demise prior to embryonic day 10.5, indicating additional developmental requirements for Ott1. The spen gene family, to which Ott1 belongs, has a transcriptional activation/repression domain and RNA recognition motifs and has a significant role in the development of the head and thorax in Drosophila melanogaster. Early Ott1-deficient embryos show growth retardation and incomplete closure of the notochord. Further analysis demonstrated placental defects in the spongiotrophoblast and syncytiotrophoblast layers, resulting in an arrest of vascular branching morphogenesis. The rescue of the placental defect using a conditional allele with a trophoblast-sparing cre transgene allowed embryos to form a normal placenta and survive gestation. This outcome showed that the process of vascular branching morphogenesis in Ott1-deficient animals was regulated by the trophoblast compartment rather than the fetal vasculature. Mice surviving to term manifested hyposplenia and abnormal cardiac development. Analysis of global gene expression of Ott1-deficient embryonic hearts showed an enrichment of hypoxia-related genes and a significant alteration of several candidate genes critical for cardiac development. Thus, Ott1-dependent pathways, in addition to being implicated in leukemogenesis, may also be important for the pathogenesis of placental insufficiency and cardiac malformations.

Standard name | RAFFEL_VEGFA_TARGETS_DN
Systematic name | M2358
Organism | Mus musculus
PMID | 18981216
Authors | Raffel GD,Chu GC,Jesneck JL,Cullen DE,Bronson RT,Bernard OA,Gilliland DG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hearts of E18.5 embryos upon knockout of VEGFA [GeneID=7422].
Full description | The infant leukemia-associated gene Ott1 (Rbm15) has broad regulatory effects within murine hematopoiesis. However, germ line Ott1 deletion results in fetal demise prior to embryonic day 10.5, indicating additional developmental requirements for Ott1. The spen gene family, to which Ott1 belongs, has a transcriptional activation/repression domain and RNA recognition motifs and has a significant role in the development of the head and thorax in Drosophila melanogaster. Early Ott1-deficient embryos show growth retardation and incomplete closure of the notochord. Further analysis demonstrated placental defects in the spongiotrophoblast and syncytiotrophoblast layers, resulting in an arrest of vascular branching morphogenesis. The rescue of the placental defect using a conditional allele with a trophoblast-sparing cre transgene allowed embryos to form a normal placenta and survive gestation. This outcome showed that the process of vascular branching morphogenesis in Ott1-deficient animals was regulated by the trophoblast compartment rather than the fetal vasculature. Mice surviving to term manifested hyposplenia and abnormal cardiac development. Analysis of global gene expression of Ott1-deficient embryonic hearts showed an enrichment of hypoxia-related genes and a significant alteration of several candidate genes critical for cardiac development. Thus, Ott1-dependent pathways, in addition to being implicated in leukemogenesis, may also be important for the pathogenesis of placental insufficiency and cardiac malformations.

Standard name | TERAO_AOX4_TARGETS_HG_UP
Systematic name | M2360
Organism | Mus musculus
PMID | 18981221
Authors | Terao M,Kurosaki M,Barzago MM,Fratelli M,Bagnati R,Bastone A,Giudice C,Scanziani E,Mancuso A,Tiveron C,Garattini E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Harderian gland tissue upon knockout of AOX4 [GeneID=71872].
Full description | The mouse aldehyde oxidase AOH2 (aldehyde oxidase homolog 2) is a molybdoflavoenzyme. Harderian glands are the richest source of AOH2, although the protein is detectable also in sebaceous glands, epidermis, and other keratinized epithelia. The levels of AOH2 in the Harderian gland and skin are controlled by genetic background, being maximal in CD1 and C57BL/6 and minimal in DBA/2, CBA, and 129/Sv strains. Testosterone is a negative regulator of AOH2 in Harderian glands. Purified AOH2 oxidizes retinaldehyde into retinoic acid, while it is devoid of pyridoxal-oxidizing activity. Aoh2(-/-) mice, the first aldehyde oxidase knockout animals ever generated, are viable and fertile. The data obtained for this knockout model indicate a significant role of AOH2 in the local synthesis and biodisposition of endogenous retinoids in the Harderian gland and skin. The Harderian gland's transcriptome of knockout mice demonstrates overall downregulation of direct retinoid-dependent genes as well as perturbations in pathways controlling lipid homeostasis and cellular secretion, particularly in sexually immature animals. The skin of knockout mice is characterized by thickening of the epidermis in basal conditions and after UV light exposure. This has correlates in the corresponding transcriptome, which shows enrichment and overall upregulation of genes involved in hypertrophic responses.

Standard name | TERAO_AOX4_TARGETS_HG_DN
Systematic name | M2361
Organism | Mus musculus
PMID | 18981221
Authors | Terao M,Kurosaki M,Barzago MM,Fratelli M,Bagnati R,Bastone A,Giudice C,Scanziani E,Mancuso A,Tiveron C,Garattini E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Harderian gland tissue upon knockout of AOX4 [GeneID=71872].
Full description | The mouse aldehyde oxidase AOH2 (aldehyde oxidase homolog 2) is a molybdoflavoenzyme. Harderian glands are the richest source of AOH2, although the protein is detectable also in sebaceous glands, epidermis, and other keratinized epithelia. The levels of AOH2 in the Harderian gland and skin are controlled by genetic background, being maximal in CD1 and C57BL/6 and minimal in DBA/2, CBA, and 129/Sv strains. Testosterone is a negative regulator of AOH2 in Harderian glands. Purified AOH2 oxidizes retinaldehyde into retinoic acid, while it is devoid of pyridoxal-oxidizing activity. Aoh2(-/-) mice, the first aldehyde oxidase knockout animals ever generated, are viable and fertile. The data obtained for this knockout model indicate a significant role of AOH2 in the local synthesis and biodisposition of endogenous retinoids in the Harderian gland and skin. The Harderian gland's transcriptome of knockout mice demonstrates overall downregulation of direct retinoid-dependent genes as well as perturbations in pathways controlling lipid homeostasis and cellular secretion, particularly in sexually immature animals. The skin of knockout mice is characterized by thickening of the epidermis in basal conditions and after UV light exposure. This has correlates in the corresponding transcriptome, which shows enrichment and overall upregulation of genes involved in hypertrophic responses.

Standard name | TERAO_AOX4_TARGETS_SKIN_UP
Systematic name | M2362
Organism | Mus musculus
PMID | 18981221
Authors | Terao M,Kurosaki M,Barzago MM,Fratelli M,Bagnati R,Bastone A,Giudice C,Scanziani E,Mancuso A,Tiveron C,Garattini E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in skin upon knockout of AOX4 [GeneID=71872].
Full description | The mouse aldehyde oxidase AOH2 (aldehyde oxidase homolog 2) is a molybdoflavoenzyme. Harderian glands are the richest source of AOH2, although the protein is detectable also in sebaceous glands, epidermis, and other keratinized epithelia. The levels of AOH2 in the Harderian gland and skin are controlled by genetic background, being maximal in CD1 and C57BL/6 and minimal in DBA/2, CBA, and 129/Sv strains. Testosterone is a negative regulator of AOH2 in Harderian glands. Purified AOH2 oxidizes retinaldehyde into retinoic acid, while it is devoid of pyridoxal-oxidizing activity. Aoh2(-/-) mice, the first aldehyde oxidase knockout animals ever generated, are viable and fertile. The data obtained for this knockout model indicate a significant role of AOH2 in the local synthesis and biodisposition of endogenous retinoids in the Harderian gland and skin. The Harderian gland's transcriptome of knockout mice demonstrates overall downregulation of direct retinoid-dependent genes as well as perturbations in pathways controlling lipid homeostasis and cellular secretion, particularly in sexually immature animals. The skin of knockout mice is characterized by thickening of the epidermis in basal conditions and after UV light exposure. This has correlates in the corresponding transcriptome, which shows enrichment and overall upregulation of genes involved in hypertrophic responses.

Standard name | TERAO_AOX4_TARGETS_SKIN_DN
Systematic name | M2363
Organism | Mus musculus
PMID | 18981221
Authors | Terao M,Kurosaki M,Barzago MM,Fratelli M,Bagnati R,Bastone A,Giudice C,Scanziani E,Mancuso A,Tiveron C,Garattini E
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in skin upon knockout of AOX4 [GeneID=71872].
Full description | The mouse aldehyde oxidase AOH2 (aldehyde oxidase homolog 2) is a molybdoflavoenzyme. Harderian glands are the richest source of AOH2, although the protein is detectable also in sebaceous glands, epidermis, and other keratinized epithelia. The levels of AOH2 in the Harderian gland and skin are controlled by genetic background, being maximal in CD1 and C57BL/6 and minimal in DBA/2, CBA, and 129/Sv strains. Testosterone is a negative regulator of AOH2 in Harderian glands. Purified AOH2 oxidizes retinaldehyde into retinoic acid, while it is devoid of pyridoxal-oxidizing activity. Aoh2(-/-) mice, the first aldehyde oxidase knockout animals ever generated, are viable and fertile. The data obtained for this knockout model indicate a significant role of AOH2 in the local synthesis and biodisposition of endogenous retinoids in the Harderian gland and skin. The Harderian gland's transcriptome of knockout mice demonstrates overall downregulation of direct retinoid-dependent genes as well as perturbations in pathways controlling lipid homeostasis and cellular secretion, particularly in sexually immature animals. The skin of knockout mice is characterized by thickening of the epidermis in basal conditions and after UV light exposure. This has correlates in the corresponding transcriptome, which shows enrichment and overall upregulation of genes involved in hypertrophic responses.

Standard name | PURBEY_TARGETS_OF_CTBP1_AND_SATB1_UP
Systematic name | M2364
Organism | Homo sapiens
PMID | 19103759
Authors | Purbey PK,Singh S,Notani D,Kumar PP,Limaye AS,Galande S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HEK-293 cells (fibroblast) upon knockdown of both CTBP1 and SATB1 [GeneID=1487, 6304] by RNAi.
Full description | Special AT-rich binding protein 1 (SATB1) acts as a global regulator of gene expression by recruiting various corepressor or coactivator complexes, thereby establishing a unique chromatin structure at its genomic targets in a context-dependent manner. Although SATB1 acts predominantly as a repressor via recruitment of histone deacetylase 1 (HDAC1) complexes, the precise mechanism of global repression is not clear. Here we report that SATB1 and C-terminal binding protein 1 (CtBP1) form a repressor complex in vivo. The interaction occurs via the CtBP1 interaction consensus motif PVPLS within the PDZ-like domain of SATB1. The acetylation of SATB1 upon LiCl and ionomycin treatments disrupts its association with CtBP1, resulting in enhanced target gene expression. Chromatin immunoprecipitation analysis indicated that the occupancy of CtBP1 and HDAC1 is gradually decreased and the occupancy of PCAF is elevated at the SATB1 binding sites within the human interleukin-2 and mouse c-Myc promoters. Moreover, gene expression profiling studies using cells in which expression of SATB1 and CtBP1 was silenced indicated commonly targeted genes that may be coordinately repressed by the SATB1-CtBP1 complex. Collectively, these results provide a mechanistic insight into the role of SATB1-CtBP1 interaction in the repression and derepression of SATB1 target genes during Wnt signaling in T cells.

Standard name | PURBEY_TARGETS_OF_CTBP1_AND_SATB1_DN
Systematic name | M2365
Organism | Homo sapiens
PMID | 19103759
Authors | Purbey PK,Singh S,Notani D,Kumar PP,Limaye AS,Galande S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HEK-293 cells (fibroblast) upon knockdown of both CTBP1 and SATB1 [GeneID=1487, 6304] by RNAi.
Full description | Special AT-rich binding protein 1 (SATB1) acts as a global regulator of gene expression by recruiting various corepressor or coactivator complexes, thereby establishing a unique chromatin structure at its genomic targets in a context-dependent manner. Although SATB1 acts predominantly as a repressor via recruitment of histone deacetylase 1 (HDAC1) complexes, the precise mechanism of global repression is not clear. Here we report that SATB1 and C-terminal binding protein 1 (CtBP1) form a repressor complex in vivo. The interaction occurs via the CtBP1 interaction consensus motif PVPLS within the PDZ-like domain of SATB1. The acetylation of SATB1 upon LiCl and ionomycin treatments disrupts its association with CtBP1, resulting in enhanced target gene expression. Chromatin immunoprecipitation analysis indicated that the occupancy of CtBP1 and HDAC1 is gradually decreased and the occupancy of PCAF is elevated at the SATB1 binding sites within the human interleukin-2 and mouse c-Myc promoters. Moreover, gene expression profiling studies using cells in which expression of SATB1 and CtBP1 was silenced indicated commonly targeted genes that may be coordinately repressed by the SATB1-CtBP1 complex. Collectively, these results provide a mechanistic insight into the role of SATB1-CtBP1 interaction in the repression and derepression of SATB1 target genes during Wnt signaling in T cells.

Standard name | PURBEY_TARGETS_OF_CTBP1_NOT_SATB1_UP
Systematic name | M2366
Organism | Homo sapiens
PMID | 19103759
Authors | Purbey PK,Singh S,Notani D,Kumar PP,Limaye AS,Galande S
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HEK-293 cells (fibroblast) upon knockdown of CTBP1 but not of SATB1 [GeneID=1487, 6304] by RNAi.
Full description | Special AT-rich binding protein 1 (SATB1) acts as a global regulator of gene expression by recruiting various corepressor or coactivator complexes, thereby establishing a unique chromatin structure at its genomic targets in a context-dependent manner. Although SATB1 acts predominantly as a repressor via recruitment of histone deacetylase 1 (HDAC1) complexes, the precise mechanism of global repression is not clear. Here we report that SATB1 and C-terminal binding protein 1 (CtBP1) form a repressor complex in vivo. The interaction occurs via the CtBP1 interaction consensus motif PVPLS within the PDZ-like domain of SATB1. The acetylation of SATB1 upon LiCl and ionomycin treatments disrupts its association with CtBP1, resulting in enhanced target gene expression. Chromatin immunoprecipitation analysis indicated that the occupancy of CtBP1 and HDAC1 is gradually decreased and the occupancy of PCAF is elevated at the SATB1 binding sites within the human interleukin-2 and mouse c-Myc promoters. Moreover, gene expression profiling studies using cells in which expression of SATB1 and CtBP1 was silenced indicated commonly targeted genes that may be coordinately repressed by the SATB1-CtBP1 complex. Collectively, these results provide a mechanistic insight into the role of SATB1-CtBP1 interaction in the repression and derepression of SATB1 target genes during Wnt signaling in T cells.

Standard name | PURBEY_TARGETS_OF_CTBP1_NOT_SATB1_DN
Systematic name | M2367
Organism | Homo sapiens
PMID | 19103759
Authors | Purbey PK,Singh S,Notani D,Kumar PP,Limaye AS,Galande S
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HEK-293 cells (fibroblast) upon knockdown of CTBP1 but not of SATB1 [GeneID=1487, 6304] by RNAi.
Full description | Special AT-rich binding protein 1 (SATB1) acts as a global regulator of gene expression by recruiting various corepressor or coactivator complexes, thereby establishing a unique chromatin structure at its genomic targets in a context-dependent manner. Although SATB1 acts predominantly as a repressor via recruitment of histone deacetylase 1 (HDAC1) complexes, the precise mechanism of global repression is not clear. Here we report that SATB1 and C-terminal binding protein 1 (CtBP1) form a repressor complex in vivo. The interaction occurs via the CtBP1 interaction consensus motif PVPLS within the PDZ-like domain of SATB1. The acetylation of SATB1 upon LiCl and ionomycin treatments disrupts its association with CtBP1, resulting in enhanced target gene expression. Chromatin immunoprecipitation analysis indicated that the occupancy of CtBP1 and HDAC1 is gradually decreased and the occupancy of PCAF is elevated at the SATB1 binding sites within the human interleukin-2 and mouse c-Myc promoters. Moreover, gene expression profiling studies using cells in which expression of SATB1 and CtBP1 was silenced indicated commonly targeted genes that may be coordinately repressed by the SATB1-CtBP1 complex. Collectively, these results provide a mechanistic insight into the role of SATB1-CtBP1 interaction in the repression and derepression of SATB1 target genes during Wnt signaling in T cells.

Standard name | GOBERT_OLIGODENDROCYTE_DIFFERENTIATION_UP
Systematic name | M2368
Organism | Mus musculus
PMID | 19139271
Authors | Gobert RP,Joubert L,Curchod ML,Salvat C,Foucault I,Jorand-Lebrun C,Lamarine M,Peixoto H,Vignaud C,Frémaux C,Jomotte T,Françon B,Alliod C,Bernasconi L,Abderrahim H,Perrin D,Bombrun A,Zanoguera F,Rommel C,Huijsduijnen van Hooft R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during later stage of differentiation of Oli-Neu cells (oligodendroglial precursor) in response to PD174265 [PubChem=4709].
Full description | Inadequate remyelination of brain white matter lesions has been associated with a failure of oligodendrocyte precursors to differentiate into mature, myelin-producing cells. In order to better understand which genes play a critical role in oligodendrocyte differentiation, we performed time-dependent, genome-wide gene expression studies of mouse Oli-neu cells as they differentiate into process-forming and myelin basic protein-producing cells, following treatment with three different agents. Our data indicate that different inducers activate distinct pathways that ultimately converge into the completely differentiated state, where regulated gene sets overlap maximally. In order to also gain insight into the functional role of genes that are regulated in this process, we silenced 88 of these genes using small interfering RNA and identified multiple repressors of spontaneous differentiation of Oli-neu, most of which were confirmed in rat primary oligodendrocyte precursors cells. Among these repressors were CNP, a well-known myelin constituent, and three phosphatases, each known to negatively control mitogen-activated protein kinase cascades. We show that a novel inhibitor for one of the identified genes, dual-specificity phosphatase DUSP10/MKP5, was also capable of inducing oligodendrocyte differentiation in primary oligodendrocyte precursors. Oligodendrocytic differentiation feedback loops may therefore yield pharmacological targets to treat disease related to dysfunctional myelin deposition.

Standard name | GOBERT_OLIGODENDROCYTE_DIFFERENTIATION_DN
Systematic name | M2369
Organism | Mus musculus
PMID | 19139271
Authors | Gobert RP,Joubert L,Curchod ML,Salvat C,Foucault I,Jorand-Lebrun C,Lamarine M,Peixoto H,Vignaud C,Frémaux C,Jomotte T,Françon B,Alliod C,Bernasconi L,Abderrahim H,Perrin D,Bombrun A,Zanoguera F,Rommel C,Huijsduijnen van Hooft R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during differentiation of Oli-Neu cells (oligodendroglial precursor) in response to PD174265 [PubChem=4709].
Full description | Inadequate remyelination of brain white matter lesions has been associated with a failure of oligodendrocyte precursors to differentiate into mature, myelin-producing cells. In order to better understand which genes play a critical role in oligodendrocyte differentiation, we performed time-dependent, genome-wide gene expression studies of mouse Oli-neu cells as they differentiate into process-forming and myelin basic protein-producing cells, following treatment with three different agents. Our data indicate that different inducers activate distinct pathways that ultimately converge into the completely differentiated state, where regulated gene sets overlap maximally. In order to also gain insight into the functional role of genes that are regulated in this process, we silenced 88 of these genes using small interfering RNA and identified multiple repressors of spontaneous differentiation of Oli-neu, most of which were confirmed in rat primary oligodendrocyte precursors cells. Among these repressors were CNP, a well-known myelin constituent, and three phosphatases, each known to negatively control mitogen-activated protein kinase cascades. We show that a novel inhibitor for one of the identified genes, dual-specificity phosphatase DUSP10/MKP5, was also capable of inducing oligodendrocyte differentiation in primary oligodendrocyte precursors. Oligodendrocytic differentiation feedback loops may therefore yield pharmacological targets to treat disease related to dysfunctional myelin deposition.

Standard name | GOBERT_CORE_OLIGODENDROCYTE_DIFFERENTIATION
Systematic name | M2370
Organism | Mus musculus
PMID | 19139271
Authors | Gobert RP,Joubert L,Curchod ML,Salvat C,Foucault I,Jorand-Lebrun C,Lamarine M,Peixoto H,Vignaud C,Frémaux C,Jomotte T,Françon B,Alliod C,Bernasconi L,Abderrahim H,Perrin D,Bombrun A,Zanoguera F,Rommel C,Huijsduijnen van Hooft R
Category | C2
Sub-category | CGP
Brief description | Oligodendrocyte core differentiation genes: up-regulated in Oli-neo cells (oligodendroglial precursor) at 10 h after treatment with PD174265, dexamethasone or isotretinoin [PubChem=4709, 5743, 5282379].
Full description | Inadequate remyelination of brain white matter lesions has been associated with a failure of oligodendrocyte precursors to differentiate into mature, myelin-producing cells. In order to better understand which genes play a critical role in oligodendrocyte differentiation, we performed time-dependent, genome-wide gene expression studies of mouse Oli-neu cells as they differentiate into process-forming and myelin basic protein-producing cells, following treatment with three different agents. Our data indicate that different inducers activate distinct pathways that ultimately converge into the completely differentiated state, where regulated gene sets overlap maximally. In order to also gain insight into the functional role of genes that are regulated in this process, we silenced 88 of these genes using small interfering RNA and identified multiple repressors of spontaneous differentiation of Oli-neu, most of which were confirmed in rat primary oligodendrocyte precursors cells. Among these repressors were CNP, a well-known myelin constituent, and three phosphatases, each known to negatively control mitogen-activated protein kinase cascades. We show that a novel inhibitor for one of the identified genes, dual-specificity phosphatase DUSP10/MKP5, was also capable of inducing oligodendrocyte differentiation in primary oligodendrocyte precursors. Oligodendrocytic differentiation feedback loops may therefore yield pharmacological targets to treat disease related to dysfunctional myelin deposition.

Standard name | WACKER_HYPOXIA_TARGETS_OF_VHL
Systematic name | M2371
Organism | Homo sapiens
PMID | 19158274
Authors | Wacker I,Sachs M,Knaup K,Wiesener M,Weiske J,Huber O,Akçetin Z,Behrens J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by VHL [GeneID=7428] and re-expressed under hypoxia conditions in renal carcinoma cells.
Full description | The von Hippel-Lindau tumor suppressor gene (VHL) is mutated in clear cell renal cell carcinomas (RCC), leading to the activation of hypoxia-inducible factor (HIF)-mediated gene transcription. Several VHL/HIF targets, such as glycolysis, angiogenesis, cell growth, and chemotaxis of tumor cells, have been implicated in the transformed phenotype of RCC-regulating properties. Here, we show that VHL suppresses key features of cell transformation through downregulation of the HIF-dependent expression of activin B, a member of the transforming growth factor beta superfamily. Activin B expression is repressed by restoration of VHL in VHL-deficient RCC cells and upregulated by hypoxia. RCC tumor samples show increased expression of activin B compared to that in the normal kidney. VHL increases cell adhesion to the extracellular matrix, promotes cell flattening, and reduces invasiveness. These effects are completely phenocopied by RNA interference-mediated knockdown of activin B and reverted by treatment with recombinant activin B. Finally, knockdown of activin B reduces tumor growth of RCC cells in nude mice. Our data indicate that activin B is a key mediator of VHL/HIF-induced transformation in RCC.

Standard name | IKEDA_MIR1_TARGETS_UP
Systematic name | M2372
Organism | Mus musculus
PMID | 19188439
Authors | Ikeda S,He A,Kong SW,Lu J,Bejar R,Bodyak N,Lee KH,Ma Q,Kang PM,Golub TR,Pu WT
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hypertrophic hearts (due to expression of constitutively active form of PPP3CA [GeneID=5530]) and predicted to be targets of miR-1 microRNA.
Full description | Calcium signaling is a central regulator of cardiomyocyte growth and function. Calmodulin is a critical mediator of calcium signals. Because the amount of calmodulin within cardiomyocytes is limiting, the precise control of calmodulin expression is important for the regulation of calcium signaling. In this study, we show for the first time that calmodulin levels are regulated posttranscriptionally in heart failure. The cardiomyocyte-restricted microRNA miR-1 inhibited the translation of calmodulin-encoding mRNAs via highly conserved target sites within their 3' untranslated regions. In keeping with its effect on calmodulin expression, miR-1 downregulated calcium-calmodulin signaling through calcineurin to NFAT. miR-1 also negatively regulated the expression of Mef2a and Gata4, key transcription factors that mediate calcium-dependent changes in gene expression. Consistent with the downregulation of these hypertrophy-associated genes, miR-1 attenuated cardiomyocyte hypertrophy in cultured neonatal rat cardiomyocytes and in the intact adult heart. Our data indicate that miR-1 regulates cardiomyocyte growth responses by negatively regulating the calcium signaling components calmodulin, Mef2a, and Gata4.

Standard name | IKEDA_MIR1_TARGETS_DN
Systematic name | M2376
Organism | Mus musculus
PMID | 19188439
Authors | Ikeda S,He A,Kong SW,Lu J,Bejar R,Bodyak N,Lee KH,Ma Q,Kang PM,Golub TR,Pu WT
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hypertrophic hearts (due to expression of constitutively active form of PPP3CA [GeneID=5530]) and predicted to be targets of miR-1 microRNA.
Full description | Calcium signaling is a central regulator of cardiomyocyte growth and function. Calmodulin is a critical mediator of calcium signals. Because the amount of calmodulin within cardiomyocytes is limiting, the precise control of calmodulin expression is important for the regulation of calcium signaling. In this study, we show for the first time that calmodulin levels are regulated posttranscriptionally in heart failure. The cardiomyocyte-restricted microRNA miR-1 inhibited the translation of calmodulin-encoding mRNAs via highly conserved target sites within their 3' untranslated regions. In keeping with its effect on calmodulin expression, miR-1 downregulated calcium-calmodulin signaling through calcineurin to NFAT. miR-1 also negatively regulated the expression of Mef2a and Gata4, key transcription factors that mediate calcium-dependent changes in gene expression. Consistent with the downregulation of these hypertrophy-associated genes, miR-1 attenuated cardiomyocyte hypertrophy in cultured neonatal rat cardiomyocytes and in the intact adult heart. Our data indicate that miR-1 regulates cardiomyocyte growth responses by negatively regulating the calcium signaling components calmodulin, Mef2a, and Gata4.

Standard name | IKEDA_MIR133_TARGETS_UP
Systematic name | M2377
Organism | Mus musculus
PMID | 19188439
Authors | Ikeda S,He A,Kong SW,Lu J,Bejar R,Bodyak N,Lee KH,Ma Q,Kang PM,Golub TR,Pu WT
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hypertrophic hearts (due to expression of constitutively active form of PPP3CA [GeneID=5530]) and predicted to be targets of miR-133 microRNA.
Full description | Calcium signaling is a central regulator of cardiomyocyte growth and function. Calmodulin is a critical mediator of calcium signals. Because the amount of calmodulin within cardiomyocytes is limiting, the precise control of calmodulin expression is important for the regulation of calcium signaling. In this study, we show for the first time that calmodulin levels are regulated posttranscriptionally in heart failure. The cardiomyocyte-restricted microRNA miR-1 inhibited the translation of calmodulin-encoding mRNAs via highly conserved target sites within their 3' untranslated regions. In keeping with its effect on calmodulin expression, miR-1 downregulated calcium-calmodulin signaling through calcineurin to NFAT. miR-1 also negatively regulated the expression of Mef2a and Gata4, key transcription factors that mediate calcium-dependent changes in gene expression. Consistent with the downregulation of these hypertrophy-associated genes, miR-1 attenuated cardiomyocyte hypertrophy in cultured neonatal rat cardiomyocytes and in the intact adult heart. Our data indicate that miR-1 regulates cardiomyocyte growth responses by negatively regulating the calcium signaling components calmodulin, Mef2a, and Gata4.

Standard name | IKEDA_MIR133_TARGETS_DN
Systematic name | M2378
Organism | Mus musculus
PMID | 19188439
Authors | Ikeda S,He A,Kong SW,Lu J,Bejar R,Bodyak N,Lee KH,Ma Q,Kang PM,Golub TR,Pu WT
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hypertrophic hearts (due to expression of constitutively active form of PPP3CA [GeneID=5530]) and predicted to be targets of miR-133 microRNA.
Full description | Calcium signaling is a central regulator of cardiomyocyte growth and function. Calmodulin is a critical mediator of calcium signals. Because the amount of calmodulin within cardiomyocytes is limiting, the precise control of calmodulin expression is important for the regulation of calcium signaling. In this study, we show for the first time that calmodulin levels are regulated posttranscriptionally in heart failure. The cardiomyocyte-restricted microRNA miR-1 inhibited the translation of calmodulin-encoding mRNAs via highly conserved target sites within their 3' untranslated regions. In keeping with its effect on calmodulin expression, miR-1 downregulated calcium-calmodulin signaling through calcineurin to NFAT. miR-1 also negatively regulated the expression of Mef2a and Gata4, key transcription factors that mediate calcium-dependent changes in gene expression. Consistent with the downregulation of these hypertrophy-associated genes, miR-1 attenuated cardiomyocyte hypertrophy in cultured neonatal rat cardiomyocytes and in the intact adult heart. Our data indicate that miR-1 regulates cardiomyocyte growth responses by negatively regulating the calcium signaling components calmodulin, Mef2a, and Gata4.

Standard name | IKEDA_MIR30_TARGETS_UP
Systematic name | M2379
Organism | Mus musculus
PMID | 19188439
Authors | Ikeda S,He A,Kong SW,Lu J,Bejar R,Bodyak N,Lee KH,Ma Q,Kang PM,Golub TR,Pu WT
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in hypertrophic hearts (due to expression of constitutively active form of PPP3CA [GeneID=5530]) and predicted to be targets of miR-30 microRNA.
Full description | Calcium signaling is a central regulator of cardiomyocyte growth and function. Calmodulin is a critical mediator of calcium signals. Because the amount of calmodulin within cardiomyocytes is limiting, the precise control of calmodulin expression is important for the regulation of calcium signaling. In this study, we show for the first time that calmodulin levels are regulated posttranscriptionally in heart failure. The cardiomyocyte-restricted microRNA miR-1 inhibited the translation of calmodulin-encoding mRNAs via highly conserved target sites within their 3' untranslated regions. In keeping with its effect on calmodulin expression, miR-1 downregulated calcium-calmodulin signaling through calcineurin to NFAT. miR-1 also negatively regulated the expression of Mef2a and Gata4, key transcription factors that mediate calcium-dependent changes in gene expression. Consistent with the downregulation of these hypertrophy-associated genes, miR-1 attenuated cardiomyocyte hypertrophy in cultured neonatal rat cardiomyocytes and in the intact adult heart. Our data indicate that miR-1 regulates cardiomyocyte growth responses by negatively regulating the calcium signaling components calmodulin, Mef2a, and Gata4.

Standard name | IKEDA_MIR30_TARGETS_DN
Systematic name | M2380
Organism | Mus musculus
PMID | 19188439
Authors | Ikeda S,He A,Kong SW,Lu J,Bejar R,Bodyak N,Lee KH,Ma Q,Kang PM,Golub TR,Pu WT
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in hypertrophic hearts (due to expression of constitutively active form of PPP3CA [GeneID=5530]) and predicted to be targets of miR-30 microRNA.
Full description | Calcium signaling is a central regulator of cardiomyocyte growth and function. Calmodulin is a critical mediator of calcium signals. Because the amount of calmodulin within cardiomyocytes is limiting, the precise control of calmodulin expression is important for the regulation of calcium signaling. In this study, we show for the first time that calmodulin levels are regulated posttranscriptionally in heart failure. The cardiomyocyte-restricted microRNA miR-1 inhibited the translation of calmodulin-encoding mRNAs via highly conserved target sites within their 3' untranslated regions. In keeping with its effect on calmodulin expression, miR-1 downregulated calcium-calmodulin signaling through calcineurin to NFAT. miR-1 also negatively regulated the expression of Mef2a and Gata4, key transcription factors that mediate calcium-dependent changes in gene expression. Consistent with the downregulation of these hypertrophy-associated genes, miR-1 attenuated cardiomyocyte hypertrophy in cultured neonatal rat cardiomyocytes and in the intact adult heart. Our data indicate that miR-1 regulates cardiomyocyte growth responses by negatively regulating the calcium signaling components calmodulin, Mef2a, and Gata4.

Standard name | KUWANO_RNA_STABILIZED_BY_NO
Systematic name | M2381
Organism | Mus musculus
PMID | 19289500
Authors | Kuwano Y,Rabinovic A,Srikantan S,Gorospe M,Demple B
Category | C2
Sub-category | CGP
Brief description | Transcripts stabilized by NO [PubChem=145068] identified as up-regulated by NO [PubChem=145068] in the presence of actinomycin D [PubChemiD=2019] in IMR-90 and NIH 3T3 cells (fibroblast).
Full description | We previously observed that nitric oxide (NO) exposure increases the stability of mRNAs encoding heme oxygenase 1 (HO-1) and TIEG-1 in human and mouse fibroblasts. Here, we have used microarrays to look broadly for changes in mRNA stability in response to NO treatment. Using human IMR-90 and mouse NIH 3T3 fibroblasts treated with actinomycin D to block de novo transcription, microarray analysis suggested that the stability of the majority of mRNAs was unaffected. Among the mRNAs that were stabilized by NO treatment, seven transcripts were found in both IMR-90 and NIH 3T3 cells (CHIC2, GADD45B, HO-1, PTGS2, RGS2, TIEG, and ID3) and were chosen for further analysis. All seven mRNAs showed at least one hit of a signature motif for the stabilizing RNA-binding protein (RBP) HuR; accordingly, ribonucleoprotein immunoprecipitation analysis revealed that all seven mRNAs associated with HuR. In keeping with a functional role of HuR in the response to NO, a measurable fraction of HuR increased in the cytoplasm following NO treatment. However, among the seven transcripts, only HO-1 mRNA showed a robust increase in the level of its association with HuR following NO treatment. In turn, HO-1 mRNA and protein levels were significantly reduced when HuR levels were silenced in IMR-90 cells, and they were elevated when HuR was overexpressed. In sum, our results indicate that NO stabilizes mRNA subsets in fibroblasts, identify HuR as an RBP implicated in the NO response, reveal that HuR alone is insufficient for stabilizing several mRNAs by NO, and show that HO-1 induction by NO is regulated by HuR.

Standard name | LIU_TOPBP1_TARGETS
Systematic name | M2382
Organism | Homo sapiens
PMID | 19289498
Authors | Liu K,Bellam N,Lin HY,Wang B,Stockard CR,Grizzle WE,Lin WC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in U2OS cells (osteosarcoma) upon knockdown of TOPBP1 [GeneID=11073].
Full description | Proper control of the G(1)/S checkpoint is essential for normal proliferation. The activity of p53 must be kept at a very low level under unstressed conditions to allow growth. Here we provide evidence supporting a crucial role for TopBP1 in actively repressing p53. Depletion of TopBP1 upregulates p53 target genes involved in cell cycle arrest and apoptosis and enhances DNA damage-induced apoptosis. The regulation is mediated by an interaction between the seventh and eighth BRCT domains of TopBP1 and the DNA-binding domain of p53, leading to inhibition of p53 promoter binding activity. Importantly, TopBP1 overexpression is found in 46 of 79 primary breast cancer tissues and is associated with high tumor grade and shorter patient survival time. Overexpression of TopBP1 to a level comparable to that seen in breast tumors leads to inhibition of p53 target gene expression and DNA damage-induced apoptosis and G(1) arrest. Thus, a physiological level of TopBP1 is essential for normal G(1)/S transition, but a pathological level of TopBP1 in cancer may perturb p53 function and contribute to an aggressive tumor behavior.

Standard name | SCHMIDT_POR_TARGETS_IN_LIMB_BUD_UP
Systematic name | M2383
Organism | Mus musculus
PMID | 19273610
Authors | Schmidt K,Hughes C,Chudek JA,Goodyear SR,Aspden RM,Talbot R,Gundersen TE,Blomhoff R,Henderson C,Wolf CR,Tickle C
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in E12.5 forelimb buds with POR [GeneID=5447] knockout.
Full description | Cytochrome P450 oxidoreductase (POR) is the obligate electron donor for all microsomal cytochrome P450 enzymes, which catalyze the metabolism of a wide spectrum of xenobiotic and endobiotic compounds. Point mutations in POR have been found recently in patients with Antley-Bixler-like syndrome, which includes limb skeletal defects. In order to study P450 function during limb and skeletal development, we deleted POR specifically in mouse limb bud mesenchyme. Forelimbs and hind limbs in conditional knockout (CKO) mice were short with thin skeletal elements and fused joints. POR deletion occurred earlier in forelimbs than in hind limbs, leading additionally to soft tissue syndactyly and loss of wrist elements and phalanges due to changes in growth, cell death, and skeletal segmentation. Transcriptional analysis of E12.5 mouse forelimb buds demonstrated the expression of P450s involved in retinoic acid, cholesterol, and arachidonic acid metabolism. Biochemical analysis of CKO limbs confirmed retinoic acid excess. In CKO limbs, expression of genes throughout the whole cholesterol biosynthetic pathway was upregulated, and cholesterol deficiency can explain most aspects of the phenotype. Thus, cellular POR-dependent cholesterol synthesis is essential during limb and skeletal development. Modulation of P450 activity could contribute to susceptibility of the embryo and developing organs to teratogenesis.

Standard name | SCHMIDT_POR_TARGETS_IN_LIMB_BUD_DN
Systematic name | M2384
Organism | Mus musculus
PMID | 19273610
Authors | Schmidt K,Hughes C,Chudek JA,Goodyear SR,Aspden RM,Talbot R,Gundersen TE,Blomhoff R,Henderson C,Wolf CR,Tickle C
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in E12.5 forelimb buds with POR [GeneID=5447] knockout.
Full description | Cytochrome P450 oxidoreductase (POR) is the obligate electron donor for all microsomal cytochrome P450 enzymes, which catalyze the metabolism of a wide spectrum of xenobiotic and endobiotic compounds. Point mutations in POR have been found recently in patients with Antley-Bixler-like syndrome, which includes limb skeletal defects. In order to study P450 function during limb and skeletal development, we deleted POR specifically in mouse limb bud mesenchyme. Forelimbs and hind limbs in conditional knockout (CKO) mice were short with thin skeletal elements and fused joints. POR deletion occurred earlier in forelimbs than in hind limbs, leading additionally to soft tissue syndactyly and loss of wrist elements and phalanges due to changes in growth, cell death, and skeletal segmentation. Transcriptional analysis of E12.5 mouse forelimb buds demonstrated the expression of P450s involved in retinoic acid, cholesterol, and arachidonic acid metabolism. Biochemical analysis of CKO limbs confirmed retinoic acid excess. In CKO limbs, expression of genes throughout the whole cholesterol biosynthetic pathway was upregulated, and cholesterol deficiency can explain most aspects of the phenotype. Thus, cellular POR-dependent cholesterol synthesis is essential during limb and skeletal development. Modulation of P450 activity could contribute to susceptibility of the embryo and developing organs to teratogenesis.

Standard name | KATSANOU_ELAVL1_TARGETS_UP
Systematic name | M2385
Organism | Mus musculus
PMID | 19307312
Authors | Katsanou V,Milatos S,Yiakouvaki A,Sgantzis N,Kotsoni A,Alexiou M,Harokopos V,Aidinis V,Hemberger M,Kontoyiannis DL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) with ELAVL1 [GeneID=1994] knocked out.
Full description | HuR is an RNA-binding protein implicated in a diverse array of pathophysiological processes due to its effects on the posttranscriptional regulation of AU- and U-rich mRNAs. Here we reveal HuR's requirement in embryonic development through its genetic ablation. Obligatory HuR-null embryos exhibited a stage retardation phenotype and failed to survive beyond midgestation. By means of conditional transgenesis, we restricted HuR's mutation in either embryonic or endothelial compartments to demonstrate that embryonic lethality is consequent to defects in extraembryonic placenta. HuR's absence impaired the invagination of allantoic capillaries into the chorionic trophoblast layer and the differentiation of syncytiotrophoblast cells that control the morphogenesis and vascularization of the placental labyrinth and fetal support. HuR-null embryos rescued from these placental defects proceeded to subsequent developmental stages but displayed defects in skeletal ossification, fusions in limb elements, and asplenia. By coupling gene expression measurements, data meta-analysis, and HuR-RNA association assays, we identified transcription and growth factor mRNAs controlled by HuR, primarily at the posttranscriptional level, to guide morphogenesis, specification, and patterning. Collectively, our data demonstrate the dominant role of HuR in organizing gene expression programs guiding placental labyrinth morphogenesis, skeletal specification patterns, and splenic ontogeny.

Standard name | KATSANOU_ELAVL1_TARGETS_DN
Systematic name | M2387
Organism | Mus musculus
PMID | 19307312
Authors | Katsanou V,Milatos S,Yiakouvaki A,Sgantzis N,Kotsoni A,Alexiou M,Harokopos V,Aidinis V,Hemberger M,Kontoyiannis DL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblast) with ELAVL1 [GeneID=1994] knocked out.
Full description | HuR is an RNA-binding protein implicated in a diverse array of pathophysiological processes due to its effects on the posttranscriptional regulation of AU- and U-rich mRNAs. Here we reveal HuR's requirement in embryonic development through its genetic ablation. Obligatory HuR-null embryos exhibited a stage retardation phenotype and failed to survive beyond midgestation. By means of conditional transgenesis, we restricted HuR's mutation in either embryonic or endothelial compartments to demonstrate that embryonic lethality is consequent to defects in extraembryonic placenta. HuR's absence impaired the invagination of allantoic capillaries into the chorionic trophoblast layer and the differentiation of syncytiotrophoblast cells that control the morphogenesis and vascularization of the placental labyrinth and fetal support. HuR-null embryos rescued from these placental defects proceeded to subsequent developmental stages but displayed defects in skeletal ossification, fusions in limb elements, and asplenia. By coupling gene expression measurements, data meta-analysis, and HuR-RNA association assays, we identified transcription and growth factor mRNAs controlled by HuR, primarily at the posttranscriptional level, to guide morphogenesis, specification, and patterning. Collectively, our data demonstrate the dominant role of HuR in organizing gene expression programs guiding placental labyrinth morphogenesis, skeletal specification patterns, and splenic ontogeny.

Standard name | WANG_THOC1_TARGETS_UP
Systematic name | M2390
Organism | Mus musculus
PMID | 19307311
Authors | Wang X,Chinnam M,Wang J,Wang Y,Zhang X,Marcon E,Moens P,Goodrich DW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in testis tissue expressing hypomorphic allele of THOC1 [GeneID=9984].
Full description | Accumulating evidence suggests that regulation of RNA processing through an RNP-driven mechanism is important for coordinated gene expression. This hypothesis predicts that defects in RNP biogenesis will adversely affect the elaboration of specific gene expression programs. To explore the role of RNP biogenesis on mammalian development, we have characterized the phenotype of mice hypomorphic for Thoc1. Thoc1 encodes an essential component of the evolutionarily conserved TREX complex. TREX accompanies the elongating RNA polymerase II and facilitates RNP assembly and recruitment of RNA processing factors. Hypomorphic Thoc1 mice are viable despite significantly reduced Thoc1 expression in the tissues examined. While most tissues of Thoc1-deficient mice appear to develop and function normally, gametogenesis is severely compromised. Male infertility is associated with a loss in spermatocyte viability and abnormal endocrine signaling. We suggest that loss of spermatocyte viability is a consequence of defects in the expression of genes required for normal differentiation of cell types within the testes. A number of the genes affected appear to be direct targets for regulation by Thoc1. These findings support the notion that Thoc1-mediated RNP assembly contributes to the coordinated expression of genes necessary for normal differentiation and development in vivo.

Standard name | WANG_THOC1_TARGETS_DN
Systematic name | M2391
Organism | Mus musculus
PMID | 19307311
Authors | Wang X,Chinnam M,Wang J,Wang Y,Zhang X,Marcon E,Moens P,Goodrich DW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in testis tissue expressing hypomorphic allele of THOC1 [GeneID=9984].
Full description | Accumulating evidence suggests that regulation of RNA processing through an RNP-driven mechanism is important for coordinated gene expression. This hypothesis predicts that defects in RNP biogenesis will adversely affect the elaboration of specific gene expression programs. To explore the role of RNP biogenesis on mammalian development, we have characterized the phenotype of mice hypomorphic for Thoc1. Thoc1 encodes an essential component of the evolutionarily conserved TREX complex. TREX accompanies the elongating RNA polymerase II and facilitates RNP assembly and recruitment of RNA processing factors. Hypomorphic Thoc1 mice are viable despite significantly reduced Thoc1 expression in the tissues examined. While most tissues of Thoc1-deficient mice appear to develop and function normally, gametogenesis is severely compromised. Male infertility is associated with a loss in spermatocyte viability and abnormal endocrine signaling. We suggest that loss of spermatocyte viability is a consequence of defects in the expression of genes required for normal differentiation of cell types within the testes. A number of the genes affected appear to be direct targets for regulation by Thoc1. These findings support the notion that Thoc1-mediated RNP assembly contributes to the coordinated expression of genes necessary for normal differentiation and development in vivo.

Standard name | SERVITJA_ISLET_HNF1A_TARGETS_UP
Systematic name | M2395
Organism | Mus musculus
PMID | 19289501
Authors | Servitja JM,Pignatelli M,Maestro MA,Cardalda C,Boj SF,Lozano J,Blanco E,Lafuente A,McCarthy MI,Sumoy L,Guigó R,Ferrer J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in pancreatic islets upon knockout of HNF1A [GeneID=6927].
Full description | Heterozygous HNF1A mutations cause pancreatic-islet beta-cell dysfunction and monogenic diabetes (MODY3). Hnf1alpha is known to regulate numerous hepatic genes, yet knowledge of its function in pancreatic islets is more limited. We now show that Hnf1a deficiency in mice leads to highly tissue-specific changes in the expression of genes involved in key functions of both islets and liver. To gain insights into the mechanisms of tissue-specific Hnf1alpha regulation, we integrated expression studies of Hnf1a-deficient mice with identification of direct Hnf1alpha targets. We demonstrate that Hnf1alpha can bind in a tissue-selective manner to genes that are expressed only in liver or islets. We also show that Hnf1alpha is essential only for the transcription of a minor fraction of its direct-target genes. Even among genes that were expressed in both liver and islets, the subset of targets showing functional dependence on Hnf1alpha was highly tissue specific. This was partly explained by the compensatory occupancy by the paralog Hnf1beta at selected genes in Hnf1a-deficient liver. In keeping with these findings, the biological consequences of Hnf1a deficiency were markedly different in islets and liver. Notably, Hnf1a deficiency led to impaired large-T-antigen-induced growth and oncogenesis in beta cells yet enhanced proliferation in hepatocytes. Collectively, these findings show that Hnf1alpha governs broad, highly tissue-specific genetic programs in pancreatic islets and liver and reveal key consequences of Hnf1a deficiency relevant to the pathophysiology of monogenic diabetes.

Standard name | SERVITJA_ISLET_HNF1A_TARGETS_DN
Systematic name | M2396
Organism | Mus musculus
PMID | 19289501
Authors | Servitja JM,Pignatelli M,Maestro MA,Cardalda C,Boj SF,Lozano J,Blanco E,Lafuente A,McCarthy MI,Sumoy L,Guigó R,Ferrer J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in pancreatic islets upon knockout of HNF1A [GeneID=6927].
Full description | Heterozygous HNF1A mutations cause pancreatic-islet beta-cell dysfunction and monogenic diabetes (MODY3). Hnf1alpha is known to regulate numerous hepatic genes, yet knowledge of its function in pancreatic islets is more limited. We now show that Hnf1a deficiency in mice leads to highly tissue-specific changes in the expression of genes involved in key functions of both islets and liver. To gain insights into the mechanisms of tissue-specific Hnf1alpha regulation, we integrated expression studies of Hnf1a-deficient mice with identification of direct Hnf1alpha targets. We demonstrate that Hnf1alpha can bind in a tissue-selective manner to genes that are expressed only in liver or islets. We also show that Hnf1alpha is essential only for the transcription of a minor fraction of its direct-target genes. Even among genes that were expressed in both liver and islets, the subset of targets showing functional dependence on Hnf1alpha was highly tissue specific. This was partly explained by the compensatory occupancy by the paralog Hnf1beta at selected genes in Hnf1a-deficient liver. In keeping with these findings, the biological consequences of Hnf1a deficiency were markedly different in islets and liver. Notably, Hnf1a deficiency led to impaired large-T-antigen-induced growth and oncogenesis in beta cells yet enhanced proliferation in hepatocytes. Collectively, these findings show that Hnf1alpha governs broad, highly tissue-specific genetic programs in pancreatic islets and liver and reveal key consequences of Hnf1a deficiency relevant to the pathophysiology of monogenic diabetes.

Standard name | SERVITJA_LIVER_HNF1A_TARGETS_UP
Systematic name | M2397
Organism | Mus musculus
PMID | 19289501
Authors | Servitja JM,Pignatelli M,Maestro MA,Cardalda C,Boj SF,Lozano J,Blanco E,Lafuente A,McCarthy MI,Sumoy L,Guigó R,Ferrer J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in liver tissue upon knockout of HNF1A [GeneID=6927].
Full description | Heterozygous HNF1A mutations cause pancreatic-islet beta-cell dysfunction and monogenic diabetes (MODY3). Hnf1alpha is known to regulate numerous hepatic genes, yet knowledge of its function in pancreatic islets is more limited. We now show that Hnf1a deficiency in mice leads to highly tissue-specific changes in the expression of genes involved in key functions of both islets and liver. To gain insights into the mechanisms of tissue-specific Hnf1alpha regulation, we integrated expression studies of Hnf1a-deficient mice with identification of direct Hnf1alpha targets. We demonstrate that Hnf1alpha can bind in a tissue-selective manner to genes that are expressed only in liver or islets. We also show that Hnf1alpha is essential only for the transcription of a minor fraction of its direct-target genes. Even among genes that were expressed in both liver and islets, the subset of targets showing functional dependence on Hnf1alpha was highly tissue specific. This was partly explained by the compensatory occupancy by the paralog Hnf1beta at selected genes in Hnf1a-deficient liver. In keeping with these findings, the biological consequences of Hnf1a deficiency were markedly different in islets and liver. Notably, Hnf1a deficiency led to impaired large-T-antigen-induced growth and oncogenesis in beta cells yet enhanced proliferation in hepatocytes. Collectively, these findings show that Hnf1alpha governs broad, highly tissue-specific genetic programs in pancreatic islets and liver and reveal key consequences of Hnf1a deficiency relevant to the pathophysiology of monogenic diabetes.

Standard name | SERVITJA_LIVER_HNF1A_TARGETS_DN
Systematic name | M2398
Organism | Mus musculus
PMID | 19289501
Authors | Servitja JM,Pignatelli M,Maestro MA,Cardalda C,Boj SF,Lozano J,Blanco E,Lafuente A,McCarthy MI,Sumoy L,Guigó R,Ferrer J
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in liver tissue upon knockout of HNF1A [GeneID=6927].
Full description | Heterozygous HNF1A mutations cause pancreatic-islet beta-cell dysfunction and monogenic diabetes (MODY3). Hnf1alpha is known to regulate numerous hepatic genes, yet knowledge of its function in pancreatic islets is more limited. We now show that Hnf1a deficiency in mice leads to highly tissue-specific changes in the expression of genes involved in key functions of both islets and liver. To gain insights into the mechanisms of tissue-specific Hnf1alpha regulation, we integrated expression studies of Hnf1a-deficient mice with identification of direct Hnf1alpha targets. We demonstrate that Hnf1alpha can bind in a tissue-selective manner to genes that are expressed only in liver or islets. We also show that Hnf1alpha is essential only for the transcription of a minor fraction of its direct-target genes. Even among genes that were expressed in both liver and islets, the subset of targets showing functional dependence on Hnf1alpha was highly tissue specific. This was partly explained by the compensatory occupancy by the paralog Hnf1beta at selected genes in Hnf1a-deficient liver. In keeping with these findings, the biological consequences of Hnf1a deficiency were markedly different in islets and liver. Notably, Hnf1a deficiency led to impaired large-T-antigen-induced growth and oncogenesis in beta cells yet enhanced proliferation in hepatocytes. Collectively, these findings show that Hnf1alpha governs broad, highly tissue-specific genetic programs in pancreatic islets and liver and reveal key consequences of Hnf1a deficiency relevant to the pathophysiology of monogenic diabetes.

Standard name | MADAN_DPPA4_TARGETS
Systematic name | M2399
Organism | Mus musculus
PMID | 19332562
Authors | Madan B,Madan V,Weber O,Tropel P,Blum C,Kieffer E,Viville S,Fehling HJ
Category | C2
Sub-category | CGP
Brief description | Genes differentially expressed in ES cells with DPPA4 [GeneID=55211] knockout.
Full description | Dppa4 (developmental pluripotency-associated 4) has been identified in several high-profile screens as a gene that is expressed exclusively in pluripotent cells. It encodes a nuclear protein with an SAP-like domain and appears to be associated preferentially with transcriptionally active chromatin. Its exquisite expression pattern and results of RNA interference experiments have led to speculation that Dppa4, as well as its nearby homolog Dppa2, might play essential roles in embryonic stem (ES) cell function and/or germ cell development. To rigorously assess suggested roles, we have generated Dppa4-deficient and Dppa4/Dppa2 doubly deficient ES cells, as well as mice lacking Dppa4. Contrary to predictions, we find that Dppa4 is completely dispensable for ES cell identity and germ cell development. Instead, loss of Dppa4 in mice results in late embryonic/perinatal death and striking skeletal defects with partial penetrance. Thus, surprisingly, Dppa4-deficiency affects tissues that apparently never transcribed the gene, and at least some loss-of-function defects manifest phenotypically at an embryonic stage long after physiologic Dppa4 expression has ceased. Concomitant with targeted gene inactivation, we have introduced into the Dppa4 locus a red fluorescent marker (tandem-dimer red fluorescent protein) that is compatible with green fluorescent proteins and allows noninvasive visualization of pluripotent cells and reprogramming events.

Standard name | KOHOUTEK_CCNT1_TARGETS
Systematic name | M2401
Organism | Mus musculus
PMID | 19364821
Authors | Kohoutek J,Li Q,Blazek D,Luo Z,Jiang H,Peterlin BM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in E14 ES (embryonic stem) cells upon knockdown of CYCT1 [GeneID=904] by RNAi.
Full description | The positive transcription elongation factor b (P-TEFb) is essential for the elongation of transcription and cotranscriptional processing by RNA polymerase II. In mammals, it contains predominantly the C-type cyclin cyclin T1 (CycT1) or CycT2 and cyclin-dependent kinase 9 (Cdk9). To determine if these cyclins have redundant functions or affect distinct sets of genes, we genetically inactivated the CycT2 gene (Ccnt2) using the beta-galactosidase-neomycin gene (beta-geo) gene trap technology in the mouse. Visualizing beta-galactosidase during mouse embryogenesis revealed that CycT2 is expressed abundantly during embryogenesis and throughout the organism in the adult. This finding was reflected in the expression of CycT2 in all adult tissues and organs. However, despite numerous matings of heterozygous mice, we observed no CycT2(-/-) embryos, pups, or adult mice. This early lethality could have resulted from decreased expression of critical genes, which were revealed by short interfering RNAs against CycT2 in embryonic stem cells. Thus, CycT1 and CycT2 are not redundant, and these different P-TEFb complexes regulate subsets of distinct genes that are important for embryonic development.

Standard name | KOHOUTEK_CCNT2_TARGETS
Systematic name | M2402
Organism | Mus musculus
PMID | 19364821
Authors | Kohoutek J,Li Q,Blazek D,Luo Z,Jiang H,Peterlin BM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in E14 ES (embryonic stem) cells upon knockdown of CYCT2 [GeneID=905] by RNAi.
Full description | The positive transcription elongation factor b (P-TEFb) is essential for the elongation of transcription and cotranscriptional processing by RNA polymerase II. In mammals, it contains predominantly the C-type cyclin cyclin T1 (CycT1) or CycT2 and cyclin-dependent kinase 9 (Cdk9). To determine if these cyclins have redundant functions or affect distinct sets of genes, we genetically inactivated the CycT2 gene (Ccnt2) using the beta-galactosidase-neomycin gene (beta-geo) gene trap technology in the mouse. Visualizing beta-galactosidase during mouse embryogenesis revealed that CycT2 is expressed abundantly during embryogenesis and throughout the organism in the adult. This finding was reflected in the expression of CycT2 in all adult tissues and organs. However, despite numerous matings of heterozygous mice, we observed no CycT2(-/-) embryos, pups, or adult mice. This early lethality could have resulted from decreased expression of critical genes, which were revealed by short interfering RNAs against CycT2 in embryonic stem cells. Thus, CycT1 and CycT2 are not redundant, and these different P-TEFb complexes regulate subsets of distinct genes that are important for embryonic development.

Standard name | PEDERSEN_METASTASIS_BY_ERBB2_ISOFORM_1
Systematic name | M2407
Organism | Homo sapiens
PMID | 19364815
Authors | Pedersen K,Angelini PD,Laos S,Bach-Faig A,Cunningham MP,Ferrer-Ramón C,Luque-García A,García-Castillo J,Parra-Palau JL,Scaltriti M,Cajal y Ramón S,Baselga J,Arribas J
Category | C2
Sub-category | CGP
Brief description | Genes regulated in MCF7 cells (breast cancer) by expression of full-length and truncated (611-CTF) forms of ERBB2 [GeneID=2064] at both 15 h and 60 h time points.
Full description | HER2 is a tyrosine kinase receptor causally involved in cancer. A subgroup of breast cancer patients with particularly poor clinical outcomes expresses a heterogeneous collection of HER2 carboxy-terminal fragments (CTFs). However, since the CTFs lack the extracellular domain that drives dimerization and subsequent activation of full-length HER2, they are in principle expected to be inactive. Here we show that at low expression levels one of these fragments, 611-CTF, activated multiple signaling pathways because of its unanticipated ability to constitutively homodimerize. A transcriptomic analysis revealed that 611-CTF specifically controlled the expression of genes that we found to be correlated with poor prognosis in breast cancer. Among the 611-CTF-regulated genes were several that have previously been linked to metastasis, including those for MET, EPHA2, matrix metalloproteinase 1, interleukin 11, angiopoietin-like 4, and different integrins. It is thought that transgenic mice overexpressing HER2 in the mammary glands develop tumors only after acquisition of activating mutations in the transgene. In contrast, we show that expression of 611-CTF led to development of aggressive and invasive mammary tumors without the need for mutations. These results demonstrate that 611-CTF is a potent oncogene capable of promoting mammary tumor progression and metastasis.

Standard name | PEDERSEN_METASTASIS_BY_ERBB2_ISOFORM_3
Systematic name | M2408
Organism | Homo sapiens
PMID | 19364815
Authors | Pedersen K,Angelini PD,Laos S,Bach-Faig A,Cunningham MP,Ferrer-Ramón C,Luque-García A,García-Castillo J,Parra-Palau JL,Scaltriti M,Cajal y Ramón S,Baselga J,Arribas J
Category | C2
Sub-category | CGP
Brief description | Genes regulated in MCF7 cells (breast cancer) by expression of the truncated (611-CTF) form of ERBB2 [GeneID=2064] at both 15 h and 60 h time points.
Full description | HER2 is a tyrosine kinase receptor causally involved in cancer. A subgroup of breast cancer patients with particularly poor clinical outcomes expresses a heterogeneous collection of HER2 carboxy-terminal fragments (CTFs). However, since the CTFs lack the extracellular domain that drives dimerization and subsequent activation of full-length HER2, they are in principle expected to be inactive. Here we show that at low expression levels one of these fragments, 611-CTF, activated multiple signaling pathways because of its unanticipated ability to constitutively homodimerize. A transcriptomic analysis revealed that 611-CTF specifically controlled the expression of genes that we found to be correlated with poor prognosis in breast cancer. Among the 611-CTF-regulated genes were several that have previously been linked to metastasis, including those for MET, EPHA2, matrix metalloproteinase 1, interleukin 11, angiopoietin-like 4, and different integrins. It is thought that transgenic mice overexpressing HER2 in the mammary glands develop tumors only after acquisition of activating mutations in the transgene. In contrast, we show that expression of 611-CTF led to development of aggressive and invasive mammary tumors without the need for mutations. These results demonstrate that 611-CTF is a potent oncogene capable of promoting mammary tumor progression and metastasis.

Standard name | PEDERSEN_METASTASIS_BY_ERBB2_ISOFORM_4
Systematic name | M2410
Organism | Homo sapiens
PMID | 19364815
Authors | Pedersen K,Angelini PD,Laos S,Bach-Faig A,Cunningham MP,Ferrer-Ramón C,Luque-García A,García-Castillo J,Parra-Palau JL,Scaltriti M,Cajal y Ramón S,Baselga J,Arribas J
Category | C2
Sub-category | CGP
Brief description | Genes regulated in MCF7 cells (breast cancer) by expression of the full-length and truncated (611-CTF) forms of ERBB2 [GeneID=2064] at 60 h time point.
Full description | HER2 is a tyrosine kinase receptor causally involved in cancer. A subgroup of breast cancer patients with particularly poor clinical outcomes expresses a heterogeneous collection of HER2 carboxy-terminal fragments (CTFs). However, since the CTFs lack the extracellular domain that drives dimerization and subsequent activation of full-length HER2, they are in principle expected to be inactive. Here we show that at low expression levels one of these fragments, 611-CTF, activated multiple signaling pathways because of its unanticipated ability to constitutively homodimerize. A transcriptomic analysis revealed that 611-CTF specifically controlled the expression of genes that we found to be correlated with poor prognosis in breast cancer. Among the 611-CTF-regulated genes were several that have previously been linked to metastasis, including those for MET, EPHA2, matrix metalloproteinase 1, interleukin 11, angiopoietin-like 4, and different integrins. It is thought that transgenic mice overexpressing HER2 in the mammary glands develop tumors only after acquisition of activating mutations in the transgene. In contrast, we show that expression of 611-CTF led to development of aggressive and invasive mammary tumors without the need for mutations. These results demonstrate that 611-CTF is a potent oncogene capable of promoting mammary tumor progression and metastasis.

Standard name | PEDERSEN_METASTASIS_BY_ERBB2_ISOFORM_5
Systematic name | M2411
Organism | Homo sapiens
PMID | 19364815
Authors | Pedersen K,Angelini PD,Laos S,Bach-Faig A,Cunningham MP,Ferrer-Ramón C,Luque-García A,García-Castillo J,Parra-Palau JL,Scaltriti M,Cajal y Ramón S,Baselga J,Arribas J
Category | C2
Sub-category | CGP
Brief description | Genes regulated in MCF7 cells (breast cancer) by expression of the truncated (611-CTF) form of ERBB2 [GeneID=2064] at 15 h time point.
Full description | HER2 is a tyrosine kinase receptor causally involved in cancer. A subgroup of breast cancer patients with particularly poor clinical outcomes expresses a heterogeneous collection of HER2 carboxy-terminal fragments (CTFs). However, since the CTFs lack the extracellular domain that drives dimerization and subsequent activation of full-length HER2, they are in principle expected to be inactive. Here we show that at low expression levels one of these fragments, 611-CTF, activated multiple signaling pathways because of its unanticipated ability to constitutively homodimerize. A transcriptomic analysis revealed that 611-CTF specifically controlled the expression of genes that we found to be correlated with poor prognosis in breast cancer. Among the 611-CTF-regulated genes were several that have previously been linked to metastasis, including those for MET, EPHA2, matrix metalloproteinase 1, interleukin 11, angiopoietin-like 4, and different integrins. It is thought that transgenic mice overexpressing HER2 in the mammary glands develop tumors only after acquisition of activating mutations in the transgene. In contrast, we show that expression of 611-CTF led to development of aggressive and invasive mammary tumors without the need for mutations. These results demonstrate that 611-CTF is a potent oncogene capable of promoting mammary tumor progression and metastasis.

Standard name | PEDERSEN_METASTASIS_BY_ERBB2_ISOFORM_6
Systematic name | M2412
Organism | Homo sapiens
PMID | 19364815
Authors | Pedersen K,Angelini PD,Laos S,Bach-Faig A,Cunningham MP,Ferrer-Ramón C,Luque-García A,García-Castillo J,Parra-Palau JL,Scaltriti M,Cajal y Ramón S,Baselga J,Arribas J
Category | C2
Sub-category | CGP
Brief description | Genes regulated in MCF7 cells (breast cancer) by expression of the full-length form of ERBB2 [GeneID=2064] at 60 h time point.
Full description | HER2 is a tyrosine kinase receptor causally involved in cancer. A subgroup of breast cancer patients with particularly poor clinical outcomes expresses a heterogeneous collection of HER2 carboxy-terminal fragments (CTFs). However, since the CTFs lack the extracellular domain that drives dimerization and subsequent activation of full-length HER2, they are in principle expected to be inactive. Here we show that at low expression levels one of these fragments, 611-CTF, activated multiple signaling pathways because of its unanticipated ability to constitutively homodimerize. A transcriptomic analysis revealed that 611-CTF specifically controlled the expression of genes that we found to be correlated with poor prognosis in breast cancer. Among the 611-CTF-regulated genes were several that have previously been linked to metastasis, including those for MET, EPHA2, matrix metalloproteinase 1, interleukin 11, angiopoietin-like 4, and different integrins. It is thought that transgenic mice overexpressing HER2 in the mammary glands develop tumors only after acquisition of activating mutations in the transgene. In contrast, we show that expression of 611-CTF led to development of aggressive and invasive mammary tumors without the need for mutations. These results demonstrate that 611-CTF is a potent oncogene capable of promoting mammary tumor progression and metastasis.

Standard name | PEDERSEN_METASTASIS_BY_ERBB2_ISOFORM_7
Systematic name | M2413
Organism | Homo sapiens
PMID | 19364815
Authors | Pedersen K,Angelini PD,Laos S,Bach-Faig A,Cunningham MP,Ferrer-Ramón C,Luque-García A,García-Castillo J,Parra-Palau JL,Scaltriti M,Cajal y Ramón S,Baselga J,Arribas J
Category | C2
Sub-category | CGP
Brief description | Genes regulated in MCF7 cells (breast cancer) by expression of the truncated (611-CTF) form of ERBB2 [GeneID=2064] at 60 h time point.
Full description | HER2 is a tyrosine kinase receptor causally involved in cancer. A subgroup of breast cancer patients with particularly poor clinical outcomes expresses a heterogeneous collection of HER2 carboxy-terminal fragments (CTFs). However, since the CTFs lack the extracellular domain that drives dimerization and subsequent activation of full-length HER2, they are in principle expected to be inactive. Here we show that at low expression levels one of these fragments, 611-CTF, activated multiple signaling pathways because of its unanticipated ability to constitutively homodimerize. A transcriptomic analysis revealed that 611-CTF specifically controlled the expression of genes that we found to be correlated with poor prognosis in breast cancer. Among the 611-CTF-regulated genes were several that have previously been linked to metastasis, including those for MET, EPHA2, matrix metalloproteinase 1, interleukin 11, angiopoietin-like 4, and different integrins. It is thought that transgenic mice overexpressing HER2 in the mammary glands develop tumors only after acquisition of activating mutations in the transgene. In contrast, we show that expression of 611-CTF led to development of aggressive and invasive mammary tumors without the need for mutations. These results demonstrate that 611-CTF is a potent oncogene capable of promoting mammary tumor progression and metastasis.

Standard name | PEDERSEN_TARGETS_OF_611CTF_ISOFORM_OF_ERBB2
Systematic name | M2414
Organism | Homo sapiens
PMID | 19364815
Authors | Pedersen K,Angelini PD,Laos S,Bach-Faig A,Cunningham MP,Ferrer-Ramón C,Luque-García A,García-Castillo J,Parra-Palau JL,Scaltriti M,Cajal y Ramón S,Baselga J,Arribas J
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MCF7 cells (breast cancer) more than three-fold by the truncated form 611-CTF of ERBB2 [GeneID=2064] and less than two-fold by the full-length ERBB2 [GeneID=2064].
Full description | HER2 is a tyrosine kinase receptor causally involved in cancer. A subgroup of breast cancer patients with particularly poor clinical outcomes expresses a heterogeneous collection of HER2 carboxy-terminal fragments (CTFs). However, since the CTFs lack the extracellular domain that drives dimerization and subsequent activation of full-length HER2, they are in principle expected to be inactive. Here we show that at low expression levels one of these fragments, 611-CTF, activated multiple signaling pathways because of its unanticipated ability to constitutively homodimerize. A transcriptomic analysis revealed that 611-CTF specifically controlled the expression of genes that we found to be correlated with poor prognosis in breast cancer. Among the 611-CTF-regulated genes were several that have previously been linked to metastasis, including those for MET, EPHA2, matrix metalloproteinase 1, interleukin 11, angiopoietin-like 4, and different integrins. It is thought that transgenic mice overexpressing HER2 in the mammary glands develop tumors only after acquisition of activating mutations in the transgene. In contrast, we show that expression of 611-CTF led to development of aggressive and invasive mammary tumors without the need for mutations. These results demonstrate that 611-CTF is a potent oncogene capable of promoting mammary tumor progression and metastasis.

Standard name | WAKABAYASHI_ADIPOGENESIS_PPARG_RXRA_BOUND_36HR
Systematic name | M2415
Organism | Mus musculus
PMID | 19414603
Authors | Wakabayashi K,Okamura M,Tsutsumi S,Nishikawa NS,Tanaka T,Sakakibara I,Kitakami J,Ihara S,Hashimoto Y,Hamakubo T,Kodama T,Aburatani H,Sakai J
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by both PPARG and RXRA [GeneID=5468, 6256] at 36 h time point of adipocyte differentiation of 3T3-L1 cells (preadipocyte).
Full description | Control of cell differentiation occurs through transcriptional mechanisms and through epigenetic modification. Using a chromatin immunoprecipitation-on-chip approach, we performed a genome-wide search for target genes of peroxisome proliferator-activated receptor gamma (PPAR gamma) and its partner protein retinoid X receptor alpha during adipogenesis. We show that these two receptors target several genes that encode histone lysine methyltransferase SET domain proteins. The histone H4 Lys 20 (H4K20) monomethyltransferase PR-Set7/Setd8 gene is upregulated by PPAR gamma during adipogenesis, and the knockdown of PR-Set7/Setd8 suppressed adipogenesis. Intriguingly, monomethylated H4K20 (H4K20me1) levels are robustly increased toward the end of differentiation. PR-Set7/Setd8 positively regulates the expression of PPAR gamma and its targets through H4K20 monomethylation. Furthermore, the activation of PPAR gamma transcriptional activity leads to the induction of H4K20me1 modification of PPAR gamma and its targets and thereby promotes adipogenesis. We also show that PPAR gamma targets PPAR gamma2 and promotes its gene expression through H4K20 monomethylation. Our results connect transcriptional regulation and epigenetic chromatin modulation through H4K20 monomethylation during adipogenesis through a feedback loop.

Standard name | WAKABAYASHI_ADIPOGENESIS_PPARG_BOUND_36HR
Systematic name | M2416
Organism | Mus musculus
PMID | 19414603
Authors | Wakabayashi K,Okamura M,Tsutsumi S,Nishikawa NS,Tanaka T,Sakakibara I,Kitakami J,Ihara S,Hashimoto Y,Hamakubo T,Kodama T,Aburatani H,Sakai J
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by PPARG [GeneID=5468] at 36 h time point of adipocyte differentiation of 3T3-L1 cells (preadipocyte).
Full description | Control of cell differentiation occurs through transcriptional mechanisms and through epigenetic modification. Using a chromatin immunoprecipitation-on-chip approach, we performed a genome-wide search for target genes of peroxisome proliferator-activated receptor gamma (PPAR gamma) and its partner protein retinoid X receptor alpha during adipogenesis. We show that these two receptors target several genes that encode histone lysine methyltransferase SET domain proteins. The histone H4 Lys 20 (H4K20) monomethyltransferase PR-Set7/Setd8 gene is upregulated by PPAR gamma during adipogenesis, and the knockdown of PR-Set7/Setd8 suppressed adipogenesis. Intriguingly, monomethylated H4K20 (H4K20me1) levels are robustly increased toward the end of differentiation. PR-Set7/Setd8 positively regulates the expression of PPAR gamma and its targets through H4K20 monomethylation. Furthermore, the activation of PPAR gamma transcriptional activity leads to the induction of H4K20me1 modification of PPAR gamma and its targets and thereby promotes adipogenesis. We also show that PPAR gamma targets PPAR gamma2 and promotes its gene expression through H4K20 monomethylation. Our results connect transcriptional regulation and epigenetic chromatin modulation through H4K20 monomethylation during adipogenesis through a feedback loop.

Standard name | WAKABAYASHI_ADIPOGENESIS_PPARG_RXRA_BOUND_8D
Systematic name | M2417
Organism | Mus musculus
PMID | 19414603
Authors | Wakabayashi K,Okamura M,Tsutsumi S,Nishikawa NS,Tanaka T,Sakakibara I,Kitakami J,Ihara S,Hashimoto Y,Hamakubo T,Kodama T,Aburatani H,Sakai J
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by both PPARG and RXRA [GeneID=5468, 6256] at 8 day time point of adipocyte differentiation of 3T3-L1 cells (preadipocyte).
Full description | Control of cell differentiation occurs through transcriptional mechanisms and through epigenetic modification. Using a chromatin immunoprecipitation-on-chip approach, we performed a genome-wide search for target genes of peroxisome proliferator-activated receptor gamma (PPAR gamma) and its partner protein retinoid X receptor alpha during adipogenesis. We show that these two receptors target several genes that encode histone lysine methyltransferase SET domain proteins. The histone H4 Lys 20 (H4K20) monomethyltransferase PR-Set7/Setd8 gene is upregulated by PPAR gamma during adipogenesis, and the knockdown of PR-Set7/Setd8 suppressed adipogenesis. Intriguingly, monomethylated H4K20 (H4K20me1) levels are robustly increased toward the end of differentiation. PR-Set7/Setd8 positively regulates the expression of PPAR gamma and its targets through H4K20 monomethylation. Furthermore, the activation of PPAR gamma transcriptional activity leads to the induction of H4K20me1 modification of PPAR gamma and its targets and thereby promotes adipogenesis. We also show that PPAR gamma targets PPAR gamma2 and promotes its gene expression through H4K20 monomethylation. Our results connect transcriptional regulation and epigenetic chromatin modulation through H4K20 monomethylation during adipogenesis through a feedback loop.

Standard name | WAKABAYASHI_ADIPOGENESIS_PPARG_BOUND_8D
Systematic name | M2419
Organism | Mus musculus
PMID | 19414603
Authors | Wakabayashi K,Okamura M,Tsutsumi S,Nishikawa NS,Tanaka T,Sakakibara I,Kitakami J,Ihara S,Hashimoto Y,Hamakubo T,Kodama T,Aburatani H,Sakai J
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by PPARG [GeneID=5468] at 8 day time point of adipocyte differentiation of 3T3-L1 cells (preadipocyte).
Full description | Control of cell differentiation occurs through transcriptional mechanisms and through epigenetic modification. Using a chromatin immunoprecipitation-on-chip approach, we performed a genome-wide search for target genes of peroxisome proliferator-activated receptor gamma (PPAR gamma) and its partner protein retinoid X receptor alpha during adipogenesis. We show that these two receptors target several genes that encode histone lysine methyltransferase SET domain proteins. The histone H4 Lys 20 (H4K20) monomethyltransferase PR-Set7/Setd8 gene is upregulated by PPAR gamma during adipogenesis, and the knockdown of PR-Set7/Setd8 suppressed adipogenesis. Intriguingly, monomethylated H4K20 (H4K20me1) levels are robustly increased toward the end of differentiation. PR-Set7/Setd8 positively regulates the expression of PPAR gamma and its targets through H4K20 monomethylation. Furthermore, the activation of PPAR gamma transcriptional activity leads to the induction of H4K20me1 modification of PPAR gamma and its targets and thereby promotes adipogenesis. We also show that PPAR gamma targets PPAR gamma2 and promotes its gene expression through H4K20 monomethylation. Our results connect transcriptional regulation and epigenetic chromatin modulation through H4K20 monomethylation during adipogenesis through a feedback loop.

Standard name | WAKABAYASHI_ADIPOGENESIS_PPARG_RXRA_BOUND_WITH_H4K20ME1_MARK
Systematic name | M2420
Organism | Mus musculus
PMID | 19414603
Authors | Wakabayashi K,Okamura M,Tsutsumi S,Nishikawa NS,Tanaka T,Sakakibara I,Kitakami J,Ihara S,Hashimoto Y,Hamakubo T,Kodama T,Aburatani H,Sakai J
Category | C2
Sub-category | CGP
Brief description | Genes with promoters bound by both PPARG and RXRA [GeneID=5468, 6256] at 8 (but not 0) day time point of adipocyte differentiation of 3T3-L1 cells (preadipocyte) and that were newly modified by H4K20me1.
Full description | Control of cell differentiation occurs through transcriptional mechanisms and through epigenetic modification. Using a chromatin immunoprecipitation-on-chip approach, we performed a genome-wide search for target genes of peroxisome proliferator-activated receptor gamma (PPAR gamma) and its partner protein retinoid X receptor alpha during adipogenesis. We show that these two receptors target several genes that encode histone lysine methyltransferase SET domain proteins. The histone H4 Lys 20 (H4K20) monomethyltransferase PR-Set7/Setd8 gene is upregulated by PPAR gamma during adipogenesis, and the knockdown of PR-Set7/Setd8 suppressed adipogenesis. Intriguingly, monomethylated H4K20 (H4K20me1) levels are robustly increased toward the end of differentiation. PR-Set7/Setd8 positively regulates the expression of PPAR gamma and its targets through H4K20 monomethylation. Furthermore, the activation of PPAR gamma transcriptional activity leads to the induction of H4K20me1 modification of PPAR gamma and its targets and thereby promotes adipogenesis. We also show that PPAR gamma targets PPAR gamma2 and promotes its gene expression through H4K20 monomethylation. Our results connect transcriptional regulation and epigenetic chromatin modulation through H4K20 monomethylation during adipogenesis through a feedback loop.

Standard name | PARK_OSTEOBLAST_DIFFERENTIATION_BY_PHENYLAMIL_UP
Systematic name | M2421
Organism | Mus musculus
PMID | 19433444
Authors | Park KW,Waki H,Kim WK,Davies BS,Young SG,Parhami F,Tontonoz P
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in M2-10B4 cells (osteoblast) in response to phenylamil [PubChem=4755].
Full description | Stimulation of osteoblast differentiation from mesenchymal stem cells is a potential strategy for bone repair. Bone morphogenetic proteins (BMPs) that induce osteoblastic differentiation have been successfully used in humans to treat fractures. Here we outline a new approach to the stimulation of osteoblast differentiation using small molecules that stimulate BMP activity. We have identified the amiloride derivative phenamil as a stimulator of osteoblast differentiation and mineralization. Remarkably, phenamil acts cooperatively with BMPs to induce the expression of BMP target genes, osteogenic markers, and matrix mineralization in both mesenchymal stem cell lines and calvarial organ cultures. Transcriptional profiling of cells treated with phenamil led to the identification of tribbles homolog 3 (Trb3) as a mediator of its effects. Trb3 is induced by phenamil selectively in cells with osteoblastic potential. Both Trb3 and phenamil stabilize the expression of SMAD, the critical transcription factor in BMP signaling, by promoting the degradation of SMAD ubiquitin regulatory factor 1. Small interfering RNA-mediated knockdown of Trb3 blunts the effects of phenamil on BMP signaling and osteogenesis. Thus, phenamil induces osteogenic differentiation, at least in part, through Trb3-dependent promotion of BMP action. The synergistic use of small molecules such as phenamil along with BMPs may provide new strategies for the promotion of bone healing.

Standard name | PARK_OSTEOBLAST_DIFFERENTIATION_BY_PHENYLAMIL_DN
Systematic name | M2423
Organism | Mus musculus
PMID | 19433444
Authors | Park KW,Waki H,Kim WK,Davies BS,Young SG,Parhami F,Tontonoz P
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in M2-10B4 cells (osteoblast) in response to phenylamil [PubChem=4755].
Full description | Stimulation of osteoblast differentiation from mesenchymal stem cells is a potential strategy for bone repair. Bone morphogenetic proteins (BMPs) that induce osteoblastic differentiation have been successfully used in humans to treat fractures. Here we outline a new approach to the stimulation of osteoblast differentiation using small molecules that stimulate BMP activity. We have identified the amiloride derivative phenamil as a stimulator of osteoblast differentiation and mineralization. Remarkably, phenamil acts cooperatively with BMPs to induce the expression of BMP target genes, osteogenic markers, and matrix mineralization in both mesenchymal stem cell lines and calvarial organ cultures. Transcriptional profiling of cells treated with phenamil led to the identification of tribbles homolog 3 (Trb3) as a mediator of its effects. Trb3 is induced by phenamil selectively in cells with osteoblastic potential. Both Trb3 and phenamil stabilize the expression of SMAD, the critical transcription factor in BMP signaling, by promoting the degradation of SMAD ubiquitin regulatory factor 1. Small interfering RNA-mediated knockdown of Trb3 blunts the effects of phenamil on BMP signaling and osteogenesis. Thus, phenamil induces osteogenic differentiation, at least in part, through Trb3-dependent promotion of BMP action. The synergistic use of small molecules such as phenamil along with BMPs may provide new strategies for the promotion of bone healing.

Standard name | YANG_BCL3_TARGETS_UP
Systematic name | M2424
Organism | Rattus norvegicus
PMID | 19451226
Authors | Yang J,Williams RS,Kelly DP
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in neonatal cardiac myocytes upon knockdown of BCL3 [GeneID=602] by RNAi.
Full description | Estrogen-related receptors (ERRs) play critical roles in regulation of cellular energy metabolism in response to inducible coactivators such as peroxisome proliferator-activated receptor gamma (PPARgamma) coactivator 1alpha (PGC-1alpha). A yeast two-hybrid screen led to the identification of the cytokine-stimulated transcriptional regulator, Bcl3, as an ERRalpha coactivator. Bcl3 was shown to synergize with PGC-1alpha to coactivate ERRalpha. Chromatin immunoprecipitation studies demonstrated that ERRalpha, PGC-1alpha, and Bcl3 form a complex on an ERRalpha-responsive element within the pyruvate dehydrogenase kinase 4 gene promoter in cardiac myocytes. Mapping studies demonstrated that Bc13 interacts with PGC-1alpha and ERRalpha, allowing for interaction with both proteins. Transcriptional profiling demonstrated that Bcl3 activates genes involved in diverse pathways including a subset involved in cellular energy metabolism known to be regulated by PGC-1alpha, ERRalpha, and a second nuclear receptor, PPARalpha. Consistent with the gene expression profiling results, Bcl3 was shown to synergistically coactivate PPARalpha with PGC-1alpha in a manner similar to ERRalpha. We propose that the cooperativity between Bcl3 and PGC-1alpha may serve as a point of convergence on nuclear receptor targets to direct programs orchestrating inflammatory and energy metabolism responses in heart and other tissues.

Standard name | YANG_BCL3_TARGETS_DN
Systematic name | M2425
Organism | Rattus norvegicus
PMID | 19451226
Authors | Yang J,Williams RS,Kelly DP
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in neonatal cardiac myocytes upon knockdown of BCL3 [GeneID=602] by RNAi.
Full description | Estrogen-related receptors (ERRs) play critical roles in regulation of cellular energy metabolism in response to inducible coactivators such as peroxisome proliferator-activated receptor gamma (PPARgamma) coactivator 1alpha (PGC-1alpha). A yeast two-hybrid screen led to the identification of the cytokine-stimulated transcriptional regulator, Bcl3, as an ERRalpha coactivator. Bcl3 was shown to synergize with PGC-1alpha to coactivate ERRalpha. Chromatin immunoprecipitation studies demonstrated that ERRalpha, PGC-1alpha, and Bcl3 form a complex on an ERRalpha-responsive element within the pyruvate dehydrogenase kinase 4 gene promoter in cardiac myocytes. Mapping studies demonstrated that Bc13 interacts with PGC-1alpha and ERRalpha, allowing for interaction with both proteins. Transcriptional profiling demonstrated that Bcl3 activates genes involved in diverse pathways including a subset involved in cellular energy metabolism known to be regulated by PGC-1alpha, ERRalpha, and a second nuclear receptor, PPARalpha. Consistent with the gene expression profiling results, Bcl3 was shown to synergistically coactivate PPARalpha with PGC-1alpha in a manner similar to ERRalpha. We propose that the cooperativity between Bcl3 and PGC-1alpha may serve as a point of convergence on nuclear receptor targets to direct programs orchestrating inflammatory and energy metabolism responses in heart and other tissues.

Standard name | LOPEZ_TRANSLATION_VIA_FN1_SIGNALING
Systematic name | M2426
Organism | Homo sapiens
PMID | 19451229
Authors | López-Lago MA,Okada T,Murillo MM,Socci N,Giancotti FG
Category | C2
Sub-category | CGP
Brief description | Genes translationally up-regulated in HUVEC cells (endothelium) grown on FN1 [GeneID=2335] compared to those grown on laminin 1.
Full description | Integrin signaling promotes, through p21-activated kinase, phosphorylation and inactivation of the tumor suppressor merlin, thus removing a block to mitogenesis in normal cells. However, the biochemical function of merlin and the effector pathways critical for the pathogenesis of malignant mesothelioma and other NF2-related malignancies are not known. We report that integrin-specific signaling promotes activation of mTORC1 and cap-dependent mRNA translation. Depletion of merlin rescues mTORC1 signaling in cells deprived of anchorage to a permissive extracellular matrix, suggesting that integrin signaling controls mTORC1 through inactivation of merlin. This signaling pathway controls translation of the cyclin D1 mRNA and, thereby, cell cycle progression. In addition, it promotes cell survival. Analysis of a panel of malignant mesothelioma cell lines reveals a strong correlation between loss of merlin and activation of mTORC1. Merlin-negative lines are sensitive to the growth-inhibitory effect of rapamycin, and the expression of recombinant merlin renders them partially resistant to rapamycin. Conversely, depletion of merlin restores rapamycin sensitivity in merlin-positive lines. These results indicate that integrin-mediated adhesion promotes mTORC1 signaling through the inactivation of merlin. Furthermore, they reveal that merlin-negative mesotheliomas display unregulated mTORC1 signaling and are sensitive to rapamycin, thus providing a preclinical rationale for prospective, biomarker-driven clinical studies of mTORC1 inhibitors in these tumors.

Standard name | VERNOCHET_ADIPOGENESIS
Systematic name | M2432
Organism | Mus musculus
PMID | 19564408
Authors | Vernochet C,Peres SB,Davis KE,McDonald ME,Qiang L,Wang H,Scherer PE,Farmer SR
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during adipogenic differentiation of 3T3-L1 cells (preadipocyte) and down-regulated by troglitazone [PubChem=5591].
Full description | White adipose tissue (WAT) stores energy in the form of triglycerides, whereas brown tissue (BAT) expends energy, primarily by oxidizing lipids. WAT also secretes many cytokines and acute-phase proteins that contribute to insulin resistance in obese subjects. In this study, we have investigated the mechanisms by which activation of peroxisome proliferator-activated receptor gamma (PPARgamma) with synthetic agonists induces a brown phenotype in white adipocytes in vivo and in vitro. We demonstrate that this phenotypic conversion is characterized by repression of a set of white fat genes (visceral white), including the resistin, angiotensinogen, and chemerin genes, in addition to induction of brown-specific genes, such as Ucp-1. Importantly, the level of expression of the visceral white genes is high in mesenteric and gonadal WAT depots but low in the subcutaneous WAT depot and in BAT. Mutation of critical amino acids within helix 7 of the ligand-binding domain of PPARgamma prevents inhibition of visceral white gene expression by the synthetic agonists and therefore shows a direct role for PPARgamma in the repression process. Inhibition of the white adipocyte genes also depends on the expression of C/EBPalpha and the corepressors, carboxy-terminal binding proteins 1 and 2 (CtBP1/2). The data further show that repression of resistin and angiotensinogen expression involves recruitment of CtBP1/2, directed by C/EBPalpha, to the minimal promoter of the corresponding genes in response to the PPARgamma ligand. Developing strategies to enhance the brown phenotype in white adipocytes while reducing secretion of stress-related cytokines from visceral WAT is a means to combat obesity-associated disorders.

Standard name | IM_SREBF1A_TARGETS
Systematic name | M2433
Organism | Mus musculus
PMID | 19564420
Authors | Im SS,Hammond LE,Yousef L,Nugas-Selby C,Shin DJ,Seo YK,Fong LG,Young SG,Osborne TF
Category | C2
Sub-category | CGP
Brief description | Genes differentially expressed in liver tissue upon knockout of the 1a isoform of SREBF1 [GeneID=6720].
Full description | We generated a line of mice in which sterol regulatory element binding protein 1a (SREBP-1a) was specifically inactivated by insertional mutagenesis. Homozygous mutant mice were completely viable despite expressing SREBP-1a mRNA below 5% of normal, and there were minimal effects on expression of either SREBP-1c or -2. Microarray expression studies in liver, where SREBP-1a mRNA is 1/10 the level of the highly similar SREBP-1c, demonstrated that only a few genes were affected. The only downregulated genes directly linked to lipid metabolism were Srebf1 (which encodes SREBP-1) and Acacb (which encodes acetyl coenzyme A [acetyl-CoA] carboxylase 2 [ACC2], a critical regulator of fatty acyl-CoA partitioning between cytosol and mitochondria). ACC2 regulation is particularly important during food restriction. Similar to Acacb knockout mice, SREBP-1a-deficient mice have lower hepatic triglycerides and higher serum ketones during fasting than wild-type mice. SREBP-1a and -1c have identical DNA binding and dimerization domains; thus, the failure of the more abundant SREBP-1c to substitute for activating hepatic ACC2 must relate to more efficient recruitment of transcriptional coactivators to the more potent SREBP-1a activation domain. Our chromatin immunoprecipitation results support this hypothesis.

Standard name | GUO_TARGETS_OF_IRS1_AND_IRS2
Systematic name | M2434
Organism | Mus musculus
PMID | 19596788
Authors | Guo S,Copps KD,Dong X,Park S,Cheng Z,Pocai A,Rossetti L,Sajan M,Farese RV,White MF
Category | C2
Sub-category | CGP
Brief description | Transcripts dependent upon IRS1 and IRS2 [GeneID=3667, 8660] for normal expression in liver.
Full description | We used a Cre-loxP approach to generate mice with varied expression of hepatic Irs1 and Irs2 to establish the contribution of each protein to hepatic nutrient homeostasis. While nutrient-sensitive transcripts were expressed nearly normally in liver lacking Irs2 (LKO2 mice), these transcripts were significantly dysregulated in liver lacking Irs1 (LKO1 mice) or Irs1 and Irs2 together (DKO mice). Similarly, a set of key gluconeogenic and lipogenic genes was regulated nearly normally by feeding in liver retaining a single Irs1 allele without Irs2 (DKO/1 mice) but was poorly regulated in liver retaining one Irs2 allele without Irs1 (DKO/2 mice). DKO/2 mice, but not DKO/1 mice, also showed impaired glucose tolerance and insulin sensitivity-though both Irs1 and Irs2 were required to suppress hepatic glucose production during hyperinsulinemic-euglycemic clamp. In contrast, either hepatic Irs1 or Irs2 mediated suppression of HGP by intracerebroventricular insulin infusion. After 12 weeks on a high-fat diet, postprandial tyrosine phosphorylation of Irs1 increased in livers of control and LKO2 mice, whereas tyrosine phosphorylation of Irs2 decreased in control and LKO1 mice. Moreover, LKO1 mice -- but not LKO2 mice -- that were fed a high-fat diet developed postprandial hyperglycemia. We conclude that Irs1 is the principal mediator of hepatic insulin action that maintains glucose homeostasis.

Standard name | HUANG_GATA2_TARGETS_UP
Systematic name | M2437
Organism | Mus musculus
PMID | 19620289
Authors | Huang Z,Dore LC,Li Z,Orkin SH,Feng G,Lin S,Crispino JD
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in G1ME cells (megakaryocyte/erythroid progenitor lacking GATA1 [GeneID=2623]) upon knockdown of GATA2 [GeneID=2624] by RNAi.
Full description | GATA-2 is an essential transcription factor that regulates multiple aspects of hematopoiesis. Dysregulation of GATA-2 is a hallmark of acute megakaryoblastic leukemia in children with Down syndrome, a malignancy that is defined by the combination of trisomy 21 and a GATA1 mutation. Here, we show that GATA-2 is required for normal megakaryocyte development as well as aberrant megakaryopoiesis in Gata1 mutant cells. Furthermore, we demonstrate that GATA-2 indirectly controls cell cycle progression in GATA-1-deficient megakaryocytes. Genome-wide microarray analysis and chromatin immunoprecipitation studies revealed that GATA-2 regulates a wide set of genes, including cell cycle regulators and megakaryocyte-specific genes. Surprisingly, GATA-2 also negatively regulates the expression of crucial myeloid transcription factors, such as Sfpi1 and Cebpa. In the absence of GATA-1, GATA-2 prevents induction of a latent myeloid gene expression program. Thus, GATA-2 contributes to cell cycle progression and the maintenance of megakaryocyte identity of GATA-1-deficient cells, including GATA-1s-expressing fetal megakaryocyte progenitors. Moreover, our data reveal that overexpression of GATA-2 facilitates aberrant megakaryopoiesis.

Standard name | HUANG_GATA2_TARGETS_DN
Systematic name | M2439
Organism | Mus musculus
PMID | 19620289
Authors | Huang Z,Dore LC,Li Z,Orkin SH,Feng G,Lin S,Crispino JD
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in G1ME cells (megakaryocyte/erythroid progenitor lacking GATA1 [GeneID=2623]) upon knockdown of GATA2 [GeneID=2624] by RNAi.
Full description | GATA-2 is an essential transcription factor that regulates multiple aspects of hematopoiesis. Dysregulation of GATA-2 is a hallmark of acute megakaryoblastic leukemia in children with Down syndrome, a malignancy that is defined by the combination of trisomy 21 and a GATA1 mutation. Here, we show that GATA-2 is required for normal megakaryocyte development as well as aberrant megakaryopoiesis in Gata1 mutant cells. Furthermore, we demonstrate that GATA-2 indirectly controls cell cycle progression in GATA-1-deficient megakaryocytes. Genome-wide microarray analysis and chromatin immunoprecipitation studies revealed that GATA-2 regulates a wide set of genes, including cell cycle regulators and megakaryocyte-specific genes. Surprisingly, GATA-2 also negatively regulates the expression of crucial myeloid transcription factors, such as Sfpi1 and Cebpa. In the absence of GATA-1, GATA-2 prevents induction of a latent myeloid gene expression program. Thus, GATA-2 contributes to cell cycle progression and the maintenance of megakaryocyte identity of GATA-1-deficient cells, including GATA-1s-expressing fetal megakaryocyte progenitors. Moreover, our data reveal that overexpression of GATA-2 facilitates aberrant megakaryopoiesis.

Standard name | LE_NEURONAL_DIFFERENTIATION_UP
Systematic name | M2440
Organism | Homo sapiens
PMID | 19635812
Authors | Le MT,Xie H,Zhou B,Chia PH,Rizk P,Um M,Udolph G,Yang H,Lim B,Lodish HF
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated during neuronal differentiation of SH-SY5Y cells (neuroblastoma) in response to stimulation by tretinoin (all-trans retinoic acid, ATRA) [PubChem=444795] and BDNF [GeneID=627].
Full description | MicroRNAs (miRNAs) are a class of small noncoding RNAs that regulate gene expression at the posttranscriptional level. Research on miRNAs has highlighted their importance in neural development, but the specific functions of neurally enriched miRNAs remain poorly understood. We report here the expression profile of miRNAs during neuronal differentiation in the human neuroblastoma cell line SH-SY5Y. Six miRNAs were significantly upregulated during differentiation induced by all-trans-retinoic acid and brain-derived neurotrophic factor. We demonstrated that the ectopic expression of either miR-124a or miR-125b increases the percentage of differentiated SH-SY5Y cells with neurite outgrowth. Subsequently, we focused our functional analysis on miR-125b and demonstrated the important role of this miRNA in both the spontaneous and induced differentiations of SH-SH5Y cells. miR-125b is also upregulated during the differentiation of human neural progenitor ReNcell VM cells, and miR-125b ectopic expression significantly promotes the neurite outgrowth of these cells. To identify the targets of miR-125b regulation, we profiled the global changes in gene expression following miR-125b ectopic expression in SH-SY5Y cells. miR-125b represses 164 genes that contain the seed match sequence of the miRNA and/or that are predicted to be direct targets of miR-125b by conventional methods. Pathway analysis suggests that a subset of miR-125b-repressed targets antagonizes neuronal genes in several neurogenic pathways, thereby mediating the positive effect of miR-125b on neuronal differentiation. We have further validated the binding of miR-125b to the miRNA response elements of 10 selected mRNA targets. Together, we report here for the first time the important role of miR-125b in human neuronal differentiation.

Standard name | LE_NEURONAL_DIFFERENTIATION_DN
Systematic name | M2441
Organism | Homo sapiens
PMID | 19635812
Authors | Le MT,Xie H,Zhou B,Chia PH,Rizk P,Um M,Udolph G,Yang H,Lim B,Lodish HF
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated during neuronal differentiation of SH-SY5Y cells (neuroblastoma) in response to stimulation by tretinoin (all-trans retinoic acid, ATRA) [PubChem=444795] and BDNF [GeneID=627].
Full description | MicroRNAs (miRNAs) are a class of small noncoding RNAs that regulate gene expression at the posttranscriptional level. Research on miRNAs has highlighted their importance in neural development, but the specific functions of neurally enriched miRNAs remain poorly understood. We report here the expression profile of miRNAs during neuronal differentiation in the human neuroblastoma cell line SH-SY5Y. Six miRNAs were significantly upregulated during differentiation induced by all-trans-retinoic acid and brain-derived neurotrophic factor. We demonstrated that the ectopic expression of either miR-124a or miR-125b increases the percentage of differentiated SH-SY5Y cells with neurite outgrowth. Subsequently, we focused our functional analysis on miR-125b and demonstrated the important role of this miRNA in both the spontaneous and induced differentiations of SH-SH5Y cells. miR-125b is also upregulated during the differentiation of human neural progenitor ReNcell VM cells, and miR-125b ectopic expression significantly promotes the neurite outgrowth of these cells. To identify the targets of miR-125b regulation, we profiled the global changes in gene expression following miR-125b ectopic expression in SH-SY5Y cells. miR-125b represses 164 genes that contain the seed match sequence of the miRNA and/or that are predicted to be direct targets of miR-125b by conventional methods. Pathway analysis suggests that a subset of miR-125b-repressed targets antagonizes neuronal genes in several neurogenic pathways, thereby mediating the positive effect of miR-125b on neuronal differentiation. We have further validated the binding of miR-125b to the miRNA response elements of 10 selected mRNA targets. Together, we report here for the first time the important role of miR-125b in human neuronal differentiation.

Standard name | STEINER_ERYTHROCYTE_MEMBRANE_GENES
Systematic name | M2442
Organism | Homo sapiens
PMID | 19687298
Authors | Steiner LA,Maksimova Y,Schulz V,Wong C,Raha D,Mahajan MC,Weissman SM,Gallagher PG
Category | C2
Sub-category | CGP
Brief description | Major erythrocyte membrane genes.
Full description | Erythrocyte membrane protein genes serve as excellent models of complex gene locus structure and function, but their study has been complicated by both their large size and their complexity. To begin to understand the intricate interplay of transcription, dynamic chromatin architecture, transcription factor binding, and genomic organization in regulation of erythrocyte membrane protein genes, we performed chromatin immunoprecipitation (ChIP) coupled with microarray analysis and ChIP coupled with massively parallel DNA sequencing in both erythroid and nonerythroid cells. Unexpectedly, most regions of GATA-1 and NF-E2 binding were remote from gene promoters and transcriptional start sites, located primarily in introns. Cooccupancy with FOG-1, SCL, and MTA-2 was found at all regions of GATA-1 binding, with cooccupancy of SCL and MTA-2 also found at regions of NF-E2 binding. Cooccupancy of GATA-1 and NF-E2 was found frequently. A common signature of histone H3 trimethylation at lysine 4, GATA-1, NF-E2, FOG-1, SCL, and MTA-2 binding and consensus GATA-1-E-box binding motifs located 34 to 90 bp away from NF-E2 binding motifs was found frequently in erythroid cell-expressed genes. These results provide insights into our understanding of membrane protein gene regulation in erythropoiesis and the regulation of complex genetic loci in erythroid and nonerythroid cells and identify numerous candidate regions for mutations associated with membrane-linked hemolytic anemia.

Standard name | PLASARI_TGFB1_TARGETS_1HR_UP
Systematic name | M2443
Organism | Mus musculus
PMID | 19752192
Authors | Plasari G,Calabrese A,Dusserre Y,Gronostajski RM,McNair A,Michalik L,Mermod N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) upon stimulation with TGFB1 [GeneID=7040] for 1 h.
Full description | Transforming growth factor beta (TGF-beta) and platelet-derived growth factor A (PDGFAlpha) play a central role in tissue morphogenesis and repair, but their interplay remain poorly understood. The nuclear factor I C (NFI-C) transcription factor has been implicated in TGF-beta signaling, extracellular matrix deposition, and skin appendage pathologies, but a potential role in skin morphogenesis or healing had not been assessed. To evaluate this possibility, we performed a global gene expression analysis in NFI-C(-/-) and wild-type embryonic primary murine fibroblasts. This indicated that NFI-C acts mostly to repress gene expression in response to TGF-beta1. Misregulated genes were prominently overrepresented by regulators of connective tissue inflammation and repair. In vivo skin healing revealed a faster inflammatory stage and wound closure in NFI-C(-/-) mice. Expression of PDGFA and PDGF-receptor alpha were increased in wounds of NFI-C(-/-) mice, explaining the early recruitment of macrophages and fibroblasts. Differentiation of fibroblasts to contractile myofibroblasts was also elevated, providing a rationale for faster wound closure. Taken together with the role of TGF-beta in myofibroblast differentiation, our results imply a central role of NFI-C in the interplay of the two signaling pathways and in regulation of the progression of tissue regeneration.

Standard name | PLASARI_TGFB1_TARGETS_1HR_DN
Systematic name | M2444
Organism | Mus musculus
PMID | 19752192
Authors | Plasari G,Calabrese A,Dusserre Y,Gronostajski RM,McNair A,Michalik L,Mermod N
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblast) upon stimulation with TGFB1 [GeneID=7040] for 1 h.
Full description | Transforming growth factor beta (TGF-beta) and platelet-derived growth factor A (PDGFAlpha) play a central role in tissue morphogenesis and repair, but their interplay remain poorly understood. The nuclear factor I C (NFI-C) transcription factor has been implicated in TGF-beta signaling, extracellular matrix deposition, and skin appendage pathologies, but a potential role in skin morphogenesis or healing had not been assessed. To evaluate this possibility, we performed a global gene expression analysis in NFI-C(-/-) and wild-type embryonic primary murine fibroblasts. This indicated that NFI-C acts mostly to repress gene expression in response to TGF-beta1. Misregulated genes were prominently overrepresented by regulators of connective tissue inflammation and repair. In vivo skin healing revealed a faster inflammatory stage and wound closure in NFI-C(-/-) mice. Expression of PDGFA and PDGF-receptor alpha were increased in wounds of NFI-C(-/-) mice, explaining the early recruitment of macrophages and fibroblasts. Differentiation of fibroblasts to contractile myofibroblasts was also elevated, providing a rationale for faster wound closure. Taken together with the role of TGF-beta in myofibroblast differentiation, our results imply a central role of NFI-C in the interplay of the two signaling pathways and in regulation of the progression of tissue regeneration.

Standard name | PLASARI_TGFB1_TARGETS_10HR_UP
Systematic name | M2445
Organism | Mus musculus
PMID | 19752192
Authors | Plasari G,Calabrese A,Dusserre Y,Gronostajski RM,McNair A,Michalik L,Mermod N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) upon stimulation with TGFB1 [GeneID=7040] for 10 h.
Full description | Transforming growth factor beta (TGF-beta) and platelet-derived growth factor A (PDGFAlpha) play a central role in tissue morphogenesis and repair, but their interplay remain poorly understood. The nuclear factor I C (NFI-C) transcription factor has been implicated in TGF-beta signaling, extracellular matrix deposition, and skin appendage pathologies, but a potential role in skin morphogenesis or healing had not been assessed. To evaluate this possibility, we performed a global gene expression analysis in NFI-C(-/-) and wild-type embryonic primary murine fibroblasts. This indicated that NFI-C acts mostly to repress gene expression in response to TGF-beta1. Misregulated genes were prominently overrepresented by regulators of connective tissue inflammation and repair. In vivo skin healing revealed a faster inflammatory stage and wound closure in NFI-C(-/-) mice. Expression of PDGFA and PDGF-receptor alpha were increased in wounds of NFI-C(-/-) mice, explaining the early recruitment of macrophages and fibroblasts. Differentiation of fibroblasts to contractile myofibroblasts was also elevated, providing a rationale for faster wound closure. Taken together with the role of TGF-beta in myofibroblast differentiation, our results imply a central role of NFI-C in the interplay of the two signaling pathways and in regulation of the progression of tissue regeneration.

Standard name | PLASARI_TGFB1_TARGETS_10HR_DN
Systematic name | M2446
Organism | Mus musculus
PMID | 19752192
Authors | Plasari G,Calabrese A,Dusserre Y,Gronostajski RM,McNair A,Michalik L,Mermod N
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblast) upon stimulation with TGFB1 [GeneID=7040] for 10 h.
Full description | Transforming growth factor beta (TGF-beta) and platelet-derived growth factor A (PDGFAlpha) play a central role in tissue morphogenesis and repair, but their interplay remain poorly understood. The nuclear factor I C (NFI-C) transcription factor has been implicated in TGF-beta signaling, extracellular matrix deposition, and skin appendage pathologies, but a potential role in skin morphogenesis or healing had not been assessed. To evaluate this possibility, we performed a global gene expression analysis in NFI-C(-/-) and wild-type embryonic primary murine fibroblasts. This indicated that NFI-C acts mostly to repress gene expression in response to TGF-beta1. Misregulated genes were prominently overrepresented by regulators of connective tissue inflammation and repair. In vivo skin healing revealed a faster inflammatory stage and wound closure in NFI-C(-/-) mice. Expression of PDGFA and PDGF-receptor alpha were increased in wounds of NFI-C(-/-) mice, explaining the early recruitment of macrophages and fibroblasts. Differentiation of fibroblasts to contractile myofibroblasts was also elevated, providing a rationale for faster wound closure. Taken together with the role of TGF-beta in myofibroblast differentiation, our results imply a central role of NFI-C in the interplay of the two signaling pathways and in regulation of the progression of tissue regeneration.

Standard name | PLASARI_NFIC_TARGETS_BASAL_UP
Systematic name | M2447
Organism | Mus musculus
PMID | 19752192
Authors | Plasari G,Calabrese A,Dusserre Y,Gronostajski RM,McNair A,Michalik L,Mermod N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) upon knockout of NFIC [GeneID=4782].
Full description | Transforming growth factor beta (TGF-beta) and platelet-derived growth factor A (PDGFAlpha) play a central role in tissue morphogenesis and repair, but their interplay remain poorly understood. The nuclear factor I C (NFI-C) transcription factor has been implicated in TGF-beta signaling, extracellular matrix deposition, and skin appendage pathologies, but a potential role in skin morphogenesis or healing had not been assessed. To evaluate this possibility, we performed a global gene expression analysis in NFI-C(-/-) and wild-type embryonic primary murine fibroblasts. This indicated that NFI-C acts mostly to repress gene expression in response to TGF-beta1. Misregulated genes were prominently overrepresented by regulators of connective tissue inflammation and repair. In vivo skin healing revealed a faster inflammatory stage and wound closure in NFI-C(-/-) mice. Expression of PDGFA and PDGF-receptor alpha were increased in wounds of NFI-C(-/-) mice, explaining the early recruitment of macrophages and fibroblasts. Differentiation of fibroblasts to contractile myofibroblasts was also elevated, providing a rationale for faster wound closure. Taken together with the role of TGF-beta in myofibroblast differentiation, our results imply a central role of NFI-C in the interplay of the two signaling pathways and in regulation of the progression of tissue regeneration.

Standard name | PLASARI_NFIC_TARGETS_BASAL_DN
Systematic name | M2449
Organism | Mus musculus
PMID | 19752192
Authors | Plasari G,Calabrese A,Dusserre Y,Gronostajski RM,McNair A,Michalik L,Mermod N
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in MEF cells (embryonic fibroblast) upon knockout of NFIC [GeneID=4782].
Full description | Transforming growth factor beta (TGF-beta) and platelet-derived growth factor A (PDGFAlpha) play a central role in tissue morphogenesis and repair, but their interplay remain poorly understood. The nuclear factor I C (NFI-C) transcription factor has been implicated in TGF-beta signaling, extracellular matrix deposition, and skin appendage pathologies, but a potential role in skin morphogenesis or healing had not been assessed. To evaluate this possibility, we performed a global gene expression analysis in NFI-C(-/-) and wild-type embryonic primary murine fibroblasts. This indicated that NFI-C acts mostly to repress gene expression in response to TGF-beta1. Misregulated genes were prominently overrepresented by regulators of connective tissue inflammation and repair. In vivo skin healing revealed a faster inflammatory stage and wound closure in NFI-C(-/-) mice. Expression of PDGFA and PDGF-receptor alpha were increased in wounds of NFI-C(-/-) mice, explaining the early recruitment of macrophages and fibroblasts. Differentiation of fibroblasts to contractile myofibroblasts was also elevated, providing a rationale for faster wound closure. Taken together with the role of TGF-beta in myofibroblast differentiation, our results imply a central role of NFI-C in the interplay of the two signaling pathways and in regulation of the progression of tissue regeneration.

Standard name | PLASARI_TGFB1_SIGNALING_VIA_NFIC_1HR_UP
Systematic name | M2450
Organism | Mus musculus
PMID | 19752192
Authors | Plasari G,Calabrese A,Dusserre Y,Gronostajski RM,McNair A,Michalik L,Mermod N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated after 1 h of TGFB1 [GeneID=7040] stimulation in MEF cells (embryonic fibroblast) with NFIC [GeneID=4782] knockout vs wild type MEFs.
Full description | Transforming growth factor beta (TGF-beta) and platelet-derived growth factor A (PDGFAlpha) play a central role in tissue morphogenesis and repair, but their interplay remain poorly understood. The nuclear factor I C (NFI-C) transcription factor has been implicated in TGF-beta signaling, extracellular matrix deposition, and skin appendage pathologies, but a potential role in skin morphogenesis or healing had not been assessed. To evaluate this possibility, we performed a global gene expression analysis in NFI-C(-/-) and wild-type embryonic primary murine fibroblasts. This indicated that NFI-C acts mostly to repress gene expression in response to TGF-beta1. Misregulated genes were prominently overrepresented by regulators of connective tissue inflammation and repair. In vivo skin healing revealed a faster inflammatory stage and wound closure in NFI-C(-/-) mice. Expression of PDGFA and PDGF-receptor alpha were increased in wounds of NFI-C(-/-) mice, explaining the early recruitment of macrophages and fibroblasts. Differentiation of fibroblasts to contractile myofibroblasts was also elevated, providing a rationale for faster wound closure. Taken together with the role of TGF-beta in myofibroblast differentiation, our results imply a central role of NFI-C in the interplay of the two signaling pathways and in regulation of the progression of tissue regeneration.

Standard name | PLASARI_TGFB1_SIGNALING_VIA_NFIC_1HR_DN
Systematic name | M2451
Organism | Mus musculus
PMID | 19752192
Authors | Plasari G,Calabrese A,Dusserre Y,Gronostajski RM,McNair A,Michalik L,Mermod N
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated after 1 h of TGFB1 [GeneID=7040] stimulation in MEF cells (embryonic fibroblast) with NFIC [GeneID=4782] knockout vs wild type MEFs.
Full description | Transforming growth factor beta (TGF-beta) and platelet-derived growth factor A (PDGFAlpha) play a central role in tissue morphogenesis and repair, but their interplay remain poorly understood. The nuclear factor I C (NFI-C) transcription factor has been implicated in TGF-beta signaling, extracellular matrix deposition, and skin appendage pathologies, but a potential role in skin morphogenesis or healing had not been assessed. To evaluate this possibility, we performed a global gene expression analysis in NFI-C(-/-) and wild-type embryonic primary murine fibroblasts. This indicated that NFI-C acts mostly to repress gene expression in response to TGF-beta1. Misregulated genes were prominently overrepresented by regulators of connective tissue inflammation and repair. In vivo skin healing revealed a faster inflammatory stage and wound closure in NFI-C(-/-) mice. Expression of PDGFA and PDGF-receptor alpha were increased in wounds of NFI-C(-/-) mice, explaining the early recruitment of macrophages and fibroblasts. Differentiation of fibroblasts to contractile myofibroblasts was also elevated, providing a rationale for faster wound closure. Taken together with the role of TGF-beta in myofibroblast differentiation, our results imply a central role of NFI-C in the interplay of the two signaling pathways and in regulation of the progression of tissue regeneration.

Standard name | PLASARI_TGFB1_SIGNALING_VIA_NFIC_10HR_UP
Systematic name | M2452
Organism | Mus musculus
PMID | 19752192
Authors | Plasari G,Calabrese A,Dusserre Y,Gronostajski RM,McNair A,Michalik L,Mermod N
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated after 10 h of TGFB1 [GeneID=7040] stimulation in MEF cells (embryonic fibroblast) with NFIC [GeneID=4782] knockout vs wild type MEFs.
Full description | Transforming growth factor beta (TGF-beta) and platelet-derived growth factor A (PDGFAlpha) play a central role in tissue morphogenesis and repair, but their interplay remain poorly understood. The nuclear factor I C (NFI-C) transcription factor has been implicated in TGF-beta signaling, extracellular matrix deposition, and skin appendage pathologies, but a potential role in skin morphogenesis or healing had not been assessed. To evaluate this possibility, we performed a global gene expression analysis in NFI-C(-/-) and wild-type embryonic primary murine fibroblasts. This indicated that NFI-C acts mostly to repress gene expression in response to TGF-beta1. Misregulated genes were prominently overrepresented by regulators of connective tissue inflammation and repair. In vivo skin healing revealed a faster inflammatory stage and wound closure in NFI-C(-/-) mice. Expression of PDGFA and PDGF-receptor alpha were increased in wounds of NFI-C(-/-) mice, explaining the early recruitment of macrophages and fibroblasts. Differentiation of fibroblasts to contractile myofibroblasts was also elevated, providing a rationale for faster wound closure. Taken together with the role of TGF-beta in myofibroblast differentiation, our results imply a central role of NFI-C in the interplay of the two signaling pathways and in regulation of the progression of tissue regeneration.

Standard name | PLASARI_TGFB1_SIGNALING_VIA_NFIC_10HR_DN
Systematic name | M2455
Organism | Mus musculus
PMID | 19752192
Authors | Plasari G,Calabrese A,Dusserre Y,Gronostajski RM,McNair A,Michalik L,Mermod N
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated after 10 h of TGFB1 [GeneID=7040] stimulation in MEF cells (embryonic fibroblast) with NFIC [GeneID=4782] knockout vs wild type MEFs.
Full description | Transforming growth factor beta (TGF-beta) and platelet-derived growth factor A (PDGFAlpha) play a central role in tissue morphogenesis and repair, but their interplay remain poorly understood. The nuclear factor I C (NFI-C) transcription factor has been implicated in TGF-beta signaling, extracellular matrix deposition, and skin appendage pathologies, but a potential role in skin morphogenesis or healing had not been assessed. To evaluate this possibility, we performed a global gene expression analysis in NFI-C(-/-) and wild-type embryonic primary murine fibroblasts. This indicated that NFI-C acts mostly to repress gene expression in response to TGF-beta1. Misregulated genes were prominently overrepresented by regulators of connective tissue inflammation and repair. In vivo skin healing revealed a faster inflammatory stage and wound closure in NFI-C(-/-) mice. Expression of PDGFA and PDGF-receptor alpha were increased in wounds of NFI-C(-/-) mice, explaining the early recruitment of macrophages and fibroblasts. Differentiation of fibroblasts to contractile myofibroblasts was also elevated, providing a rationale for faster wound closure. Taken together with the role of TGF-beta in myofibroblast differentiation, our results imply a central role of NFI-C in the interplay of the two signaling pathways and in regulation of the progression of tissue regeneration.

Standard name | WANG_MLL_TARGETS
Systematic name | M2456
Organism | Mus musculus
PMID | 19703992
Authors | Wang P,Lin C,Smith ER,Guo H,Sanderson BW,Wu M,Gogol M,Alexander T,Seidel C,Wiedemann LM,Ge K,Krumlauf R,Shilatifard A
Category | C2
Sub-category | CGP
Brief description | Genes requiring MLL [GeneID=4297] for H3K4me3 and expression in MEF cells (embryonic fibroblast).
Full description | A common landmark of activated genes is the presence of trimethylation on lysine 4 of histone H3 (H3K4) at promoter regions. Set1/COMPASS was the founding member and is the only H3K4 methylase in Saccharomyces cerevisiae; however, in mammals, at least six H3K4 methylases, Set1A and Set1B and MLL1 to MLL4, are found in COMPASS-like complexes capable of methylating H3K4. To gain further insight into the different roles and functional targets for the H3K4 methylases, we have undertaken a genome-wide analysis of H3K4 methylation patterns in wild-type Mll1(+/+) and Mll1(-)(/)(-) mouse embryonic fibroblasts (MEFs). We found that Mll1 is required for the H3K4 trimethylation of less than 5% of promoters carrying this modification. Many of these genes, which include developmental regulators such as Hox genes, show decreased levels of RNA polymerase II recruitment and expression concomitant with the loss of H3K4 methylation. Although Mll1 is only required for the methylation of a subset of Hox genes, menin, a component of the Mll1 and Mll2 complexes, is required for the overwhelming majority of H3K4 methylation at Hox loci. However, the loss of MLL3/MLL4 and/or the Set1 complexes has little to no effect on the H3K4 methylation of Hox loci or their expression levels in these MEFs. Together these data provide insight into the redundancy and specialization of COMPASS-like complexes in mammals and provide evidence for a possible role for Mll1-mediated H3K4 methylation in the regulation of transcriptional initiation.

Standard name | SANDERSON_PPARA_TARGETS
Systematic name | M2458
Organism | Mus musculus
PMID | 19805517
Authors | Sanderson LM,Degenhardt T,Koppen A,Kalkhoven E,Desvergne B,Müller M,Kersten S
Category | C2
Sub-category | CGP
Brief description | Hepatic genes regulated by fasting or in response to WY14643 [PubChem=5694] and which require intact PPARA [GeneID=5465].
Full description | Peroxisome proliferator-activated receptor alpha (PPARalpha) is an important transcription factor in liver that can be activated physiologically by fasting or pharmacologically by using high-affinity synthetic agonists. Here we initially set out to elucidate the similarities in gene induction between Wy14643 and fasting. Numerous genes were commonly regulated in liver between the two treatments, including many classical PPARalpha target genes, such as Aldh3a2 and Cpt2. Remarkably, several genes induced by Wy14643 were upregulated by fasting independently of PPARalpha, including Lpin2 and St3gal5, suggesting involvement of another transcription factor. Using chromatin immunoprecipitation, Lpin2 and St3gal5 were shown to be direct targets of PPARbeta/delta during fasting, whereas Aldh3a2 and Cpt2 were exclusive targets of PPARalpha. Binding of PPARbeta/delta to the Lpin2 and St3gal5 genes followed the plasma free fatty acid (FFA) concentration, consistent with activation of PPARbeta/delta by plasma FFAs. Subsequent experiments using transgenic and knockout mice for Angptl4, a potent stimulant of adipose tissue lipolysis, confirmed the stimulatory effect of plasma FFAs on Lpin2 and St3gal5 expression levels via PPARbeta/delta. In contrast, the data did not support activation of PPARalpha by plasma FFAs. The results identify Lpin2 and St3gal5 as novel PPARbeta/delta target genes and show that upregulation of gene expression by PPARbeta/delta is sensitive to plasma FFA levels. In contrast, this is not the case for PPARalpha, revealing a novel mechanism for functional differentiation between PPARs.

Standard name | KANG_GLIS3_TARGETS
Systematic name | M2460
Organism | Mus musculus
PMID | 19805515
Authors | Kang HS,Kim YS,ZeRuth G,Beak JY,Gerrish K,Kilic G,Sosa-Pineda B,Jensen J,Pierreux CE,Lemaigre FP,Foley J,Jetten AM
Category | C2
Sub-category | CGP
Brief description | Genes downregulated in the postnatal day 3 pancreata with impaired function of GLIS3 [GeneID=169792].
Full description | Chromatin assembly factor 1 (CAF-1) deposits histones H3 and H4 rapidly behind replication forks through an interaction with the proliferating cell nuclear antigen (PCNA), a DNA polymerase processivity factor that also binds to a number of replication enzymes and other proteins that act on nascent DNA. The mechanisms that enable CAF-1 and other PCNA-binding proteins to function harmoniously at the replication fork are poorly understood. Here we report that the large subunit of human CAF-1 (p150) contains two distinct PCNA interaction peptides (PIPs). The N-terminal PIP binds strongly to PCNA in vitro but, surprisingly, is dispensable for nucleosome assembly and only makes a modest contribution to targeting p150 to DNA replication foci in vivo. In contrast, the internal PIP (PIP2) lacks one of the highly conserved residues of canonical PIPs and binds weakly to PCNA. Surprisingly, PIP2 is essential for nucleosome assembly during DNA replication in vitro and plays a major role in targeting p150 to sites of DNA replication. Unlike canonical PIPs, such as that of p21, the two p150 PIPs are capable of preferentially inhibiting nucleosome assembly, rather than DNA synthesis, suggesting that intrinsic features of these peptides are part of the mechanism that enables CAF-1 to function behind replication forks without interfering with other PCNA-mediated processes.

Standard name | DELACROIX_RARG_BOUND_MEF
Systematic name | M2461
Organism | Mus musculus
PMID | 19884340
Authors | Delacroix L,Moutier E,Altobelli G,Legras S,Poch O,Choukrallah MA,Bertin I,Jost B,Davidson I
Category | C2
Sub-category | CGP
Brief description | Genes with DNA sequences bound by RARG [GeneID=5916] in MEF cells (embryonic fibroblast).
Full description | All-trans retinoic acid (RA) induces transforming growth factor beta (TGF-beta)-dependent autocrine growth of mouse embryonic fibroblasts (MEFs). We have used chromatin immunoprecipitation to map 354 RA receptor (RAR) binding loci in MEFs, most of which were similarly occupied by the RAR alpha and RAR gamma receptors. Only a subset of the genes associated with these loci are regulated by RA, among which are several critical components of the TGF-beta pathway. We also show RAR binding to a novel series of target genes involved in cell cycle regulation, transformation, and metastasis, suggesting new pathways by which RA may regulate proliferation and cancer. Few of the RAR binding loci contained consensus direct-repeat (DR)-type elements. The majority comprised either degenerate DRs or no identifiable DRs but anomalously spaced half sites. Furthermore, we identify 462 RAR target loci in embryonic stem (ES) cells and show that their occupancy is cell type specific. Our results also show that differences in the chromatin landscape regulate the accessibility of a subset of more than 700 identified loci to RARs, thus modulating the repertoire of target genes that can be regulated and the biological effects of RA.

Standard name | DELACROIX_RAR_TARGETS_UP
Systematic name | M2464
Organism | Mus musculus
PMID | 19884340
Authors | Delacroix L,Moutier E,Altobelli G,Legras S,Poch O,Choukrallah MA,Bertin I,Jost B,Davidson I
Category | C2
Sub-category | CGP
Brief description | Genes bound by RARG [GeneID=5916] and up-regulated by tretinoin (all-trans retinoic acid, ATRA) [PubChem=444795] in MEF cells (embryonic fibroblast).
Full description | All-trans retinoic acid (RA) induces transforming growth factor beta (TGF-beta)-dependent autocrine growth of mouse embryonic fibroblasts (MEFs). We have used chromatin immunoprecipitation to map 354 RA receptor (RAR) binding loci in MEFs, most of which were similarly occupied by the RAR alpha and RAR gamma receptors. Only a subset of the genes associated with these loci are regulated by RA, among which are several critical components of the TGF-beta pathway. We also show RAR binding to a novel series of target genes involved in cell cycle regulation, transformation, and metastasis, suggesting new pathways by which RA may regulate proliferation and cancer. Few of the RAR binding loci contained consensus direct-repeat (DR)-type elements. The majority comprised either degenerate DRs or no identifiable DRs but anomalously spaced half sites. Furthermore, we identify 462 RAR target loci in embryonic stem (ES) cells and show that their occupancy is cell type specific. Our results also show that differences in the chromatin landscape regulate the accessibility of a subset of more than 700 identified loci to RARs, thus modulating the repertoire of target genes that can be regulated and the biological effects of RA.

Standard name | DELACROIX_RAR_TARGETS_DN
Systematic name | M2465
Organism | Mus musculus
PMID | 19884340
Authors | Delacroix L,Moutier E,Altobelli G,Legras S,Poch O,Choukrallah MA,Bertin I,Jost B,Davidson I
Category | C2
Sub-category | CGP
Brief description | Genes bound by RARG [GeneID=5916] and down-regulated by tretinoin (all-trans retinoic acid, ATRA) [PubChem=444795] in MEF cells (embryonic fibroblast).
Full description | All-trans retinoic acid (RA) induces transforming growth factor beta (TGF-beta)-dependent autocrine growth of mouse embryonic fibroblasts (MEFs). We have used chromatin immunoprecipitation to map 354 RA receptor (RAR) binding loci in MEFs, most of which were similarly occupied by the RAR alpha and RAR gamma receptors. Only a subset of the genes associated with these loci are regulated by RA, among which are several critical components of the TGF-beta pathway. We also show RAR binding to a novel series of target genes involved in cell cycle regulation, transformation, and metastasis, suggesting new pathways by which RA may regulate proliferation and cancer. Few of the RAR binding loci contained consensus direct-repeat (DR)-type elements. The majority comprised either degenerate DRs or no identifiable DRs but anomalously spaced half sites. Furthermore, we identify 462 RAR target loci in embryonic stem (ES) cells and show that their occupancy is cell type specific. Our results also show that differences in the chromatin landscape regulate the accessibility of a subset of more than 700 identified loci to RARs, thus modulating the repertoire of target genes that can be regulated and the biological effects of RA.

Standard name | DELACROIX_RAR_BOUND_ES
Systematic name | M2466
Organism | Mus musculus
PMID | 19884340
Authors | Delacroix L,Moutier E,Altobelli G,Legras S,Poch O,Choukrallah MA,Bertin I,Jost B,Davidson I
Category | C2
Sub-category | CGP
Brief description | Genes with DNA sequences bound by RARA and RARG [GeneID=5914, 5916] in ES cells.
Full description | All-trans retinoic acid (RA) induces transforming growth factor beta (TGF-beta)-dependent autocrine growth of mouse embryonic fibroblasts (MEFs). We have used chromatin immunoprecipitation to map 354 RA receptor (RAR) binding loci in MEFs, most of which were similarly occupied by the RAR alpha and RAR gamma receptors. Only a subset of the genes associated with these loci are regulated by RA, among which are several critical components of the TGF-beta pathway. We also show RAR binding to a novel series of target genes involved in cell cycle regulation, transformation, and metastasis, suggesting new pathways by which RA may regulate proliferation and cancer. Few of the RAR binding loci contained consensus direct-repeat (DR)-type elements. The majority comprised either degenerate DRs or no identifiable DRs but anomalously spaced half sites. Furthermore, we identify 462 RAR target loci in embryonic stem (ES) cells and show that their occupancy is cell type specific. Our results also show that differences in the chromatin landscape regulate the accessibility of a subset of more than 700 identified loci to RARs, thus modulating the repertoire of target genes that can be regulated and the biological effects of RA.

Standard name | KRIEG_HYPOXIA_VIA_KDM3A
Systematic name | M2467
Organism | Homo sapiens
PMID | 19858293
Authors | Krieg AJ,Rankin EB,Chan D,Razorenova O,Fernandez S,Giaccia AJ
Category | C2
Sub-category | CGP
Brief description | Genes dependent on KDM3A [GeneID=55818] for hypoxic induction in RCC4 cells (renal carcinoma) expressing VHL [GeneID=7428].
Full description | The hypoxia-inducible transcription factors (HIFs) directly and indirectly mediate cellular adaptation to reduced oxygen tensions. Recent studies have shown that the histone demethylase genes JMJD1A, JMJD2B, and JARID1B are HIF targets, suggesting that HIFs indirectly influence gene expression at the level of histone methylation under hypoxia. In this study, we identify a subset of hypoxia-inducible genes that are dependent on JMJD1A in both renal cell and colon carcinoma cell lines. JMJD1A regulates the expression of adrenomedullin (ADM) and growth and differentiation factor 15 (GDF15) under hypoxia by decreasing promoter histone methylation. In addition, we demonstrate that loss of JMJD1A is sufficient to reduce tumor growth in vivo, demonstrating that histone demethylation plays a significant role in modulating growth within the tumor microenvironment. Thus, hypoxic regulation of JMJD1A acts as a signal amplifier to facilitate hypoxic gene expression, ultimately enhancing tumor growth.

Standard name | KRIEG_KDM3A_TARGETS_NOT_HYPOXIA
Systematic name | M2468
Organism | Homo sapiens
PMID | 19858293
Authors | Krieg AJ,Rankin EB,Chan D,Razorenova O,Fernandez S,Giaccia AJ
Category | C2
Sub-category | CGP
Brief description | Genes not induced under hypoxia, but dependent on KDM3A [GeneID=55818] for hypoxic expression in RCC4 cells (renal carcinoma) expressing VHL [GeneID=7428].
Full description | The hypoxia-inducible transcription factors (HIFs) directly and indirectly mediate cellular adaptation to reduced oxygen tensions. Recent studies have shown that the histone demethylase genes JMJD1A, JMJD2B, and JARID1B are HIF targets, suggesting that HIFs indirectly influence gene expression at the level of histone methylation under hypoxia. In this study, we identify a subset of hypoxia-inducible genes that are dependent on JMJD1A in both renal cell and colon carcinoma cell lines. JMJD1A regulates the expression of adrenomedullin (ADM) and growth and differentiation factor 15 (GDF15) under hypoxia by decreasing promoter histone methylation. In addition, we demonstrate that loss of JMJD1A is sufficient to reduce tumor growth in vivo, demonstrating that histone demethylation plays a significant role in modulating growth within the tumor microenvironment. Thus, hypoxic regulation of JMJD1A acts as a signal amplifier to facilitate hypoxic gene expression, ultimately enhancing tumor growth.

Standard name | KRIEG_HYPOXIA_NOT_VIA_KDM3A
Systematic name | M2469
Organism | Homo sapiens
PMID | 19858293
Authors | Krieg AJ,Rankin EB,Chan D,Razorenova O,Fernandez S,Giaccia AJ
Category | C2
Sub-category | CGP
Brief description | Genes induced under hypoxia independently of KDM3A [GeneID=55818] in RCC4 cells (renal carcinoma) expressing VHL [GeneID=7428].
Full description | The hypoxia-inducible transcription factors (HIFs) directly and indirectly mediate cellular adaptation to reduced oxygen tensions. Recent studies have shown that the histone demethylase genes JMJD1A, JMJD2B, and JARID1B are HIF targets, suggesting that HIFs indirectly influence gene expression at the level of histone methylation under hypoxia. In this study, we identify a subset of hypoxia-inducible genes that are dependent on JMJD1A in both renal cell and colon carcinoma cell lines. JMJD1A regulates the expression of adrenomedullin (ADM) and growth and differentiation factor 15 (GDF15) under hypoxia by decreasing promoter histone methylation. In addition, we demonstrate that loss of JMJD1A is sufficient to reduce tumor growth in vivo, demonstrating that histone demethylation plays a significant role in modulating growth within the tumor microenvironment. Thus, hypoxic regulation of JMJD1A acts as a signal amplifier to facilitate hypoxic gene expression, ultimately enhancing tumor growth.

Standard name | MALIK_REPRESSED_BY_ESTROGEN
Systematic name | M2470
Organism | Homo sapiens
PMID | 19917725
Authors | Malik S,Jiang S,Garee JP,Verdin E,Lee AV,O'Malley BW,Zhang M,Belaguli NS,Oesterreich S
Category | C2
Sub-category | CGP
Brief description | Genes consistently and robustly repressed by estradiol [PubChem=5757] in MCF7 cells (breast cancer); this reperession was prevented by fulvestrant [PubChem=3478439].
Full description | Activation of estrogen receptor alpha (ERalpha) results in both induction and repression of gene transcription; while mechanistic details of estrogen induction are well described, details of repression remain largely unknown. We characterized several ERalpha-repressed targets and examined in detail the mechanism for estrogen repression of Reprimo (RPRM), a cell cycle inhibitor. Estrogen repression of RPRM is rapid and robust and requires a tripartite interaction between ERalpha, histone deacetylase 7 (HDAC7), and FoxA1. HDAC7 is the critical HDAC needed for repression of RPRM; it can bind to ERalpha and represses ERalpha's transcriptional activity--this repression does not require HDAC7's deacetylase activity. We further show that the chromatin pioneer factor FoxA1, well known for its role in estrogen induction of genes, is recruited to the RPRM promoter, is necessary for repression of RPRM, and interacts with HDAC7. Like other FoxA1 recruitment sites, the RPRM promoter is characterized by H3K4me1/me2. Estrogen treatment causes decreases in H3K4me1/me2 and release of RNA polymerase II (Pol II) from the RPRM proximal promoter. Overall, these data implicate a novel role for HDAC7 and FoxA1 in estrogen repression of RPRM, a mechanism which could potentially be generalized to many more estrogen-repressed genes and hence be important in both normal physiology and pathological processes.

Standard name | TIAN_BHLHA15_TARGETS
Systematic name | M2471
Organism | Homo sapiens
PMID | 20038531
Authors | Tian X,Jin RU,Bredemeyer AJ,Oates EJ,Błazewska KM,McKenna CE,Mills JC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in both AGS and HGC-27 cells (gastric cancer) by BHLHA15 [GeneID=168620] transfection.
Full description | Little is known about how differentiating cells reorganize their cellular structure to perform specialized physiological functions. MIST1, an evolutionarily conserved transcription factor, is required for the formation of large, specialized secretory vesicles in gastric zymogenic (chief) cells (ZCs) as they differentiate from their mucous neck cell progenitors. Here, we show that MIST1 binds to highly conserved CATATG E-boxes to directly activate transcription of 6 genes, including those encoding the small GTPases RAB26 and RAB3D. We next show that RAB26 and RAB3D expression is significantly downregulated in Mist1(-)(/)(-) ZCs, suggesting that MIST1 establishes large secretory granules by inducing RAB transcription. To test this hypothesis, we transfected human gastric cancer cell lines stably expressing MIST1 with red fluorescent protein (RFP)-tagged pepsinogen C, a key secretory product of ZCs. Those cells upregulate expression of RAB26 and RAB3D to form large secretory granules, whereas control, non-MIST1-expressing cells do not. Moreover, granule formation in MIST1-expressing cells requires RAB activity because treatment with a RAB prenylation inhibitor and transfection of dominant negative RAB26 abrogate granule formation. Together, our data establish the molecular process by which a transcription factor can directly induce fundamental cellular architecture changes by increasing transcription of specific cellular effectors that act to organize a unique subcellular compartment.

Standard name | LIU_IL13_MEMORY_MODEL_UP
Systematic name | M2474
Organism | Homo sapiens
PMID | 20123980
Authors | Liu W,Tundwal K,Liang Q,Goplen N,Rozario S,Quayum N,Gorska M,Wenzel S,Balzar S,Alam R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in BEAS-2B cells (bronchial epithelium) stimulated with IL13 [GeneID=3596] on days 1 to 3 and then rested for the next 3 days (repeated-stimulation or memory model)
Full description | Our objective was to establish an experimental model of a self-sustained and bistable extracellular signal-regulated kinase 1/2 (ERK1/2) signaling process. A single stimulation of cells with cytokines causes rapid ERK1/2 activation, which returns to baseline in 4 h. Repeated stimulation leads to sustained activation of ERK1/2 but not Jun N-terminal protein kinase (JNK), p38, or STAT6. The ERK1/2 activation lasts for 3 to 7 days and depends upon a positive-feedback mechanism involving Sprouty 2. Overexpression of Sprouty 2 induces, and its genetic deletion abrogates, ERK1/2 bistability. Sprouty 2 directly activates Fyn kinase, which then induces ERK1/2 activation. A genome-wide microarray analysis shows that the bistable phospho-ERK1/2 (pERK1/2) does not induce a high level of gene transcription. This is due to its nuclear exclusion and compartmentalization to Rab5+ endosomes. Cells with sustained endosomal pERK1/2 manifest resistance against growth factor withdrawal-induced cell death. They are primed for heightened cytokine production. Epithelial cells from cases of human asthma and from a mouse model of chronic asthma manifest increased pERK1/2, which is associated with Rab5+ endosomes. The increase in pERK1/2 was associated with a simultaneous increase in Sprouty 2 expression in these tissues. Thus, we have developed a cellular model of sustained ERK1/2 activation, which may provide a mechanistic understanding of self-sustained biological processes in chronic illnesses such as asthma.

Standard name | LIU_IL13_MEMORY_MODEL_DN
Systematic name | M2475
Organism | Homo sapiens
PMID | 20123980
Authors | Liu W,Tundwal K,Liang Q,Goplen N,Rozario S,Quayum N,Gorska M,Wenzel S,Balzar S,Alam R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in BEAS-2B cells (bronchial epithelium) stimulated with IL13 [GeneID=3596] on days 1 to 3 and then rested for the next 3 days (repeated-stimulation or memory model)
Full description | Our objective was to establish an experimental model of a self-sustained and bistable extracellular signal-regulated kinase 1/2 (ERK1/2) signaling process. A single stimulation of cells with cytokines causes rapid ERK1/2 activation, which returns to baseline in 4 h. Repeated stimulation leads to sustained activation of ERK1/2 but not Jun N-terminal protein kinase (JNK), p38, or STAT6. The ERK1/2 activation lasts for 3 to 7 days and depends upon a positive-feedback mechanism involving Sprouty 2. Overexpression of Sprouty 2 induces, and its genetic deletion abrogates, ERK1/2 bistability. Sprouty 2 directly activates Fyn kinase, which then induces ERK1/2 activation. A genome-wide microarray analysis shows that the bistable phospho-ERK1/2 (pERK1/2) does not induce a high level of gene transcription. This is due to its nuclear exclusion and compartmentalization to Rab5+ endosomes. Cells with sustained endosomal pERK1/2 manifest resistance against growth factor withdrawal-induced cell death. They are primed for heightened cytokine production. Epithelial cells from cases of human asthma and from a mouse model of chronic asthma manifest increased pERK1/2, which is associated with Rab5+ endosomes. The increase in pERK1/2 was associated with a simultaneous increase in Sprouty 2 expression in these tissues. Thus, we have developed a cellular model of sustained ERK1/2 activation, which may provide a mechanistic understanding of self-sustained biological processes in chronic illnesses such as asthma.

Standard name | LIU_IL13_PRIMING_MODEL
Systematic name | M2476
Organism | Homo sapiens
PMID | 20123980
Authors | Liu W,Tundwal K,Liang Q,Goplen N,Rozario S,Quayum N,Gorska M,Wenzel S,Balzar S,Alam R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in BEAS-2B cells (bronchial epithelium) stimulated with IL13 [GeneID=3596] on days 1 to 3, rested on days 4 and 5, and then restimulated on day 6 for 1 h before lysis (priming model).
Full description | Our objective was to establish an experimental model of a self-sustained and bistable extracellular signal-regulated kinase 1/2 (ERK1/2) signaling process. A single stimulation of cells with cytokines causes rapid ERK1/2 activation, which returns to baseline in 4 h. Repeated stimulation leads to sustained activation of ERK1/2 but not Jun N-terminal protein kinase (JNK), p38, or STAT6. The ERK1/2 activation lasts for 3 to 7 days and depends upon a positive-feedback mechanism involving Sprouty 2. Overexpression of Sprouty 2 induces, and its genetic deletion abrogates, ERK1/2 bistability. Sprouty 2 directly activates Fyn kinase, which then induces ERK1/2 activation. A genome-wide microarray analysis shows that the bistable phospho-ERK1/2 (pERK1/2) does not induce a high level of gene transcription. This is due to its nuclear exclusion and compartmentalization to Rab5+ endosomes. Cells with sustained endosomal pERK1/2 manifest resistance against growth factor withdrawal-induced cell death. They are primed for heightened cytokine production. Epithelial cells from cases of human asthma and from a mouse model of chronic asthma manifest increased pERK1/2, which is associated with Rab5+ endosomes. The increase in pERK1/2 was associated with a simultaneous increase in Sprouty 2 expression in these tissues. Thus, we have developed a cellular model of sustained ERK1/2 activation, which may provide a mechanistic understanding of self-sustained biological processes in chronic illnesses such as asthma.

Standard name | ALFANO_MYC_TARGETS
Systematic name | M2477
Organism | Homo sapiens
PMID | 20123981
Authors | Alfano D,Votta G,Schulze A,Downward J,Caputi M,Stoppelli MP,Iaccarino I
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated hT-RPE cells (immortalized retinal pigment epithelium) by MYC [GeneID=4609].
Full description | It has been proposed that c-Myc proapoptotic activity accounts for most of its restraint of tumor formation. We established a telomerase-immortalized human epithelial cell line expressing an activatable c-Myc protein. We found that c-Myc activation induces, in addition to increased sensitivity to apoptosis, reductions in cell motility and invasiveness. Transcriptome analysis revealed that urokinase (uPA) and uPA receptor (uPAR) were strongly downregulated by c-Myc. Evidence is provided that the repression of uPA and uPAR may account for most of the antimigratory and proapoptotic activities of c-Myc. c-Myc is known to cooperate with Ras in cellular transformation. We therefore investigated if this cooperation could converge in the control of uPA/uPAR expression. We found that Ras is able to block the effects of c-Myc activation on apoptosis and cellular motility but not on cell invasiveness. Accordingly, the activation of c-Myc in the context of Ras expression had only minor influence on uPAR expression but still had a profound repressive effect on uPA expression. Thus, the differential regulation of uPA and uPAR by c-Myc and Ras correlates with the effects of these two oncoproteins on cell motility, invasiveness, and survival. In conclusion, we have discovered a novel link between c-Myc and uPA/uPAR. We propose that reductions of cell motility and invasiveness could contribute to the inhibition of tumorigenesis by c-Myc and that the regulation of uPA and uPAR expression may be a component of the ability of c-Myc to reduce motility and invasiveness.

Standard name | FU_INTERACT_WITH_ALKBH8
Systematic name | M2478
Organism | Homo sapiens
PMID | 20308323
Authors | Fu D,Brophy JA,Chan CT,Atmore KA,Begley U,Paules RS,Dedon PC,Begley TJ,Samson LD
Category | C2
Sub-category | CGP
Brief description | Proteins identified by mass spectrometry in complexes containing ALKBH8 [GeneID=91801].
Full description | tRNA nucleosides are extensively modified to ensure their proper function in translation. However, many of the enzymes responsible for tRNA modifications in mammals await identification. Here, we show that human AlkB homolog 8 (ABH8) catalyzes tRNA methylation to generate 5-methylcarboxymethyl uridine (mcm(5)U) at the wobble position of certain tRNAs, a critical anticodon loop modification linked to DNA damage survival. We find that ABH8 interacts specifically with tRNAs containing mcm(5)U and that purified ABH8 complexes methylate RNA in vitro. Significantly, ABH8 depletion in human cells reduces endogenous levels of mcm(5)U in RNA and increases cellular sensitivity to DNA-damaging agents. Moreover, DNA-damaging agents induce ABH8 expression in an ATM-dependent manner. These results expand the role of mammalian AlkB proteins beyond that of direct DNA repair and support a regulatory mechanism in the DNA damage response pathway involving modulation of tRNA modification.

Standard name | SUZUKI_CTCFL_TARGETS_UP
Systematic name | M2479
Organism | Mus musculus
PMID | 20231363
Authors | Suzuki T,Kosaka-Suzuki N,Pack S,Shin DM,Yoon J,Abdullaev Z,Pugacheva E,Morse HC 3rd,Loukinov D,Lobanenkov V
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in testis tissue upon knockout of CTCFL [GeneID=140690].
Full description | Previously, it was shown that the CTCF paralogous gene, BORIS (brother of the regulator of imprinted sites) is expressed in male germ cells, but its function in spermatogenesis has not been defined. To develop an understanding of the functional activities of BORIS, we generated BORIS knockout (KO) mice. Mice homozygous for the null allele had a defect in spermatogenesis that resulted in small testes associated with increased cell death. The defect was evident as early as postnatal day 21 and was manifested by delayed production of haploid cells. By gene expression profiling, we found that transcript levels for Gal3st1 (also known as cerebroside sulfotransferase [CST]), known to play a crucial role in meiosis, were dramatically reduced in BORIS KO testes. We found that CST is expressed in testis as a novel testis-specific isoform, CST form F(TS), that has a short exon 1f. We showed that BORIS bound to and activated the promoter of CST form F(TS). Mutation of the BORIS binding site in the promoter reduced the ability of BORIS to activate the promoter. These findings define transcriptional regulation of CST expression as a critical role for BORIS in spermatogenesis.

Standard name | REICHERT_MITOSIS_LIN9_TARGETS
Systematic name | M2483
Organism | Mus musculus
PMID | 20404087
Authors | Reichert N,Wurster S,Ulrich T,Schmitt K,Hauser S,Probst L,Götz R,Ceteci F,Moll R,Rapp U,Gaubatz S
Category | C2
Sub-category | CGP
Brief description | Genes with known mitosis function that were down-regulated in MEF cells (embryonic fibroblast) upon knockout of LIN9 [GeneID=286826].
Full description | The retinoblastoma tumor suppressor protein (pRB) and related p107 and p130 pocket proteins function together with the E2F transcription factors to repress gene expression during the cell cycle and development. Recent biochemical studies have identified the multisubunit DREAM pocket protein complexes in Drosophila melanogaster and Caenorhabditis elegans in regulating developmental gene repression. Although a conserved DREAM complex has also been identified in mammalian cells, its physiological function in vivo has not been determined. Here we addressed this question by targeting Lin9, a conserved core subunit of DREAM. We found that LIN9 is essential for early embryonic development and for viability of adult mice. Loss of Lin9 abolishes proliferation and leads to multiple defects in mitosis and cytokinesis because of its requirement for the expression of a large set of mitotic genes, such as Plk1, Aurora A, and Kif20a. While Lin9 heterozygous mice are healthy and normal, they are more susceptible to lung tumorigenesis induced by oncogenic c-Raf than wild-type mice. Together these experiments provide the first direct genetic evidence for the role of LIN9 in development and mitotic gene regulation and they suggest that it may function as a haploinsufficient tumor suppressor.

Standard name | GUILLAUMOND_KLF10_TARGETS_UP
Systematic name | M2485
Organism | Mus musculus
PMID | 20385766
Authors | Guillaumond F,Gréchez-Cassiau A,Subramaniam M,Brangolo S,Peteri-Brünback B,Staels B,Fiévet C,Spelsberg TC,Delaunay F,Teboul M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the liver tissue from 10 week old male mice with KLF10 [GeneID=7071] compared to wild-type littermates.
Full description | The circadian timing system coordinates many aspects of mammalian physiology and behavior in synchrony with the external light/dark cycle. These rhythms are driven by endogenous molecular clocks present in most body cells. Many clock outputs are transcriptional regulators, suggesting that clock genes primarily control physiology through indirect pathways. Here, we show that Krüppel-like factor 10 (KLF10) displays a robust circadian expression pattern in wild-type mouse liver but not in clock-deficient Bmal1 knockout mice. Consistently, the Klf10 promoter recruited the BMAL1 core clock protein and was transactivated by the CLOCK-BMAL1 heterodimer through a conserved E-box response element. Profiling the liver transcriptome from Klf10(-/-) mice identified 158 regulated genes with significant enrichment for transcripts involved in lipid and carbohydrate metabolism. Importantly, approximately 56% of these metabolic genes are clock controlled. Male Klf10(-/-) mice displayed postprandial and fasting hyperglycemia, a phenotype accompanied by a significant time-of-day-dependent upregulation of the gluconeogenic gene Pepck and increased hepatic glucose production. Consistently, functional data showed that the proximal Pepck promoter is repressed directly by KLF10. Klf10(-/-) females were normoglycemic but displayed higher plasma triglycerides. Correspondingly, rhythmic gene expression of components of the lipogenic pathway, including Srebp1c, Fas, and Elovl6, was altered in females. Collectively, these data establish KLF10 as a required circadian transcriptional regulator that links the molecular clock to energy metabolism in the liver.

Standard name | GUILLAUMOND_KLF10_TARGETS_DN
Systematic name | M2486
Organism | Mus musculus
PMID | 20385766
Authors | Guillaumond F,Gréchez-Cassiau A,Subramaniam M,Brangolo S,Peteri-Brünback B,Staels B,Fiévet C,Spelsberg TC,Delaunay F,Teboul M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in the liver tissue from 10 week old male mice with KLF10 [GeneID=7071] compared to wild-type littermates.
Full description | The circadian timing system coordinates many aspects of mammalian physiology and behavior in synchrony with the external light/dark cycle. These rhythms are driven by endogenous molecular clocks present in most body cells. Many clock outputs are transcriptional regulators, suggesting that clock genes primarily control physiology through indirect pathways. Here, we show that Krüppel-like factor 10 (KLF10) displays a robust circadian expression pattern in wild-type mouse liver but not in clock-deficient Bmal1 knockout mice. Consistently, the Klf10 promoter recruited the BMAL1 core clock protein and was transactivated by the CLOCK-BMAL1 heterodimer through a conserved E-box response element. Profiling the liver transcriptome from Klf10(-/-) mice identified 158 regulated genes with significant enrichment for transcripts involved in lipid and carbohydrate metabolism. Importantly, approximately 56% of these metabolic genes are clock controlled. Male Klf10(-/-) mice displayed postprandial and fasting hyperglycemia, a phenotype accompanied by a significant time-of-day-dependent upregulation of the gluconeogenic gene Pepck and increased hepatic glucose production. Consistently, functional data showed that the proximal Pepck promoter is repressed directly by KLF10. Klf10(-/-) females were normoglycemic but displayed higher plasma triglycerides. Correspondingly, rhythmic gene expression of components of the lipogenic pathway, including Srebp1c, Fas, and Elovl6, was altered in females. Collectively, these data establish KLF10 as a required circadian transcriptional regulator that links the molecular clock to energy metabolism in the liver.

Standard name | FORTSCHEGGER_PHF8_TARGETS_UP
Systematic name | M2487
Organism | Homo sapiens
PMID | 20421419
Authors | Fortschegger K,de Graaf P,Outchkourov NS,van Schaik FM,Timmers HT,Shiekhattar R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in HeLa cells (cervical carcinoma) upon knockdown of PHF8 [GeneID=23133] by RNAi.
Full description | Mutations in PHF8 are associated with X-linked mental retardation and cleft lip/cleft palate. PHF8 contains a plant homeodomain (PHD) in its N terminus and is a member of a family of JmjC domain-containing proteins. While PHDs can act as methyl lysine recognition motifs, JmjC domains can catalyze lysine demethylation. Here, we show that PHF8 is a histone demethylase that removes repressive histone H3 dimethyl lysine 9 marks. Our biochemical analysis revealed specific association of the PHF8 PHD with histone H3 trimethylated at lysine 4 (H3K4me3). Chromatin immunoprecipitation followed by high-throughput sequencing indicated that PHF8 is enriched at the transcription start sites of many active or poised genes, mirroring the presence of RNA polymerase II (RNAPII) and of H3K4me3-bearing nucleosomes. We show that PHF8 can act as a transcriptional coactivator and that its activation function largely depends on binding of the PHD to H3K4me3. Furthermore, we present evidence for direct interaction of PHF8 with the C-terminal domain of RNAPII. Importantly, a PHF8 disease mutant was defective in demethylation and in coactivation. This is the first demonstration of a chromatin-modifying enzyme that is globally recruited to promoters through its association with H3K4me3 and RNAPII.

Standard name | FORTSCHEGGER_PHF8_TARGETS_DN
Systematic name | M2488
Organism | Homo sapiens
PMID | 20421419
Authors | Fortschegger K,de Graaf P,Outchkourov NS,van Schaik FM,Timmers HT,Shiekhattar R
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in HeLa cells (cervical carcinoma) upon knockdown of PHF8 [GeneID=23133] by RNAi.
Full description | Mutations in PHF8 are associated with X-linked mental retardation and cleft lip/cleft palate. PHF8 contains a plant homeodomain (PHD) in its N terminus and is a member of a family of JmjC domain-containing proteins. While PHDs can act as methyl lysine recognition motifs, JmjC domains can catalyze lysine demethylation. Here, we show that PHF8 is a histone demethylase that removes repressive histone H3 dimethyl lysine 9 marks. Our biochemical analysis revealed specific association of the PHF8 PHD with histone H3 trimethylated at lysine 4 (H3K4me3). Chromatin immunoprecipitation followed by high-throughput sequencing indicated that PHF8 is enriched at the transcription start sites of many active or poised genes, mirroring the presence of RNA polymerase II (RNAPII) and of H3K4me3-bearing nucleosomes. We show that PHF8 can act as a transcriptional coactivator and that its activation function largely depends on binding of the PHD to H3K4me3. Furthermore, we present evidence for direct interaction of PHF8 with the C-terminal domain of RNAPII. Importantly, a PHF8 disease mutant was defective in demethylation and in coactivation. This is the first demonstration of a chromatin-modifying enzyme that is globally recruited to promoters through its association with H3K4me3 and RNAPII.

Standard name | BRIDEAU_IMPRINTED_GENES
Systematic name | M2491
Organism | Mus musculus
PMID | 20421412
Authors | Brideau CM,Eilertson KE,Hagarman JA,Bustamante CD,Soloway PD
Category | C2
Sub-category | CGP
Brief description | List of genomically imprinted genes.
Full description | Approximately 100 mouse genes undergo genomic imprinting, whereby one of the two parental alleles is epigenetically silenced. Imprinted genes influence processes including development, X chromosome inactivation, obesity, schizophrenia, and diabetes, motivating the identification of all imprinted loci. Local sequence features have been used to predict candidate imprinted genes, but rigorous testing using reciprocal crosses validated only three, one of which resided in previously identified imprinting clusters. Here we show that specific epigenetic features in mouse cells correlate with imprinting status in mice, and we identify hundreds of additional genes predicted to be imprinted in the mouse. We used a multitiered approach to validate imprinted expression, including use of a custom single nucleotide polymorphism array and traditional molecular methods. Of 65 candidates subjected to molecular assays for allele-specific expression, we found 10 novel imprinted genes that were maternally expressed in the placenta.

Standard name | PEDRIOLI_MIR31_TARGETS_UP
Systematic name | M2493
Organism | Homo sapiens
PMID | 20479124
Authors | Pedrioli DM,Karpanen T,Dabouras V,Jurisic G,Hoek de van G,Shin JW,Marino D,Kälin RE,Leidel S,Cinelli P,Schulte-Merker S,Brändli AW,Detmar M
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in primary LEC cells (lymphatic endothelum) upon overexpression of MIR31 [GeneID=407035].
Full description | The lymphatic vascular system maintains tissue fluid homeostasis, helps mediate afferent immune responses, and promotes cancer metastasis. To address the role microRNAs (miRNAs) play in the development and function of the lymphatic vascular system, we defined the in vitro miRNA expression profiles of primary human lymphatic endothelial cells (LECs) and blood vascular endothelial cells (BVECs) and identified four BVEC signature and two LEC signature miRNAs. Their vascular lineage-specific expression patterns were confirmed in vivo by quantitative real-time PCR and in situ hybridization. Functional characterization of the BVEC signature miRNA miR-31 identified a novel BVEC-specific posttranscriptional regulatory mechanism that inhibits the expression of lymphatic lineage-specific transcripts in vitro. We demonstrate that suppression of lymphatic differentiation is partially mediated via direct repression of PROX1, a transcription factor that functions as a master regulator of lymphatic lineage-specific differentiation. Finally, in vivo studies of Xenopus and zebrafish demonstrated that gain of miR-31 function impaired venous sprouting and lymphatic vascular development, thus highlighting the importance of miR-31 as a negative regulator of lymphatic development. Collectively, our findings identify miR-31 is a potent regulator of vascular lineage-specific differentiation and development in vertebrates.

Standard name | PEDRIOLI_MIR31_TARGETS_DN
Systematic name | M2494
Organism | Homo sapiens
PMID | 20479124
Authors | Pedrioli DM,Karpanen T,Dabouras V,Jurisic G,Hoek de van G,Shin JW,Marino D,Kälin RE,Leidel S,Cinelli P,Schulte-Merker S,Brändli AW,Detmar M
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in primary LEC cells (lymphatic endothelum) upon overexpression of MIR31 [GeneID=407035].
Full description | The lymphatic vascular system maintains tissue fluid homeostasis, helps mediate afferent immune responses, and promotes cancer metastasis. To address the role microRNAs (miRNAs) play in the development and function of the lymphatic vascular system, we defined the in vitro miRNA expression profiles of primary human lymphatic endothelial cells (LECs) and blood vascular endothelial cells (BVECs) and identified four BVEC signature and two LEC signature miRNAs. Their vascular lineage-specific expression patterns were confirmed in vivo by quantitative real-time PCR and in situ hybridization. Functional characterization of the BVEC signature miRNA miR-31 identified a novel BVEC-specific posttranscriptional regulatory mechanism that inhibits the expression of lymphatic lineage-specific transcripts in vitro. We demonstrate that suppression of lymphatic differentiation is partially mediated via direct repression of PROX1, a transcription factor that functions as a master regulator of lymphatic lineage-specific differentiation. Finally, in vivo studies of Xenopus and zebrafish demonstrated that gain of miR-31 function impaired venous sprouting and lymphatic vascular development, thus highlighting the importance of miR-31 as a negative regulator of lymphatic development. Collectively, our findings identify miR-31 is a potent regulator of vascular lineage-specific differentiation and development in vertebrates.

Standard name | PHONG_TNF_TARGETS_UP
Systematic name | M2496
Organism | Homo sapiens
PMID | 20516219
Authors | Phong MS,Van Horn RD,Li S,Tucker-Kellogg G,Surana U,Ye XS
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in Calu-6 cells (lung cancer) at 1 h time point after TNF [GeneID=7124] treatment.
Full description | p38 mitogen-activated protein kinase (MAPK) is rapidly activated by stresses and is believed to play an important role in the stress response. While Chk1 is known to mediate G(2) DNA damage checkpoint control, p38 was also reported to have an essential function in this checkpoint control. Here, we have investigated further the roles of p38 and Chk1 in the G(2) DNA damage checkpoint in cancer cells. We find that although p38 activation is strongly induced by DNA damage, its activity is not required for the G(2) DNA damage checkpoint. In contrast, Chk1 kinase is responsible for the execution of G(2) DNA damage checkpoint control in p53-deficient cells. The inhibition of p38 activity has no effect on Chk1 activation and gamma-H2AX expression. Global gene expression profiling of cancer cells in response to tumor necrosis factor alpha (TNF-alpha) revealed that p38 plays a strong prosurvival role through the coordinated downregulation of proapoptotic genes and upregulation of prosurvival genes. We show that the inhibition of p38 activity during G(2) DNA damage checkpoint arrest triggers apoptosis in a p53-independent manner with a concurrent decrease in the level of Bcl2 family proteins. Our results suggest that although p38 MAPK is not required for the G(2) DNA damage checkpoint function, it plays an important prosurvival role during the G(2) DNA damage checkpoint response through the upregulation of the Bcl2 family proteins.

Standard name | PHONG_TNF_TARGETS_DN
Systematic name | M2498
Organism | Homo sapiens
PMID | 20516219
Authors | Phong MS,Van Horn RD,Li S,Tucker-Kellogg G,Surana U,Ye XS
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in Calu-6 cells (lung cancer) at 1 h time point after TNF [GeneID=7124] treatment.
Full description | p38 mitogen-activated protein kinase (MAPK) is rapidly activated by stresses and is believed to play an important role in the stress response. While Chk1 is known to mediate G(2) DNA damage checkpoint control, p38 was also reported to have an essential function in this checkpoint control. Here, we have investigated further the roles of p38 and Chk1 in the G(2) DNA damage checkpoint in cancer cells. We find that although p38 activation is strongly induced by DNA damage, its activity is not required for the G(2) DNA damage checkpoint. In contrast, Chk1 kinase is responsible for the execution of G(2) DNA damage checkpoint control in p53-deficient cells. The inhibition of p38 activity has no effect on Chk1 activation and gamma-H2AX expression. Global gene expression profiling of cancer cells in response to tumor necrosis factor alpha (TNF-alpha) revealed that p38 plays a strong prosurvival role through the coordinated downregulation of proapoptotic genes and upregulation of prosurvival genes. We show that the inhibition of p38 activity during G(2) DNA damage checkpoint arrest triggers apoptosis in a p53-independent manner with a concurrent decrease in the level of Bcl2 family proteins. Our results suggest that although p38 MAPK is not required for the G(2) DNA damage checkpoint function, it plays an important prosurvival role during the G(2) DNA damage checkpoint response through the upregulation of the Bcl2 family proteins.

Standard name | PHONG_TNF_RESPONSE_VIA_P38_COMPLETE
Systematic name | M2500
Organism | Homo sapiens
PMID | 20516219
Authors | Phong MS,Van Horn RD,Li S,Tucker-Kellogg G,Surana U,Ye XS
Category | C2
Sub-category | CGP
Brief description | Genes whose expression changes in Calu-6 cells (lung cancer) by TNF [GeneID=7124] were blocked completely by p38 inhibitor LY479754.
Full description | p38 mitogen-activated protein kinase (MAPK) is rapidly activated by stresses and is believed to play an important role in the stress response. While Chk1 is known to mediate G(2) DNA damage checkpoint control, p38 was also reported to have an essential function in this checkpoint control. Here, we have investigated further the roles of p38 and Chk1 in the G(2) DNA damage checkpoint in cancer cells. We find that although p38 activation is strongly induced by DNA damage, its activity is not required for the G(2) DNA damage checkpoint. In contrast, Chk1 kinase is responsible for the execution of G(2) DNA damage checkpoint control in p53-deficient cells. The inhibition of p38 activity has no effect on Chk1 activation and gamma-H2AX expression. Global gene expression profiling of cancer cells in response to tumor necrosis factor alpha (TNF-alpha) revealed that p38 plays a strong prosurvival role through the coordinated downregulation of proapoptotic genes and upregulation of prosurvival genes. We show that the inhibition of p38 activity during G(2) DNA damage checkpoint arrest triggers apoptosis in a p53-independent manner with a concurrent decrease in the level of Bcl2 family proteins. Our results suggest that although p38 MAPK is not required for the G(2) DNA damage checkpoint function, it plays an important prosurvival role during the G(2) DNA damage checkpoint response through the upregulation of the Bcl2 family proteins.

Standard name | PHONG_TNF_RESPONSE_VIA_P38_PARTIAL
Systematic name | M2502
Organism | Homo sapiens
PMID | 20516219
Authors | Phong MS,Van Horn RD,Li S,Tucker-Kellogg G,Surana U,Ye XS
Category | C2
Sub-category | CGP
Brief description | Genes whose expression changes in Calu-6 cells (lung cancer) by TNF [GeneID=7124] were blocked partially by p38 inhibitor LY479754.
Full description | p38 mitogen-activated protein kinase (MAPK) is rapidly activated by stresses and is believed to play an important role in the stress response. While Chk1 is known to mediate G(2) DNA damage checkpoint control, p38 was also reported to have an essential function in this checkpoint control. Here, we have investigated further the roles of p38 and Chk1 in the G(2) DNA damage checkpoint in cancer cells. We find that although p38 activation is strongly induced by DNA damage, its activity is not required for the G(2) DNA damage checkpoint. In contrast, Chk1 kinase is responsible for the execution of G(2) DNA damage checkpoint control in p53-deficient cells. The inhibition of p38 activity has no effect on Chk1 activation and gamma-H2AX expression. Global gene expression profiling of cancer cells in response to tumor necrosis factor alpha (TNF-alpha) revealed that p38 plays a strong prosurvival role through the coordinated downregulation of proapoptotic genes and upregulation of prosurvival genes. We show that the inhibition of p38 activity during G(2) DNA damage checkpoint arrest triggers apoptosis in a p53-independent manner with a concurrent decrease in the level of Bcl2 family proteins. Our results suggest that although p38 MAPK is not required for the G(2) DNA damage checkpoint function, it plays an important prosurvival role during the G(2) DNA damage checkpoint response through the upregulation of the Bcl2 family proteins.

Standard name | PHONG_TNF_RESPONSE_NOT_VIA_P38
Systematic name | M2504
Organism | Homo sapiens
PMID | 20516219
Authors | Phong MS,Van Horn RD,Li S,Tucker-Kellogg G,Surana U,Ye XS
Category | C2
Sub-category | CGP
Brief description | Genes whose expression changes in Calu-6 cells (lung cancer) by TNF [GeneID=7124] were not affected by p38 inhibitor LY479754.
Full description | p38 mitogen-activated protein kinase (MAPK) is rapidly activated by stresses and is believed to play an important role in the stress response. While Chk1 is known to mediate G(2) DNA damage checkpoint control, p38 was also reported to have an essential function in this checkpoint control. Here, we have investigated further the roles of p38 and Chk1 in the G(2) DNA damage checkpoint in cancer cells. We find that although p38 activation is strongly induced by DNA damage, its activity is not required for the G(2) DNA damage checkpoint. In contrast, Chk1 kinase is responsible for the execution of G(2) DNA damage checkpoint control in p53-deficient cells. The inhibition of p38 activity has no effect on Chk1 activation and gamma-H2AX expression. Global gene expression profiling of cancer cells in response to tumor necrosis factor alpha (TNF-alpha) revealed that p38 plays a strong prosurvival role through the coordinated downregulation of proapoptotic genes and upregulation of prosurvival genes. We show that the inhibition of p38 activity during G(2) DNA damage checkpoint arrest triggers apoptosis in a p53-independent manner with a concurrent decrease in the level of Bcl2 family proteins. Our results suggest that although p38 MAPK is not required for the G(2) DNA damage checkpoint function, it plays an important prosurvival role during the G(2) DNA damage checkpoint response through the upregulation of the Bcl2 family proteins.

Standard name | RATTENBACHER_BOUND_BY_CELF1
Systematic name | M2505
Organism | Homo sapiens
PMID | 20547756
Authors | Rattenbacher B,Beisang D,Wiesner DL,Jeschke JC,von Hohenberg M,St Louis-Vlasova IA,Bohjanen PR
Category | C2
Sub-category | CGP
Brief description | Transcripts bound by CELF1 [GeneID=10658] in HeLa cells (cervical carcinoma).
Full description | CUG-repeat binding protein 1 (CUGBP1) mediates selective mRNA decay by binding to GU-rich elements (GREs) containing the sequence UGUUUGUUUGU found in the 3' untranslated region (UTR) of short-lived transcripts. We used an anti-CUGBP1 antibody to immunoprecipitate CUGBP1 from HeLa cytoplasmic extracts and analyzed the associated transcripts using oligonucleotide microarrays. We identified 613 putative mRNA targets of CUGBP1 and found that the UGUUUGUUUGU GRE sequence and a GU-repeat sequence were both highly enriched in the 3' UTRs of these targets. We showed that CUGBP1 bound specifically to the GU-repeat sequence and that insertion of this sequence into the 3' UTR of a beta-globin reporter transcript conferred instability to the transcript. Based on these results, we redefined the GRE to include this GU-repeat sequence. Our results suggest that CUGBP1 coordinately regulates the mRNA decay of a network of transcripts involved in cell growth, cell motility, and apoptosis.

Standard name | KINNEY_DNMT1_METHYLATION_TARGETS
Systematic name | M2508
Organism | Mus musculus
PMID | 20584988
Authors | Kinney SR,Moser MT,Pascual M,Greally JM,Foster BA,Karpf AR
Category | C2
Sub-category | CGP
Brief description | Hypomethylated genes in prostate tissue from mice carrying hypomorphic alleles of DNMT1 [GeneID=1786].
Full description | Previous studies have shown that tumor progression in the transgenic adenocarcinoma of mouse prostate (TRAMP) model is characterized by global DNA hypomethylation initiated during early-stage disease and locus-specific DNA hypermethylation occurring predominantly in late-stage disease. Here, we utilized Dnmt1 hypomorphic alleles to examine the role of Dnmt1 in normal prostate development and in prostate cancer in TRAMP. Prostate tissue morphology and differentiation status was normal in Dnmt1 hypomorphic mice, despite global DNA hypomethylation. TRAMP; Dnmt1 hypomorphic mice also displayed global DNA hypomethylation, but were characterized by altered tumor phenotype. Specifically, TRAMP; Dnmt1 hypomorphic mice exhibited slightly increased tumor incidence and significantly increased pathological progression at early ages and, conversely, displayed slightly decreased tumor incidence and significantly decreased pathological progression at advanced ages. Remarkably, hypomorphic Dnmt1 expression abrogated local and distant site macrometastases. Thus, Dnmt1 has tumor suppressor activity in early-stage prostate cancer, and oncogenic activity in late stage prostate cancer and metastasis. Consistent with the biological phenotype, epigenomic studies revealed that TRAMP; Dnmt1 hypomorphic mice show dramatically reduced CpG island and promoter DNA hypermethylation in late-stage primary tumors compared to control mice. Taken together, the data reveal a crucial role for Dnmt1 in prostate cancer and suggest that Dnmt1-targeted interventions may have utility specifically for advanced and/or metastatic prostate cancer.

Standard name | ABDELMOHSEN_ELAVL4_TARGETS
Systematic name | M2509
Organism | Homo sapiens
PMID | 20584986
Authors | Abdelmohsen K,Hutchison ER,Lee EK,Kuwano Y,Kim MM,Masuda K,Srikantan S,Subaran SS,Marasa BS,Mattson MP,Gorospe M
Category | C2
Sub-category | CGP
Brief description | Major ELAVL4 [GeneID=1996] associated mRNAs encoding proteins with functions in neuronal physiology.
Full description | Neuronal development and plasticity are maintained by tightly regulated gene expression programs. Here, we report that the developmentally regulated microRNA miR-375 affects dendrite formation and maintenance. miR-375 overexpression in mouse hippocampus potently reduced dendrite density. We identified the predominantly neuronal RNA-binding protein HuD as a key effector of miR-375 influence on dendrite maintenance. Heterologous reporter analysis verified that miR-375 repressed HuD expression through a specific, evolutionarily conserved site on the HuD 3' untranslated region. miR-375 overexpression lowered both HuD mRNA stability and translation and recapitulated the effects of HuD silencing, which reduced the levels of target proteins with key functions in neuronal signaling and cytoskeleton organization (N-cadherin, PSD-95, RhoA, NCAM1, and integrin alpha1). Moreover, the increase in neurite outgrowth after brain-derived neurotrophic factor (BDNF) treatment was diminished by miR-375 overexpression; this effect was rescued by reexpression of miR-375-refractory HuD. Our findings indicate that miR-375 modulates neuronal HuD expression and function, in turn affecting dendrite abundance.

Standard name | ZHANG_ADIPOGENESIS_BY_BMP7
Systematic name | M2511
Organism | Mus musculus
PMID | 20584981
Authors | Zhang H,Schulz TJ,Espinoza DO,Huang TL,Emanuelli B,Kristiansen K,Tseng YH
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in C3H10T1/2 cells (mesenchyme multipotent cells) upon their differentiation to brown adipocytes in response to BMP7 [GeneID=655].
Full description | Both insulin and bone morphogenetic protein (BMP) signaling systems are important for adipocyte differentiation. Analysis of gene expression in BMP7-treated fibroblasts revealed a coordinated change in insulin signaling components by BMP7. To further investigate the cross talk between insulin and BMP signaling systems in brown adipogenesis, we examined the effect of BMP7 in insulin receptor substrate 1 (IRS-1)-deficient brown preadipocytes, which exhibit a severe defect in differentiation. Treatment of these cells with BMP7 for 3 days prior to adipogenic induction restored differentiation and expression of brown adipogenic markers. The high level of adipogenic inhibitor preadipocyte factor 1 (Pref-1) in IRS-1-null cells was markedly reduced by 3 days of BMP7 treatment, and analysis of the 1.3-kb pref-1 promoter revealed 9 putative Smad binding elements (SBEs), suggesting that BMP7 could directly suppress Pref-1 expression, thereby allowing the initiation of the adipogenic program. Using a series of sequential deletion mutants of the pref-1 promoter linked to the luciferase gene and chromatin immunoprecipitation, we demonstrate that the promoter-proximal SBE (-192/-184) was critical in mediating BMP7's suppressive effect on pref-1 transcription. Together, these data suggest cross talk between the insulin and BMP signaling systems by which BMP7 can rescue brown adipogenesis in cells with insulin resistance.

Standard name | FOSTER_KDM1A_TARGETS_UP
Systematic name | M2512
Organism | Mus musculus
PMID | 20713442
Authors | Foster CT,Dovey OM,Lezina L,Luo JL,Gant TW,Barlev N,Bradley A,Cowley SM
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in ES cells (embryonic stem) heterozygotic for KDM1A [GeneID=23028] loss of function mutant compared to the homozygotic loss of the gene.
Full description | Lysine-specific demethylase 1 (LSD1), which demethylates mono- and dimethylated histone H3-Lys4 as part of a complex including CoREST and histone deacetylases (HDACs), is essential for embryonic development in the mouse beyond embryonic day 6.5 (e6.5). To determine the role of LSD1 during this early period of embryogenesis, we have generated loss-of-function gene trap mice and conditional knockout embryonic stem (ES) cells. Analysis of postimplantation gene trap embryos revealed that LSD1 expression, and therefore function, is restricted to the epiblast. Conditional deletion of LSD1 in mouse ES cells, the in vitro counterpart of the epiblast, revealed a reduction in CoREST protein and associated HDAC activity, resulting in a global increase in histone H3-Lys56 acetylation, but not H3-Lys4 methylation. Despite this biochemical perturbation, ES cells with LSD1 deleted proliferate normally and retain stem cell characteristics. Loss of LSD1 causes the aberrant expression of 588 genes, including those coding for transcription factors with roles in anterior/posterior patterning and limb development, such as brachyury, Hoxb7, Hoxd8, and retinoic acid receptor γ (RARγ). The gene coding for brachyury, a key regulator of mesodermal differentiation, is a direct target gene of LSD1 and is overexpressed in e6.5 Lsd1 gene trap embryos. Thus, LSD1 regulates the expression and appropriate timing of key developmental regulators, as part of the LSD1/CoREST/HDAC complex, during early embryonic development.

Standard name | FOSTER_KDM1A_TARGETS_DN
Systematic name | M2514
Organism | Mus musculus
PMID | 20713442
Authors | Foster CT,Dovey OM,Lezina L,Luo JL,Gant TW,Barlev N,Bradley A,Cowley SM
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in ES cells (embryonic stem) heterozygotic for KDM1A [GeneID=23028] loss of function mutant compared to the homozygotic loss of the gene.
Full description | Lysine-specific demethylase 1 (LSD1), which demethylates mono- and dimethylated histone H3-Lys4 as part of a complex including CoREST and histone deacetylases (HDACs), is essential for embryonic development in the mouse beyond embryonic day 6.5 (e6.5). To determine the role of LSD1 during this early period of embryogenesis, we have generated loss-of-function gene trap mice and conditional knockout embryonic stem (ES) cells. Analysis of postimplantation gene trap embryos revealed that LSD1 expression, and therefore function, is restricted to the epiblast. Conditional deletion of LSD1 in mouse ES cells, the in vitro counterpart of the epiblast, revealed a reduction in CoREST protein and associated HDAC activity, resulting in a global increase in histone H3-Lys56 acetylation, but not H3-Lys4 methylation. Despite this biochemical perturbation, ES cells with LSD1 deleted proliferate normally and retain stem cell characteristics. Loss of LSD1 causes the aberrant expression of 588 genes, including those coding for transcription factors with roles in anterior/posterior patterning and limb development, such as brachyury, Hoxb7, Hoxd8, and retinoic acid receptor γ (RARγ). The gene coding for brachyury, a key regulator of mesodermal differentiation, is a direct target gene of LSD1 and is overexpressed in e6.5 Lsd1 gene trap embryos. Thus, LSD1 regulates the expression and appropriate timing of key developmental regulators, as part of the LSD1/CoREST/HDAC complex, during early embryonic development.

Standard name | YU_BAP1_TARGETS
Systematic name | M2515
Organism | Homo sapiens
PMID | 20805357
Authors | Yu H,Mashtalir N,Daou S,Hammond-Martel I,Ross J,Sui G,Hart GW,Rauscher FJ 3rd,Drobetsky E,Milot E,Shi Y,Affar el B
Category | C2
Sub-category | CGP
Brief description | Genes deregulated in U2OS cells (osteosarcoma) upon knockdown of BAP1 [GeneID=8314] by RNAi.
Full description | The candidate tumor suppressor BAP1 is a deubiquitinating enzyme (DUB) involved in the regulation of cell proliferation, although the molecular mechanisms governing its function remain poorly defined. BAP1 was recently shown to interact with and deubiquitinate the transcriptional regulator host cell factor 1 (HCF-1). Here we show that BAP1 assembles multiprotein complexes containing numerous transcription factors and cofactors, including HCF-1 and the transcription factor Yin Yang 1 (YY1). Through its coiled-coil motif, BAP1 directly interacts with the zinc fingers of YY1. Moreover, HCF-1 interacts with the middle region of YY1 encompassing the glycine-lysine-rich domain and is essential for the formation of a ternary complex with YY1 and BAP1 in vivo. BAP1 activates transcription in an enzymatic-activity-dependent manner and regulates the expression of a variety of genes involved in numerous cellular processes. We further show that BAP1 and HCF-1 are recruited by YY1 to the promoter of the cox7c gene, which encodes a mitochondrial protein used here as a model of BAP1-activated gene expression. Our findings (i) establish a direct link between BAP1 and the transcriptional control of genes regulating cell growth and proliferation and (ii) shed light on a novel mechanism of transcription regulation involving ubiquitin signaling.

Standard name | RAO_BOUND_BY_SALL4_ISOFORM_A
Systematic name | M2517
Organism | Mus musculus
PMID | 20837710
Authors | Rao S,Zhen S,Roumiantsev S,McDonald LT,Yuan GC,Orkin SH
Category | C2
Sub-category | CGP
Brief description | Loci bound exclusively by SALL4 [GeneID=57167] isoform a in ES cells (embryonic stem).
Full description | Murine embryonic stem (ES) cells are defined by continuous self-renewal and pluripotency. A diverse repertoire of protein isoforms arising from alternative splicing is expressed in ES cells without defined biological roles. Sall4, a transcription factor essential for pluripotency, exists as two isoforms (Sall4a and Sall4b). Both isoforms can form homodimers and a heterodimer with each other, and each can interact with Nanog. By genomewide location analysis, we determined that Sall4a and Sall4b have overlapping, but not identical binding sites within the ES cell genome. In addition, Sall4b, but not Sall4a, binds preferentially to highly expressed loci in ES cells. Sall4a and Sall4b binding sites are distinguished by both epigenetic marks at target loci and their clustering with binding sites of other pluripotency factors. When ES cells expressing a single isoform of Sall4 are generated, Sall4b alone could maintain the pluripotent state, although it could not completely suppress all differentiation markers. Sall4a and Sall4b collaborate in maintenance of the pluripotent state but play distinct roles. Our work is novel in establishing such isoform-specific differences in ES cells.

Standard name | RAO_BOUND_BY_SALL4_ISOFORM_B
Systematic name | M2520
Organism | Mus musculus
PMID | 20837710
Authors | Rao S,Zhen S,Roumiantsev S,McDonald LT,Yuan GC,Orkin SH
Category | C2
Sub-category | CGP
Brief description | Loci bound exclusively by SALL4 [GeneID=57167] isoform b in ES cells (embryonic stem).
Full description | Murine embryonic stem (ES) cells are defined by continuous self-renewal and pluripotency. A diverse repertoire of protein isoforms arising from alternative splicing is expressed in ES cells without defined biological roles. Sall4, a transcription factor essential for pluripotency, exists as two isoforms (Sall4a and Sall4b). Both isoforms can form homodimers and a heterodimer with each other, and each can interact with Nanog. By genomewide location analysis, we determined that Sall4a and Sall4b have overlapping, but not identical binding sites within the ES cell genome. In addition, Sall4b, but not Sall4a, binds preferentially to highly expressed loci in ES cells. Sall4a and Sall4b binding sites are distinguished by both epigenetic marks at target loci and their clustering with binding sites of other pluripotency factors. When ES cells expressing a single isoform of Sall4 are generated, Sall4b alone could maintain the pluripotent state, although it could not completely suppress all differentiation markers. Sall4a and Sall4b collaborate in maintenance of the pluripotent state but play distinct roles. Our work is novel in establishing such isoform-specific differences in ES cells.

Standard name | RAO_BOUND_BY_SALL4
Systematic name | M2521
Organism | Mus musculus
PMID | 20837710
Authors | Rao S,Zhen S,Roumiantsev S,McDonald LT,Yuan GC,Orkin SH
Category | C2
Sub-category | CGP
Brief description | Loci bound by both isoforms (a and b) of SALL4 [GeneID=57167] in ES cells (embryonic stem).
Full description | Murine embryonic stem (ES) cells are defined by continuous self-renewal and pluripotency. A diverse repertoire of protein isoforms arising from alternative splicing is expressed in ES cells without defined biological roles. Sall4, a transcription factor essential for pluripotency, exists as two isoforms (Sall4a and Sall4b). Both isoforms can form homodimers and a heterodimer with each other, and each can interact with Nanog. By genomewide location analysis, we determined that Sall4a and Sall4b have overlapping, but not identical binding sites within the ES cell genome. In addition, Sall4b, but not Sall4a, binds preferentially to highly expressed loci in ES cells. Sall4a and Sall4b binding sites are distinguished by both epigenetic marks at target loci and their clustering with binding sites of other pluripotency factors. When ES cells expressing a single isoform of Sall4 are generated, Sall4b alone could maintain the pluripotent state, although it could not completely suppress all differentiation markers. Sall4a and Sall4b collaborate in maintenance of the pluripotent state but play distinct roles. Our work is novel in establishing such isoform-specific differences in ES cells.

Standard name | VANOEVELEN_MYOGENESIS_SIN3A_TARGETS
Systematic name | M2524
Organism | Mus musculus
PMID | 20956564
Authors | van Oevelen C,Bowman C,Pellegrino J,Asp P,Cheng J,Parisi F,Micsinai M,Kluger Y,Chu A,Blais A,David G,Dynlacht BD
Category | C2
Sub-category | CGP
Brief description | Loci bound exclusively by SIN3A [GeneID=25942] in myotubules.
Full description | The highly related mammalian Sin3A and Sin3B proteins provide a versatile platform for chromatin-modifying activities. Sin3-containing complexes play a role in gene repression through deacetylation of nucleosomes. Here, we explore a role for Sin3 in myogenesis by examining the phenotypes resulting from acute somatic deletion of both isoforms in vivo and from primary myotubes in vitro. Myotubes ablated for Sin3A alone, but not Sin3B, displayed gross defects in sarcomere structure that were considerably enhanced upon simultaneous ablation of both isoforms. Massively parallel sequencing of Sin3A- and Sin3B-bound genomic loci revealed a subset of target genes directly involved in sarcomere function that are positively regulated by Sin3A and Sin3B proteins. Both proteins were coordinately recruited to a substantial number of genes. Interestingly, depletion of Sin3B led to compensatory increases in Sin3A recruitment at certain target loci, but Sin3B was never found to compensate for Sin3A loss. Thus, our analyses describe a novel transcriptional role for Sin3A and Sin3B proteins associated with maintenance of differentiated muscle cells.

Standard name | BOUDOUKHA_BOUND_BY_IGF2BP2
Systematic name | M2525
Organism | Mus musculus
PMID | 20956565
Authors | Boudoukha S,Cuvellier S,Polesskaya A
Category | C2
Sub-category | CGP
Brief description | Transcripts bound to IGF2BP2 [GeneID=10644] complexes and differentially regulated in myoblasts with IGF2BP2 [GeneID=10644] knockdown by RNAi.
Full description | Insulin-like growth factor 2 (IGF-2) mRNA-binding proteins (IMPs) are a family of posttranscriptional regulatory factors with well-understood roles in embryonic development and cancer but with poorly characterized functions in normal adult cells and tissues. We now show that IMP-2, the most ubiquitously expressed member of the family, is abundant in human and mouse adult skeletal myoblasts, where it is indispensable for cell motility and for stabilization of microtubules. To explore the functions of IMP-2, we analyzed the transcripts that were differentially regulated in IMP-2-depleted myoblasts and bound to IMP-2 in normal myoblasts. Among them were the mRNAs of PINCH-2, an important mediator of cell adhesion and motility, and MURF-3, a microtubule-stabilizing protein. By gain- and loss-of-function assays and gel shift experiments, we show that IMP-2 regulates the expression of PINCH-2 and MURF-3 proteins via direct binding to their mRNAs. Upregulation of PINCH-2 in IMP-2-depleted myoblasts is the key event responsible for their decreased motility. Our data reveal how the posttranscriptional regulation of gene expression by IMP-2 contributes to the control of adhesion structures and stable microtubules and demonstrate an important function for IMP-2 in cellular motility.

Standard name | BOSCO_ALLERGEN_INDUCED_TH2_ASSOCIATED_MODULE
Systematic name | M2526
Organism | Homo sapiens
PMID | 19414752
Authors | Bosco A,McKenna KL,Firth MJ,Sly PD,Holt PG
Category | C2
Sub-category | CGP
Brief description | Genes representing a co-expression network in atopic CD4 [GeneID=920] T lymphocyte responses.
Full description | Complex cellular functions within immunoinflammatory cascades are conducted by networks of interacting genes. In this study, we employed a network modeling approach to dissect and interpret global gene expression patterns in allergen-induced Th cell responses that underpin human atopic disease. We demonstrate that a subnet of interconnected genes enriched for Th2 and regulatory T cell-associated signatures plus many novel genes is hardwired into the atopic response and is a hallmark of atopy at the systems level. We show that activation of this subnet is stabilized via hyperconnected hub genes, the selective disruption of which can collapse the entire network in a comprehensive fashion. Finally, we investigated gene expression in different Th cell subsets and show that regulatory T cell- and Th2-associated signatures partition at different stages of Th memory cell differentiation. Moreover, we demonstrate the parallel presence of a core element of the Th2-associated gene signature in bystander naive cells, which can be reproduced by rIL-4. These findings indicate that network analysis provides significant additional insight into atopic mechanisms beyond that achievable with conventional microarray analyses, predicting functional interactions between novel genes and previously recognized members of the allergic cascade. This approach provides novel opportunities for design of therapeutic strategies that target entire networks of genes rather than individual effector molecules.

Standard name | BOSCO_TH1_CYTOTOXIC_MODULE
Systematic name | M2527
Organism | Homo sapiens
PMID | 20336062
Authors | Bosco A,Ehteshami S,Stern DA,Martinez FD
Category | C2
Sub-category | CGP
Brief description | Genes representing Th1 / cytotoxic module in sputum during asthma exacerbations.
Full description | Asthma exacerbations are associated with subsequent deficits in lung function. Here, we tested the hypothesis that a specific pattern of inflammatory responses during acute exacerbations may be associated with chronic airway obstruction. Gene coexpression networks were characterized in induced sputum obtained during an acute exacerbation, from asthmatic children with or without chronic airflow limitation. The data showed that activation of Th1-like/cytotoxic and interferon signaling pathways during acute exacerbations was decreased in asthmatic children with deficits in baseline lung function. These associations were independent of the identification of picornaviruses in nasal secretions or the use of medications at the time of the exacerbation. Th2-related pathways were also detected in the responses, but variations in these pathways were not related to chronic airways obstruction. Our findings show that decreased activation of Th1-like/cytotoxic and interferon pathways is a hallmark of acute exacerbation responses in asthmatic children with evidence of chronic airways obstruction.

Standard name | BOSCO_INTERFERON_INDUCED_ANTIVIRAL_MODULE
Systematic name | M2532
Organism | Homo sapiens
PMID | 20336062
Authors | Bosco A,Ehteshami S,Stern DA,Martinez FD
Category | C2
Sub-category | CGP
Brief description | Genes representing interferon-induced antiviral module in sputum during asthma exacerbations.
Full description | Asthma exacerbations are associated with subsequent deficits in lung function. Here, we tested the hypothesis that a specific pattern of inflammatory responses during acute exacerbations may be associated with chronic airway obstruction. Gene coexpression networks were characterized in induced sputum obtained during an acute exacerbation, from asthmatic children with or without chronic airflow limitation. The data showed that activation of Th1-like/cytotoxic and interferon signaling pathways during acute exacerbations was decreased in asthmatic children with deficits in baseline lung function. These associations were independent of the identification of picornaviruses in nasal secretions or the use of medications at the time of the exacerbation. Th2-related pathways were also detected in the responses, but variations in these pathways were not related to chronic airways obstruction. Our findings show that decreased activation of Th1-like/cytotoxic and interferon pathways is a hallmark of acute exacerbation responses in asthmatic children with evidence of chronic airways obstruction.

Standard name | BOSCO_EPITHELIAL_DIFFERENTIATION_MODULE
Systematic name | M2533
Organism | Homo sapiens
PMID | 20336062
Authors | Bosco A,Ehteshami S,Stern DA,Martinez FD
Category | C2
Sub-category | CGP
Brief description | Genes representing epithelial differentiation module in sputum during asthma exacerbations.
Full description | Asthma exacerbations are associated with subsequent deficits in lung function. Here, we tested the hypothesis that a specific pattern of inflammatory responses during acute exacerbations may be associated with chronic airway obstruction. Gene coexpression networks were characterized in induced sputum obtained during an acute exacerbation, from asthmatic children with or without chronic airflow limitation. The data showed that activation of Th1-like/cytotoxic and interferon signaling pathways during acute exacerbations was decreased in asthmatic children with deficits in baseline lung function. These associations were independent of the identification of picornaviruses in nasal secretions or the use of medications at the time of the exacerbation. Th2-related pathways were also detected in the responses, but variations in these pathways were not related to chronic airways obstruction. Our findings show that decreased activation of Th1-like/cytotoxic and interferon pathways is a hallmark of acute exacerbation responses in asthmatic children with evidence of chronic airways obstruction.

Standard name | PECE_MAMMARY_STEM_CELL_UP
Systematic name | M2534
Organism | Homo sapiens
PMID | 20074520
Authors | Pece S,Tosoni D,Confalonieri S,Mazzarol G,Vecchi M,Ronzoni S,Bernard L,Viale G,Pelicci PG,Di Fiore PP
Category | C2
Sub-category | CGP
Brief description | The '3/3 signature': genes consistently up-regulated in all three pools of normal mammary stem cells (defined by their ability to retain the dye PKH26).
Full description | Pathways that govern stem cell (SC) function are often subverted in cancer. Here, we report the isolation to near purity of human normal mammary SCs (hNMSCs), from cultured mammospheres, on the basis of their ability to retain the lipophilic dye PKH26 as a consequence of their quiescent nature. PKH26-positive cells possess all the characteristics of hNMSCs. The transcriptional profile of PKH26-positive cells (hNMSC signature) was able to predict biological and molecular features of breast cancers. By using markers of the hNMSC signature, we prospectively isolated SCs from the normal gland and from breast tumors. Poorly differentiated (G3) cancers displayed higher content of prospectively isolated cancer SCs (CSCs) than did well-differentiated (G1) cancers. By comparing G3 and G1 tumors in xenotransplantation experiments, we directly demonstrated that G3s are enriched in CSCs. Our data support the notion that the heterogeneous phenotypical and molecular traits of human breast cancers are a function of their CSC content.

Standard name | PECE_MAMMARY_STEM_CELL_DN
Systematic name | M2535
Organism | Homo sapiens
PMID | 20074520
Authors | Pece S,Tosoni D,Confalonieri S,Mazzarol G,Vecchi M,Ronzoni S,Bernard L,Viale G,Pelicci PG,Di Fiore PP
Category | C2
Sub-category | CGP
Brief description | The '3/3 signature': genes consistently down-regulated in all three pools of normal mammary stem cells (defined by their ability to retain the dye PKH26).
Full description | Pathways that govern stem cell (SC) function are often subverted in cancer. Here, we report the isolation to near purity of human normal mammary SCs (hNMSCs), from cultured mammospheres, on the basis of their ability to retain the lipophilic dye PKH26 as a consequence of their quiescent nature. PKH26-positive cells possess all the characteristics of hNMSCs. The transcriptional profile of PKH26-positive cells (hNMSC signature) was able to predict biological and molecular features of breast cancers. By using markers of the hNMSC signature, we prospectively isolated SCs from the normal gland and from breast tumors. Poorly differentiated (G3) cancers displayed higher content of prospectively isolated cancer SCs (CSCs) than did well-differentiated (G1) cancers. By comparing G3 and G1 tumors in xenotransplantation experiments, we directly demonstrated that G3s are enriched in CSCs. Our data support the notion that the heterogeneous phenotypical and molecular traits of human breast cancers are a function of their CSC content.

Standard name | ABRAMSON_INTERACT_WITH_AIRE
Systematic name | M2536
Organism | Homo sapiens
PMID | 20085707
Authors | Abramson J,Giraud M,Benoist C,Mathis D
Category | C2
Sub-category | CGP
Brief description | Proteins interacting with AIRE [GeneID=326], based on massspectroscopy analysis of co-immunoprecipitates in 293T cells (embryonic kidney).
Full description | Aire induces the expression of a battery of peripheral-tissue self-antigens (PTAs) in thymic stromal cells, promoting the clonal deletion of differentiating T cells that recognize them. Just how Aire targets and induces PTA transcripts remains largely undefined. Screening via Aire-targeted coimmunoprecipitation followed by mass spectrometry, and validating by multiple RNAi-mediated knockdown approaches, we identified a large set of proteins that associate with Aire. They fall into four major functional classes: nuclear transport, chromatin binding/structure, transcription and pre-mRNA processing. One set of Aire interactions centered on DNA protein kinase and a group of proteins it partners with to resolve DNA double-stranded breaks or promote transcriptional elongation. Another set of interactions was focused on the pre-mRNA splicing and maturation machinery, potentially explaining the markedly more effective processing of PTA transcripts in the presence of Aire. These findings suggest a model to explain Aire's widespread targeting and induction of weakly transcribed chromatin regions.

Standard name | MIZUSHIMA_AUTOPHAGOSOME_FORMATION
Systematic name | M2537
Organism | Mus musculus
PMID | 20144757
Authors | Mizushima N,Yoshimori T,Levine B
Category | C2
Sub-category | CGP
Brief description | Key proteins in mammalian autophagosome formation.
Full description | Autophagy has been implicated in many physiological and pathological processes. Accordingly, there is a growing scientific need to accurately identify, quantify, and manipulate the process of autophagy. However, as autophagy involves dynamic and complicated processes, it is often analyzed incorrectly. In this Primer, we discuss methods to monitor autophagy and to modulate autophagic activity, with a primary focus on mammalian macroautophagy.

Standard name | KUMAR_PATHOGEN_LOAD_BY_MACROPHAGES
Systematic name | M2538
Organism | Homo sapiens
PMID | 20211141
Authors | Kumar D,Nath L,Kamal MA,Varshney A,Jain A,Singh S,Rao KV
Category | C2
Sub-category | CGP
Brief description | Genes indentified by RNAi screen as regulating infection of THP-1 cells (macrophage) with Mycobacterium tuberculosis.
Full description | We performed a genome-wide siRNA screen to identify host factors that regulated pathogen load in human macrophages infected with a virulent strain of Mycobacterium tuberculosis. Iterative rounds of confirmation, followed by validation, identified 275 such molecules that were all found to functionally associate with each other through a dense network of interactions. This network then yielded to a molecular description of the host cell functional modules that were both engaged and perturbed by the pathogen. Importantly, a subscreen against a panel of field isolates revealed that the molecular composition of the host interface varied with both genotype and the phenotypic properties of the pathogen. An analysis of these differences, however, permitted identification of those host factors that were invariantly involved, regardless of the diversification in adaptive mechanisms employed by the pathogen. Interestingly, these factors were found to predominantly function through the regulation of autophagy.

Standard name | KUMAR_AUTOPHAGY_NETWORK
Systematic name | M2539
Organism | Homo sapiens
PMID | 20211141
Authors | Kumar D,Nath L,Kamal MA,Varshney A,Jain A,Singh S,Rao KV
Category | C2
Sub-category | CGP
Brief description | Genes defining the Mycobacterium tuberculosis strain-independent regulatory axis of the host macrophage cells.
Full description | We performed a genome-wide siRNA screen to identify host factors that regulated pathogen load in human macrophages infected with a virulent strain of Mycobacterium tuberculosis. Iterative rounds of confirmation, followed by validation, identified 275 such molecules that were all found to functionally associate with each other through a dense network of interactions. This network then yielded to a molecular description of the host cell functional modules that were both engaged and perturbed by the pathogen. Importantly, a subscreen against a panel of field isolates revealed that the molecular composition of the host interface varied with both genotype and the phenotypic properties of the pathogen. An analysis of these differences, however, permitted identification of those host factors that were invariantly involved, regardless of the diversification in adaptive mechanisms employed by the pathogen. Interestingly, these factors were found to predominantly function through the regulation of autophagy.

Standard name | GENTLES_LEUKEMIC_STEM_CELL_UP
Systematic name | M2542
Organism | Homo sapiens
PMID | 21177505
Authors | Gentles AJ,Plevritis SK,Majeti R,Alizadeh AA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in LSC (leukemic stem) cells compared to LPC (leukemia progenitor) cells from AML (acute myeloid leukemia) tumor samples.
Full description | In many cancers, specific subpopulations of cells appear to be uniquely capable of initiating and maintaining tumors. The strongest support for this cancer stem cell model comes from transplantation assays in immunodeficient mice, which indicate that human acute myeloid leukemia (AML) is driven by self-renewing leukemic stem cells (LSCs). This model has significant implications for the development of novel therapies, but its clinical relevance has yet to be determined.

Standard name | GENTLES_LEUKEMIC_STEM_CELL_DN
Systematic name | M2543
Organism | Homo sapiens
PMID | 21177505
Authors | Gentles AJ,Plevritis SK,Majeti R,Alizadeh AA
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in LSC (leukemic stem) cells compared to LPC (leukemia progenitor) cells from AML (acute myeloid leukemia) tumor samples.
Full description | In many cancers, specific subpopulations of cells appear to be uniquely capable of initiating and maintaining tumors. The strongest support for this cancer stem cell model comes from transplantation assays in immunodeficient mice, which indicate that human acute myeloid leukemia (AML) is driven by self-renewing leukemic stem cells (LSCs). This model has significant implications for the development of novel therapies, but its clinical relevance has yet to be determined.

Standard name | ROESSLER_LIVER_CANCER_METASTASIS_UP
Systematic name | M2544
Organism | Homo sapiens
PMID | 21159642
Authors | Roessler S,Jia HL,Budhu A,Forgues M,Ye QH,Lee JS,Thorgeirsson SS,Sun Z,Tang ZY,Qin LX,Wang XW
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in liver samples containing tumor thrombi in the major branches of the portal vein at surgery (PT) compared to those from metastasis-free HCC patients (PN) at the time of surgery and at follow-up.
Full description | Metastasis-related recurrence often occurs in hepatocellular carcinoma (HCC) patients who receive curative therapies. At present, it is challenging to identify patients with high risk of recurrence, which would warrant additional therapies. In this study, we sought to analyze a recently developed metastasis-related gene signature for its utility in predicting HCC survival, using 2 independent cohorts consisting of a total of 386 patients who received radical resection. Cohort 1 contained 247 predominantly HBV-positive cases analyzed with an Affymetrix platform, whereas cohort 2 contained 139 cases with mixed etiology analyzed with the NCI Oligo Set microarray platform. We employed a survival risk prediction algorithm with training, test, and independent cross-validation strategies and found that the gene signature is predictive of overall and disease-free survival. Importantly, risk was significantly predicted independently of clinical characteristics and microarray platform. In addition, survival prediction was successful in patients with early disease, such as small (<5 cm in diameter) and solitary tumors, and the signature predicted particularly well for early recurrence risk (<2 years), especially when combined with serum alpha fetoprotein or tumor staging. In conclusion, we have shown in 2 independent cohorts with mixed etiologies and ethnicity that the metastasis gene signature is a useful tool to predict HCC outcome, suggesting the general utility of this classifier. We recommend the use of this classifier as a molecular diagnostic test to assess the risk that an HCC patient will develop tumor relapse within 2 years after surgical resection, particularly for those with early-stage tumors and solitary presentation.

Standard name | ROESSLER_LIVER_CANCER_METASTASIS_DN
Systematic name | M2545
Organism | Homo sapiens
PMID | 21159642
Authors | Roessler S,Jia HL,Budhu A,Forgues M,Ye QH,Lee JS,Thorgeirsson SS,Sun Z,Tang ZY,Qin LX,Wang XW
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in liver samples containing tumor thrombi in the major branches of the portal vein at surgery (PT) compared to those from metastasis-free HCC patients (PN) at the time of surgery and at follow-up.
Full description | Metastasis-related recurrence often occurs in hepatocellular carcinoma (HCC) patients who receive curative therapies. At present, it is challenging to identify patients with high risk of recurrence, which would warrant additional therapies. In this study, we sought to analyze a recently developed metastasis-related gene signature for its utility in predicting HCC survival, using 2 independent cohorts consisting of a total of 386 patients who received radical resection. Cohort 1 contained 247 predominantly HBV-positive cases analyzed with an Affymetrix platform, whereas cohort 2 contained 139 cases with mixed etiology analyzed with the NCI Oligo Set microarray platform. We employed a survival risk prediction algorithm with training, test, and independent cross-validation strategies and found that the gene signature is predictive of overall and disease-free survival. Importantly, risk was significantly predicted independently of clinical characteristics and microarray platform. In addition, survival prediction was successful in patients with early disease, such as small (<5 cm in diameter) and solitary tumors, and the signature predicted particularly well for early recurrence risk (<2 years), especially when combined with serum alpha fetoprotein or tumor staging. In conclusion, we have shown in 2 independent cohorts with mixed etiologies and ethnicity that the metastasis gene signature is a useful tool to predict HCC outcome, suggesting the general utility of this classifier. We recommend the use of this classifier as a molecular diagnostic test to assess the risk that an HCC patient will develop tumor relapse within 2 years after surgical resection, particularly for those with early-stage tumors and solitary presentation.

Standard name | HOLLEMAN_PREDNISOLONE_RESISTANCE_B_ALL_UP
Systematic name | M2547
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing prednisolone [PubChem=5755] resistant and sensitive B-lineage ALL; here - genes up-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_PREDNISOLONE_RESISTANCE_B_ALL_DN
Systematic name | M2548
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing prednisolone [PubChem=5755] resistant and sensitive B-lineage ALL; here - genes down-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_VINCRISTINE_RESISTANCE_B_ALL_UP
Systematic name | M2550
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing vincristine [PubChem=5978] resistant and sensitive B-lineage ALL; here - genes up-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_VINCRISTINE_RESISTANCE_B_ALL_DN
Systematic name | M2552
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing vincristine [PubChem=5978] resistant and sensitive B-lineage ALL; here - genes down-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_ASPARAGINASE_RESISTANCE_B_ALL_UP
Systematic name | M2553
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing asparaginase resistant and sensitive B-lineage ALL; here - genes up-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_ASPARAGINASE_RESISTANCE_B_ALL_DN
Systematic name | M2554
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing asparaginase resistant and sensitive B-lineage ALL; here - genes down-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_DAUNORUBICIN_B_ALL_UP
Systematic name | M2556
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing daunorubicin [PubChem=30323] resistant and sensitive B-lineage ALL; here - genes up-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_DAUNORUBICIN_B_ALL_DN
Systematic name | M2557
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing daunorubicin [PubChem=30323] resistant and sensitive B-lineage ALL; here - genes down-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_PREDNISOLONE_RESISTANCE_ALL_UP
Systematic name | M2558
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing prednisolone [PubChem=5755] resistant and sensitive ALL (B- and T-lineage ALL); here - genes up-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_PREDNISOLONE_RESISTANCE_ALL_DN
Systematic name | M2560
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing prednisolone [PubChem=5755] resistant and sensitive ALL (B- and T-lineage ALL); here - genes down-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_VINCRISTINE_RESISTANCE_ALL_UP
Systematic name | M2561
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing vincristine [PubChem=5978] resistant and sensitive ALL (B- and T-lineage ALL); here - genes up-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_VINCRISTINE_RESISTANCE_ALL_DN
Systematic name | M2562
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing vincristine [PubChem=5978] resistant and sensitive ALL (B- and T-lineage ALL); here - genes down-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_DAUNORUBICIN_ALL_UP
Systematic name | M2563
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing daunorubicin [PubChem=30323] resistant and sensitive ALL (B- and T-lineage ALL); here - genes up-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_DAUNORUBICIN_ALL_DN
Systematic name | M2564
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing daunorubicin [PubChem=30323] resistant and sensitive ALL (B- and T-lineage ALL); here - genes down-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_ASPARAGINASE_RESISTANCE_ALL_UP
Systematic name | M2565
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing asparaginase resistant and sensitive ALL (B- and T-lineage ALL); here - genes up-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | HOLLEMAN_ASPARAGINASE_RESISTANCE_ALL_DN
Systematic name | M2566
Organism | Homo sapiens
PMID | 15295046
Authors | Holleman A,Cheok MH,den Boer ML,Yang W,Veerman AJ,Kazemier KM,Pei D,Cheng C,Pui CH,Relling MV,Janka-Schaub GE,Pieters R,Evans WE
Category | C2
Sub-category | CGP
Brief description | Genes distinguishing asparaginase resistant and sensitive ALL (B- and T-lineage ALL); here - genes down-regulated in the drug resistant samples.
Full description | Childhood acute lymphoblastic leukemia (ALL) is curable with chemotherapy in approximately 80 percent of patients. However, the cause of treatment failure in the remaining 20 percent of patients is largely unknown.

Standard name | ALTEMEIER_RESPONSE_TO_LPS_WITH_MECHANICAL_VENTILATION
Systematic name | M2568
Organism | Mus musculus
PMID | 16116230
Authors | Altemeier WA,Matute-Bello G,Gharib SA,Glenny RW,Martin TR,Liles WC
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in lung tissue upon LPS aspiration with mechanical ventilation (MV) compared to control (PBS aspiration without MV).
Full description | Mechanical ventilation (MV) with tidal volumes of 10-12 ml/kg is considered safe in the absence of acute lung injury (ALI). However, recent studies show that, when lung injury is already present, tidal volumes of this magnitude increase inflammation and injury in the lungs. We hypothesized that MV with tidal volumes of 10-ml/kg can also function as a cofactor in the initiation of ALI by modulating the transcriptional response to bacterial products. To test this hypothesis, we developed a mouse model in which MV did not independently cause inflammation or injury but augmented the inflammatory response to low-dose aspirated LPS and promoted development of ALI. We analyzed gene expression in lungs from 24 mice assigned to four different groups: control, MV only, intratracheal LPS only, and MV + LPS. There were twice as many differentially regulated genes in the MV + LPS group compared with the LPS-only group and 10 times as many differentially regulated genes compared with the MV-only group. For genes up-regulated by LPS treatment alone, the addition of MV further augmented expression. Cytokine concentrations in bronchoalveolar lavage fluid and tissue distribution of an intracellular protein, GADD45-gamma, correlated with mRNA levels. We conclude that MV with conventional tidal volumes enhanced the transcriptional response to LPS and promoted development of ALI.

Standard name | ANASTASSIOU_MULTICANCER_INVASIVENESS_SIGNATURE
Systematic name | M2572
Organism | Homo sapiens
PMID | 22208948
Authors | Anastassiou D,Rumjantseva V,Cheng W,Huang J,Canoll PD,Yamashiro DJ,Kandel JJ
Category | C2
Sub-category | CGP
Brief description | Invasiveness signature resulting from cancer cell/microenvironment interaction.
Full description | BACKGROUND: The biological mechanisms underlying cancer cell motility and invasiveness remain unclear, although it has been hypothesized that they involve some type of epithelial-mesenchymal transition (EMT). METHODS: We used xenograft models of human cancer cells in immunocompromised mice, profiling the harvested tumors separately with species-specific probes and computationally analyzing the results. RESULTS: Here we show that human cancer cells express in vivo a precise multi-cancer invasion-associated gene expression signature that prominently includes many EMT markers, among them the transcription factor Slug, fibronectin, and alpha-SMA. We found that human, but not mouse, cells express the signature and Slug is the only upregulated EMT-inducing transcription factor. The signature is also present in samples from many publicly available cancer gene expression datasets, suggesting that it is produced by the cancer cells themselves in multiple cancer types, including nonepithelial cancers such as neuroblastoma. Furthermore, we found that the presence of the signature in human xenografted cells was associated with a downregulation of adipocyte markers in the mouse tissue adjacent to the invasive tumor, suggesting that the signature is triggered by contextual microenvironmental interactions when the cancer cells encounter adipocytes, as previously reported. CONCLUSIONS: The known, precise and consistent gene composition of this cancer mesenchymal transition signature, particularly when combined with simultaneous analysis of the adjacent microenvironment, provides unique opportunities for shedding light on the underlying mechanisms of cancer invasiveness as well as identifying potential diagnostic markers and targets for metastasis-inhibiting therapeutics.

Standard name | LIM_MAMMARY_STEM_CELL_UP
Systematic name | M2573
Organism | Mus musculus
PMID | 20346151
Authors | Lim E,Wu D,Pal B,Bouras T,Asselin-Labat ML,Vaillant F,Yagita H,Lindeman GJ,Smyth GK,Visvader JE
Category | C2
Sub-category | CGP
Brief description | Genes consistently up-regulated in mammary stem cells both in mouse and human species.
Full description | INTRODUCTION: Molecular characterization of the normal epithelial cell types that reside in the mammary gland is an important step toward understanding pathways that regulate self-renewal, lineage commitment, and differentiation along the hierarchy. Here we determined the gene expression signatures of four distinct subpopulations isolated from the mouse mammary gland. The epithelial cell signatures were used to interrogate mouse models of mammary tumorigenesis and to compare with their normal human counterpart subsets to identify conserved genes and networks.METHODS: RNA was prepared from freshly sorted mouse mammary cell subpopulations (mammary stem cell (MaSC)-enriched, committed luminal progenitor, mature luminal and stromal cell) and used for gene expression profiling analysis on the Illumina platform. Gene signatures were derived and compared with those previously reported for the analogous normal human mammary cell subpopulations. The mouse and human epithelial subset signatures were then subjected to Ingenuity Pathway Analysis (IPA) to identify conserved pathways.RESULTS: The four mouse mammary cell subpopulations exhibited distinct gene signatures. Comparison of these signatures with the molecular profiles of different mouse models of mammary tumorigenesis revealed that tumors arising in MMTV-Wnt-1 and p53-/- mice were enriched for MaSC-subset genes, whereas the gene profiles of MMTV-Neu and MMTV-PyMT tumors were most concordant with the luminal progenitor cell signature. Comparison of the mouse mammary epithelial cell signatures with their human counterparts revealed substantial conservation of genes, whereas IPA highlighted a number of conserved pathways in the three epithelial subsets.CONCLUSIONS: The conservation of genes and pathways across species further validates the use of the mouse as a model to study mammary gland development and highlights pathways that are likely to govern cell-fate decisions and differentiation. It is noteworthy that many of the conserved genes in the MaSC population have been considered as epithelial-mesenchymal transition (EMT) signature genes. Therefore, the expression of these genes in tumor cells may reflect basal epithelial cell characteristics and not necessarily cells that have undergone an EMT. Comparative analyses of normal mouse epithelial subsets with murine tumor models have implicated distinct cell types in contributing to tumorigenesis in the different models.

Standard name | LIM_MAMMARY_STEM_CELL_DN
Systematic name | M2574
Organism | Mus musculus
PMID | 20346151
Authors | Lim E,Wu D,Pal B,Bouras T,Asselin-Labat ML,Vaillant F,Yagita H,Lindeman GJ,Smyth GK,Visvader JE
Category | C2
Sub-category | CGP
Brief description | Genes consistently down-regulated in mammary stem cells both in mouse and human species.
Full description | INTRODUCTION: Molecular characterization of the normal epithelial cell types that reside in the mammary gland is an important step toward understanding pathways that regulate self-renewal, lineage commitment, and differentiation along the hierarchy. Here we determined the gene expression signatures of four distinct subpopulations isolated from the mouse mammary gland. The epithelial cell signatures were used to interrogate mouse models of mammary tumorigenesis and to compare with their normal human counterpart subsets to identify conserved genes and networks.METHODS: RNA was prepared from freshly sorted mouse mammary cell subpopulations (mammary stem cell (MaSC)-enriched, committed luminal progenitor, mature luminal and stromal cell) and used for gene expression profiling analysis on the Illumina platform. Gene signatures were derived and compared with those previously reported for the analogous normal human mammary cell subpopulations. The mouse and human epithelial subset signatures were then subjected to Ingenuity Pathway Analysis (IPA) to identify conserved pathways.RESULTS: The four mouse mammary cell subpopulations exhibited distinct gene signatures. Comparison of these signatures with the molecular profiles of different mouse models of mammary tumorigenesis revealed that tumors arising in MMTV-Wnt-1 and p53-/- mice were enriched for MaSC-subset genes, whereas the gene profiles of MMTV-Neu and MMTV-PyMT tumors were most concordant with the luminal progenitor cell signature. Comparison of the mouse mammary epithelial cell signatures with their human counterparts revealed substantial conservation of genes, whereas IPA highlighted a number of conserved pathways in the three epithelial subsets.CONCLUSIONS: The conservation of genes and pathways across species further validates the use of the mouse as a model to study mammary gland development and highlights pathways that are likely to govern cell-fate decisions and differentiation. It is noteworthy that many of the conserved genes in the MaSC population have been considered as epithelial-mesenchymal transition (EMT) signature genes. Therefore, the expression of these genes in tumor cells may reflect basal epithelial cell characteristics and not necessarily cells that have undergone an EMT. Comparative analyses of normal mouse epithelial subsets with murine tumor models have implicated distinct cell types in contributing to tumorigenesis in the different models.

Standard name | LIM_MAMMARY_LUMINAL_PROGENITOR_UP
Systematic name | M2575
Organism | Mus musculus
PMID | 20346151
Authors | Lim E,Wu D,Pal B,Bouras T,Asselin-Labat ML,Vaillant F,Yagita H,Lindeman GJ,Smyth GK,Visvader JE
Category | C2
Sub-category | CGP
Brief description | Genes consistently up-regulated in mammary luminal progenitor cells both in mouse and human species.
Full description | INTRODUCTION: Molecular characterization of the normal epithelial cell types that reside in the mammary gland is an important step toward understanding pathways that regulate self-renewal, lineage commitment, and differentiation along the hierarchy. Here we determined the gene expression signatures of four distinct subpopulations isolated from the mouse mammary gland. The epithelial cell signatures were used to interrogate mouse models of mammary tumorigenesis and to compare with their normal human counterpart subsets to identify conserved genes and networks.METHODS: RNA was prepared from freshly sorted mouse mammary cell subpopulations (mammary stem cell (MaSC)-enriched, committed luminal progenitor, mature luminal and stromal cell) and used for gene expression profiling analysis on the Illumina platform. Gene signatures were derived and compared with those previously reported for the analogous normal human mammary cell subpopulations. The mouse and human epithelial subset signatures were then subjected to Ingenuity Pathway Analysis (IPA) to identify conserved pathways.RESULTS: The four mouse mammary cell subpopulations exhibited distinct gene signatures. Comparison of these signatures with the molecular profiles of different mouse models of mammary tumorigenesis revealed that tumors arising in MMTV-Wnt-1 and p53-/- mice were enriched for MaSC-subset genes, whereas the gene profiles of MMTV-Neu and MMTV-PyMT tumors were most concordant with the luminal progenitor cell signature. Comparison of the mouse mammary epithelial cell signatures with their human counterparts revealed substantial conservation of genes, whereas IPA highlighted a number of conserved pathways in the three epithelial subsets.CONCLUSIONS: The conservation of genes and pathways across species further validates the use of the mouse as a model to study mammary gland development and highlights pathways that are likely to govern cell-fate decisions and differentiation. It is noteworthy that many of the conserved genes in the MaSC population have been considered as epithelial-mesenchymal transition (EMT) signature genes. Therefore, the expression of these genes in tumor cells may reflect basal epithelial cell characteristics and not necessarily cells that have undergone an EMT. Comparative analyses of normal mouse epithelial subsets with murine tumor models have implicated distinct cell types in contributing to tumorigenesis in the different models.

Standard name | LIM_MAMMARY_LUMINAL_PROGENITOR_DN
Systematic name | M2576
Organism | Mus musculus
PMID | 20346151
Authors | Lim E,Wu D,Pal B,Bouras T,Asselin-Labat ML,Vaillant F,Yagita H,Lindeman GJ,Smyth GK,Visvader JE
Category | C2
Sub-category | CGP
Brief description | Genes consistently down-regulated in mammary luminal progenitor cells both in mouse and human species.
Full description | INTRODUCTION: Molecular characterization of the normal epithelial cell types that reside in the mammary gland is an important step toward understanding pathways that regulate self-renewal, lineage commitment, and differentiation along the hierarchy. Here we determined the gene expression signatures of four distinct subpopulations isolated from the mouse mammary gland. The epithelial cell signatures were used to interrogate mouse models of mammary tumorigenesis and to compare with their normal human counterpart subsets to identify conserved genes and networks.METHODS: RNA was prepared from freshly sorted mouse mammary cell subpopulations (mammary stem cell (MaSC)-enriched, committed luminal progenitor, mature luminal and stromal cell) and used for gene expression profiling analysis on the Illumina platform. Gene signatures were derived and compared with those previously reported for the analogous normal human mammary cell subpopulations. The mouse and human epithelial subset signatures were then subjected to Ingenuity Pathway Analysis (IPA) to identify conserved pathways.RESULTS: The four mouse mammary cell subpopulations exhibited distinct gene signatures. Comparison of these signatures with the molecular profiles of different mouse models of mammary tumorigenesis revealed that tumors arising in MMTV-Wnt-1 and p53-/- mice were enriched for MaSC-subset genes, whereas the gene profiles of MMTV-Neu and MMTV-PyMT tumors were most concordant with the luminal progenitor cell signature. Comparison of the mouse mammary epithelial cell signatures with their human counterparts revealed substantial conservation of genes, whereas IPA highlighted a number of conserved pathways in the three epithelial subsets.CONCLUSIONS: The conservation of genes and pathways across species further validates the use of the mouse as a model to study mammary gland development and highlights pathways that are likely to govern cell-fate decisions and differentiation. It is noteworthy that many of the conserved genes in the MaSC population have been considered as epithelial-mesenchymal transition (EMT) signature genes. Therefore, the expression of these genes in tumor cells may reflect basal epithelial cell characteristics and not necessarily cells that have undergone an EMT. Comparative analyses of normal mouse epithelial subsets with murine tumor models have implicated distinct cell types in contributing to tumorigenesis in the different models.

Standard name | LIM_MAMMARY_LUMINAL_MATURE_UP
Systematic name | M2578
Organism | Mus musculus
PMID | 20346151
Authors | Lim E,Wu D,Pal B,Bouras T,Asselin-Labat ML,Vaillant F,Yagita H,Lindeman GJ,Smyth GK,Visvader JE
Category | C2
Sub-category | CGP
Brief description | Genes consistently up-regulated in mature mammary luminal cells both in mouse and human species.
Full description | INTRODUCTION: Molecular characterization of the normal epithelial cell types that reside in the mammary gland is an important step toward understanding pathways that regulate self-renewal, lineage commitment, and differentiation along the hierarchy. Here we determined the gene expression signatures of four distinct subpopulations isolated from the mouse mammary gland. The epithelial cell signatures were used to interrogate mouse models of mammary tumorigenesis and to compare with their normal human counterpart subsets to identify conserved genes and networks.METHODS: RNA was prepared from freshly sorted mouse mammary cell subpopulations (mammary stem cell (MaSC)-enriched, committed luminal progenitor, mature luminal and stromal cell) and used for gene expression profiling analysis on the Illumina platform. Gene signatures were derived and compared with those previously reported for the analogous normal human mammary cell subpopulations. The mouse and human epithelial subset signatures were then subjected to Ingenuity Pathway Analysis (IPA) to identify conserved pathways.RESULTS: The four mouse mammary cell subpopulations exhibited distinct gene signatures. Comparison of these signatures with the molecular profiles of different mouse models of mammary tumorigenesis revealed that tumors arising in MMTV-Wnt-1 and p53-/- mice were enriched for MaSC-subset genes, whereas the gene profiles of MMTV-Neu and MMTV-PyMT tumors were most concordant with the luminal progenitor cell signature. Comparison of the mouse mammary epithelial cell signatures with their human counterparts revealed substantial conservation of genes, whereas IPA highlighted a number of conserved pathways in the three epithelial subsets.CONCLUSIONS: The conservation of genes and pathways across species further validates the use of the mouse as a model to study mammary gland development and highlights pathways that are likely to govern cell-fate decisions and differentiation. It is noteworthy that many of the conserved genes in the MaSC population have been considered as epithelial-mesenchymal transition (EMT) signature genes. Therefore, the expression of these genes in tumor cells may reflect basal epithelial cell characteristics and not necessarily cells that have undergone an EMT. Comparative analyses of normal mouse epithelial subsets with murine tumor models have implicated distinct cell types in contributing to tumorigenesis in the different models.

Standard name | LIM_MAMMARY_LUMINAL_MATURE_DN
Systematic name | M2580
Organism | Mus musculus
PMID | 20346151
Authors | Lim E,Wu D,Pal B,Bouras T,Asselin-Labat ML,Vaillant F,Yagita H,Lindeman GJ,Smyth GK,Visvader JE
Category | C2
Sub-category | CGP
Brief description | Genes consistently down-regulated in mature mammary luminal cells both in mouse and human species.
Full description | INTRODUCTION: Molecular characterization of the normal epithelial cell types that reside in the mammary gland is an important step toward understanding pathways that regulate self-renewal, lineage commitment, and differentiation along the hierarchy. Here we determined the gene expression signatures of four distinct subpopulations isolated from the mouse mammary gland. The epithelial cell signatures were used to interrogate mouse models of mammary tumorigenesis and to compare with their normal human counterpart subsets to identify conserved genes and networks.METHODS: RNA was prepared from freshly sorted mouse mammary cell subpopulations (mammary stem cell (MaSC)-enriched, committed luminal progenitor, mature luminal and stromal cell) and used for gene expression profiling analysis on the Illumina platform. Gene signatures were derived and compared with those previously reported for the analogous normal human mammary cell subpopulations. The mouse and human epithelial subset signatures were then subjected to Ingenuity Pathway Analysis (IPA) to identify conserved pathways.RESULTS: The four mouse mammary cell subpopulations exhibited distinct gene signatures. Comparison of these signatures with the molecular profiles of different mouse models of mammary tumorigenesis revealed that tumors arising in MMTV-Wnt-1 and p53-/- mice were enriched for MaSC-subset genes, whereas the gene profiles of MMTV-Neu and MMTV-PyMT tumors were most concordant with the luminal progenitor cell signature. Comparison of the mouse mammary epithelial cell signatures with their human counterparts revealed substantial conservation of genes, whereas IPA highlighted a number of conserved pathways in the three epithelial subsets.CONCLUSIONS: The conservation of genes and pathways across species further validates the use of the mouse as a model to study mammary gland development and highlights pathways that are likely to govern cell-fate decisions and differentiation. It is noteworthy that many of the conserved genes in the MaSC population have been considered as epithelial-mesenchymal transition (EMT) signature genes. Therefore, the expression of these genes in tumor cells may reflect basal epithelial cell characteristics and not necessarily cells that have undergone an EMT. Comparative analyses of normal mouse epithelial subsets with murine tumor models have implicated distinct cell types in contributing to tumorigenesis in the different models.

Standard name | DURAND_STROMA_S_UP
Systematic name | M2581
Organism | Mus musculus
PMID |
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the HSC supportive stromal cell lines.
Full description | Stromal cell lines represent an exceptional tool to study the role on the microenvironment on hematopoietic stem cell (HSC) activity. We have compared the expression profile of HSC supportive vs non-supportive stromal lines generated from different hematopoietic tissues in the mouse, i.e the aorta-gonad-mesonephros (AGM) region, the fetal liver and the adult bone marrow, sequentially activated during development. In this study, six stromal lines were used with one HSC supportive and one non-supportive for each tissue (triplicate samples for each stromal line). We used Mouse Gene 1.0 ST microrrays in combination with GSEA and statistical analysis to identify lists of genes that segregate HSC supportive from non-supportive stromal lines.

Standard name | DURAND_STROMA_NS_UP
Systematic name | M2582
Organism | Mus musculus
PMID |
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the HSC non-supportive stromal cell lines.
Full description | Stromal cell lines represent an exceptional tool to study the role on the microenvironment on hematopoietic stem cell (HSC) activity. We have compared the expression profile of HSC supportive vs non-supportive stromal lines generated from different hematopoietic tissues in the mouse, i.e the aorta-gonad-mesonephros (AGM) region, the fetal liver and the adult bone marrow, sequentially activated during development. In this study, six stromal lines were used with one HSC supportive and one non-supportive for each tissue (triplicate samples for each stromal line). We used Mouse Gene 1.0 ST microrrays in combination with GSEA and statistical analysis to identify lists of genes that segregate HSC supportive from non-supportive stromal lines.

Standard name | SMIRNOV_RESPONSE_TO_IR_2HR_UP
Systematic name | M2585
Organism | Homo sapiens
PMID | 21844125
Authors | Smirnov DA,Brady L,Halasa K,Morley M,Solomon S,Cheung VG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in B lymphocytes at 2 h after exprosure to 10 Gy dose of ionizing radiation.
Full description | Radiation exposure through environmental, medical, and occupational settings is increasingly common. While radiation has harmful effects, it has utility in many applications such as radiotherapy for cancer. To increase the efficacy of radiation treatment and minimize its risks, a better understanding of the individual differences in radiosensitivity and the molecular basis of radiation response is needed. Here, we integrated human genetic and functional genomic approaches to study the response of human cells to radiation. We measured radiation-induced changes in gene expression and cell death in B cells from normal individuals. We found extensive individual variation in gene expression and cellular responses. To understand the genetic basis of this variation, we mapped the DNA sequence variants that influence expression response to radiation. We also identified radiation-responsive genes that regulate cell death; silencing of these genes by small interfering RNA led to an increase in radiation-induced cell death in human B cells, colorectal and prostate cancer cells. Together these results uncovered DNA variants that contribute to radiosensitivity and identified genes that can be targeted to increase the sensitivity of tumors to radiation.

Standard name | SMIRNOV_RESPONSE_TO_IR_2HR_DN
Systematic name | M2586
Organism | Homo sapiens
PMID | 21844125
Authors | Smirnov DA,Brady L,Halasa K,Morley M,Solomon S,Cheung VG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in B lymphocytes at 2 h after exprosure to 10 Gy dose of ionizing radiation.
Full description | Radiation exposure through environmental, medical, and occupational settings is increasingly common. While radiation has harmful effects, it has utility in many applications such as radiotherapy for cancer. To increase the efficacy of radiation treatment and minimize its risks, a better understanding of the individual differences in radiosensitivity and the molecular basis of radiation response is needed. Here, we integrated human genetic and functional genomic approaches to study the response of human cells to radiation. We measured radiation-induced changes in gene expression and cell death in B cells from normal individuals. We found extensive individual variation in gene expression and cellular responses. To understand the genetic basis of this variation, we mapped the DNA sequence variants that influence expression response to radiation. We also identified radiation-responsive genes that regulate cell death; silencing of these genes by small interfering RNA led to an increase in radiation-induced cell death in human B cells, colorectal and prostate cancer cells. Together these results uncovered DNA variants that contribute to radiosensitivity and identified genes that can be targeted to increase the sensitivity of tumors to radiation.

Standard name | SMIRNOV_RESPONSE_TO_IR_6HR_UP
Systematic name | M2588
Organism | Homo sapiens
PMID | 21844125
Authors | Smirnov DA,Brady L,Halasa K,Morley M,Solomon S,Cheung VG
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in B lymphocytes at 6 h after exprosure to 10 Gy dose of ionizing radiation.
Full description | Radiation exposure through environmental, medical, and occupational settings is increasingly common. While radiation has harmful effects, it has utility in many applications such as radiotherapy for cancer. To increase the efficacy of radiation treatment and minimize its risks, a better understanding of the individual differences in radiosensitivity and the molecular basis of radiation response is needed. Here, we integrated human genetic and functional genomic approaches to study the response of human cells to radiation. We measured radiation-induced changes in gene expression and cell death in B cells from normal individuals. We found extensive individual variation in gene expression and cellular responses. To understand the genetic basis of this variation, we mapped the DNA sequence variants that influence expression response to radiation. We also identified radiation-responsive genes that regulate cell death; silencing of these genes by small interfering RNA led to an increase in radiation-induced cell death in human B cells, colorectal and prostate cancer cells. Together these results uncovered DNA variants that contribute to radiosensitivity and identified genes that can be targeted to increase the sensitivity of tumors to radiation.

Standard name | SMIRNOV_RESPONSE_TO_IR_6HR_DN
Systematic name | M2590
Organism | Homo sapiens
PMID | 21844125
Authors | Smirnov DA,Brady L,Halasa K,Morley M,Solomon S,Cheung VG
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in B lymphocytes at 6 h after exprosure to 10 Gy dose of ionizing radiation.
Full description | Radiation exposure through environmental, medical, and occupational settings is increasingly common. While radiation has harmful effects, it has utility in many applications such as radiotherapy for cancer. To increase the efficacy of radiation treatment and minimize its risks, a better understanding of the individual differences in radiosensitivity and the molecular basis of radiation response is needed. Here, we integrated human genetic and functional genomic approaches to study the response of human cells to radiation. We measured radiation-induced changes in gene expression and cell death in B cells from normal individuals. We found extensive individual variation in gene expression and cellular responses. To understand the genetic basis of this variation, we mapped the DNA sequence variants that influence expression response to radiation. We also identified radiation-responsive genes that regulate cell death; silencing of these genes by small interfering RNA led to an increase in radiation-induced cell death in human B cells, colorectal and prostate cancer cells. Together these results uncovered DNA variants that contribute to radiosensitivity and identified genes that can be targeted to increase the sensitivity of tumors to radiation.

Standard name | GHANDHI_DIRECT_IRRADIATION_UP
Systematic name | M2591
Organism | Homo sapiens
PMID | 19108712
Authors | Ghandhi SA,Yaghoubian B,Amundson SA
Category | C2
Sub-category | CGP
Brief description | Genes significantly (FDR < 10%) up-regulated in IMR-90 cells (fibroblast) in response to direct irradiation.
Full description | Background: The existence of a radiation bystander effect, in which non-irradiated cells respond to signals from irradiated cells, is now well established. It raises concerns for the interpretation of risks arising from exposure to low doses of ionizing radiation. However, the regulatory mechanisms involved in the bystander response have not been well elucidated. To provide insight into the signaling pathways responding in bystanders, we have measured global gene expression four hours after bystander and direct alpha particle exposure of primary human lung fibroblasts. Results: Although common p53-regulated radiation response genes like CDKN1A were expressed at elevated levels in the directly exposed cultures, they showed little or no change in the bystanders. In contrast, genes regulated by NF_B, such as PTGS2 (cyclooxygenase-2), IL8 and BCL2A1, responded nearly identically in bystander and irradiated cells. This trend was substantiated by gene ontology and pathway analyses of the microarray data, which suggest that bystander cells mount a full NF_B response, but a muted or partial p53 response. In time-course analyses, quantitative real-time PCR measurements of CDKN1A showed the expected 4-hour peak of expression in irradiated but not bystander cells. In contrast, PTGS2, IL8 and BCL2A1 responded with two waves of expression in both bystander and directly irradiated cells, one peaking at half an hour and the other between four and six hours after irradiation. Conclusion: Two major transcriptional hubs that regulate the direct response to ionizing radiation are also implicated in regulation of the bystander response, but to dramatically different degrees. While activation of the p53 response pathway is minimal in bystander cells, the NF_B response is virtually identical in irradiated and bystander cells. This alteration in the balance of signaling is likely to lead to different outcomes in irradiated cells and their bystanders, perhaps leading to greater survival of bystanders and increased risk from any long-term damage they have sustained.

Standard name | GHANDHI_DIRECT_IRRADIATION_DN
Systematic name | M2594
Organism | Homo sapiens
PMID | 19108712
Authors | Ghandhi SA,Yaghoubian B,Amundson SA
Category | C2
Sub-category | CGP
Brief description | Genes significantly (FDR < 10%) down-regulated in IMR-90 cells (fibroblast) in response to direct irradiation.
Full description | Background: The existence of a radiation bystander effect, in which non-irradiated cells respond to signals from irradiated cells, is now well established. It raises concerns for the interpretation of risks arising from exposure to low doses of ionizing radiation. However, the regulatory mechanisms involved in the bystander response have not been well elucidated. To provide insight into the signaling pathways responding in bystanders, we have measured global gene expression four hours after bystander and direct alpha particle exposure of primary human lung fibroblasts. Results: Although common p53-regulated radiation response genes like CDKN1A were expressed at elevated levels in the directly exposed cultures, they showed little or no change in the bystanders. In contrast, genes regulated by NF_B, such as PTGS2 (cyclooxygenase-2), IL8 and BCL2A1, responded nearly identically in bystander and irradiated cells. This trend was substantiated by gene ontology and pathway analyses of the microarray data, which suggest that bystander cells mount a full NF_B response, but a muted or partial p53 response. In time-course analyses, quantitative real-time PCR measurements of CDKN1A showed the expected 4-hour peak of expression in irradiated but not bystander cells. In contrast, PTGS2, IL8 and BCL2A1 responded with two waves of expression in both bystander and directly irradiated cells, one peaking at half an hour and the other between four and six hours after irradiation. Conclusion: Two major transcriptional hubs that regulate the direct response to ionizing radiation are also implicated in regulation of the bystander response, but to dramatically different degrees. While activation of the p53 response pathway is minimal in bystander cells, the NF_B response is virtually identical in irradiated and bystander cells. This alteration in the balance of signaling is likely to lead to different outcomes in irradiated cells and their bystanders, perhaps leading to greater survival of bystanders and increased risk from any long-term damage they have sustained.

Standard name | GHANDHI_BYSTANDER_IRRADIATION_UP
Systematic name | M2597
Organism | Homo sapiens
PMID | 19108712
Authors | Ghandhi SA,Yaghoubian B,Amundson SA
Category | C2
Sub-category | CGP
Brief description | Genes significantly (FDR < 10%) up-regulated in IMR-90 cells (fibroblast) in response to bystander irradiation.
Full description | Background: The existence of a radiation bystander effect, in which non-irradiated cells respond to signals from irradiated cells, is now well established. It raises concerns for the interpretation of risks arising from exposure to low doses of ionizing radiation. However, the regulatory mechanisms involved in the bystander response have not been well elucidated. To provide insight into the signaling pathways responding in bystanders, we have measured global gene expression four hours after bystander and direct alpha particle exposure of primary human lung fibroblasts. Results: Although common p53-regulated radiation response genes like CDKN1A were expressed at elevated levels in the directly exposed cultures, they showed little or no change in the bystanders. In contrast, genes regulated by NF_B, such as PTGS2 (cyclooxygenase-2), IL8 and BCL2A1, responded nearly identically in bystander and irradiated cells. This trend was substantiated by gene ontology and pathway analyses of the microarray data, which suggest that bystander cells mount a full NF_B response, but a muted or partial p53 response. In time-course analyses, quantitative real-time PCR measurements of CDKN1A showed the expected 4-hour peak of expression in irradiated but not bystander cells. In contrast, PTGS2, IL8 and BCL2A1 responded with two waves of expression in both bystander and directly irradiated cells, one peaking at half an hour and the other between four and six hours after irradiation. Conclusion: Two major transcriptional hubs that regulate the direct response to ionizing radiation are also implicated in regulation of the bystander response, but to dramatically different degrees. While activation of the p53 response pathway is minimal in bystander cells, the NF_B response is virtually identical in irradiated and bystander cells. This alteration in the balance of signaling is likely to lead to different outcomes in irradiated cells and their bystanders, perhaps leading to greater survival of bystanders and increased risk from any long-term damage they have sustained.

Standard name | GHANDHI_BYSTANDER_IRRADIATION_DN
Systematic name | M2599
Organism | Homo sapiens
PMID | 19108712
Authors | Ghandhi SA,Yaghoubian B,Amundson SA
Category | C2
Sub-category | CGP
Brief description | Genes significantly (FDR < 10%) down-regulated in IMR-90 cells (fibroblast) in response to bystander irradiation.
Full description | Background: The existence of a radiation bystander effect, in which non-irradiated cells respond to signals from irradiated cells, is now well established. It raises concerns for the interpretation of risks arising from exposure to low doses of ionizing radiation. However, the regulatory mechanisms involved in the bystander response have not been well elucidated. To provide insight into the signaling pathways responding in bystanders, we have measured global gene expression four hours after bystander and direct alpha particle exposure of primary human lung fibroblasts. Results: Although common p53-regulated radiation response genes like CDKN1A were expressed at elevated levels in the directly exposed cultures, they showed little or no change in the bystanders. In contrast, genes regulated by NF_B, such as PTGS2 (cyclooxygenase-2), IL8 and BCL2A1, responded nearly identically in bystander and irradiated cells. This trend was substantiated by gene ontology and pathway analyses of the microarray data, which suggest that bystander cells mount a full NF_B response, but a muted or partial p53 response. In time-course analyses, quantitative real-time PCR measurements of CDKN1A showed the expected 4-hour peak of expression in irradiated but not bystander cells. In contrast, PTGS2, IL8 and BCL2A1 responded with two waves of expression in both bystander and directly irradiated cells, one peaking at half an hour and the other between four and six hours after irradiation. Conclusion: Two major transcriptional hubs that regulate the direct response to ionizing radiation are also implicated in regulation of the bystander response, but to dramatically different degrees. While activation of the p53 response pathway is minimal in bystander cells, the NF_B response is virtually identical in irradiated and bystander cells. This alteration in the balance of signaling is likely to lead to different outcomes in irradiated cells and their bystanders, perhaps leading to greater survival of bystanders and increased risk from any long-term damage they have sustained.

Standard name | WARTERS_RESPONSE_TO_IR_SKIN
Systematic name | M2600
Organism | Homo sapiens
PMID | 19580510
Authors | Warters RL,Packard AT,Kramer GF,Gaffney DK,Moos PJ
Category | C2
Sub-category | CGP
Brief description | Genes displaying an ionizing radiation response in the human skin cell samples.
Full description | Although skin is usually exposed during human exposures to ionizing radiation, there have been no thorough examinations of the transcriptional response of skin fibroblasts and keratinocytes to radiation. The transcriptional response of quiescent primary fibroblasts and keratinocytes exposed to from 10 cGy to 5 Gy and collected 4 h after treatment was examined. RNA was isolated and examined by microarray analysis for changes in the levels of gene expression. Exposure to ionizing radiation altered the expression of 279 genes across both cell types. Changes in RNA expression could be arranged into three main categories: (1) changes in keratinocytes but not in fibroblasts, (2) changes in fibroblasts but not in keratinocytes, and (3) changes in both. All of these changes were primarily of p53 target genes. Similar radiation-induced changes were induced in immortalized fibroblasts or keratinocytes. In separate experiments, protein was collected and analyzed by Western blotting for expression of proteins observed in microarray experiments to be overexpressed at the mRNA level. Both Q-PCR and Western blot analysis experiments validated these transcription changes. Our results are consistent with changes in the expression of p53 target genes as indicating the magnitude of cell responses to ionizing radiation.

Standard name | WARTERS_IR_RESPONSE_5GY
Systematic name | M2601
Organism | Homo sapiens
PMID | 19580510
Authors | Warters RL,Packard AT,Kramer GF,Gaffney DK,Moos PJ
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the human skin cells at 4 h after exprosure to 5 Gy dose of ionizing radiation.
Full description | Although skin is usually exposed during human exposures to ionizing radiation, there have been no thorough examinations of the transcriptional response of skin fibroblasts and keratinocytes to radiation. The transcriptional response of quiescent primary fibroblasts and keratinocytes exposed to from 10 cGy to 5 Gy and collected 4 h after treatment was examined. RNA was isolated and examined by microarray analysis for changes in the levels of gene expression. Exposure to ionizing radiation altered the expression of 279 genes across both cell types. Changes in RNA expression could be arranged into three main categories: (1) changes in keratinocytes but not in fibroblasts, (2) changes in fibroblasts but not in keratinocytes, and (3) changes in both. All of these changes were primarily of p53 target genes. Similar radiation-induced changes were induced in immortalized fibroblasts or keratinocytes. In separate experiments, protein was collected and analyzed by Western blotting for expression of proteins observed in microarray experiments to be overexpressed at the mRNA level. Both Q-PCR and Western blot analysis experiments validated these transcription changes. Our results are consistent with changes in the expression of p53 target genes as indicating the magnitude of cell responses to ionizing radiation.

Standard name | ZHOU_CELL_CYCLE_GENES_IN_IR_RESPONSE_2HR
Systematic name | M2604
Organism | Homo sapiens
PMID | 17404513
Authors | Zhou T,Chou J,Mullen TE,Elkon R,Zhou Y,Simpson DA,Bushel PR,Paules RS,Lobenhofer EK,Hurban P,Kaufmann WK
Category | C2
Sub-category | CGP
Brief description | Cell cycle genes significantly (p =< 0.05) changed in fibroblast cells at 2 h after exposure to ionizing radiation.
Full description | The changes in global gene expression in response to DNA damage may derive from either direct induction or repression by transcriptional regulation or indirectly by synchronization of cells to specific cell cycle phases, such as G1 or G2. We developed a model that successfully estimated the expression levels of >400 cell cycle-regulated genes in normal human fibroblasts based on the proportions of cells in each phase of the cell cycle. By isolating effects on the gene expression associated with the cell cycle phase redistribution after genotoxin treatment, the direct transcriptional target genes were distinguished from genes for which expression changed secondary to cell synchronization. Application of this model to ionizing radiation (IR)-treated normal human fibroblasts identified 150 of 406 cycle-regulated genes as putative direct transcriptional targets of IR-induced DNA damage. Changes in expression of these genes after IR treatment derived from both direct transcriptional regulation and cell cycle synchronization.

Standard name | ZHOU_CELL_CYCLE_GENES_IN_IR_RESPONSE_6HR
Systematic name | M2606
Organism | Homo sapiens
PMID | 17404513
Authors | Zhou T,Chou J,Mullen TE,Elkon R,Zhou Y,Simpson DA,Bushel PR,Paules RS,Lobenhofer EK,Hurban P,Kaufmann WK
Category | C2
Sub-category | CGP
Brief description | Cell cycle genes significantly (p =< 0.05) changed in fibroblast cells at 6 h after exposure to ionizing radiation.
Full description | The changes in global gene expression in response to DNA damage may derive from either direct induction or repression by transcriptional regulation or indirectly by synchronization of cells to specific cell cycle phases, such as G1 or G2. We developed a model that successfully estimated the expression levels of >400 cell cycle-regulated genes in normal human fibroblasts based on the proportions of cells in each phase of the cell cycle. By isolating effects on the gene expression associated with the cell cycle phase redistribution after genotoxin treatment, the direct transcriptional target genes were distinguished from genes for which expression changed secondary to cell synchronization. Application of this model to ionizing radiation (IR)-treated normal human fibroblasts identified 150 of 406 cycle-regulated genes as putative direct transcriptional targets of IR-induced DNA damage. Changes in expression of these genes after IR treatment derived from both direct transcriptional regulation and cell cycle synchronization.

Standard name | ZHOU_CELL_CYCLE_GENES_IN_IR_RESPONSE_24HR
Systematic name | M2608
Organism | Homo sapiens
PMID | 17404513
Authors | Zhou T,Chou J,Mullen TE,Elkon R,Zhou Y,Simpson DA,Bushel PR,Paules RS,Lobenhofer EK,Hurban P,Kaufmann WK
Category | C2
Sub-category | CGP
Brief description | Cell cycle genes significantly (p =< 0.05) changed in fibroblast cells at 24 h after exposure to ionizing radiation.
Full description | The changes in global gene expression in response to DNA damage may derive from either direct induction or repression by transcriptional regulation or indirectly by synchronization of cells to specific cell cycle phases, such as G1 or G2. We developed a model that successfully estimated the expression levels of >400 cell cycle-regulated genes in normal human fibroblasts based on the proportions of cells in each phase of the cell cycle. By isolating effects on the gene expression associated with the cell cycle phase redistribution after genotoxin treatment, the direct transcriptional target genes were distinguished from genes for which expression changed secondary to cell synchronization. Application of this model to ionizing radiation (IR)-treated normal human fibroblasts identified 150 of 406 cycle-regulated genes as putative direct transcriptional targets of IR-induced DNA damage. Changes in expression of these genes after IR treatment derived from both direct transcriptional regulation and cell cycle synchronization.

Standard name | ZWANG_EGF_PERSISTENTLY_UP
Systematic name | M2609
Organism | Homo sapiens
PMID | 21596316
Authors | Zwang Y,Sas-Chen A,Drier Y,Shay T,Avraham R,Lauriola M,Shema E,Lidor-Nili E,Jacob-Hirsch J,Amariglio N,Lu Y,Mills GB,Rechavi G,Oren M,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes persistently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium).
Full description | Normal cells require continuous exposure to growth factors in order to cross a restriction point and commit to cell-cycle progression. This can be replaced by two short, appropriately spaced pulses of growth factors, where the first pulse primes a process, which is completed by the second pulse, and enables restriction point crossing. Through integration of comprehensive proteomic and transcriptomic analyses of each pulse, we identified three processes that regulate restriction point crossing: (1) The first pulse induces essential metabolic enzymes and activates p53-dependent restraining processes. (2) The second pulse eliminates, via the PI3K/AKT pathway, the suppressive action of p53, as well as (3) sets an ERK-EGR1 threshold mechanism, which digitizes graded external signals into an all-or-none decision obligatory for S phase entry. Together, our findings uncover two gating mechanisms, which ensure that cells ignore fortuitous growth factors and undergo proliferation only in response to consistent mitogenic signals.

Standard name | ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF
Systematic name | M2611
Organism | Homo sapiens
PMID | 21596316
Authors | Zwang Y,Sas-Chen A,Drier Y,Shay T,Avraham R,Lauriola M,Shema E,Lidor-Nili E,Jacob-Hirsch J,Amariglio N,Lu Y,Mills GB,Rechavi G,Oren M,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Class I of genes transiently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium).
Full description | Normal cells require continuous exposure to growth factors in order to cross a restriction point and commit to cell-cycle progression. This can be replaced by two short, appropriately spaced pulses of growth factors, where the first pulse primes a process, which is completed by the second pulse, and enables restriction point crossing. Through integration of comprehensive proteomic and transcriptomic analyses of each pulse, we identified three processes that regulate restriction point crossing: (1) The first pulse induces essential metabolic enzymes and activates p53-dependent restraining processes. (2) The second pulse eliminates, via the PI3K/AKT pathway, the suppressive action of p53, as well as (3) sets an ERK-EGR1 threshold mechanism, which digitizes graded external signals into an all-or-none decision obligatory for S phase entry. Together, our findings uncover two gating mechanisms, which ensure that cells ignore fortuitous growth factors and undergo proliferation only in response to consistent mitogenic signals.

Standard name | ZWANG_CLASS_2_TRANSIENTLY_INDUCED_BY_EGF
Systematic name | M2612
Organism | Homo sapiens
PMID | 21596316
Authors | Zwang Y,Sas-Chen A,Drier Y,Shay T,Avraham R,Lauriola M,Shema E,Lidor-Nili E,Jacob-Hirsch J,Amariglio N,Lu Y,Mills GB,Rechavi G,Oren M,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Class II of genes transiently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium).
Full description | Normal cells require continuous exposure to growth factors in order to cross a restriction point and commit to cell-cycle progression. This can be replaced by two short, appropriately spaced pulses of growth factors, where the first pulse primes a process, which is completed by the second pulse, and enables restriction point crossing. Through integration of comprehensive proteomic and transcriptomic analyses of each pulse, we identified three processes that regulate restriction point crossing: (1) The first pulse induces essential metabolic enzymes and activates p53-dependent restraining processes. (2) The second pulse eliminates, via the PI3K/AKT pathway, the suppressive action of p53, as well as (3) sets an ERK-EGR1 threshold mechanism, which digitizes graded external signals into an all-or-none decision obligatory for S phase entry. Together, our findings uncover two gating mechanisms, which ensure that cells ignore fortuitous growth factors and undergo proliferation only in response to consistent mitogenic signals.

Standard name | ZWANG_CLASS_3_TRANSIENTLY_INDUCED_BY_EGF
Systematic name | M2613
Organism | Homo sapiens
PMID | 21596316
Authors | Zwang Y,Sas-Chen A,Drier Y,Shay T,Avraham R,Lauriola M,Shema E,Lidor-Nili E,Jacob-Hirsch J,Amariglio N,Lu Y,Mills GB,Rechavi G,Oren M,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Class III of genes transiently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium).
Full description | Normal cells require continuous exposure to growth factors in order to cross a restriction point and commit to cell-cycle progression. This can be replaced by two short, appropriately spaced pulses of growth factors, where the first pulse primes a process, which is completed by the second pulse, and enables restriction point crossing. Through integration of comprehensive proteomic and transcriptomic analyses of each pulse, we identified three processes that regulate restriction point crossing: (1) The first pulse induces essential metabolic enzymes and activates p53-dependent restraining processes. (2) The second pulse eliminates, via the PI3K/AKT pathway, the suppressive action of p53, as well as (3) sets an ERK-EGR1 threshold mechanism, which digitizes graded external signals into an all-or-none decision obligatory for S phase entry. Together, our findings uncover two gating mechanisms, which ensure that cells ignore fortuitous growth factors and undergo proliferation only in response to consistent mitogenic signals.

Standard name | ZWANG_DOWN_BY_2ND_EGF_PULSE
Systematic name | M2615
Organism | Homo sapiens
PMID | 21596316
Authors | Zwang Y,Sas-Chen A,Drier Y,Shay T,Avraham R,Lauriola M,Shema E,Lidor-Nili E,Jacob-Hirsch J,Amariglio N,Lu Y,Mills GB,Rechavi G,Oren M,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by second pulse of EGF [GeneID =1950] in 184A1 cells (mammary epithelium).
Full description | Normal cells require continuous exposure to growth factors in order to cross a restriction point and commit to cell-cycle progression. This can be replaced by two short, appropriately spaced pulses of growth factors, where the first pulse primes a process, which is completed by the second pulse, and enables restriction point crossing. Through integration of comprehensive proteomic and transcriptomic analyses of each pulse, we identified three processes that regulate restriction point crossing: (1) The first pulse induces essential metabolic enzymes and activates p53-dependent restraining processes. (2) The second pulse eliminates, via the PI3K/AKT pathway, the suppressive action of p53, as well as (3) sets an ERK-EGR1 threshold mechanism, which digitizes graded external signals into an all-or-none decision obligatory for S phase entry. Together, our findings uncover two gating mechanisms, which ensure that cells ignore fortuitous growth factors and undergo proliferation only in response to consistent mitogenic signals.

Standard name | ZWANG_TRANSIENTLY_UP_BY_2ND_EGF_PULSE_ONLY
Systematic name | M2616
Organism | Homo sapiens
PMID | 21596316
Authors | Zwang Y,Sas-Chen A,Drier Y,Shay T,Avraham R,Lauriola M,Shema E,Lidor-Nili E,Jacob-Hirsch J,Amariglio N,Lu Y,Mills GB,Rechavi G,Oren M,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes transiently induced only by the second pulse of EGF [GeneID =1950] in 184A1 cells (mammary epithelium).
Full description | Normal cells require continuous exposure to growth factors in order to cross a restriction point and commit to cell-cycle progression. This can be replaced by two short, appropriately spaced pulses of growth factors, where the first pulse primes a process, which is completed by the second pulse, and enables restriction point crossing. Through integration of comprehensive proteomic and transcriptomic analyses of each pulse, we identified three processes that regulate restriction point crossing: (1) The first pulse induces essential metabolic enzymes and activates p53-dependent restraining processes. (2) The second pulse eliminates, via the PI3K/AKT pathway, the suppressive action of p53, as well as (3) sets an ERK-EGR1 threshold mechanism, which digitizes graded external signals into an all-or-none decision obligatory for S phase entry. Together, our findings uncover two gating mechanisms, which ensure that cells ignore fortuitous growth factors and undergo proliferation only in response to consistent mitogenic signals.

Standard name | ZWANG_EGF_INTERVAL_UP
Systematic name | M2619
Organism | Homo sapiens
PMID | 21596316
Authors | Zwang Y,Sas-Chen A,Drier Y,Shay T,Avraham R,Lauriola M,Shema E,Lidor-Nili E,Jacob-Hirsch J,Amariglio N,Lu Y,Mills GB,Rechavi G,Oren M,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes induced in the time interval between two pulses of EGF [GeneID =1950] in 184A1 cells (mammary epithelium).
Full description | Normal cells require continuous exposure to growth factors in order to cross a restriction point and commit to cell-cycle progression. This can be replaced by two short, appropriately spaced pulses of growth factors, where the first pulse primes a process, which is completed by the second pulse, and enables restriction point crossing. Through integration of comprehensive proteomic and transcriptomic analyses of each pulse, we identified three processes that regulate restriction point crossing: (1) The first pulse induces essential metabolic enzymes and activates p53-dependent restraining processes. (2) The second pulse eliminates, via the PI3K/AKT pathway, the suppressive action of p53, as well as (3) sets an ERK-EGR1 threshold mechanism, which digitizes graded external signals into an all-or-none decision obligatory for S phase entry. Together, our findings uncover two gating mechanisms, which ensure that cells ignore fortuitous growth factors and undergo proliferation only in response to consistent mitogenic signals.

Standard name | ZWANG_EGF_INTERVAL_DN
Systematic name | M2620
Organism | Homo sapiens
PMID | 21596316
Authors | Zwang Y,Sas-Chen A,Drier Y,Shay T,Avraham R,Lauriola M,Shema E,Lidor-Nili E,Jacob-Hirsch J,Amariglio N,Lu Y,Mills GB,Rechavi G,Oren M,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes repressed in the time interval between two pulses of EGF [GeneID =1950] in 184A1 cells (mammary epithelium).
Full description | Normal cells require continuous exposure to growth factors in order to cross a restriction point and commit to cell-cycle progression. This can be replaced by two short, appropriately spaced pulses of growth factors, where the first pulse primes a process, which is completed by the second pulse, and enables restriction point crossing. Through integration of comprehensive proteomic and transcriptomic analyses of each pulse, we identified three processes that regulate restriction point crossing: (1) The first pulse induces essential metabolic enzymes and activates p53-dependent restraining processes. (2) The second pulse eliminates, via the PI3K/AKT pathway, the suppressive action of p53, as well as (3) sets an ERK-EGR1 threshold mechanism, which digitizes graded external signals into an all-or-none decision obligatory for S phase entry. Together, our findings uncover two gating mechanisms, which ensure that cells ignore fortuitous growth factors and undergo proliferation only in response to consistent mitogenic signals.

Standard name | ZWANG_EGF_PERSISTENTLY_DN
Systematic name | M2621
Organism | Homo sapiens
PMID | 21596316
Authors | Zwang Y,Sas-Chen A,Drier Y,Shay T,Avraham R,Lauriola M,Shema E,Lidor-Nili E,Jacob-Hirsch J,Amariglio N,Lu Y,Mills GB,Rechavi G,Oren M,Domany E,Yarden Y
Category | C2
Sub-category | CGP
Brief description | Genes persistently repressed by EGF [GeneID =1950] in 184A1 cells (mammary epithelium).
Full description | Normal cells require continuous exposure to growth factors in order to cross a restriction point and commit to cell-cycle progression. This can be replaced by two short, appropriately spaced pulses of growth factors, where the first pulse primes a process, which is completed by the second pulse, and enables restriction point crossing. Through integration of comprehensive proteomic and transcriptomic analyses of each pulse, we identified three processes that regulate restriction point crossing: (1) The first pulse induces essential metabolic enzymes and activates p53-dependent restraining processes. (2) The second pulse eliminates, via the PI3K/AKT pathway, the suppressive action of p53, as well as (3) sets an ERK-EGR1 threshold mechanism, which digitizes graded external signals into an all-or-none decision obligatory for S phase entry. Together, our findings uncover two gating mechanisms, which ensure that cells ignore fortuitous growth factors and undergo proliferation only in response to consistent mitogenic signals.

Standard name | CHEMELLO_SOLEUS_VS_EDL_MYOFIBERS_UP
Systematic name | M3001
Organism | Mus musculus
PMID | 21364935
Authors | Chemello F,Bean C,Cancellara P,Laveder P,Reggiani C,Lanfranchi G
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in type 1 (soleus) vs type 2B (EDL) myofibers.
Full description | BACKGROUND: Skeletal muscle is a complex, versatile tissue composed of a variety of functionally diverse fiber types. Although the biochemical, structural and functional properties of myofibers have been the subject of intense investigation for the last decades, understanding molecular processes regulating fiber type diversity is still complicated by the heterogeneity of cell types present in the whole muscle organ. METHODOLOGY/PRINCIPAL FINDINGS: We have produced a first catalogue of genes expressed in mouse slow-oxidative (type 1) and fast-glycolytic (type 2B) fibers through transcriptome analysis at the single fiber level (microgenomics). Individual fibers were obtained from murine soleus and EDL muscles and initially classified by myosin heavy chain isoform content. Gene expression profiling on high density DNA oligonucleotide microarrays showed that both qualitative and quantitative improvements were achieved, compared to results with standard muscle homogenate. First, myofiber profiles were virtually free from non-muscle transcriptional activity. Second, thousands of muscle-specific genes were identified, leading to a better definition of gene signatures in the two fiber types as well as the detection of metabolic and signaling pathways that are differentially activated in specific fiber types. Several regulatory proteins showed preferential expression in slow myofibers. Discriminant analysis revealed novel genes that could be useful for fiber type functional classification. CONCLUSIONS/SIGNIFICANCE: As gene expression analyses at the single fiber level significantly increased the resolution power, this innovative approach would allow a better understanding of the adaptive transcriptomic transitions occurring in myofibers under physiological and pathological conditions.

Standard name | CHEMELLO_SOLEUS_VS_EDL_MYOFIBERS_DN
Systematic name | M3004
Organism | Mus musculus
PMID | 21364935
Authors | Chemello F,Bean C,Cancellara P,Laveder P,Reggiani C,Lanfranchi G
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in type 2B (EDL) vs type 1 (soleus) myofibers.
Full description | BACKGROUND: Skeletal muscle is a complex, versatile tissue composed of a variety of functionally diverse fiber types. Although the biochemical, structural and functional properties of myofibers have been the subject of intense investigation for the last decades, understanding molecular processes regulating fiber type diversity is still complicated by the heterogeneity of cell types present in the whole muscle organ. METHODOLOGY/PRINCIPAL FINDINGS: We have produced a first catalogue of genes expressed in mouse slow-oxidative (type 1) and fast-glycolytic (type 2B) fibers through transcriptome analysis at the single fiber level (microgenomics). Individual fibers were obtained from murine soleus and EDL muscles and initially classified by myosin heavy chain isoform content. Gene expression profiling on high density DNA oligonucleotide microarrays showed that both qualitative and quantitative improvements were achieved, compared to results with standard muscle homogenate. First, myofiber profiles were virtually free from non-muscle transcriptional activity. Second, thousands of muscle-specific genes were identified, leading to a better definition of gene signatures in the two fiber types as well as the detection of metabolic and signaling pathways that are differentially activated in specific fiber types. Several regulatory proteins showed preferential expression in slow myofibers. Discriminant analysis revealed novel genes that could be useful for fiber type functional classification. CONCLUSIONS/SIGNIFICANCE: As gene expression analyses at the single fiber level significantly increased the resolution power, this innovative approach would allow a better understanding of the adaptive transcriptomic transitions occurring in myofibers under physiological and pathological conditions.

Standard name | HORTON_SREBF_TARGETS
Systematic name | M3009
Organism | Mus musculus
PMID | 14512514
Authors | Horton JD,Shah NA,Warrington JA,Anderson NN,Park SW,Brown MS,Goldstein JL
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in liver from mice transgenic for SREBF1 or SREBF2 [GeneID = 6720, 6721] and down-regulated in mice lacking SCAP [GeneID=22937].
Full description | The synthesis of fatty acids and cholesterol, the building blocks of membranes, is regulated by three membrane-bound transcription factors: sterol regulatory element-binding proteins (SREBP)-1a, -1c, and -2. Their function in liver has been characterized in transgenic mice that overexpress each SREBP isoform and in mice that lack all three nuclear SREBPs as a result of gene knockout of SREBP cleavage-activating protein (SCAP), a protein required for nuclear localization of SREBPs. Here, we use oligonucleotide arrays hybridized with RNA from livers of three lines of mice (transgenic for SREBP-1a, transgenic for SREBP-2, and knockout for SCAP) to identify genes that are likely to be direct targets of SREBPs in liver. A total of 1,003 genes showed statistically significant increased expression in livers of transgenic SREBP-1a mice, 505 increased in livers of transgenic SREBP-2 mice, and 343 showed decreased expression in Scap-/- livers. A subset of 33 genes met the stringent combinatorial criteria of induction in both SREBP transgenics and decreased expression in SCAP-deficient mice. Of these 33 genes, 13 were previously identified as direct targets of SREBP action. Of the remaining 20 genes, 13 encode enzymes or carrier proteins involved in cholesterol metabolism, 3 participate in fatty acid metabolism, and 4 have no known connection to lipid metabolism. Through application of stringent combinatorial criteria, the transgenic/knockout approach allows identification of genes whose activities are likely to be controlled directly by one family of transcription factors, in this case the SREBPs.

Standard name | HECKER_IFNB1_TARGETS
Systematic name | M3010
Organism | Homo sapiens
PMID | 23636981
Authors | Hecker M,Hartmann C,Kandulski O,Paap BK,Koczan D,Thiesen HJ,Zettl UK
Category | C2
Sub-category | CGP
Brief description | Genes transcriptionally modulated in the blood of multiple sclerosis patients in response to subcutaneous treatment with recombinant IFNB1 [GeneID = 3456].
Full description | Therapy with interferon-beta (IFN-beta) is a mainstay in the management of relapsing-remitting multiple sclerosis (MS), with proven long-term effectiveness and safety. Much has been learned about the molecular mechanisms of action of IFN-beta in the past years. Previous studies described more than a hundred genes to be modulated in expression in blood cells in response to the therapy. However, for many of these genes, the precise temporal expression pattern and the therapeutic relevance are unclear. We used Affymetrix microarrays to investigate in more detail the gene expression changes in peripheral blood mononuclear cells from MS patients receiving subcutaneous IFN-beta-1a. The blood samples were obtained longitudinally at five different time points up to 2 years after the start of therapy, and the patients were clinically followed up for 5 years. We examined the functions of the genes that were upregulated or downregulated at the transcript level after short-term or long-term treatment. Moreover, we analyzed their mutual interactions and their regulation by transcription factors. Compared to pretreatment levels, 96 genes were identified as highly differentially expressed, many of them already after the first IFN-beta injection. The interactions between these genes form a large network with multiple feedback loops, indicating the complex crosstalk between innate and adaptive immune responses during therapy. We discuss the genes and biological processes that might be important to reduce disease activity by attenuating the proliferation of autoreactive immune cells and their migration into the central nervous system. In summary, we present novel insights that extend the current knowledge on the early and late pharmacodynamic effects of IFN-beta therapy and describe gene expression differences between the individual patients that reflect clinical heterogeneity.

Standard name | FARMER_BREAST_CANCER_CLUSTER_6
Systematic name | M19779
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Cluster 6: selected luminal genes clustered together across breast cancer samples.
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | FARMER_BREAST_CANCER_CLUSTER_5
Systematic name | M682
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Cluster 5: selected 17q21_23 amplicon genes clustered together across breast cancer samples.
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | FARMER_BREAST_CANCER_CLUSTER_4
Systematic name | M15125
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Cluster 4: selected stromal genes clustered together across breast cancer samples.
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | FARMER_BREAST_CANCER_CLUSTER_3
Systematic name | M19675
Organism | Homo sapiens
PMID | 15897907
Authors | Farmer P,Bonnefoi H,Becette V,Tubiana-Hulin M,Fumoleau P,Larsimont D,Macgrogan G,Bergh J,Cameron D,Goldstein D,Duss S,Nicoulaz AL,Brisken C,Fiche M,Delorenzi M,Iggo R
Category | C2
Sub-category | CGP
Brief description | Cluster 3: selected apocrine, basal and hypoxia genes clustered together across breast cancer samples.
Full description | Previous microarray studies on breast cancer identified multiple tumour classes, of which the most prominent, named luminal and basal, differ in expression of the oestrogen receptor alpha gene (ER). We report here the identification of a group of breast tumours with increased androgen signalling and a 'molecular apocrine' gene expression profile. Tumour samples from 49 patients with large operable or locally advanced breast cancers were tested on Affymetrix U133A gene expression microarrays. Principal components analysis and hierarchical clustering split the tumours into three groups: basal, luminal and a group we call molecular apocrine. All of the molecular apocrine tumours have strong apocrine features on histological examination (P=0.0002). The molecular apocrine group is androgen receptor (AR) positive and contains all of the ER-negative tumours outside the basal group. Kolmogorov-Smirnov testing indicates that oestrogen signalling is most active in the luminal group, and androgen signalling is most active in the molecular apocrine group. ERBB2 amplification is commoner in the molecular apocrine than the other groups. Genes that best split the three groups were identified by Wilcoxon test. Correlation of the average expression profile of these genes in our data with the expression profile of individual tumours in four published breast cancer studies suggest that molecular apocrine tumours represent 8-14% of tumours in these studies. Our data show that it is possible with microarray data to divide mammary tumour cells into three groups based on steroid receptor activity: luminal (ER+ AR+), basal (ER- AR-) and molecular apocrine (ER- AR+).

Standard name | EPPERT_LSC_R
Systematic name | M19230
Organism | Homo sapiens
PMID | 21873988
Authors | Eppert K,Takenaka K,Lechman ER,Waldron L,Nilsson B,Galen van P,Metzeler KH,Poeppl A,Ling V,Beyene J,Canty AJ,Danska JS,Bohlander SK,Buske C,Minden MD,Golub TR,Jurisica I,Ebert BL,Dick JE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in functionally defined leukemic stem cells (LSC) from acute myeloid leukemia (AML) patients.
Full description | Xenograft studies indicate that some solid tumors and leukemias are organized as cellular hierarchies sustained by cancer stem cells (CSCs). Despite the promise of the CSC model, its relevance in humans remains uncertain. Here we show that acute myeloid leukemia (AML) follows a CSC model on the basis of sorting multiple populations from each of 16 primary human AML samples and identifying which contain leukemia stem cells (LSCs) using a sensitive xenograft assay. Analysis of gene expression from all functionally validated populations yielded an LSC-specific signature. Similarly, a hematopoietic stem cell (HSC) gene signature was established. Bioinformatic analysis identified a core transcriptional program shared by LSCs and HSCs, revealing the molecular machinery underlying stemness properties. Both stem cell programs were highly significant independent predictors of patient survival and were found in existing prognostic signatures. Thus, determinants of stemness influence the clinical outcome of AML, establishing that LSCs are clinically relevant and not artifacts of xenotransplantation.

Standard name | EPPERT_HSC_R
Systematic name | M19231
Organism | Homo sapiens
PMID | 21873988
Authors | Eppert K,Takenaka K,Lechman ER,Waldron L,Nilsson B,Galen van P,Metzeler KH,Poeppl A,Ling V,Beyene J,Canty AJ,Danska JS,Bohlander SK,Buske C,Minden MD,Golub TR,Jurisica I,Ebert BL,Dick JE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in human hematopoietic stem cell (HSC) enriched populations compared to committed progenitors and mature cells.
Full description | Xenograft studies indicate that some solid tumors and leukemias are organized as cellular hierarchies sustained by cancer stem cells (CSCs). Despite the promise of the CSC model, its relevance in humans remains uncertain. Here we show that acute myeloid leukemia (AML) follows a CSC model on the basis of sorting multiple populations from each of 16 primary human AML samples and identifying which contain leukemia stem cells (LSCs) using a sensitive xenograft assay. Analysis of gene expression from all functionally validated populations yielded an LSC-specific signature. Similarly, a hematopoietic stem cell (HSC) gene signature was established. Bioinformatic analysis identified a core transcriptional program shared by LSCs and HSCs, revealing the molecular machinery underlying stemness properties. Both stem cell programs were highly significant independent predictors of patient survival and were found in existing prognostic signatures. Thus, determinants of stemness influence the clinical outcome of AML, establishing that LSCs are clinically relevant and not artifacts of xenotransplantation.

Standard name | EPPERT_PROGENITOR
Systematic name | M19232
Organism | Homo sapiens
PMID | 21873988
Authors | Eppert K,Takenaka K,Lechman ER,Waldron L,Nilsson B,Galen van P,Metzeler KH,Poeppl A,Ling V,Beyene J,Canty AJ,Danska JS,Bohlander SK,Buske C,Minden MD,Golub TR,Jurisica I,Ebert BL,Dick JE
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in human hematopoietic lineage committed progenitor cells versus hematopoietic stem cells (HSC) and mature cells.
Full description | Xenograft studies indicate that some solid tumors and leukemias are organized as cellular hierarchies sustained by cancer stem cells (CSCs). Despite the promise of the CSC model, its relevance in humans remains uncertain. Here we show that acute myeloid leukemia (AML) follows a CSC model on the basis of sorting multiple populations from each of 16 primary human AML samples and identifying which contain leukemia stem cells (LSCs) using a sensitive xenograft assay. Analysis of gene expression from all functionally validated populations yielded an LSC-specific signature. Similarly, a hematopoietic stem cell (HSC) gene signature was established. Bioinformatic analysis identified a core transcriptional program shared by LSCs and HSCs, revealing the molecular machinery underlying stemness properties. Both stem cell programs were highly significant independent predictors of patient survival and were found in existing prognostic signatures. Thus, determinants of stemness influence the clinical outcome of AML, establishing that LSCs are clinically relevant and not artifacts of xenotransplantation.

Standard name | EPPERT_CE_HSC_LSC
Systematic name | M19233
Organism | Homo sapiens
PMID | 21873988
Authors | Eppert K,Takenaka K,Lechman ER,Waldron L,Nilsson B,Galen van P,Metzeler KH,Poeppl A,Ling V,Beyene J,Canty AJ,Danska JS,Bohlander SK,Buske C,Minden MD,Golub TR,Jurisica I,Ebert BL,Dick JE
Category | C2
Sub-category | CGP
Brief description | Shared human hematopoietic stem cell (HSC) and acute myeloid leukemia (AML) stem cell (LSC) genes: HSC genes that are highly expressed in LSC versus other leukemic cells.
Full description | Xenograft studies indicate that some solid tumors and leukemias are organized as cellular hierarchies sustained by cancer stem cells (CSCs). Despite the promise of the CSC model, its relevance in humans remains uncertain. Here we show that acute myeloid leukemia (AML) follows a CSC model on the basis of sorting multiple populations from each of 16 primary human AML samples and identifying which contain leukemia stem cells (LSCs) using a sensitive xenograft assay. Analysis of gene expression from all functionally validated populations yielded an LSC-specific signature. Similarly, a hematopoietic stem cell (HSC) gene signature was established. Bioinformatic analysis identified a core transcriptional program shared by LSCs and HSCs, revealing the molecular machinery underlying stemness properties. Both stem cell programs were highly significant independent predictors of patient survival and were found in existing prognostic signatures. Thus, determinants of stemness influence the clinical outcome of AML, establishing that LSCs are clinically relevant and not artifacts of xenotransplantation.

Standard name | QUINTENS_EMBRYONIC_BRAIN_RESPONSE_TO_IR
Systematic name | M39
Organism | Mus musculus
PMID | 25681390
Authors | Quintens R,Verreet T,Janssen A,Neefs M,Leysen L,Michaux A,Verslegers M,Samari N,Pani G,Verheyde J,Baatout S,Benotmane MA
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the mouse embryonic brain or immature neurons at 2 h or 6 h, respectively after exposure to 1 Gy dose of ionizing radiation.
Full description | The mammalian brain is especially sensitive to ionizing radiation during development, as shown by the increased occurrence of mental retardation and small head size in children who were in utero exposed to ionizing radiation after the atomic bombings of Hiroshima and Nagasaki. These effects of prenatal irradiation can be mimicked by irradiation of mouse embryos during the organogenesis period. In order to better understand the early effects of ionizing radiation on the embryonic brain and immature neurons, we performed a microarray analysis on brains from mice irradiated with different doses at E11 and E14, as well as primary cortical neuron cultures at 14 h in vitro. RNA was extracted at either 2 h (brains) or 6 h (neurons) post-irradiation. This gene set includes genes that were differentially expressed in at least two different conditions, to generate a bona fide list of early radiation-responsive genes in the embryonic mouse brain.

Standard name | MACAEVA_PBMC_RESPONSE_TO_IR
Systematic name | M52
Organism | Homo sapiens
PMID | 26763932
Authors | Macaeva E,Saeys Y,Tabury K,Janssen A,Michaux A,Benotmane MA,Vos De WH,Baatout S,Quintens R
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in human peripheral blood mononuclear cells (PBMC) at 8 h after exposure to 0.1 and 1.0 Gy dose of ionizing radiation.
Full description | Peripheral blood mononuclear cells (PBMC) were isolated using Histopaque-1077 (Sigma-Aldrich) from 10 healthy donors (5 males, 5 females, aged 23-50). Isolated cells were resuspended at a density of 106 cells/ml and allowed to equilibrate to culture conditions at 37°C in a humidified 5% CO2 atmosphere. PBMCs were then exposed to 0 (sham), 0.1 or 1.0 Gy of X-rays (250 keV - 1 mA, 1 mm Cu) at a dose rate of 0.26 Gy/min. After irradiation, cells were incubated at 37°C in a humidified 5% CO2 atmosphere for 8 h before RNA extraction. Two weeks later, the experiment was repeated using fresh PBMCs from the same donors, resulting in a total of 60 RNA samples. Total RNA (250 ng) was used for hybridization to GeneChip Human Gene 1.0 ST arrays (Affymetrix). This gene set contains genes that were up-regulated after radiation exposure (3-way ANOVA, FDR <0.05).

Standard name | FISCHER_DIRECT_P53_TARGETS_META_ANALYSIS
Systematic name | M61
Organism | Homo sapiens
PMID | 27280975
Authors | Fischer M,Grossmann P,Padi M,DeCaprio JA
Category | C2
Sub-category | CGP
Brief description | Genes directly bound and regulated by TP53[GeneID=7157].
Full description | Genes identified as transcriptionally activated by p53 in at least 5 out of 20 genome-wide p53 gene expression profiles and identified as bound by p53 within 2.5kb of the TSS in at least 4 out of 15 genome-wide p53 binding profiles.

Standard name | FISCHER_G1_S_CELL_CYCLE
Systematic name | M107
Organism | Homo sapiens
PMID | 27280975
Authors | Fischer M,Grossmann P,Padi M,DeCaprio JA
Category | C2
Sub-category | CGP
Brief description | Cell cycle genes with peak expression in G1/S check point.
Full description | Cell cycle genes with a CC Expression Score <= -2 (identified in at least 2 genome-wide cell cycle gene expression profiles with peak expression in G1/S)

Standard name | FISCHER_G2_M_CELL_CYCLE
Systematic name | M130
Organism | Homo sapiens
PMID | 27280975
Authors | Fischer M,Grossmann P,Padi M,DeCaprio JA
Category | C2
Sub-category | CGP
Brief description | Cell cycle genes with peak expression in G2/M check point.
Full description | Cell cycle genes with a CC Expression Score >= 2 (identified in at least 2 genome-wide cell cycle gene expression profiles with peak expression in G2/M)

Standard name | FISCHER_DREAM_TARGETS
Systematic name | M149
Organism | Homo sapiens
PMID | 27280975
Authors | Fischer M,Grossmann P,Padi M,DeCaprio JA
Category | C2
Sub-category | CGP
Brief description | Target genes of the DREAM complex.
Full description | Genes bound and regulated by the DREAM complex according to multiple genome-wide datasets

Standard name | GRYDER_PAX3FOXO1_ENHANCERS_IN_TADS
Systematic name | M157
Organism | Homo sapiens
PMID | 28446439
Authors | Gryder BE,Yohe ME,Chou HC,Zhang X,Marques J,Wachtel M,Schaefer B,Sen N,Song Y,Gualtieri A,Pomella S,Rota R,Cleveland A,Wen X,Sindiri S,Wei JS,Barr FG,Das S,Andresson T,Guha R,Lal-Nag M,Ferrer M,Shern JF,Zhao K,Thomas CJ,Khan J
Category | C2
Sub-category | CGP
Brief description | Expressed genes (FPKM>1) associated with high-confidence PAX3-FOXO1 sites with enhancers in primary tumors and cell lines, restricted to those within topological domain boundaries
Full description | While previous studies have attempted to identify PAX3-FOXO1 target genes, these were based either on changes in gene expression or proximity to PAX3-FOXO1 in a single cell line with no consideration of expression or chromatin context. By gene expression many targets could be falsely identified which were in fact indirect, and 336 (31%) of the nearby genes previously reported to be direct targets were not expressed, while others may not be physically interacting because of barriers in 3D chromatin space. We therefore identified high-confidence PAX3-FOXO1 target genes by a series of criteria: first, using only PAX3-FOXO1 bound to enhancers recurrent in cell lines and tumors. Secondly, we only selected expressed genes, as PAX3-FOXO1 was not found in repressive chromatin. Third, we excluded nearby expressed genes if they were not found within the same topologically associated domain (TAD) as the PAX3-FOXO1 bound enhancer. Fourth, we also called out the maximally expressed gene within each TAD harboring PAX3-FOXO1. This approach removed 435 nearby but not expressed genes, and 78 expressed but out of TAD bounds. We found 1010 high-confidence targets, 678 of which were novel, and 439 were significantly reduced by shRNA knockdown of PAX3-FOXO1 for 48 hours. Novel targets include 24 oncogenes, 14 pan-cancer upregulated genes, 53 transcription factors, and 7 imprinted genes, many of which were rapidly decommissioned upon depletion of P3F (both reduced RNA-seq and H3K27ac at their enhancers.

Standard name | GRYDER_PAX3FOXO1_TOP_ENHANCERS
Systematic name | M172
Organism | Homo sapiens
PMID | 28446439
Authors | Gryder BE,Yohe ME,Chou HC,Zhang X,Marques J,Wachtel M,Schaefer B,Sen N,Song Y,Gualtieri A,Pomella S,Rota R,Cleveland A,Wen X,Sindiri S,Wei JS,Barr FG,Das S,Andresson T,Guha R,Lal-Nag M,Ferrer M,Shern JF,Zhao K,Thomas CJ,Khan J
Category | C2
Sub-category | CGP
Brief description | Expressed genes (FPKM>1) associated with super-high-confidence PAX3-FOXO1 sites with highly-recurrent enhancers in primary tumors and cell lines, restricted to those within topological domain boundaries
Full description | While previous studies have attempted to identify PAX3-FOXO1 target genes, these were based either on changes in gene expression or proximity to PAX3-FOXO1 in a single cell line with no consideration of expression or chromatin context. By gene expression many targets could be falsely identified which were in fact indirect, and 336 (31%) of the nearby genes previously reported to be direct targets were not expressed, while others may not be physically interacting because of barriers in 3D chromatin space. We therefore identified high-confidence PAX3-FOXO1 target genes by a series of criteria: first, using only PAX3-FOXO1 bound to enhancers recurrent in cell lines and tumors. Secondly, we only selected expressed genes, as PAX3-FOXO1 was not found in repressive chromatin. Third, we excluded nearby expressed genes if they were not found within the same topologically associated domain (TAD) as the PAX3-FOXO1 bound enhancer. Fourth, we also called out the maximally expressed gene within each TAD harboring PAX3-FOXO1. This approach removed 435 nearby but not expressed genes, and 78 expressed but out of TAD bounds. We found 1010 high-confidence targets, 678 of which were novel, and 439 were significantly reduced by shRNA knockdown of PAX3-FOXO1 for 48 hours. Novel targets include 24 oncogenes, 14 pan-cancer upregulated genes, 53 transcription factors, and 7 imprinted genes, many of which were rapidly decommissioned upon depletion of P3F (both reduced RNA-seq and H3K27ac at their enhancers.

Standard name | GRYDER_PAX3FOXO1_ENHANCERS_KO_DOWN
Systematic name | M227
Organism | Homo sapiens
PMID | 28446439
Authors | Gryder BE,Yohe ME,Chou HC,Zhang X,Marques J,Wachtel M,Schaefer B,Sen N,Song Y,Gualtieri A,Pomella S,Rota R,Cleveland A,Wen X,Sindiri S,Wei JS,Barr FG,Das S,Andresson T,Guha R,Lal-Nag M,Ferrer M,Shern JF,Zhao K,Thomas CJ,Khan J
Category | C2
Sub-category | CGP
Brief description | Expressed genes (FPKM>1) associated with high-confidence PAX3-FOXO1 sites with enhancers in primary tumors and cell lines, restricted to those within topological domain boundaries, which are downregulated by delta log2(FPKM) < -0.2
Full description | We identified high-confidence PAX3-FOXO1 target genes by a series of criteria: first, using only PAX3-FOXO1 bound to enhancers recurrent in cell lines and tumors. Secondly, we only selected expressed genes, as PAX3-FOXO1 was not found in repressive chromatin. Third, we excluded nearby expressed genes if they were not found within the same topologically associated domain (TAD) as the PAX3-FOXO1 bound enhancer. Fourth, we also called out the maximally expressed gene within each TAD harboring PAX3-FOXO1. This approach removed 435 nearby but not expressed genes, and 78 expressed but out of TAD bounds. We found 1010 high-confidence targets, 678 of which were novel, and 439 were significantly reduced by shRNA knockdown of PAX3-FOXO1 for 48 hours. The reduced genes are represented in this gene set, which is a subset of GRYDER_PAX3FOXO1_ENHANCERS_IN_TADS.

Standard name | ANDERSEN_CHOLANGIOCARCINOMA_CLASS2
Systematic name | M246
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes overexpressed in cholangiocarcinoma class 2 associated with poor prognosis.
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | ANDERSEN_CHOLANGIOCARCINOMA_CLASS1
Systematic name | M282
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes overexpressed in cholangiocarcinoma class 1 associated with good prognosis
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | OISHI_CHOLANGIOMA_STEM_CELL_LIKE_UP
Systematic name | M283
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes over-expressed in stem cell-like cholangiocellular carcinoma.
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | OISHI_CHOLANGIOMA_STEM_CELL_LIKE_DN
Systematic name | M289
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes under-expressed in stem cell-like cholangiocellular carcinoma
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | VILLANUEVA_LIVER_CANCER_KRT19_UP
Systematic name | M336
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes over-expressed in KRT19-positive [GeneID=3880] hepatocellular carcinoma (HCC).
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | VILLANUEVA_LIVER_CANCER_KRT19_DN
Systematic name | M373
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes under-expressed in KRT19-positive [GeneID=3880] hepatocellular carcinoma (HCC).
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | MINGUEZ_LIVER_CANCER_VASCULAR_INVASION_UP
Systematic name | M378
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes over-expressed in hepatocellular carcinoma (HCC) with vascular invasion.
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | MINGUEZ_LIVER_CANCER_VASCULAR_INVASION_DN
Systematic name | M398
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes under-expressed in hepatocellular carcinoma (HCC) with vascular invasion.
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | ANDERSEN_LIVER_CANCER_KRT19_UP
Systematic name | M416
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes over-expressed in KRT19-positive [GeneID=3880] hepatocellular carcinoma.
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | ANDERSEN_LIVER_CANCER_KRT19_DN
Systematic name | M424
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes under-expressed in KRT19-positive [GeneID=3880] hepatocellular carcinoma.
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | KIM_LIVER_CANCER_POOR_SURVIVAL_UP
Systematic name | M450
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes over-expressed in hepatocellular carcinoma (HCC) with poor survival
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | KIM_LIVER_CANCER_POOR_SURVIVAL_DN
Systematic name | M534
Organism | Homo sapiens
PMID | 21320499
Authors | Villanueva A,Hoshida Y,Battiston C,Tovar V,Sia D,Alsinet C,Cornella H,Liberzon A,Kobayashi M,Kumada H,Thung SN,Bruix J,Newell P,April C,Fan JB,Roayaie S,Mazzaferro V,Schwartz ME,Llovet JM
Category | C2
Sub-category | CGP
Brief description | Genes under-expressed in hepatocellular carcinoma (HCC) with poor survival
Full description | In approximately 70% of patients with hepatocellular carcinoma (HCC) treated by resection or ablation, disease recurs within 5 years. Although gene expression signatures have been associated with outcome, there is no method to predict recurrence based on combined clinical, pathology, and genomic data (from tumor and cirrhotic tissue). We evaluated gene expression signatures associated with outcome in a large cohort of patients with early stage (Barcelona-Clinic Liver Cancer 0/A), single-nodule HCC and heterogeneity of signatures within tumor tissues.

Standard name | HOLLERN_ADENOMYOEPITHELIAL_BREAST_TUMOR
Systematic name | M555
Organism | Mus musculus
PMID | 29346386
Authors | Hollern DP,Swiatnicki MR,Andrechek ER
Category | C2
Sub-category | CGP
Brief description | Genes that have high expression in mammary tumors of adenomyoepithelial histology.
Full description | Human breast cancer has been characterized by extensive transcriptional heterogeneity, with dominant patterns reflected in the intrinsic subtypes. Mouse models of breast cancer also have heterogeneous transcriptomes and we noted that specific histological subtypes were associated with particular subsets. We hypothesized that unique sets of genes define each tumor histological type across mouse models of breast cancer. Using mouse models that contained both gene expression data and expert pathologist classification of tumor histology on a sample by sample basis, we predicted and validated gene expression signatures for Papillary, EMT, Microacinar and other histological subtypes. These signatures predict known histological events across murine breast cancer models and identify counterparts of mouse mammary tumor types in subtypes of human breast cancer. Importantly, the EMT, Adenomyoepithelial, and Solid signatures were predictive of clinical events in human breast cancer. In addition, a pan-cancer comparison revealed that the histological signatures were active in a variety of human cancers such as lung, oral, and esophageal squamous tumors. Finally, the differentiation status and transcriptional activity implicit within these signatures was identified. These data reveal that within tumor histology groups are unique gene expression profiles of differentiation and pathway activity that stretch well beyond the transgenic initiating events and that have clear applicability to human cancers. As a result, our work provides a predictive resource and insights into possible mechanisms that govern tumor heterogeneity.

Standard name | HOLLERN_EMT_BREAST_TUMOR_UP
Systematic name | M617
Organism | Mus musculus
PMID | 29346386
Authors | Hollern DP,Swiatnicki MR,Andrechek ER
Category | C2
Sub-category | CGP
Brief description | Genes that are highly expressed in mammary tumors of epithelial-mesenchymal transition (EMT) histology.
Full description | Human breast cancer has been characterized by extensive transcriptional heterogeneity, with dominant patterns reflected in the intrinsic subtypes. Mouse models of breast cancer also have heterogeneous transcriptomes and we noted that specific histological subtypes were associated with particular subsets. We hypothesized that unique sets of genes define each tumor histological type across mouse models of breast cancer. Using mouse models that contained both gene expression data and expert pathologist classification of tumor histology on a sample by sample basis, we predicted and validated gene expression signatures for Papillary, EMT, Microacinar and other histological subtypes. These signatures predict known histological events across murine breast cancer models and identify counterparts of mouse mammary tumor types in subtypes of human breast cancer. Importantly, the EMT, Adenomyoepithelial, and Solid signatures were predictive of clinical events in human breast cancer. In addition, a pan-cancer comparison revealed that the histological signatures were active in a variety of human cancers such as lung, oral, and esophageal squamous tumors. Finally, the differentiation status and transcriptional activity implicit within these signatures was identified. These data reveal that within tumor histology groups are unique gene expression profiles of differentiation and pathway activity that stretch well beyond the transgenic initiating events and that have clear applicability to human cancers. As a result, our work provides a predictive resource and insights into possible mechanisms that govern tumor heterogeneity.

Standard name | HOLLERN_EMT_BREAST_TUMOR_DN
Systematic name | M624
Organism | Mus musculus
PMID | 29346386
Authors | Hollern DP,Swiatnicki MR,Andrechek ER
Category | C2
Sub-category | CGP
Brief description | Genes that that have low expression in mammary tumors of epithelial-mesenchymal transition (EMT) histology.
Full description | Human breast cancer has been characterized by extensive transcriptional heterogeneity, with dominant patterns reflected in the intrinsic subtypes. Mouse models of breast cancer also have heterogeneous transcriptomes and we noted that specific histological subtypes were associated with particular subsets. We hypothesized that unique sets of genes define each tumor histological type across mouse models of breast cancer. Using mouse models that contained both gene expression data and expert pathologist classification of tumor histology on a sample by sample basis, we predicted and validated gene expression signatures for Papillary, EMT, Microacinar and other histological subtypes. These signatures predict known histological events across murine breast cancer models and identify counterparts of mouse mammary tumor types in subtypes of human breast cancer. Importantly, the EMT, Adenomyoepithelial, and Solid signatures were predictive of clinical events in human breast cancer. In addition, a pan-cancer comparison revealed that the histological signatures were active in a variety of human cancers such as lung, oral, and esophageal squamous tumors. Finally, the differentiation status and transcriptional activity implicit within these signatures was identified. These data reveal that within tumor histology groups are unique gene expression profiles of differentiation and pathway activity that stretch well beyond the transgenic initiating events and that have clear applicability to human cancers. As a result, our work provides a predictive resource and insights into possible mechanisms that govern tumor heterogeneity.

Standard name | HOLLERN_SQUAMOUS_BREAST_TUMOR
Systematic name | M650
Organism | Mus musculus
PMID | 29346386
Authors | Hollern DP,Swiatnicki MR,Andrechek ER
Category | C2
Sub-category | CGP
Brief description | Genes that have high expression in mammary tumors of squamous epithelium histology.
Full description | Human breast cancer has been characterized by extensive transcriptional heterogeneity, with dominant patterns reflected in the intrinsic subtypes. Mouse models of breast cancer also have heterogeneous transcriptomes and we noted that specific histological subtypes were associated with particular subsets. We hypothesized that unique sets of genes define each tumor histological type across mouse models of breast cancer. Using mouse models that contained both gene expression data and expert pathologist classification of tumor histology on a sample by sample basis, we predicted and validated gene expression signatures for Papillary, EMT, Microacinar and other histological subtypes. These signatures predict known histological events across murine breast cancer models and identify counterparts of mouse mammary tumor types in subtypes of human breast cancer. Importantly, the EMT, Adenomyoepithelial, and Solid signatures were predictive of clinical events in human breast cancer. In addition, a pan-cancer comparison revealed that the histological signatures were active in a variety of human cancers such as lung, oral, and esophageal squamous tumors. Finally, the differentiation status and transcriptional activity implicit within these signatures was identified. These data reveal that within tumor histology groups are unique gene expression profiles of differentiation and pathway activity that stretch well beyond the transgenic initiating events and that have clear applicability to human cancers. As a result, our work provides a predictive resource and insights into possible mechanisms that govern tumor heterogeneity.

Standard name | HOLLERN_PAPILLARY_BREAST_TUMOR
Systematic name | M694
Organism | Mus musculus
PMID | 29346386
Authors | Hollern DP,Swiatnicki MR,Andrechek ER
Category | C2
Sub-category | CGP
Brief description | Genes that have high expression in paplillary mammary tumors.
Full description | Human breast cancer has been characterized by extensive transcriptional heterogeneity, with dominant patterns reflected in the intrinsic subtypes. Mouse models of breast cancer also have heterogeneous transcriptomes and we noted that specific histological subtypes were associated with particular subsets. We hypothesized that unique sets of genes define each tumor histological type across mouse models of breast cancer. Using mouse models that contained both gene expression data and expert pathologist classification of tumor histology on a sample by sample basis, we predicted and validated gene expression signatures for Papillary, EMT, Microacinar and other histological subtypes. These signatures predict known histological events across murine breast cancer models and identify counterparts of mouse mammary tumor types in subtypes of human breast cancer. Importantly, the EMT, Adenomyoepithelial, and Solid signatures were predictive of clinical events in human breast cancer. In addition, a pan-cancer comparison revealed that the histological signatures were active in a variety of human cancers such as lung, oral, and esophageal squamous tumors. Finally, the differentiation status and transcriptional activity implicit within these signatures was identified. These data reveal that within tumor histology groups are unique gene expression profiles of differentiation and pathway activity that stretch well beyond the transgenic initiating events and that have clear applicability to human cancers. As a result, our work provides a predictive resource and insights into possible mechanisms that govern tumor heterogeneity.

Standard name | HOLLERN_MICROACINAR_BREAST_TUMOR_UP
Systematic name | M696
Organism | Mus musculus
PMID | 29346386
Authors | Hollern DP,Swiatnicki MR,Andrechek ER
Category | C2
Sub-category | CGP
Brief description | Genes that have high expression in mammary tumors of microacinar histology.
Full description | Human breast cancer has been characterized by extensive transcriptional heterogeneity, with dominant patterns reflected in the intrinsic subtypes. Mouse models of breast cancer also have heterogeneous transcriptomes and we noted that specific histological subtypes were associated with particular subsets. We hypothesized that unique sets of genes define each tumor histological type across mouse models of breast cancer. Using mouse models that contained both gene expression data and expert pathologist classification of tumor histology on a sample by sample basis, we predicted and validated gene expression signatures for Papillary, EMT, Microacinar and other histological subtypes. These signatures predict known histological events across murine breast cancer models and identify counterparts of mouse mammary tumor types in subtypes of human breast cancer. Importantly, the EMT, Adenomyoepithelial, and Solid signatures were predictive of clinical events in human breast cancer. In addition, a pan-cancer comparison revealed that the histological signatures were active in a variety of human cancers such as lung, oral, and esophageal squamous tumors. Finally, the differentiation status and transcriptional activity implicit within these signatures was identified. These data reveal that within tumor histology groups are unique gene expression profiles of differentiation and pathway activity that stretch well beyond the transgenic initiating events and that have clear applicability to human cancers. As a result, our work provides a predictive resource and insights into possible mechanisms that govern tumor heterogeneity.

Standard name | HOLLERN_MICROACINAR_BREAST_TUMOR_DN
Systematic name | M717
Organism | Mus musculus
PMID | 29346386
Authors | Hollern DP,Swiatnicki MR,Andrechek ER
Category | C2
Sub-category | CGP
Brief description | Genes that have low expression in mammary tumors of microacinar histology.
Full description | Human breast cancer has been characterized by extensive transcriptional heterogeneity, with dominant patterns reflected in the intrinsic subtypes. Mouse models of breast cancer also have heterogeneous transcriptomes and we noted that specific histological subtypes were associated with particular subsets. We hypothesized that unique sets of genes define each tumor histological type across mouse models of breast cancer. Using mouse models that contained both gene expression data and expert pathologist classification of tumor histology on a sample by sample basis, we predicted and validated gene expression signatures for Papillary, EMT, Microacinar and other histological subtypes. These signatures predict known histological events across murine breast cancer models and identify counterparts of mouse mammary tumor types in subtypes of human breast cancer. Importantly, the EMT, Adenomyoepithelial, and Solid signatures were predictive of clinical events in human breast cancer. In addition, a pan-cancer comparison revealed that the histological signatures were active in a variety of human cancers such as lung, oral, and esophageal squamous tumors. Finally, the differentiation status and transcriptional activity implicit within these signatures was identified. These data reveal that within tumor histology groups are unique gene expression profiles of differentiation and pathway activity that stretch well beyond the transgenic initiating events and that have clear applicability to human cancers. As a result, our work provides a predictive resource and insights into possible mechanisms that govern tumor heterogeneity.

Standard name | HOLLERN_SOLID_NODULAR_BREAST_TUMOR_UP
Systematic name | M742
Organism | Mus musculus
PMID | 29346386
Authors | Hollern DP,Swiatnicki MR,Andrechek ER
Category | C2
Sub-category | CGP
Brief description | Genes that have high expression in mammary tumors of solid nodular histology.
Full description | Human breast cancer has been characterized by extensive transcriptional heterogeneity, with dominant patterns reflected in the intrinsic subtypes. Mouse models of breast cancer also have heterogeneous transcriptomes and we noted that specific histological subtypes were associated with particular subsets. We hypothesized that unique sets of genes define each tumor histological type across mouse models of breast cancer. Using mouse models that contained both gene expression data and expert pathologist classification of tumor histology on a sample by sample basis, we predicted and validated gene expression signatures for Papillary, EMT, Microacinar and other histological subtypes. These signatures predict known histological events across murine breast cancer models and identify counterparts of mouse mammary tumor types in subtypes of human breast cancer. Importantly, the EMT, Adenomyoepithelial, and Solid signatures were predictive of clinical events in human breast cancer. In addition, a pan-cancer comparison revealed that the histological signatures were active in a variety of human cancers such as lung, oral, and esophageal squamous tumors. Finally, the differentiation status and transcriptional activity implicit within these signatures was identified. These data reveal that within tumor histology groups are unique gene expression profiles of differentiation and pathway activity that stretch well beyond the transgenic initiating events and that have clear applicability to human cancers. As a result, our work provides a predictive resource and insights into possible mechanisms that govern tumor heterogeneity.

Standard name | HOLLERN_SOLID_NODULAR_BREAST_TUMOR_DN
Systematic name | M743
Organism | Mus musculus
PMID | 29346386
Authors | Hollern DP,Swiatnicki MR,Andrechek ER
Category | C2
Sub-category | CGP
Brief description | Genes that have low expression in mammary tumors of solid nodular histology.
Full description | Human breast cancer has been characterized by extensive transcriptional heterogeneity, with dominant patterns reflected in the intrinsic subtypes. Mouse models of breast cancer also have heterogeneous transcriptomes and we noted that specific histological subtypes were associated with particular subsets. We hypothesized that unique sets of genes define each tumor histological type across mouse models of breast cancer. Using mouse models that contained both gene expression data and expert pathologist classification of tumor histology on a sample by sample basis, we predicted and validated gene expression signatures for Papillary, EMT, Microacinar and other histological subtypes. These signatures predict known histological events across murine breast cancer models and identify counterparts of mouse mammary tumor types in subtypes of human breast cancer. Importantly, the EMT, Adenomyoepithelial, and Solid signatures were predictive of clinical events in human breast cancer. In addition, a pan-cancer comparison revealed that the histological signatures were active in a variety of human cancers such as lung, oral, and esophageal squamous tumors. Finally, the differentiation status and transcriptional activity implicit within these signatures was identified. These data reveal that within tumor histology groups are unique gene expression profiles of differentiation and pathway activity that stretch well beyond the transgenic initiating events and that have clear applicability to human cancers. As a result, our work provides a predictive resource and insights into possible mechanisms that govern tumor heterogeneity.

Standard name | FLORIO_NEOCORTEX_BASAL_RADIAL_GLIA_DN
Systematic name | M761
Organism | Homo sapiens
PMID | 25721503
Authors | Florio M,Albert M,Taverna E,Namba T,Brandl H,Lewitus E,Haffner C,Sykes A,Wong FK,Peters J,Guhr E,Klemroth S,Prüfer K,Kelso J,Naumann R,Nüsslein I,Dahl A,Lachmann R,Pääbo S,Huttner WB
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated in basal radial glia (bRG) relative to apical radial glia (aRG), and up-regulated in both aRG and bRG relative to neurons.
Full description | Evolutionary expansion of the human neocortex reflects increased amplification of basal progenitors in the subventricular zone, producing more neurons during fetal corticogenesis. In this work, we analyze the transcriptomes of distinct progenitor subpopulations isolated by a cell polarity-based approach from developing mouse and human neocortex. We identify 56 genes preferentially expressed in human apical and basal radial glia that lack mouse orthologs. Among these, ARHGAP11B has the highest degree of radial glia-specific expression. ARHGAP11B arose from partial duplication of ARHGAP11A (which encodes a Rho guanosine triphosphatase-activating protein) on the human lineage after separation from the chimpanzee lineage. Expression of ARHGAP11B in embryonic mouse neocortex promotes basal progenitor generation and self-renewal and can increase cortical plate area and induce gyrification. Hence, ARHGAP11B may have contributed to evolutionary expansion of human neocortex.

Standard name | FLORIO_NEOCORTEX_BASAL_RADIAL_GLIA_UP
Systematic name | M798
Organism | Homo sapiens
PMID | 25721503
Authors | Florio M,Albert M,Taverna E,Namba T,Brandl H,Lewitus E,Haffner C,Sykes A,Wong FK,Peters J,Guhr E,Klemroth S,Prüfer K,Kelso J,Naumann R,Nüsslein I,Dahl A,Lachmann R,Pääbo S,Huttner WB
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in basal radial glia (bRG) relative to apical radial glia (aRG), and up-regulated in both aRG and bRG relative to neurons.
Full description | Evolutionary expansion of the human neocortex reflects increased amplification of basal progenitors in the subventricular zone, producing more neurons during fetal corticogenesis. In this work, we analyze the transcriptomes of distinct progenitor subpopulations isolated by a cell polarity-based approach from developing mouse and human neocortex. We identify 56 genes preferentially expressed in human apical and basal radial glia that lack mouse orthologs. Among these, ARHGAP11B has the highest degree of radial glia-specific expression. ARHGAP11B arose from partial duplication of ARHGAP11A (which encodes a Rho guanosine triphosphatase-activating protein) on the human lineage after separation from the chimpanzee lineage. Expression of ARHGAP11B in embryonic mouse neocortex promotes basal progenitor generation and self-renewal and can increase cortical plate area and induce gyrification. Hence, ARHGAP11B may have contributed to evolutionary expansion of human neocortex.

Standard name | FLORIO_HUMAN_NEOCORTEX
Systematic name | M799
Organism | Homo sapiens
PMID | 25721503
Authors | Florio M,Albert M,Taverna E,Namba T,Brandl H,Lewitus E,Haffner C,Sykes A,Wong FK,Peters J,Guhr E,Klemroth S,Prüfer K,Kelso J,Naumann R,Nüsslein I,Dahl A,Lachmann R,Pääbo S,Huttner WB
Category | C2
Sub-category | CGP
Brief description | Human-specific genes up-regulated in basal radial glia (bRG) relative to apical radial glia (aRG), and up-regulated in both aRG and bRG relative to neurons.
Full description | Evolutionary expansion of the human neocortex reflects increased amplification of basal progenitors in the subventricular zone, producing more neurons during fetal corticogenesis. In this work, we analyze the transcriptomes of distinct progenitor subpopulations isolated by a cell polarity-based approach from developing mouse and human neocortex. We identify 56 genes preferentially expressed in human apical and basal radial glia that lack mouse orthologs. Among these, ARHGAP11B has the highest degree of radial glia-specific expression. ARHGAP11B arose from partial duplication of ARHGAP11A (which encodes a Rho guanosine triphosphatase-activating protein) on the human lineage after separation from the chimpanzee lineage. Expression of ARHGAP11B in embryonic mouse neocortex promotes basal progenitor generation and self-renewal and can increase cortical plate area and induce gyrification. Hence, ARHGAP11B may have contributed to evolutionary expansion of human neocortex.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_PINK_DN
Systematic name | M27963
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the pink module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_PURPLE_DN
Systematic name | M27964
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the purple module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_BROWN_UP
Systematic name | M27965
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the brown module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_TAN_DN
Systematic name | M27966
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the tan module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_SALMON_DN
Systematic name | M27967
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the salmon module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_CYAN_UP
Systematic name | M27968
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the cyan module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_LIGHTGREEN_DN
Systematic name | M27969
Organism | Homo sapiens
PMID | 16912112
Authors | Gargalovic PS,Imura M,Zhang B,Gharavi NM,Clark MJ,Pagnon J,Yang WP,He A,Truong A,Patel S,Nelson SF,Horvath S,Berliner JA,Kirchgessner TG,Lusis AJ
Category | C2
Sub-category | CGP
Brief description | Genes from the lightgreen module which are dn-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC).
Full description | Oxidized phospholipids are thought to promote atherogenesis by stimulating endothelial cells (ECs) to produce inflammatory cytokines, such as IL-8. In studies with mouse models, we previously demonstrated that genetic variation in inflammatory responses of endothelial cells to oxidized lipids contributes importantly to atherosclerosis susceptibility. We now show that similar variations occur in cultured aortic ECs derived from multiple heart transplant donors. These variations were stably maintained between passages and, thus, reflect either genetic or epigenetic regulatory differences. Expression array analysis of aortic EC cultures derived from 12 individuals revealed that >1,000 genes were regulated by oxidized phospholipids. We have used the observed variations in the sampled population to construct a gene coexpression network comprised of 15 modules of highly connected genes. We show that several identified modules are significantly enriched in genes for known pathways and confirm a module enriched for unfolded protein response (UPR) genes using siRNA and the UPR inducer tunicamycin. On the basis of the constructed network, we predicted that a gene of unknown function (MGC4504) present in the UPR module is a target for UPR transcriptional activator ATF4. Our data also indicate that IL-8 is present in the UPR module and is regulated, in part, by the UPR. We validate these by using siRNA. In conclusion, we show that interindividual variability can be used to group genes into pathways and predict gene-gene regulatory relationships, thus identifying targets potentially involved in susceptibility to common diseases such as atherosclerosis.

Standard name | CASTELLANO_HRAS_TARGETS_UP
Systematic name | M1907
Organism | Mus musculus
PMID | 16909116
Authors | Castellano E,De Las Rivas J,Guerrero C,Santos E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in MEF cells (embryonic fibroblast) isolated from HRAS [GeneID=3265] knockout mice.
Full description | We characterized differential gene expression profiles of fibroblast cell lines harboring single or double-homozygous null mutations in H-ras and N-ras. Whereas the expression level of the individual H-, N- and K-ras genes appeared unaffected by the presence or absence of the other ras loci, significant differences were observed between the expression profiles of cells missing N-ras and/or H-ras. Absence of N-ras produced much stronger effects than absence of H-ras over the profile of the cellular transcriptome. N-ras(-/-) and H-ras(-/-) fibroblasts displayed rather antagonistic expression profiles and the transcriptome of H-ras(-/-) cells was significantly closer to that of wild-type fibroblasts than to that of N-ras(-/-) cells. Classifying all differentially expressed genes into functional categories suggested specific roles for H-Ras and N-Ras. It was particularly striking in N-ras(-/-) cells the upregulation of a remarkable number of immunity-related genes, as well as of several loci involved in apoptosis. Reverse-phase protein array assays demonstrated in the same N-ras(-/-) cells the overexpression and nuclear migration of tyrosine phosphorylated signal transducer and activator of transcription 1 (Stat1) which was concomitant with transcriptional activation mediated by interferon-stimulated response elements. Significantly enhanced numbers of apoptotic cells were also detected in cultures of N-ras(-/-) cells. Our data support the notion that different Ras isoforms play functionally distinct cellular roles and indicate that N-Ras is significantly involved in immune modulation/host defense and apoptotic responses.

Standard name | WIEMANN_TELOMERE_SHORTENING_AND_CHRONIC_LIVER_DAMAGE_DN
Systematic name | M1244
Organism | Mus musculus
PMID | 15608677
Authors | Wiemann SU,Satyanarayana A,Buer J,Kamino K,Manns MP,Rudolph KL
Category | C2
Sub-category | CGP
Brief description | Genes down-regulated by telomere shortening due to the knockout of TERC [GeneID=7012] in the presence of chronic liver damage.
Full description | Telomere shortening limits the regenerative capacity of cells during aging and chronic disease but at the same time inhibits tumor progression, and it has yet to be determined which of these mechanisms is dominantly affecting organismal survival. Here we show that telomere shortening in telomerase knockout (mTERC-/-) mice in combination with chronic liver damage significantly reduced organismal survival even though telomere shortening strongly inhibited liver tumor formation. Decreased survival induced by telomere shortening correlated with an imbalance between liver cell proliferation and liver cell apoptosis. Specific changes in gene expression were associated with telomere shortening and chronic liver damage and these gene expression changes were partially reversed by adenovirus mediated telomerase gene delivery. This study gives experimental evidence that the negative impact of telomere shortening on organ homeostasis and organismal survival can surpass the beneficial effects of telomere shortening on suppression of tumor growth in the setting of chronic organ damage.

Standard name | BIERIE_INFLAMMATORY_RESPONSE_TGFB1
Systematic name | M778
Organism | Mus musculus
PMID | 18339861
Authors | Bierie B,Stover DG,Abel TW,Chytil A,Gorska AE,Aakre M,Forrester E,Yang L,Wagner KU,Moses HL
Category | C2
Sub-category | CGP
Brief description | Inflammatory genes down-regulated in mammary carcinoma cells after stimulation with TGFB1 [GeneID=7040] for 1 hr.
Full description | Transforming growth factor (TGF)-beta signaling has been associated with early tumor suppression and late tumor progression; however, many of the mechanisms that mediate these processes are not known. Using Cre/LoxP technology, with the whey acidic protein promoter driving transgenic expression of Cre recombinase (WAP-Cre), we have now ablated the type II TGF-beta receptor (T beta RII) expression specifically within mouse mammary alveolar progenitors. Transgenic expression of the polyoma virus middle T antigen, under control of the mouse mammary tumor virus enhancer/promoter, was used to produce mammary tumors in the absence or presence of Cre (T beta RII((fl/fl);PY) and T beta RII((fl/fl);PY;WC), respectively). The loss of TGF-beta signaling significantly decreased tumor latency and increased the rate of pulmonary metastasis. The loss of TGF-beta signaling was significantly correlated with increased tumor size and enhanced carcinoma cell survival. In addition, we observed significant differences in stromal fibrovascular abundance and composition accompanied by increased recruitment of F4/80(+) cell populations in T beta RII((fl/fl);PY;WC) mice when compared with T beta RII((fl/fl);PY) controls. The recruitment of F4/80(+) cells correlated with increased expression of known inflammatory genes including Cxcl1, Cxcl5, and Ptgs2 (cyclooxygenase-2). Notably, we also identified an enriched K5(+) dNp63(+) cell population in primary T beta RII((fl/fl);PY;WC) tumors and corresponding pulmonary metastases, suggesting that loss of TGF-beta signaling in this subset of carcinoma cells can contribute to metastasis. Together, our current results indicate that loss of TGF-beta signaling in mammary alveolar progenitors may affect tumor initiation, progression, and metastasis through regulation of both intrinsic cell signaling and adjacent stromal-epithelial interactions in vivo.

Standard name | NICK_RESPONSE_TO_PROC_TREATMENT_UP
Systematic name | M16154
Organism | Homo sapiens
PMID | 15339848
Authors | Nick JA,Coldren CD,Geraci MW,Poch KR,Fouty BW,O'Brien J,Gruber M,Zarini S,Murphy RC,Kuhn K,Richter D,Kast KR,Abraham E
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in neutrophils upon treatment with activated protein C (PROC) [GeneID=5624] of pulmonary inflammation induced by bacterial lipopolysaccharide (LPS).
Full description | Recombinant human activated protein C (rhAPC) is a natural anticoagulant with potentially important anti-inflammatory properties. In humans with severe sepsis, rhAPC treatment reduces mortality, but mechanisms responsible have not been well characterized. Accumulation of activated neutrophils in the lungs and other organs during severe infection contributes to sepsis-induced organ dysfunction, including acute inflammatory lung injury. Because neutrophils express an APC receptor, we hypothesized that immunomodulatory effects of rhAPC occur, in part, via modulation of neutrophil responses. To examine this issue, we performed a double-blinded, placebo-controlled study of rhAPC in a human model of endotoxin-induced pulmonary inflammation. Administration of rhAPC significantly reduced leukocyte accumulation to the airspaces, independent of pulmonary cytokine or chemokine release. Neutrophils recovered from bronchoalveolar lavage fluid of volunteers receiving rhAPC demonstrated decreased chemotaxis ex vivo. Decreased neutrophil chemotaxis following exposure to rhAPC was confirmed in vitro. No differences were detected in gene expression, kinase activation, cytokine release, cell survival, or apoptosis of neutrophils recovered in the presence or absence of rhAPC. These studies demonstrate that rhAPC reduces both endotoxin-induced accumulation of leukocytes in the airspaces and neutrophil chemotaxis. These rhAPC-induced effects on neutrophil function may represent a mechanism by which rhAPC improves survival in patients with sepsis.

Standard name | MALTA_CURATED_STEMNESS_MARKERS
Systematic name | M30411
Organism | Homo sapiens
PMID | 29625051
Authors |
Category | C2
Sub-category | CGP
Brief description | Literature curated collection of genes marking normal and cancer stem cells.
Full description |

Standard name | BIOCARTA_RELA_PATHWAY
Systematic name | M10183
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Acetylation and Deacetylation of RelA in The Nucleus
Full description |

Standard name | BIOCARTA_NO1_PATHWAY
Systematic name | M4383
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Actions of Nitric Oxide in the Heart
Full description | Nitric oxide (NO) has a number of important physiological actions in the cardiovascular system. In the heart, NO plays role in keeping the vessels patent via vasodilation and prevention of platelet aggregation. It also plays an important role in regulating the force and rate of contraction. In vivo NO is released by shear stress of ligands that increase intracellular Ca2+ in endothelial cells. The increase intracellular Ca2+ activates nitric oxide synthase III (NOSIII) by promoting the binding of Ca/Calmodulin to the enzyme. NOSIII, which is resident in the Golgi complex, is transported together with caveolin-1 to the caveolae at the plasma membrane via vesicles. Shear stress signals via a potassium channel and the cytoskeleton, which results in tyrosine phosphorylation of specific proteins, activation of phosphatidylinositol 3-kinase, and subsequently in activation of Akt kinase. Akt activation by shear stress but also by VEGF activates NOSIII by serine phosphorylation, which increases the affinity of NOSIII for calmodulin. After agonist binding at the plasma membrane, NOSIII-activating receptors translocate to caveolae. VEGF receptor signals via its tyrosine kinase domain. Furthermore, agonist receptors activate calcium channels of the endoplasmic reticulum (ER) via phospholipase C and inositol 1,4,5-trisphosphate. This calcium flux induces binding of calmodulin to NOSIII, whereas the NOSIII-caveolin-1 interaction is disrupted. At the same time, NOSIII is translocated into the cytosol. On binding of calmodulin, NOSIII generates NO, is enhanced by the interaction with Hsp90. Once activated, NOSIII catabolizes L-arginine to NO, which diffuses out of the cell. NO stimulates guanylate (G-) cyclase and increases cGMP levels. cGMP activates cGMP-dependent protein kinase (PKG), cGMP-inhibited phosphodiesterase (PDEIII), and cGMP-stimulated phosphodiesterase (PDEII). PKG may reduce the force and rate of contraction, possibly by phosphorylating troponin I or by phosphorylating phospholamban. PDEIII is inhibited by the increases in cGMP brought about by NO. This may result in an increase in cAMP and cAMP-dependent protein kinase (PKA). PKA in turn activates Ca2+ channels, countering the effects of PKG. In contrast, cGMP may stimulate PDEII, reduce cAMP levels and PKA activity, and thereby reduce Ca2+ channel activity. Ach, acetylcholine. CAT-1, cationic amino acid transporter.

Standard name | BIOCARTA_CSK_PATHWAY
Systematic name | M6327
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Activation of Csk by cAMP-dependent Protein Kinase Inhibits Signaling through the T Cell Receptor
Full description | Interaction of T cell receptor with specific antigen in the context of MHC II activates a signal transduction pathway that leads to T cell activation. In the T cell receptor signaling pathway, the src family kinases Lck and Fyn are activated to phosphorylate proteins in the T cell receptor complex which recruit and activate the ZAP70 kinase. The activation of ZAP70 phosphorylates downstream targets that activate MAP kinase pathways and cause T cell activation. The CD45 phosphorylase also plays a role in T cell receptor signaling, dephosphorylated Lck and Fyn to activate them. Other factors modulate T cell receptor activation. Csk (COOH-terminal Srk kinase) phosphorylates Lck and deactivates it, opposing the action of CD45. The phosphorylation of Lck by Csk inhibits T cell receptor signaling and inhibits T cell activation. Csk activity is regulated in T cells by PKA, the cAMP-dependent protein kinase activated by the second messenger cAMP. The activity of Csk also appears to depend on other factors such as CBP, which recruits Csk to the plasma membrane in lipid rafts where other signaling factors such the T cell receptor complex are localized. CBP also directly activates Csk.

Standard name | BIOCARTA_SRCRPTP_PATHWAY
Systematic name | M10994
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Activation of Src by Protein-tyrosine phosphatase alpha
Full description | Progression through the cell cycle is accompanied by activation of the proto-oncogene c-Src, a protein tyrosine kinase. Overexpression of Src leads to tyrosine phosphorylation of multiple protein substrates and cellular transformation. During interphase the Src protein folds back upon itself to stay in the inactive state, with a phophotyrosine residue in one domain at Tyrosine 529 bound by an SH2 domain in the same protein. Activation of c-Src involves protein-tyrosine phosphatase alpha (PTP-alpha, or RPTP-alpha), a transmembrane protein with a cytoplasmic phosphatase domain. A variety of evidence has indicated that PTP-alpha dephosphorylates c-Src at Tyr529, allowing Src to open up and become activated, and that this activation occurs in association with mitosis. To activate Src, PTP-alpha must first open up the folded Src through binding itself to the phosphorylated Src domain, a process blocked by binding of Grb-2 to PTP-alpha at phosphorylated Tyr789. PTP-alpha phosphorylated at Tyr789 also binds to the Src SH2 domain, causing the Src structure to open at Src Tyr529 to become available for dephosphorylation. During mitosis the mitotic kinase Cdc-2 phosphorylates Src, along with other cellular substrates, and in so doing makes Src more prone PTP-alpha dephosphorylation and activation. The activity of PTP-alpha toward Src is also regulated by phosphorylation of PTP-alpha by protein kinase C at serines 180 and 204, releasing the inhibition of PTP-alpha by Grb-2. In the normal cell cycle, Src activity is down-regulated after cell division through dephosphorylation by protein phosphatases and phosphorylation by Csk (C-terminal src kinase) and PTP-alpha dephoshorylation returns the cycle to its interphase condition. The regulation of Src activity during mitosis demonstrates how protein phosphorylation can shifts the delicate equilibrium of molecular interactions and cellular responses.

Standard name | BIOCARTA_AMI_PATHWAY
Systematic name | M15394
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Acute Myocardial Infarction
Full description | Myocardial infraction (MI)is the condition of irreversible necrosis of the heart muscle that results from prolonged ischemia. Nearly 1.5 million people in US sustain an MI each year, and this event proves fatal in approximately one third of patients. Approximately 90% of MI result from formation of an acute thrombus that obstructs an atherosclerotic coronary artery. The thrombus transforms a region of plaque narrowing to one of complete vessel occlusion (top right in pink). The responsible thrombus appears to be generated by interactions between the atherosclerotic plaque, the coronary endothelium, circulating platelets, and dynamic vasomotor tone of the vessel wall, all of which overwhelm natural protective mechanisms. The endogenous protective mechanisms against thrombosis include: 1. Inactivation of thrombin by antithrombin III (ATIII), the effectiveness of which is enhanced by binding of ATIII to heparin sulafate. The antithrombin binding region of commercial heparin consists of sulfated disaccharide units (bottom panel). 2. Inactivation of clotting factors Va and VIIIa by activated protein C (protein C*), an action that is enhanced by protein S. Protein C is activated by the thrombomodulin (TM)-thrombin complex. 3. Inactivation of factor VII/tissue factor complex by tissue factor pathway inhibitor (TFPI). Coumarin drugs (Warfarin) blocks the g-carboxylation of Glu residues in prothrombin and factors VII, IX and X which results in incomplete molecules that are biologically inactive in coagulation (left panel). 4. Lysis of fibrin clots by tissue plasminogen activator (tPA). 5. Inhibition of platelet activation by prostacyclin and EDRF-NO. Platelets adhere to exposed collagen and are activated at the site of endothelial damage in the blood vessel. Activated platelets release adenosine diphosphate (ADP), serotonin (5-HT), and thromboxane A2 (TXA2), which activate additional platelets. Binding of thrombin further activates the platelets. Three adjoining platelets are shown in the process of viscous metamorphosis (top right). Increased cellular Ca2+ facilitates binding of fibrinogen. If the intraluminal thrombus at the site of plaque disruption totally occludes the vessel, blood flow beyond the obstruction will cease, prolonged ischemia will occur and MI (usually Q-wave MI) will likely result.

Standard name | BIOCARTA_GRANULOCYTES_PATHWAY
Systematic name | M5467
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Adhesion and Diapedesis of Granulocytes
Full description | Cell adhesion is a fundamental feature of multicellular organisms including their defense mechanisms. In the later case in mammals, leukocytes play central role. They bind bacteria, parasites, viruses, tumor cells etc. Furthermore, their interactions with the endothelium are of special importance. During an inflammation or immune reaction, specialized leukocytes (eosinophilic granulocytes) adhere to and pass through the endothelium of the blood vessels and the underlying matrix. The reaction passes through the following steps: 1. Rolling (the flow of cells is slowed down by first making contacts to the endothelium via P-, E-, and L-selectins and their receptors); 2. Adhesion (After activation of leukocyte integrins, firm contacts are established between them and endothelium molecules of the Ig superfamily - LFA-1, Mac-1, VLA-4 etc.); 3. Flattening of the cells and diapedesis (Adhering leukocytes crawl to an intercellular junction of the endothelium and then transmigrate to or even through the intercellular matrix. This is mediated by a homophilic interactions of PECAM and CD31.

Standard name | BIOCARTA_LYM_PATHWAY
Systematic name | M1469
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Adhesion and Diapedesis of Lymphocytes
Full description | Cell adhesion is a fundamental feature of multicellular organisms including their defense mechanisms. In the later case in mammals, leukocytes play central role. They bind bacteria, parasites, viruses, tumor cells etc. Furthermore, their interactions with the endothelium are of special importance. Generally, lymphocyte adhesion and passage from the bloodstream to the lymphatic system occurs in the high endothelial venules of the lymphnodes. This way the lymphocytes can communicate with each other in the lymphatic system and search for foreign compounds after their recirculation to the bloodstream, this fulfilling their role in the immune system. The reaction passes through the following steps: 1. Rolling (the flow of cells is slowed down by first making contacts to the endothelium via P-, E-, and L-selectins and their receptors); 2. Adhesion (After activation of leukocyte integrins, firm contacts are established between them and endothelium molecules of the Ig superfamily - LFA-1, Mac-1, VLA-4 etc.); 3. Flatteningof the cells and diapedesis (Adhering leukocytes crawl to an intercellular junction of the endothelium and then transmigrate to or even through the intercellular matrix. This is mediated by a homophilic interactions of PECAM and CD31.

Standard name | BIOCARTA_ARAP_PATHWAY
Systematic name | M2482
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | ADP-Ribosylation Factor
Full description | ADP-ribosylation factors (ARFs) are 20-kDa guanine nucleotide-binding proteins, members of the Ras GTPase superfamily that were initially recognized and purified because of their ability to stimulate the ADP-ribosyltransferase activity of the cholera toxin A subunit. We now know that they are critical components of several different vesicular trafficking pathways in all eukaryotic cells and activators of specific phospholipase Ds (PLDs) (reviewed in Refs. 13). ARF interacts with many proteins and other molecules that regulate its state of activation or are involved in its intracellular function. Arf proteins cycle between GDP-bound, inactive and GTP-bound, active forms, and the cycling is regulated by specific GEPs and GAPs. Members of the Arf GEP family can be grouped into two major subfamilies on the basis of their sequence similarities and functional differences. The high-molecular-weight Arf GEP subfamily includes yeast Sec7, Gea1, and Gea2, and mammalian BIG1/p200, BIG2, and GBF1, which all consist of 1,400 2,000 amino acid residues. Many Arf GAPs are multidomain proteins and have been found to interact with multiple signaling molecules. For instance, ASAP1 has a PH domain, ankyrin (ANK) repeats, proline-rich and Src-homology (SH) 3 domains and has been shown to bind PI(4,5)P2, Src, and Crk. PAPa/PAG3, with a similar domain structure, binds phosphoinositides, Src, Pyk, and paxillin. The GITs bind bARK, paxillin and the Rac/Cdc42 exchange factor PIX (also known as Cool). ASAP-related proteins, ARAP1, 2 and 3 have Arf GAP, Rho GAP,Ankyrin repeat, Ras-associating (RA), and five PH domains, and therefore have the potential of integrating four signaling pathways.

Standard name | BIOCARTA_AGR_PATHWAY
Systematic name | M6220
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Agrin in Postsynaptic Differentiation
Full description | The heparan sulphate proteoglycan agrin is well known as the key assembly factor of postsynaptic differentiation at the neuromuscular junction (NMJ), but recent data suggest it also plays a direct role in the organization of the cytoskeleton in the skeletal muscle. Signaling through muscle-specific proteins such as muscle specific kinase (MuSK) and or acetylcholine receptor (AchRs)/rapsyn, agrin can activate ubiquitously expressed Rac, Cdc42, and p21-activated kinase (PAK) that are involved in actin polymerization. Agrin also engages signaling pathways of several potent oncogenes (i.e., SFK, ErbB receptors, and cortactin).

Standard name | BIOCARTA_AKAP95_PATHWAY
Systematic name | M5731
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | AKAP95 role in mitosis and chromosome dynamics
Full description | The chromatin packaging of the genome is dynamic, changing with the cell cycle and with transcriptional regulation. During mitosis, chromatin is condensed for segregation of chromosomes, while for transcription chromatin is more open. The nuclear matrix, or scaffold, is a protein network in the nucleus providing structure and regulating chromatin condensation. Regulated interactions of matrix proteins with each other, DNA and other factors in different phases of the cell cycle alter the structure and function of chromatin. AKAP95 (A-kinase anchoring protein) is a nuclear matrix associated protein that also binds DNA and different proteins during different phases of the cell cycle. The interaction of AKAP95 with DNA and proteins alters the condensation and transcription of chromatin. A specific domain of AKAP95 regulates its interaction with the nuclear matrix and another regulates its association with DNA. One key protein that AKAP95 interacts with is the cAMP-dependent protein kinase, PKA. AKAP95 binds to PKA through a PKA RII regulatory subunit, an interaction that requires PKA phosphorylation by Cdk1. PKA activity and cAMP are reduced during entry into mitosis, but PKA recruited by AKAP95 to condensed chromosomes is essential to maintain the condensed state. Another protein recruited by AKAP95 is Eg7, a 150 kD protein recruited during mitotic chromatin condensation. Eg7 is a part of a multiprotein condensin complex, recruiting another key component of mitotic chromatin condensation. Modification of the core histones through phosphorylation regulates chromatin condensation. Histone H3 interacts with the condensin complex, and is phosphorylated during mitosis. Histone H3 phosphorylation by Aurora-2 induces chromatin condensation, and dephosphorylation by PP1 promotes chromatin decondensation for reentry into interphase. AKAP95 may play a role during the regulation of chromatin structure for transcription during interphase as well. The interaction of AKAP95 with the p68 RNA helicase recruits this enzyme to the nuclear matrix during interphase. Other nuclear RNA helicases interact with transcription factors and cofactors, suggesting that the p68 RNA helicase also may regulate interactions of transcription complexes.

Standard name | BIOCARTA_AKT_PATHWAY
Systematic name | M15258
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | AKT Signaling Pathway
Full description | Many cell-surface receptors induce production of second messengers like PIP3, phosphatidylinositol 3,4,5-trisphosphate, that convey signals to the cytoplasm from the cell surface. PIP3 signals activates the kinase PDK1, 3-phosphoinositide-dependent protein kinase-1, which in turn activates the kinase AKT, also known as protein kinase B. Proteins phosphorylated by activated AKT promote cell survival. Phosphorylation of Ikappa-B kinase leads to activation of the transcription factor NF-kB to oppose apoptosis. Bad is a protein in the Bcl-2 gene family that opposes Bcl-2 to induce apoptosis. Phosphorylation of Bad by AKT blocks anti-apoptotic activity to promote cell survival. Similarly, phosphorylation of the protease caspase 9 or forkhead transcription factors by AKT block the induction of apoptosis by these factors. AKT promotes cell survival and opposes apoptosis by a variety of routes.

Standard name | BIOCARTA_ALK_PATHWAY
Systematic name | M17400
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | ALK in cardiac myocytes
Full description | Heart formation is cued by a combination of positive and negative signals from surrounding tissues. Inhibitory signals that block heart formation in anterior paraxial mesoderm include Wnt family members expressed in dorsal neural tube and anti-BMPs expressed in the axial tissues (i.e., noggin in the notochord). Wnt signalling pathway, which is essential for setting up the entire body pattern during embryonic development involves glycogen synthase kinase-3 (GSK3). In the absence of Wnt signaling, GSK3 is active and phosphorylates b-catenin resulting in its degradation by ubiquitin-mediated proteolysis. Activation of Wnt signaling inhibits GSK3, thereby preventing phosphorylation of b-catenin, which is then able to move to the nucleus. There it associates with members of the LEF-1/TCF family of transcription factors, which activate the transcription of genes like cyclin-D1, myc, and MMPs. The Wnt signaling pathway is blocked by a family of secreted proteins such as crescent and Dkk-1 sufficient for induction of heart formation in posterior mesoderm. BMP signaling can also be blocked by the BMP antagonists noggin and chordin, which are secreted from the notochord and cooperate with Wnts to prevent cardiogenesis. Receptors for BMPs, members of the transforming growth factor-beta (TGFb) superfamily, are persistently expressed during cardiac development, yet mice lacking type II or type IA BMP receptors die at gastrulation and cannot be used to assess potential later roles in creation of the heart. Activin receptor-like kinase 3 (ALK3) is specifically required at mid-gestation for normal development of the trabeculae, compact myocardium, interventricular septum, and endocardial cushion. Cardiac muscle lacking ALK3 is specifically deficient in expressing TGFb2, an established paracrine mediator of cushion morphogenesis. In humans, congenital heart defects occur with a prevalence of at least 1% in newborns, and are even more common in death before term. Most frequent are defects in septation and the cardiac valves, and few single gene etiologies are known. The invariable defects in myocardium and AV cushion resulting from congenital deletion of ALK3 provide strong support for its assessment as a candidate gene in human congenital heart disease.

Standard name | BIOCARTA_AT1R_PATHWAY
Systematic name | M14899
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Angiotensin II mediated activation of JNK Pathway via Pyk2 dependent signaling
Full description | Ang II binding to AT1-R triggers the activation of Ca2+ signaling and PKC. The signal is then transmitted to the Pyk2 and further to the small G protein Rac1 but not Cdc42, although the direct activation of Rac1 by Pyk2 is not proved in this study. In turn, Rac1 activates a small G protein-activated kinase whose identity is still controversial, but one of which has been suggested to be PAK1. Finally, the JNK cascade, including MEKK1, SEK1, and JNK, is activated, causing induction of c-Jun gene via binding of ATF2 and c-Jun heterodimer to the junTRE2 site. Ang II is closely involved in the cardiac remodeling by stimulating synthesis of extracellular matrix proteins. It was recently found that expression of fibronectin by Ang II is transcriptionally regulated by AP-1 complex in cardiac fibroblasts. Collagenase gene containg AP-1 sites is also regulated by AP-1 components including c-Jun. AP-1 activity is also enhanced in Ang II-induced cardiac hypertrophy. Expression of ANF is regulated by AP-1 components.

Standard name | BIOCARTA_ACE2_PATHWAY
Systematic name | M12950
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Angiotensin-converting enzyme 2 regulates heart function
Full description | Cardiovascular diseases are predicted to be the most common cause of death worldwide by 2020. The major regulator of blood pressure homeostasis is the renin-angiotensis system. Angiotensinogen is digested by renin to produce angiotensin I (AGT I). AGT I is an inactive 10 amino-acid peptide that is further degraded to produce angiotensin II by the agiotensin-converting enzyme (ACE). Angiotensis II is the master regulator of blood pressure increase acting on the heart, kidneys and blood vessels. Angiotensin II causes direct constriction of the resistance vessels and stimulation of the adrenal cortex to increase blood volume and sodium absorption. In 2000, Tipnis et al., discovered ACE 2 a second carboxypeptidase that digests angiotensin. ACE is a di-peptidase, cleaving off 2 peptides from the c-terminal end of angiotensin. ACE 2 only cleaves 1 amino acid to produce angiotensin 1-9 (AGT 1-9) which has no identified function at this time. AGT 1-9 is not converted to angiotensin II but further degraded by ACE to AGT 1-7, a vasodilator. It would appear that ACE 2 inhibits the formation of angiotensin and reduces blood pressure increases. Crackower et al determined that ace2 -/- mice suffered significant heart defects at 6 months. Further deletion of ACE resulted in restored cardiac functions.

Standard name | BIOCARTA_ASBCELL_PATHWAY
Systematic name | M7298
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Antigen Dependent B Cell Activation
Full description | A key part of the immune system is the production of immunoglobulins (antibodies) by B cells to bind and inactivate specific foreign antigens. The body produces B cells with a wide range of antigen specificities in the immunoglobulin B cell receptor, one antigen specificity per cell. When the B cell receptor immunoglobulin binds antigen, that cell is activated to proliferate and create plasma cells secreting immunoglobulins to bind that specific antigen. B cell activation also creates memory cells with the same antigen specificity that do not actively secrete immunoglobulin but provide for rapid future immune responses to the same antigen. B cells are not activated by antigen on their own, but require interaction with helper CD4+ T cells to become activated and proliferate. The B cell first expresses immunoglobulin on the cell surface as the B cell receptor. If the B cell receptor immunoglobulin binds specific antigen, then the cell internalizes the antigen and presents it to T cells in MHC II, where it is recognized by the T cell receptor. In addition to the interaction between the T cell receptor and the B cell MHC-antigen, T cell interaction with the B cell involves additional positive and negative regulatory signals. CD40 interaction with CD40L and CD28 interaction with CD80 provide positive costimulatory signals that stimulate B cell activation and proliferation. T cell receptor activation induces expression of molecules like the CD40 ligand that modulate the B cell-T cell interaction. The CD40-CD40L interaction induces cytokine production and expression of other genes and alters the fate of the B cell involved in the interaction. If the interaction between CD40 and CD40L is prolonged, the B cell can be induced to become a memory cell rather than a plasma cell. Fas ligand binding to Fas between B and T cells may negatively modulate B cell activation, inducing apoptosis that limits B cell proliferation and activation. Cytokines like IL-2, IL-4 and IL-10 also play an important role in B cell activation.

Standard name | BIOCARTA_DNAFRAGMENT_PATHWAY
Systematic name | M7239
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Apoptotic DNA fragmentation and tissue homeostasis
Full description | Apoptotic cell death can be triggered by many different cellular stimuli, resulting in activation of apoptotic signaling pathways including caspases and mitochondria. A cellular response that is characteristic of apoptosis is fragmentation of the nuclear genome to create a nucleosomal ladder. This activity is conducted by multiple nucleases activated by apoptotic signaling pathways. One nuclease involved in apoptosis is DNA fragmentation factor (DFF), a caspase-activated DNAse (CAD). DFF/CAD is activated through cleavage of its associated inhibitor ICAD by caspases proteases during apoptosis. DFF/CAD interacts with chromatin components such as topo II and histone H1 to condense chromatin structure and perhaps recruit CAD to chromatin. Another apoptosis activated protease is endonuclease G, EndoG. EndoG is encoded in the nuclear genome but is localized to mitochondria in normal cells. EndoG may play a role in the replication of the mitochondrial genome, as well as in apoptosis. Apoptotic signaling causes the release of EndoG from mitochondria. Mitochondria are involved in apoptotic signaling in other ways as well, through the release of cytochrome c induced by Bid to activate the caspase protease cascade. These pathways are independent since the EndoG pathway still occurs in cells lacking DFF.

Standard name | BIOCARTA_CHEMICAL_PATHWAY
Systematic name | M3873
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Apoptotic Signaling in Response to DNA Damage
Full description | The cellular activation of the caspase cascade resulting in cell death is triggered by chemical damage to DNA which stimulates a sequence resulting in the cleavage of Bid in a manner similar to the binding of so called death-receptors or directly initiates the permeability transition of the mitochondrial membrane. The permiability transition releases several factors including cytochrome c, AIF and other factors in to the cytoplasm. Cytochrome c, a key protein in electron transport, is released from mitochondria in response to apoptotic signals, and activates Apaf-1, a protease released from mitochondria. Activated Apaf-1 activates caspase-9 and the rest of the caspase cascade. The caspases are a class of cysteine proteases that includes several representatives involved in apoptosis. The caspases convey the apoptotic signal in a proteolytic cascade, with caspases cleaving and activating other caspases that then degrade other cellular targets that lead to cell death.

Standard name | BIOCARTA_SPPA_PATHWAY
Systematic name | M8731
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Aspirin Blocks Signaling Pathway Involved in Platelet Activation
Full description | Activation of the protease-activated GPCRs in platelets contributes to platelet activation in clotting. The protease-activated receptors PAR1 and PAR4 are cleaved by the protease thrombin, releasing a tethered peptide ligand that activates the receptor and triggers intracellular calcium release. Platelets from mice lacking the PAR4 gene are not activated by thrombin and are impaired in clotting, supporting the importance of thrombin signaling through PAR4 in clotting. Human platelets express both PAR1 and PAR4, with PAR1 playing a more dominant role in clotting in humans. Calcium release induced by PARs activates PKC, modulating integrin alpha IIB beta 3 (glycoprotein IIb/IIIa) and opening integrin ligand binding sites to contribute to platelet aggregation. Intracellular calcium increases induced by thrombin activates phospholipase A2, liberating arachidonic acid, the first step in prostaglandin and thromboxane biosynthesis. Ras/Map kinase activation by the PAR receptors also activates phospholipase A2. The activation of PAR-induced platelet aggregation is inhibited by aspirin, indicating that thromboxane production induced by PAR signaling contributes to platelet activation. Arachidonic acid is converted to the prostaglandin PGG2 by the enzyme Cox-1 in platelets, and Cox-1 is inhibited by aspirin, reducing thromboxane A2 production by platelets. Thromboxane is a potent vasoconstrictor and platelet activator, so inhibition of Cox-1 in platelets by aspirin may explain some of the cardioprotective actions of aspirin.

Standard name | BIOCARTA_ATM_PATHWAY
Systematic name | M10628
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | ATM Signaling Pathway
Full description | The ataxia telangiectasia-mutated gene (ATM) encodes a protein kinase that acts as a tumor suppressor. ATM activation by ionizing radiation damage to DNA stimulates DNA repair and blocks progression through the cell cycle. Mutation of the ATM gene causes the disease ataxia telangiectasia which which involves an inherited predisposition to some cancers. To play this role ATM interacts with a broad network of proteins, including checkpoint factors (chk1, chk2), tumor suppressors (p53 and BRCA), DNA repair factors (RAD50, RAD51, GADD45), and other signaling molecules (c-Abl and NF-kB). In addition to regulating DNA repair and the cell cycle, ATM can also trigger apoptosis in radiation treated cells.

Standard name | BIOCARTA_AGPCR_PATHWAY
Systematic name | M19829
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Attenuation of GPCR Signaling
Full description | The G-protein coupled receptor (GPCR) family transduces extracellular signals across the plasma membrane, activating cellular responses through a variety of second messenger cascades. These receptors provide rapid responses to a variety of stimuli, and are often rapidly attenuated in their signaling. Failure to attenuate GPCR signaling can have dramatic consequences. One method to attenuate GPCR signaling is by removal of the stimulus from the extracellular fluid. At the synapse, removal of neurotransmitter or peptide signaling molecules is accomplished by either reuptake or degradation. Acetylcholine is removed from synapses through degradation by the enzyme acetylcholinesterase. Inhibition of acetylcholinesterase results in prolonged signaling at the neuromuscular junction, and uncontrollable spasms in humans caused by nerve gas or in insects by some insecticides. Inhibition of acetylcholinesterase is also used therapeutically to treat Alzheimer's disease, compensating for the loss of cholinergic neurons. Transporters for serotonin, dopamine, GABA and noradrenaline remove these neurotransmitters from the synapse to terminate signaling. Antidepressants such as Prozac inhibit reuptake of serotonin and many drugs of abuse such as cocaine act by blocking reuptake of dopamine or adrenaline. Reuptake not only terminates signaling, but can also conserve neurotransmitter through recycling back into the presynaptic cell. The next step in the attenuation of GPCR signaling is receptor desensitization, in which receptors are modified to no longer transduce a signal even if the stimulus is still present. Desensitization of GPCRs occurs through protein kinases that phosphorylate the GPCR to turn off signaling. Downstream protein kinases such as PKA and PKC turned on by GPCR signaling can phosphorylate the activated GPCR and other GPCRs to prevent further signaling. G-protein receptor kinases (GRKs) are a family of kinases that specifically phosphorylate only agonist-occupied GPCRs. GRKs attenuate GPCR signaling in concert with arrestins, proteins that bind GRK-phosphorylated GPCRs to disrupt interaction with G-protein and to terminate signaling. Reducing the number of receptor expressed on the cell surface can also attenuate receptor signaling. Many GPCRs are removed from the cell surface by receptor-mediated endocytosis when they are activated. Endocytosis of activated GPCRs appears to be stimulated by GRKs and arrestins. Once internalized, receptors can either be degraded in lysosomes or they can be recycled back to the cell surface.

Standard name | BIOCARTA_BCELLSURVIVAL_PATHWAY
Systematic name | M4835
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | B Cell Survival Pathway
Full description | Physical interactions between intergrin alpha4beta1 heterodimer expressed on B cells and counter receptors on stroma cells are key mediators of the survival of normal and malignant B cells. Recent data indicate that integrin stimulation increases FBI-1, XIAP, surviving, and CCT4 expression but inhibits Requiem, c-Fos, and caspase 3 and 7 induction.

Standard name | BIOCARTA_BLYMPHOCYTE_PATHWAY
Systematic name | M1473
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | B Lymphocyte Cell Surface Molecules
Full description | B cells must communicate with their environment to participate in the immune system as the source of antigen-specific immunoglobulins. Cell surface proteins on B cells receive signals from the exterior, adhere to other cells, and transmit signals to other cells. Antigen recognized by a B cell's immunoglobulin is presented in MHC Class II to T cells during B cell activation. Cell surface immunoglobulins are a key to B cell function, assisting in the response of B cells to specific antigen recognized by that cell's immunoglobulin. CD54 (ICAM-1) is an adhesion molecule involved in the binding of B cells to other cell types and LFA-1 is an integrin adhesion protein with two subunits that binds to ICAM. CD35 and CD21 are receptors for complement factors that stimulate the B cell response when complement is activated. CD80 and CD40 bind to T cell proteins (CD28 and CD40L, respectively) to provide costimulatory signals in the B cell-T cell interaction required for B cell activation. CD45 is a protein tyrosine phosphatase that regulates activation of B cells and T cells through dephosphorylation of signaling factors. CD32 is a receptor for IgG Fc, and is also called FcgammaRII. The number of proteins on the surface of B cell proteins indicates the complexity of regulation of B cell activation.

Standard name | BIOCARTA_BCR_PATHWAY
Systematic name | M9494
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | BCR Signaling Pathway
Full description | Significant progress has been made towards delineation of the intrinsic molecular processes that regulate B lymphocyte immune function. Recent observations have provided a clearer picture of the interactive signaling pathways that emanate from the mature B cell antigen receptor (BCR) complex and the different precursor complexes that are expressed during development. Studies have also revealed that the net functional response to a given antigenic challenge is affected by the combined action of BCR-dependent signaling pathways, as well as those originating from various coreceptors expressed by B cells (e.g. CD19, CD22, FcgRIIb and PIR-B). It is now well established that reversible tyrosine phosphorylation plays an important role in regulating B cell biology. In particular, binding of antigen to the BCR promotes the activation of several protein tyrosine kinases (PTK) that, in conjunction with protein tyrosine phosphatases (PTP), alter the homeostasis of reversible tyrosine phosphorylation in the resting B cell. The net effect is a transient increase in protein tyrosine phosphorylation that facilitates the phosphotyrosine dependent formation of effector protein complexes, promotes targeting of effector proteins to specific microenvironments within the B cell and initiates the catalytic activation of downstream effector proteins. Studies have demonstrated that Src family PTKs are activated initially and serve to phosphorylate CD79a and CD79b thereby creating phosphotyrosine motifs that recruit downstream signaling proteins. In particular, phosphorylation of the BCR complex leads to the recruitment and activation of the PTK Syk, which in turn promotes phosphorylation of PLCg, Shc and Vav. Additionally, the Tec family member Btk is recruited to the plasma membrane where it is involved in activation of PLCg. Initiation of B lymphocyte activation is dependent on the tyrosine phosphorylation-dependent formation of multi-molecular effector protein complexes that activate downstream signaling pathways. The formation of such complexes was initially hypothesized to occur primarily via effector protein binding to the BCR complex itself. However, recent studies have demonstrated that productive signaling via the BCR is in fact dependent on tyrosine phosphorylation of one or more adapter proteins that play a crucial role in recruitment and organization of effector proteins at the plasma membrane. The SLP-65/BLNK adapter protein has recently been shown to play a crucial role in recruitment and activation of key signal transducing effector proteins in the B cell. After the BCR has been engaged by antigen and the activation response has been initiated, numerous second messengers and intermediate signal transducing proteins are activated. These include the production of lipid second messengers by phosphatidylinositol 3-kinase, and the PLC-dependent hydrolysis of phosphatidylinositol 4,5-bisphosphate to yield diacylglycerol and 1,4,5-inositoltrisphosphate (IP3). DAG is important for activation of PKC whereas IP3 promote release of calcium from the endoplasmic reticulum and the subsequent influx Ca2+ from the extracellular space. Numerous intermediate signaling proteins are also activated including the Ras and Rap1, which are small molecular weight GTPases and these ultimately lead to the activation of MAP kinases including Erk, JNK and p38. The net effect of second messenger production and activation of intermediate signaling proteins is the concerted regulation of several transcription factors that mediate gene transcription in the B cell.

Standard name | BIOCARTA_BIOPEPTIDES_PATHWAY
Systematic name | M13494
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Bioactive Peptide Induced Signaling Pathway
Full description | Many different peptides act as signaling molecules, including the proinflammatory peptide bradykinin, the protease enzyme thrombin, and the blood pressure regulating peptide angiotensin. While these three proteins are distinct in their sequence and physiology, and act through different cell surface receptors, they share in a common class of cell surface receptors called G-protein coupled receptors (GPCRs). Other polypeptide ligands of GPCRs include vasopressin, oxytocin, somatostatin, neuropeptide Y, GnRH, leutinizing hormone, follicle stimulating hormone, parathyroid hormone, orexins, urotensin II, endorphins, enkephalins, and many others. GPCRs are a broad and diverse gene family that respond not only to peptide ligands but also small molecule neurotransmitters (acetylcholine, dopamine, serotonin and adrenaline), light, odorants, taste, lipids, nucleotides, and ions. The main signaling mechanism used by GPCRs is to interact with G-protein GTPase proteins coupled to downstream second messenger systems including intracellular calcium release and cAMP production. The intracellular signaling systems used by peptide GPCRs are similar to those used by all GPCRs, and are typically classified according to the G-protein they interact with and the second messenger system that is activated. For Gs-coupled GPCRs, activation of the G-protein Gs by receptor stimulates the downstream activation of adenylate cyclase and the production of cyclic AMP, while Gi-coupled receptors inhibit cAMP production. One of the key results of cAMP production is activation of protein kinase A. Gq-coupled receptors stimulate phospholipase C, releasing IP3 and diacylglycerol. IP3 binds to a receptor in the ER to cause the release of intracellular calcium, and the subsequent activation of protein kinase C, calmodulin-dependent pathways. In addition to these second messenger signaling systems for GPCRs, GPCR pathways exhibit crosstalk with other signaling pathways including tyrosine kinase growth factor receptors and map kinase pathways. Transactivation of either receptor tyrosine kinases like the EGF receptor or focal adhesion complexes can stimulate ras activation through the adaptor proteins Shc, Grb2 and Sos, and downstream Map kinases activating Erk1 and Erk2. Src kinases may also play an essential intermediary role in the activation of ras and map kinase pathways by GPCRs.

Standard name | BIOCARTA_RANKL_PATHWAY
Systematic name | M2602
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Bone Remodelling
Full description | Bone density and structure is maintained through a balance of bone resorption by osteoclasts and bone deposition by osteoblasts. The combination of simultaneous resorption and deposition creates continual remodeling of bone while excess osteoclast activity leads to an imbalance and a loss of bone density, causing osteoporosis. RANK (receptor activator of NF-kB ligand) is a receptor in the TNF receptor gene family that is involved in osteoclast differentiation. RANK-ligand, also called osteoprotegerin-ligand, binds to RANK, induces receptor dimerization, and activates downstream signaling. Osteoprotegerin is a decoy receptor for RANK-ligand that suppresses osteoclast activity and bone remodeling, helping to maintain balanced bone remodeling. RANK-ligand and osteoprotegerin are produced by osteoblasts and some factors regulate osteoclast activity indirectly through their action on the expression of these factors by osteoblasts. Binding of RANK-ligand to RANK activates signaling through TRAF-6. TRAF-6 induces several downstream signaling events, including activation of NF-kB, c-Fos and the kinase JNK1. Jnk-1 activation contribute to fos activation by RANK-ligand and may be involved in the modulation of RANK-ligand by other factors such as estrogen. Mice lacking the c-Fos gene have overly dense bone and decreased bone resorption due to reduced osteoclast differentiation, indicating that c-Fos is an important mediator of osteoclast differentiation. One of the results of c-Fos induction is transcriptional activation of interferon-beta. Interferon-beta binds to its receptor on neighboring osteoclast precursor cells to block RANK-ligand signaling and down-regulate c-Fos expression, inhibiting further osteoclast differentiation. Mice lacking interferon-beta or the interferon-beta receptor lose bone due to uncontrolled osteoclast activity, demonstrating the importance of this mechanism in vivo. Interferon-beta signaling could be used as a mechanism to prevent osteoporosis and other conditions involving excessive osteoclast resorption of bone.

Standard name | BIOCARTA_CACAM_PATHWAY
Systematic name | M3412
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Ca++/ Calmodulin-dependent Protein Kinase Activation
Full description | The calcium/calmodulin-dependent kinases (CaMKs) are involved in a large number of cellular responses induced by hormones, neurotransmitters and other signalling. Elevation of calcium functions as a major second messenger, where the intracellular concentration of calcium can be maintained at extremely low levels and susequently increased following specific calcium-mobilizing stimuli. There are many buffers to the calcium fluxuations including membrane pumps and calcium-binding proteins that create discrete spatial control of its effectors and their targets. The current family of multifunctional calcium/calmodulin (CaM)-dependent protein kinases (CaMKs) consists of CaMKI, CaMKII and CaMKIV. These kinases translate and co-ordinate the calcium fluxuations into the appropriate cellular responses via phosphorylation. These kinases are partially regulated by the intracellular calcium receptor calmodulin (CaM), have common as well as unique features in their structure, regulation and activation. CaMKII, CaMKI and CaMKIV, have an autoregulatory domain that restricts or inhibits enzymic activity in the absence of calcium/CaM. Calcium/CaM binding alone produces maximal activity of CaMKII, whereas CaMKI and CaMKIV have an activation loop that requires phosphorylation of a threonine residue by CaMK kinase (CaMKK) for maximal activity. Two genes (alpha and beta) for CaMKK, which is also regulated by CaM, have been identified. The highest expression of these isoforms occurs in the brain but the activity of the CaMKs has been identified in most cell types. CaMKIV has a post-calmodulin autophosphorylation step that is not observed in CaMKI. The CaMKII multimer can autophosphorylate either the autoregulatory domain or the CaM-binding domain, producing diverse effects in its regulation and sensitivity to Calcium/CaM. Autophosphorylation of CaMKII can produce Calcium/CaM- independent activity (autonomous activity), without affecting its maximal Calcium/CaM-stimulated activity. The CaMKII autophosphorylation involves a kinase cascade of sorts, with each subunit of the multimeric enzyme acting as both kinase and kinase kinase. Autophosphorylation establishes a 1000-fold increase in the affinity for its activator Calcium/CaM (also known as CaM trapping); however, autophosphorylation within the CaM-binding domain following CaM dissociation of activated/autophosphorylated enzyme restricts or prevents CaM from rebinding (CaM capping). The mechanisms and consequences of autophosphorylation are central to the CaMKII enzyme's complex regulatory behavior enabling it to become differentially activated at different frequencies and levels of calcium spikes. The target proteins for the CaMKs are very similar. An example target of the CaMKs is the transcriptional activating protein CREB. The phosphorylation states of CREB after CaMK phosphorlyation differ by the additional phosphorylation of CREB at serine 142 that functions as an additional inhibitory site. This difference appears to be the result of adjacent amino acids.

Standard name | BIOCARTA_CDMAC_PATHWAY
Systematic name | M4388
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cadmium induces DNA synthesis and proliferation in macrophages
Full description | Exposure to divalent cadmium ions (Cd2+) is a known cancer risk factor, but the molecular mechanisms responsible for the inappropriate induction of cellular proliferation by cadmium are still being figured out. One cellular model used to study this process is macrophages grown in culture. In cultured macrophages, cadmium acts both at the cell surface and in the cytoplasm to induce proliferation. At the cell surface, cadmium interacts with a pertussis-sensitive cell surface receptor, probably a Gi-coupled GPCR, to stimulate proliferation. Cadmium can enter cells through calcium ion channels and once in cells affects calcium release by the ER. In addition to changes in intracellular calcium, the proliferative effects of cadmium are mediated by the Ras/Map kinase pathway, and also NF-kB. Inhibition of phospholipase C, map kinases, or NF-kB with a variety of pharmacological inhibitors all blocked the activation of cellular proliferation by cadmium. Protein kinase C is also activated by cadmium, upstream of the Map kinase pathway. Changes in transcription induced by cadmium include induction of immediate early genes like fos, jun, and myc. In addition to inducing cellular proliferation, cadmium also is slightly genotoxic due to inhibition of DNA repair, activates stress genes, and inhibits the immune system. The immuno-modulatory effects observed with cadmium treatment may also involvement transcriptional disregulation, including the expression of cytokines such as IL-4, IL-10, and TNF-alpha. Although macrophages have been used for many studies, other cell types are also the target of cadmiums toxicity.

Standard name | BIOCARTA_CARM_ER_PATHWAY
Systematic name | M2499
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | CARM1 and Regulation of the Estrogen Receptor
Full description | Several forms of post-translational modification regulate protein activities. Recently, protein methylation by CARM1 (coactivator-associated arginine methyltransferase 1) has been observed to play a key role in transcriptional regulation. CARM1 associates with the p160 class of transcriptional coactivators involved in gene activation by steroid hormone family receptors. CARM1 also interacts with CBP/p300 transcriptional coactivators involved in gene activation by a large variety of transcription factors, including steroid hormone receptors and CEBP. One target of CARM1 is the core histones H3 and H4, which are also targets of the histone acetylase activity of CBP/p300 coactivators. Recruitment of CARM1 to the promoter region by binding to coactivators increases histone methylation and makes promoter regions more accessible for transcription. Another target of CARM1 methylation is a coactivator it interacts with, CBP. Methylation of CBP by CARM1 blocks CBP from acting as a coactivator for CREB and redirects the limited CBP pool in the cell to be available for steroid hormone receptors. Other forms of post-translational protein modification such as phosphorylation are reversible in nature, but as of yet a protein demethylase is not known. The methylation activity of CARM1 modulates the activity of specific transcriptional regulators. CARM1 acts as a coactivator for the myogenic transcription factor Mef2c, and is necessary for normal muscle cell differentiation. The estrogen receptor is another transcription factor that uses CARM1 as one of several coactivators, acting synergistically with CBP through the Grip1 member of the p160 family of coactivators. The interaction of estrogen receptor with various ligand-dependent coactivators may produce the tissue selective response of some estrogen receptor ligands like tamoxifen.

Standard name | BIOCARTA_CASPASE_PATHWAY
Systematic name | M17902
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Caspase Cascade in Apoptosis
Full description | Apoptosis, programmed cell death, is triggered by a variety of stimuli, including cell surface receptors like FAS, mitochondrial response to stress, and cytotoxic T cells. Caspases are a class of cysteine proteases that includes several representatives involved in apoptosis. The caspases convey the apoptotic signal in a proteolytic cascade, with caspases cleaving and activating other caspases that then degrade other cellular targets that lead to cell death. The caspases at the upper end of the cascade include caspase-8 and caspase-9. Caspase-8 is the initial caspase involved in response to receptors with a death domain like FAS. The mitochondrial stress pathway begins with the release of cytochrome c from mitochondria, which then interacts with Apaf-1, causing self-cleavage and activation of caspase-9. Caspase-3, -6 and-7 are downstream caspases that are activated by the upstream proteases and act themselves to cleave cellular targets. Granzyme B and perforin proteins released by cytotoxic T cells induce apoptosis in target cells, forming transmembrane pores, and triggering apoptosis, perhaps through cleavage of caspases, although caspase-independent mechanisms of Granzyme B mediated apoptosis have been suggested.

Standard name | BIOCARTA_CBL_PATHWAY
Systematic name | M16973
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | CBL mediated ligand-induced downregulation of EGF receptors
Full description | As with many cell-surface receptors, activation of the EGF receptor can result in receptor internalization through receptor-mediated endocytosis, desensitizing further receptor signaling. This process requires clathrin and occurs in clathrin-coated pits, which pinch off from the plasma membrane to form vesicles that move to the early endosome. From the early endosome, receptors can either be recycled back to the cell surface, or they can move through the late endosome to the lysosome for proteolytic degradation. The sorting of receptors in the early endosome for degradation requires the tyrosine kinase activity of activated growth factor receptor, and involves ubiquitination of the receptor. Targeting of receptors for degradation requires members of the Cbl gene family. Cbl proteins bind to tyrosine phosphorylated EGF receptor, and are E3 ubiquitination ligases that label receptor for degradation. Cbl also recruits Cin85 to the receptor complex, and blocking Cin85 interaction blocks receptor internalization and degradation. Endophilins are also a member of this receptor-bound protein complex. In its role as a ubiquitin ligase and docking protein, Cbl desensitizes EGF signaling and also opposes cellular proliferation induced by EGF. EGF activation also appears to activate the tyrosine kinase Src, which phosphorylates Cbl, and helps to activate the ubiquitination and degradation of EGF receptor. PKC activation and threonine phosphorylation of the EGF receptor can induce heterologous receptor internalization, but opposes Cbl-mediated receptor degradation. PKC phosphorylated receptors are sorted for recycling to the cell surface, and directed away from the late endosome and proteosome. Other growth factor receptors are regulated in a similar manner, including the PDGF receptor, HGF receptor and the CSF-1 receptor, indicating that this is a fairly general regulatory mechanism. The importance of Cbl in the down-regulation of growth factor signaling means that it will have an important role in cellular transformation and the development and treatment of cancer.

Standard name | BIOCARTA_CCR3_PATHWAY
Systematic name | M9152
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | CCR3 signaling in Eosinophils
Full description | Eosinophils are a key class of leukocytes involved in inflammatory responses, including allergic reactions in skin and airway. The eosinophil response in inflammation is absent in mice lacking CCR3, indicating the key role of this G protein coupled receptor in inflammation and allergic responses. Eotaxin is a chemokine ligand for CCR3 that recruits eosinophils to the site of inflammation and activates them. Other chemokine ligands of CCR3 include eotaxin-2, MCP-3, MCP-4, and RANTES. Multiple signaling pathways activated by CCR3 participate in the inflammatory response of eosinophils. Eotaxin stimulates intracellular calcium release, production of reactive oxygen species, and changes in actin polymerization through a pertussis sensitive pathway. Rho and ROCK regulate actin stress fiber formation and are required for eosinophil chemotaxis. Rho is a G protein that activates ROCK, a protein kinase. Map kinase pathways are also involved in chemotaxis. Another key action of activated eosinophils is the release of reactive oxygen species, causing tissue damage during chronic inflammatory responses. Blocking eosinophil activation and the signaling pathways that lead to chemotaxis, degranulation and reactive oxygen release may alleviate inflammatory conditions and inflammation-associated tissue damage.

Standard name | BIOCARTA_CD40_PATHWAY
Systematic name | M16697
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | CD40L Signaling Pathway
Full description | The CD40 receptor was first associated with expression in B cells and the role it plays through its ligand CD40L (CD154) in moderating T cell activation. Broader expression may indicate a broader role for CD40 and CD40L in immune function and disease states such as transplant rejection and HIV infection. Disruption of CD40 interaction with CD40L may prove therapeutic in the treatment of autoimmune disorders or heart disease and modulation of the interaction may in the future be exploited in cancer treatment. As a member of the TNF receptor family, CD40 relies on interaction with TRAF proteins to mediate an intracellular signal in response to CD40L binding. The pathway downstream of TRAFs activates the transcription factor NF-kappaB through a kinase pathway involving map kinases, NIK (NF-kappaB inducing kinase) and I-kappa B kinases. Some CD40 responses like regulation of immunoglobulin expression might be mediated by NF-kappaB transcriptional activation.

Standard name | BIOCARTA_MCM_PATHWAY
Systematic name | M6682
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | CDK Regulation of DNA Replication
Full description | Initiation of DNA replication in eukaryotes is a highly conserved, multi-step process (replication licensing) designed to restrict initiation events to once per replication origin per S phase. Its control has been uncovered by the discovery of the cyclin dependent kinases (CDKs) as master regulators of the cell cycle and the initiator proteins of DNA replication, such as the Origin Recognition Complex (ORC), Cdc6/18, Cdt1 and the mini-chromosome maintenance complex (Mcm). The proteins and the sequence of events involved in this process are conserved throughout the eukaryotic kingdom. First, the ORC comprised of six proteins binds to replication origins in the chromosomal DNA. At the end of mitosis, ORC, Cdc6/18 and Cdt1 assist the binding of Mcm proteins 27 to chromatin, and chromatin becomes licensed for replication. The activated Mcm complex functions as a replicating helicase and moves along with the replication fork to bring the origins to the unlicensed state. The cycling of CDK activity in the cell cycle regulates the two states of replication origins, the licensed state in G1-phase and the unlicensed state for the rest of the cell cycle. The restriction on licensing is relieved when CDK falls off at the completion of mitosis to allow a new round of replication.

Standard name | BIOCARTA_G1_PATHWAY
Systematic name | M648
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cell Cycle: G1/S Check Point
Full description | The G1/S cell cycle checkpoint controls the passage of eukaryotic cells from the first 'gap' phase (G1) into the DNA synthesis phase (S). Two cell cycle kinases, CDK4/6-cyclin D and CDK2-cyclin E, and the transcription complex that includes Rb and E2F are pivotal in controlling this checkpoint. During G1 phase, the Rb-HDAC repressor complex binds to the E2F-DP1 transcription factors, inhibiting the downstream transcription. Phosphorylation of Rb by CDK4/6 and CDK2 dissociates the Rb-repressor complex, permitting transcription of S-phase genes encoding for proteins that amplify the G1 to S phase switch and that are required for DNA replication. Many different stimuli exert checkpoint control including TGFb, DNA damage, contact inhibition, replicative senescence, and growth factor withdrawal. The first four act by inducing members of the INK4 or Kip/Cip families of cell cycle kinase inhibitors. TGFb additionally inhibits the transcription of Cdc25A, a phosphatase that activates the cell cycle kinases. Growth factor withdrawal activates GSK3b, which phosphorylates cyclin D, leading to its rapid ubiquitination and proteosomal degradation. Ubiquitination, nuclear export, and degradation are mechanisms commonly used to rapidly reduce the concentration of cell-cycle control proteins.

Standard name | BIOCARTA_G2_PATHWAY
Systematic name | M8560
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cell Cycle: G2/M Checkpoint
Full description | The G2/M DNA damage checkpoint prevents the cell from entering mitosis (M phase) if the genome is damaged. The Cdc2-cyclin B kinase is pivotal in regulating this transition. During G2 phase, Cdc2 is maintained in an inactive state by the kinases Wee1 and Mt1. As cells approach M phase, the phosphatase Cdc25 is activated, perhaps by the polo-kinase Pik1. Cdc25 then activates Cdc2, establishing a feedback amplification loop that efficiently drives the cell into mitosis. DNA damage activates the DNA-PK/ATM/ATR kinases, initiating two parallel cascades that inactivate Cdc2-cyclin B. The first cascade rapidly inhibits progression into mitosis: the CHK kinases phosphorylate and inactivate Cdc25, which can no longer activate Cdc2. The second cascade is slower. Phosphorylation of p53 dissociates it from MDM2, activating its DNA binding activity. Acetylation by p300/PCAF further activates its transcriptional activity. The genes that are turned on by p53 constitute effectors of this second cascade. They include 14-3-3s, which binds to the phosphorylated Cdc2-cyclin B kinase and exports it from the nucleus; GADD45, which apparently binds to and dissociates the Cdc2-cyclin B kinase; and p21Cip1, an inhibitor of a subset of the cyclin-dependent kinases including Cdc2 (CDK1).

Standard name | BIOCARTA_CELL2CELL_PATHWAY
Systematic name | M12851
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cell to Cell Adhesion Signaling
Full description | Interactions between cells responsible for cell to cell adhesion also can communicate signals into the cellular interior, often involving interactions with cytoskeletal elements to produce changes in cell motility, migration, proliferation and shape. The cadherins are cell surface adhesion molecules that help form tight junctions between cells such as formation of epithelial cell layers. E-cadherin inactivation has been implicated in cancer development. In addition to mediating adhesion with other cells, cadherins transduce signals into cells through interactions with the catenins. Catenins probably affect actin cytoskeletal function through interactions with proteins like actinin and vinculin. Catenins also probably trigger changes in cell shape and motility with signals through the Rho small GTPases. Another important cell adhesion molecule is CD-31, or PECAM-1, involved in the formation of junctions between endothelial cells, cell migration, migration of lymphocytes, and regulation of lymphocyte activation. Src phosphorylates PECAM-1 on tyrosine residues causing SHP-2 association with PECAM-1. Paxillin acts as an adaptor protein between proteins involved in adhesion signaling like FAK and src and cytoskeletal elements. In addition to signals created by adhesion molecules to alter cellular responses, other signaling pathways can alter adhesion through components of the focal adhesion complex.

Standard name | BIOCARTA_LAIR_PATHWAY
Systematic name | M3952
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cells and Molecules involved in local acute inflammatory response
Full description | Inflammation has several distinct components, including the localized response at the site of tissue injury or infection. Tissue injury stimulates the release of inflammatory signaling molecules such as bradykinin. Bacterial infection stimulates an immune response in several ways. Bacteria that are phagocytosed can activate macrophages, causing the release of inflammatory cytokines such as IL-1, TNF, and IL-6. Bacteria can also activate the complement cascade through either the antibody-mediated pathway (classical pathway) or the alternative complement pathway. In extravascular tissues, cells that respond to infection or injury include macrophages and mast cells. Macrophages and other immune cells secrete chemokines that recruit leukocytes from the circulation to the site of inflammation. Mast cells release histamine, prostaglandins, and leukotrienes that act as chemokines, increase vascular permeability, and act on the vascular endothelium to increase tissue recruitment of leukocytes. Chemokines can recruit leukocytes or lymphocytes out of the blood stream into tissues and make blood vessels more permeable. Leukocytes are activated by inflammatory signals to express adhesion molecules that cause them to interact with the vascular endothelium, penetrate the endothelial wall and migrate into the extracellular space of tissues. The combined response of immune cells and signaling molecules at the site of inflammation induces swelling, activation of immune cells, and clearance of potential infectious agents. Chronic inflammation can however also lead to tissue damage in conditions such as arthritis, in which anti-inflammatory drugs act on various steps in inflammation to prevent disease.

Standard name | BIOCARTA_CERAMIDE_PATHWAY
Systematic name | M19943
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Ceramide Signaling Pathway
Full description | Over 1,000 papers and reviews have been written about the role of ceramide in the production of programmed cell death or apoptosis. Ceramide is a sphingosine-based lipid-signaling molecule involved in the regulation of cellular differentiation, proliferation, and apoptosis. This diagram represents some of the current understanding of the cascades that couple ceramide to specific signaling pathways. These cascades illustrate that ceramide can be a growth stimulus or proapototic signal. The ultimate ceramide action is determined within the context of other stimuli and by the subcellular topology of its production and is cell-type specific. There are 2 forms of sphingomyelinase, acid (acid-sphingomyelinase:A-SMase) and neutral (neutral-sphingomyelinase N-SMase), that can produce ceramide. TNF-alpha can stimulate either form of sphingomyelinase as can other death receptors. Different domanis of TNF-alpha stimulate the different Smases. N-SMase stimulation is enhanced by the receptor for activated-C kinase 1 (RACK1). The activity of each form is dependent on the local intracellular pH. In the illustration the forms are seperated to reduce confusion however ceramide produced by either method can stimulate either cascade depending on the presence of specific co-factors and activators. A-SMase has been recognized as one of the required molecules to mediate proapoptotic signalling in cell death induced by a diverse array of stresses such as H2O2, Heat, UV exposure and Radiation. ROS generation in mitochondria activates caspase-3 via cooperation of cytochrome c, Aif and caspase-9 and stimulates or increases ceramide generation through A-SMase in a proaptotic activation cycle. Caspase-3 further increases its own activation by proteolytically cleaving ceramide inhibited catalase which is an inhibitor of ROS generation. Ceramide-activated protein kinase(CARK) also known as Kinase Supressor of RAS (KSR) activity is in some cases the switch point in the balance between proapoptotic and antiapoptotic signals and is also cell-type specific. In endothelial cells for example the activation of KSR is required for apoptosis. In contrast in epithelial cells activation of KSR is required for cell proliferation. An additional switch point is the availability of Bad in the cell. Activation of KSR leads to further mitocondrial stimulation or association with RAS and activation of the Raf1 cascade leading to proliferation or differentiation.

Standard name | BIOCARTA_TID_PATHWAY
Systematic name | M9546
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Chaperones modulate interferon Signaling Pathway
Full description | Signaling by interferon-gamma stimulates anti-viral responses and tumor suppression through the heterodimeric interferon-gamma receptor. Signaling is initiated by binding of interferon-gamma to its receptor, activating the receptor-associated JAK2 tyrosine kinase to phosphorylate STAT transcription factors that activate interferon responsive genes. Molecular chaperones that modulate or alter protein folding interact with different components of the interferon signaling pathway. One chaperone that modulates interferon signaling is hTid-1, a member of the DnaJ family of chaperones and a cochaperone for the heat shock protein Hsp70, another molecular chaperone. hTid-1 was found in a two-hybrid screen to bind to JAK2 and also to interact with the interferon-gamma receptor. In addition, hTid-1 and JAK2 also interact with Hsp70. Overexpression of hTid-1 represses transcriptional activation by interferon-gamma and Hsp70 dissociates from these proteins when interferon is added to cells, suggesting that Hsp70 holds Jak2 in an inactive conformation prior to ligand activation, and is released in the presence of agonist to allow the activation of Jak-2 and downstream pathways. hTid-1 and Hsp-70 interact with other signaling proteins as well. One of this is Tax, a protein encoded by the HTLV-1 virus that binds to hTid-1. hTid-1 also represses NF-kB activation by blocking the phosphorylation and inactivation of I-kappaB by the IkappaB kinase beta. Hsp70 plays a significant role in protein unfolding for entry into mitochondria and also interacts with tumor suppressor gene products to produce their anti-proliferative activity. One of the actions of interferon is to induce apoptosis of infected target cells, in part through a mitochondrial dependent mechanism. An interaction between interferon signaling and Hsp70 may alter this mitochondrial apoptosis pathway, perhaps playing a role in interferon-mediated apoptosis of infected or transformed cells. The HTLV-1 Tax protein that interacts with Hsp70 blocks mitochondrial induced apoptosis, providing a protection against interferon-mediated cellular defenses.

Standard name | BIOCARTA_CLASSIC_PATHWAY
Systematic name | M7146
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Classical Complement Pathway
Full description | The complement system is part of the defense against invading cells and is composed of about twenty different proteins found in the plasma. When activated, complement proteins form a pathway of proteolytic reactions that culminates in the lysis of foreign cells. The complement system also stimulates phagocytosis of foreign cells and an inflammatory response. There are two different complement systems, the classical complement pathway initiated by antibody complexes on the cell surface, and an alternative complement pathway that is initiated without antibodies. The complement system proteins are named with a capital C followed by a number. A small letter after the number indicates that the protein is a smaller protein resulting from the cleavage of a larger precursor by a protease. In the classical pathway, the first step is the initiation of the pathway triggered by recognition by complement factor C1 of antigen-antibody complexes on the cell surface. When C1 complex interacts with aggregates of IgG with antigen on a cell's surface, two C1-associated proteases, C1r and C1s, are activated. Other factors like lipopolysaccharide also activate C1s. Once C1s is activated, it cleaves C4 to form C4b that then binds to the cell membrane of the cell being attacked. The proteolytic complement cascade is then amplified on the cell membrane through sequential cleavage of complement factors and recruitment of new factors until a cell surface complex containing C5b, C6, C7, and C8 is formed. The addition of a multiple C9 proteins creates the membrane attack complex results in a large pore that spans the membrane of the cell being attacked, allowing ions to flow freely between the cellular interior and exterior. Ions flow out, but large molecules stay in, causing water to flood into the cell and ultimately burst the cell from osmotic pressure.

Standard name | BIOCARTA_COMP_PATHWAY
Systematic name | M917
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Complement Pathway
Full description | The complement pathway consists of a series of over thirty proteins in plasma that are part of the immune response. Activation of the complement system lyses bacterial cells, forms chemotactic peptides (C3a and C5a) attracting immune cells, and increases phagocytotic clearance of infecting cells. Complement can also increase the permeability of vascular walls and cause inflammation. Most complement proteins exist in plasma as inactive precursors that cleave and activate each other in a proteolytic cascade in response to three different mechanisms by which the complement system is activated, the classical pathway, the alternative pathway and the lectin-induced pathway. These three systems are distinct in the initiation of the proteolytic cascade but share most of their components and all three converge in the creation of a C3 convertase that cleaves the C3 complement protein, leading ultimately to the formation of the membrane attack complex, MAC, a pore causing lysis of cells. The classical pathway is activated by the recognition of foreign cells by antibodies bound to the surface of the cells. The alternative and lectin-induced pathways are both antibody independent. Proteolysis is triggered in the alternative pathway by the spontaneous activation of C3 convertase from C3 and is triggered in the lectin-induced pathway by the recognition of carbohydrates on the bacterial cell surface by mannan-binding protein, Mbp. In addition to providing a key part of the response to bacterial infection, the complement system can be involved in the response to fungi, viruses and protists. While activation of the complement system is a key part of the immune system, it must also be kept in check to prevent inappropriate or exaggerated responses. Twelve different proteins have been identified that inhibit complement activation to control the system, including Factor H, Factor I and C1 inhibitor. Deficiencies in components of the complement system have been identified in humans that cause a variety of immune related disorders. C3 deficiency is associated with recurrent bacterial infections, while a lack of C2 can cause antibody-antigen complexes to accumulate and cause the autoimmune disorder systemic lupus erythematosus. People lacking C1 inhibitor have also been identified and found to be prone to uncontrolled complement activation and dangerous swelling through production of C3a and C5a anaphylotoxins.

Standard name | BIOCARTA_VDR_PATHWAY
Systematic name | M13404
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Control of Gene Expression by Vitamin D Receptor
Full description | The vitamin D receptor, VDR is the mediator of all genomic actions of vitamin D3 and its analogs. It belongs to a family of ligand induced transcription factors, nuclear receptors (NRs). Vitamin D3 is the main regulator of calcium homeostasis and is critical in bone formation. It is also involved in controlling cellular growth, differentiation and apoptosis, which makes synthetic vitamin D3 analogues interesting for therapy of such diseases as cancer and psoriasis. NRs are comprised of: an amino-terminal activation function domain AF-1; the DNA-binding domain; a hinge region; and a carboxy-terminal ligand-binding domain containing a second activation function, AF-2. VDR acts primarily as a heterodimer with the retinoid X receptor (RXR) on vitamin D response elements (VDREs). It interacts with the transcription machinery and nuclear receptor coactivators or corepressors to regulate target gene activity. NRs coregulators can be divided into 3 major classes: 1)ATP-dependent chromatin remodeling complexes that are involved in the location and association of nucleosomes with DNA; 2) Enzymes that catalyze modifications of histone tails to regulate histone-histone and histone-DNA interactions 3) General transcription factors adaptors that bridge the functions between regulators and basal transcription factors. A novel multifunctional ATP-dependent chromatin remodeling complex c WINAC directly interacts with the vitamin D receptor. It contains BRG1 or hBRM as ATPase subunits as all SWI/SNF complexes do, but it also has subunits associated with DNA replication (TopoII_ and CAF-1p150) and transcript elongation through nucleosomes (FACTP140) not found before in SWI/SNF complexes. WINAC also contains the Williams syndrome transcription factor (WSTF). WSTF appears to function as a platform protein for the assembly of components in WINAC, and it interacts directly with the vitamin D receptor in a ligand-independent manner. WINAC and vitamin Dreceptor are targeted to vitamin D responsive promoters in the absence of ligand to both positively and negatively regulated genes. WINAC may rearrange the nucleosome array around the positive and negative VDREs, thereby facilitating the coregulatory complexes access for further transcription control. Upon ligand binding, two HAT complexes, p160/CBP and TRRAP/PCAF, coactivate the NR function. The p160 proteins (SRC protein family) interact directly with an NR activation surface AF2 and serve as platforms for the recruitment of histone-modifying enzymes, including CBP/p300 and methyltransferases. The SRC/p160 family members SRC-1 and p/CIP, as well as CBP and p300 contain intrinsic histone acetyltransferase activity(HAT). Both the HAT activity and the histone methyltransferase activity may cooperate in histone modification and facilitate nucleosome remodeling and recruitment of transcriptional machinery. A third group of coactivators is represented by thyroid receptor-associated proteins (TRAP)/vitamin D receptor-interacting proteins (DRIP). This complex may play a role by directly contacting the basal transcriptional machinery. As the VDR/RXR heterodimer also represses transcription in a ligand-dependent manner through negative VDRE (nVDRE), a number of corepressor proteins such as NCoR and ALIEN may also be recruited to the surface of the receptor. They, too function as platforms but serve to recruit enzymes such as histone deacetylases. WINAC association with VDR facilitates targeting of a putative corepressor complex to the nVDRE

Standard name | BIOCARTA_HDAC_PATHWAY
Systematic name | M1547
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Control of skeletal myogenesis by HDAC & calcium/calmodulin-dependent kinase (CaMK)
Full description | The differentiation of muscle cells is transcriptionally regulated, in part by the myocyte enhancer factor-2, MEF2. During myogenesis MEF2 binds to MyoD and other basic helix-loop-helix factors to activate transcription of genes involved in muscle cell differentiation. Transcriptional activation by MEF2 is blocked by interaction with HDAC5 and other histone deacetylases. In undifferentiated myoblasts, HDAC5 is present in the nucleus where it binds to MEF2 to block activation of muscle genes. When activated by IGF-1 signaling, CaM kinase phosphorylates HDAC proteins, causing them to be exported from the nucleus, releasing the block on MEF2 transcriptional activation and allowing differentiation to proceed. Transcription cofactors also interact with MEF2 to contribute to gene regulation and myogenesis. The transcriptional regulator NFAT, for example, acts as a cofactor for MEF2 when calcium and calcineurin signaling activate it. There are four members of the Mef2 gene family, Mef2a-2d. Mef2a is expressed in brain, heart and skeletal muscle. Mef2c is involved in myogenesis in cardiac and skeletal muscle. Mef2d is widely expressed, and may be involved in the regulation of T cell function as well as muscle. Several factors regulate Mef2 transcription factors, including Map kinases and histone deacetylase (HDAC) enzymes. Mef2 is phosphorylated by p38 map kinase, and phosphorylation of Mef2c by p38 contributes to skeletal muscle differentiation. BMK-1 (also called Erk5) is another member of the Map kinase family that regulates the activity of Mef2 family members and is unique in that it appears itself to possess a transcriptional activation domain and act as a transcriptional coactivator. Mekk3 disruption prevented normal cardiovascular development in mice and appears to signal through p38 and Mef2c in normal cardiovascular development.

Standard name | BIOCARTA_GCR_PATHWAY
Systematic name | M10066
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Corticosteroids and cardioprotection
Full description | Myocardial infarction damages heart tissue both during the initial ischemia and the subsequent reperfusion of tissues with oxygen. Corticosteroids can protect cardiac tissue from damage following a heart attack, but the mechanisms by which corticosteroids are cardioprotective have not been clear and negative side effects such as reduced wound healing may result from their use. Corticosteroids exert a variety of actions through binding to the glucocorticoid receptor (GR), a member of the steroid hormone receptor gene family. GR acts as a ligand-dependent transcription factor, but some of the cardioprotective effects mediated by GR-bound corticosteroids are non-transcriptional in nature. Glucocorticoids are commonly used as anti-inflammatory drugs in a variety of conditions, and some of their effects in the heart result from inhibition of the inflammatory response of heart tissue to ischemia and reperfusion. NF-kB is a transcription factor involved in signaling by inflammatory factors such as TNF, and is repressed by glucocorticoids. Annexin-1 is a calcium-dependent phospholipid binding protein whose expression is induced by corticosteroids and inhibits the infiltration of neutrophils into tissue, blocking reperfusion-induced inflammatory heart damage. A non-transcriptional cardioprotective effect of glucocorticoids is activation of NO production by endothelial nitric oxide synthase (eNOS). Glucocorticoids activate eNOS through activation of PI3 kinase and AKT and increased NO produced by eNOS can diffuse into surrounding tissues to prevent clotting and cause vasodilation. The beta-2 adrenergic receptor can also activate PI3 kinase and may synergize with glucocorticoids in this pathway. The atrial natriuretic factor (ANF) is a peptide secreted by the atrial wall in response to increased atrial pressure such as occurs during cardiac failure and to be decreased by myocardial infarction. Glucocorticoids increase the secretion of ANF by acting at the transcriptional level to increase expression of the pro-ANF peptide, perhaps inducing increased water excretion in the kidneys to reduce blood volume and reduce atrial pressure. The exploration of glucorticoid responses may allow the identification of compounds that retain the cardioprotective activities but do not inhibit wound healing. Alternative mechanisms of eNOS activation may also provide a route to identify cardioprotective drugs.

Standard name | BIOCARTA_CTCF_PATHWAY
Systematic name | M11420
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | CTCF: First Multivalent Nuclear Factor
Full description | CTCF is central to signaling pathways in immature B cells elicited by cross-linking the Ig BCR and stimulation with TGF. Both stimuli result in induction of cell cycle arrest and apoptosis. BCR ligation stimulates a transient induction of MYC that leads to high level CTCF expression and feedback suppression of MYC transcription. BCR ligation also activates PTEN opposing PI3K activation of MYC. Pharmacologic inactivation of PI3K or mTOR/FRAP results in suppression of S6K resulting in activation of CTCF and suppression of MYC. CTCF activation induces transcriptional activation of p19ARF, with its downstream consequences, and of p27. Growth arrest is occasioned by co-expression of p21 and p27 and inhibition of MYC. CTCF, is bona fide multivalent DNA-sequence binder which specificity is mediated by different sets of zinc fingers (ZFs). For three different DNA target sites, particular groups of ZFs which cannot be deleted from the 11 ZF domain without loosing binding to a given site, are shown by a rainbow in the box on the left.

Standard name | BIOCARTA_CTL_PATHWAY
Systematic name | M1462
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | CTL mediated immune response against target cells
Full description | Cytotoxic T lymphocytes (CTLs), also known as killer T cells, provide a cell-mediated response to specific foreign antigens associated with cells. CTLs only respond to foreign antigen when it is presented bound to the MHC-1 expressed on the surface of all cells. CTLs do not respond to soluble antigen, but induce apoptosis in viral-infected cells and in cancer cells. When the complex of antigen bound to MHC-1 is bound to antigen-specific T cell receptor, the cytotoxic T cell induces apoptosis in the target cell primarily by two pathways, one involving perforin-mediated apoptosis and the other involving Fas/Fas-ligand interaction. When CTLs are activated by recognition of specific antigen on a cell, they release perforin proteins that integrate into the membrane of the target cell and organize to form a membrane pore. This allows the protease granzyme to enter the cell and activate the apoptotic caspase proteolytic cascade , and also allows other molecules to cross the cell membrane and trigger osmotic lysis of the membrane. The interaction of T-cell Fas ligand with the Fas receptor in the target cell can also activate the caspase cascade and other pathways involved in apoptosis. The interaction of a CTL with antigen-MHC I complex activates the CTL to proliferate and amplify the clone of T cells that respond to that antigen, amplifying the immune response against that specific antigen.

Standard name | BIOCARTA_CXCR4_PATHWAY
Systematic name | M882
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | CXCR4 Signaling Pathway
Full description | CXCR4 is a chemokine receptor in the GPCR gene family, and is expressed by cells in the immune system and the central nervous system. In response to binding its ligand SDF-1 (stromal cell-derived factor-1), CXCR4 triggers the migration and recruitment of immune cells. This ligand-receptor pair may also play a role in development of the nervous system. In addition to acting as a chemokine receptor, CXCR4 is a co-receptor for entry of HIV into T cells and ligands of CXCR4, including SDF-1 may help to block HIV infection. Early in the infection of an individual, HIV viruses often are tropic for the CCR5 coreceptor that provides for macrophage entry, then later in infection are tropic for CXCR4 and T cell entry. Viruses that are tropic for CXCR4 are generally syncitium forming, causing T cells to aggregate and be destroyed at a rapid rate. CXCR4 induces downstream signaling by several different pathways. As a GPCR, CXCR4 binding of SDF-1 activates G-protein mediated signaling, including downstream pathways such as ras, and PI3 kinase. PI3 kinase activated by SDF-1 and CXCR4 plays a role in lymphocyte chemotaxis in response to these signals. One endpoint of CXCR4 signaling is the activation of transcription factors such as AP-1 and chemokine regulated genes. JAK/STAT signaling pathways also appear to play a role in SDF-1/CXCR4 signaling. Delineation of the signaling mechanisms utilized by CXCR4 may assist in determining the role of CXCR4 in HIV infection and in the immune response.

Standard name | BIOCARTA_CELLCYCLE_PATHWAY
Systematic name | M17770
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cyclins and Cell Cycle Regulation
Full description | The cell cycle is regulated by the interplay of many molecules. Key among these are the cyclins which are expressed and then degraded in a concerted fashion to drive the stages of the cell cycle. Cyclins combine with cyclin dependent kinases (cdks) to form activated kinases that phosphorylate targets leading to cell cycle regulation. A breakdown in the regulation of this cycle can lead to out of control growth and contribute to tumor formation. Defects in many of the molecules that regulate the cell cycle have been implicated in cancer. Key among these are p53, the cdk inhibitors (p15, p16, p18, p19, p21, p27), and Rb, all of which act to keep the cell cycle from progressing until all repairs to damaged DNA have been completed.

Standard name | BIOCARTA_CFTR_PATHWAY
Systematic name | M12399
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cystic fibrosis transmembrane conductance regulator (CFTR) and beta 2 adrenergic receptor (b2AR) pathway
Full description | The defects in cAMP-regulated chloride channel CTFR are believed to be the major cause for cystic fibrosis. Regulation of CFTR protein by the surface receptor beta adrenergic receptor is mediated through the ezrin/radixin/moesin binding phosphoprotein 50 (EBP50), which binds both the C-termini CFTR and b2AR through their PDZ binding motifs. In the resting state, CFTR, b2AR, and EBP50 exist as a macromolecular complex on the apical surface of epithelial cells. Upon agonist activation of the b2AR, the adenulate cyclase is stimulated through the G protein pathway, leading to an increase in cAMP. The elevated concentration of cAMP activates PKA, which is anchored near CFTR via interaction with Ezrin. The phosphorylation of CFTR by PKA disrupts the complex and leads to compartmentalized and specific signaling of the channel.

Standard name | BIOCARTA_CYTOKINE_PATHWAY
Systematic name | M17406
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cytokine Network
Full description | Several different cell types coordinate their efforts as part of the immune system, including B cells, T cells, macrophages, neutrophils, basophils and eosinophils. Each of these cell types has a distinct role in the immune system, and communicates with other immune cells using secreted factors called cytokines, including interleukins, TNF, and the interferons. Macrophages phagocytose foreign bodies and are antigen-presenting cells, using cytokines to stimulate specific antigen dependent responses by B and T cells and non-specific responses by other cell types. T cells secrete a variety of factors to coordinate and stimulate immune responses to specific antigen, such as the role of helper T cells in B cell activation in response to antigen. The proliferation and activation of eosinophils, neutrophils and basophils respond to cytokines as well. Cytokine communication is often local, within a tissue or between cells in close proximity. Each of the cytokines is secreted by one set of cells and provokes a response in another target set of cells, often including the cell that secretes the cytokine. Some cytokines, like IL-1, interferons and TNF, stimulate a broad inflammatory response in response to infection or injury. Other cytokines have more specific functions such the following examples. IL-2 stimulates the proliferation and activation of B and T cells. IL-4 plays a role in the differentiation of Th2 cells, in allergic responses, and in the switching of antibody types. IL-5 stimulates the production and maturation of eosinophils during inflammation. IL-8 is a chemokine, a chemotactic factor that attracts neutrophils, basophils and T cells to sites of inflammation. IL-12 and IL-18 are involved in helper T cell differentiation. IL-10 apparently acts to repress secretion of proinflammatory cytokines. The complex interplay of these different cytokine functions with immune cells is essential for correct immune function.

Standard name | BIOCARTA_INFLAM_PATHWAY
Systematic name | M6910
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cytokines and Inflammatory Response
Full description | Inflammation is a protective response to infection by the immune system that requires communication between different classes of immune cells to coordinate their actions. Acute inflammation is an important part of the immune response, but chronic inappropriate inflammation can lead to destruction of tissues in autoimmune disorders and perhaps neurodegenerative or cardiovascular disease. Secreted cytokine proteins provide signals between immune cells to coordinate the inflammatory response. Some cytokines such as IL-1, IL-6 and TNF act to broadly provoke the inflammatory response while others act on specific types of immune cells. Macrophages and other phagocytotic cells provide a front-line defense against bacterial infection. Macrophages stimulate the inflammatory responses of neutrophils, fibroblasts, and endothelial cells in response infection by secreting IL-1 and TNF. IL-1 and TNF cause fever through alteration of the body temperature set-point in the hypothalamus. Fibroblasts and endothelial cells respond to IL-1 and TNF by recruiting more immune cells to the site of inflammation. Secreted IL-8 is a chemokine that attracts neutrophils to sites of infection. Macrophages also present antigen to T helper cells that play a central role in coordinating immune responses. T helper cells induce clonal expansion of T cells that respond to antigen, with IL-2 as a key mediator of T cell proliferation and activation. TGF-beta is a negative regulator of proliferation in many cells, have anti-inflammatory actions in some settings. The cytotoxic activity of Natural Killer cells (NK cells) and lymphokine activated killer cells (LAK cells) toward viral infected or tumor cells is stimulated by IL-2 and other cytokines. T helpers secrete IL-3 and IL-5 to stimulate eosinophil proliferation and activation. Eosinophils are involved in the immune response to parasitic infection. T helper cells are required to stimulate B cell responses as well, with the cytokines IL-10, IL-4 and other cytokines regulating the clonal selection and differentiation of antigen-specific B cells to form antibody-secreting plasma B cells and memory cells. In addition to inducing activation and proliferation of specific differentiated immune cells, cytokines act on hematopoeitic stem cells, causing their proliferation and differentiation into the full range of immune cells.

Standard name | BIOCARTA_D4GDI_PATHWAY
Systematic name | M15513
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | D4-GDI Signaling Pathway
Full description | D4-GDI (GDP dissociation inhibitor) is a negative regulator of the ras related Rho Family of GTPases. Since the rho GTPases promote cytoskeletal and membrane changes associated with apoptotic cell death, the removal of the D4-GDI block through its cleavage is important for inducing apoptosis. Caspase-3 cleaves the 28 kDa mature form of D4-GDI to give a 5 kDa and 23 kDa Size fragment. The 23 kDa fragment then translocates to the nucleus. The mechanisms involving cleavage of D4-GDI with apoptosis are not presently known. Activation of the Jun N-Terminal kinase, a regulator of apoptosis, may be one of the mechanisms.

Standard name | BIOCARTA_DC_PATHWAY
Systematic name | M9177
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Dendritic cells in regulating TH1 and TH2 Development
Full description | While T cells and B cells carry out the actions of antigen-specific immune responses, antigen-presenting cells called dendritic cells are required for this to happen. The name of dendritic cells is based on their shape, with activated dendritic cells displaying long processes on their surface. When immature dendritic cells found throughout the body internalize and present antigen, they express markers that stimulate the activation of lymphocytes, and migrate to lymphocyte rich tissues like the spleen and lymph nodes to initiate immune responses. In addition to stimulating responses against antigens, dendritic cells also produce tolerance to self antigens. Dendritic cells can be derived from either myeloid or lymphoid lineages. Monocyte derived lineages (pDC1) stimulate Th1 cell differentiation while plasmacytoid (lymphoid) dendritic cells (pDC2) induce Th2 cell differentiation. Factors that stimulate the maturation of monocytes derived dendritic cells include GM-CSF, and IL-4. IL-3 stimulates the differentiation of pDC2 cells into DC2 cells. A variety of factors are involved in antigen-recognition and processing by immature dendritic cells and in the maturation of these cells. The transition to mature dendritic cells down-regulates the factors involved in antigen internalization, and increases the expression of MHC, costimulatory molecules involved in lymphocyte activation, adhesion molecules, and specific cytokines and chemokines. Toll-like receptors on the surface of immature dendritic cells recognize microbial components to induce dendritic cell maturation. In addition to stimulating B cell responses, dendritic cells are potent activators of T cells. IL-12 secretion by dendritic cells stimulates T cell responses, particularly differentiation of Th1 cells that produce interferon-gamma and other pro-inflammatory cytokines. While IL-4 generally stimulates Th2 differentiation, the stimulation of Th2 cell formation by DC2 cells does not appear to involve IL-4. The stimulation of Th1 and Th2 cell formation by dendritic cells appears to be balanced by counter-regulation of each pathway by the other. Interferon-gamma produced by Th1 cells blocks the further stimulation of Th1 differentiation by DC1 cells. The IL-4 produced by Th2 cells kills dendritic cell precursors that contribute to Th2 cell creation. Direct interactions between T cells and dendritic cells are enhanced through the expression of adhesion molecules and costimulatory receptors CD80 and CD86 expressed by mature dendritic cells activate T cells in concert with the recognition of antigen/MHC by the T cell receptor. The central role of dendritic cells as modulators of immune responses makes them an important focus of studies about autoimmune disease, transplant rejection, allergies, responses to infections, and other alterations of the immune response.

Standard name | BIOCARTA_P35ALZHEIMERS_PATHWAY
Systematic name | M12718
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Deregulation of CDK5 in Alzheimers Disease
Full description | Cyclin-dependent kinase 5 (cdk5), a multi-functional kinase, and its neuron-specific activator p35 are required for neurite outgrowth and cortical lamination. Proteolytic cleavage of p35 produces p25, which accumulates in the brains of patients with Alzheimer's disease. Conversion of p35 to p25 causes prolonged activation and mislocalization of cdk5 and the hyperphosphorylates tau, leading to the formation of paired helical filaments and promotes apoptosis. In cultured primary cortical neurons, excitotoxins, hypoxic stress and calcium influx induce the production of p25. In fresh brain lysates, addition of calcium can stimulate cleavage of p35 to p25. Specific inhibitors of calpain1, effectively inhibit the calcium-induced cleavage of p35. In vitro, calpain1 directly cleaves p35 to release a fragment with relative molecular mass 25,000. Application of the amyloid beta-peptide A beta induces the conversion of p35 to p25 in primary cortical neurons. Inhibition of cdk5 or calpain activity reduces cell death in A beta-treated cortical neurons. These observations indicate that cleavage of p35 to p25 by calpain may be involved in the pathogenesis of Alzheimer's disease. GSK3B also phosphoryklates tau but does not induce hyperphosphorylation in response to calpain activating stimuli. Additionally down-regulation or inhibition of PP2A increases the hyper-phosphorylation of tau.

Standard name | BIOCARTA_RNA_PATHWAY
Systematic name | M10570
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Double Stranded RNA Induced Gene Expression
Full description | One defense against viral infection is provided by PKR, double-stranded RNA activated protein kinase. When PKR interacts with dsRNA found in cells during viral infection, PKR phosphorylates itself and cellular proteins including the translation factor elF2a and the transcription factor NF-kB. The repression of translation caused by phosphorylation of elF2a prevents cells from producing viral proteins and creating infectious viral particles. PKR phosphorylation of I-kB kinase activates NF-kB to induce transcription of inflammatory factors and stimulate an immune response that impedes viral infection. The PKR kinase is induced by interferon and some of the anti-viral activity of interferon may be mediated by PKR. Some viruses have evolved mechanisms to inactivate PKR to promote successful infection. Another substrate of PKR, the tumor suppressor p53, may be involved in potential PKR regulation of the cell cycle and apoptosis.

Standard name | BIOCARTA_MTA3_PATHWAY
Systematic name | M225
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Downregulated of MTA-3 in ER-negative Breast Tumors
Full description | Approximately 30% of breast carcinomas lack ER expression. Presumably, these breast cancers become estrogen independent through genetic alterations that bypass the requirement for ER-dependent stimulation of cell proliferation. As such estrogen receptor is a key regulator of proliferation and differentiation in mammary epithelia and represents a crucial prognostic indicator and therapeutic target in breast cancer. Mechanistically, estrogen receptor induces changes in gene expression through direct gene activation of a number of genes (cathepsin D, HSP27 (heat shock protein 27,000 kDa, aldolase A, dehydrogenase, alpha-tubulin, and glyceraldehyde-3-phosphat, Pdzk1, Greb ets) and also through the biological functions of target loci. The product of human MTA3 has been identified as an estrogen-dependent component of the Mi-2/NuRD transcriptional corepressor in breast epithelial cells and demonstrate that MTA3 constitutes a key component of an estrogen-dependent pathway regulating growth and differentiation. The absence of estrogen receptor or of MTA3 leads to aberrant expression of the transcriptional repressor Snail, a master regulator of epithelial to mesenchymal transitions. Aberrant Snail expression results in loss of expression of the cell adhesion molecule E-cadherin, an event associated with changes in epithelial architecture and invasive growth. MTA3 is the mechanistic link between estrogen receptor status and invasive growth of breast cancers.

Standard name | BIOCARTA_SKP2E2F_PATHWAY
Systematic name | M6031
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | E2F1 Destruction Pathway
Full description | E2F-1 is a transcription factor that regulates the expression of genes involved in the cell cycle and that is involved in progression of the cell cycle from G1 into S phase. Over-expression of E2F-1 can induce cellular transformation and its under-expression can repress apoptosis. Association with the tumor suppressor Rb represses E2F-1 activity, and this repression is relieved when the cdk2/cyclin E complex at the G1 to S phase transition phosphorylates Rb. Like many cell cycle regulators, E2F-1 is regulated through phosphorylation by a cyclin-dependent protein kinase, cdk2/cyclin A, and by proteolytic degradation. Phosphorylation of E2F-1 by cdk2/cyclin A leads to E2F-1 inactivation, blocking DNA binding. E2F-1 is also regulated through degradation in the proteosome at the S/G2 transition. The F box complex that degrades E2F-1 contains components shared with the complexes that target other cell cycle factors for degradation. The F box protein that specifically recruits E2F for ubiquitination and degradation is Skp2. Other components of the SCF complex include Skp1, Cul1, and cdc34. Skp2 expression is cyclical, increasing in the S/G2 transition as E2F-1 is degraded. Knowledge of E2F-1 activity and its regulation form part of the complex set of interactions regulating the cell cycle and potential targets for the treatment of cancer.

Standard name | BIOCARTA_CALCINEURIN_PATHWAY
Systematic name | M3430
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Effects of calcineurin in Keratinocyte Differentiation
Full description | The differentiation of keratinocytes constantly replenishes the upper layers of human skin we lose each day. One factor that contributes to terminal keratinocyte differentiation is increased levels of intracellular calcium. Adding calcium to the medium of cultured keratinocytes elevates intracellular calcium and triggers differentiation. Intracellular calcium levels are also increased in response to phospholipase C activation, producing IP3 and releasing calcium from stores in the ER. Intracellular calcium alters multiple signaling pathways, one of which is binding to calmodulin to activate the serine-threonine protein phosphatase calcineurin. Calcineurin dephosphorylates and activates the transcription factor NFAT and both calcineurin and NFAT are expressed in differentiating keratinocytes. Activated NFAT can regulate transcription through binding its own cognate DNA binding site. One marker of keratinocyte differentiation, the p21 gene, is activated by NFAT by a different mechanism, with NFAT activating the p21 promoter by acting as a coactivator for the transcription factors Sp1 and Sp3. Another protein activated by calcium that may be involved in keratinocyte differentiation is protein kinase C (PKC). One substrate of activated PKC is MARCKS (myristoylated alanine-rich kinase C substrate). Phosphorylation of MARCKS by PKC in intact keratinocytes is not induced during calcium-induced differentiation, but does increase when tested in vitro. PKC activity is increased by calcium during keratinocyte differentiation but PKC MARCKS phosphorylation is blocked by the formation of a complex between calmodulin and MARCKS. The immunosuppressants cyclosporin-A (CsA) and FK506 inhibit T cell activation through indirect inhibition of NFAT activation and have several side effects including changes in the skin, suggesting that calcineurin activity may play a role in normal skin physiology. CsA is used to treat psoriasis, a disease involving abnormal proliferation of skin cells. The activity of CsA in treating psoriasis may involve inhibition of immune cells, but may also directly involve inhibition of calcineurin activity in keratinocytes.

Standard name | BIOCARTA_EGF_PATHWAY
Systematic name | M1909
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | EGF Signaling Pathway
Full description | The epidermal growth factor (EGF) peptide induces cellular proliferation through the EGF receptor, which has a tyrosine kinase cytoplasmic domain, a single transmembrane domain and an extracellular domain involved in EGF binding and receptor dimerization. Inhibitors of the EGF receptor are being pursued as potential cancer therapies and EGF may stimulate wound healing. Mutation of the EGF receptor has been associated with cancer in humans. The proliferative effects of EGF are signaled through several pathways. Binding of EGF results in EGF receptor dimerization, autophosphorylation of the receptor, and tyrosine phosphorylation of other proteins. The EGF receptor activates ras and the MAP kinase pathway, ultimately causing phosphorylation of transcription factors such as c-Fos to create AP-1 and ELK-1 that contribute to proliferation. Activation of STAT-1 and STAT-3 transcription factors by JAK kinases in response to EGF contributes to proliferative signaling. Phosphatidylinositol signaling and calcium release induced by EGF activate protein kinase C, another component of EGF signaling. Crosstalk of EGF signaling with other pathways make the EGF receptor a junction point between signaling systems.

Standard name | BIOCARTA_ETC_PATHWAY
Systematic name | M15371
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Electron Transport Reaction in Mitochondria
Full description | The body gets energy through the oxidation of food such as glucose and fatty acids. The chemical energy contained in these foods is extracted and converted until it reaches a common form, the high-energy phosphate bonds of ATP. The hydrolysis of ATP is highly favorable and is coupled to a variety of energetically unfavorable processes to drive them forward. How is the energy of glucose captured and converted to make ATP? Most of the energy of glucose or fatty acids is extracted through oxidation to produce the reduced high-energy electron carriers NADH and FADH2. From there, the energy is transferred next to the electron transport system associated with the mitochondrial inner membrane. This chain includes a series of protein complexes and non-membrane cofactors that transfer the electrons from NADH and FADH2 in a series of redox reactions from carrier to carrier. Oxygen is the final electron acceptor at the end of the chain, resulting in the production of water. The oxygen we breath, and which is transported by hemoglobin in the blood to all of the tissues, serves this purpose and allows electron transport to occur. As the electrons pass through the chain, they transfer their energy to the complexes, which use the energy to pump protons out of the mitochondrial matrix, creating a proton gradient across the inner mitochondrial membrane. The chemical energy that started with glucose, and was transferred to NADH and FADH2, is then converted to the energy of a concentration gradient. The inner mitochondrial membrane is impermeable to protons on its own, so the energy of the proton gradient is stable, waiting to be recaptured. The energy is recaptured by ATP synthase in the inner mitochondrial membrane. This enzyme allows protons to flow back down their concentration gradient across the membrane, and in the process uses the energy of the gradient to drive ATP synthesis. The movement of the electrons through electron transport, the proton gradient and ATP synthesis are all coupled processes that require each other to occur. The cell does not store energy as ATP, but only has enough ATP on hand for its immediate energy needs. If electron transport ceases or is inhibited, then ATP synthesis also rapidly halts. This regulation ensures that ATP production closely matches the needs of the cell. Glycolysis and the Krebs cycle are also closely linked to the energy needs of the cell. The abundance of ATP, NADH and pathway intermediates regulates key steps in these pathways so that are activated when energy is required to feed the electron transport system and they are inhibited when not needed to save metabolic energy. If oxygen is absent, electron transport and the Kreb's cycle rapidly halt, leaving glycolysis and fermentation as the main means of energy production. During aerobic exercise, the rapid consumption of ATP leads to use of the proton gradient to make more ATP, increased electron transport to regenerate the proton gradient, increased oxygen consumption, and increased activity of the Kreb's cycle and glycolysis to supply high energy electrons to drive electron transport. Uncoupling agents allow protons to flow across the mitochondrial membrane without producing ATP. The chemical compound dinitrophenol (DNP), for example, can transport protons to flow across the inner mitochondrial membrane without ATP synthase. In the presence of dinitrophenol, energy is consumed to pump protons out of mitochondria, but this energy is not recaptured in chemical form in ATP. Instead, this energy is released as heat. Dinitrophenol was once used as diet remedy to lose weight without exercise or diet, but this compound is a metabolic poison and resulted in deaths in when purposefully given to humans. Proteins also can act as uncoupling agents in the mitochondria. A mitochondrial uncoupling protein is found in brown adipose tissue. An increase in the activity of uncoupling proteins increases heat production by allowing protons to flow down their gradient without making ATP and may serve as protection against cold, as well as a potential means of obesity control.

Standard name | BIOCARTA_NDKDYNAMIN_PATHWAY
Systematic name | M5940
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Endocytotic role of NDK, Phosphins and Dynamin
Full description | Reliable neurotransmitter release requires the presence of sufficent numbers of synaptic vesicles. The process of synaptic vesicle endocytosis (SVE) is coordinated by a group of proteins called dephosphins. The current set of seven known dephosphins are nerve treminal proteins with little or no structural hoimology but satisfy two essential criteria: they are essential for SVE and they are rapidly and coordinately dephosphorlyated in response to a calcium influx through voltage-dependent calicium channels. The calicium signal is mediated by calmodulin (CaM) and calcineurin. Each dephosphin plays an essential role in overlapping phases or segments of the cycle. The four phases of SVE are nucleation, invagination, fission and uncoating. In this diagram the internalization of the vesicle is the uncoating step. In order to illustrate the complexity of this process the initial display of the protein is labelled with a name and a number. This number is then used at the decloaking or uncoating step to show the release and seperation of the various factors. Each step in the process has a different set of complex components. The components are shown in highlighted boxes above. The nucleation phase initiates with the activation of CaM/Calcineurin and the subsequent dephosphorylation of AP180. AP180 and clathrin are then recruited to the membrane by AP2 and PtdIns(4,5)P2 (comma shaped molecule in the diagram). Nucleation is completed by the addition of epsin and eps15. Invagination proceeds with the formation of the amphiphysin1/2 heterodimer and its addition to the maturing vesicle surface complexes. The final components, dynamin and synaptojanin, are recruited to the budding vesicle by the amphiphysin1/2 heterodimer. Dynamin forms a complete ring around the vesicle neck and completes fission via its PtdIns(4,5)P2 stimulated GTPase activity. After internalization the vesicle is quickly uncoated, in a process believed to be mediated by synaptojanin, and is accompnied by the disassembly of clathrin.

Standard name | BIOCARTA_EPHA4_PATHWAY
Systematic name | M16334
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Eph Kinases and ephrins support platelet aggregation
Full description | Eph kinases are a family of receptor tyrosine kinases with an extracellular domain that binds their ligand, the ephrins, and an intracellular kinase domain. The ephrins are also expressed on the cell surface, so that interaction between Eph kinases and ephrins occurs at the interface between neighboring cells. Binding of ephrins to Eph kinases stimulates signaling in both directions across the interface between cells, in both the receptor expressing and the ligand expressing cells. Eph kinases and ephrins are involved in several biological processes, and their role in neuronal development has been extensively examined. Both Eph kinases (EphA4 and EphB1) and ephrins (ephrinB1) are expressed on platelets, suggesting activation of eph kinases by ephrins may play a role in clotting when platelets are brought into close proximity in the developing clot. Platelet activation progresses in stages with an early stage that is stimulated by soluble factors like ADP acting through GPCRs and is reversible and later stages with stronger interaction between platelets that may require interact between Eph kinases and ephrins. One of the molecular targets of signaling by Eph kinases and ephrins is the actin cytoskeleton, which also plays a role in platelet activation. Clustering Eph kinases or ephrins in platelets stimulated cytoskeletal changes as well as other markers of platelet activation during clotting such as secretion of alpha-granules to release clotting factors. Clustering ephrins together activated Rap1b, a ras gene family member that may regulate integrins. Platelet activation caused Eph kinases to bind to src family members Fyn and Lyn and also with the cell adhesion molecule L1. Failure of the ephrins/Eph kinase pathway to function normally in platelets may result in loosely associated platelets and improper clot formation. Eph kinases and ephrins are also expressed on the vascular wall by endothelial cells, suggesting that signaling by these proteins may also play a role in the interaction of platelets with the vascular wall and clot formation in the vasculature.

Standard name | BIOCARTA_EPO_PATHWAY
Systematic name | M12836
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | EPO Signaling Pathway
Full description | Erythropoietin functions to increase the number of red blood cells. Thus, it has found utility as a drug for those needing to replenish erythrocytes for a number of reasons. The signaling mechanism includes multimerization of the receptor upon ligand binding, activation of MAPK cascade, and phosphorylation and activation of Stat5.

Standard name | BIOCARTA_ECM_PATHWAY
Systematic name | M6355
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Erk and PI-3 Kinase Are Necessary for Collagen Binding in Corneal Epithelia
Full description | Activation of the MAPK kinase pathway has been identified as a mechanism that integrins use to regulate gene expression leading to cell shape changes during cell spreading or migration Epithelial cells respond to extracellular matrix (ECM) cause integrin-mediated FAK phosphorylation that in turn phosphorylates the surrounding proteins (paxillin, Fyn/shc, and src) and leads to signal amplification. FAK also binds PI-3 kinase and is upstream of the MAP kinase pathway. When MAPkinase or PI-3 kinase was inhibited, actin reorganization was blocked. Src phosphorylates p190RhoGAP, inactivating its GAP function that may allow RhoGTP to stay active longer, promoting further signal amplification. Activated RhoGTP binds to downstream kinases such as Rho-associated coiled coil-containing protein kinase (p160ROCK) and p140 diaphanous (p140Dia) to increase actin polymerization and contraction. Actin reorganization assists integrin clustering, allowing more ECM binding that increase FAK phosphorylation and other signal transduction events.

Standard name | BIOCARTA_ERK_PATHWAY
Systematic name | M287
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Erk1/Erk2 Mapk Signaling pathway
Full description | The p44/42 MAP Kinase pathway consists of a protein kinase cascade linking growth and differentiation signals with transcription in the nucleus. Growth factor receptors and tyrosine kinases activate Ras which in turn activates c-Raf, MEK, and MAP kinase. Activated p44/42 MAP Kinase translocates to the nucleus and activates transcription by phosphorylation of kinases such as p90 RSK, MSK, and transcription factors such as ELK-1 and Stat3. The importance of this pathway in both growth control and development has been demonstrated via the transforming properties of various mutant forms of Ras, Raf, MEK and by their effects on development. Signal amplification and the potential for crosstalk appear to be important features of this regulatory network.

Standard name | BIOCARTA_ERYTH_PATHWAY
Systematic name | M9367
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Erythrocyte Differentiation Pathway
Full description | Stem cells in the bone marrow produce a variety of hematopoietic cell types from common progenitor cells under the influence of cytokines and growth factors. CFU-GEMM cells are a key intermediate in the differentiation of granulocytes, erythrocytes, monocytes and megakaryocytes. Erythropoietin (EPO) is a cytokine produced in the kidneys that, along with other cytokines, induces red blood cell (erythrocyte) differentiation in the bone marrow from CFU-GEMM cells. As the erythrocyte lineage progresses, cells lose their nuclei, and move out of the bone marrow into circulation. The ability of EPO to selectively induce red blood cell differentiation has allowed extensive therapeutic use of the recombinant form of this cytokine to treat anemias.

Standard name | BIOCARTA_EPONFKB_PATHWAY
Systematic name | M6917
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Erythropoietin mediated neuroprotection through NF-kB
Full description | Erythropoietin (Epo) is most commonly known as the cytokine secreted by the kidneys that stimulates red blood cell production and is used as a drug for the treatment of anemias. Epo is also secreted in the brain in response to hypoxia, such as ischemic stroke. Epo production in the brain is stimulated by the hypoxia-inducible transcription factor HIF-1. Administration of Epo to the brain in rodents before hypoxic stress or other neuronal stresses is neuroprotective, preventing neuronal apoptosis. The erythropoietin receptor (EpoR) is known to associate with JAK kinases that phosphorylate and activate the STAT family of transcription factors. The neuroprotection by Epo involves cross-talk between Epo receptor and anti-apoptotic pathways through activation of NF-kB by the JAK2 kinase. Epo stimulates JAK2 phosphorylation of I-kB, releasing NF-kB to translocate into the nucleus and activate transcription of neuroprotective genes. Neuroprotective genes activated by NF-kB include the anti-oxidant enzyme manganese superoxide dismutase and calbindin-D(28k). The erythropoietin receptor is also essential for proper brain development in mice. The absence of EpoR causes high levels of neuronal apoptosis in the developing mouse brain, further confirming the important role of Epo as a neuroprotective agent.

Standard name | BIOCARTA_EIF_PATHWAY
Systematic name | M7721
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Eukaryotic protein translation
Full description | The scanning translation initiation model suggests that 40S ribosomal subunit preloaded with factors bind to the 5 end of the mRNA near the cap. The 48S subunit moves along the mRNA until it finds the initiation triplet and in complex with tRNA and 60S subunit formed the first peptide bond. Translation control is mostly regulated at the protein initiation step through translation initiation factors such as eIF2 or eIF4.

Standard name | BIOCARTA_EXTRINSIC_PATHWAY
Systematic name | M4470
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Extrinsic Prothrombin Activation Pathway
Full description | Blood coagulation or clotting takes place in 3 essential phases. The first phase is the activation of a prothrombin activator complex. The second phase is the activation of prothrombin. The third stage is clot formation as a result of fibrinogen cleavage by activated thrombin. The prothrombin activation complex is formed by two pathways each of which results in a different form of the prothrombin activator. The extrinsic mechanism of prothrombin activator formation begins with trauma to vascular walls or extravascular tissues. The damaged tissue releases tissue thromboplastin also known as tissue factor (TF). The formation of a clot by this mechanism usually takes as little as 15 seconds. This cascade is initiated by the activation of factor X by TF and factor VII. Activated factor X combined with factor V, factor VII and TF constitutes the prothrombin activator. Calcium (Ca++) is required for each of these steps. The prothrombin activator in the extrinsic pathway is very similar to the activator in the intrinsic pathway. Antithrombin III inhibits the activity of thrombin and also the step leading to the activation of factor X. Antithrombin III is a hundred to a thousand times more effective when bound by heparin. Protein C is activated by thrombin and with the Protein S cofactor provides a strong negative feedback in this phase of clot formation. Disease Significance: Most of the clotting factors are formed in the liver. Diseases of the liver or damage to the liver can depress the levels of these factors in the blood resulting in excessive bleeding. Vitamin K deficiency can also result in a similar condition since Vitamin K is essential for the formation of factor VII, IX, X and prothrombin. Vitamin K is synthesized in the intestinal tract by bacteria.

Standard name | BIOCARTA_FAS_PATHWAY
Systematic name | M9503
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | FAS signaling pathway ( CD95 )
Full description | Receptors in the TNF receptor family are associated with the induction of apoptosis, as well as inflammatory signaling. The Fas receptor (CD95) mediates apoptotic signaling by Fas-ligand expressed on the surface of other cells. The Fas-FasL interaction plays an important role in the immune system and lack of this system leads to autoimmunity, indicating that Fas-mediated apoptosis removes self-reactive lymphocytes. Fas signaling is also involved in immune surveillance to remove transformed cells and virus infected cells. Binding of FAS to oligimerized FasL on another cell activates apoptotic signaling through a cytoplasmic domain termed the death domain that interacts with signaling adaptors including FAF, FADD and DAX to activate the caspase proteolytic cascade. Caspase-8 and caspase-10 are first activated, to then cleave and activate downstream caspases, and a variety of cellular substrates that lead to cell death. Caspases cleave nuclear lamins, causing the nucleus to break down and lose its normal structure and another caspase substrate is DFF, inducing cleavage and degradation of the genome. Other caspase substrates are involved in cytoskeletal structure, cell cycle regulation and signaling pathways. Activation of JNK kinase, activation of Jun, and production of ceramide may also play roles in Fas-mediated apoptosis. Activation of fas-mediated apoptosis is opposed by I-FLICE and FAP. Viruses and tumors may escape immune surveillance in part through suppression of fas-mediated apoptosis using similar mechanisms.

Standard name | BIOCARTA_FCER1_PATHWAY
Systematic name | M1908
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Fc Epsilon Receptor I Signaling in Mast Cells
Full description | The Fc Epsilon Receptor 1 signaling pathway in mast cells uses multiple core signal path to achieve its necessary ends. Through the BTK protein and PKC Mast cells are able to degranulate, through the PKC and MAPK paths the cells are able to alter cytokine expression and arachidonic acid release.

Standard name | BIOCARTA_FIBRINOLYSIS_PATHWAY
Systematic name | M2842
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Fibrinolysis Pathway
Full description | Clot formation and fibrinolysis is a balance of plasmin activation/inhibition and thrombin-thrombomodulin activity that regulates fibrin polymer formation and degradation. Active thrombin is produced by the cleavage of prothrombin in the intrinsic thrombin activation pathway or the extrinsic thrombin activation pathway. Cleavage of fibrinogen by thrombin releases the fibrin monomers that auto-polymerize within seconds into fibrin threads or fibers. The coagulation cascade has many feedback loops. One example is the binding of thrombin to the fibrin polymers resulting in a reduction in soluble thrombin. The fibers form a more stable clot as a result of the covalent bonds formed by activated factor XIII enzyme (also known as Fibrin stabilizing factor). These fibers form a mesh the traps platelets, blood cells and plasma to form a clot. The removal of the clot is caused by plasmin cleavage of the fibrin monomers into soluble fibrin degradation products. Plasmin is formed by the cleavage of plasminogen between Arg561 and Val562. Plasmin is a two-chain trypsin-like serine protease. Plasminogen activator inhibitor 1 (PAI1) and plasminogen activator inhibitor 2 (PAI2) inhibit cleavage of plasminogen by tissue-type plasminogen activator (tPA) or urokinase plasminogen activator (uPA). The presence of fibrin fibers and fibrin degradation products exert a two-fold stimulation of tPA and uPA. Plasmin activity is also inhibited by alpha2-antiplasmin. Thrombin activatable fibrinolysis inhibitor (TAFI) is a carboxy-peptidase B-like proenzyme activated by the thrombin-thrombomodulin dimer. TAFI cleaves (DD)E2 to separate DD and E fragments which do not enhance the activation of tPA or uPA and results in a reduced feedback signal. Disease Significance: Overabundance or increased activity of the plamsminogen activator inhibitors or reduced presence or function of tPA or uPA can result in atherosclerotic disease and venous thrombosis due to an increase in fibrin deposition or formation of a thrombus. Thrombosis can also result from plasminogen deficiency caused by a lack of protein or lack of functional protein. Reduced or depleted levels of alpha2-antiplamin can result in severe bleeding disorders.

Standard name | BIOCARTA_FMLP_PATHWAY
Systematic name | M10287
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | fMLP induced chemokine gene expression in HMC-1 cells
Full description | Neutrophils respond to bacterial infection by releasing reactive oxygen species that kill bacteria and by expressing chemokines that attract other immune cells to the site of infection. The multisubunit enzyme NADPH oxidase expressed by neutrophils produces reactive oxygen species rapidly released in what is known as the respiratory burst. Activity of the NADPH oxidase is induced by fMLP receptor ligands, formylated peptides from bacteria. The fMLP receptor is a G-protein coupled receptor, FPR-1, that activates Map kinase pathways and phospholipase C. Phospholipase C activation releases IP3 and calcium, activating protein kinase C and also activating the transcription factor NFAT, which contributes to activation of chemokine genes. One of the components of the NADPH oxidase is p47phox. PKC activation phosphorylates p47phox to activate NADPH oxidase activity. Activation of Map kinase cascades leads to Erk1/Erk2 dependent p47phox phosphorylation as well as activation of the Elk-1 transcription factor and chemokine gene expression. Inhibition of p38 did not affect p47phox phosphorylation, indicating that p38 is not involved in Erk1/2 activation of the NADPH oxidase. Inhibition of p38 did inhibit NADPH oxidase though, indicating that other pathways contribute to activation of this enzyme. The pathways involved in neutrophils activation are important to understand innate immune responses to bacterial infection.

Standard name | BIOCARTA_FREE_PATHWAY
Systematic name | M96
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Free Radical Induced Apoptosis
Full description | Oxidative stress is one factor that can trigger programmed cell death. Activated neutrophils responding to inflammatory stimulation produce reactive oxygen species like superoxide free radicals to kill invading bacteria, but these reactive oxygen species can also attack endothelial cells lining the vascular wall and trigger apoptosis. Endothelial cells also produce reactive oxygen species inside the cell that can contribute to oxidative stress and apoptosis, such as during reperfusion injury following ischemia. Superoxide dismutase (SOD) converts highly reactive and damaging superoxide free radicals to peroxides that are less reactive than superoxide but stimulate apoptosis. The glutathione (GSH) peptide reducing agent removes toxic metabolites and repairs damage created by reactive oxygen species. Glutathione peroxidase (GPx), for example, removes peroxides using glutathione as a reducing agent, and glutathione reductase (GSR) regenerates reduced glutathione. Inside the endothelial cell peroxide can be converted to hydroxyl ions in the presence of iron. Peroxides and hydroxyl radicals activate NF-kB and activate expression of inflammatory genes including adhesion molecules, TNF and IL-8. The apoptotic response of endothelial cells to oxidative stress may be involved in the development and progression of atherosclerosis.

Standard name | BIOCARTA_GABA_PATHWAY
Systematic name | M477
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Gamma-aminobutyric Acid Receptor Life Cycle
Full description | Gamma-amino butyric acid (GABA) is an inhibitory neurotransmitter that acts at synapses through binding to ligand-gated ion channels, the GABA receptors. Clustering of the GABA-A receptor chloride channel alters receptor pharmacology on the cell surface and reduced clustering of the GABA receptor is associated with anxiety. GABA-A interacts with several proteins that modulate its clustering, endocytosis, and recycling or degradation. Plic-1 is a ubiquitin-like protein that binds to GABA-A receptors and causes them to accumulate at inhibitory synapses. Gephyrin interacts with the cytoplasmic domain of GABA-A, and with microtubules, bringing receptors together in plasma microdomains. Curiously, Gephyrin appears to be a bifunctional protein, with a domain involved in molybdenum metabolism. Another protein interacting with the GABA-A receptor is GABARAP, a microtubule-associated protein. Anchoring of the GABA-A receptor to GABARAP helps to cluster the receptor at the synaptic termini and to mediate fast synaptic transmission. GABARAP may mediate interaction of gephyrin with the GABA-A receptor and gephyrin may stabilize clusters by forming multimeric structures. GABARAP and gephyrin may play more of a role in receptor sorting and transport to the cell surface than in anchoring to the cytoplasm, since at inhibitory synapses GABARAP appears to associated with transport vesicles rather than the cell surface. The association of GABARAP with NSF (N-ethyl maleimide sensitive factor), a protein involved in intracellular vesicle transport, supports this hypothesis.

Standard name | BIOCARTA_GATA3_PATHWAY
Systematic name | M1394
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | GATA3 participate in activating the Th2 cytokine genes expression
Full description | CD4+ helper T cells differentiate into distinct subtypes, Th1 and Th2 cells. Th2 cells are involved in the response to extracellular helminthe parasites and allergic responses and secrete a distinct set of cytokines including IL-4, IL-5 and IL-13. The development and differentiation of T cells is influenced by many factors, including transcription factors such as GATA-3, a transcription factor associated with induction of Th2 cells. Factors that increase cAMP levels in Th2 cells activate p38 kinase, which phosphorylates and activates GATA-3 independently of PKA. Cells expressing GATA-3 develop the profile of Th2 cells, secreting IL-4, IL-5 and IL-13. These cytokines are found in a gene cluster together and are regulated coordinately by GATA-3. Binding of GATA-3 in the regulatory regions of these genes alters chromatin structure, increasing accessibility to other transcription factors. Activation of the T cell receptor through interaction with antigen on antigen presenting cells activates NFAT and other transcription factors that cooperate with GATA-3 in inducing Th2 cell differentiation. Dominant negative GATA-3 can repress the secretion of these cytokines and block the airway inflammation that causes asthma. Blocking GATA-3 action such as through antisense treatment has been suggested as a therapeutic strategy to treat asthma. GATA-3 has also been implicated in developmental processes such as the development of the inner ear.

Standard name | BIOCARTA_SET_PATHWAY
Systematic name | M3075
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Granzyme A mediated Apoptosis Pathway
Full description | One mechanism used by cytotoxic T cells to kill tumor cells and virus-infected cells is the release of perforin and granzyme proteins. Perforin proteins form pores in the membranes of the attacked cell, allowing the entry of Granzyme A and Granzyme B. Granzyme B induces caspase activation and cleavage of factors like ICAD, releasing DFF40 to fragment DNA, one of the hallmarks of apoptotic cell death. Granzyme A is also an abundant granzyme released by cytotoxic T cells and is important in cytotoxic T cell induced apoptosis, activating caspase independent pathways. Once in a cell, Granzyme A activates DNA nicking by the recently identified DNAse NM23-H1, a tumor suppressor gene product whose expression is reduced in transformed, metastatic cells. The previous identification of NM23-H1 as a tumor suppressor indicates that its DNAse activity plays an important role in immune surveillance to prevent cancer through the induction of tumor cell apoptosis. The activation of NM23-H1 occurs indirectly, through the cleavage of proteins that inhibit NM23-H1 in the SET complex, which includes SET, Ape1, pp32 and HMG2. SET is a substrate for the Granzyme A protease, and SET cleavage relieves NM23-H1 inhibition to cause apoptotic DNA degradation. In addition to inhibiting NM23-H1, SET has nucleosome assembly activity and also may help the interaction of transcriptional regulation with chromatin structure by interacting with the transcriptional coactivator CBP. The targets of Granzyme A found in the SET complex also have other important functions. Ape1 repairs oxidative DNA damage, reduces transcription factors involved in immediate early responses, and its cleavage by Granzyme A may contribute to DNA degradation and apoptosis. HMG2 is an acidic chromatin-associated protein that bends DNA, alters chromatin structure and alters the accessibility of genes for transcription. In addition to acting as a nucleosome assembly factor and an inhibitor of NM23-H1, SET inhibits DNA and histone methylation by the CBP transcriptional coactivator. The tumor suppressor pp32 is not cleaved by Granzyme A but is part of the SET complex. Other targets of Granzyme A include nuclear lamins responsible for maintaining nuclear structure and histones, the basic building blocks of chromatin structure. The common involvement of the proteins of the SET complex in chromatin structure and DNA repair suggest that they work together to protect chromatin and DNA structure and that inactivation of the complex contributes to apoptosis by blocking the maintenance of DNA and chromatin structural integrity.

Standard name | BIOCARTA_GH_PATHWAY
Systematic name | M9043
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Growth Hormone Signaling Pathway
Full description | Growth hormone plays a major role in regulating growth during childhood and adolescence and also regulates metabolism. Defects in growth hormone signaling can result in dwarfism and decreases in growth hormone levels with age have been suggested to play a role in the reduced function of some physiological systems. Growth hormone signals a response in cells through the growth hormone receptor, a member of the cytokine receptor gene family. Growth hormone causes the receptor to dimerize, activating the JAK2 protein kinase. The activity of JAK2 mediates many of the downstream responses to growth hormone through phosphorylation of STAT transcription factors, MAP kinases, other kinase cascades and molecules involved in metabolism like IRS-1. Factors like SOCS and SHP-1 appear to play a role in the down regulation of signaling by growth hormone and cytokines.

Standard name | BIOCARTA_AHSP_PATHWAY
Systematic name | M19553
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Hemoglobin's Chaperone
Full description | The function of hemoglobin in oxygen transport by red blood cells requires precise assembly of a tetramer of two beta-subunits and two alpha-units. If too many beta-subunits are present, then all tetramers of beta-subunits are formed that bind oxygen but do not release it when needed. When alpha-subunits are in excess they form precipitates with oxidized heme that damage red blood cells. Red blood cells require a precise coregulation of alpha and beta subunit expression to maintain the proper ratio of the subunits and normal red blood cell function. Generally red blood cells express slightly more alpha than beta-subunits to avoid forming unproductive beta-tetramers (HbH). The slight excess of alpha units are blocked from precipitation by a molecular chaperone, AHSP, alpha-hemoglobin stabilizing protein. Expression of the AHSP gene is coordinately activated with the globin genes and heme biosynthesis genes by the GATA-1 gene involved in erythrocyte differentiation. AHSP blocks precipitation of alpha-units, and promotes the formation of normal productive alpha-beta tetramers (HbA). People with mutation or deletion of the beta-subunit gene have Beta-thalassemias resulting from an over-abundance of alpha subunits and their precipitation. The severity of the phenotype may depend on the AHSP genotype of these individuals and elevating AHSP levels through gene therapy may provide a treatment strategy for beta-thalassemia.

Standard name | BIOCARTA_TCAPOPTOSIS_PATHWAY
Systematic name | M16519
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | HIV Induced T Cell Apoptosis
Full description | HIV infection is associated with immunosuppression caused by a dramatic reduction in the helper T cell population. The loss of helper T cells may be caused by HIV-induced apoptosis of both infected and uninfected helper T cells. HIV uses the CCR5 chemokine receptor as a coreceptor for macrophage cell entry and upregulates fas-ligand on these cells. CD4 on helper T cells is essential for viral cell entry and infection. Cross-linking of CD4 on the T cell surface may be involved in upregulation of Fas and sensitization of T cells to apoptosis induced by the Fas/Fas-ligand interaction.

Standard name | BIOCARTA_HIVNEF_PATHWAY
Systematic name | M13968
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | HIV-I Nef: negative effector of Fas and TNF
Full description | HIV infection leads to drastic declines in CD4 T helper cells, in part through apoptosis of uninfected cells. Apoptosis of uninfected cells may be induced through the expression of Fas ligand on the surface of HIV-infected cells, stimulating the Fas-dependent apoptotic pathway in cells that come in contact with infected cells. The NEF protein expressed by HIV may play induce the expression of Fas-ligand by infected cells. If this is the case, then a question that arises is how infected cells themselves escape Fas-mediated apoptosis. The NEF protein appears to play a role in this process as well. NEF interacts with the ASK1 kinase (apoptosis signal-regulating kinase) involved in apoptotic signaling by TNF and Fas-ligand. Interaction of NEF with ASK1 prevents phosphorylation of downstream MAP kinases and JNK kinases involved in apoptotic signaling.

Standard name | BIOCARTA_SALMONELLA_PATHWAY
Systematic name | M16120
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | How does salmonella hijack a cell
Full description | Pathogenic Salmonella enter cells such as those of the intestinal epithelium by altering cellular cytoskeletal structure and inducing membrane ruffling of the infected cell. Salmonella is able to alter the cytoskeleton and membrane through the action of secreted bacterial Sip proteins, SopE, SopB, and SptP that are inserted into the cytosol of the infected cell. Sip proteins encoded by Salmonella are required for the action of SopE and for the invasion of epithelial cells. SipA stabilizes actin filaments, inducing membrane ruffling and perhaps focusing membrane changes where bacteria are localized to allow their entry. SipC produces a similar effect on actin filaments and cytoskeletal structure. SopE acts as an exchange factor on Rac1 and Cdc42, two GTPases in the Rho family that regulate actin cytoskeleton. The activation of Rac2 and Cdc42 by Salmonella SopE induces changes in cytoskeleton structure that allow bacterial entry into the cell. SopB is another salmonella protein that acts as an inositol polyphosphate phosphatase and also stimulates Cdc42 and Rac1. One of the cellular targets of both Cdc42 and Rac1 that affects actin structure is the Arp2/3 complex. Cdc42 and Rac1 activate Wasp, which activates Arp2/3. Activated Arp2/3 induces the formation of actin Y branches, which in combination with changes in actin caused by SipA and SipC help to form lamellipodia, and causes membrane ruffling, leading to entry of Salmonella into the affected cell. After the initial infection, cells quickly return to their normal morphology, a process that depends on the action of the bacterial protein SptP. While SopE acts as an exchange factor, SptP acts as a GTPase activating protein to inactivate Rac1 and Cdc42 once again. This inactivation of the original entry mechanism provides an example of the delicate balance between infectious organisms and their host.

Standard name | BIOCARTA_MPR_PATHWAY
Systematic name | M13883
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | How Progesterone Initiates the Oocyte Maturation
Full description | Progesterone (Pg) binds to both intracellular iPR and plasma membrane- bound mPR. (Right Top) After binding to Pg, iPR is recruited to the membrane associated protein tyrosine kinase p60c- src, which induces activation of the MAPK signaling pathway. This results in activation of p90Rsk and the subsequent phosphorylation and inactivation of Myt1, which favors formation of the activated cell cycle complex cyclin B-Cdc2. Activation of cyclin B-Cdc2 causes breakdown of the germinal vesicle and the initiation of oocyte maturation. (Left). In contrast, binding of Pg to mPR leads to inhibition of adenylyl cyclase (AC) through activation of Gi or inhibition of Gs. This leads to a decrease in the cAMPdependent kinase PKA, which relieves inhibition of Cdc25C (the phosphatase that dephosphorylates and activates cyclin B-Cdc2) and also indirectly promotes the activation of MAPK signaling. PKA also regulates the initiation of oocyte maturation through other effects that are independent of PKA activity.

Standard name | BIOCARTA_HCMV_PATHWAY
Systematic name | M8353
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Human Cytomegalovirus and Map Kinase Pathways
Full description | To replicate in the host cell, viruses commandeer cellular signaling pathways. Cytomegalovirus (CMV) is a DNA virus with that is widespread in the population but usually causes disease only in immunocompromised individuals and is also a viral cause of birth defects. One of the actions of CMV in the host cell is to stimulate MAP kinase pathways. Both p38 and ERK kinases are activated by CMV infection through activation map kinase kinases and inhibition of phosphatases. One result of Map kinase activation by CMV is activation of transcription of viral genes, increasing the production of viral gene products. Both p38 and ERK kinases contribute to the activation of viral genes by cellular transcription factors acting through the viral UL4 promoter at upstream and basal transcription elements. Another target of prolonged p38 activation during infection is Rb, contributing to viral replication. Activation of MKK1 and MKK2 leads to Erk1 and Erk2 activation, and phosphorylation of downstream targets. The MEKK1 kinase regulates the immediate early promoter indirectly through downstream kinase signaling and perhaps more directly through activation of NF-kB. Map kinase pathways activated by CMV converge on increased transcription of viral genes and increased replication of the viral genome. Better understanding of the mechanisms involved in the interaction of CMV with cellular signaling machinery will provide improved ways to treat CMV-mediated disease.

Standard name | BIOCARTA_P53HYPOXIA_PATHWAY
Systematic name | M5202
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Hypoxia and p53 in the Cardiovascular system
Full description | Hypoxic stress, like DNA damage, induces p53 protein accumulation and p53-dependent apoptosis in oncogenically transformed cells. Unlike DNA damage, hypoxia does not induce p53-dependent cell cycle arrest, suggesting that p53 activity is differentially regulated by these two stresses. Hypoxia induces p53 protein accumulation, but in contrast to DNA damage, hypoxia fails to induce endogenous downstream p53 effector mRNAs and proteins, such as p21, Bax, CIP1, WAF1 etc. Hypoxia does not inhibit the induction of p53 target genes by ionizing radiation, indicating that p53-dependent transactivation requires a DNA damage-inducible signal that is lacking under hypoxic treatment alone. The phosphatidylinositol 3-OH-kinase-Akt pathway inhibits p53-mediated transcription and apoptosis. Mdm2, a ubiquitin ligase for p53, plays a central role in regulation of the stability of p53 and serves as a good substrate for Akt. Mdm-2 targets the p53 tumor suppressor for ubiquitin-dependent degradation by the proteasome, but, in addition, the p53 transcription factor induces Mdm-2, thus, establishing a feedback loop. Hypoxia or DNA damage by abrogating binding of HIF-1 with VHL and p53 with Mdm-2, respectively, leads to stabilization and accumulation transcriptionally active HIF-1 and p53. At the molecular level, DNA damage induces the interaction of p53 with the transcriptional activator p300 as well as with the transcriptional corepressor mSin3A. In contrast, hypoxia primarily induces an interaction of p53 with mSin3A, but not with p300.

Standard name | BIOCARTA_HIF_PATHWAY
Systematic name | M13324
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Hypoxia-Inducible Factor in the Cardiovascular System
Full description | Hypoxia (or low O2 levels) affects various pathologies. First, tissue ischemia, a variation in O2 tension caused by hypoxia/reoxygenation, can lead to endothelial cell changes. For example, long periods of ischemia result in endothelial changes, such as vascular leakage, resulting in varicose veins. In more severe situations, ischemia can lead to myocardial or cerebral infarction and retinal vessel occlusion. Of interest, HIF-1 is stabilized prior to induction of vascular endothelial growth factor (VEGF) expression during acute ischemia in the human heart. Second, pulmonary hypertension associated with chronic respiratory disorders results from persistent vasoconstriction and vascular remodeling. Third, hypoxic gradients created in enlarging solid tumors trigger expression of genes containing hypoxia response element (HRE)s such as those involved in angiogenesis. This allows subsequent delivery of O2, nutrients, and further tumor growth. Vascular remodeling is an important component to tumorigenesis; without proper blood supply, delivery of oxygen may occur by diffusion, but becomes inefficient in tumors greater than 1 mm in diameter. Short-term hypoxia can also elevate platelet numbers, while prolonged exposure may cause some degree of thrombocytopenia in response to increased levels of erythropoetin (EPO). Another disorder involving inadequate responses to hypoxia is preeclampsia, a pathology of pregnancy thought to be caused by improper differentiation of placental trophoblast cells due to poorly controlled O2 tension or improper hypoxia-inducible factor (HIF)-mediated responses. The primary molecular mechanism of gene activation during hypoxia is through HIF-1. Several genes involved in cellular differentiation are directly or indirectly regulated by hypoxia. These include EPO, LDH-A, ET-1, transferrin, transferrin receptor, VEGF, Flk-1, Flt-1, platelet-derived growth factor- (PDGF-), basic fibroblast growth factor (bFGF), and others genes affecting glycolysis. HIF-1 is a member of the basic helix-loop-helix (bHLH)-PAS family of transcription factors known to induce gene expression by binding to a ~50-bp HRE containing a core 5'-ACGTG-3' sequence. bHLH-PAS proteins heterodimerize to form transcription complexes that regulate O2 homeostasis, circadian rhythms, neurogenesis, and toxin metabolism. Three bHLH-PAS proteins in vertebrates respond to hypoxia: HIF-1 , EPAS (HIF-2 ), and HIF-3. These dimerize with ARNT (aryl hydrocarbon receptor nuclear translocator protein), ARNT-2, or ARNT-3. HIF-1 is ubiquitinated and subsequently degraded in less than 5 minutes under normoxic conditions. Although several candidate O2-sensing molecules have emerged in the literature, the molecular basis of how cells sense O2 levels is poorly characterized. pVHL, the protein product of a tumor-suppressor gene responsible for von Hippel Lindau disease, is implicated in this O2-sensing system by its association with HIF-1 , targeting it for ubiquitin-mediated degradation. Similarly, F-box-containing proteins recognize substrates of the ubiquitin ligases, targeting them for phosphorylation-dependent ubiquitination and proteosomal degradation. In addition to F-boxes, most of these proteins also contain a WD40 or a leucine-rich repeat (LLR) domain that presumably functions as a Ser/Thr binding module. A second family of proteins assisting the ubiquitin ligases share a region designated SOCS-box (originally from the suppressor of cytokine signaling proteins SOCS). Under low O2 (&lt;5% O2) HIF-1 is stabilized leading to the formation of a functional transcription factor complex with ARNT. This complex is the master regulator of O2 homeostasis and induces a network of genes involved in angiogenesis, erythropoiesis, and glucose metabolism.

Standard name | BIOCARTA_IGF1_PATHWAY
Systematic name | M2623
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IGF-1 Signaling Pathway
Full description | Insulin like growth factor 1 (IGF-1) and its receptor (IGF-1R) provide a potent proliferative signaling system that stimulates growth in many different cell types and blocks apoptosis. In vivo IGF-1 acts as an intermediate of many growth hormone responses, and may stimulate the growth of some types of cancer. IGF-1 also provides a mitogenic signal to act as a growth factor for many tissue culture cells. One component of IGF-1 mitogenic signaling is association of the receptor tyrosine kinase with Shc, Grb2, and Sos-1 to activate ras and the Map kinase cascade (raf, Mek, Erk). An endpoint of the Map kinase pathway is modification of transcription factor activity, such as activation of ELK transcription factors. Serum response factor (SRF) and AP-1 contribute to mitogenic signaling by many factors. Phosphorylation of IRS-1 and PI3 kinase activation are also involved in IGF-1 signaling, similar to insulin signaling.

Standard name | BIOCARTA_IL17_PATHWAY
Systematic name | M19422
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL 17 Signaling Pathway
Full description | Inflammation is a complex response involving many different cells and signaling molecules, including the secretion of the cytokine IL-17 by activated T cells. IL-17 secretion is restricted to specific subsets of T cells but the receptor for IL-17 is widely expressed throughout the body, including fibroblasts and epithelial cells. Inflammatory responses involving IL-17 probably contribute to arthritis, asthma, skin immune reactions and autoimmune disorders. Fibroblasts and other cells stimulated by IL-17 are induced themselves to secrete inflammatory and hematopoietic cytokines, including IL-6, IL-8, G-CSF and Stem Cell Factor (SCF). These cytokines in turn provoke a range of activities, including the stimulation of neutrophil proliferation and differentiation.

Standard name | BIOCARTA_IL2_PATHWAY
Systematic name | M7747
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL 2 signaling pathway
Full description | Interleukin 2 (IL-2) is a potent cytokine that can lead to cellular activation and proliferation. IL-2 Receptors are found on activated B-Cells, LPS treated Monocytes, and many T cells. The receptor is formed from three chains alpha (CD25), beta (CD122), and gamma (CD132). Primary signaling is through the JAK/Stat pathway and MAPKs.

Standard name | BIOCARTA_IL3_PATHWAY
Systematic name | M17681
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL 3 signaling pathway
Full description | Interleukin-3 promotes the proliferation and differentiation of hematopoietic cells through binding to its receptor. The receptor for IL-3 is a heterodimer with a ligand-specific alpha chain (70 kD, CD123) and a common beta chain (shared with IL-5 and GM-CSF). Signaling is believed to be primarily through Stat5 and the MAPK pathways.

Standard name | BIOCARTA_IL4_PATHWAY
Systematic name | M5415
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL 4 signaling pathway
Full description | Interleukin 4 (IL-4) is a cytokine that can lead to development of Th2 cells. The 140 kD IL-4 Receptor (CD124) is found on many cell types, even those of non-hematopoietic origen. The receptor is formed from two chains: IL-4R(alpha) and the IL-2R gamma chain (CD132). Primary signaling is through the JAK/Stat6 pathway and MAPKs.

Standard name | BIOCARTA_IL5_PATHWAY
Systematic name | M18928
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL 5 Signaling Pathway
Full description | IL-5 is an inflammatory signaling molecule that primarily stimulates eosinophil proliferation, maturation and activation. Eosinophils are leukocytes involved in inflammatory responses that defend against parasites and cause some aspects of asthma, allergic reactions, and perhaps autoimmune disorders. The action of IL-5 begins with an immune response in tissues, such as activation of macrophages and T cells that secrete IL-1, IL-4 and IL-6. The immune response can lead to IL-5 secretion by T cells, eosinophils and mast cells. Secreted IL-5 stimulates production and maturation of eosinophils in bone marrow that migrate to tissues in response to eotaxin and release factors that damage tissues, causing some of the undesirable consequences of inflammation. The receptor for IL-5 is a heterodimer of an alpha subunit that is required for IL-5 selective binding and a beta subunit that is also part of the IL-3 and GM-CSF receptors. Binding of IL-5 to the IL-5 receptor at the cell surface activates JAK/STAT signaling pathways that regulate transcription, proliferation, and differentiation.

Standard name | BIOCARTA_IL6_PATHWAY
Systematic name | M5489
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL 6 signaling pathway
Full description | Interleukin-6 (IL-6) is a cytokine that provokes a broad range of cellular and physiological responses. In addition to playing a role in inflammation and hematopoiesis, IL-6 is involved in other processes such as neuronal differentiation and bone loss. To produce these effects IL-6 signals through a receptor composed of two different subunits, an alpha subunit that produces ligand specificity and gp130, a receptor subunit shared in common with other cytokines in the IL-6 family. Binding of IL-6 to its receptor initiates cellular events including activation of JAK kinases and activation of ras-mediated signaling. Activated JAK kinases phosphorylate and activate STAT transcription factors, particularly STAT3, that move into the nucleus to activate transcription of genes containing STAT3 response elements. The ras-mediated pathway, acting through Shc, Grb-2 and Sos-1 upstream and activating Map kinases downstream, activates transcription factors such as ELK-1 and NF-IL-6 (C/EBP-beta) that can act through their own cognate response elements in the genome. These factors and other transcription factors like AP-1 and SRF (serum response factor) that respond to many different signaling pathways come together to regulate a variety of complex promoters and enhancers that respond to IL-6 and other signaling factors.

Standard name | BIOCARTA_IL10_PATHWAY
Systematic name | M6778
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL-10 Anti-inflammatory Signaling Pathway
Full description | IL-10 is a cytokine with potent anti-inflammatory properties, repressing the expression of inflammatory cytokines such as TNF-alpha, IL-6 and IL-1 by activated macrophages. The IL-10 receptor is in the JAK/STAT class of receptors but activation of the JAK/STAT pathways by IL-10 does not appear on its own to be responsible for the anti-inflammatory properties of this cytokine. The anti-inflammatory actions of IL-10 appear to require induction of the enzyme heme oxygenase-1 (HO-1) through a map kinase pathway involving the p38 kinases. HO-1 is involved in the biosynthesis of heme, and catalyzes a reaction producing carbon monoxide, free iron, and the heme precursor biliverdin. HO-1 is induced by IL-10 and is also induced by oxidative stress. Blocking HO-1 with inhibitors or antisense blocks the anti-inflammatory actions of IL-10. The anti-inflammatory actions of HO-1 appear to be the result of signaling by carbon monoxide it produces since removal of CO blocks the anti-inflammatory action of IL-10 and HO-1. The anti-inflammatory actions of IL-10 may be therapeutically useful either directly or through modulation of HO-1 activity.

Standard name | BIOCARTA_IL12_PATHWAY
Systematic name | M4319
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL12 and Stat4 Dependent Signaling Pathway in Th1 Development
Full description | Interleukin-12 (IL-12) promotes cell-mediated immunity by inducing Th1 cell differentiation and activation of both T cells and NK cells. Dendritic cells and macrophages in peripheral tissues act as antigen presenting cells and secrete IL-12 as one component of the antigen response, Th1 differentiation. The role of IL-12 in cellular immunity is largely mediated by the STAT-4 transcription factor. STAT-4 is essential for IL-12 activity and the phenotype of mice lacking STAT-4 is very similar to the phenotype of mice lacking the IL-12 receptor or IL-12. The role of IL-12 in Th1 differentiation may not be to induce the Th1 cell fate, but to stimulate growth of cells determined for the Th1 cell fate by the T-bet transcription factor. Several signaling pathways contribute to IL-12 activation of STAT-4 to regulate cell-mediated immune responses. The JAK kinases such as JAK2 and TYK2 interact with the activated IL-12 receptor and tyrosine phosphorylate the IL-12 receptor and STAT-4. IL-12 also activates a map kinase pathway activating the map kinase kinase MKK6 and p38. Phosphorylation of STAT-4 on serine 721 by p38 contributes to the full transcriptional activation of genes by STAT-4. Some of the events downstream of IL-12 appear to include genes activated indirectly by STAT-4, such as genes activated by the transcription factor ERM. ERM is in the Ets family of transcription factors, is activated by IL-12 and activates IL-12 inducible genes such as Interferon-gamma that are not activated by STAT-4 itself. Interferon-gamma transcription in T cells is also activated by other signals such as from the T cell receptor. Other proteins activated transcriptionally downstream of IL-12 and STAT-4 include the chemokine receptor CCR5 and IL-18 and its receptor. Some viruses, including HIV, repress cell-mediated immunity by blocking IL-12 signaling.

Standard name | BIOCARTA_IL2RB_PATHWAY
Systematic name | M8615
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL-2 Receptor Beta Chain in T cell Activation
Full description | The IL-2 receptor is a key component of immune signaling and is required for the activation, proliferation, and survival of T cells. This receptor is composed of three polypeptide chains, the alpha, beta and gamma chains. The IL-2 receptor gamma chain is a common component for several other cytokine receptors, including IL-4, IL-7, IL-9 and IL-15. The IL-2 receptor beta chain is essential for IL-2 signaling and is also a component of the IL-15 receptor complex. The polypeptides of the IL-2 receptor do not themselves have intrinsic catalytic activity, but interact with cytoplasmic signaling proteins to transduce signals. br&gt;Different regions of the cytoplasmic domain of the IL-2 receptor beta chain interact and couple with distinct signaling pathways and cellular responses. JAK1 associates with the beta chain, and JAK3 with the gamma chain. Binding of IL-2 induces heterodimerization of receptor subunits, and activation of JAK kinase activity. Tyrosine residues in the beta chain cytoplasmic domain are phosphorylated during activation, recruiting other factors to the phosphorylated tyrosine residues through src homology 2 (SH2) domains. The adaptor protein Shc binds to phosphorylated tyrosine 338 of the beta chain. When bound, Shc is phosphorylated and couples through Grb2 and Sos-1 to activate Ras and stimulate T cell proliferation. Another key proliferative pathway activated by IL-2 is phosphorylation of STAT-5 by JAK kinases. STAT-5 is recruited to IL-2 beta phosphorylated tyrosines at multiple positions, including Y338, Y392 and Y510. Once phosphorylated, STAT-5 enters the nucleus to regulate the transcription of several genes, some proliferative such as cyclin genes and others that are involved in T cell immune function such as cytokine genes. The suppressors of cytokine activation, SOCS-3 and SOCS-1, oppose phosphorylation and activation of STAT-5 and JAK1 caused by IL-2. PI3 kinase is another protein recruited to IL-2 receptor beta chain tyrosines when phosphorylated. Activation of PI3 Kinase also contributes to the proliferative activity of IL-2 in T cells. The role of other tyrosines in the IL-2 receptor beta chain, Y355, Y358 and Y361, is not yet clear, but may be involved in signaling by the protein kinase p56lck. In addition to stimulating T cell activation and proliferation, IL-2 activation blocks T cell apoptosis through multiple pathways. Among the genes activated by STAT-5 are BCL-xL, an inhibitor of apoptosis, and fas-ligand, an activator of apoptosis in cells expressed the fas receptor. PI3 kinase also contributes to anti-apoptotic activity of IL-2 through AKT activation. T cell responses to IL-2 must be coordinated in part in the complex protein-protein interactions with the IL-2 receptor beta chain.

Standard name | BIOCARTA_IL22BP_PATHWAY
Systematic name | M8066
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL22 Soluble Receptor Signaling Pathway
Full description | IL-22 is an inflammatory cytokine related to IL-10 that is produced by T cells and that induces a response in cells through a heterodimeric cell surface receptor composed of IL-22R1 and IL-10R2C. One of the actions of IL-22 appears to be the induction of the acute phase inflammatory response in hetapocytes, acting through activation of STATs and transcriptional regulation. A gene with homology to the extracellular domain of the cell surface IL-22R1 receptor component was identified that lacked transmembrane and cytoplasmic domains. The protein derived from this gene was found to bind IL-22 and block its interaction with the cell surface receptor. The IL-22 soluble receptor (IL-22BP, IL-22 binding protein) also blocks some of the downstream effects of IL-22 such as STAT activation and the transcriptional induction of genes involved in the immune and inflammatory responses. The IL-22 soluble receptor may act as an anti-inflammatory agent.

Standard name | BIOCARTA_IL7_PATHWAY
Systematic name | M1296
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IL-7 Signal Transduction
Full description | IL-7 is a key cytokine in the immune system, essential for normal development of B cells and T cells. Mice with the IL-7 receptor deleted lack B and T cells. Some humans with SCID (severe combined immunodeficiency disease) also have mutation of their IL-7 receptor gene leading to an absence of T cells and greatly impaired B cell production. The IL-7 receptor includes two polypeptides, a gamma chain and an alpha chain. The alpha-chain is unique to the IL-7 receptor while several other cytokines use the same gamma receptor chain as IL-7, including IL-2, IL-4, IL-9, IL-15 and IL-21. Binding of IL-7 to the alpha chain leads to dimerization of the alpha and gamma chains. JAK3 associated with the gamma chain tyrosine phosphorylates the alpha chain after dimerization. The importance of JAK3 in IL-7 signaling is supported by the similarity of the immune defects in JAK3 knockout mice and IL-7 knockout mice. The phosphorylated alpha chain serves as the site for recruiting other signaling molecules to the complex to be phosphorylated and activated, including STAT5, src kinases, PI3 kinase, Pyk2 and Bcl2 proteins. Some targets of IL-7 signaling contribute to cellular survival, including Bcl2 and Pyk2. Other targets contribute to cellular proliferation, including PI3 kinase, src family kinases (lck and fyn) and STAT5. The transcription factor STAT5 contributes to activation of multiple different downstream genes in B and T cells and may contribute to VDJ recombination through alteration of chromatin structure. The cell survival and cell proliferation signals induced by IL-7 combine to induce normal B and T cell development.

Standard name | BIOCARTA_GSK3_PATHWAY
Systematic name | M11106
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Inactivation of Gsk3 by AKT causes accumulation of b-catenin in Alveolar Macrophages
Full description | Lipopolysaccharide. One of the key actions of AKT is to block apoptosis. AKT phosphorylation of NF-kB promotes the survival and activation of macrophages responding to LPS. Another substrate of AKT is the protein kinase Gsk3-beta. AKT phosphorylates and deactivates Gsk3-beta. Non-phosphorylated Gsk3-beta is active and phosphorylates beta-catenin, leading to its degradation in the ubiquitin dependent proteosome pathway. Stimulation by LPS causes the accumulation of beta-catenin in the nucleus and the activation of genes in concert with the transcription factor LEF1. This pathway is probably not restricted to alveolar pathway, but leads to the activation of beta-catenin dependent genes by LPS in other cells as well. Other pathways regulate this pathway also, such as the modulation of PI3 kinase activity by ceramide, and the inhibition of Gsk3-beta activity by the Wnt/frizzled/disheveled (DSH) pathway.

Standard name | BIOCARTA_DEATH_PATHWAY
Systematic name | M14971
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Induction of apoptosis through DR3 and DR4/5 Death Receptors
Full description | Apoptosis is specifically induced via signaling through a family of receptors known collectively as 'death receptors' including Fas, TNFR, DR3, -4 and -5. Death receptor ligands characteristically initiate signaling via receptor oligomerization, recruitment of specialized adaptor proteins and activation of caspase cascades. Apo3L recruits initiator caspase 8 via the adapter protein FADD. Caspase 8 then oligomerizes and is activated via autocatalysis. Activated caspase 8 stimulates apoptosis via two parallel cascades: it directly cleaves and activates caspase-3, and it cleaves Bid (a Bcl-2 family protein). Truncated Bid (tBid) translocates to mitochondria, inducing cytochrome C release, which sequentially activates caspases 9 and 3. DR-3L can deliver pro- or anti-apoptotic signals. DR-3 promote apoptosis via the adaptor proteins TRADD/FADD and the activation of caspase 8. Alternatively, apoptosis inhibited via an adaptor protein complex including RIP which activates NF-kB and induces survival genes including IAP. Induction of apoptosis via Apo2L requires caspase activity, but the adaptor requirement is unclear.

Standard name | BIOCARTA_RACCYCD_PATHWAY
Systematic name | M14512
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Influence of Ras and Rho proteins on G1 to S Transition
Full description | The cell cycle transition from G1 to S phase is a key regulatory point in the cell cycle. This transition is regulated by the checkpoint kinase cdk2 that activates the G1 to S transition when it is associated with cyclin E. Cdk2/Cyclin E causes the G1 to S transition through phosphorylation of the tumor suppressor Rb, releasing the transcription factor E2F-1. Other pathways acting through Rac, Ras and Rho also regulate the G1 to S transition. Ras regulates cyclin D1 expression to affect the G1 to S transition. Transforming forms of Ras or Raf induce cyclin D1 expression and cause early entry into S phase. Signaling from Ras to Raf to MEK to ERKs induces Cyclin D1 expression, allowing Cyclin D1 to complex with Cdk4 and Cdk6 and phosphorylate Rb. Rac-1 and PAK appear to induce Cyclin D1 expression and induce the G1 to S transition primarily through activation of NF-kB to activate the Cyclin D1 promoter. Rho activates cdk2 and also inhibits p21 and p27 to induce cyclin D1 and stimulate the G1 to S transition. Rho represses p21 expression to block p21 induction by Ras and to allow Ras induced progression from G1 to S. Cells that lack p21 do not require Rho for Ras to induce cell cycle progression from G1 to S phase. The cooperative action of Ras, Rac and Rho to induce Cyclin D1 expression is a key component of oncogenic transformation.

Standard name | BIOCARTA_GLEEVEC_PATHWAY
Systematic name | M7897
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Inhibition of Cellular Proliferation by Gleevec
Full description | The drug Gleevec (also known as imatinib mesylate or STI-571) was approved by the FDA in 2001 for the treatment of CML, chronic myeloid leukemia. While traditional cytotoxic cancer treatments such as chemotherapy or radiation therapy kill all dividing cells, Gleevec acts on a molecular target by a mechanism that is more specific to cancer cells. Traditional cytotoxic cancer agents have serious side effects such as nausea, weight loss, hair loss and severe fatigue that result from their lack of specificity in killing cells. Gleevec was designed as an inhibitor of a specific receptor associated with CML, and so produces less severe side effects than other cancer agents. CML is associated in most cases with a specific chromosomal defect, a translocation between chromosomes 9 and 22 that creates the Philadelphia chromosome. This translocation occurs at the site in the genome of a protein tyrosine kinase called abl, creating the abnormal bcr-abl protein, a fusion of the abl gene with another gene called bcr. The kinase activity of abl in the bcr-abl fusion is activated and unregulated, driving the uncontrolled cell growth observed in CML. White blood cells containing the bcr-abl mutation become able to proliferate in the absence of growth factors they normally require. Gleevec inhibits abl kinase activity, helping to reverse uncontrolled cell growth. Gleevec also inhibits the PDGF tyrosine kinase and the c-kit tyrosine kinase. There are a variety of cellular substrates of the bcr-abl kinase that may be involved in cellular transformation. Bcr-abl is associated with the cytoplasm as part of a large signaling complex. Some of the downstream factors in bcr-abl signaling include PI3 kinase/AKT and STAT transcription factors. The activation of bcr-abl also represses apoptosis through induction of anti-apoptosis factors such as Bad, allowing transformed cells to divide. JAK2 kinase activity appears to be one target of bcr-abl. Grb-2 phosphorylation by bcr-abl may play a role in down-regulation of tyrosine kinase signaling. STAT5 may be involved in the failure of apoptosis in bcr-abl cells. In addition to supporting the idea that cancer therapies targeting specific molecular targets should be efficacious with fewer side effects, Gleevec has also demonstrated that drugs inhibiting protein kinases can be developed successfully. Tyrosine kinases are important in a range of cellular processes, including other cancers, and will provide additional drug targets. Gleevec itself has already demonstrated potential in other cancers such as gastrointestinal stromal tumor that do not respond to existing treatments. Although Gleevec has produced very strong clinical responses in patients with early stage CML, patients with late stage disease have had an initial response followed by a relapse of drug resistant CML cells. Cancer cells in patients with Gleevec resistant cancer either had amplification of the bcr-abl gene, or mutation of a key amino acid involved in binding drug from threonine to isoleucine.

Standard name | BIOCARTA_INSULIN_PATHWAY
Systematic name | M765
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Insulin Signaling Pathway
Full description | The appropriate signaling through the insulin pathway is critical for the regulation of glucose levels and the avoidance of diabetes. Insulin forms a complex with the Insulin Receptor (IR) and b chains to form the active signaling complex. Through recruitment of adaptor molecules and the activation of RAS, the activated IR can cause transcriptional activation.

Standard name | BIOCARTA_INTEGRIN_PATHWAY
Systematic name | M3342
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Integrin Signaling Pathway
Full description | Integrins are cell surface receptors that interact with the extracellular matrix and mediate intracellular signals in response to the extracellular matrix including cellular shape, mobility, and progression through the cell cycle. Integrins do not themselves possess a kinase domain or enzymatic activity but rely on association with other signaling molecules to transmit signals. Interactions between the extracellular matrix and the actin cytoskeleton commonly take place at focal adhesions on the cell surface that contain localized concentrations of integrins, signaling molecules, and cytoskeletal elements. Talin forms a direct interaction with the integrin cytoplasmic domain, and interacts with cytoskeletal elements (actin) and signaling factors. Paxillin and CAS also localize in focal adhesions and may serve as a scaffold for other integrin signaling components like FAK and src. Interaction of FAK, CAS and src may be required for integrin regulation of cell cycle progression. The CrkL adaptor protein may regulate downstream integrin signaling. Growth factor signaling pathways and the caveolin receptor exhibit important cross talk with integrin receptors in cellular responses like activation of map kinase, proliferation and motility.

Standard name | BIOCARTA_INTRINSIC_PATHWAY
Systematic name | M15997
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Intrinsic Prothrombin Activation Pathway
Full description | Blood coagulation or clotting takes place in 3 essential phases. The first phase is the activation of a prothrombin activator complex. The second phase is the activation of prothrombin. The third stage is clot formation as a result of fibrinogen cleavage by activated thrombin. The prothrombin activation complex is formed by two pathways each of which results in a different form of the prothrombin activator. The intrinsic mechanism of prothrombin activator formation begins with trauma to the blood or exposure of blood to collagen in a traumatized vessel wall. This usually also results in damage to fragile platelets. The formation of a clot by this mechanism usually takes 1 to 6 minutes. This cascade begins with the activation of factor XII and the release of platelet factor 3 (PF3) from damaged platelets. Activated factor XII cleaves and actives factor XI and prekallikrein (PK). Factor XII is also activated by activated prekallikrein (aPK) in an internal amplification loop. Calcium (Ca++) is required for the initial three steps. The prothrombin activator in the intrinsic pathway is very similar to the activator in the extrinsic pathway. Antithrombin III inhibits the activity of thrombin and also two of the steps in the formation of the activator. Protein C is activated by thrombin and with the Protein S cofactor provides a strong negative feedback in this phase of clot formation. When blood is collected, the intrinsic pathway is activated by contact with the collection devices causing damage to the platelets and activation of factor XII. Antithrombin III is a hundred to a thousand times more effective when bound by heparin. Use of nonwettable surface materials can increase the clot formation time to over an hour. Disease Significance: Most of the clotting factors are formed in the liver. Diseases of the liver or damage to the liver can depress the levels of these factors in the blood resulting in excessive bleeding. Vitamin K deficiency can also result in a similar condition since Vitamin K is essential for the formation of factor VII, IX, X and prothrombin. Vitamin K is synthesized in the intestinal tract by bacteria.

Standard name | BIOCARTA_KERATINOCYTE_PATHWAY
Systematic name | M19118
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Keratinocyte Differentiation
Full description | The epidermis, which provides a protective barrier that undergoes a constant renewal, is a multi-layered tissue with the proliferating cells located in the basal layer. As cells leave the basal layer the underog significant differentiation, biochemical and morphological remodeling. The final differentiation results in the formation of corneocytes. In vitro keratinocytes mimic this process. Several genes mark keratinocyte specific differentiation. Among the most frequently tracked markers are Transglutaminase, Cystatin and Involucrin. The keratinocyte differentiation studies have identified and provided significant detail regarding the involvement of three of the 4 major MAP kinase pathways from several diverse stimuli such as EGF, FAS, TNF and Calicium influx. The p38 cascade is represented twice since both p38alpha (p38) and p38delta (MAPK13) are involved. The keratinocyte differentiation cascased also provide for detailed study of the functions of individual PKC isoforms. It is interesting to note the contrasting functions of the PKC isoforms in this process. In recent studies it has been determined that the cPKC (conventional/classical Protein Kinase C) isoforms, which are calcium-, phospholipid-, and diacylglycerol-dependent are inhibitory where as the nPKC (novel Protein Kinase C) isoforms which are calcium independent are stimulatory for keratinocyte differentiation markers. On the right hand side is an earlier step showing the upregulation loop of TRAF2. This step occurs prior to the activation os ASK1 and the p38 cascade.

Standard name | BIOCARTA_TCRA_PATHWAY
Systematic name | M10765
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Lck and Fyn tyrosine kinases in initiation of TCR Activation
Full description | T cell activation is initiated by recognition of antigen by the T cell receptor (TCR) in the context of Class II MHC on an antigen-presenting cell. The T cell receptor contains multiple subunits and interacts with several factors to transduce antigen-stimulated T cell activation. One of the key steps that initiates receptor activation is the tyrosine phosphorylation of TCR subunits by the src family protein kinases Lck and Fyn. T cell receptor phosphorylated by Lck and Fyn recruits the ZAP-70 protein kinase to the receptor complex, which becomes activated and stimulates downstream pathways like the Map kinase cascade. The CD45 protein tyrosine phosphatase activates Lck and Fyn by dephosphorylating these proteins and is required for TCR activation. Association of the CD4 coreceptor with Lck may also be involved in Lck activation.

Standard name | BIOCARTA_LECTIN_PATHWAY
Systematic name | M4732
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Lectin Induced Complement Pathway
Full description | The complement cascade of proteolytic factors involved in cellular lysis can be initiated by several different factors, including antibody-dependent and antibody-independent recognition of infectious organisms. In the lectin-induced complement cascade, carbohydrates on the surface of microbial cells activate the complement cascade by binding to mannan-binding lectin (also called the mannan-binding protein, Mbl/Mbp). Mbp is an acute phase serum protein whose expression is induced by microbial infection. The binding of Mbl to microbial ligands activates the Mbl associated serine proteases Masp1 and Masp2, triggering the cleavage of C2 and C4 to create C4bC2a, a C3 convertase that cleaves large numbers of C3. Masp1 and Masp2 are similar to the C1 protease in the classical complement pathway. Once formed the C3 convertase cleaves and activates the remaining complement factors leading ultimately to formation of a pore in the bacterial membrane by the membrane attack complex (MAC) that lyses the bacterial cell. The lectin-induced pathway also appears to play an important role of the activation of phagocytotic cells by infection. Although the initiating event activating the complement cascade is distinct in the lectin-induced pathway, from the C3 convertase onward the lectin induced complement pathway is the same as the classical complement pathway. Since antibodies are not required in the lectin-induced pathway, this aspect of the immune response is part of the innate immune response. The importance of this pathway to the immune response has been demonstrated by the identification of children and adults with little or no Mbl who lacked normal phagocytotic responses and are highly susceptible to infection.

Standard name | BIOCARTA_PYK2_PATHWAY
Systematic name | M7739
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Links between Pyk2 and Map Kinases
Full description | This diagram is a compilation of Pyk2 effort cascades. In specific cell types the receptor and effoectors will vary. Binding of a transmembrane receptor triggers the activation of Ca2+ signaling and PKC. The signal is then transmitted to Pyk2 and further to the small G protein Rac1. In turn, Rac1 initiatates the JNK cascade, starting with PAK follwed by MEKK1, SEK1, and JNK. JNK activation causes induction of c-Jun gene binding. Pyk2 stimulation has also been shown to activate MKK3 leading to activation of p38. The other major mitogen activated kinase cascade for ERK1/2 is stimulated via RAS, RAF and MEKK1/2.

Standard name | BIOCARTA_EGFR_SMRTE_PATHWAY
Systematic name | M18837
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Map Kinase Inactivation of SMRT Corepressor
Full description | Corepressors are coregulators that interact with transcriptional silencers in a variety of pathways such as cell proliferation, differentiation and apoptosis. Abnormal corepressor-silencer interactions have been implicated in a variety of human disease pathways including several types of leukemia. The regulation of the SMRT corepressor via the p38 and Mek-1 Kinase pathway is shown in this diagram. The EFG receptor represents one mechanism by which SMRT function is inhibited by the tyrosine kinase signaling pathway. The MEKK1 and p38 pathways are activated by EGF resulting in cross-regulation of SMRT. The induction of SMRT phosphorylation by each pathway is shown, causing SMRT to unbind from the transcription factor complexes represented by RXR, RAR, T3R and PLZF.

Standard name | BIOCARTA_MAPK_PATHWAY
Systematic name | M13863
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | MAPKinase Signaling Pathway
Full description | The ever evolving mitogen-activated protein kinase (MAP kinase) pathways consist of four major groupings and numerous related proteins which constitute interrelated signal transduction cascades activated by stimuli such as growth factors, stress, cytokines and inflammation. The four major groupings are the Erk (red), JNK or SAPK (blue), p38 (green) and the Big MAPK or ERK5 (light blue) cascades. Signals from cell surface receptors such as GPCRs and growth factor receptors are transduced, directly or via small G proteins such as ras and rac, to multiple tiers of protein kinases that amplify these signals and/or regulate each other. The diagram is organized to illustrate the cascades by the background colors and also the tiers of kinases as indicated down the left hand side and separated by the horizontal dashed lines. In some cascades the first activation tier involves the MAPKKKKs, MAP kinase kinase kinase kinases or MAP4K proteins. The next tier are the serine/threonine MAPKKKs, MAP kinase kinase kinase or MAP3Ks such as RAF, TAK, ASK, and MEKK1. This level has the greatest amount of cross-communication curently known. The serine/threonine/tyrosine MAPKKs, MAP Kinase kinases or MAP2Ks, such as the MKK and MEK kinases, are one step up from the MAP kinase cascade, phosphorylating and activating these kinases. The focal tier, the MAPKs or MAP kinases includes JNK1, p38, and ERKs, and are the kinases that give each cascade its name BR&gt;The endpoints of these cascades, shown in the bottom tier, includes the MAPK activated protein kinases (MAPKAPK) and some of the numerous transcription factors that regulate genes involved in apoptosis, inflammation, cell growth and differentiation NOTES:- The shared color and the bold arrows show the major flow of each cascade. - The smaller arrows indicate cross communication between cascades. In many cases this is restricted to certain cell types or requires additional factors. - Kinases that have been identified as MAP kinases based on sequence or structural homolgies but have not yet been assigned to a cascade have been placed out side the grouping backrgounds. - The PAKs (p21 associated kinases) are not MAPKs but participate in the transduction to the JNK cascade are included for this reason.) - MEK4 appears to function in both the JNK and p38 cascades and so has a mixed color. MEK4 signal is much stronger in the JNK than the p38 cascade and so the bold arrow towards the JNK and the dashed arrow towards the p38 cascade indicate the relative strengths of signaling. - For space and readability concerns not all interactions and stimuli are indicated and the scaffold and phosphatase proteins are not shown.

Standard name | BIOCARTA_MCALPAIN_PATHWAY
Systematic name | M8719
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | mCalpain and friends in Cell motility
Full description | The mammalian calpain gene family currently contains 13 distinct large subunit products most of which complex with one of two smaller 30kDa subunits. ( An excellent introduction to the calpain family can be found on a web site created by Valery Thompson http://ag.arizona.edu/calpains/index.html ) One of the most carefully studied functions of the calpains is the regulation of integrin-mediated cell migration. Calpains digests the links between the actin cytoskeleton and several focal adhesion complex proteins; talin, paxillin and focal adhesion kinase. The release from the focal adhesion complex facilitates migration. Calpestatin is an inhibitor expressed in most cells. Calpestatin binds the four inhibitory domains of calpain. Release from calpestatin does not activate calpain. Activation requires additional signaling, coactivators and an appropriate calcium concentration. During cell migration calpain1 (mu-calpain) acts at the leading edge as a response to integrin signals or calcium fluxuations due to the stretch activated calcium channels. Calpain1 cleaves the target proteins, talin, exzrin, paxillin and the cytoplasmic tail of the integrins B1(a) and B3(b) to release the adhesion and form new adhesions. Calpain2 (M-calpain) is believed to be membrane bound and functions at the trailing edge of the migrating cell to cleave the integrins in response to growth factor receptor signals. PKA functions to down regulate or inhibit calpain2. Disease related notes: In Alzheimers disease, amyloid peptides interfere with calpain activity causing a mislocalization of cdk5. Deregulated cdk5 hyperphosphorylates tau promoting cell death in neurons. Mutations in the muscle specific calpain p94 lead to Limb Girdle muscular dystrophy 2A (LGMD2A). Over activity of calpains due to elevated calcium leads to tissue damage in the heart and brain

Standard name | BIOCARTA_PPARA_PATHWAY
Systematic name | M2404
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Mechanism of Gene Regulation by Peroxisome Proliferators via PPARa(alpha)
Full description | The most recognized mechanism by which peroxisome proliferators regulated gene expresssion is through a PPAR/RXR heterodimeric complex binding to a peroxisome proliferator-response element (PPRE) (classical mechanism). However, there are the possibility of several variations on this theme: 1). The peroxisome proliferator interacts with PPAR that preexists as a DNA complex with associated corepressors proteins. The interaction with ligand causes release of the corepressor and association with a coactivator, resulting in the classical mechanism. 2). The peroxisome proliferator interacts with PPAR as a soluble member of the nucleus. The binding of ligand results in RXR heterodimerization, DNA binding and coactivator recruitment. 3). In this scenario, PPAR exists in the cytosol, perhaps complexed to heat shock protein 90 and/or other chaperones. Binding of peroxisome proliferator causes a conformational change and translocation into the nucleus. Scenarios 4 and 5 require regulation of gene expression via non-classical mechanisms: 4). PPAR is capable of interacting with, and forming DNA binding heterodimers with, several nuclear receptors including the thyroid hormone receptor. The binding site for this non-RXR heterodimer need not be the classic DR-1 motif found in the PPRE. 5). PPAR may participate in the regulation of gene expression witout binding to DNA. By association with transcription factors such as c-jun or p65, PPAR diminishes the ability of AP1 or NFB to bind to their cognate DNA sequences, respectively. Also shown in this scheme are two means to modify the peroxisome proliferator response. Most importantly, growth factor signaling has a pronounced affect on PPAR via post-translational modification. PPAR is a phosphoprotein and its activity is affected by insulin. Several kinase pathways affects PPARa's activity, although the specific kinases and phosphorylation sites have not been conclusively determined.

Standard name | BIOCARTA_ETS_PATHWAY
Systematic name | M14449
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | METS affect on Macrophage Differentiation
Full description | Terminal differentiation of cells is often accompanied by repression of cellular proliferation, suggesting that there is a mechanism by which these cellular functions are coordinated. Macrophage differentiation is one model system in which this occurs; as macrophages differentiate, they also stop proliferating. Transcriptional regulation plays a key role in cell cycle progression as well as many differentiation processes. Ras stimulates cell cycle progression in part through Ets transcription factors that bind to cell cycle regulatory genes to activate their expression. Ets transcription factors also help to induce early macrophage differentiation. The activation of Ras signaling by M-CSF activates transcription of genes involved in differentiation through the coordinate expression of both Ets factors and AP-1. Other genes involved in cell cycle regulation involved the coordinate action of E2F-1 and Ets transcription factors. Mets is a factor related in sequence to Ets2 that is upregulated during macrophage differentiation. Increased expression of the Mets protein during macrophage differentiation allows the creation of heterodimers with DP103 to act as transcriptional repressors of cell cycle progression genes, recruiting corepressor to promoters they interact with. DP103 is a gene previously identified as an RNA helicase involved in RNA processing that interacts with EBNA factors from Epstein Barr Virus. The transcriptional repression involving Mets with DP103 is selective, and does not involve all Ets regulated genes. While cell cycle genes are repressed by Mets, other gene activated by Ets factors such as those involved in differentiation are not repressed by Mets. The transcriptional repression by Mets also involved members of the Rb family of tumor suppressors, such as p107 and p130. This requirement for additional factors involved in regulating proliferation may allow for another level of control on cell proliferation and coordination with differentiation.

Standard name | BIOCARTA_MONOCYTE_PATHWAY
Systematic name | M4956
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Monocyte and its Surface Molecules
Full description | Monocytes are a class of phagocytes involved in non-specific immune defense that develop into macrophages. In plasma, monocytes ingest and destroy bacteria, and can form macrophages when they enter the extracellular space in tissues. In addition to the immune protection that monocytes provide, they may contribute to disease states such as arthritis and heart disease through an aberrant immune response. As with other immune cells, the immune function and differentiation of monocytes rely on communication with other cells through cell surface proteins. Cell surface proteins are involved in both interaction and adhesion with other cells and in transducing signals into the cellular interior. The LFA-1 integrin (Leukocyte function-associated molecule 1) is composed of two subunits, CD11a and CD18 and is involved in monocytes adhesion with ICAM-1 endothelial cells. Mac-1 is composed of the subunits CD11b and CD18 and is induced during inflammation as well. PECAM-1 mediates the migration of monocytes and other immune cells into inflamed tissues through interaction with vascular endothelial cells. CD44 interaction of leukocytes with hyaluronan in the extracellular matrix is induced by inflammation. VLA-4 is another integrin expressed on lymphocytes that plays a role in adhesion through interaction with its adhesion partner on endothelial cells, VCAM-1.

Standard name | BIOCARTA_MTOR_PATHWAY
Systematic name | M16563
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | mTOR Signaling Pathway
Full description | mTOR (mammalian target of rapamycin) appears to play a central role in signaling caused by nutrients and mitogens such as growth factors to regulate translation. The drug rapamycin acts on mammalian cells through the mTOR protein kinase, also known as FRAP. When bound to the immunophilin binding protein FKBP12, rapamycin inhibits mTOR kinase activity and has immunosuppressant activity. Rapamycin and the mTOR inhibitor CCI-779 are being tested as anti-cancer agents, acting to block mitogenic signaling. Recently, mTOR was also found to act as an ATP sensor to regulate cell growth. Upstream activation of PI 3 kinase activity that leads to oncogenic transformation can be blocked by inhibition of mTOR by rapamycin. Growth factor receptors first stimulate PI 3 kinase, and through inositol phosphates activate PDK-1 and AKT (protein kinase B). AKT phosphorylates mTOR. The phosphorylation of p70S6K and 4EBP by mTOR and the phosphorylation downstream of RPS6 and EIF-4B stimulate translational initiation and contribute to cell growth.

Standard name | BIOCARTA_IGF1R_PATHWAY
Systematic name | M19613
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Multiple antiapoptotic pathways from IGF-1R signaling lead to BAD phosphorylation
Full description | IGF-1R, the type 1 receptor for insulin-like growth factor, mediates cell survival and growth in response to its ligands IGF-1 and IGF-2. This tyrosine kinase receptor is widely expressed in many cell types and is a key mediator of growth. Overexpression or activation of IGF-1R may be involved in the proliferation of transformed cells, making inhibition of IGF-1R signaling a strategy for the development of cancer drugs. IGF-1R activates three signaling pathways that converge to phosphorylate BAD protein and block apoptosis. The first pathway activated by IGF-1R stimulates PI3-kinase and the AKT pathway to phosphorylate BAD and block apoptosis. A second pathway activated by IGF-1R involves ras mediated activation of the map kinase pathway to block apoptosis. A third pathway involves interaction of raf with mitochondria in response to IGF-1R activation. The convergence of these pathways to block apoptosis may enhance the IGF-1R response.

Standard name | BIOCARTA_PITX2_PATHWAY
Systematic name | M8516
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Multi-step Regulation of Transcription by Pitx2
Full description | Many transcription factors play essential roles in normal development by determining the proliferation and differentiation of cells. The coordinated transcriptional control of proliferation in specific developmental cell types is crucial in multiple developmental settings. One of a family of three bicoid-related transcription factors, Pitx2 acts downstream of the extracellular signaling protein Wnt to drive proliferation of cells with specific developmental fates, including cells in the pituitary, cardiac outflow region, and muscle. Wnt binds to Frizzled, a G-protein coupled receptor, activating homologs of the Drosophila Disheveled protein. Activation of Frizzled and Disheveled inhibits the kinase GSK-3 beta, part of a protein complex in the absence of Wnt signaling, causing beta-catenin protein to accumulate in the cytoplasm. Beta-catenin is known to alter the function of transcription factors like TCF/Lef. One result of Wnt signaling is activation of the transcription factor Lef by beta-catenin, inducing Pitx2 expression. Wnt activation also changes Pitx2 from a repressor to an activator by causing transcriptional corepressors like histone deacetylase 1 (HDAC1) bound to Pitx2 to be exchanged for coactivators. With coactivators bound, Pitx2 activates transcription of genes that regulate the cell cycle like Cyclin D2. Different coactivators are recruited by Pitx2 and other transcription factors like Myc to the Cyclin D2 promoter, with CBP/p300 recruited first, followed by NLI/Ldb/CLIM, Tip60/TRRAP, and PBP coactivators. Many of these coactivators help to alter histone acetylation and chromatin structure as part of transcriptional activation. The activation of cell cycle genes by Pitx2 ultimately stimulates the proliferation of specific cell types with the confluence of tissue-specific gene expression, growth factor signaling and coactivator recruitment.

Standard name | BIOCARTA_NGF_PATHWAY
Systematic name | M7860
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Nerve growth factor pathway (NGF)
Full description | Nerve growth factor (NGF) is one of a family of neurotrophins that induce the survival and proliferation of neurons. In cell culture NGF induces the formation of neurite projections and in vivo may stimulate the innervation of tissues. NGF plays a role in the repair, regeneration, and protection of neurons, and as such could serve as a therapeutic agent in neurodegenerative conditions such as Alzheimer's disease. One potential method of NGF application would be through gene therapy or through implantation of cells that have been genetically modified ex vivo. NGF has also been suggested to play a role in other physiological systems and tissues such as the immune system. NGF has two receptors, TrkA and the p75(NTR). NGF may signal its neuroprotective actions through the tyrosine kinase TrkA receptor and trigger apoptosis in some cells through the p75 receptor. High-affinity binding of NGF requires both TrkA and p75(NTR). Binding of NGF to the TrkA receptor causes activation of the receptor tyrosine kinase and downstream signaling cascades. One of the downstream signaling pathways of NGF activates phospholipase C, releasing DAG and IP3 and activating associated downstream pathways such as protein kinase C. Another NGF-activated pathway is the ras-mediated activation of the map kinase pathway. This pathway is initiated through recruitment and activation of Shc, which leads to ras activation through Grb-2 and Sos-1. The Map kinase cascade includes raf, Mek and Erk. The downstream effectors of the ras pathway include activation of fos and jun to form AP-1, activating genes through this transcription factor. Other transcription factors involved in NGF responses include Egr and CREB. The Egr family of transcription factors as well as the Mek/Erk pathway contribute to NGF-induced neurite formation. The CREB family of transcription factors are involved in NGF-induced survival of sympathetic neurons. Further understanding of NGF signaling may be applied to the modulation of NGF responses in neurodegenerative conditions.

Standard name | BIOCARTA_VIP_PATHWAY
Systematic name | M17941
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Neuropeptides VIP and PACAP inhibit the apoptosis of activated T cells
Full description | Vasoactive intestinal peptide (VIP) and the structurally related pituitary adenylate cyclase-activating polypeptide (PACAP), two neuropeptides present in the lymphoid microenvironment, elicit a broad spectrum of biological functions, including the modulation of innate and adaptive immunity. Another important immunoregulatory function of VIP and PACAP is their inhibition effect on AICD in T cells. They inhibit the TCR-stimulated FasL expression and apoptosis of T cell through specific receptors and induction of intracellular cAMP. VIP down-regulate c-Myc synthesis, the NF-AT-dependent Egr2 and Egr3 expression, the NF-AT and NF-kB.

Standard name | BIOCARTA_NFAT_PATHWAY
Systematic name | M2288
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | NFAT and Hypertrophy of the heart (Transcription in the broken heart)
Full description | Hypertrophy associated with both hypertension and obstruction to ventricular outflow leads to pathologic cardiac growth and it is associated with increase morbidity and mortality. Symptomatic ventricular disease takes a growing toll on the health of nations. As other cardiovascular diseases such as stroke and myocardial infraction are in decline as causes of mortality, the heart failure problem becomes increasingly urgent. Congenital heart defects occur in 1% of live births and fetal heart malformations are implicated in many pregnancies that end in still-birth or spontaneous abortion. The current paradigm suggests that the heart adapts to excess of hemodynamic loading by compensatory hypertrophy, which under condition of persistent stress, over time evolves into dysfunction and myocardial failure. There is considerable evidence that direct effects of increased mechanical stress are sensed within the ventricular wall and that signals critical for the generation of growth responses. Despite compelling statistics we still do not understand biochemically why heart defects are so prevalent. A single transcriptional regulator initially associated with the activation of the T-cells

Standard name | BIOCARTA_NTHI_PATHWAY
Systematic name | M2821
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | NFkB activation by Nontypeable Hemophilus influenzae
Full description | The role of Hemophilus influenzae in ear infections and chronic obstructive pulmonary disease includes the induction of an inflammatory response through activation of the transcription factor NF-kB. In addition to activation of inflammatory cytokine genes like IL-1 and TNF, H. influenzae activates TLR2 expression and genes involved in mucus production. Hemophilus influenzae activates NF-kB by multiple mechanisms, starting with activation of the Toll-like receptor 2 (TLR2) by the p16 protein in the H. influenzae outer membrane. TLR2 plays a key role in innate immune responses and is expressed in high levels in lymphoid cells as well as low levels in epithelial cells. The role of TLR2 was supported by blocking NF-kB activation with a dominant negative TLR2 and increasing it with transfection of a normal TLR2 gene. TLR2 in turn activates TAK1, which activates two divergent signaling pathways. One of these pathways leads to IkB kinase activation, IkB phosphorylation and degradation, releasing the NF-kB heterodimer to translocate into the nucleus and activate transcription of target genes. In the alternate pathway, TAK1 also activates NF-kB through a Map kinase pathway, activating p38 and NF-kB in a nuclear translocation independent manner. Investigation of the mechanisms of H. influenzae signaling involved in NF-kB activation may provide the information needed to develop better treatments for inflammatory conditions caused by this pathogen. Other pathways modulate the role of NF-kB in H. influenzae pathogenesis. Glucocorticoids widely used as anti-inflammatory drugs increase TLR2 activation by H. influenzae through the NIK/I-kB kinase pathway, while they repress the p38 dependent activation of NF-kB. The repression of the p38 pathway by glucocorticoids occurs through activation of the MAP kinase phosphatase-1 (MKP-1) which dephosphorylates and deactivates p38. Another aspect of the inflammatory response to H. influenzae infection is the production of excessive mucus, contributing to the overall symptoms of infection. NF-kB activation of the Muc2 gene contributes to mucus overproduction, in addition to H. influenzae activation of the TGF-beta receptor, activating SMAD transcription factors SMAD3 and SMAD4. Understanding mechanisms that modify H. influenzae signaling will contribute to further understanding the pathogenesis and treatment of ear infections and chronic obstructive pulmonary disease.

Standard name | BIOCARTA_NFKB_PATHWAY
Systematic name | M15285
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | NF-kB Signaling Pathway
Full description | Nuclear factor kB (NF-kB) is a nuclear transcription factor that regulates expression of a large number of genes that are critical for the regulation of apoptosis, viral replication, tumorigenesis, inflammation, and various autoimmune diseases. The activation of NF-kB is thought to be part of a stress response as it is activated by a variety of stimuli that include growth factors, cytokines, lymphokines, UV, pharmacological agents, and stress. In its inactive form, NF-kB is sequestered in the cytoplasm, bound by members of the IkB family of inhibitor proteins, which include IkBa, IkBb, IkBg, and IkBe. The various stimuli that activate NF-kB cause phosphorylation of IkB, which is followed by its ubiquitination and subsequent degradation. This results in the exposure of the nuclear localization signals (NLS) on NF-kB subunits and the subsequent translocation of the molecule to the nucleus. In the nucleus, NF-kB binds with a consensus sequence (5'GGGACTTTCC-3') of various genes and thus activates their transcription. IkB proteins are phosphorylated by IkB kinase complex consisting of at least three proteins; IKK1/IKKa, IKK2/IKKb, and IKK3/IKKg. These enzymes phosphorylate IkB leading to its ubiquitination and degradation. Tumor necrosis factor (TNF) which is the best-studied activator binds to its receptor and recruits a protein called TNF receptor death domain (TRADD). TRADD binds to the TNF receptor-associated factor 2 (TRAF-2) that recruits NF-kB-inducible kinase (NIK). Both IKK1 and IKK2 have canonical sequences that can be phosphorylated by the MAP kinase NIK/MEKK1 and both kinases can independently phosphorylate IkBa or IkBb. TRAF-2 also interacts with A20, a zinc finger protein whose expression is induced by agents that activate NF-kB. A20 functions to block TRAF2-mediated NF-kB activation. A20 also inhibits TNF and IL-1 induced activation of NF-kB suggesting that it may act as a general inhibitor of NF-kB activation.

Standard name | BIOCARTA_NOS1_PATHWAY
Systematic name | M11650
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Nitric Oxide Signaling Pathway
Full description | Glutamatergic-mediated nitric oxide (NO) production occurs via the N-methyl-D-aspartic acid (NMDA) postsynaptic density protein 95 (PSD95)-neuronal nitric oxide synthase (NOS1) ternary complex. The increased intracellular Ca2+ stimulates the interaction of nNOS and calmodulin (CaM) and the translocaton of nNOS from the plasma membrane to the cytoplasm. The dephosphorylation of nNOS by Calcineurin catalyzes the conversion of arginine to citrulline and nitric oxide (NO), which turns on guanylate cyclase and the various cGMP regulated signaling pathways.

Standard name | BIOCARTA_NO2IL12_PATHWAY
Systematic name | M6231
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | NO2-dependent IL 12 Pathway in NK cells
Full description | Macrophages and NK cells help provide innate immunity against infection by intracellular parasites and communicate with each other to regulate this process. When stimulated, macrophages secrete the cytokine IL-12 that is essential for activation of the cytotoxic activity of natural killer (NK) cells. IL-12 stimulates this NK cell response through activation of a JAK/STAT signaling pathway. Binding of IL-12 to its receptor on NK cells causes tyrosine phosphorylation and activation of JAK2 and another JAK kinase, Tyk2. Tyk2 in turn phosphorylates the transcription factor STAT4, which can then translocate to the nucleus to activate genes, including the expression of interferon-gamma. IFN-gamma and IL-12 induce the differentiation of TH1 helper T cells that activate macrophages through interferon-gamma. A key modulator of NK cell activation by IL-12 is nitric oxide, NO, produced from arginine by the inducible nitric oxide synthase NOS2. Inactivation of the NOS2 gene in mice impairs the initial innate response to infection, including the activation of NK cells. This phenotype is similar to that of mice lacking interferon-gamma or IL-12 and a similar effect can be produced by inhibiting NOS2 with L-N6-iminoethyl-lysine (L-NIL) during infection, blocking the activation of NK cells by IL-12. NO production does not affect the activation of JAK2 by IL-12, but is required for Tyk2 activity, the downstream activation of STAT-4 and the production of interferon-gamma by NK cells. The role of NO in Tyk2 activation is not yet known, but does not seem to involve change the phosphorylation status of Tyk2. Curiously, activation of T cells by IL-12 does not appear to involved NO production, indicating a distinct mechanism is involved in NK cells. NO also plays a role as a feedback inhibitor of IL-12 production by macrophages, helping to prevent over-activation of the Th1 cells by IL-12. NO appears to make an important contribution to the early innate response to infections before specific immunity is active.

Standard name | BIOCARTA_RARRXR_PATHWAY
Systematic name | M6907
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Nuclear receptors coordinate the activities of chromatin remodeling complexes and coactivators to facilitate initiation of transcription in carcinoma cells
Full description | RXR and RAR are nuclear receptors that bind either all trans retinoic (tRA) or 9cis retinoic acid (9cisRA). In the absence of ligand corepressors with histone deacetylase activity are bound to the RAR/RXR hetrodimer and suppress transcription. Once they bind retinoic acid a conformational change in the receptors cause the dissociation of the corepressors and the binding of coactivators with histone acetylase activity (1). Following ligand binding by the hetrodimer the receptors and proteins in the basal transcription machinery (like TBP and TAF135) are degraded by the proteasome (2).

Standard name | BIOCARTA_NUCLEARRS_PATHWAY
Systematic name | M16393
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Nuclear Receptors in Lipid Metabolism and Toxicity
Full description | Nuclear receptors are transcription factors that are activated upon binding to its ligands. Initially, they had been classified as classic endocrine nuclear hormone receptors and orphan receptors. However, further studies have led to the identification of lipid ligands for some of these adopted orphan receptors, which are responsible for lipid metabolism, storage or elimination. One of the characteristics of these receptors is that they act by forming heterodimers with retinoid X receptor (RXR). The receptors include peroxisome proliferators-Activated receptors (PPARs) for fatty acids, liver X receptor (LCR) for oxysterols, Farnesoid X receptors (FXR) for bile acids and steroid xenobiotic receptor/X receptor (SXR/PXR or Nsil2) for xenobiotics. Other orphan receptors also require RXR for its functions are vitamin D receptor (VDR) for vitamin D and retinoic acid receptor (RAR) for retinoid acids, although these receptors are not involved in lipid metabolism. Upon binding to various ligands, three classes of proteins are synthesized including lipid binding proteins, the ATP-binding cassette (ABC) transporters and cytochrome P450 member proteins which catalyzes lipid anabolism, metabolism and elimination. In addition to lipid metabolism, some members of the cytochrome P450 family genes are responsible for activation of procarcinogens, detoxification of environmental toxins and metabolism of drugs and xenobiotics. In particular, CAR, Nsil2 and recently identified VDR are important in up-regulation of these cytochromes. Of all the human cytochrome P450 genes, only a few CYP1A2, CYP2C9, CYP2C19, CYP2D6, CYP2E1 and CYP3A4 account for most toxicity effects, specifically CYP3A is responsible for clearing approximately half of the clinically prescribed drugs. For instance, acetaminophen, one of the most commonly used drug, is toxic in high doses due to the activation of CAR and the drugs subsequentconversion to acetyl-p-benzoquinone imine (NAPQI) by CYP1A2, CYP2E1 and CYP3A.

Standard name | BIOCARTA_ARENRF2_PATHWAY
Systematic name | M14339
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Oxidative Stress Induced Gene Expression Via Nrf2
Full description | Reactive oxygen species (ROS) can damage biological macromolecules and are detrimental to cellular health. Electrophilic compounds, xenobiotics and antioxidants are sources of reactive oxygen species, creating oxidative stress that can harm cells. Enzymes are involved in the Phase II detoxification of xenobiotics to reduce cellular stress include glutathione transferases, quinone reductase, epoxide hydrolase, heme oxygenase, UDP-glucuronosyl transferases, and gamma-glutamylcysteine synthetase. Expression of these genes protects cells from oxidative damage and can prevent mutagenesis and cancer. Transcription of these enzymes is coordinately regulated through antioxidant response elements (AREs). Nrf2 (NF-E2-related factor 2) and Nrf1 are transcription factors that bind to AREs and activate these genes. Inactive Nrf2 is retained in the cytosol by association a complex with the cytoskeletal protein Keap1. Cytosolic Nrf2 is phosphorylated and translocates into the nucleus in response to protein kinase C activation and Map kinase pathways. In the nucleus, Nrf2 activate genes through AREs by interacting with transcription factors in the bZIP family, including CREB, ATF4 and fos or jun. Nrf2 activation of genes is opposed by small maf proteins, including MafG and MafK, maintaining a counterbalance to Nrf2 and balancing the oxidation level of the intracellular environment.

Standard name | BIOCARTA_P38MAPK_PATHWAY
Systematic name | M862
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | p38 MAPK Signaling Pathway
Full description | p38 MAPKs are members of the MAPK family that are activated by a variety of environmental stresses and inflammatory cytokines. Stress signals are delivered to this cascade by members of small GTPases of the Rho family (Rac, Rho, Cdc42). As with other MAPK cascades, the membrane-proximal component is a MAPKKK, typically a MEKK or a mixed lineage kinase (MLK). The MAPKKK phosphorylates and activated MKK3/5, the p38 MAPK kinase. MKK3/6 can also be activated directly by ASK1, which is stimulated by apoptotic stimuli. P38 MAK is involved in regulation of Hsp27 and MAPKAP-2 and several transcription factors including ATF2, STAT1, THE Max/Myc complex, MEF-2, ELK-1 and indirectly CREB via activation of MSK1.

Standard name | BIOCARTA_P53_PATHWAY
Systematic name | M14863
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | p53 Signaling Pathway
Full description | p53 is a transcription factor who's activity is regulated by phosphorylation. The function is p53 is to keep the cell from progressing through the cell cycle if there is damage to DNA present. It may do this in multiple ways from holding the cell at a checkpoint until repairs can be made to causing the cell to enter apoptosis if the damage cannot be repaired. The critical role of p53 is evidenced by the fact that it is mutated in a very large fraction of tumors from nearly all sources.

Standard name | BIOCARTA_PDGF_PATHWAY
Systematic name | M2529
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | PDGF Signaling Pathway
Full description | Platelet Derived Growth Factor (PDGF) plays a critical role in cellular proliferation and development. The biologically active form is a dimer formed from the A and B chains. PDGF is active to a differing degree depending on which dimer is formed (AA, AB, or BB). The PDGF Receptor (PDGFR) is also a dimer and can form from the combination of the alpha and beta chains in any order (alpha-alpha, alpha-beta, beta-beta). The PDGFR dimer is only formed after ligand binding so the alpha/beta composition of the receptor can be influenced by the form of PDGF that is present. Upon binding of ligand the PDGFR is tyrosine phosphorylated and leads to the phosphorylation of several other cellular proteins.

Standard name | BIOCARTA_CCR5_PATHWAY
Systematic name | M2349
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Pertussis toxin-insensitive CCR5 Signaling in Macrophage
Full description | The chemokine receptors CCR5 and CXCR4 in macrophages are activated by their peptide ligands and also by the HIV envelope protein GP120 during HIV infection. One mechanism of signaling by these GPCRs is through activation of Gi signaling. These chemokine receptors can also signal through a Gi-independent pertussis toxin-insensitive pathway. This pathway elevates calcium influx into the cell through CRAC channels, ion channels that are activated by calcium release. Elevated calcium from CRAC is required for downstream activation of Pyk2, a focal adhesion-associated protein kinase. Non Gi signaling by these chemokine receptors also involves the Jnk and p38 Map kinase pathways leading to AP-1 activation and activation of genes such as MIP-1 and MCP-1. This pathway may be involved in the role of macrophages in the pathogenesis of AIDS.

Standard name | BIOCARTA_PTDINS_PATHWAY
Systematic name | M8809
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Phosphoinositides and their downstream targets.
Full description | Nine currently identified phosphoinositide 3-kinases (PI 3-K) constitute a subfamily of lipid kinases that catalyze the addition of a phosphate molecule on the 3-position of the inositol ring of phosphoinositides. Phosphatidylinositol (PtdIns), the precursor of all phosphoinosi-tides (PI), constitutes less than 10% of the total lipid in eukaryotic cell membranes. Approximately 5% of cellular PI is phosphorylated at the 4-position (PtdIns-4-P), and another 5% is phosphorylated at both the 4- and 5-positions (PtdIns-4,5-P2 ). However, less than 0.25% of the total inositol-containing lipids are phosphorylated at the 3-position, consistent with the idea that these lipids exert specific regulatory functions inside the cell, as opposed to a structural function. Here we have chosen to highlight a group of the phosphoinositide targets of the PI3-Ks and their downstream targets. The downstream effects of these PI-3 targets are indicated in the lower band illustrating the important role the PI3Ks have in cell function and survival.

Standard name | BIOCARTA_PLCE_PATHWAY
Systematic name | M5576
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Phospholipase C-epsilon pathway
Full description | Proposed model for b2-AR- and prostanoid-receptor-mediated PLC and calcium signalling. Receptors coupling to Gs stimulate AC, resulting in elevated cAMP levels and activation of Epac1. Epac1 then catalyses GTP-loading on Rap2B, which leads to PLC-e activation. The proposed pathway may involve additional signalling components to attain PLC stimulation. The action of cAMP seems to be independent of PKA; Instead, the cAMP-activated Rap-GEF Epac seems to serve as a cAMP effector, inducing GTP loading and, hence, activation of Rap2B, which then leads to specific activation of PLC-e, which has been shown to interact with Rap GTPases. It is an attractive hypothesis, therefore, that the Rap-dependent PLC and calcium signalling pathway reported here is not restricted to Gs-and AC-coupled receptors, such as the b2-AR and the prostanoid receptor, but could be used by other receptors as well.

Standard name | BIOCARTA_EDG1_PATHWAY
Systematic name | M10579
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Phospholipids as signalling intermediaries
Full description | Sphingosine-1-phosphate (S1P) is an example of lipid messengers with both intracellular and extracellular functions. Intracellularly S1P regulates proliferation and survival; extracellularly S1P is a ligand for EDG1 (also known as S1P1). Activation of sphingosine kinase (SPHK), the enzyme that catalyzes the phosphorylation of sphingosine, increases cellular levels of S1P. Inhibitors of SPHK block formation of S1P and inhibit cellular proliferation induced by a variety of factors, including as an example platelet-derived growth factor (PDGF) and PMA. In a study using endothelial cells it was demonstrated that S1P induces activation of alpha-v and B3 integrins via RhoA. S1P also activates Akt via Gi and PI3K. The activated Akt phosphorlyates the Edg1 receptor on threonine 236 leading to the activation of Rac1 and subsequent signals leading to actin assembly, chemotaxis and lamellipodia formation. Edg1 stimulation also leads to the activation of the ERK signaling cascade resulting in anti-apoptotic reversal, proliferation and cell survival.

Standard name | BIOCARTA_CDK5_PATHWAY
Systematic name | M89
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Phosphorylation of MEK1 by cdk5/p35 down regulates the MAP kinase pathway
Full description | Map kinases transduce responses to extracellular signals by a variety of routes, and communicate with other pathways through extensive crosstalk networks. A closely studied Map kinase cascade originates with tyrosine kinase activation, and activation of Ras. Ras activates Raf, Raf activates the Map kinase kinases Mek1 and Mek2 and these kinases activate downstream Map kinases like Erk1 and Erk2. Erk1 and Erk2 in turn activate transgenes like p35 through the Map kinase activated transcription factor EGR-1. Mek1 plays a central role in many different Map kinase pathways. Factors that activate Mek1 include growth factors like NGF, cytokines, chemokines, and phorbol ester, resulting in cellular proliferation and survival. Mek1 activation may also play a role in differentiation in neuronal tissues. In cultured neuronal PC-12 cells, NGF induces neurite outgrowth via Mek1 and the map kinase pathway. Constitutive activation of Mek1 can transform cells and may play a role in cancer. The crucial role of Mek1 in a variety of pathways including cellular transformation suggests that the cell must tightly regulate its activity. Cdk5 is a kinase that regulates the activity of Mek1. Although Cdk5 is a member of the cyclin-dependent kinase gene family, the activity of Cdk5 does not appear to be regulated by cyclins, but is activated by association with p35. Cdk5 does not act as a checkpoint kinase to regulate cell cycle progression, but acts as a regulatory kinase involved in other post-mitotic processes such as neuronal activity such as neuronal migration during development and neurite outgrowth. Mice lacking Cdk5 exhibit defects in neuronal development. One target of Cdk5 is Mek1. Phosphorylation of Mek1 by Cdk5 represses Mek1 activity and blocks downstream cellular responses. The activation of p35 by Map kinase pathways followed by deactivation of Map kinase signaling by the Cdk5/p35 complex completes the loop of a feedback circuit to terminate Map kinase signaling.

Standard name | BIOCARTA_MYOSIN_PATHWAY
Systematic name | M7014
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | PKC-catalyzed phosphorylation of inhibitory phosphoprotein of myosin phosphatase
Full description | The phosphorylation of myosin affects its role in smooth muscle contraction, platelet formation and possibly other processes. Phosphorylation by myosin light chain kinase (MLCK) increases myosin activity and dephosphorylation by myosin phosphatase decreases myosin activity. CPI, a factor that binds to and inhibits myosin phosphatase, is a target of phosphorylation by PKC and PKN. The inhibitory activity of CPI is regulated by its own phosphorylation state; when CPI is phosphorylated, its inhibitory activity is increased. The activation of signal transduction cascades such as GPCR pathways can lead to activation of PKC, phosphorylation of CPI, inhibition of myosin phosphatase, increased myosin phosphorylation and increased smooth muscle contraction or platelet release. The action of histamine in vasoconstriction, for example, may be mediated by activation of PKC through the histamine receptor, resulting in phosphorylation of CPI-17, increased inhibition of myosin phosphatase, and increased smooth muscle contraction.

Standard name | BIOCARTA_PLATELETAPP_PATHWAY
Systematic name | M6487
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Platelet Amyloid Precursor Protein Pathway
Full description | The amyloid -beta peptide (Ab), a proteolytic fragment of amyloid precursor protein (APP), is the major componenet of senile plaques, the hallmark of alzhemiers disease. Platelets contain both APP and Ab and probably contribute greater than 90% of circulating APP. The soluble APP is the major inhibitor of coagulation factors IXa and XIa, and platelet aggregation. Agonists such as ADP, thrombin, epinephrine and collagen activate the release of APP and plasminogen activator inhibitor I (an important regulator of coagulation) from platelet storage granules. These important molecules released from platelets are key regulators of hemostasis, the physiologic arrest of hemorrhage at site of vascular leakage.

Standard name | BIOCARTA_PS1_PATHWAY
Systematic name | M16173
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Presenilin action in Notch and Wnt signaling
Full description | Presenilin-1 (PS1) is associated with gamma secretase activity that cleaves amyloid precursor protein (APP) and is implicated in Alzheimer's disease. Presenilin-1 is also a component in gamma-secretase activity involved in signaling by the transmembrane protein Notch. Active gamma secretase requires PS-1 N-terminal fragment and a C-terminal fragment and is unique in catalyzing proteolysis within the transmembrane region of proteins. Other proteins such as nicastrin may also be components of the gamma-secretase. Binding of the ligand Delta by Notch appears to trigger two proteolytic cleavages of Notch. The first step cleaves an extracellular domain and is catalyzed by a metalloprotease termed alpha-secretase or TACE. The second cleavage step appears to occur within the transmembrane domain of Notch, and releases a Notch intracellular doman (NICD). Once released, NICD moves into the nucleus where it is involved in transcriptional regulation through CSL family transcription factors (CBF1, Su(H), Lag-1) or other transcriptional regulators such as LEF-1. Presenilin is also involved in the Wnt/frizzled signaling pathway through beta-catenin. Beta-catenin is a cytoskeletal component that enters the nucleus to act as a transcriptional cofactor. Binding of WNT to Frizzled causes disheveled (DSH) to inhibit Glycogen synthase kinase 3 beta (GSK-3b) activity. Phosphorylation of Beta-catenin induces the ubiquitination and proteolytic degradation of beta-catenin by the proteasome. Non-phosphorylated beta-catenin is stable and enters the nucleus to regulate transcription with TCF. The beta-catenin/TCF complex activates genes that promote cellular survival, proliferation and differentiation during development. Presenilin stimulates beta-catenin turnover, reducing its transcriptional activation.

Standard name | BIOCARTA_AKAPCENTROSOME_PATHWAY
Systematic name | M15347
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Protein Kinase A at the Centrosome
Full description | Protein kinase A regulatory subunit RIIalpha (PKA-RIIa) is tightly bound to centrosomal structures during interphase through interaction with the A-kinase anchoring protein AKAP350 (also known as AKAP450 and CGNAP), MAP2 and Pericentrin. This diagram illustrates these three PKA-RII binding complexes. The cyclin B-p34(cdc2) kinase (CDK1) has been shown to phosphorylate PKA-RIIa on T54 and this has been proposed to alter the subcellular localization of PKA-RIIa at the on set of mitosis. It has been demonstrated that PKA-RIIa dissociates and redistributes from centrosomes at mitosis. The focal point of this illustration is the AKAP350 complex. In addition to binding PKA-RIIa, AKAP350 binds PKN (Takahashi et al 1999) and the phosphatases PP1 and PPA2 (Takahashi et al 1999). PKN is a serine/threonine protein kinase, having a catalytic domain homologous to the PKC family in the C-terminal region and a unique regulatory region in the N-terminal region. PKN is activated by a small GTPase RhoA and unsaturated fatty acids such as arachidonic acid. The binding of both kinases and phophatases by the same scaffold protein provides a focal point where physiological events, such as cell cycle progression and intracellular membrane traffic, may be regulated by phosphorylation state of specific protein substrates. There are at least 4 isoforms of AKAP350 which lead to the possibility that they may behave differently at different subcellular locations. MAP2 is a member of a group of proteins that provide microtubule stabilization. MAP2 affinity appears to be dependent on PKA phosphorylation of MAP2. Pericentrin is also an AKAP (Diviani and Scott). Pericentrin binds Dynein which is also regulated by PKA leading to the possibility that pericentrin positions PKA to regulate dynein function (Diviani and Scott). Another example of AKAP/PKA interaction is illustrated in the AKAP95 role in mitosis and chromosome dynamics pathway.

Standard name | BIOCARTA_PTEN_PATHWAY
Systematic name | M10145
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | PTEN dependent cell cycle arrest and apoptosis
Full description | PTEN is a tumor suppressor gene. Recombinant PTEN is capable of dephosphorylating phosphatidylinositol 3,4,5-triphosphate, the product of phosphatidylinositol 3 -kinase. Many of the cancer-related mutations have been mapped to the phosphatase catalytic domain, it has been suggested that the phosphatase activity of PTEN is required for its tumor suppressor function. The activation of PKB/AKT is regulated in a complex manner via phosphorylation of AKT on Thr308 and Ser473 by PDK1 and ILK(integrin-linked kinase) respectively. Inactivation of PTEN will constitutively activate PKB/AKT pathway. In addition to its role in regulating the PI 3-K/AKT cell survival pathway, PTEN also inhibits growth factor-induced Shc phosphorylation and suppresses the mitogen-activated protein (MAP) kinase signaling pathway. PTEN also interact with FAK, a key molecule implicated in integrin signaling pathways, and it directly dephosphorylates tyrosine-phosphorylated FAK. PTEN down-regulation of p130CAS through FAK results in inhibition of cell migration and spreading.

Standard name | BIOCARTA_RAB_PATHWAY
Systematic name | M8179
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Rab GTPases Mark Targets In The Endocytotic Machinery
Full description | The eukaryotic cell contains compartments with distinct functions bounded by lipid bilayer membranes. The movement of membrane vesicles between these compartments allows proteins in the secretory pathway to move outward from the endoplasmic reticulum (ER) to the Golgi, trans Golgi network (TGN), secretory vesicles, and the plasma membrane and to be secreted into the extracellular environment. The trafficking of membrane vesicles is also essential for endocytosis and the movement of material from the extracellular environment into the early endosome (EE), late endosome (LE) and lysosome. The movement of vesicles and their contents between these compartments and their secretion are essential for a host of cellular functions, including the release of neurotransmitters and hormones. The movement of membrane vesicles between all of these compartments is regulated by members of the Rab family of GTPases, part of the ras superfamily of genes, regulated through binding of GTP and hydrolysis of bound GTP to GDP. At least eleven yeast genes in this family have been identified as Ypts, yeast transport proteins, and over sixty mammalian Rab genes have been identified in this highly conserved gene family. The products of the Rab genes regulate specific steps in vesicle transport. Rab1 is involved in the movement of membranes from the ER through the Golgi. Rab3 regulates secretory vesicle release and Rab27 is also involved in regulated release of secreted proteins. Rab5, 7 and 9 contribute to endocytosis while Rab4 and Rab11 mediate recycling from the endosome back to the plasma membrane. Rab11 is involved in both endocytosis and exocytosis. As with other Ras family GTPases, the activity of Rabs is regulated by guanine-nucleotide exchange factors (GEFs) and GAPs (GTPase activating proteins). Downstream effectors must also interact with Rabs to transmit their signals regulating each step of the membrane trafficking pathways including vesicle formation, movement of vesicles between compartments, vesicle docking, fusion and membrane remodeling. Downstream effectors of the Rabs include Rabphilin-3 (vesicle movement effector for Rab3), Rabphilin-11 (vesicle formation effector for Rab11), and EEA1 (vesicle fusion and membrane remodeling). If Rabs are involved in more than one role and other components of Rab signaling also interact with more than one Rab this will further increase the complexity of the system. Elucidating the interaction of Rabs and regulation of vesicle trafficking by other signaling pathways will be a key area of research in the future.

Standard name | BIOCARTA_RAC1_PATHWAY
Systematic name | M8601
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Rac 1 cell motility signaling pathway
Full description | Rac-1 is a small G-protein in the Rho family that regulates cell motility in response to extracellular signals. Several changes in cytoskeletal structure and other aspects of cell structure are involved in cell motility. Rac-1 is activated by GEF factors, and repressed by GAPs. GEFs are guanine nucleotide exchange factors, including Trio and Vav. Sos-1 is involved in Ras signaling and also acts as a GEF for Rac to transduce signals between Ras and Rac. SWAP-70 is a Rac GEF that binds IP3 and transduces signals from tyrosine kinases to Rac to modulate the cytoskeleton and cause membrane ruffling. GAPs are GTPase- activating proteins. Rac stimulates the formation of actin-based structures such as filopodia and lamellopodia, while GAPs such as chimerin oppose the formation of these Rac dependent structures. Several different factors downstream of Rac act on cytoskeletal structure and other aspects of cell motility. Pak1 provides a direct link from Rac to cell motility through phosphorylation of the myosin light chain. Pak1 also phosphorylates and activates LIM kinase, which phosphorylates cofilin as one target. Cofilin stimulates actin depolymerization and changes in cell structure, and phosphorylation of cofilin by LIM kinase represses its activity. In neurons, Rac acts through the protein kinase cdk5 and p35 to phosphorylate and downregulate Pak1, increasing neuronal migration. Rac-1 also interacts with several other factors to regulate a variety of processes. Interaction of Por1 with Rac-1 is involved in membrane ruffling. WAVE is a member of the WASP family of proteins that regulate actin organization and that is involved in Rac signaling to cause membrane ruffling. Interaction of Rac-1 with MEKK1 integrates Rac signaling with pathways signaling through map kinases.

Standard name | BIOCARTA_RAS_PATHWAY
Systematic name | M17294
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Ras Signaling Pathway
Full description | Ras activates many signaling cascades. Here we illustrate some of the well-characterized cascades in a generic compilation of effector molecules. The effectors mediate Ras stimulation to a diverse set of cellular signals. Many of these signals are interpreted differently depending on the cell type or microenvironment receiving the stimulus. Not all of these effectors are activated in any given cell type. The primary method of activation is to promote the translocation of the molecule to the plasma membrane where additional interactions lead to the activation of the molecule. RalGDS is a Guanine Exchange Factor (GEF) for Ral but also has other independent functions. RalGDS activates RalA/B-related small GTPases. RalBP1 is a GTPase activating protein that leads to the inhibition of the Rac and CDC42 GTPases. Ral can also interact with phospholipase D1 (PLD1) that can also be activated by RhoA. Ras stimulation of the lipid kinase activity of PI3K occurs through an interaction with the p110 catalytic subunit. PI3K phosphorylates the D3 position of phosphatidylinositides. In this example Pip2 is converted to PIP3. PIP3 stimulates the AKT/PKB kinase and several of the Rac-GEFs such as Sos1 AND Vav. AKT activation inhibits apoptosis by inhibiting the actions of Bad, Caspase9 and AFX. AKT further hinders apoptosis by phosphorylating the IkB repressor of NFkB. Stimulus of Rac causes among other things the activation of NFkB. Ras also stimulates the mitogen-activated kinases ERK1/2 via the Raf1 cascade. The Erk kinases translocate to the nucleus where they phosphorylate various transcription factors such as ELK1

Standard name | BIOCARTA_NKCELLS_PATHWAY
Systematic name | M16355
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Ras-Independent pathway in NK cell-mediated cytotoxicity
Full description | NK (natural killer) cells are lymphocytes distinct from B and T cells that induce perforin-mediated lysis of tumor cells and virus-infected cells. NK cell-mediated cytotoxicity is activated by glycoproteins on the cell surface (activating receptors) and inhibited by MHC-1 with self-peptide bound. The MHC-1 inhibitory signal through Ig-family or lectin receptors prevents NK cells from killing normal cells. Abnormal MHC-1 expression in infected or tumor cells results in the release of perforin, the lysis of the abnormal cell and the release of cytokines that stimulate the immune response. MAP kinase inhibitors but not ras inhibitors are able to block NK cell cytotoxicity, indicating that the pathway can function by a ras-independent manner that involves the MAP kinase pathway. This pathway includes phosphoinositide-3-kinase (PI3K) as a key component, followed by Rac1 and the exchange factor Vav. The tyrosine kinase SYK and LAT may provide an additional pathway for activation of MAP kinases leading to NK cell activation, and also Pyk-2 activation by integrins. The protein tyrosine phosphatase SHP-1 appears to mediate the cytotoxicity inhibitory signal that blocks lysis of normal cells. The balance of these positive and negative signaling pathways regulates the role of NK cells in the immune response.

Standard name | BIOCARTA_RB_PATHWAY
Systematic name | M18159
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | RB Tumor Suppressor/Checkpoint Signaling in response to DNA damage
Full description | Cell cycle checkpoint controls at the G1 to S transition and the G2 to M transition prevent the cell cycle from progressing when DNA is damaged. The ATM protein kinase detects DNA damage and in response to this activates DNA repair factors and inhibits cell cycle progression. Two of the proteins that ATM phosphorylates in response to DNA damage are the tumor suppressor p53 and the checkpoint kinase chk1. In turn, the tumor suppressor p53 interacts with p21 to block the activity of cdk2 (cyclin dependent kinase 2) preventing passage from G1 to S phase and harmful replication of damaged DNA. One of the targets of cdk2 is the Rb gene product, another tumor suppressor. When dephosphorylated, Rb interacts with E2F transcription factors and prevents transcription of genes required for progression through the cell cycle. When phosphorylated by cell cycle dependent kinases like cdk2 and cdk4, Rb no longer interacts with E2F and the cell cycle proceeds through the G1-S checkpoint. DNA damage also regulates the G2-M phase transition by acting on the cell cycle regulator cdc2.

Standard name | BIOCARTA_BAD_PATHWAY
Systematic name | M85
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of BAD phosphorylation
Full description | The function of the pro-apoptotic molecule BAD is regulated by phosphorylation of three sites (ser 112,136 and 155). Phosphorylation at these sites results in loss of the ability of BAD to heterodimerize with the survival proteins BCL-XL or BCL-2. Phosphorylated BAD binds to 14-3-3 and is sequestered in the cytoplasm. While ser-136 phosphorylation is concordant with the activation of Akt, Ser-112 phosphorylation requires activation of the Ras-MAPK pathway. BAD Ser 155 was found to be a major site of phosphorylation induced following stimulation by growth factors and prevented by protein kinase A inhibitors.

Standard name | BIOCARTA_CK1_PATHWAY
Systematic name | M16626
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of ck1/cdk5 by type 1 glutamate receptors
Full description | Cdk5 is a cyclin dependent protein kinase involved in dopaminergic signaling in the neostriatal region of the brain. The role of cdk5 in dopamine responses occurs through phosphorylation of DARPP-32. Caseine kinase 1 (CK1) also regulates DARPP-32 phosphorylation and dopamine signaling. The phosphorylation of DARPP-32 by cdk5 reduced dopamine signaling. Depending on its phosphorylation state, DARPP-32 inhibits either protein phosphatase 1 (PP1) or PKA. The role of mGLUR1 in this process is supported by the induction of cdk5 and CK1 activity by the mGLUR1 agonist DHPG and the subsequent phosphorylation of DARPP-32 associated with DHPG treatment of nigrostriatal neurons. CK-1 and Ckd5 inhibitors block the DHPG induced DARPP-32 phosphorylation. Dopamine exerts a positive signal that increases dopamine response by reversing phosphorylation of DARPP-32 at threonine-75. Dopamine initiates this pathway through activation of the D1 dopamine receptor, a Gs coupled GPCR, elevating cAMP and activating PKA. PKA activates protein phosphatase 2A (PP2A) which dephosphorylates DARPP-32 and increases dopamine responsiveness. This also removes the inhibition of PKA by DARPP-32, forming a positive feedback loop for further DARPP-32 inactivation by PKA. Activation of the D2 dopamine receptor has the opposite effect, shifting the DARPP-32 population toward the threonine-75 phosphorylated form.

Standard name | BIOCARTA_EIF2_PATHWAY
Systematic name | M6924
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of eIF2
Full description | Protein phosphorylation plays an important role in the control of translation by eukaryotic initiation factor-2 (eIF-2). eIF-2 binds GTP and Met-tRNAi and transfers the Met-tRNA to the 40S subunit, to form the 43S preinitiation complex. Later in the cycle, prior to elongation, the bound GTP is hydrolyzed , releasing eIF-2-GDP. For eIF-2 to promote another round of initiation, GDP must be exchanged for GTP, a reaction catalyzed by eIF-2B. Kinases activated by viral infection (PKR), endoplasmic reticulum stress (PERK/PEK), amino acid deprivation (GCN2), and hemin deficiency (HRI) can phosphorylate the a subunit of eIF-2. This phosphorylation stabilizes the eIF-2-GDP-eIF-2B complex, inhibiting the turnover of eIF-2B. eIF-2B is also inhibited by GSK-3b phosphorylation. These events result in a shut-down of cellular protein synthesis and can lead to apoptosis.

Standard name | BIOCARTA_EIF4_PATHWAY
Systematic name | M4791
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of eIF4e and p70 S6 Kinase
Full description | eIF-4F and p70 S6 kinase play critical roles in translational regulation. eIF-4F is a complex whose functions include the recognition of the mRNA 5' cap structure (eIF-4E), delivery of an RNA helicase to the 5' region (eIF-4A), bridging of the mRNA and the ribosome (eIF-4G), and circularization of the mRNA via interaction between eIF-4G and the poly(A) binding protein (PABP). Several stimuli, including growth factors and cytokines, regulate the eIF-4 complex and p70 S6 kinase by initiating a phosphorylation cascade involving the sequential activation of PI3-K, PDK1/2, Akt/PKB, and FRAP/mTOR kinase. FRAP/mTOR, together with an unidentified kinase, phosphorylates 4E-BP, leading to its dissociation from and activation of eIF-4E. MNK1/2, activated by ERK and p38 MAPK, phosphorylates and activates eIF-4E. Both processes contribute to the association of eIF-4E and eIF-4G to form the active eIF-4F complex, a necessary component of the 48S initiation complex. Phosphorylation of ribosomal protein S6 by p70 S6 kinase stimulates the translation of mRNAs with a 5' oligopyrimidine tract which typically encode components of the protein synthesis.

Standard name | BIOCARTA_STEM_PATHWAY
Systematic name | M5298
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of hematopoiesis by cytokines
Full description | The process of hematopoesis is regulated by various cytokines. The combination of cytokines stimulates the proliferation and/or differentiation of the various hematopoietic cell types. Bone marrow stromal cells are the major source of hematopoietic cytokines in the non-infecteous state. In the presence of infection, cytokines produced by activated macrophages and TH cells induce hematopoietic activity. The induction by cytokines results in rapid expansion of the population of white blood cells to fight infection. The specific cytokines that affect a step of cell differentiation are placed adjacent to the arrow representing that step. Lines with '?' indicate likely, but still hypothetical pathways.

Standard name | BIOCARTA_P27_PATHWAY
Systematic name | M17977
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of p27 Phosphorylation during Cell Cycle Progression
Full description | p27/Kip1 regulates the cell cycle by inhibiting the checkpoint kinase cdk2/cyclin E and blocking cell cycle progression through the G1-S transition. Cancer cells in some cases have reduced levels of p27, supporting the importance of p27 in cell cycle regulation. The activity of p27 is regulated by phosphorylation, synthesis and degradation. Phosphorylation of p27 at threonine-187 by cdk2 causes p27 to associate with an SCF complex that targets p27 for proteolytic degradation. The F box protein Skp2 binds specifically to threonine-187 phosphorylated p27, recruiting it to the SCF complex for degradation. Other components of the p27 ubiquitin ligase complex include Skp1, Cul1, and Roc1/Rbx-1. Cks-1 has also been identified in a reconstituted system as an essential component for recruitment of p27 for degradation by the SCF complex. Signaling by cytokines may modulate cell survival, proliferation, or apoptosis through modulation of p27 expression. Cytokine and AKT signaling pathways activate forkhead transcription factors that induce p27 expression at the transcriptional level.

Standard name | BIOCARTA_PGC1A_PATHWAY
Systematic name | M15181
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of PGC-1a
Full description | Peroxisome proliferator-activated receptor gamma coactivator-1 alpha (PGC-1a) is a tissue-specific coactivator that enhances the activity of many nuclear receptors and coordinates transcriptional programs important for energy metabolism and energy homeostasis. Inappropriate increases in PGC-1a activity have been linked to a number of pathological conditions including heart failure and diabetes. PGC-1a is highly expressed in metabolically active tissues including brown fat, skeletal muscle and heart. PGC-1a has been implicated in mitochondrial biogenesis in the heart and increased mitochondrial respiration in brown fat. PGC-1a is a coactivator for many factors including, CBP, Scr-1, PPARa, GR (glucocorticoid receptor), THR (thyroid hormone receptor), several orphan receptors and MEF2. This pathway illustrates two of the cofactor regulatory factors MEF2 and PPARa) and an example orphan receptor feedback inhibition loop. Glut4 is used as an example of the downstream elements leading to changes in metabolism. Ichida et al discovered the ERRa repression of PGC-1a. Their results suggest a novel mechanism of transcriptional control wherein ERR-a can function as a specific molecular repressor of PGC-1a. This suggests that other co-activators might also have specific repressors, adding another layer of combinatorial complexity in transcriptional regulation. Czubryt et al identified PGC-1 a as a key target of the MEF2/HDAC regulatory pathway and demonstrated this pathway's importance in maintenance of cardiac mitochondrial function. The linking of MEF2/HDAC provides an potential explanation for the increase in mitochondrial number observed in response to CaMK signaling.

Standard name | BIOCARTA_PML_PATHWAY
Systematic name | M4891
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of transcriptional activity by PML
Full description | The PML nuclear bodies are ring-shaped nuclear substructures associated with the regulation of transcription, transformation, cell growth, and apoptosis and are characterized by the presence of the protein PML. The activities of PML as a tumor suppressor and apoptosis inducing factor are exerted through the numerous proteins it interacts with in the PML-nuclear bodies including the tumor suppressor p53. DNA damage induced activation of p53-dependent apoptosis requires PML. PML acts as a coactivator for p53 and increases acetylation of p53 by the transcriptional coactivator CBP. This acetylation of p53 is reversed by the deacetylase SirT1, the human homolog of the yeast gene Sir2, and this deacetylation opposes the transcriptional activation of p53. The tumor suppressor Rb also interacts with the PML nuclear body, increasing transcriptional repression of genes involved in cell cycle progression, suggesting that PML may affect cellular transformation through more than one mechanism. PML interacts directly with Ubc9, which modifies PML through the attachment of the ubiquitin-like peptide Sumo-1. Sumo-1 modification of PML is not necessary for the nuclear bodies to form, but may affect the recruitment of proteins that interact with PML. PML is involved in non-p53 mediated apoptotic pathways, such as DAXX-mediated apoptosis induced by Fas and TNF and regulates the transcriptional repressor activity of Daxx. The sequestration of Daxx by the PML nuclear bodies relieves the repression of other transcription factors like Pax3 by Daxx. Tumor suppression by PML may in general involve the formation of specific regulatory transcription complexes, including those with DAXX, p53 and CBP. Factors that affect the assembly of PML into the PML nuclear bodies affect the proliferation and transformation of cells. Viral early proteins can interact with PML to disrupt the nuclear bodies, allowing increased proliferation of cells and reduced apoptosis, good conditions for DNA virus infection. Another factor that disrupts the formation of PML nuclear bodies is a translocation between the PML and RAR-alpha genes found in acute promyelocytic leukemia (APL) patients. Binding of retinoic acid to the RAR-alpha steroid hormone receptor activates transcription of retinoic-acid responsive genes. The translocation found in APL patients creates two chimeric proteins, RARalpha-PML and PML-RARalpha. Retinoic acid given to APL patients causes the reappearance of nuclear bodies, and the reversal of cellular transformation, effecting a cure for these patients.

Standard name | BIOCARTA_DREAM_PATHWAY
Systematic name | M18899
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Repression of Pain Sensation by the Transcriptional Regulator DREAM
Full description | The molecular events that lead to the perception of pain are a key research field in medicine and drug discovery. The opioid receptors modulate pain signaling in response to endogenous peptide ligands and opiate drugs such as morphine. The kappa opioid receptor plays a key role in the profound analgesia of opiates and is activated by the endogenous peptide ligand dynorphin, encoded by the prodynorphin gene. Production of prodynorphin is transcriptionally regulated by a downstream regulatory element (DRE) in the prodynorphin gene. A transcription factor called DREAM (DRE antagonistic modulator) binds to the DRE and represses prodynorphin transcription when bound. DREAM binds calcium with 4 EF-hand motifs and the binding of DREAM to DNA is repressed in the presence of calcium. Many transcription factors are regulated by calcium indirectly through calcium sensitive kinases and phosphatases, but DREAM is unique to date in being a transcription factor that directly binds calcium and is regulated by calcium binding. DREAM may also regulate other genes such as c-fos. DREAM is expressed in spinal cord neurons in regions involved in pain signaling. The regulation of prodynorphin expression by DREAM also leads to the hypothesis that DREAM is involved in pain signaling. Transgenic mice lacking the DREAM gene were unusually pain insensitive and had elevated spinal levels of dynorphin and tonic activation of the kappa opioid receptor, supporting this hypothesis. Other functions of DREAM may exist such as regulation of presenilins and potassium channel activity in the heart. DREAM is also known as calsenilin and KChIP3 through its association with these other proteins. These processes were not affected in mice lacking the DREAM gene however.

Standard name | BIOCARTA_LEPTIN_PATHWAY
Systematic name | M18053
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Reversal of Insulin Resistance by Leptin
Full description | The insulin resistance of type II diabetes appears to be caused in part by the presence of high levels of lipids in cells such as skeletal muscle where this would not normally be found. The presence of excess lipid stores in skeletal muscle cells interferes with energy metabolism, impairing glucose oxidation and insulin response. Skeletal muscle is one of the primary glucose-consuming tissues, giving it a central role in insulin resistance. The increased risk of diabetes associated with obesity may be caused by increased lipid deposits in skeletal muscle and liver, creating insulin resistance. Leptin is a peptide hormone secreted by adipose tissue that has been associated with many processes. One of the target tissues of leptin is the hypothalamus where it can act to regulate feeding behavior and metabolism. Another leptin target is skeletal muscle. Activation of leptin signaling in skeletal muscle activates the AMP-activated protein kinase (AMP-kinase), known to play a key role in signaling in response to nutrients throughout evolution. AMPK phosphorylates and inactivates the enzyme ACC, acetyl-CoA carboxylase. ACC catalyzes the production of malonyl-CoA from acetyl-CoA. Malonyl-CoA in turn is an inhibitor of the import of fatty acids into mitochondria by carnitine palmitoyl-transferase I for oxidation and energy production. In the presence of leptin, AMPK is activated, ACC is inhibited, and malonyl-CoA levels fall, increasing the oxidation of fatty acids and reducing the lipid content of cells. The reduced lipid content in skeletal muscle allows insulin signaling and glucose consumption to return to their normal levels, reducing insulin resistance.

Standard name | BIOCARTA_RHO_PATHWAY
Systematic name | M1001
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Rho cell motility signaling pathway
Full description | RhoA is a small G-protein in the Rho family that regulates cell morphology via actin cytoskeleton reorganization in response to extracellular signals. The majority of RhoA activations is due to disruption of intramolecular autoinhibitory interactions. Changes in cytoskeletal structure and other aspects of cell structure are involved in cell morphology. RhoA is activated by GEF factors, and repressed by GAPs. GEFs are guanine nucleotide exchange factors. GAPs are GTPase-activating proteins. The RhoGAP ARHGAP1 also acts as a GAP for Rac and CDC42. Active RhoA increases the stability of actin-based structures such as stress fibers and focal adhesions. Several different factors downstream of RhoA act on cytoskeletal structures to affect stability of these structures. Rock1 provides a direct link from RhoA to cell morphology through phosphorylation of the myosin light chain. Rock1 also phosphorylates and activates LIM kinase, which phosphorylates cofilin. Cofilin stimulates actin depolymerization and changes in cell structure, and phosphorylation of cofilin by LIM kinase represses this activity. According to Nimnual et al. Rho activity is reduced as a result of Rac-induced redox-dependent inhibition. Related Disease: Non-syndromic deafness appears to be the result of amino acid substitutions in the 52-amino acid C-terminal end of Dia 1. This modification creates a constituatively active Dia 1 protein. A mutation in the RhoGAP Oligophrenin-1 is thought to contribute to a form of mental retardation due to loss of Rho inhibition in neuronal development.

Standard name | BIOCARTA_AKAP13_PATHWAY
Systematic name | M17668
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Rho-Selective Guanine Exchange Factor AKAP13 Mediates Stress Fiber Formation
Full description | The A-kinase anchor protein 13 (AKAP13, also known as AKAP-LBC) is one of a group of structurally diverse proteins, which have the common function of binding to the regulatory subunit of protein kinase A (PKA) and confining the holoenzyme to discrete locations within the cell. AKAP13 is a splice variant of the oncogene Lbc. Alternative splicing of the AKAP13 gene results in at least 3 transcript variants encoding different isoforms containing a Dbl oncogene homology (DH) domain and a pleckstrin homology (PH) domain. The DH domain is associated with guanine nucleotide exchange activation for the Rho/Rac family of small GTP binding proteins, resulting in the conversion of the inactive GTPase to the active form capable of transducing signals. The PH domain has multiple functions. These splice variants contain a fragment that was originally identified as Ht31 which acts as a scaffolding protein to regulate the Rho signaling pathway and as protein kinase A-anchoring protein creating a coordination of these two signalling pathways. Diviani et al. found that in HEK293 cells LPA induced stimulation preferentially activates AKAP13 via G-alpha12. As yet targets for the anchored PKA have not been identified. AKAP13 and Rho do not appear to be phosphorylated by PKA. Diviani et al also found that the Lbc oncogene and protooncogene splice variant show higher activation and stress fiber localization. This appears to be a result of the presence of N terminal inhibitory sequences. A similar model of regulation has been proposed for Dbl and Vav.

Standard name | BIOCARTA_ATRBRCA_PATHWAY
Systematic name | M9703
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of BRCA1, BRCA2 and ATR in Cancer Susceptibility
Full description | BRCA1 and BRCA2 were identified genetically as breast cancer susceptibility genes when a single copy of the gene is mutated and are involved in the cellular response to DNA damage, including blocking cell cycle progression and inducing DNA repair to preserve the integrity of the genome during cell division. BRCA1 and BRCA2 induce double-stranded repair of breaks using homologous recombination, in part through activation of RAD51. BRCA1 acts as a ubiquitin ligase targeting the protein FancD2 that activates checkpoint control, integrating the ATM response to ionizing radiation and the FA response to cross-linking agents like mitomycin C. Mutation of one of the several components of the FA complex involved in maintaining integrity of the genome leads to the condition Fanconi anemia. One member of the FA complex was recently identified as BRCA2, which leads to Fanconi anemia when both copies of the gene are mutated. Another related factor involved in the response of cells to DNA damage is the kinase ATM. ATM is mutated in patients with AT, a condition with many similar traits to Fanconi anemia. Like ATM, ATR serves as a checkpoint kinase that halts cell cycle progression and induces DNA repair when DNA is damaged. Loss of ATR results in a loss of checkpoint control in response to DNA damage, leading to cell death, and deletion of the ATR gene in mice is embryonic lethal. ATRIP is a protein that interacts with ATR and is a substrate for its kinase activity. ATRIP is required for ATR function, and removal of ATRIP also leads to a loss of checkpoint control of the cell cycle. ATR and ATM kinase targets include repair enzymes like Rad51, and the checkpoint kinases Chk1 and Chk2, as well as BRCA1 and BRCA2. The close relationship of the genes involved in breast cancer and Fanconi anemia has helped illuminate this signaling system, and may help lead to improved understanding and treatment of these conditions.

Standard name | BIOCARTA_CARDIACEGF_PATHWAY
Systematic name | M7552
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of EGF Receptor Transactivation by GPCRs in Cardiac Hypertrophy
Full description | One of responses to increased blood pressure is cardiac hypertrophy through increased size of ventricular myocardial cells leading to increased thickness of the ventricular walls. Cardiac hypertrophy allows the heart to handle the increased stress caused by elevated blood pressure but is also a risk factor associated with heart disease. Cardiac hypertrophy results from cross-talk between G-protein coupled receptor signaling and the EGF receptor pathway. Several GPCR ligands are known to stimulate cardiac hypertrophy, including factors that regulate blood pressure such as angiotensin II and endothelin- 1. These factors stimulate phospholipase C through Gq activation, and the production of 1P3 and diacylglycerol second messengers. PKC-delta is activated by DAG and interacts with the metalloproteinase ADAM12. ADAM12 cleaves the membrane-bound HB-EGF to release soluble EGF ligand that activates EGF receptor in myocardial cells. EGF receptor activation downstream through small G proteins and the MAP kinase pathway ultimately leads to cardiac hypertrophy. Signals by GPCR ligands such as angiotensin II result in transcriptional translation of immediate early genes like fos and other genes involved in long-term remodeling of heart tissue and the physiological response to stress in the heart such as the atrial natriuretic factor. Factors such as the AKT kinase, reactive oxygen species (ROS) and NE-kB also are involved in signaling that leads to hypertrophy, although their role is not yet clear. Blocking this pathway at various steps may prevent heart disease through the prevention of cardiac hypertrophy, but may also have other consequences.

Standard name | BIOCARTA_HER2_PATHWAY
Systematic name | M18719
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of ERBB2 in Signal Transduction and Oncology
Full description | Her2 or ERBB2 belongs to a class of proteins having high homology with epidermal growth factor receptor (EGFR or ERBB1). It encodes a protein with the molecular weight of 185 KDa. Unlike other members of EGFR family, no ligand for Her2 has been found and it usually associates with members of ERBB1 family to form functional heterodimers. It has been shown that it can form dimers with ERBB (EGFR), ERBB3 and ERBB4 as well as gp130 subunits of IL-6 receptor. In at least some cell types, the association between gp130 and HRBB2 is essential for HRBB2-ERBB3 phosphorylation and subsequent MAP kinase signaling. Although ERBB1 can form homodimers, the signaling for ERBB1 is usually transient and the receptor undergoes internalization after ligand binding and activation. EGFR-HER2 complex increases the signaling capacity of EGFR by increasing the ligand affinity as well as the recycling of the heterodimer. Of all the ERBB heterodimers, ERBB2-ERBB3 heterodimers perhaps elicit the strongest signal. Removing ERBB3 from the cell has a drastic effect on ERBB2 mediated signaling and downstream effectors. The clinical importance of HER2 cannot be overstated. In addition, monoclonal antibody (Herceptin) against this receptor has been shown to be an effective treatment of breast cancer patients who have a high level of HER2 over expression.

Standard name | BIOCARTA_ERK5_PATHWAY
Systematic name | M16811
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of Erk5 in Neuronal Survival
Full description | Axons extend significant distances to innervate target tissues. At the site of innervation, target tissues release neurotrophins including NGF, BDNF and neurotrophin-3 that stimulate the survival of the associated neuron. Local signaling by activated Trk receptors at the synaptic terminus mediates some presynaptic neuronal responses to neurotrophins. Map kinase pathways activated by Trk receptor activate Erk1 and Erk2 at the terminus stimulating axonal growth, and PI3K activates AKT in the terminus as well. Activation of these kinases does not propagate a signal to the cell body though and does not induce a transcriptional response. This local signaling at the terminus or local signaling at the cell body appears distinct from the signaling pathway that transduces the survival signal from the target tissue. Retrograde axonal transport plays an essential role in neuronal survival induced by neurotrophins released at the target tissue. Failure of retrograde neurotrophin signaling may play a role in neurodegenerative conditions. The neuronal survival signal is initiated by binding of neurotrophins to Trk receptors in the presynaptic membrane, then travels back along the axon to the neuronal cell body. To transmit the signal back along the axon, activated Trk receptors are internalized through receptor-mediated endocytosis and receptor containing vesicles then rapidly travel back to the cell body along axonal microtubules. Several reports indicate that neurotrophins remain receptor-bound during the retrograde axonal transport to the cell body, but recently it was reported that retrograde transport of NGF was not required to induce neuronal survival. Once in the cell body, Trk receptors activate multiple pathways. A key pathway activated by Trk after retrograde transport involves Erk5, also called BMK1. Trk activates Mek5, which activates Erk5, inducing phosphorylation of the CREB and Mef2 transcription factors. Erk5 does not directly phosphorylate CREB, but translocates into the nucleus and phosphorylates the kinase Rsk, which phosphorylates CREB in turn. Both CREB and Mef2 induce a transcriptional program that contributes to neuronal survival. Local activation of Erk5 on the cell body does not appear to induce the same signaling system or neuronal survival, indicating that the retrograde transport is an essential part of the survival signaling system. Also, activation of Erk1 and Erk2 in the cell body can induce CREB activation and neuronal survival, but these kinases are not activated by neurotrophins applied to the axonal terminus. Another pathway activated by retrograde neurotrophin signaling though Erk5 is PI3 Kinase.

Standard name | BIOCARTA_MAL_PATHWAY
Systematic name | M10547
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of MAL in Rho-Mediated Activation of SRF
Full description | Serum response factor (SRF) is a transcription factor, which binds to a serum response element (SRE) associated with a variety of genes including (i)immediate early genes such as c-fos, fosB, junB, egr-1 and -2, (ii)neuronal genes such as nurr1 and nur77, and (iii)muscle genes such as actins and myosins. By regulating expression of these genes, SRF controls cell growth and differentiation, neuronal transmission as well as muscle development and function. SRF can be activated by serum, lysophosphatidic acid (LPA), lipopolysaccharide (LPS), 12-O-tetradecanoylphorbol-13-acetate (TPA), cytokines, tumor necrosis factor-alpha (TNFalpha), agents that increase intracellular Ca2+, T-cell virus1 activator protein, hepatitis B virus activator proteins pX, activated oncogenes and protooncogenes and extracellular stimuli such as antioxidant and UV light. In serum-starved cells, MAL is predominantly cytoplasmic where it is sequestered by actin monomers. Upon serum stimulation, Rho becomes active and, through its interaction with ROCK and mDia1, causes an accumulation of F-actin and a commensurate decrease in the level of G-actin. As a consequence, MAL is no longer sequestered and is free to translocate to the nucleus where it associates with SRF and activates SRE-mediated gene expression.

Standard name | BIOCARTA_MEF2D_PATHWAY
Systematic name | M5290
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of MEF2D in T-cell Apoptosis
Full description | Mef2 pathway.

Standard name | BIOCARTA_MITOCHONDRIA_PATHWAY
Systematic name | M16257
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of Mitochondria in Apoptotic Signaling
Full description | Mitochondria participate in apoptotic signaling pathways through the release of mitochondrial proteins into the cytoplasm. Cytochrome c, a key protein in electron transport, is released from mitochondria in response to apoptotic signals, and activates Apaf-1, a protease released from mitochondria. Activated Apaf-1 activates caspase-9 and the rest of the caspase pathway. Smac/DIABLO is released from mitochondria and inhibits IAP proteins that normally interact with caspase-9 to inhibit apoptosis. Apoptosis regulation by Bcl-2 family proteins occurs as family members form complexes that enter the mitochondrial membrane, regulating the release of cytochrome c and other proteins. TNF family receptor that cause apoptosis directly activate the caspase cascade, but can also activate Bid, a Bcl-2 family member, which activates mitochondria-mediated apoptosis. Bax, another Bcl-2 family member, is activated by this pathway to localize to the mitochondrial membrane and increase its permeability, releasing cytochre c and other mitochondrial proteins. Bcl-2 and Bcl-xL prevent pore formation, blocking apoptosis. AIF (Apoptosis inducing factor) is another mitochondrial factor that is released into the cytoplasm to induce apoptosis. AIF-induced apoptosis is important during development but is not caspase dependent.

Standard name | BIOCARTA_ACH_PATHWAY
Systematic name | M16884
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of nicotinic acetylcholine receptors in the regulation of apoptosis
Full description | Nicotinic acetylcholine receptors are essential for neuromuscular signaling and are also expressed in non-neuronal tissues, where their function is less clear. Although nicotinic acetylcholine receptors are primarily known for their action as ligand-gated ion channels transducing action potentials across synapses, they may have other actions. Nicotinic acetylcholine receptors in neurons alter apoptotic signaling, protecting against cell death in some settings, and this action may in some cases be directed through alternative signaling pathways. In neurons the alpha-7 nicotinic receptor activates PI3 kinase through a src-family kinase, activating the anti-apoptotic kinase AKT. One pathway involved in AKT signaling involves phosphorylation of the forkhead transcription factor FKHRL1, causing its retention in the cytoplasm associated with 14-3-3, and blocking expression of the apoptotic fas protein. The PI3 kinase/AKT pathway protects a broad range of neurons against apoptotic cell death and may block apoptosis triggered by beta-amyloid fragments that contributes to the progression of Alzheimers disease. If so, nicotinic agents may prove useful in the treatment of this and other neurodegenerative conditions. There are several proteins that modulate the response of nicotinic acetylcholine receptors, include synapse formation. Prior to synapse formation, nicotinic receptors are randomly dispersed in the post-synaptic membrane. A neuronal protein, agrin, binds to the Musk receptor in the muscle membrane, stimulating clustering of nicotinic receptors and synapse formation. Rapsyn is present at high levels at synapses with nicotinic receptors, bringing them together at high densities and anchoring clustered receptors to the cytoskeleton. Members of the Src family of tyrosine kinases also play a role in clustering caused by Rapsyn, phosphorylating the nicotinic receptors, rapsyn, and other targets. Nicotinic receptors expressed in non-neuronal tissues may also be involved in the response to smoking. In lung epithelial cells, nicotine from cigarette smoke blocks apoptosis by activating the anti-apoptotic kinase AKT, contributing perhaps to carcinogenesis and resistance to chemotherapy. Activation of nicotinic acetylcholine receptors in dermal fibroblasts may contribute to the altered wound healing and skin elasticity related to smoking. Activation of keratinocyte nicotinic receptors may also alter the properties of skin.

Standard name | BIOCARTA_PARKIN_PATHWAY
Systematic name | M13917
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of Parkin in the Ubiquitin-Proteasomal Pathway
Full description | The motor defects of Parkinson's disease are related to the loss of dopaminergic neurons in specific brain regions. Examination of these neurons in diseased tissue has revealed the presence of Lewy bodies, dense aggregates that include the protein alpha-synuclein. A genetic basis for most cases of Parkinson's disease has not yet been identified, but mutations in alpha-synuclein have been associated with at least one rare form of the disease, and mutations in another protein, the parkin gene, are associated with another inherited form of Parkinson's disease. Parkin is found in Lewy bodies along with alpha-synuclein and the parkin protein is an E3 ubiquitin ligase. Parkin appears to work in conjuction with ubiquitin activating (Uba)1, an E1 protein and the ubiquitin-conjugating (Ubc) enzymes UbcH7 and 8. The E1 delivers ubiquitin to the E2 in a cycle that creates an increasing chain of ubiquitin. The Parkin E3 ligates this onto substrates and so tags these proteins in normal cells, targeting them for destruction in the proteosome. One of the proteins that parkin normally targets for destruction is a specific O-glycosylated form of alpha-synuclein. Failure of parkin-mediated degradation of alpha-synuclein may be a key factor leading to the death of dopaminergic neurons. Another substrate of parkin is a GPCR-like protein called Pael-R that accumulates in the ER of affected cells and may cause neuronal cell death. The involvement of Parkin and alpha-synuclein mutations in genetic forms of Parkinson's suggest that failure of ubiquitination and protein degradation may be causative in other forms of Parkinson's. Questions remaining include the cause of the lack of effective ubiquitination in individuals lacking obvious genetic defects in this pathway and how to use this knowledge of ubiquitination and protein degradation in Parkinson's disease to identify therapeutic strategies.

Standard name | BIOCARTA_CDC42RAC_PATHWAY
Systematic name | M5291
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of PI3K subunit p85 in regulation of Actin Organization and Cell Migration
Full description | Migration of cells is involved in essential functions such as development, invasiveness of cancer cells, leukocyte movement toward chemotactic signals, and fibroblast response to injury. Cells can migrate in a specific direction in response to extracellular signals through pathways that trigger changes in the cytoskeleton, particularly actin filaments, increasing lamellipodia and filopodia formation and decreasing focal adhesions. Factors like PDGF activate PI3 kinase and multiple pathways downstream to stimulate cell migration. One pathway regulating migration through the p85 regulatory subunit of PI3 kinase does not require PI3-kinase activity. In this pathway, p85 of PI3-kinase activates cdc42, which activates N-Wasp (Wiskott-Aldrich Syndrome Protein) to regulate ARP-2/3. ARP-2/3 is a complex of proteins localized at the leading edge of moving cells that nucleates the formation of new actin fibers and interacts with Wasp to stimulate migration. The cdc42 pathway also regulates p21-activate kinase 1 (PAK1). Another pathway by which PI3 kinase regulates migration is through the small GTPase Rac. PAK1 is a downstream target of Rac as well as cdc42. Downstream of Rac and PAK1, Myosin light chain kinase (MLCK) phosphorylates myosin light chain to increase cell migration. The regulation of the localization and activity of signaling factors creates coordinated pathways linking extracellular signals and cellular migration.

Standard name | BIOCARTA_RANMS_PATHWAY
Systematic name | M17370
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of Ran in mitotic spindle regulation
Full description | One of the central features of mitotic cell division is the formation of the spindle that segregates chromosomes into each daughter cell. Chromosomes are not just passengers along for a ride with the spindle, but active participants in the nucleation and stabilization of spindle microtubules in their near vicinity. The ras-like GTPase Ran that regulates nucleocytoplasmic transport through the nuclear pore complex (NPC) during interphase also regulates the formation of the mitotic spindle. Ran plays a similar role in each of these processes, regulating downstream signaling pathways in a differential manner based on whether GDP or GTP is bound. Like other GTPases, the inherent GTPase activity of Ran is regulated by GTPase activating proteins (GAPs) and by exchange factors. An exchange factor that stimulates nucleotide exchange by the Ran GTPase is RCC1, which binds to chromatin in both interphase and mitosis. While RCC1 helps RAN drive transport between the nucleus and cytoplasm during interphase, the localization of RCC1 on chromatin during mitosis localizes Ran-GTP near chromosomes, localizing microtubule formation in these regions. Ran-BP1 and Ran-GAP1 stimulate GTP hydrolysis by Ran, converting it back to Ran-GDP further away from chromosomes. Aster promoting activities (APA) and the importin-alpha and importin-beta proteins involved with Ran in nucleocytoplasmic transport are also involved in mitotic spindle formation. Aster promoting activities stabilize microtubules during spindle formation, but binding of importins to APA neutralizes their activity in forming microtubules. The importins bind to APA when far from the chromosomes, where Ran-GDP predominates, but Ran-GTP near chromosomes causes importins to release APA factors including Tpx2 and NuMa, allowing them to stimulate microtubule formation. Tpx2 interacts with the microtubule motor protein Xklp2 and also activates the Aurora A mitotic kinase, required for spindle formation. In addition to regulating spindle formation, Ran may also help reform the nuclear envelope after cell division and may use a similar mechanism to regulate other cellular processes.

Standard name | BIOCARTA_BARR_MAPK_PATHWAY
Systematic name | M668
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of b-arrestins in the activation and targeting of MAP kinases
Full description | The binding of -arrestins to agonist-occupied GPCRs triggers the assembly of a MAP kinase activation complex using -arrestin as a scaffold, with subsequent activation of a -arrestin-bound pool of ERK1/2. The receptor-arrestinERK complexes are localized to endosomal vesicles, and their formation does not result in nuclear translocation of activated ERK1/2 or stimulation of cell proliferation. The function of -arrestin-bound ERK1/2 is presently unknown. Activation of ERK1/2 by -arrestin scaffolds may favor the phosphorylation of plasma membrane, cytosolic, or cytoskeletal ERK1/2 substrates, or it may lead to transcriptional activation through the ERK-dependent activation of other kinases. The model depicts -arrestin scaffolding of the ERK1/2 MAP kinase cascade, based upon data obtained with the protease-activated PAR2 and angiotensin AT1a receptors. A similar mechanism has been proposed for regulation of the JNK3 MAP kinase cascade by AT1a receptors.

Standard name | BIOCARTA_TOB1_PATHWAY
Systematic name | M18215
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of Tob in T-cell activation
Full description | Regulation of T cell activation is a crucial component of balanced functioning of the immune system. If the T cell response is too great and activation of self-responsive cells or unstimulated cells is not suppressed, then autoimmune disorders or tissue injury can result. Unstimulated T cells are maintained in a quiescent state and the activity of self-reactive T cells is maintained in an anergic state in which IL-2 expression is repressed. IL-2 is a cytokine with a key role in the activation and proliferation of T cells. The maintenance of T cells in the anergic or unstimulated state may not involve just an absence of activation, but an active repression of IL-2 expression, T cell proliferation and activation. TGF beta may play a role in suppressing T cell activation. Tob is a factor identified recently that represses T cell activation that is a member of a family of genes with anti-proliferative properties. Tob expression is highest in unstimulated and anergic T cells, and is reduced in activated T cells. Tob interacts with the TGF activated transcription factors SMAD2 and SMAD4, increasing their binding to the IL-2 promoter, and helping to repress IL-2 expression. This role of Tob suggests that interference in Tobs function may lead to autoimmune disease.

Standard name | BIOCARTA_BARRESTIN_SRC_PATHWAY
Systematic name | M111
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Roles of b-arrestin-dependent Recruitment of Src Kinases in GPCR Signaling
Full description | The binding of -arrestins to agonist-occupied GPCRs coincides with the recruitment of Src family tyrosine kinases, including c-Src, Hck and c-Fgr (Src-TK), to the receptor-arrestin complex. Several signaling events have been reported to involve -arrestin-dependent Src recruitment. These include the regulation of clathrin-dependent 2-adrenergic receptor endocytosis by tyrosine phosphorylation of dynamin, Ras-dependent activation of the ERK1/2 MAP kinase cascade and stimulation of cell proliferation by 2-adrenergic and neurokinin NK1 receptors, and stimulation of chemokine CXCR1 receptor-mediated neutrophil degranulation

Standard name | BIOCARTA_NKT_PATHWAY
Systematic name | M4047
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Selective expression of chemokine receptors during T-cell polarization
Full description | Chemokine receptors expressed by T helper cells help recruit cells to specific locations based on their chemoattractant ligands. The polarization of T cells into Th1 and Th2 cells is associated with their expression of different subsets of chemokine receptors. Naive CD4 positive cells that have not been exposed to antigen express CXCR4 and CCR7. The most abundant chemokine receptors on Th1 cells involved in the cellular immune response to microbial agents include CXCR3, CCR1, CCR2 and CCR5, while Th2 cells express CCR2, CCR3 and CCR5. An additional class of T cells termed semi-nave cells may be induced by TGF-beta to express yet another class of chemokine receptors, CCR4 and CCR7. Although the expression of chemokine receptors in different cells is preferred in these cases, it is not absolute or exclusive, and there is overlap in expression between Th1 and Th2 cells. Although CCR7 positive cells have been reported to lack effector action, not be polarized, and to home only to lymphoid tissues, other studies have found CCR7 positive Th1 and Th2 cells and have identified CCR7 positive cells in non-lymphoid tissues. CCR4 appears associated with homing of lymphocytes to the skin, and CCR9 is associated with homing to the small intestine, while other chemokines like CXCR3 and CCR5 are associated with homing toward inflamed tissues more broadly. The expression of different chemokine receptors by subsets of T helper cells plays an important role in the migration and homing of these cells in tissues, and targeting of the immune response to specific cells.

Standard name | BIOCARTA_IL1R_PATHWAY
Systematic name | M12095
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Signal transduction through IL1R
Full description | Interleukin-1 (IL-1) is a pro-inflammatory cytokine that signals primarily through the type 1 IL-1 receptor (IL-1R1). The activities of IL-1 include induction of fever, expression of vascular adhesion molecules, and roles in arthritis and septic shock. The inflammatory activities of IL-1 are partially derived by transcriptionally inducing expression of cytokines such as TNF-alpha and interferons, as well as inducing the expression of other inflammation-related genes. There are two forms of IL-1 encoded by distinct genes, IL-1 alpha and IL-1 beta. IL-1 beta is produced as a 269 amino acid precursor that is cleaved by IL-1beta converting enzyme (ICE) to the active IL-1 beta form that is secreted. IL-1 signaling is opposed by the naturally occurring peptide IL-1 receptor antagonist which is a therapeutic agent for the treatment of arthritis. The type 1 IL-1 receptor protein binds IL-1 beta but requires the IL-1 receptor accessory protein (IL-1RAcP) to transduce a signal. IL-1 binding causes activation of two kinases, IRAK-1 and IRAK-2, associated with the IL-1 receptor complex. IRAK-1 (IL-1 Receptor Associated Kinase) activates and recruits TRAF6 to the IL-1 receptor complex. TRAF6 activates two pathways, one leading to NF-kB activation and another leading to c-jun activation. The TRAF associated protein ECSIT leads to c-Jun activation through the Map kinase/JNK signaling system. TRAF6 also signals through the TAB1/TAK1 kinases to trigger the degradation of I-kB, and activation of NF-kB. The IL-1 signaling cascade represents a highly conserved response to pathogens through evolution, with homologs in insects and even in plants. The signal transduction cascade utilized by IL-1 receptor is similar to that of TNF, resulting in NF-kB activation, and is most similar to that of the Toll-like receptors that also participate in inflammatory signaling responses to pathogen components like endotoxin.

Standard name | BIOCARTA_MET_PATHWAY
Systematic name | M19358
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Signaling of Hepatocyte Growth Factor Receptor
Full description | The hepatocyte growth factor receptor, also called c-Met, is activated by HGF and stimulates proliferation of hepatocytes and other cell types. Mutated forms of the HGF receptor are associated with oncogenesis and metastasis, making the HGF receptor a potential therapeutic target for cancer drugs. Changes in cell motility, cell shape, adhesion, resistance to apoptosis, and anchorage independent growth all contribute to the role of c-Met in cancer. The HGF receptor is a heterodimer with tyrosine kinase activity and associates with a multiprotein complex involved in downstream signal transduction. The HGF receptor can associate with several different signaling systems, including src, Grb2/SOS, PI3 kinase and Gab1. One of the major substrates of the activated HGF receptor tyrosine kinase is the adaptor protein Gab1. Gab1 interacts with Crk and CrkL, two proteins with SH2 and SH3 protein interaction domains that couple to signaling further downstream. The actions of HGF on paxillin, DOCK180 and Rap1 mediated through GAB1 and other members of this complex alter cell motility. Regulation of Rho, Rac1 and CDC42 pathways in response to HGF all contribute to changes in cellular motility. Another target of the HGF receptor kinase is the focal adhesion kinase, FAK. The activation of FAK induces the formation of focal adhesions, a preliminary step to increased cell motility and tissue invasion by transformed cells, and paxillin phosphorylation may also alter cell adhesion of Met transformed cells. Src and p130cas are required for the role of FAK in HGF induced cellular transformation. HGF also blocks anoikis, the induction of apoptosis through suspension of cells, by acting on Erk and AKT kinases. This activity may contribute to anchorage independent growth of Met transformed cells. Signaling by integrins also plays a key role in the activation of tissue invasive growth by HGF. The alpha6beta4 integrin acts as a cofactor along with Meta to participate in cell growth and proliferation. In addition to altering cell adhesion, proliferation and cell motility, HGF alters cellular transcription through activation of STAT3. STAT3 activation by HGF is independent of PI3 kinase or map kinases and alters gene expression leading to changes in cellular shape. Although HGF is associated with cellular proliferation and survival, in rat liver epithelial cells HGF induces apoptosis and inhibits cell growth.

Standard name | BIOCARTA_GPCR_PATHWAY
Systematic name | M9664
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Signaling Pathway from G-Protein Families
Full description | G-aS-coupled receptors stimulate adenylyl cyclase (AC), which synthesizes cAMP from ATP. In contrast Gai-coupled receptors inhibit AC and so reduce cAMP formation. The bg subunits from Gai and other G proteins are able to activate the MAP kinase pathways and PLCb. GPCRs coupled to the Gaq family of G proteins stimulate PLCb, which cleaves membrane phospholipids to produce IP3, which mobilizes intracellular calcium, and DAG, which activates PKC. Second messenger pathways then activate a range of effector systems to change cell behaviour; in many cases this includes the regulation of gene transcription. Dotted line shows a more indirect pathway.

Standard name | BIOCARTA_IGF1MTOR_PATHWAY
Systematic name | M16991
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Skeletal muscle hypertrophy is regulated via AKT/mTOR pathway
Full description | Skeletal muscle atrophies with disuse while with increased use and increased load skeletal muscle exhibits hypertrophy, with an increase in the size of existing muscle fibers. One signaling pathway involved in regulating skeletal muscle atrophy and hypertrophy is the AKT/mTOR pathway. The mTOR pathway activity increases in response to muscle activity during hypertrophy and decreases in activity during atrophy. Blocking this pathway genetically or with the mTOR inhibitor rapamycin blocks hypertrophy and genetic activation of the pathway induces hypertrophy. One agent that promotes muscle hypertrophy is the growth factor IGF-1. IGF-1 activates AKT, GSK-3beta and mTOR to promote hypertrophy. In contrast, the calcineurin pathway is not involved in hypertrophy and is down-regulated by agents such as IGF-1 that promote hypertrophy. Calcineurin may modulate other aspects of muscle function such as the development of slow muscle fibers through transcriptional regulation. These pathways lead to regulation of protein translation, with increased translation apparently acting as a key regulatory point in skeletal muscle hypertrophy. Agents such as IGF-1 that stimulate skeletal muscle hypertrophy may provide treatments for muscle atrophy and wasting.

Standard name | BIOCARTA_SODD_PATHWAY
Systematic name | M2699
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | SODD/TNFR1 Signaling Pathway
Full description | The tumor necrosis factor (TNF) receptor superfamily contains several members with homologous cytoplasmic domains known as death domains (DD). The intracellular DD are important in initiating apoptosis and other signaling pathways following ligand binding by the receptors.1 In the absence of ligand, DD-containing receptors are maintained in an inactive state. TNF RI contains a cytoplasmic DD required for signaling pathways associated with apoptosis and NF-kB activation.2,3 Jiang et al.4 identified a widely expressed 60 kDa protein, named SODD (silencer of death domains), associated with the DD of TNF RI and DR3. Overexpression of SODD suppresses TNF-induced cell death and NF-kB activation demonstrating its role as a negative regulatory protein for these signaling pathways. TNF-induced receptor trimerization aggregates the DD of TNF RI and recruits the adapter protein TRADD.3,5 This in turn promotes the recruitment of the DD-containing cytoplasmic proteins FADD, TRAF2 and RIP to form an active TNF RI signaling complex (Figure 1A).6-9 In contrast, SODD acts as a silencer of TNF RI signaling and does not interact with TRADD, FADD, or RIP (Figure 1B).4 It is associated with the DD of TNF RI and maintains TNF RI in an inactive, monomeric state. TNF-induced aggregation of TNF RI promotes the disruption of the SODD-TNF RI complex. SODD does not interact with the DD of other TNF receptor superfamily members such as Fas, DR4, DR5, or TNF RII. SODD association with TNF RI may represent a general model for the prevention of spontaneous TNF signaling by other DD-containing receptors.

Standard name | BIOCARTA_SHH_PATHWAY
Systematic name | M11792
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Sonic Hedgehog (Shh) Pathway
Full description | Sonic Hedgehog (Shh) is one of a family of three secreted proteins, including Indian Hedgehog (Ihh) and Desert Hedgehog (Dhh), that play distinct and crucial roles in development. The morphogenic signal Shh provides in the developing CNS induces proliferation of neuronal precursor cells in the developing cerebellum and other tissues. Proliferative signaling by Shh is involved in the development of cancer, including specific brain and skin cancers such as basal cell carcinomas, while activation of Shh signaling in neurons may also provide a means to induce neuronal regeneration. Mitogenic Shh signaling does not appear to involve Map kinase pathways, but may involve induction of Cyclin D1 expression to maintain Rb in the hyperphosphorylated state and allow progression through the G1 phase of the cell cycle. Activation of myc may be one mechanism by which Shh induces cell cycle progression. Activation of Shh proliferative signaling occurs through binding to a receptor complex including Patched (Ptc-1) and Smoothened, a G-protein coupled receptor. Patched is an integral membrane protein with twelve transmembrane domains that acts as an inhibitor of Smoothened activation. Patched has been classified as a tumor suppressor due to its inhibition of Smoothened and the presence of inactivated Ptc-1 mutations in some cancers. One possibility is that Ptc-1, which resembles transmembrane channels, may not directly associate with Smoothened but may repress Smoothened signaling by transporting an endogenous Smoothened inhibitor across the plasma membrane into the cytoplasm. Small non-peptidic agonists and antagonists of the Shh pathway have been identified and appear to act at the level of the Smoothened receptor, providing pharmacological tools to study Shh signaling. The pathway downstream of the Smoothened receptor has remained somewhat unclear, but involves the Gli family of transcriptional activators, including Gli-1, Gli-2, and Gli-3, homologs of the drosophila gene cubitis interruptis. Kinases including GSK-3 and PKA oppose activation of the Shh pathway, perhaps by regulating the stability of Shh pathway intermediate signaling factors transcription factors. Supressor of Fused (SUFU) interacts directly with Gli proteins, repressing Shh signaling while Dyrk1 is a kinase that acts by a distinct pathway to stimulate Gli1 activation of transcription. The multiplicity of factors involved in Shh signaling creates many opportunities for therapeutic intervention in the treatment of cancer and possibly neurodegenerative diseases.

Standard name | BIOCARTA_PTC1_PATHWAY
Systematic name | M13022
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Sonic Hedgehog (SHH) Receptor Ptc1 Regulates cell cycle
Full description | Sonic Hedgehog (Shh) is a secreted protein identified genetically as an important developmental factor. Shh provides a morphogenic signal in the developing CNS, organizing the spatial patterning of cells in the midbrain and inducing proliferation of neuronal precursor cells in the developing cerebellum, neural tube and retina. Proliferative signaling by Shh is involved in the development of cancer, including specific brain and skin cancers such as basal cell carcinomas. Sonic hedgehog signaling may proceed by more than one mechanism. One signaling pathway is activated by Shh binding to Patched (Ptc-1) which releases inhibition of the GPCR Smoothened, activating the Shh signaling pathway and allowing progression through the G1 phase of the cell cycle. Shh can also affect progression through the G2/M transition. Patched binds to phosphorylated Cyclin B1, one component of the M-phase promoting factor (MPF), along with the kinase Cdc2. The interaction of Cyclin B1 with Patched blocks MPF activity, blocking progression through the G2/M transition. Shh binding leads to degradation of Ptc-1, release of Cyclin B1, and entry of the cyclin B1 into the nucleus. Patched acts as a tumor suppressor by blocking MPF activity. Blockade of the Hedgehog pathway by cyclopamine demonstrated the therapeutic potential of Hedgehog inhibition in the treatment of some cancers.

Standard name | BIOCARTA_SPRY_PATHWAY
Systematic name | M1389
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Sprouty regulation of tyrosine kinase signals
Full description | Four different members of the Sprouty protein family block the cellular proliferation and differentiation induced by several different growth factors, including EGF and FGF. One mechanism by which Sprouty proteins inhibit signaling is through binding to Grb-2, a signaling intermediary between the tyrosine kinase growth factors and the Ras/map kinase pathway. Binding of Sprouty to Grb-2 prevents Grb-2 and Sos-1 from interacting with downstream signaling factors that activate Ras and map kinases, including Ras, Raf-1, Mek1, Erk1/2 and downstream transcription factors. The action of Sprouty as an inhibitor of this pathway requires Sprouty phosphorylation and membrane localization, at the site of the factors it interacts with. The inhibition of growth factor signaling by Sprouty is specific to the Ras pathway since the PI3 Kinase pathway responsible for cell survival signals from growth factor receptors is not inhibited by Sprouty. Tyrosine kinase activity of growth factor receptors is also not affected. The mechanism by which Sprouty inhibits Ras activation may be by blocking the nucleotide exchange activity of Sos. Sprouty expression is induced by growth factor receptor activation of Ras signaling, provided a self-regulatory feedback inhibition mechanism that regulates growth factor signaling through Ras. In addition to blocking the Ras pathway, Sprouty also induces protein tyrosine phosphatase 1B activity. Activation of PTP1B by Sprouty is responsible for the inhibition of cellular migration that Sprouty causes, but is not involved in regulation of cellular proliferation. While blocking receptor tyrosine kinase signaling, at least one member of the Sprouty family, Sprouty-2, also acts by one mechanism to stimulate EGF receptor signaling. Cbl targets the EGF receptor for tagging with ubiquitin and proteolytic destruction. Sprouty-2 binds to Cbl and blocks the ubiquitination and destruction of the EGF receptor, increasing EGF signaling.

Standard name | BIOCARTA_BARRESTIN_PATHWAY
Systematic name | M7772
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | b-arrestins in GPCR Desensitization
Full description | Role of -arrestins in the desensitization, sequestration and intracellular trafficking of GPCRs. Homologous desensitization of GPCRs (1) results from the binding of -arrestins (-arr) to agonist -occupied receptors following phosphorylation of the receptor by GRKs. -arrestin binding sterically precludes coupling between the receptor and heterotrimeric G proteins, leading to termination of signaling by G proteins effectors. Receptor-bound -arrestins also act as adapter proteins, binding to components of the clathrin endocytic machinery including clathrin, 2-adaptin (AP-2). Receptor sequestration (2) reflects the dynamin (Dyn)-dependent endocytosis of GPCRs via clathrin-coated pits. Once internalized, GPCRs exhibit two distinct patterns of -arrestin interaction. `Class A' GPCRs, for example the 2 adrenergic receptor, rapidly dissociate from -arrestin upon internalization. These receptors are trafficked to an acidified endosomal compartment, wherein the ligand is dissociated and the receptor dephosphorylated by a GPCR-specific protein phosphatase PP2A isoform, and are subsequently recycled to the plasma membrane (3). `Class B' receptors, for example the angiotensin II AT1a receptor, form stable receptor--arrestin complexes. These receptors accumulate in endocytic vesicles and are either targeted for degradation or slowly recycled to the membrane via as yet poorly defined routes.

Standard name | BIOCARTA_STATHMIN_PATHWAY
Systematic name | M16966
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Stathmin and breast cancer resistance to antimicrotubule agents
Full description | Stathmin is a ubiquitous, cytosolic 19-kDa protein, which is phosphorylated on up to four sites in response to many regulatory signals within cells. Its molecular characterization indicates a functional organization including an N-terminal regulatory domain that bears the phosphorylation sites, linked to a putative alpha-helical binding domain predicted to participate in coiled-coil, protein-protein interactions. In addtion to the protein kinases that phospjhorylate Stathmin such as CaMK, MAPK, p34cdc2, PKA, a few other proteins have been suggested to interact with stathmin in vivo. One of them was identified as BiP, a member of the hsp70 heat-shock protein family. Another is a previously unidentified, putative serine/threonine kinase, KIS, which might be regulated by stathmin or, more likely, be part of the kinases controlling its phosphorylation state. Finally, two proteins, CC1 and CC2, predicted to form alpha-helices participating in coiled-coil interacting structures. It has been also suggest that the action of antimicrotubule drugs can be affected by stathmin in at least two ways: (a) altered drug binding; and (b) growth arrest at the G2 to M boundary. Mutant p53 breast cancers exhibiting high levels of stathmin may be resistant to antimicrotubule agents.

Standard name | BIOCARTA_HSP27_PATHWAY
Systematic name | M2587
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Stress Induction of HSP Regulation
Full description | Mammalian cells can respond to a variety of stresses such as heat, cold, oxidative stress, metabolic disturbance, and environmental toxins through necrotic or apoptotic cell death, while increased expression and phosphorylation of heat shock proteins such as Hsp27 can protect cells against cellular stress. Heat shock proteins commonly exhibit molecular chaperone activity and also interact with a wide variety of proteins to exert specific effects. The small heat shock protein Hsp27 exists as monomers, dimers, and oligomers in the cell, and each form has distinct activities. Oligomers are the main form of Hsp27 with molecular chaperone activity and are disrupted by phosphorylation of Hsp27 to form dimers and monomers. S-thiolation of Hsp27 on cysteine also dissociates oligomers and may provide another route of regulating the action of Hsp27 in stress. Map kinase cascades mediate Hsp27 phosphorylation. Heat stress activates the p38 kinase cascade and induces phosphorylation of Hsp27 by the downstream Map kinases Mapkapk2 and Mapkap3. Cytokines such as TNF and IL-1 can also induce Hsp27 phoshorylation through this Map kinase cascade, protecting cells in some settings against cytotoxic responses. In stressful conditions, dissociation of oligomeric Hsp27 by phosphorylation may allow lower molecular weight forms to perform other non-chaperone functions. One action of Hsp27 induced by stress is to protect cells against apoptosis and a common component of apoptotic pathways is the mitochondrial release of cytochrome c. One way that Hsp27 reduces apoptosis is by preventing the release of cytochrome c and by binding to cytochrome c in the cytosol. Downstream, Hsp27 also blocks caspase 9 activation and the subsequent activation of caspase 3, inhibiting the rest of the proteolytic caspase cascade. Yet a further role of Hsp27 in blocking apoptosis is through blocking Fas-induced apoptosis. Fas is a receptor in the TNF receptor gene family that induces apoptosis when stimulated by its cell-bound ligand, Fas-ligand. Fas induces apoptosis through two pathways, one mediated by the protein Daxx. Phosphorylated Hsp27 dimers block apoptosis by binding with Daxx and preventing downstream activation of the kinase Ask1. The interaction of Hsp27 with actin filaments may also prevent apoptosis triggered by some agents like staurosporine that damage actin. Unphosphorylated Hsp27 monomers regulate actin filament growth by binding to the end of fibers and capping them. Finally, Hsp27 appears to prevent damage to cells by reactive oxygen species (ROS), by altering the oxidative environment of the cell through induction of glutathione expression, as well as blocking apoptosis induced by ROS. Modulation of Hsp27 expression and phosphorylation may provide a useful means to alter cellular sensitivity to stress.

Standard name | BIOCARTA_TCR_PATHWAY
Systematic name | M19784
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | T Cell Receptor Signaling Pathway
Full description | The T Cell Receptor plays a key role in the immune system. The specificity of the receptor is governed by the binding site formed from the mature alpha and beta chains (shown here) or gamma and delta chains in gamma/delta T Cells. It is the ability of this receptor to bind a complex of foreign peptide in the groove of an MHC molecule that leads to T cell activation. Upon activation the T cell can assist in activating other cells or carry out cytolytic attacks depending on the particular T cell type. The CD3 complex and CD4 (Th cells) or CD8 (Tc cells) work to transmit the activation signal to the T cell's transcriptional machinary upon engagement of the receptor.

Standard name | BIOCARTA_TCYTOTOXIC_PATHWAY
Systematic name | M13247
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | T Cytotoxic Cell Surface Molecules
Full description | Cytotoxic T cells are a key part of the cellular immune response, killing cells that display foreign antigen on their surface, primarily virus-infected cells. Transformed cells can also be detected and eliminated by cytotoxic T cells. There are two mechanisms by which activated cytotoxic T cells kill cells presenting specific antigen. One method involves the release of secretory granules containing perforin and granzyme to induce lysis of the targeted cell. Cytotoxic T cells also express Fas ligand to bind to Fas on target cells and induce apoptosis. Communication with and interaction with other cell types is essential for cytotoxic T cell function. Distinct types of T cells are characterized and their activities determined by the proteins they express on their cell surface. Cytotoxic T cells will only respond to antigen presented on the surface of cells bound to MHC I proteins, not antigens present in solution. The T cell receptor, with the multiprotein CD3 complex, is responsible for the recognition of specific antigens, triggering the activation and proliferation of cells. Cytotoxic T cell activation also requires additional signals provided by helper T cells in addition to signals provided by antigen-presenting cells. Thy1 provides a general marker of T cells, and the presence of CD8 protein that binds to MHC distinguishes cytotoxic T cells from CD4 positive helper T cells. CD28 expressed by T cells acts as a costimulatory signal with the T cell receptor when it binds its ligand, a B-7 coreceptor, on antigen-presenting cells. Inappropriate regulation of the costimulatory signal can lead to too great or too small of an immune response. Interaction of activated cytotoxic T cells is aided by increased expression of LFA-1, a cell-adhesion molecule that binds to ICAM on target cells. CD2 is a T cell adhesion molecule. Mice with a disrupted CD2 gene are largely normal and appear to have a normal immune system, but CD2 on cytotoxic T cells may assist in interaction with target cells.

Standard name | BIOCARTA_THELPER_PATHWAY
Systematic name | M6427
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | T Helper Cell Surface Molecules
Full description | T helper cells play an essential role coordinating the activities of other parts of the immune system, including B cells, cytotoxic T cells, macrophages and other cells. The crucial nature of helper T cells in the normal immune response is demonstrated by the severe immune deficiency associated with the HIV-induced helper T cell depletion. To communicate with other cells, helper T cells express a range of cell surface molecules, a few of which are illustrated in this figure. Like all T cells, helper T cells express T cell receptors complexed with the CD3 proteins that are responsible for the recognition and response of the cell to specific antigens. CD4 is commonly used as a marker for helper T cells, in contrast to cytotoxic T cells, which express CD8. CD4 is used by HIV to gain cell entry, as well as the CCR5 chemokine receptor. Thy1 provides a more general cell surface antigen used to identify both T helper and cytotoxic T cells. CD28 provides a costimulatory signal in association with the activation of the T cell receptor complex by an antigen presenting cell that is required for the T cell to become activated. Adhesion molecules on the surface of T cells assist in their interaction with other cells. LFA-1 binds to its ligand ICAM-1 in a variety of cells and T cells themselves also express ICAM-1. The CD45 protein tyrosine phosphatase dephosphorylates factors in the pathways involved in B cells and T cells activation. Although CD45 is required for T cell receptor activation, exclusion of CD45 from the local membrane region near the T cell receptor appears important for efficient T cell activation. Helper T cells can be subdivided further into Th1 and Th2 cells, distinguished by their response to different antigens, differing cytokine expression and expression of different chemokine receptors CD2 is required for efficient helper T cell maturation and stimulates their differentiation, but does not select for a specific increase in Th1 or Th2 populations of cells.

Standard name | BIOCARTA_TALL1_PATHWAY
Systematic name | M12985
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | TACI and BCMA stimulation of B cell immune responses.
Full description | TACI and BCMA signal transduction pathway that enhances cell survival APRIL and BAFF (also called TALL-I and BLyS) are TNF family members that act as ligands for the BCMA and TACI receptors. Both APRIL and BAFF bind to both the BCMA and TACI receptors to activate the humoral immune response, stimulating B cell immunoglobulin production and proliferation. BAFF is found as a membrane bound form in T cells and a soluble form that is released from the cell to stimulate B cell proliferation and differentiation. As members of the TNF receptor gene family, BCMA and TACI interact with TRAF family members to transduce signals downstream to NF-kappaB activation and MAP kinase pathways. Abnormally active BAFF or APRIL signaling may play a role in autoimmune disorders such as lupus.

Standard name | BIOCARTA_TEL_PATHWAY
Systematic name | M10401
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Telomeres, Telomerase, Cellular Aging, and Immortality
Full description | Telomeres, which define the ends of chromosomes, consist of short, tandemly repeated DNA sequences loosely conserved in eukaryotes. Telomerase is a ribonucleoprotein complex ( we only show a few of the components in this illustration) which in vitro recognizes a single-stranded G-rich telomere primer and adds multiple telomeric repeats to its 3-prime end by using an RNA template. Telomerase may also have a role in de novo formation of telomeres. Telomerase has been identified in many cultured cell lines and actively dividing cell types. The active reverse transcriptase component has been identified in teh TERT protein. The presence of this factor determines the availability of the telomerase function. The TERT protein has a high turnover rate and its expression is regulated by factors that promote growth (c-MYC, v-k-ras, Bcl-2 and E6) and inhibiting factors (RB and p53) that promote cell death or that block cell division. It appears that the regulation of active telomerase has many levels and can be inhibited by TEP1 not releasing TERT or by TRF1 which binds the end repeats and prevents access to the chromosome ends. Additional modulation is due to phosphorlyation by PKC and AKT or dephophorylation by PP2A. Wilke et al found that a case of human alpha-thalassemia was caused by a truncation of chromosome 16 that had been healed by the addition of telomeric repeats (TTAGGG)n. Human telomeres consist of many kilobases of (TTAGGG)n together with various associated proteins. Small amounts of these terminal sequences are lost from the tips of the chromosomes during each S phase because of incomplete DNA replication, but de novo addition of TTAGGG repeats by the enzyme telomerase compensates for this loss. Many human cells progressively lose terminal bases with each cell division, a loss that correlates with the apparent absence of telomerase in these cells. There has been considerable interest in the possible relationship between human telomeres and cellular senescence and immortalization. This interest includes the question of a role in the malignant process and the question of the use of telomerase inhibitors as anti-tumor drugs.

Standard name | BIOCARTA_TGFB_PATHWAY
Systematic name | M18933
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | TGF beta signaling pathway
Full description | TGF-beta regulates growth and proliferation of cells, blocking growth of many cell types. The TGF-beta receptor includes type 1 and type 2 subunits that are serine-threonine kinases and that signal through the SMAD family of transcriptional regulators. Defects in TGF-beta signaling, includes mutation in SMADs, have been associated with cancer in humans. Prior to activation, receptor regulated SMADs are anchored to the cell membrane by factors like SARA (SMAD Anchor for Receptor Activation) that brings the SMADs into proximity of the TGF receptor kinases. Binding of TGF induces phosphorylation and activation of the TGF-beta R1 receptor by the TGF-beta R2 receptor. The activated TGF-beta R1 phosphorylates SMAD2 and SMAD3, which bind to the SMAD4 mediator to move into the nucleus and form complexes that regulate transcription. SMADs regulate transcription in several ways, including binding to DNA, interacting with other transcription factors, and interacting with transcription corepressors and coactivators like p300 and CBP. SMAD-7 represses signaling by other SMADs to down-regulate the system. Other signaling pathways like the MAP kinase-ERK cascade are activated by TGF-beta signaling, modulate SMAD activation. SnoN also regulates TGF-beta signaling, by binding to SMADs to block transcriptional activation. TGF-beta signaling causes degradation of SnoN, releasing SMADs to regulate transcription, and also activates expression of SnoN, to down-regulate SMAD signaling at later times.

Standard name | BIOCARTA_TH1TH2_PATHWAY
Systematic name | M6705
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Th1/Th2 Differentiation
Full description | Helper T cells are found in two distinct cell types, Th1 and Th2, distinguished by the cytokines they produce and respond to and the immune responses they are involved in. Th1 cells produce pro-inflammatory cytokines like IFN-g, TNF-b and IL-2, while Th2 cells produce the cytokines IL-4, IL-5, IL-6 and IL-13. The cytokines produced by Th1 cells stimulate the phagocytosis and destruction of microbial pathogens while Th2 cytokines like IL-4 generally stimulate the production of antibodies directed toward large extracellular parasites. IL-5 stimulates eosinophil responses, also part of the immune response toward large extracellular parasites Th1 and Th2 are produced by differentiation from a non-antigen exposed precursor cell type, Thp. Exposure of Thp cells to antigen by antigen-presenting cells may result in their differentiation to Th0 cells, not yet committed to become either Th1 or Th2 cells, although the existence of Th0 cells is controversial. Cells committed as either Th1 and Th2 cells are called polarized, whether they are effector cells actively secreting cytokines or are memory cells. The stimulation of Thp cells by exposure to antigen-presenting cells induces the proliferation of undifferentiated cells, and their expression of IL-2 and IL-2 receptor. The differentiation of Th1 cells and Th2 cells depends on the cytokines they are exposed to. IL-12 causes Th1 differentiation and blocks Th2 cell production , while IL-4 causes Th2 differentiation and antagonizes Th1 development. IL-18 also induces Th1 differentiation. Polarized Th1 and Th2 cells also express distinct sets of chemokine receptors that further modify their homing and other cellular responses. Improved understanding of Th1 and Th2 differentiation will improve our overall understanding of the immune system, its response to infection and aberrant responses that lead to disease.

Standard name | BIOCARTA_41BB_PATHWAY
Systematic name | M2064
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | The 4-1BB-dependent immune response
Full description | The activation of T cells requires a co-stimulatory signal with T cell receptor activation, provided in many cases by activation of CD28 in resting T cells. 4-1BB (CD137) is a member of the TNF receptor gene family that provides another T cell co-stimulatory signal. 4-1BB is expressed by activated cytotoxic and helper T cells and its expression is induced by a variety of T cell stimuli, including activation of the T cell receptor or stimulation with mitogens. The ligand for 4-1BB (4-1BBL) is induced on activated antigen-presenting cells including macrophages, activating T cells expressing 4-1BB. Mice lacking 4-1BB survive and have an altered though functional immune response. T cells of mice lacking 4-1BB proliferate more rapidly than normal T cells, but have reduced cytokine secretion. The costimulatory signal provided by 4-1BB may act in combination with CD28 activation to prolong the T cell response, and may also act independently of CD28. Stimulation of T cells with the 4-1BB ligand may provide a therapeutic immune response in the treatment of cancer or viral infection. 4-1BB in T cells activates several signaling pathways. Like other members of the TNF receptor family, the 4-1BB receptor does not have an intrinsic kinase activity. TRAF2 is a signaling adapter that mediates signaling by other members of the TNF receptor family and that also binds to the cytoplasmic domain of ligand activated 4-1BB to activate intracellular kinase cascades. TRAF1 also binds to the cytoplasmic domain of 4-1BB although with lower affinity than TRAF2. One downstream effector activated by 4-1BB through TRAF2 is the transcription factor NF-kB. 4-1BB also activates map kinase pathways, including p38 and JNK activation. ASK1 dependent pathways can activate both p38 and JNK, and dominant negative ASK1 blocks their activation. Other kinase pathways may also be involved in 4-1BB activation of p38 and JNK, such as activation of germinal center kinase (GCK) or related kinases involved in activation of JNK and p38 by TNF. Map kinase activation along with NF-kB activation results in transcriptional activation of cytokine genes involved in T cell activation and signaling. The co-stimulatory signaling provided by 4-1BB shares some features with CD28 signaling, providing an explanation for the ability of 4-1BB to replace the CD28 costimulatory signal in some settings.

Standard name | BIOCARTA_CTLA4_PATHWAY
Systematic name | M1467
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | The Co-Stimulatory Signal During T-cell Activation
Full description | For a T cell to be activated by a specific antigen, the T cell receptor must recognize complexes of MHCI with the antigen on the surface of an antigen-presenting cell. T cells and the T cell receptor complex do not respond to antigen in solution, but even for the specific antigen they only respond to antigen-MHC-1 complexes on the cell surface. This interaction is necessary for T cell activation, but it is not sufficient. T cell activation also requires a co-stimulatory signal involving interaction of CD28 on the T cell with CD80 or CD86 (B7 family genes) on the antigen-presenting cell. CD28 activates a signal transduction pathway acting through PI-3K, Lck and Grb-2/ITK to provide its co-stimulatory signal for T cell activation. Another means to control T cell activation is by expressing factors that down-regulate T cell activation. Signaling by activated T cell receptors induces expression of CTLA-4, a receptor that opposes T cell activation. CTLA-4 has a higher affinity than CD28 for B7 proteins, terminating T cell activation. ICOS is a protein related to CD28 that is only expressed on activated T cells, and that provides another important co-stimulatory signal. The requirement for co-stimulatory signals provides additional control mechanisms that prevent inappropriate and hazardous T cell activation.

Standard name | BIOCARTA_LONGEVITY_PATHWAY
Systematic name | M13158
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | The IGF-1 Receptor and Longevity
Full description | A demonstrated means to increase lifespan in a wide range of organisms is through the restriction of caloric intake. Reducing the consumption of calories increases the lifespan of many different organisms, including mice. Although caloric restriction has not been demonstrated experimentally to increase human lifespan, short-term changes in physiological measures like insulin responsiveness have been observed. Caloric restriction not only increases lifespan, but decreases age-related deterioration of systems and physiological responses, reducing age related diseases like cancer and neurodegenerative disease. Caloric restriction in animals reduces the levels of plasma glucose and insulin and reduces inflammatory responses and may reduce oxidative stress through reduced oxidative metabolism, further contributing to the health benefits of reduced calorie intake. The reduction in inflammation may be related to reduces plasma glucose and in humans could reduce an inflammation connection to cancer, heart disease, and Alzheimers disease. Genetic analysis has indicated several genes that influence lifespan, particularly those that alter pituitary development, reduce growth hormone secretion, reduce food intake, and reduce apoptosis (p66 Shc). All of these appear to converge on an IGF-1 receptor pathway and to reproduce many of the effects of caloric restriction. Although dwarf mice with defective growth hormone or IGF-1 signaling also have significantly increased lifespan, humans with defects in growth hormone signaling tend to develop diseases that shorten their lifespan. One of the downstream targets of IGF-1 signaling is to repress stress resistance proteins including antioxidant enzymes like superoxide dismutase, and heat shock proteins, so a reduction in IGF signaling may extend lifespan by increasing the expression of stress resistance genes. The link between caloric restriction and IGF signaling may be that a reduction in food intake reduces the expression of IGF-1, increasing the expression of stress resistance proteins. In addition to the IGF-1R mutation, p66 Shc mutation also increases lifespan without significant aberration of other systems. Shc is a target of IGF-1R phosphorylation, and a major inducer of cellular responses to oxidative stress. Shc increases levels of intracellular reactive oxygen species, repressing the forkhead factor FKHRL1. Alhtough FKHRL1 is also involved in apoptosis, in the absence of Shc, FKHRL1 mediates increased resistance to oxidative stress. Exploration of the genes that induce longevity in animals models may enlighten the role of these genes in human disease and lifespan.

Standard name | BIOCARTA_SARS_PATHWAY
Systematic name | M5374
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | SARS Coronavirus Protease
Full description | Severe Acute Respiratory Syndrome (SARS) has affected thousands of individuals, causing fever, and pneumonia with a mortality rate estimated at 10-18%. A novel coronavirus has been identified as the cause agent and its genome has been sequenced. Human coronaviruses cause mild respiratory illness and accounts for about a third of all cases of the common cold. The enveloped SARS virus contains a large + strand RNA genome, approximately 30,000 nucleotides. Examination of the SARS coronavirus sequences reveals that rep gene covers over 20,000 nucleotides and encodes two overlapping polyproteins cleaved by viral proteases into smaller protein products. Translation of the longer polyprotein encoded by the rep gene requires a ribosomal frameshift. Other viral genes are predicted to encode the transmembrane spike protein S involved in viral fusion with host cells, the envelope protein E, the membrane protein M and the nucleocapsid protein N that binds to the RNA genome as well as several additional open reading frames with unknown functions. Viral entry into the cell is followed by translation of the viral rep gene, which codes for a viral protease within the polyprotein, Mpro or 3CLpro. The SARS 3CLpro has also been verified in vitro to cleave after the Gln residue at Leu-Gln-(Ser, Ala, Gly),. Polypeptides released from the polyproteins by the main viral protease Mpro or 3CLpro include the viral polymerase and a protease. Both products are essential for viral replication and transcription. Structural crystals of a porcine coronavirus protease with a transition state inhibitor suggest that inhibitors of the distantly related rhinovirus protease like the drug AG7088 may be modified to produce drugs that block the SARS protease and viral replication. Blocking entry of the SARS virus into cells, involving recognition of cellular receptors by the S spike protein, may provide another strategy for the development of drugs to treat SARS.

Standard name | BIOCARTA_PAR1_PATHWAY
Systematic name | M3494
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Thrombin signaling and protease-activated receptors
Full description | Thrombin is an extracellular protease that is involved in the clotting of blood and inflammation through its action on platelets and endothelial cells in the vasculature and that plays a role in thrombosis and myocardial infarction. The protease activated receptors PAR1 and PAR4 are cellular targets of thrombin signaling and members of the G-protein coupled receptor gene family. Both of these receptors are cleaved in their N-terminus by thrombin, unmasking a portion of the receptor sequence that acts itself as a tethered peptide ligand that activates the receptor. The tethered ligand that activates PAR1 is SFLLRN and the tethered ligand that activates PAR4 is GYPGQV. Other members of the family include PAR2 which is activated by trypsin rather than thrombin and PAR3 which seems to play a role in the activation of other PARs but does not itself transduce a signal directly. Addition of peptide agonist exogenously in solution can also activate PAR1, PAR2 and PAR4. PAR1 activation may be involved in the dilation of arteries during inflammation through the action of thrombin on endothelial cells and in platelet activation by thrombin during clotting. PAR1 and PAR2 activation cause bronchodilation in airway and may protect against asthma. PAR 4 activation by thrombin activates platelets during clotting and mice lacking PAR4 have impaired clotting and platelets that do not respond to thrombin signaling. The action of thrombin on PAR1 and PAR4 on platelets and endothelial cells may also contribute to vascular permeability and inflammation. Activated PARs appear to couple primarily through Gq-mediated stimulation of inositol phosphate metabolism and intracellular calcium levels to activate platelets. PAR1 and PAR4 also appear to couple to multiple G-proteins and transduce signals through more than one G-protein mediated pathway in some circumstances. Signaling by PAR1 and PAR4 through Galpha12 pathways couples to Rho signaling and changes in cytoskeletal structure and cell shape. Gi activation does not appear necessary for platelet activation by PAR1 or PAR4, and platelet activation by these receptors requires an ADP signal perhaps acting through the platelet-associated purinergic receptor P2Y12. Gi-coupled signaling may play a role in mitogenic PAR signaling in some settings through Map kinase activation. Activation of Rho by PAR1 can induce cellular transformation through a Galpha12 mediated mechanism and sustained rho-dependent phosphorylation of the myosin light chain by PAR1 contributes to cytoskeletal changes and activation of platelets. Since the activation of PARs by protease cleavage is irreversible the primary mechanism for down-regulation of the PAR signaling cascade appears to be internalization and degradation of PAR receptors.

Standard name | BIOCARTA_STRESS_PATHWAY
Systematic name | M9670
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | TNF/Stress Related Signaling
Full description | TNF acts on several different signaling pathways through two cell surface receptors, TNFR1 and TNFR2 to regulate apoptotic pathways, NF-kB activation of inflammation, and activate stress-activated protein kinases (SAPKs). Interaction of TNFR1 with TRADD leads to activation of NF-kB and apoptosis pathways, while interaction with TRAF2 has generally been thought to be involved in stress kinase and NF-kB activation but is not required for TNF to induce apoptosis. Activation of NF-kB is mediated by TRAF2 through the NIK kinase and also by RIP but the observation that TNF activates NF-kB in mice lacking TRAF2 indicates that TRAF-2 does not play an essential role in this process. Stress-activated protein kinases, also called JNKs, are a family of map kinases activated by cellular stress and inflammatory signals. Binding of TNF to the TNFR1 receptor activates the germinal center kinase (GCK) through the TNF adaptor Traf2, activating the map kinase MEKK1. Both GCK and MEKK1 interact with Traf2, and GCK is required for MEKK1 activation by TNF, but GCK kinase activity does not appear to be required for MEKK1 activation. Instead, GCK activates MEKK1 by causing MEKK1 oligomerization and autophosphorylation. Tank increases the affinity of Traf2 for GCK to increase Map kinase activation by TNF. Once activated, MEKK1 stands at the top of a map kinase pathways leading to transcriptional regulation, including JNK phosphorylation of c-Jun to stimulate transcriptional activation by AP-1, a heterodimer of c-jun and fos or ATF proteins. The activation of the p38 Map kinase also contributes to AP-1 activation leading to the transcriptional activation of many stress and growth related genes. RIP has been suggested as a component of the p38 pathway in addition to playing a role in NF-kB activation. MEKK1 knockout mice support the role of MEKK1 in JNK activation in some cells but did not support MEKK1 dependent activation of NF-kB. Alternative redundant mechanisms may obscure the role of MEKK1 in NF-kB mechanisms. TNF activation of stress kinase pathways and downstream transcription factors may help to modulate the apoptotic pathways also activated by TNF.

Standard name | BIOCARTA_TNFR1_PATHWAY
Systematic name | M3618
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | TNFR1 Signaling Pathway
Full description | TNFR1 (a.k.a. p55, CD120a) is the receptor for TNF(alpha) and also will bind TNF(beta). Upon binding TNF(alpha) a TNFR1+ cell is triggered to undergo apoptosis. This critical regulatory process is accomplished by activating the proteolytic caspase cascade that results in the degradation of many critical cellular proteins.

Standard name | BIOCARTA_TNFR2_PATHWAY
Systematic name | M10082
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | TNFR2 Signaling Pathway
Full description | TNFR2 is the receptor for the 171 amino acid 19 kD TNF(beta) (a.k.a. lymphotoxin). TNF(beta) is produced by activated lymphocytes and can be cytotoxic to many tumor and other cells. In neutrophils, endothelial cells and osteoclasts TNF(beta) can lead to activation while in many other cell types it can lead to increased expression of MHC and adhesion molecules.

Standard name | BIOCARTA_TOLL_PATHWAY
Systematic name | M984
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Toll-Like Receptor Pathway
Full description | The innate immune response responds in a general manner to factors present in invading pathogens. Bacterial factors such as lipopolysaccharides (LPS, endotoxin), bacterial lipoproteins, peptidoglycans and also CpG nucleic acids activate innate immunity as well as stimulating the antigen-specific immune response and triggering the inflammatory response. Members of the toll-like receptor (TLR) gene family convey signals stimulated by these factors, activating signal transduction pathways that result in transcriptional regulation and stimulate immune function. TLR2 is activated by bacterial lipoproteins, TLR4 is activated by LPS, and TLR9 is activated by CpG DNA; peptidoglycan recognition protein (PGRP) is activated by peptidoglycan (PGN). The downstream signaling pathways used by these receptors are similar to that used by the IL-1 receptor, activating the IL-1 receptor associated kinase (IRAK) through the MyD88 adaptor protein, and signaling through TRAF-6 and protein kinase cascades to activate NF-kB and Jun. NF-kB and c-Jun activate transcription of genes such as the proinflammatory cytokines IL-1 and IL-12. Several recent reports have suggested that the functional outcomes of signaling via TLR2, TLR4 and PGRP are not equivalent. For example, while the LPS-induced, p38-dependent response was dependent upon PU.1 binding, the PGN-induced, p38 response was not. The intracelular receptor for PGN, PGRP is conserved from insects to mammals. In insects, PGRP activates prophenoloxidase cascade, a part of the insect antimicrobial defense system. Because mammals do not have the prophenoloxidase cascade, its function in mammals is unknown. However, it was suggested that an identical protein Tag7 was a tumor necrosis factor-like (TNF-like) cytokine. PGRP/Tag7 possesses cytotoxicity and triggers intranucleosomal DNA fragmentation in target cells in the same way as many known members of the TNF family. Fragmentation of DNA is one of the characteristics of apoptosis. The possibility that in another system, PGRP/Tag7 would induce NF-kB activation, as observed for TRAIL (TNF-related apoptosis-inducing ligand) receptors canot be ruled out.

Standard name | BIOCARTA_TPO_PATHWAY
Systematic name | M11520
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | TPO Signaling Pathway
Full description | Thrombopoietin (TPO) binds to its receptor inducing aggregation and activation. TPO signals its growth regulating effects to the cell through several major pathways including MAPK (ERK and JNK), Protein Kinase C, and JAK/Stat.

Standard name | BIOCARTA_CREB_PATHWAY
Systematic name | M9070
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Transcription factor CREB and its extracellular signals
Full description | The transcription factor CREB binds the cyclic AMP response element (CRE) and activates transcription in response to a variety of extracellular signals including neurotransmitters, hormones, membrane depolarization, and growth and neurotrophic factors. Protein kinase A and the calmodulin-dependent protein kinases CaMKII stimulate CREB phosphorylation at Ser133, a key regulatory site controlling transcriptional activity. Growth and neurotrophic factors also stimulate CREB phosphorylation at Ser133. Phosphorylation occurs at Ser133 via p44/42 MAP Kinase and p90RSK and also via p38 MAP Kinase and MSK1. CREB exhibit deficiencies in spatial learning tasks, while flies overexpressing or lacking CREB show enhanced or diminished learning, respectively.

Standard name | BIOCARTA_CARM1_PATHWAY
Systematic name | M7968
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Transcription Regulation by Methyltransferase of CARM1
Full description | Several forms of post-translational modification regulate protein activities. Recently, protein methylation by CARM1 (coactivator-associated arginine methyltransferase 1) has been observed to play a key role in transcriptional regulation. CARM1 associates with the p160 class of transcriptional coactivators involved in gene activation by steroid hormone family receptors. CARM1 also interacts with CBP/p300 transcriptional coactivators involved in gene activation by a large variety of transcription factors, including steroid hormone receptors and CEBP. One target of CARM1 is the core histones H3 and H4, which are also targets of the histone acetylase activity of CBP/p300 coactivators. Recruitment of CARM1 to the promoter region by binding to coactivators increases histone methylation and makes promoter regions more accessible for transcription. Another target of CARM1 methylation is a coactivator it interacts with, CBP. Methylation of CBP by CARM1 blocks CBP from acting as a coactivator for CREB and redirects the limited CBP pool in the cell to be available for steroid hormone receptors. Other forms of post-translational protein modification such as phosphorylation are reversible in nature, but as of yet a protein demethylase is not known.

Standard name | BIOCARTA_TFF_PATHWAY
Systematic name | M15926
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Trefoil Factors Initiate Mucosal Healing
Full description | Maintaining the integrity of the gastrointestinal tract despite the continual presence of microbial flora and injurious agents is essential. Epithelial repair requires restitution and regeneration. During restitution, epithelial cells spread and migrate across the basement membrane to re-establish surface-cell continuity, a process that is independent of cell proliferation. Epithelial continuity depends on a family of small abundant secreted proteins, the trefoil factors (TFFs). The trefoil factor (TFF) family comprises the gastric peptides pS2/TFF1 and spasmolytic peptide (SP)/TFF2, and the intestinal trefoil factor (ITF)/TFF3. Their fundamental action is to promote epithelial-cell restitution within the gastrointestinal tract. TFFs are abundantly secreted onto the mucosal surface by mucus-secreting cells. Their expression is rapidly and coordinately upregulated at the margins of mucosal injury. Secreted TFF acts on adjacent mucosal cell populations either extracellularly (augmenting barrier function) or intracellularly (transcriptional and signalling events). TFF response elements in TFF gene promoters allow increases in TFF expression through auto-induction and cross-induction of other TFFs, in addition to mucin expression and possibly tumor suppression. Cell migration is the result of integrated disruption of cellcell and cellsubstratum adhesion and prevention of apoptosis through cell detachment. Epithelial movement therefore requires integration of motogenic and cell-survival signals. This is achieved by activation of several intracellular signalling pathways that converge on ERK/MAPK and possibly NF-B activation. Serine phosphorylation of the extracellular signal-regulated kinases (ERKs)/mitogen-activated protein kinases (MAPKs) 1 and 2 is central to trefoil factor -mediated signalling, lying downstream of EGFR activation and possibly FAK activation (through recruitment of GRB2 and SOS). Cell migration might result from cooperation between ERK/MAPKs and Rho proteins, FAK activation, beta-integrin clustering and beta-catenin activation. Abrogation of cell death has been shown to require both PI3K activation and ERK/MAPK activation; the former operates through serine/threonine phosphorylation of AKT/protein kinase B, serine phosphorylation of BAD (BCL-2 agonist of cell death) and inhibition of mitochondrial cytochrome c release and formation of the apoptosome (APAF1, caspase-9 (CASP9) and cytochrome c (CYT-c). Translocation of phosphorylated ERK/MAPK to the nucleus leads to amplification and de-restriction of TFF expression to ensure sustained action.

Standard name | BIOCARTA_TRKA_PATHWAY
Systematic name | M9134
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Trka Receptor Signaling Pathway
Full description | Nerve growth factor (NGF) is a neurotrophic factor that stimulates neuronal survival and growth through TrkA, a member of the trk family of tyrosine kinase receptors that also includes TrkB and TrkC. Some NGF responses are also mediated or modified by p75LNTR, a low affinity neurotrophin receptor. Binding of NGF to TrkA stimulates neuronal survival, and also proliferation. Pathways coupled to these responses are linked to TrkA through association of signaling factors with specific amino acids in the TrkA cytoplasmic domain. Cell survival through inhibition of apoptosis is signaled through activation of PI3-kinase and AKT. Ras-mediated signaling and phospholipase C both activate the MAP kinase pathway to stimulate proliferation.

Standard name | BIOCARTA_ARF_PATHWAY
Systematic name | M11358
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Tumor Suppressor Arf Inhibits Ribosomal Biogenesis
Full description | Cyclin-dependent kinase inhibitor-2A (CDKN2A) goes by the colloquial designation p16, which is sometimes referred to as p16(INK4). The alpha transcript of CDKN2A has been shown to encode p16(INK4a), a recognized tumor suppressor that induces a G1 cell cycle arrest by inhibiting the phosphorylation of the RB protein by the cyclin-dependent kinases CDK4 and CDK6. The beta transcript of CDKN2A encodes p14(ARF). The predicted 132-amino acid p14(ARF) is shorter than the corresponding mouse protein, p19(ARF), and the 2 proteins share only 50% identity. However, both proteins have the ability to elicit a p53 response, manifest in the increased expression of both CDKN1A and MDM2, and resulting in a distinctive cell cycle arrest in both the G1 and G2/M phases. Two unrelated proteins encoded by the INK4A-ARF locus function in tumor suppression. ARF binds to MDM2 and promotes the rapid degradation of MDM2. This interaction is mediated by the E1-beta-encoded N-terminal domain of ARF and a C-terminal region of MDM2. ARF-promoted MDM2 degradation is associated with MDM2 modification and concurrent p53 stabilization and accumulation. The p19(Arf) tumor suppressor inhibits production of ribosomal RNA, retarding processing of 47/45S and 32S precursors. These effects correlate with but do not strictly depend upon inhibition of rRNA biosynthesis or cell cycle arrest, are not mimicked by p53, and require neither p53 nor Mdm2. Arf mutants lacking conserved amino acid residues 2-14 do not block rRNA synthesis and processing or inhibit cell proliferation. Evolution may have linked a primordial nucleolar Arf function to Mdm2 and p53, creating a more efficient checkpoint-signaling pathway for coordinating ribosomal biogenesis and cell cycle progression.

Standard name | BIOCARTA_UCALPAIN_PATHWAY
Systematic name | M13143
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | uCalpain and friends in Cell spread
Full description | The mammalian calpain gene family curently contains 13 distinct large subunit products most of which complex with one of two smaller 30kDa subunits. ( An excellent introduction to the Calpain family can be found on a web site created by Valery Thompson http://ag.arizona.edu/calpains/index.html ) Spreading cells display newly transiently formed integrin adhesion clusters containing Calpain1 (mu-Calpain), cleaved Talin, B3-Integrin and SPTAN1(Spectrin). Recruitment of Rac to these clusters leads to the activation of Rac and the formation of Rac-induced Focal clusters. The Calpain1 in the integrin clusters initially inactivates RhoA allowing for the formation of lamellipodia. The subsequent activation of newly synthesized RhoA transforms these clusters into Focal Adhesion Complexes and the formation of contractile actin-myosin stress fibers. These mature adhesions do not contain calpain.

Standard name | BIOCARTA_VEGF_PATHWAY
Systematic name | M12975
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | VEGF, Hypoxia, and Angiogenesis
Full description | Vascular endothelial growth factor (VEGF) plays a key role in physiological blood vessel formation and pathological angiogenesis such as tumor growth and ischemic diseases. Hypoxia is a potent inducer of VEGF in vitro. The increase in secreted biologically active VEGF protein from cells exposed to hypoxia is partly because of an increased transcription rate, mediated by binding of hypoxia-inducible factor-1 (HIF1) to a hypoxia responsive element in the 5'-flanking region of the VEGF gene. bHLH-PAS transcription factor that interacts with the Ah receptor nuclear translocator (Arnt), and its predicted amino acid sequence exhibits significant similarity to the hypoxia-inducible factor 1alpha (HIF1a) product. HLF mRNA expression is closely correlated with that of VEGF mRNA.. The high expression level of HLF mRNA in the O2 delivery system of developing embryos and adult organs suggests that in a normoxic state, HLF regulates gene expression of VEGF, various glycolytic enzymes, and others driven by the HRE sequence, and may be involved in development of blood vessels and the tubular system of lung. VEGF expression is dramatically induced by hypoxia due in large part to an increase in the stability of its mRNA. HuR binds with high affinity and specificity to the VRS element that regulates VEGF mRNA stability by hypoxia. In addition, an internal ribosome entry site (IRES) ensures efficient translation of VEGF mRNA even under hypoxia. The VHL tumor suppressor (von Hippel-Lindau) regulates also VEGF expression at a post-transcriptional level. The secreted VEGF is a major angiogenic factor that regulates multiple endothelial cell functions, including mitogenesis. Cellular and circulating levels of VEGF are elevated in hematologic malignancies and are adversely associated with prognosis. Angiogenesis is a very complex, tightly regulated, multistep process, the targeting of which may well prove useful in the creation of novel therapeutic agents. Current approaches being investigated include the inhibition of angiogenesis stimulants (e.g., VEGF), or their receptors, blockade of endothelial cell activation, inhibition of matrix metalloproteinases, and inhibition of tumor vasculature. Preclinical, phase I, and phase II studies of both monoclonal antibodies to VEGF and blockers of the VEGF receptor tyrosine kinase pathway indicate that these agents are safe and offer potential clinical utility in patients with hematologic malignancies.

Standard name | BIOCARTA_VITCB_PATHWAY
Systematic name | M15422
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Vitamin C in the Brain
Full description | Vitamin C (ascorbic acid) was first identified by virtue of the essential role it plays in collagen modification, preventing the nutritional deficiency scurvy. Vitamin C acts as a cofactor for hydroxylase enzymes that post-translationally modify collagen to increase the strength and elasticity of tissues. Vitamin C reduces the metal ion prosthetic groups of many enzymes, maintaining activity of enzymes, also acts as an anti-oxidant. Although the prevention of scurvy through modification of collagen may be the most obvious role for vitamin C, it is not necessarily the only role of vitamin C. Svct1 and Svct2 are ascorbate transporters for vitamin C import into tissues and into cells. Both of these transporters specifically transport reduced L-ascorbic acid against a concentration gradient using the intracellular sodium gradient to drive ascorbate transport. Svct1 is expressed in epithelial cells in the intestine, upregulated in cellular models for intestinal epithelium and appears to be responsible for the import of dietary vitamin C from the intestinal lumen. The vitamin C imported from the intestine is present in plasma at approximately 50 uM, almost exclusively in the reduced form, and is transported to tissues to play a variety of roles. Svct2 imports reduced ascorbate from the plasma into very active tissues like the brain. Deletion in mice of the gene for Svct2 revealed that ascorbate is required for normal development of the lungs and brain during pregnancy. A high concentration of vitamin C in neurons of the developing brain may help protect the developing brain from free radical damage. The oxidized form of ascorbate, dehydroascorbic acid, is transported into a variety of cells by the glucose transporter Glut-1. Glut-1, Glut-3 and Glut-4 can transport dehydroascorbate, but may not transport significant quantities of ascorbic acid in vivo.

Standard name | BIOCARTA_WNT_PATHWAY
Systematic name | M16517
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | WNT Signaling Pathway
Full description | Wnt family members are secreted glycoproteins who bind to cell surface receptors such as Frizzled. Wnt members can play a role in the expression of many genes by interacting with multiple disparate signaling pathways. Shown is the Wnt/beta-catenin pathway.

Standard name | BIOCARTA_ACTINY_PATHWAY
Systematic name | M7825
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Y branching of actin filaments
Full description | Mammalian cell motility requires actin polymerization in the direction of movement to change membrane shape and extend cytoplasm into lamellipodia. The polymerization of actin to drive cell movement also involves branching of actin filaments into a network oriented with the growing ends of the fibers near the cell membrane. Manipulation of this process helps bacteria like Salmonella gain entry into cells they infect. Two of the proteins involved in the formation of Y branches and in cell motility are Arp2 and Arp3, both members of a large multiprotein complex containing several other polypeptides as well. The Arp2/3 complex is localized at the Y branch junction and induces actin polymerization. Activity of this complex is regulated by multiple different cell surface receptor signaling systems, activating WASP, and Arp2/3 in turn to cause changes in cell shape and cell motility. Wasp and its cousin Wave-1 interact with the Arp2/3 complex through the p21 component of the complex. The crystal structure of the Arp2/3 complex has revealed further insights into the nature of how the complex works. Activation by Wave-1, another member of the WASP family, also induces actin alterations in response to Rac1 signals upstream. Wave-1 is held in an inactive complex in the cytosol that is activated to allow Wave-1 to associate with Arp2/3. While WASP is activated by interaction with Cdc42, Wave-1, is activated by interaction with Rac1 and Nck. Wave-1 activation by Rac1 and Nck releases Wave-1 with Hspc300 to activate actin Y branching and polymerization by Arp2/3. Different members of this gene family may produce different actin cytoskeletal architectures. The immunological defects associated with mutation of the WASP gene, the Wiskott-Aldrich syndrome for which WASP was named, indicates the importance of this system for normal cellular function.

Standard name | BIOCARTA_PDZS_PATHWAY
Systematic name | M22001
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Synaptic Proteins at the Synaptic Junction
Full description |

Standard name | BIOCARTA_RACC_PATHWAY
Systematic name | M22002
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Ion Channels and Their Functional Role in Vascular Endothelium
Full description |

Standard name | BIOCARTA_EICOSANOID_PATHWAY
Systematic name | M22003
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Eicosanoid Metabolism
Full description |

Standard name | BIOCARTA_CHREBP_PATHWAY
Systematic name | M22004
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | ChREBP regulation by carbohydrates and cAMP
Full description | Liver is the major site for carbohydrate metabolism (glycolysis and glycogen synthesis) and triglyceride synthesis (lipogenesis). While insulin was long thought to be the major regulator of hepatic gene expression, emerging evidence show that nutrients, in particular, glucose and fatty acids, are also able to regulate hepatic genes. This diagram illustrates how glucose metabolite, rather than glucose itself, contributes to the coordinated regulation of carbohydrate and lipid homeostasis in liver through phosphorylation-dependent regulation of ChREBP (carbohydrate responsive element binding protein). ChREBP is a basic helix-loop helix/leucine zipper (bHLH/LZ) transcription factor, shuttling between the cytoplasm and nucleus in a glucose-responsive manner in hepatocytes. When serum glucose is elevated, glucose transporter (GLUT2) and glucokinase (GCK) allow for rapid uptake and equilibration of intracellular glucose levels. This flux of glucose promotes, via the hexose monophosphate shunt pathway (HMP Shunt), the formation of xylulose-5-phosphate (Xu-5-P), which activates protein phosphatase 2A (PP2A) to dephosphorylate ChREBP (Ser196) and promote its nuclear localization. PP2A further dephosphorylates ChREBP in the nucleus, allowing it to dimerize with the bHLH/LZ transcription factor Max-like protein X (MLX) and activate transcription of a number of glycolytic and lipogenic genes containing a ChoRE, such as liver-type pyruvate kinase (L-PK), acetyl-CoA carboxylase 1 (ACACA), and fatty acid synthase (FASN). Upon starvation or high-fat feeding, intrahepatic levels of cAMP and AMP are elevated to activate protein kinase A (PKA) and AMP-dependent protein kinase (AMPK), respectively. PKA-mediated phosphorylation of Thr666 and Ser626 inhibits the DNA binding capacity of ChREBP; so does AMPK-mediated modification of Ser568. PKA-dependent phosphorylation of Ser196 promotes interaction with 14-3-3 and thus sequesters ChREBP in the cytosol. In summary, the phosphorylated form of ChREBP is rendered inactive due to its diminished DNA binding capacity and subcellular compartmentalization. Glucose metabolism triggers dephosphorylation of ChREBP, allowing it to enter the nucleus and activate the transcription of both glycolytic and lipogenic gene expression in liver. The fact that ChREBP/ mice are intolerant to glucose and insulin resistant suggests that ChREBP may also play a role in the pathogenesis of type 2 diabetes.

Standard name | BIOCARTA_LIS1_PATHWAY
Systematic name | M22005
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Lissencephaly gene (LIS1) in neuronal migration and development
Full description |

Standard name | BIOCARTA_HSWI_SNF_PATHWAY
Systematic name | M22006
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Chromatin Remodeling by hSWI/SNF ATP-dependent Complexes
Full description |

Standard name | BIOCARTA_PCAF_PATHWAY
Systematic name | M22007
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | The information-processing pathway at the IFN-beta enhancer
Full description |

Standard name | BIOCARTA_LYMPHOCYTE_PATHWAY
Systematic name | M22008
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Adhesion Molecules on Lymphocyte
Full description |

Standard name | BIOCARTA_AMAN_PATHWAY
Systematic name | M22009
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Steps in the Glycosylation of Mammalian N-linked Oligosaccarides
Full description |

Standard name | BIOCARTA_NEUTROPHIL_PATHWAY
Systematic name | M22010
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Neutrophil and Its Surface Molecules
Full description |

Standard name | BIOCARTA_EFP_PATHWAY
Systematic name | M22011
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Estrogen-responsive protein Efp controls cell cycle and breast tumors growth
Full description |

Standard name | BIOCARTA_CREM_PATHWAY
Systematic name | M22012
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of Spermatogenesis by CREM
Full description |

Standard name | BIOCARTA_ERAD_PATHWAY
Systematic name | M22013
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | ERbassociated degradation (ERAD) Pathway
Full description |

Standard name | BIOCARTA_BTG2_PATHWAY
Systematic name | M22014
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | BTG family proteins and cell cycle regulation
Full description |

Standard name | BIOCARTA_TERT_PATHWAY
Systematic name | M22015
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Overview of telomerase protein component gene hTert Transcriptional Regulation
Full description |

Standard name | BIOCARTA_GHRELIN_PATHWAY
Systematic name | M22016
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Ghrelin: Regulation of Food Intake and Energy Homeostasis
Full description |

Standard name | BIOCARTA_VOBESITY_PATHWAY
Systematic name | M22017
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Visceral Fat Deposits and the Metabolic Syndrome
Full description |

Standard name | BIOCARTA_ERBB3_PATHWAY
Systematic name | M22018
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Neuroregulin receptor degredation protein-1 Controls ErbB3 receptor recycling
Full description |

Standard name | BIOCARTA_CTBP1_PATHWAY
Systematic name | M22019
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | SUMOylation as a mechanism to modulate CtBP-dependent gene responses
Full description |

Standard name | BIOCARTA_PRION_PATHWAY
Systematic name | M22020
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Prion Pathway
Full description |

Standard name | BIOCARTA_PLK3_PATHWAY
Systematic name | M22021
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of cell cycle progression by Plk3
Full description |

Standard name | BIOCARTA_FXR_PATHWAY
Systematic name | M22022
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | FXR and LXR Regulation of Cholesterol Metabolism
Full description |

Standard name | BIOCARTA_MHC_PATHWAY
Systematic name | M22023
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Antigen Processing and Presentation
Full description |

Standard name | BIOCARTA_ACETAMINOPHEN_PATHWAY
Systematic name | M22024
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Mechanism of Acetaminophen Activity and Toxicity
Full description |

Standard name | BIOCARTA_PRC2_PATHWAY
Systematic name | M22025
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | The PRC2 Complex Sets Long-term Gene Silencing Through Modification of Histone Tails
Full description |

Standard name | BIOCARTA_SM_PATHWAY
Systematic name | M22026
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Spliceosomal Assembly
Full description |

Standard name | BIOCARTA_RANBP2_PATHWAY
Systematic name | M22027
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Sumoylation by RanBP2 Regulates Transcriptional Repression
Full description |

Standard name | BIOCARTA_IRES_PATHWAY
Systematic name | M22028
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Internal Ribosome entry pathway
Full description |

Standard name | BIOCARTA_PLC_PATHWAY
Systematic name | M22029
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Phospholipase C Signaling Pathway
Full description |

Standard name | BIOCARTA_BBCELL_PATHWAY
Systematic name | M22030
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Bystander B Cell Activation
Full description |

Standard name | BIOCARTA_CDC25_PATHWAY
Systematic name | M22031
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | cdc25 and chk1 Regulatory Pathway in response to DNA damage
Full description |

Standard name | BIOCARTA_DSP_PATHWAY
Systematic name | M22032
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of MAP Kinase Pathways Through Dual Specificity Phosphatases
Full description |

Standard name | BIOCARTA_NPC_PATHWAY
Systematic name | M22033
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Mechanism of Protein Import into the Nucleus
Full description |

Standard name | BIOCARTA_FLUMAZENIL_PATHWAY
Systematic name | M22034
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cardiac Protection Against ROS
Full description |

Standard name | BIOCARTA_MELANOCYTE_PATHWAY
Systematic name | M22035
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Melanocyte Development and Pigmentation Pathway
Full description |

Standard name | BIOCARTA_S1P_PATHWAY
Systematic name | M22036
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | SREBP control of lipid synthesis
Full description |

Standard name | BIOCARTA_HBX_PATHWAY
Systematic name | M22037
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Calcium Signaling by HBx of Hepatitis B virus
Full description |

Standard name | BIOCARTA_MALATEX_PATHWAY
Systematic name | M22038
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Shuttle for transfer of acetyl groups from mitochondria to the cytosol
Full description |

Standard name | BIOCARTA_TSP1_PATHWAY
Systematic name | M22039
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | TSP-1 Induced Apoptosis in Microvascular Endothelial Cell
Full description |

Standard name | BIOCARTA_NPP1_PATHWAY
Systematic name | M22040
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulators of Bone Mineralization
Full description |

Standard name | BIOCARTA_CPSF_PATHWAY
Systematic name | M22041
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Polyadenylation of mRNA
Full description |

Standard name | BIOCARTA_HES_PATHWAY
Systematic name | M22042
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Segmentation Clock
Full description |

Standard name | BIOCARTA_ERBB4_PATHWAY
Systematic name | M22043
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | g-Secretase mediated ErbB4 Signaling Pathway
Full description |

Standard name | BIOCARTA_RHODOPSIN_PATHWAY
Systematic name | M22044
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Visual Signal Transduction
Full description |

Standard name | BIOCARTA_RNAPOL3_PATHWAY
Systematic name | M22046
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | RNA polymerase III transcription
Full description |

Standard name | BIOCARTA_TERC_PATHWAY
Systematic name | M22047
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Overview of telomerase RNA component gene hTerc Transcriptional Regulation
Full description |

Standard name | BIOCARTA_EOSINOPHILS_PATHWAY
Systematic name | M22048
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | The Role of Eosinophils in the Chemokine Network of Allergy
Full description |

Standard name | BIOCARTA_REELIN_PATHWAY
Systematic name | M22049
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Reelin Signaling Pathway
Full description |

Standard name | BIOCARTA_BARD1_PATHWAY
Systematic name | M22050
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | BRCA1-dependent Ub-ligase activity
Full description |

Standard name | BIOCARTA_LDL_PATHWAY
Systematic name | M22051
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Low-density lipoprotein (LDL) pathway during atherogenesis
Full description |

Standard name | BIOCARTA_SAM68_PATHWAY
Systematic name | M22052
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Regulation of Splicing through Sam68
Full description |

Standard name | BIOCARTA_FBW7_PATHWAY
Systematic name | M22053
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cyclin E Destruction Pathway
Full description |

Standard name | BIOCARTA_CB1R_PATHWAY
Systematic name | M22054
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Metabolism of Anandamide, an Endogenous Cannabinoid
Full description |

Standard name | BIOCARTA_SUMO_PATHWAY
Systematic name | M22055
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Basic Mechanisms of SUMOylation
Full description |

Standard name | BIOCARTA_IFNA_PATHWAY
Systematic name | M22056
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IFN alpha signaling pathway
Full description |

Standard name | BIOCARTA_PKC_PATHWAY
Systematic name | M22057
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Activation of PKC through G protein coupled receptor
Full description |

Standard name | BIOCARTA_PPARG_PATHWAY
Systematic name | M22058
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Role of PPAR-gamma Coactivators in Obesity and Thermogenesis
Full description |

Standard name | BIOCARTA_ION_PATHWAY
Systematic name | M22059
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Ion Channel and Phorbal Esters Signaling Pathway
Full description |

Standard name | BIOCARTA_PELP1_PATHWAY
Systematic name | M22062
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Pelp1 Modulation of Estrogen Receptor Activity
Full description |

Standard name | BIOCARTA_STAT3_PATHWAY
Systematic name | M22063
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Stat3 Signaling Pathway
Full description |

Standard name | BIOCARTA_EEA1_PATHWAY
Systematic name | M22064
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | The role of FYVE-finger proteins in vesicle transport
Full description |

Standard name | BIOCARTA_MITR_PATHWAY
Systematic name | M22065
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Signal Dependent Regulation of Myogenesis by Corepressor MITR
Full description |

Standard name | BIOCARTA_CIRCADIAN_PATHWAY
Systematic name | M22067
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Circadian Rhythms
Full description |

Standard name | BIOCARTA_RECK_PATHWAY
Systematic name | M22068
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Inhibition of Matrix Metalloproteinases
Full description |

Standard name | BIOCARTA_MSP_PATHWAY
Systematic name | M22069
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Msp/Ron Receptor Signaling Pathway
Full description |

Standard name | BIOCARTA_SLRP_PATHWAY
Systematic name | M22071
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Small Leucine-rich Proteoglycan (SLRP) molecules
Full description |

Standard name | BIOCARTA_ALTERNATIVE_PATHWAY
Systematic name | M22072
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Alternative Complement Pathway
Full description |

Standard name | BIOCARTA_FOSB_PATHWAY
Systematic name | M22073
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | FOSB gene expression and drug abuse
Full description |

Standard name | BIOCARTA_NOTCH_PATHWAY
Systematic name | M22074
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Proteolysis and Signaling Pathway of Notch
Full description |

Standard name | BIOCARTA_TUBBY_PATHWAY
Systematic name | M22076
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | G-Protein Signaling Through Tubby Proteins
Full description |

Standard name | BIOCARTA_MRP_PATHWAY
Systematic name | M22078
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Multi-Drug Resistance Factors
Full description |

Standard name | BIOCARTA_DICER_PATHWAY
Systematic name | M22079
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Dicer Pathway
Full description |

Standard name | BIOCARTA_PLCD_PATHWAY
Systematic name | M22080
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Phospholipase C d1 in phospholipid associated cell signaling
Full description |

Standard name | BIOCARTA_RAN_PATHWAY
Systematic name | M22082
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Cycling of Ran in nucleocytoplasmic transport
Full description |

Standard name | BIOCARTA_WNT_LRP6_PATHWAY
Systematic name | M22083
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Wnt/LRP6 Signalling
Full description |

Standard name | BIOCARTA_PEPI_PATHWAY
Systematic name | M22084
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Proepithelin Conversion to Epithelin and Wound Repair Control
Full description |

Standard name | BIOCARTA_IFNG_PATHWAY
Systematic name | M22085
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | IFN gamma signaling pathway
Full description |

Standard name | BIOCARTA_BOTULIN_PATHWAY
Systematic name | M22086
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:BIOCARTA
Brief description | Blockade of Neurotransmitter Relase by Botulinum Toxin
Full description |

Standard name | KEGG_GLYCOLYSIS_GLUCONEOGENESIS
Systematic name | M11521
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycolysis / Gluconeogenesis
Full description | Glycolysis is the process of converting glucose into pyruvate and generating small amounts of ATP (energy) and NADH (reducing power). It is a central pathway that produces important precursor metabolites: six-carbon compounds of glucose-6P and fructose-6P and three-carbon compounds of glycerone-P, glyceraldehyde-3P, glycerate-3P, phosphoenolpyruvate, and pyruvate. Acetyl-CoA, another important precursor metabolite, is produced by oxidative decarboxylation of pyruvate. When the enzyme genes of this pathway are examined in completely sequenced genomes, the reaction steps of three-carbon compounds from glycerone-P to pyruvate form a conserved core module , which is found in almost all organisms and which often corresponds to operon structures in bacterial genomes. Gluconeogenesis is a synthesis pathway of glucose from noncarbohydrate precursors. It is essentially a reversal of glycolysis with minor variations of alternative paths.

Standard name | KEGG_CITRATE_CYCLE_TCA_CYCLE
Systematic name | M3985
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Citrate cycle (TCA cycle)
Full description | The citrate cycle (TCA cycle, Krebs cycle) is an important aerobic pathway for the final steps of the oxidation of carbohydrates and fatty acids. The cycle starts with acetyl-CoA, the activated form of acetate, derived from glycolysis and pyruvate oxidation for carbohydrates and from beta oxidation of fatty acids. The two-carbon acetyl group in acetyl-CoA is transferred to the four-carbon compound of oxaloacetate to form the six-carbon compound of citrate. In a series of reactions two carbons in citrate are oxidized to CO2 and the reaction pathway supplies NADH for use in the oxidative phosphorylation and other metabolic processes. The pathway also supplies important precursor metabolites including 2-oxoglutarate. At the end of the cycle the remaining four-carbon part is transformed back to oxaloacetate. According to the genome sequence data, many organisms seem to lack genes for the full cycle , but contain genes for specific segments.

Standard name | KEGG_PENTOSE_PHOSPHATE_PATHWAY
Systematic name | M1386
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Pentose phosphate pathway
Full description | The pentose phosphate pathway is a process of glucose turnover that produces NADPH as reducing equivalents and pentoses as essential parts of nucleotides. There are two different phases in the pathway. One is irreversible oxidative phase in which glucose-6P is converted to ribulose-5P by oxidative decarboxylation, and NADPH is generated. The other is reversible non-oxidative phase in which phosphorylated sugars are interconverted to generate xylulose-5P, ribulose-5P, and ribose-5P. Phosphoribosyl pyrophosphate (PRPP) formed from ribose-5P is an activated compound used in the biosynthesis of histidine and purine/pyrimidine nucleotides. This pathway map also shows the Entner-Doudoroff pathway where 6-P-gluconate is dehydrated and then cleaved into pyruvate and glyceraldehyde-3P.

Standard name | KEGG_PENTOSE_AND_GLUCURONATE_INTERCONVERSIONS
Systematic name | M19580
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Pentose and glucuronate interconversions
Full description |

Standard name | KEGG_FRUCTOSE_AND_MANNOSE_METABOLISM
Systematic name | M15898
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Fructose and mannose metabolism
Full description |

Standard name | KEGG_GALACTOSE_METABOLISM
Systematic name | M4377
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Galactose metabolism
Full description |

Standard name | KEGG_ASCORBATE_AND_ALDARATE_METABOLISM
Systematic name | M605
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Ascorbate and aldarate metabolism
Full description |

Standard name | KEGG_FATTY_ACID_METABOLISM
Systematic name | M699
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Fatty acid metabolism
Full description |

Standard name | KEGG_STEROID_BIOSYNTHESIS
Systematic name | M5872
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Steroid biosynthesis
Full description |

Standard name | KEGG_PRIMARY_BILE_ACID_BIOSYNTHESIS
Systematic name | M3214
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Primary bile acid biosynthesis
Full description | Bile acids are steroid carboxylic acids derived from cholesterol in vertebrates. The primary bile acids, cholic acid and chenodeoxycholic acid, are synthesized in the liver and conjugated with taurine or glycine before secretion via bile into the intestine. The conversion from cholesterol to cholic and chenodeoxycholic acids involves four steps: 1) the initiation of synthesis by 7alpha-hydroxylation of sterol precursors, 2) further modifications to the ring structures, 3) side-chain oxidation and shortening (cleavage) by three carbons, and 4) conjugation of the bile acid with taurine or glycine.

Standard name | KEGG_STEROID_HORMONE_BIOSYNTHESIS
Systematic name | M14933
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Steroid hormone biosynthesis
Full description | Steroid hormones derived from cholesterol are a class of biologically active compounds in vertebrates. The cholesterol side-chain cleavage enzyme CYP11A1 catalyzes conversion of cholesterol, a C27 compound, to the first C21 steroid, pregnenolone, which is converted by a bifunctional enzyme complex to the gestagen hormone, progesterone. Pregnenolone and progesterone are the starting materials for the three groups of steroids: C21 steroids of glucocorticoids and mineralocorticoids, C19 steroids of androgens, and C18 steroids of estrogens. (i) Progesterone is converted by hydroxylations at carbons 21 and 11 to corticosterone, which is further modified by hydroxylation and oxydoreduction at carbon 18 to yield aldosterone, a mineralcorticoid. Cortisol, the main glucocorticoid, is formed from 17alpha-hydroxyprogesterone with 11-deoxycortisol as an intermediate. (ii) Male hormone testosterone is formed from pregnenolone by two pathways, delta5 pathway via dehydroepiandrosterone and delta4 pathway via androstenedione. The enzyme CYP17A1 is responsible for the 17,20 lyase and 17alpha-hydroxylase activities in respective pathways. (iii) Female hormones estrone and estradiol are formed from testosterone and 4-androstene-3,17-dione by oxidative removal of the C19 methyl group and subsequent aromatization of ring A. In addition to these three groups, recent studies show that there is another group, termed neurosteroids, synthesized in the brain rather than the peripheral endocrine gland.

Standard name | KEGG_OXIDATIVE_PHOSPHORYLATION
Systematic name | M19540
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Oxidative phosphorylation
Full description |

Standard name | KEGG_PURINE_METABOLISM
Systematic name | M14314
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Purine metabolism
Full description |

Standard name | KEGG_PYRIMIDINE_METABOLISM
Systematic name | M5109
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Pyrimidine metabolism
Full description |

Standard name | KEGG_ALANINE_ASPARTATE_AND_GLUTAMATE_METABOLISM
Systematic name | M17758
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Alanine, aspartate and glutamate metabolism
Full description |

Standard name | KEGG_GLYCINE_SERINE_AND_THREONINE_METABOLISM
Systematic name | M766
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycine, serine and threonine metabolism
Full description | Serine is derived from 3-phospho-D-glycerate, an intermediate of glycolysis , and glycine is derived from serine. Threonine is an essential amino acid, which animals cannot synthesize. In bacteria and plants, threonine is derived from aspartate.

Standard name | KEGG_CYSTEINE_AND_METHIONINE_METABOLISM
Systematic name | M10911
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Cysteine and methionine metabolism
Full description | Cysteine and methionine are sulfur-containing amino acids. Cysteine is synthesized from serine through different pathways in different organism groups. In bacteria and plants, cysteine is converted from serine (via acetylserine) by transfer of hydrogen sulfide. In animals, methionine-derived homocysteine is used as sulfur source and its condensation product with serine (cystathionine) is converted to cysteine. Cysteine is metabolized to pyruvate in multiple routes. Methionine is an essential amino acid, which animals cannot synthesize. In bacteria and plants, methionine is synthesized from aspartate. S-Adenosylmethionine (SAM), synthesized from methionine and ATP, is a methyl group donor in many important transfer reactions including DNA methylation for regulation of gene expression. SAM may also be used to regenerate methionine in the methionine salvage pathway.

Standard name | KEGG_VALINE_LEUCINE_AND_ISOLEUCINE_DEGRADATION
Systematic name | M11835
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Valine, leucine and isoleucine degradation
Full description |

Standard name | KEGG_VALINE_LEUCINE_AND_ISOLEUCINE_BIOSYNTHESIS
Systematic name | M17946
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Valine, leucine and isoleucine biosynthesis
Full description |

Standard name | KEGG_LYSINE_DEGRADATION
Systematic name | M13720
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Lysine degradation
Full description |

Standard name | KEGG_ARGININE_AND_PROLINE_METABOLISM
Systematic name | M2551
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Arginine and proline metabolism
Full description |

Standard name | KEGG_HISTIDINE_METABOLISM
Systematic name | M12524
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Histidine metabolism
Full description |

Standard name | KEGG_TYROSINE_METABOLISM
Systematic name | M16743
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Tyrosine metabolism
Full description |

Standard name | KEGG_PHENYLALANINE_METABOLISM
Systematic name | M16650
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Phenylalanine metabolism
Full description |

Standard name | KEGG_TRYPTOPHAN_METABOLISM
Systematic name | M980
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Tryptophan metabolism
Full description |

Standard name | KEGG_BETA_ALANINE_METABOLISM
Systematic name | M2668
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | beta-Alanine metabolism
Full description |

Standard name | KEGG_TAURINE_AND_HYPOTAURINE_METABOLISM
Systematic name | M12882
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Taurine and hypotaurine metabolism
Full description |

Standard name | KEGG_SELENOAMINO_ACID_METABOLISM
Systematic name | M7151
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Selenoamino acid metabolism
Full description |

Standard name | KEGG_GLUTATHIONE_METABOLISM
Systematic name | M1840
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glutathione metabolism
Full description |

Standard name | KEGG_STARCH_AND_SUCROSE_METABOLISM
Systematic name | M14171
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Starch and sucrose metabolism
Full description |

Standard name | KEGG_N_GLYCAN_BIOSYNTHESIS
Systematic name | M11079
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | N-Glycan biosynthesis
Full description | N-glycans or asparagine-linked glycans are major constituents of glycoproteins in eukaryotes. N-glycans are covalently attached to asparagine with the consensus sequence of Asn-X-Ser/Thr by an N-glycosidic bond, GlcNAc b1- Asn. Biosynthesis of N-glycans begins on the cytoplasmic face of the ER membrane with the transferase reaction of UDP-GlcNAc and the lipid-like precursor P-Dol (dolichol phosphate) to generate GlcNAc a1- PP-Dol. After sequential addition of monosaccharides by ALG glycosyltransferases, the N-glycan precursor is attached by the OST (oligosaccharyltransferase) complex to the polypeptide chain that is being synthesized and translocated through the ER membrane. The protein-bound N-glycan precursor is subsequently trimmed, extended, and modified in the ER and Golgi by a complex series of reactions catalyzed by membrane-bound glycosidases and glycosyltransferases. N-glycans thus synthesized are classified into three types: high-mannose type, complex type, and hybrid type. Defects in N-glycan biosynthesis lead to a variety of human diseases known as congenital disorders of glycosylation.

Standard name | KEGG_OTHER_GLYCAN_DEGRADATION
Systematic name | M17844
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Other glycan degradation
Full description |

Standard name | KEGG_O_GLYCAN_BIOSYNTHESIS
Systematic name | M6929
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | O-Glycan biosynthesis
Full description | O-glycans are a class of glycans that modify serine or threonine residues of proteins. Biosynthesis of O-glycans starts from the transfer of N-acetylgalactosamine (GalNAc) to serine or threonine. The first GalNAc may be extended with sugars including galactose, N-acetylglucosamine, fucose, or sialic acid, but not mannose, glucose, or xylose. Depending on the sugars added, there are four common O-glycan core structures, cores 1 through 4, and an additional four, cores 5 though 8. Mucins are highly O-glycosylated glycoproteins ubiquitous in mucous secretions on cell surfaces and in body fluids. Mucin O-glycans can be branched, and many sugars or groups of sugars are antigenic. Important modifications of mucin O-glycans include O-acetylation of sialic acid and O-sulfation of galactose and N-acetylglucosamine.

Standard name | KEGG_AMINO_SUGAR_AND_NUCLEOTIDE_SUGAR_METABOLISM
Systematic name | M8104
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Amino sugar and nucleotide sugar metabolism
Full description |

Standard name | KEGG_GLYCOSAMINOGLYCAN_DEGRADATION
Systematic name | M3624
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycosaminoglycan degradation
Full description |

Standard name | KEGG_GLYCOSAMINOGLYCAN_BIOSYNTHESIS_CHONDROITIN_SULFATE
Systematic name | M19166
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycosaminoglycan biosynthesis - chondroitin sulfate
Full description | Glycosaminoglycans (GAGs) are linear polysaccharide chains consisting of repeating disaccharide units and form proteglycans by covalently attaching to their core proteins. Chondroitin sulfate (CS) is a glycosaminoglycan with the disaccharide unit GalNAc(b1-4)GlcA(b1-3), modified with ester-linked sulfate at certain positions. Dermatan sulfate (DS) is a modified form of CS, in which a portion of D-glucuronate residues is epimerized to L-iduronates. CS and DS are linked to serine residues in core proteins via a linkage tetrasaccharide formed by the transfer of xylose and three more residues. The assembly process of CS is initiated by the transfer of N-acetylgalactosamine to the linkage tetrasaccharide. The polymerization step is catalyzed by bifunctional enzymes (chondroitin synthases) that have both b13 glucuronosyltransferase and b14 N-acetylgalactosaminyltransferase activities. Chondroitin polymerization also requires the action of the chondroitin polymerizing factor. Sulfation of chondroitin in vertebrates is a complex process, with multiple sulfotransferases involved in 4-O sulfation and 6-O sulfation of N-acetylgalactosamine residues. Additional enzymes exist for epimerization of glucuronic acid to iduronic acid in DS, sulfation at the C-2 position of the uronic acids, and other patterns of sulfation found in unusual species of chondroitin.

Standard name | KEGG_GLYCOSAMINOGLYCAN_BIOSYNTHESIS_KERATAN_SULFATE
Systematic name | M3042
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycosaminoglycan biosynthesis - keratan sulfate
Full description |

Standard name | KEGG_GLYCOSAMINOGLYCAN_BIOSYNTHESIS_HEPARAN_SULFATE
Systematic name | M7330
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycosaminoglycan biosynthesis - heparan sulfate
Full description |

Standard name | KEGG_GLYCEROLIPID_METABOLISM
Systematic name | M15902
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycerolipid metabolism
Full description |

Standard name | KEGG_INOSITOL_PHOSPHATE_METABOLISM
Systematic name | M3896
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Inositol phosphate metabolism
Full description |

Standard name | KEGG_GLYCOSYLPHOSPHATIDYLINOSITOL_GPI_ANCHOR_BIOSYNTHESIS
Systematic name | M13265
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycosylphosphatidylinositol(GPI)-anchor biosynthesis
Full description | Cell surface proteins can be attached to the cell membrane via the glycolipid structure called glycosylphosphatidylinositol (GPI) anchor. Hundreds of GPI-anchored proteins have been identified in many eukaryotes ranging from protozoa and fungi to mammals. All protein-linked GPI anchors share a common core structure, characterized by the substructure Man (a14) GlcN (a1-6) myo-inositol-1P-lipid. Biosynthesis of GPI anchors proceeds in three stages: (i) preassembly of a GPI precursor in the ER membrane, (ii) attachment of the GPI to the C-terminus of a newly synthesized protein in the lumen of the ER, and (iii) lipid remodeling and/or carbohydrate side-chain modifications in the ER and the Golgi. Defects of GPI anchor biosynthesis gene result in a genetic disorder, paroxysmal nocturnal hemoglobinuria.

Standard name | KEGG_GLYCEROPHOSPHOLIPID_METABOLISM
Systematic name | M9131
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycerophospholipid metabolism
Full description |

Standard name | KEGG_ETHER_LIPID_METABOLISM
Systematic name | M2130
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Ether lipid metabolism
Full description |

Standard name | KEGG_ARACHIDONIC_ACID_METABOLISM
Systematic name | M5410
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Arachidonic acid metabolism
Full description |

Standard name | KEGG_LINOLEIC_ACID_METABOLISM
Systematic name | M2920
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Linoleic acid metabolism
Full description |

Standard name | KEGG_ALPHA_LINOLENIC_ACID_METABOLISM
Systematic name | M311
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | alpha-Linolenic acid metabolism
Full description |

Standard name | KEGG_SPHINGOLIPID_METABOLISM
Systematic name | M15955
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Sphingolipid metabolism
Full description |

Standard name | KEGG_GLYCOSPHINGOLIPID_BIOSYNTHESIS_LACTO_AND_NEOLACTO_SERIES
Systematic name | M17377
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycosphingolipid biosynthesis - lacto and neolacto series
Full description |

Standard name | KEGG_GLYCOSPHINGOLIPID_BIOSYNTHESIS_GLOBO_SERIES
Systematic name | M12899
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycosphingolipid biosynthesis - globo series
Full description |

Standard name | KEGG_GLYCOSPHINGOLIPID_BIOSYNTHESIS_GANGLIO_SERIES
Systematic name | M8535
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glycosphingolipid biosynthesis - ganglio series
Full description |

Standard name | KEGG_PYRUVATE_METABOLISM
Systematic name | M7934
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Pyruvate metabolism
Full description |

Standard name | KEGG_GLYOXYLATE_AND_DICARBOXYLATE_METABOLISM
Systematic name | M5244
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glyoxylate and dicarboxylate metabolism
Full description |

Standard name | KEGG_PROPANOATE_METABOLISM
Systematic name | M4086
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Propanoate metabolism
Full description |

Standard name | KEGG_BUTANOATE_METABOLISM
Systematic name | M3397
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Butanoate metabolism
Full description |

Standard name | KEGG_ONE_CARBON_POOL_BY_FOLATE
Systematic name | M12039
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | One carbon pool by folate
Full description |

Standard name | KEGG_RIBOFLAVIN_METABOLISM
Systematic name | M6889
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Riboflavin metabolism
Full description |

Standard name | KEGG_NICOTINATE_AND_NICOTINAMIDE_METABOLISM
Systematic name | M19895
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Nicotinate and nicotinamide metabolism
Full description |

Standard name | KEGG_PANTOTHENATE_AND_COA_BIOSYNTHESIS
Systematic name | M7528
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Pantothenate and CoA biosynthesis
Full description |

Standard name | KEGG_FOLATE_BIOSYNTHESIS
Systematic name | M2220
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Folate biosynthesis
Full description |

Standard name | KEGG_RETINOL_METABOLISM
Systematic name | M9488
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Retinol metabolism
Full description |

Standard name | KEGG_PORPHYRIN_AND_CHLOROPHYLL_METABOLISM
Systematic name | M7399
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Porphyrin and chlorophyll metabolism
Full description |

Standard name | KEGG_TERPENOID_BACKBONE_BIOSYNTHESIS
Systematic name | M13465
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Terpenoid backbone biosynthesis
Full description |

Standard name | KEGG_LIMONENE_AND_PINENE_DEGRADATION
Systematic name | M17395
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Limonene and pinene degradation
Full description |

Standard name | KEGG_NITROGEN_METABOLISM
Systematic name | M4629
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Nitrogen metabolism
Full description |

Standard name | KEGG_SULFUR_METABOLISM
Systematic name | M18256
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Sulfur metabolism
Full description |

Standard name | KEGG_AMINOACYL_TRNA_BIOSYNTHESIS
Systematic name | M14691
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Aminoacyl-tRNA biosynthesis
Full description |

Standard name | KEGG_METABOLISM_OF_XENOBIOTICS_BY_CYTOCHROME_P450
Systematic name | M16794
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Metabolism of xenobiotics by cytochrome P450
Full description |

Standard name | KEGG_DRUG_METABOLISM_CYTOCHROME_P450
Systematic name | M9257
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Drug metabolism - cytochrome P450
Full description |

Standard name | KEGG_DRUG_METABOLISM_OTHER_ENZYMES
Systematic name | M17726
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Drug metabolism - other enzymes
Full description |

Standard name | KEGG_BIOSYNTHESIS_OF_UNSATURATED_FATTY_ACIDS
Systematic name | M11673
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Biosynthesis of unsaturated fatty acids
Full description |

Standard name | KEGG_ABC_TRANSPORTERS
Systematic name | M11911
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | ABC transporters
Full description | The ATP-binding cassette (ABC) transporters form one of the largest known protein families, and are widespread in bacteria, archaea, and eukaryotes. They couple ATP hydrolysis to active transport of a wide variety of substrates such as ions, sugars, lipids, sterols, peptides, proteins, and drugs. The structure of a prokaryotic ABC transporter usually consists of three components; typically two integral membrane proteins each having six transmembrane segments, two peripheral proteins that bind and hydrolyze ATP, and a periplasmic (or lipoprotein) substrate-binding protein. Many of the genes for the three components form operons as in fact observed in many bacterial and archaeal genomes. On the other hand, in a typical eukaryotic ABC transporter, the membrane spanning protein and the ATP-binding protein are fused, forming a multi-domain protein with the membrane-spanning domain (MSD) and the nucleotide-binding domain (NBD).

Standard name | KEGG_RIBOSOME
Systematic name | M189
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Ribosome
Full description |

Standard name | KEGG_RNA_DEGRADATION
Systematic name | M963
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | RNA degradation
Full description | The correct processing, quality control and turnover of cellular RNA molecules are critical to many aspects in the expression of genetic information. In eukaryotes, two major pathways of mRNA decay exist and both pathways are initiated by poly(A) shortening of the mRNA. In the 5' to 3' pathway, this is followed by decapping which then permits the 5' to 3' exonucleolytic degradation of transcripts. In the 3' to 5' pathway, the exosome, a large multisubunit complex, plays a key role. The exosome exists in archaeal cells, too. In bacteria, endoribonuclease E, a key enzyme involved in RNA decay and processing, organizes a protein complex called degradosome. RNase E or R interacts with the phosphate-dependent exoribonuclease polynucleotide phosphorylase, DEAD-box helicases, and additional factors in the RNA-degrading complex.

Standard name | KEGG_RNA_POLYMERASE
Systematic name | M1724
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | RNA polymerase
Full description |

Standard name | KEGG_BASAL_TRANSCRIPTION_FACTORS
Systematic name | M4864
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Basal transcription factors
Full description |

Standard name | KEGG_DNA_REPLICATION
Systematic name | M16853
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | DNA replication
Full description | A complex network of interacting proteins and enzymes is required for DNA replication. Generally, DNA replication follows a multistep enzymatic pathway. At the DNA replication fork, a DNA helicase (DnaB or MCM complex) precedes the DNA synthetic machinery and unwinds the duplex parental DNA in cooperation with the SSB or RPA. On the leading strand, replication occurs continuously in a 5 to 3 direction, whereas on the lagging strand, DNA replication occurs discontinuously by synthesis and joining of short Okazaki fragments. In prokaryotes, the leading strand replication apparatus consists of a DNA polymerase (pol III core), a sliding clamp (beta), and a clamp loader (gamma delta complex). The DNA primase (DnaG) is needed to form RNA primers. Normally, during replication of the lagging-strand DNA template, an RNA primer is removed either by an RNase H or by the 5 to 3 exonuclease activity of DNA pol I, and the DNA ligase joins the Okazaki fragments. In eukaryotes, three DNA polymerases (alpha, delta, and epsilon) have been identified. DNA primase forms a permanent complex with DNA polymerase alpha. PCNA and RFC function as a clamp and a clamp loader. FEN 1 and RNase H1 remove the RNA from the Okazaki fragments and DNA ligase I joins the DNA.

Standard name | KEGG_SPLICEOSOME
Systematic name | M2044
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Spliceosome
Full description | After transcription, eukaryotic mRNA precursors contain protein-coding exons and noncoding introns. In the following splicing, introns are excised and exons are joined by a macromolecular complex, the spliceosome. The standard spliceosome is made up of five small nuclear ribonucleoproteins (snRNPs), U1, U2, U4, U5, and U6 snRNPs, and several spliceosome-associated proteins (SAPs). Spliceosomes are not a simple stable complex, but a dynamic family of particles that assemble on the mRNA precursor and help fold it into a conformation that allows transesterification to proceed. Various spliceosome forms (e.g. A-, B- and C-complexes) have been identified.

Standard name | KEGG_PROTEASOME
Systematic name | M10680
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Proteasome
Full description | The proteasome is a protein-destroying apparatus involved in many essential cellular functions, such as regulation of cell cycle, cell differentiation, signal transduction pathways, antigen processing for appropriate immune responses, stress signaling, inflammatory responses, and apoptosis. It is capable of degrading a variety of cellular proteins in a rapid and timely fashion and most substrate proteins are modified by ubiquitin before their degradation by the proteasome. The proteasome is a large protein complex consisting of a proteolytic core called the 20S particle and ancillary factors that regulate its activity in various ways. The most common form is the 26S proteasome containing one 20S core particle and two 19S regulatory particles that enable the proteasome to degrade ubiquitinated proteins by an ATP-dependent mechanism. Another form is the immunoproteasome containing two 11S regulatory particles, PA28 alpha and PA28 beta, which are induced by interferon gamma under the conditions of intensified immune response. Other regulatory particles include PA28 gamma and PA200. Although PA28 gamma also belongs to a family of activators of the 20S proteasome, it is localized within the nucleus and forms a homoheptamer. PA28 gamma has been implicated in the regulation of cell cycle progression and apoptosis. PA200 has been identified as a large nuclear protein that stimulates proteasomal hydrolysis of peptides.

Standard name | KEGG_PROTEIN_EXPORT
Systematic name | M6981
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Protein export
Full description | The protein export is the active transport of proteins from the cytoplasm to the exterior of the cell, or to the periplasmic compartment in Gram-negative bacteria. The sec dependent pathway is the general protein export system that transports newly synthesized proteins into or across the cell membrane. The translocation channel is formed from a conserved trimeric membrane protein complex, called the Sec61/SecY complex. The twin-arginine translocation (Tat) pathway is another protein transport system that transports folded proteins in bacteria, archaea, and chloroplasts. Many Tat systems comprise three functionally different membrane proteins, TatA, TatB, and TatC, but TatA and TatE seem to have overlapping functions, with TatA having by far the more important role.

Standard name | KEGG_PPAR_SIGNALING_PATHWAY
Systematic name | M13088
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | PPAR signaling pathway
Full description | Peroxisome proliferator-activated receptors (PPARs) are nuclear hormone receptors that are activated by fatty acids and their derivatives. PPAR has three subtypes (PPARalpha, beta/delta, and gamma) showing different expression patterns in vertebrates. Each of them is encoded in a separate gene and binds fatty acids and eicosanoids. PPARalpha plays a role in the clearance of circulating or cellular lipids via the regulation of gene expression involved in lipid metabolism in liver and skeletal muscle. PPARbeta/delta is involved in lipid oxidation and cell proliferation. PPARgamma promotes adipocyte differentiation to enhance blood glucose uptake.

Standard name | KEGG_BASE_EXCISION_REPAIR
Systematic name | M5500
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Base excision repair
Full description | Base excision repair (BER) is the predominant DNA damage repair pathway for the processing of small base lesions, derived from oxidation and alkylation damages. BER is normally defined as DNA repair initiated by lesion-specific DNA glycosylases and completed by either of the two sub-pathways: short-patch BER where only one nucleotide is replaced and long-patch BER where 2-13 nucleotides are replaced. Each sub-pathway of BER relies on the formation of protein complexes that assemble at the site of the DNA lesion and facilitate repair in a coordinated fashion. This process of complex formation appears to provide an increase in specificity and efficiency to the BER pathway, thereby facilitating the maintenance of genome integrity by preventing the accumulation of highly toxic repair intermediates.

Standard name | KEGG_NUCLEOTIDE_EXCISION_REPAIR
Systematic name | M18937
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Nucleotide excision repair
Full description | Nucleotide excision repair (NER) is a mechanism to recognize and repair bulky DNA damage caused by compounds, environmental carcinogens, and exposure to UV-light. In humans hereditary defects in the NER pathway are linked to at least three diseases: xeroderma pigmentosum (XP), Cockayne syndrome (CS), and trichothiodystrophy (TTD). The repair of damaged DNA involves at least 30 polypeptides within two different sub-pathways of NER known as transcription-coupled repair (TCR-NER) and global genome repair (GGR-NER). TCR refers to the expedited repair of lesions located in the actively transcribed strand of genes by RNA polymerase II (RNAP II). In GGR-NER the first step of damage recognition involves XPC-hHR23B complex together with XPE complex (in prokaryotes, uvrAB complex). The following steps of GGR-NER and TCR-NER are similar.

Standard name | KEGG_MISMATCH_REPAIR
Systematic name | M13515
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Mismatch repair
Full description | DNA mismatch repair (MMR) is a highly conserved biological pathway that plays a key role in maintaining genomic stability. MMR corrects DNA mismatches generated during DNA replication, thereby preventing mutations from becoming permanent in dividing cells. MMR also suppresses homologous recombination and was recently shown to play a role in DNA damage signaling. Defects in MMR are associated with genome-wide instability, predisposition to certain types of cancer including HNPCC, resistance to certain chemotherapeutic agents, and abnormalities in meiosis and sterility in mammalian systems. The Escherichia coli MMR pathway has been extensively studied and is well characterized. In E. coli, the mismatch-activated MutS-MutL-ATP complex licenses MutH to incise the nearest unmethylated GATC sequence. UvrD and an exonuclease generate a gap. This gap is filled by pol III and DNA ligase. The GATC sites are then methylated by Dam. Several human MMR proteins have been identified based on their homology to E. coli MMR proteins. These include human homologs of MutS and MutL. Although E. coli MutS and MutL proteins are homodimers, human MutS and MutL homologs are heterodimers. The role of hemimethylated dGATC sites as a signal for strand discrimination is not conserved from E. coli to human. Human MMR is presumed to be nick-directed in vivo, and is thought to discriminate daughter and template strands using a strand-specific nick.

Standard name | KEGG_HOMOLOGOUS_RECOMBINATION
Systematic name | M11675
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Homologous recombination
Full description | Homologous recombination (HR) is essential for the accurate repair of DNA double-strand breaks (DSBs), potentially lethal lesions. HR takes place in the late S-G2 phase of the cell cycle and involves the generation of a single-stranded region of DNA, followed by strand invasion, formation of a Holliday junction, DNA synthesis using the intact strand as a template, branch migration and resolution. It is investigated that RecA/Rad51 family proteins play a central role. The breast cancer susceptibility protein Brca2 and the RecQ helicase BLM (Bloom syndrome mutated) are tumor suppressors that maintain genome integrity, at least in part, through HR.

Standard name | KEGG_NON_HOMOLOGOUS_END_JOINING
Systematic name | M7857
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Non-homologous end-joining
Full description | Nonhomologous end joining (NHEJ) eliminates DNA double-strand breaks (DSBs) by direct ligation. NHEJ involves binding of the KU heterodimer to double-stranded DNA ends, recruitment of DNA-PKcs (MRX complex in yeast), processing of ends, and recruitment of the DNA ligase IV (LIG4)-XRCC4 complex, which brings about ligation. A recent study shows that bacteria accomplish NHEJ using just two proteins (Ku and DNA ligase), whereas eukaryotes require many factors. NHEJ repairs DSBs at all stages of the cell cycle, bringing about the ligation of two DNA DSBs without the need for sequence homology, and so is error-prone.

Standard name | KEGG_MAPK_SIGNALING_PATHWAY
Systematic name | M10792
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | MAPK signaling pathway
Full description | The mitogen-activated protein kinase (MAPK) cascade is a highly conserved module that is involved in various cellular functions, including cell proliferation, differentiation and migration. Mammals express at least four distinctly regulated groups of MAPKs, extracellular signal-related kinases (ERK)-1/2, Jun amino-terminal kinases (JNK1/2/3), p38 proteins (p38alpha/beta/gamma/delta) and ERK5, that are activated by specific MAPKKs: MEK1/2 for ERK1/2, MKK3/6 for the p38, MKK4/7 (JNKK1/2) for the JNKs, and MEK5 for ERK5. Each MAPKK, however, can be activated by more than one MAPKKK, increasing the complexity and diversity of MAPK signalling. Presumably each MAPKKK confers responsiveness to distinct stimuli. For example, activation of ERK1/2 by growth factors depends on the MAPKKK c-Raf, but other MAPKKKs may activate ERK1/2 in response to pro-inflammatory stimuli.

Standard name | KEGG_ERBB_SIGNALING_PATHWAY
Systematic name | M12467
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | ErbB signaling pathway
Full description | The ErbB family of receptor tyrosine kinases (RTKs) couples binding of extracellular growth factor ligands to intracellular signaling pathways regulating diverse biologic responses, including proliferation, differentiation, cell motility, and survival. Ligand binding to the four closely related members of this RTK family -epidermal growth factor receptor (EGFR, also known as ErbB-1 or HER1), ErbB-2 (HER2), ErbB-3 (HER3), and ErbB-4 (HER4)-induces the formation of receptor homo- and heterodimers and the activation of the intrinsic kinase domain, resulting in phosphorylation on specific tyrosine residues (pY) within the cytoplasmic tail. Signaling effectors containing binding pockets for pY-containing peptides are recruited to activated receptors and induce the various signaling pathways. The Shc- and/or Grb2-activated mitogen-activated protein kinase (MAPK) pathway is a common target downstream of all ErbB receptors. Similarly, the phosphatidylinositol-3-kinase (PI-3K) pathway is directly or indirectly activated by most ErbBs. Several cytoplasmic docking proteins appear to be recruited by specific ErbB receptors and less exploited by others. These include the adaptors Crk, Nck, the phospholipase C gamma (PLCgamma), the intracellular tyrosine kinase Src, or the Cbl E3 ubiquitin protein ligase.

Standard name | KEGG_CALCIUM_SIGNALING_PATHWAY
Systematic name | M2890
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Calcium signaling pathway
Full description | Ca2+ that enters the cell from the outside is a principal source of signal Ca2+. Entry of Ca2+ is driven by the presence of a large electrochemical gradient across the plasma membrane. Cells use this external source of signal Ca2+ by activating various entry channels with widely different properties. The voltage-operated channels (VOCs) are found in excitable cells and generate the rapid Ca2+ fluxes that control fast cellular processes. There are many other Ca2+-entry channels, such as the receptor-operated channels (ROCs), for example the NMDA (N-methyl-D-aspartate) receptors (NMDARs) that respond to glutamate. There also are second-messenger-operated channels (SMOCs) and store-operated channels (SOCs). The other principal source of Ca2+ for signalling is the internal stores that are located primarily in the endoplasmic/sarcoplasmic reticulum (ER/SR), in which inositol-1,4,5-trisphosphate receptors (IP3Rs) or ryanodine receptors (RYRs) regulate the release of Ca2+. The principal activator of these channels is Ca2+ itself and this process of Ca2+-induced Ca2+ release is central to the mechanism of Ca2+ signalling. Various second messengers or modulators also control the release of Ca2+. IP3, which is generated by pathways using different isoforms of phospholipase C (PLCbeta, delta, epsilon, gamma and zeta), regulates the IP3Rs. Cyclic ADP-ribose (cADPR) releases Ca2+ via RYRs. Nicotinic acid adenine dinucleotide phosphate (NAADP) may activate a distinct Ca2+ release mechanism on separate acidic Ca2+ stores. Ca2+ release via the NAADP-sensitive mechanism may also feedback onto either RYRs or IP3Rs. cADPR and NAADP are generated by CD38. This enzyme might be sensitive to the cellular metabolism, as ATP and NADH inhibit it. The influx of Ca2+ from the environment or release from internal stores causes a very rapid and dramatic increase in cytoplasmic calcium concentration, which has been widely exploited for signal transduction. Some proteins, such as troponin C (TnC) involved in muscle contraction, directly bind to and sense Ca2+. However, in other cases Ca2+ is sensed through intermediate calcium sensors such as calmodulin (CALM).

Standard name | KEGG_CYTOKINE_CYTOKINE_RECEPTOR_INTERACTION
Systematic name | M9809
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Cytokine-cytokine receptor interaction
Full description | Cytokines are soluble extracellular proteins or glycoproteins that are crucial intercellular regulators and mobilizers of cells engaged in innate as well as adaptive inflammatory host defenses, cell growth, differentiation, cell death, angiogenesis, and development and repair processes aimed at the restoration of homeostasis. Cytokines are released by various cells in the body, usually in response to an activating stimulus, and they induce responses through binding to specific receptors on the cell surface of target cells. Cytokines can be grouped by structure into different families and their receptors can likewise be grouped.

Standard name | KEGG_CHEMOKINE_SIGNALING_PATHWAY
Systematic name | M4844
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Chemokine signaling pathway
Full description | Inflammatory immune response requires the recruitment of leukocytes to the site of inflammation upon foreign insult. Chemokines are small chemoattractant peptides that provide directional cues for the cell trafficking and thus are vital for protective host response. In addition, chemokines regulate plethora of biological processes of hematopoietic cells to lead cellular activation, differentiation and survival. The chemokine signal is transduced by chemokine receptors (G-protein coupled receptors) expressed on the immune cells. After receptor activation, the alpha- and beta-gamma-subunits of G protein dissociate to activate diverse downstream pathways resulting in cellular polarization and actin reorganization. Various members of small GTPases are involved in this process. Induction of nitric oxide and production of reactive oxygen species are as well regulated by chemokine signal via calcium mobilization and diacylglycerol production.

Standard name | KEGG_PHOSPHATIDYLINOSITOL_SIGNALING_SYSTEM
Systematic name | M9052
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Phosphatidylinositol signaling system
Full description |

Standard name | KEGG_NEUROACTIVE_LIGAND_RECEPTOR_INTERACTION
Systematic name | M13380
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Neuroactive ligand-receptor interaction
Full description |

Standard name | KEGG_CELL_CYCLE
Systematic name | M7963
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Cell cycle
Full description | Mitotic cell cycle progression is accomplished through a reproducible sequence of events, DNA replication (S phase) and mitosis (M phase) separated temporally by gaps known as G1 and G2 phases. Cyclin-dependent kinases (CDKs) are key regulatory enzymes, each consisting of a catalytic CDK subunit and an activating cyclin subunit. CDKs regulate the cell's progression through the phases of the cell cycle by modulating the activity of key substrates. Downstream targets of CDKs include transcription factor E2F and its regulator Rb. Precise activation and inactivation of CDKs at specific points in the cell cycle are required for orderly cell division. Cyclin-CDK inhibitors (CKIs), such as p16Ink4a, p15Ink4b, p27Kip1, and p21Cip1, are involved in the negative regulation of CDK activities, thus providing a pathway through which the cell cycle is negatively regulated. Eukaryotic cells respond to DNA damage by activating signaling pathways that promote cell cycle arrest and DNA repair. In response to DNA damage, the checkpoint kinase ATM phosphorylates and activates Chk2, which in turn directly phosphorylates and activates p53 tumor suppressor protein. p53 and its transcriptional targets play an important role in both G1 and G2 checkpoints. ATR-Chk1-mediated protein degradation of Cdc25A protein phosphatase is also a mechanism conferring intra-S-phase checkpoint activation.

Standard name | KEGG_OOCYTE_MEIOSIS
Systematic name | M16817
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Oocyte meiosis
Full description | During meiosis, a single round of DNA replication is followed by two rounds of chromosome segregation, called meiosis I and meiosis II. At meiosis I, homologous chromosomes recombine and then segregate to opposite poles, while the sister chromatids segregate from each other at meoisis II. In vertebrates, immature oocytes are arrested at the PI (prophase of meiosis I). The resumption of meiosis is stimulated by progesterone, which carries the oocyte through two consecutive M-phases (MI and MII) to a second arrest at MII. The key activity driving meiotic progression is the MPF (maturation-promoting factor), a heterodimer of CDC2 (cell division cycle 2 kinase) and cyclin B. In PI-arrested oocytes, MPF is initially inactive and is activated by the dual-specificity CDC25C phosphatase as the result of new synthesis of Mos induced by progesterone. MPF activation mediates the transition from the PI arrest to MI. The subsequent decrease in MPF levels, required to exit from MI into interkinesis, is induced by a negative feedback loop, where CDC2 brings about the activation of the APC (anaphase-promoting complex), which mediates destruction of cyclin B. Re-activation of MPF for MII requires re-accumulation of high levels of cyclin B as well as the inactivation of the APC by newly synthesized Emi2 and other components of the CSF (cytostatic factor), such as cyclin E or high levels of Mos. CSF antagonizes the ubiquitin ligase activity of the APC, preventing cyclin B destruction and meiotic exit until fertilization occurs. Fertilization triggers a transient increase in cytosolic free Ca2+, which leads to CSF inactivation and cyclin B destruction through the APC. Then eggs are released from MII into the first embryonic cell cycle.

Standard name | KEGG_P53_SIGNALING_PATHWAY
Systematic name | M6370
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | p53 signaling pathway
Full description | p53 activation is induced by a number of stress signals, including DNA damage, oxidative stress and activated oncogenes. The p53 protein is employed as a transcriptional activator of p53-regulated genes. This results in three major outputs; cell cycle arrest, cellular senescence or apoptosis. Other p53-regulated gene functions communicate with adjacent cells, repair the damaged DNA or set up positive and negative feedback loops that enhance or attenuate the functions of the p53 protein and integrate these stress responses with other signal transduction pathways.

Standard name | KEGG_UBIQUITIN_MEDIATED_PROTEOLYSIS
Systematic name | M15247
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Ubiquitin mediated proteolysis
Full description | Protein ubiquitination plays an important role in eukaryotic cellular processes. It mainly functions as a signal for 26S proteasome dependent protein degradation. The addition of ubiquitin to proteins being degraded is performed by a reaction cascade consisting of three enzymes, named E1 (ubiquitin activating enzyme), E2 (ubiquitin conjugating enzyme), and E3 (ubiquitin ligase). Each E3 has specificity to its substrate, or proteins to be targeted by ubiquitination. Many E3s are discovered in eukaryotes and they are classified into four types: HECT type, U-box type, single RING-finger type, and multi-subunit RING-finger type. Multi-subunit RING-finger E3s are exemplified by cullin-Rbx E3s and APC/C. They consist of a RING-finger-containing subunit (RBX1 or RBX2) that functions to bind E2s, a scaffold-like cullin molecule, adaptor proteins, and a target recognizing subunit that binds substrates.

Standard name | KEGG_SNARE_INTERACTIONS_IN_VESICULAR_TRANSPORT
Systematic name | M17857
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | SNARE interactions in vesicular transport
Full description |

Standard name | KEGG_REGULATION_OF_AUTOPHAGY
Systematic name | M6382
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Regulation of autophagy
Full description |

Standard name | KEGG_LYSOSOME
Systematic name | M11266
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Lysosome
Full description | Lysosomes are membrane-delimited organelles in animal cells serving as the cell's main digestive compartment to which all sorts of macromolecules are delivered for degradation. They contain more than 40 hydrolases in an acidic environment (pH of about 5). After synthesis in the ER, lysosomal enzymes are decorated with mannose-6-phosphate residues, which are recognized by mannose-6-phosphate receptors in the trans-Golgi network. They are packaged into clathrin-coated vesicles and are transported to late endosomes. Substances for digestion are acquired by the lysosomes via a series of processes including endocytosis, phagocytosis, and autophagy.

Standard name | KEGG_ENDOCYTOSIS
Systematic name | M1519
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Endocytosis
Full description | Endocytosis is a mechanism for cells to remove ligands, nutrients, and plasma membrane (PM) proteins, and lipids from the cell surface, bringing them into the cell interior. Transmembrane proteins entering through clathrin-dependent endocytosis (CDE) have sequences in their cytoplasmic domains that bind to the APs (adaptor-related protein complexes) and enable their rapid removal from the PM. In addition to APs and clathrin, there are numerous accessory proteins including dynamin. Depending on the various proteins that enter the endosome membrane, these cargoes are sorted to distinct destinations. Some cargoes, such as nutrient receptors, are recycled back to the PM. Ubiquitylated membrane proteins, such as activated growth-factor receptors, are sorted into intraluminal vesicles and eventually end up in the lysosome lumen via multivesicular endosomes (MVEs). There are distinct mechanisms of clathrin-independent endocytosis (CIE) depending upon the cargo and the cell type.

Standard name | KEGG_PEROXISOME
Systematic name | M6391
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Peroxisome
Full description | Peroxisomes are essential organelles that play a key role in redox signalling and lipid homeostasis. They contribute to many crucial metabolic processes such as fatty acid oxidation, biosynthesis of ether lipids and free radical detoxification. The biogenesis of peroxisomes starts with the early peroxins PEX3, PEX16 and PEX19 and proceeds via several steps. The import of membrane proteins into peroxisomes needs PEX19 for recognition, targeting and insertion via docking at PEX3. Matrix proteins in the cytosol are recognized by peroxisomal targeting signals (PTS) and transported to the docking complex at the peroxisomal membrane. Peroxisomes' deficiencies lead to severe and often fatal inherited peroxisomal disorders (PD). PDs are usually classified in two groups. The first group is disorders of peroxisome biogenesis which include Zellweger syndrome, and the second group is single peroxisomal enzyme deficiencies.

Standard name | KEGG_MTOR_SIGNALING_PATHWAY
Systematic name | M7561
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | mTOR signaling pathway
Full description |

Standard name | KEGG_APOPTOSIS
Systematic name | M8492
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Apoptosis
Full description | Apoptosis is a genetically controlled mechanisms of cell death involved in the regulation of tissue homeostasis. The 2 major pathways of apoptosis are the extrinsic (Fas and other TNFR superfamily members and ligands) and the intrinsic (mitochondria-associated) pathways, both of which are found in the cytoplasm. The extrinsic pathway is triggered by death receptor engagement, which initiates a signaling cascade mediated by caspase-8 activation. Caspase-8 both feeds directly into caspase-3 activation and stimulates the release of cytochrome c by the mitochondria. Caspase-3 activation leads to the degradation of cellular proteins necessary to maintain cell survival and integrity. The intrinsic pathway occurs when various apoptotic stimuli trigger the release of cytochrome c from the mitochondria (independently of caspase-8 activation). Cytochrome c interacts with Apaf-1 and caspase-9 to promote the activation of caspase-3. Recent studies point to the ER as a third subcellular compartment implicated in apoptotic execution. Alterations in Ca2+ homeostasis and accumulation of misfolded proteins in the ER cause ER stress. Prolonged ER stress can result in the activation of BAD and/or caspase-12, and execute apoptosis.

Standard name | KEGG_CARDIAC_MUSCLE_CONTRACTION
Systematic name | M17673
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Cardiac muscle contraction
Full description | Contraction of the heart is a complex process initiated by the electrical excitation of cardiac myocytes (excitation-contraction coupling, ECC). In cardiac myocytes, Ca2+ influx induced by activation of voltage-dependent L-type Ca channels (DHP receptors) upon membrane depolarization triggers the release of Ca2+ via Ca2+ release channels (ryanodine receptors) of sarcoplasmic reticulum (SR) through a Ca2+ -induced Ca release (CICR) mechanism. Ca2+ ions released via the CICR mechanism diffuse through the cytosolic space to contractile proteins to bind to troponinC resulting in the release of inhibition induced by troponinI. The Ca2+ binding to troponinC thereby triggers the sliding of thin and thick filaments, that is, the activation of a crossbridge and subsequent cardiac force development and/or cell shortening. Recovery occurs as Ca2+ is pumped out of the cell by the Na+/Ca2+ exchanger (NCX) or is returned to the sarcoplasmic reticulum (SR) by sarco(endo)plasmic Ca2+ -ATPase (SERCA) pumps on the non-junctional region of the SR.

Standard name | KEGG_VASCULAR_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M9387
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Vascular smooth muscle contraction
Full description | The vascular smooth muscle cell (VSMC) is a highly specialized cell whose principal function is contraction. On contraction, VSMCs shorten, thereby decreasing the diameter of a blood vessel to regulate the blood flow and pressure. The principal mechanisms that regulate the contractile state of VSMCs are changes in cytosolic Ca2+ concentration (c). In response to vasoconstrictor stimuli, Ca2+ is mobilized from intracellular stores and/or the extracellular space to increase c in VSMCs. The increase in c, in turn, activates the Ca2+-CaM-MLCK pathway and stimulates MLC20 phosphorylation, leading to myosin-actin interactions and, hence, the development of contractile force. The sensitivity of contractile myofilaments or MLC20 phosphorylation to Ca2+ can be secondarily modulated by other signaling pathways. During receptor stimulation, the contractile force is greatly enhanced by the inhibition of myosin phosphatase. Rho/Rho kinase, PKC, and arachidonic acid have been proposed to play a pivotal role in this enhancement. The signaling events that mediate relaxation include the removal of a contractile agonist (passive relaxation) and activation of cyclic nucleotide-dependent signaling pathways in the continued presence of a contractile agonist (active relaxation). Active relaxation occurs through the inhibition of both Ca2+ mobilization and myofilament Ca2+ sensitivity in VSMCs.

Standard name | KEGG_WNT_SIGNALING_PATHWAY
Systematic name | M19428
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Wnt signaling pathway
Full description | Wnt proteins are secreted morphogens that are required for basic developmental processes, such as cell-fate specification, progenitor-cell proliferation and the control of asymmetric cell division, in many different species and organs. There are at least three different Wnt pathways: the canonical pathway, the planar cell polarity (PCP) pathway and the Wnt/Ca2+ pathway. In the canonical Wnt pathway, the major effect of Wnt ligand binding to its receptor is the stabilization of cytoplasmic beta-catenin through inhibition of the bea-catenin degradation complex. Beta-catenin is then free to enter the nucleus and activate Wnt-regulated genes through its interaction with TCF (T-cell factor) family transcription factors and concomitant recruitment of coactivators. Planar cell polarity (PCP) signaling leads to the activation of the small GTPases RHOA (RAS homologue gene-family member A) and RAC1, which activate the stress kinase JNK (Jun N-terminal kinase) and ROCK (RHO-associated coiled-coil-containing protein kinase 1) and leads to remodelling of the cytoskeleton and changes in cell adhesion and motility. WNT-Ca2+ signalling is mediated through G proteins and phospholipases and leads to transient increases in cytoplasmic free calcium that subsequently activate the kinase PKC (protein kinase C) and CAMKII (calcium calmodulin mediated kinase II) and the phosphatase calcineurin.

Standard name | KEGG_DORSO_VENTRAL_AXIS_FORMATION
Systematic name | M11190
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Dorso-ventral axis formation
Full description |

Standard name | KEGG_NOTCH_SIGNALING_PATHWAY
Systematic name | M7946
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Notch signaling pathway
Full description | The Notch signaling pathway is an evolutionarily conserved, intercellular signaling mechanism essential for proper embryonic development in all metazoan organisms in the Animal kingdom. The Notch proteins (Notch1-Notch4 in vertebrates) are single-pass receptors that are activated by the Delta (or Delta-like) and Jagged/Serrate families of membrane-bound ligands. They are transported to the plasma membrane as cleaved, but otherwise intact polypeptides. Interaction with ligand leads to two additional proteolytic cleavages that liberate the Notch intracellular domain (NICD) from the plasma membrane. The NICD translocates to the nucleus, where it forms a complex with the DNA binding protein CSL, displacing a histone deacetylase (HDAc)-co-repressor (CoR) complex from CSL. Components of an activation complex, such as MAML1 and histone acetyltransferases (HATs), are recruited to the NICD-CSL complex, leading to the transcriptional activation of Notch target genes.

Standard name | KEGG_HEDGEHOG_SIGNALING_PATHWAY
Systematic name | M1053
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Hedgehog signaling pathway
Full description | The Hedgehog (Hh) family of secreted signaling proteins plays a crucial role in development of diverse animal phyla, from Drosophila to humans, regulating morphogenesis of a variety of tissues and organs. Hh signaling is also involved in control of stem cell proliferation in adult tissues and aberrant activation of the Hh pathway has been linked to multiple types of human cancer. Members of the Hh family bind to patched (ptc), thus releasing smoothened (smo) to transduce a signal. Transcriptional activation occurs through the GLI family of proteins resulting in activation of target genes.

Standard name | KEGG_TGF_BETA_SIGNALING_PATHWAY
Systematic name | M2642
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | TGF-beta signaling pathway
Full description | The transforming growth factor-beta (TGF-beta) family members, which include TGF-betas, activins and bone morphogenetic proteins (BMPs), are structurally related secreted cytokines found in species ranging from worms and insects to mammals. A wide spectrum of cellular functions such as proliferation, apoptosis, differentiation and migration are regulated by TGF-beta family members. TGF-beta family member binds to the Type II receptor and recruits Type I, whereby Type II receptor phosphorylates and activates Type I. The Type I receptor, in turn, phosphorylates receptor-activated Smads ( R-Smads: Smad1, Smad2, Smad3, Smad5, and Smad8). Once phosphorylated, R-Smads associate with the co-mediator Smad, Smad4, and the heteromeric complex then translocates into the nucleus. In the nucleus, Smad complexes activate specific genes through cooperative interactions with other DNA-binding and coactivator (or co-repressor) proteins.

Standard name | KEGG_AXON_GUIDANCE
Systematic name | M5539
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Axon guidance
Full description | Axon guidance represents a key stage in the formation of neuronal network. Axons are guided by a variety of guidance factors, such as netrins, ephrins, Slits, and semaphorins. These guidance cues are read by growth cone receptors, and signal transduction pathways downstream of these receptors converge onto the Rho GTPases to elicit changes in cytoskeletal organization that determine which way the growth cone will turn.

Standard name | KEGG_VEGF_SIGNALING_PATHWAY
Systematic name | M1749
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | VEGF signaling pathway
Full description | There is now much evidence that VEGFR-2 is the major mediator of VEGF-driven responses in endothelial cells and it is considered to be a crucial signal transducer in both physiologic and pathologic angiogenesis. The binding of VEGF to VEGFR-2 leads to a cascade of different signaling pathways, resulting in the up-regulation of genes involved in mediating the proliferation and migration of endothelial cells and promoting their survival and vascular permeability. For example, the binding of VEGF to VEGFR-2 leads to dimerization of the receptor, followed by intracellular activation of the PLCgamma;PKC-Raf kinase-MEK-mitogen-activated protein kinase (MAPK) pathway and subsequent initiation of DNA synthesis and cell growth, whereas activation of the phosphatidylinositol 3' -kinase (PI3K)-Akt pathway leads to increased endothelial-cell survival. Activation of PI3K, FAK, and p38 MAPK is implicated in cell migration signaling.

Standard name | KEGG_FOCAL_ADHESION
Systematic name | M7253
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Focal adhesion
Full description | Cell-matrix adhesions play essential roles in important biological processes including cell motility, cell proliferation, cell differentiation, regulation of gene expression and cell survival. At the cell-extracellular matrix contact points, specialized structures are formed and termed focal adhesions, where bundles of actin filaments are anchored to transmembrane receptors of the integrin family through a multi-molecular complex of junctional plaque proteins. Some of the constituents of focal adhesions participate in the structural link between membrane receptors and the actin cytoskeleton, while others are signalling molecules, including different protein kinases and phosphatases, their substrates, and various adapter proteins. Integrin signaling is dependent upon the non-receptor tyrosine kinase activities of the FAK and src proteins as well as the adaptor protein functions of FAK, src and Shc to initiate downstream signaling events. These signalling events culminate in reorganization of the actin cytoskeleton; a prerequisite for changes in cell shape and motility, and gene expression. Similar morphological alterations and modulation of gene expression are initiated by the binding of growth factors to their respective receptors, emphasizing the considerable crosstalk between adhesion- and growth factor-mediated signalling.

Standard name | KEGG_ECM_RECEPTOR_INTERACTION
Systematic name | M7098
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | ECM-receptor interaction
Full description | The extracellular matrix (ECM) consists of a complex mixture of structural and functional macromolecules and serves an important role in tissue and organ morphogenesis and in the maintenance of cell and tissue structure and function. Specific interactions between cells and the ECM are mediated by transmembrane molecules, mainly integrins and perhaps also proteoglycans, CD36, or other cell-surface-associated components. These interactions lead to a direct or indirect control of cellular activities such as adhesion, migration, differentiation, proliferation, and apoptosis. In addition, integrins function as mechanoreceptors and provide a force-transmitting physical link between the ECM and the cytoskeleton. Integrins are a family of glycosylated, heterodimeric transmembrane adhesion receptors that consist of noncovalently bound alpha- and beta-subunits.

Standard name | KEGG_CELL_ADHESION_MOLECULES_CAMS
Systematic name | M16476
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Cell adhesion molecules (CAMs)
Full description | Cell adhesion molecules are (glyco)proteins expressed on the cell surface and play a critical role in a wide array of biologic processes that include hemostasis, the immune response, inflammation, embryogenesis, and development of neuronal tissue. There are four main groups: the integrin family, the immunoglobulin superfamily, selectins, and cadherins. Membrane proteins that mediate immune cellcell interactions fall into different categories, namely those involved in antigen recognition, costimulation and cellular adhesion. Furthermore cell-cell adhesions are important for brain morphology and highly coordinated brain functions such as memory and learning. During early development of the nervous system, neurons elongate their axons towards their targets and establish and maintain synapses through formation of cell-cell adhesions. Cell-cell adhesions also underpin axon-axon contacts and link neurons with supporting schwann cells and oligodendrocytes.

Standard name | KEGG_ADHERENS_JUNCTION
Systematic name | M638
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Adherens junction
Full description | Cell-cell adherens junctions (AJs), the most common type of intercellular adhesions, are important for maintaining tissue architecture and cell polarity and can limit cell movement and proliferation. At AJs, E-cadherin serves as an essential cell adhesion molecules (CAMs). The cytoplasmic tail binds beta-catenin, which in turn binds alpha-catenin. Alpha-catenin is associated with F-actin bundles directly and indirectly. The integrity of the cadherin-catenin complex is negatively regulated by phosphorylation of beta-catenin by receptor tyrosine kinases (RTKs) and cytoplasmic tyrosine kinases (Fer, Fyn, Yes, and Src), which leads to dissociation of the cadherin-catenin complex. Integrity of this complex is positively regulated by beta -catenin phosphorylation by casein kinase II, and dephosphorylation by protein tyrosine phosphatases. Changes in the phosphorylation state of beta-catenin affect cell-cell adhesion, cell migration and the level of signaling beta-catenin. Wnt signaling acts as a positive regulator of beta-catenin by inhibiting beta-catenin degradation, which stabilizes beta-catenin, and causes its accumulation. Cadherin may acts as a negative regulator of signaling beta-catenin as it binds beta-catenin at the cell surface and thereby sequesters it from the nucleus. Nectins also function as CAMs at AJs, but are more highly concentrated at AJs than E-cadherin. Nectins transduce signals through Cdc42 and Rac, which reorganize the actin cytoskeleton, regulate the formation of AJs, and strengthen cell-cell adhesion.

Standard name | KEGG_TIGHT_JUNCTION
Systematic name | M11355
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Tight junction
Full description | Epithelial tight junctions (TJs) are composed of at least three types of transmembrane protein -occludin, claudin and junctional adhesion molecules (JAMs)- and a cytoplasmic 'plaque' consisting of many different proteins that form large complexes. The transmembrane proteins mediate cell adhesion and are thought to constitute the intramembrane and paracellular diffusion barriers. The cytoplasmic 'plaque' contains three major multi-protein complexes consisting largely of scaffolding proteins, the ZO protein complex, the CRB3-Pals1-PATJ complex and the PAR-3-aPKC-PAR-6 complex. The ZO protein complex appears to organize the transmembrane proteins and couple them to other cytoplasmic proteins and to actin microfilaments. Two evolutionarily conserved protein complexes, the CRB3 and PAR complexes are involved in the establishment and maintenance of epithelial cell polarity. Besides these three protein complexes which seem to be constitutively associated at TJs, a number of proteins with different functions has been identified at TJs. These include additional scaffolding proteins like MUPP1 and MAGI-1, adaptor proteins, transcription regulators and RNA processing factors, regulatory proteins like small GTPases and G-proteins, kinases and phosphatases, and heat shock proteins. These are proposed to be involved in junction assembly, barrier regulation, gene transcription, and perhaps other, presently undefined pathways.

Standard name | KEGG_GAP_JUNCTION
Systematic name | M4013
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Gap junction
Full description | Gap junctions contain intercellular channels that allow direct communication between the cytosolic compartments of adjacent cells. Each gap junction channel is formed by docking of two 'hemichannels', each containing six connexins, contributed by each neighboring cell. These channels permit the direct transfer of small molecules including ions, amino acids, nucleotides, second messengers and other metabolites between adjacent cells. Gap junctional communication is essential for many physiological events, including embryonic development, electrical coupling, metabolic transport, apoptosis, and tissue homeostasis. Communication through Gap Junction is sensitive to a variety of stimuli, including changes in the level of intracellular Ca2+, pH, transjunctional applied voltage and phosphorylation/dephosphorylation processes. This figure represents the possible activation routes of different protein kinases involved in Cx43 and Cx36 phosphorylation.

Standard name | KEGG_COMPLEMENT_AND_COAGULATION_CASCADES
Systematic name | M16894
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Complement and coagulation cascades
Full description | Blood coagulation is a series of coordinated and calcium-dependent proenzyme-to-serine protease conversions likely to be localized on the surfaces of activated cells in vivo. It culminates in the formation of thrombin, the enzyme responsible for the conversion of soluble fibrinogen to the insoluble fibrin clot. The kallikrein-kinin system is an endogenous metabolic cascade, triggering of which results in the release of vasoactive kinins (bradykinin-related peptides). Kinin peptides are implicated in many physiological and pathological processes including the regulation of blood pressure and sodium homeostasis, inflammatory processes, and the cardioprotective effects of preconditioning. Complement is a system of plasma proteins that is activated by the presence of pathogens. There are three pathways of complement activation: the classical pathway, the lectin pathway, and the alternative pathway. All of these pathways generate a crucial enzymatic activity that, intern, generates the effector molecules of complement. The three main consequences of complement activation are the opsonization of pathogens, the recruitment of inflammatory and immunocompetent cells, and the direct killing of pathogens.

Standard name | KEGG_ANTIGEN_PROCESSING_AND_PRESENTATION
Systematic name | M16004
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Antigen processing and presentation
Full description |

Standard name | KEGG_RENIN_ANGIOTENSIN_SYSTEM
Systematic name | M17636
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Renin-angiotensin system
Full description |

Standard name | KEGG_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M3261
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Toll-like receptor signaling pathway
Full description | Specific families of pattern recognition receptors are responsible for detecting microbial pathogens and generating innate immune responses. Toll-like receptors (TLRs) are membrane-bound receptors identified as homologs of Toll in Drosophila. Mammalian TLRs are expressed on innate immune cells, such as macrophages and dendritic cells, and respond to the membrane components of Gram-positive or Gram-negative bacteria. Pathogen recognition by TLRs provokes rapid activation of innate immunity by inducing production of proinflammatory cytokines and upregulation of costimulatory molecules. TLR signaling pathways are separated into two groups: a MyD88-dependent pathway that leads to the production of proinflammatory cytokines with quick activation of NF-{kappa}B and MAPK, and a MyD88-independent pathway associated with the induction of IFN-beta and IFN-inducible genes, and maturation of dendritic cells with slow activation of NF-{kappa}B and MAPK.

Standard name | KEGG_NOD_LIKE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15569
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | NOD-like receptor signaling pathway
Full description | Specific families of pattern recognition receptors are responsible for detecting various pathogens and generating innate immune responses. The intracellular NOD-like receptor (NLR) family contains more than 20 members in mammals and plays a pivotal role in the recognition of intracellular ligands. NOD1 and NOD2, two prototypic NLRs, sense the cytosolic presence of the bacterial peptidoglycan fragments that escaped from endosomal compartments, driving the activation of NF-{kappa}B and MAPK, cytokine production and apoptosis. On the other hand, a different set of NLRs induces caspase-1 activation through the assembly of multiprotein complexes called inflammasomes. These NLRs include NALP1, NALP3 and Ipaf. The inflammasomes are critical for generating mature proinflammatory cytokines in concert with Toll-like receptor signaling pathway.

Standard name | KEGG_RIG_I_LIKE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15913
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | RIG-I-like receptor signaling pathway
Full description | Specific families of pattern recognition receptors are responsible for detecting viral pathogens and generating innate immune responses. Non-self RNA appearing in a cell as a result of intracellular viral replication is recognized by a family of cytosolic RNA helicases termed RIG-I-like receptors (RLRs). The RLR proteins include RIG-I, MDA5, and LGP2 and are expressed in both immune and nonimmune cells. Upon recognition of viral nucleic acids, RLRs recruit specific intracellular adaptor proteins to initiate signaling pathways that lead to the synthesis of type I interferon and other inflammatory cytokines, which are important for eliminating viruses.

Standard name | KEGG_CYTOSOLIC_DNA_SENSING_PATHWAY
Systematic name | M11844
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Cytosolic DNA-sensing pathway
Full description | Specific families of pattern recognition receptors are responsible for detecting foreign DNA from invading microbes or host cells and generating innate immune responses. DAI is the first identified sensor of cytosolic DNA which activates the IRF and NF-{kappa}B transcription factors, leading to production of type I interferon and other cytokines. The second type of cytoplasmic DNA sensor is AIM2. Upon sensing DNA, AIM2 triggers the assembly of the inflammasome, culminating in interleukin maturation. In addition to these receptors, there is a mechanism to sense foreign DNA, with the host RNA polymerase III converting the DNA into RNA for recognition by the RNA sensor RIG-I. These pathways provide various means to alert the cell.

Standard name | KEGG_JAK_STAT_SIGNALING_PATHWAY
Systematic name | M17411
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Jak-STAT signaling pathway
Full description | The Janus kinase/signal transducers and activators of transcription (JAK/STAT) pathway is one of a handful of pleiotropic cascades used to transduce a multitude of signals for development and homeostasis in animals, from humans to flies. In mammals, the JAK/STAT pathway is the principal signaling mechanism for a wide array of cytokines and growth factors. Following the binding of cytokines to their cognate receptor, STATs are activated by members of the JAK family of tyrosine kinases. Once activated, they dimerize and translocate to the nucleus and modulate the expression of target genes. In addition to the activation of STATs, JAKs mediate the recruitment of other molecules such as the MAP kinases, PI3 kinase etc. These molecules process downstream signals via the Ras-Raf-MAP kinase and PI3 kinase pathways which results in the activation of additional transcription factors.

Standard name | KEGG_HEMATOPOIETIC_CELL_LINEAGE
Systematic name | M6856
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Hematopoietic cell lineage
Full description | Blood-cell development progresses from a hematopoietic stem cell (HSC), which can undergo either self-renewal or differentiation into a multilineage committed progenitor cell: a common lymphoid progenitor (CLP) or a common myeloid progenitor (CMP). A CLP gives rise to the lymphoid lineage of white blood cells or leukocytes-the natural killer (NK) cells and the T and B lymphocytes. A CMP gives rise to the myeloid lineage, which comprises the rest of the leukocytes, the erythrocytes (red blood cells), and the megakaryocytes that produce platelets important in blood clotting. Cells undergoing these differentiation process express a stage- and lineage-specific set of surface markers. Therefore cellular stages are identified by the specific expression patterns of these genes.

Standard name | KEGG_NATURAL_KILLER_CELL_MEDIATED_CYTOTOXICITY
Systematic name | M5669
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Natural killer cell mediated cytotoxicity
Full description | Natural killer (NK) cells are lymphocytes of the innate immune system that are involved in early defenses against both allogeneic (nonself) cells and autologous cells undergoing various forms of stress, such as infection with viruses, bacteria, or parasites or malignant transformation. Although NK cells do not express classical antigen receptors of the immunoglobulin gene family, such as the antibodies produced by B cells or the T cell receptor expressed by T cells, they are equipped with various receptors whose engagement allows them to discriminate between target and nontarget cells. Activating receptors bind ligands on the target cell surface and trigger NK cell activation and target cell lysis. However Inhibitory receptors recognize MHC class I molecules (HLA) and inhibit killing by NK cells by overruling the actions of the activating receptors. This inhibitory signal is lost when the target cells do not express MHC class I and perhaps also in cells infected with virus, which might inhibit MHC class I exprssion or alter its conformation. The mechanism of NK cell killing is the same as that used by the cytotoxic T cells generated in an adaptive immune response; cytotoxic granules are released onto the surface of the bound target cell, and the effector proteins they contain penetrate the cell membrane and induce programmed cell death.

Standard name | KEGG_T_CELL_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M9904
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | T cell receptor signaling pathway
Full description | Activation of T lymphocytes is a key event for an efficient response of the immune system. It requires the involvement of the T-cell receptor (TCR) as well as costimulatory molecules such as CD28. Engagement of these receptors through the interaction with a foreign antigen associated with major histocompatibility complex molecules and CD28 counter-receptors B7.1/B7.2, respectively, results in a series of signaling cascades. These cascades comprise an array of protein-tyrosine kinases, phosphatases, GTP-binding proteins and adaptor proteins that regulate generic and specialised functions, leading to T-cell proliferation, cytokine production and differentiation into effector cells.

Standard name | KEGG_B_CELL_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M5436
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | B cell receptor signaling pathway
Full description | B cells are an important component of adaptive immunity. They produce and secrete millions of different antibody molecules, each of which recognizes a different (foreign) antigen. The B cell receptor (BCR) is an integral membrane protein complex that is composed of two immunoglobulin (Ig) heavy chains, two Ig light chains and two heterodimers of Ig-alpha and Ig-beta. After BCR ligation by antigen, three main protein tyrosine kinases (PTKs) -the SRC-family kinase LYN, SYK and the TEC-family kinase BTK- are activated. Phosphatidylinositol 3-kinase (PI3K) and phospholipase C-gamma 2 (PLC-gamma 2) are important downstream effectors of BCR signalling. This signalling ultimately results in the expression of immediate early genes that further activate the expression of other genes involved in B cell proliferation, differentiation and Ig production as well as other processes.

Standard name | KEGG_FC_EPSILON_RI_SIGNALING_PATHWAY
Systematic name | M11816
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Fc epsilon RI signaling pathway
Full description | Fc epsilon RI-mediated signaling pathways in mast cells are initiated by the interaction of antigen (Ag) with IgE bound to the extracellular domain of the alpha chain of Fc epsilon RI. The activation pathways are regulated both positively and negatively by the interactions of numerous signaling molecules. Mast cells that are thus activated release preformed granules which contain biogenic amines (especially histamines) and proteoglycans (especially heparin). The activation of phospholipase A2 causes the release of membrane lipids followed by development of lipid mediators such as leukotrienes (LTC4, LTD4 and LTE4) and prostaglandins (especially PDG2). There is also secretion of cytokines, the most important of which are TNF-alpha, IL-4 and IL-5. These mediators and cytokines contribute to inflammatory responses.

Standard name | KEGG_FC_GAMMA_R_MEDIATED_PHAGOCYTOSIS
Systematic name | M16121
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Fc gamma R-mediated phagocytosis
Full description | Phagocytosis plays an essential role in host-defense mechanisms through the uptake and destruction of infectious pathogens. Specialized cell types including macrophages, neutrophils, and monocytes take part in this process in higher organisms. After opsonization with antibodies (IgG), foreign extracellular materials are recognized by Fc gamma receptors. Cross-linking of Fc gamma receptors initiates a variety of signals mediated by tyrosine phosphorylation of multiple proteins, which lead through the actin cytoskeleton rearrangements and membrane remodeling to the formation of phagosomes. Nascent phagosomes undergo a process of maturation that involves fusion with lysosomes. The acquisition of lysosomal proteases and release of reactive oxygen species are crucial for digestion of engulfed materials in phagosomes.

Standard name | KEGG_LEUKOCYTE_TRANSENDOTHELIAL_MIGRATION
Systematic name | M2164
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Leukocyte transendothelial migration
Full description | Leukocyte migaration from the blood into tissues is vital for immune surveillance and inflammation. During this diapedesis of leukocytes, the leukocytes bind to endothelial cell adhesion molecules (CAM) and then migrate across the vascular endothelium. A leukocyte adherent to CAMs on the endothelial cells moves forward by leading-edge protrusion and retraction of its tail. In this process, alphaL /beta2 integrin activates through Vav1, RhoA, which subsequently activates the kinase p160ROCK. ROCK activation leads to MLC phosphorylation, resulting in retraction of the actin cytoskeleton. Moreover, Leukocytes activate endothelial cell signals that stimulate endothelial cell retraction during localized dissociation of the endothelial cell junctions. ICAM-1-mediated signals activate an endothelial cell calcium flux and PKC, which are required for ICAM-1 dependent leukocyte migration. VCAM-1 is involved in the opening of the endothelial passage through which leukocytes can extravasate. In this regard, VCAM-1 ligation induces NADPH oxidase activation and the production of reactive oxygen species (ROS) in a Rac-mediated manner, with subsequent activation of matrix metallopoteinases and loss of VE-cadherin-mediated adhesion.

Standard name | KEGG_INTESTINAL_IMMUNE_NETWORK_FOR_IGA_PRODUCTION
Systematic name | M615
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Intestinal immune network for IgA production
Full description | The intestine is the largest lymphoid tissue in the body. One striking feature of intestinal immunity is its ability to generate great amounts of noninflammatory immunoglobulin A (IgA) antibodies that serve as the first line of defense against microorganisms. The basic map of IgA production includes induction of mucosal B cells in the Peyer's patches, circulation through the bloodstream and homing to intestinal mucosa of IgA-commited plasma cells, and local antibody production for export across the intestinal membranes. Multiple cytokines, including TGF-{beta}, IL-10, IL-4, IL-5, and IL-6, are required to promote IgA class switching and terminal differentiation process of the B cells. Secreted IgA promotes immune exclusion by entrapping dietary antigens and microorganisms in the mucus and functions for neutralization of toxins and pathogenic microbes.

Standard name | KEGG_CIRCADIAN_RHYTHM_MAMMAL
Systematic name | M18009
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Circadian rhythm - mammal
Full description |

Standard name | KEGG_LONG_TERM_POTENTIATION
Systematic name | M3115
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Long-term potentiation
Full description | Hippocampal long-term potentiation (LTP), a long-lasting increase in synaptic efficacy, is the molecular basis for learning and memory. Tetanic stimulation of afferents in the CA1 region of the hippocampus induces glutamate release and activation of glutamate receptors in dendritic spines. A large increase in i resulting from influx through NMDA receptors leads to constitutive activation of CaM kinase II (CaM KII). Constitutively active CaM kinase II phosphorylates AMPA receptors, resulting in potentiation of the ionic conductance of AMPA receptors. Early-phase LTP (E-LTP) expression is due, in part, to this phosphorylation of the AMPA receptor. It is hypothesized that postsynaptic Ca2+ increases generated through NMDA receptors activate several signal transduction pathways including the Erk/MAP kinase and cAMP regulatory pathways. The convergence of these pathways at the level of the CREB/CRE transcriptional pathway may increase expression of a family of genes required for late-phase LTP (L-LTP).

Standard name | KEGG_NEUROTROPHIN_SIGNALING_PATHWAY
Systematic name | M16763
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Neurotrophin signaling pathway
Full description | Neurotrophins are a family of trophic factors involved in differentiation and survival of neural cells. The neurotrophin family consists of nerve growth factor (NGF), brain derived neurotrophic factor (BDNF), neurotrophin 3 (NT-3), and neurotrophin 4 (NT-4). Neurotrophins exert their functions through engagement of Trk tyrosine kinase receptors or p75 neurotrophin receptor (p75NTR). Neurotrophin/Trk signaling is regulated by connecting a variety of intracellular signaling cascades, which include MAPK pathway, PI-3 kinase pathway, and PLC pathway, transmitting positive signals like enhanced survival and growth. On the other hand, p75NTR transmits both positive and nagative signals. These signals play an important role for neural development and additional higher-order activities such as learning and memory.

Standard name | KEGG_LONG_TERM_DEPRESSION
Systematic name | M8232
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Long-term depression
Full description | Cerebellar long-term depression (LTD), thought to be a molecular and cellular basis for cerebellar learning, is a process involving a decrease in the synaptic strength between parallel fiber (PF) and Purkinje cells (PCs) induced by the conjunctive activation of PFs and climbing fiber (CF). Multiple signal transduction pathways have been shown to be involved in this process. Activation of PFs terminating on spines in dendritic branchlets leads to glutamate release and activation of both AMPA and mGluRs. Activation of CFs, which make multiple synaptic contacts on proximal dendrites, also via AMPA receptors, opens voltage-gated calcium channels (VGCCs) and causes a generalized influx of calcium. These cellular signals, generated from two different synaptic origins, trigger a cascade of events culminating in a phosphorylation-dependent, long-term reduction in AMPA receptor sensitivity at the PF-PC synapse. This may take place either through receptor internalization and/or through receptor desensitization.

Standard name | KEGG_OLFACTORY_TRANSDUCTION
Systematic name | M14091
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Olfactory transduction
Full description | Within the compact cilia of the olfactory receptor neurons (ORNs) a cascade of enzymatic activity transduces the binding of an odorant molecule to a receptor into an electrical signal that can be transmitted to the brain. Odorant molecules bind to a receptor protein (R) coupled to an olfactory specific Gs-protein (G) and activate a type III adenylyl cyclase (AC), increasing intracellular cAMP levels. cAMP targets an olfactory-specific cyclic-nucleotide gated ion channel (CNG), allowing cations, particularly Na and Ca, to flow down their electrochemical gradients into the cell, depolarizing the ORN. Furthermore, the Ca entering the cell is able to activate a Ca-activated Cl channel, which would allow Cl to flow out of the cell, thus further increasing the depolarization. Elevated intracellular Ca causes adaptation by at least two different molecular steps: inhibition of the activity of adenylyl cyclase via CAMKII-dependent phosphorylation and down-regulation of the affinity of the CNG channel to cAMP.Longer exposure to odorants can stimulate particulate guanylyl cyclase in cilia to produce cGMP and activate PKG, leading to a further increase in amount and duration of intracellular cAMP levels, which may serve to convert inactive forms of protein kinase A (PKA2) to active forms (PKA*). As part of a feedback loop, PKA can inhibit the activation of particulate guanylyl cyclase.

Standard name | KEGG_TASTE_TRANSDUCTION
Systematic name | M5785
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Taste transduction
Full description | All taste pathways are proposed to converge on common elements that mediate a rise in intracellular Ca2+ followed by neurotransmitter release. Na+ salt depolarizes taste cells by passive influx of Na+ through the amiloride-sensitive Na+ channel (ENaC). Acids depolarize taste cells by a variety of mechanisms, including influx of protons (H+) through ENaC and a proton-gated cation channel (MDEG). Two putative umami receptors have been identified: a truncated variant of the metabotropic glutamate receptor mGluR4 and the heterodimer, T1R1 + T1R3. Umami receptors are coupled to a signaling pathway involving activation of PLCbeta2, production of IP3 and diacylglycerol, release of Ca2+ from intracellular stores and activation of a transient receptor potential channel, TRPM5. Bitter compounds, such as denatonium and PROP, activate particular T2R/TRB isoforms, which activate gustducin heterotrimers. Activated alpha-gustducin stimulates PDE to hydrolyze cAMP, whereas betagamma subunits activate PLCbeta2 to generate IP3, which leads to release of Ca2+ from internal stores. Artificial sweeteners activate GPCRs (T1R heterodimers) apparently linked via PLC to IP3 production and release of Ca2+ from intracellular stores. Sugars apparently activate GPCRs linked via AC to cAMP production which, in turn, may inhibit basolateral K+ channels through phosphorylation by cAMP-activated protein kinase A (PKA).

Standard name | KEGG_REGULATION_OF_ACTIN_CYTOSKELETON
Systematic name | M18306
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Regulation of actin cytoskeleton
Full description |

Standard name | KEGG_INSULIN_SIGNALING_PATHWAY
Systematic name | M18155
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Insulin signaling pathway
Full description | Insulin binding to its receptor results in the tyrosine phosphorylation of insulin receptor substrates (IRS) by the insulin receptor tyrosine kinase (INSR). This allows association of IRSs with the regulatory subunit of phosphoinositide 3-kinase (PI3K). PI3K activates 3-phosphoinositide-dependent protein kinase 1 (PDK1), which activates Akt, a serine kinase. Akt in turn deactivates glycogen synthase kinase 3 (GSK-3), leading to activation of glycogen synthase (GYS) and thus glycogen synthesis. Activation of Akt also results in the translocation of GLUT4 vesicles from their intracellular pool to the plasma membrane, where they allow uptake of glucose into the cell. Akt also leads to mTOR-mediated activation of protein synthesis by eIF4 and p70S6K. The translocation of GLUT4 protein is also elicited through the CAP/Cbl/TC10 pathway, once Cbl is phosphorylated by INSR. Other signal transduction proteins interact with IRS including GRB2. GRB2 is part of the cascade including SOS, RAS, RAF and MEK that leads to activation of mitogen-activated protein kinase (MAPK) and mitogenic responses in the form of gene transcription. SHC is another substrate of INSR. When tyrosine phosphorylated, SHC associates with GRB2 and can thus activate the RAS/MAPK pathway independently of IRS-1.

Standard name | KEGG_GNRH_SIGNALING_PATHWAY
Systematic name | M1979
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | GnRH signaling pathway
Full description | Gonadotropin-releasing hormone (GnRH) secretion from the hypothalamus acts upon its receptor in the anterior pituitary to regulate the production and release of the gonadotropins, LH and FSH. The GnRHR is coupled to Gq/11 proteins to activate phospholipase C which transmits its signal to diacylglycerol (DAG) and inositol 1,4,5-trisphosphate (IP3). DAG activates the intracellular protein kinase C (PKC) pathway and IP3 stimulates release of intracellular calcium. In addition to the classical Gq/11, coupling of Gs is occasionally observed in a cell-specific fashion. Signaling downstream of protein kinase C (PKC) leads to transactivation of the epidermal growth factor (EGF) receptor and activation of mitogen-activated protein kinases (MAPKs), including extracellular-signal-regulated kinase (ERK), Jun N-terminal kinase (JNK) and p38 MAPK. Active MAPKs translocate to the nucleus, resulting in activation of transcription factors and rapid induction of early genes.

Standard name | KEGG_PROGESTERONE_MEDIATED_OOCYTE_MATURATION
Systematic name | M3578
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Progesterone-mediated oocyte maturation
Full description | Xenopus oocytes are naturally arrested at G2 of meiosis I. Exposure to either insulin/IGF-1 or the steroid hormone progesterone breaks this arrest and induces resumption of the two meiotic division cycles and maturation of the oocyte into a mature, fertilizable egg. This process is termed oocyte maturation. The transition is accompanied by an increase in maturation promoting factor (MPF or Cdc2/cyclin B) which precedes germinal vesicle breakdown (GVBD). Most reports point towards the Mos-MEK1-ERK2 pathway and the polo-like kinase/CDC25 pathway as responsible for the activation of MPF in meiosis, most likely triggered by a decrease in cAMP.

Standard name | KEGG_MELANOGENESIS
Systematic name | M7761
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Melanogenesis
Full description | Cutaneous melanin pigment plays a critical role in camouflage, mimicry, social communication, and protection against harmful effects of solar radiation. Melanogenesis is under complex regulatory control by multiple agents. The most important positive regulator of melanogenesis is the MC1 receptor with its ligands melanocortic peptides. MC1R activates the cyclic AMP (cAMP) response-element binding protein (CREB). Increased expression of MITF and its activation by phosphorylation (P) stimulate the transcription of tyrosinase (TYR), tyrosinase-related protein 1 (TYRP1), and dopachrome tautomerase (DCT), which produce melanin. Melanin synthesis takes place within specialized intracellular organelles named melanosomes. Melanin-containing melanosomes then move from the perinuclear region to the dendrite tips and are transferred to keratinocytes by a still not well-characterized mechanism.

Standard name | KEGG_ADIPOCYTOKINE_SIGNALING_PATHWAY
Systematic name | M10462
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Adipocytokine signaling pathway
Full description | Increased adipocyte volume and number are positively correlated with leptin production, and negatively correlated with production of adiponectin. Leptin is an important regulator of energy intake and metabolic rate primarily by acting at hypothalamic nuclei. Leptin exerts its anorectic effects by modulating the levels of neuropeptides such as NPY, AGRP, and alpha-MSH. This leptin action is through the JAK kinase, STAT3 phosphorylation, and nuclear transcriptional effect. Adiponectin lowers plasma glucose and FFAs. These effects are partly accounted for by adiponectin-induced AMPK activation, which in turn stimulates skeletal muscle fatty acid oxidation and glucose uptake. Furthermore, activation of AMPK by adiponectin suppresses endogenous glucose production, concomitantly with inhibition of PEPCK and G6Pase expression. The proinflammatory cytokine TNFalpha has been implicated as a link between obesity and insulin resistance. TNFalpha interferes with early steps of insulin signaling. Several data have shown that TNFalpha inhibits IRS1 tyrosine phosphorylation by promoting its serine phosphorylation. Among the serine/threonine kinases activated by TNFalpha, JNK, mTOR and IKK have been shown to be involved in this phosphorylation.

Standard name | KEGG_TYPE_II_DIABETES_MELLITUS
Systematic name | M19708
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Type II diabetes mellitus
Full description | Insulin resistance is strongly associated with type II diabetes. Diabetogenic factors including FFA, TNFalpha and cellular stress induce insulin resistance through inhibition of IRS1 functions. Serine/threonine phosphorylation, interaction with SOCS, regulation of the expression, modification of the cellular localization, and degradation represent the molecular mechanisms stimulated by them. Various kinases (ERK, JNK, IKKbeta, PKCzeta, PKCtheta and mTOR) are involved in this process. The development of type II diabetes requires impaired beta-cell function. Chronic hyperglycemia has been shown to induce multiple defects in beta-cells. Hyperglycemia has been proposed to lead to large amounts of reactive oxygen species (ROS) in beta-cells, with subsequent damage to cellular components including PDX-1. Loss of PDX-1, a critical regulator of insulin promoter activity, has also been proposed as an important mechanism leading to beta-cell dysfunction. Although there is little doubt as to the importance of genetic factors in type II diabetes, genetic analysis is difficult due to complex interaction among multiple susceptibility genes and between genetic and environmental factors. Genetic studies have therefore given very diverse results. Kir6.2 and IRS are two of the candidate genes. It is known that Kir6.2 and IRS play central roles in insulin secretion and insulin signal transmission, respectively.

Standard name | KEGG_TYPE_I_DIABETES_MELLITUS
Systematic name | M12617
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Type I diabetes mellitus
Full description | Type I diabetes mellitus is a disease that results from autoimmune destruction of the insulin-producing beta-cells. Certain beta-cell proteins act as autoantigens after being processed by antigen-presenting cell (APC), such as macrophages and dendritic cells, and presented in a complex with MHC-II molecules on the surface of the APC. Then immunogenic signals from APC activate CD4+ T cells, predominantly of the Th1 subset. Antigen-activated Th1 cells produce IL-2 and IFNgamma. They activate macrophages and cytotoxic CD8+ T cells, and these effector cells may kill islet beta-cells by one or both of two types of mechanisms: (1) direct interactions of antigen-specific cytotoxic T cells with a beta-cell autoantigen-MHC-I complex on the beta-cell, and (2) non-specific inflammatory mediators, such as free radicals/oxidants and cytokines (IL-1, TNFalpha, TNFbeta, IFNgamma). Type I diabetes is a polygenic disease. One of the principle determining genetic factors in diabetes incidence is the inheritance of mutant MHC-II alleles. Another plausible candidate gene is the insulin gene.

Standard name | KEGG_MATURITY_ONSET_DIABETES_OF_THE_YOUNG
Systematic name | M18312
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Maturity onset diabetes of the young
Full description | About 2-5% of type II diabetic patients suffer from a monogenic disease with autosomal dominant inheritance. This monogenic form of type II diabetes is called maturity onset diabetes of the young (MODY). We now know that MODY is caused by heterozygous mutations in at least five genes encoding transcription factors: HNF4alpha (MODY1), HNF1alpha (MODY3), PDX1 (MODY4), HNF1beta (MODY5) and NEUROD1 (MODY6). MODY2, which is so far the only subtype not related to a transcription factor, is caused by mutations in the glucokinase gene. Mutations of MODY transcription factor genes lead to abnormal expression of genes involved in pancreatic islet development and metabolism.

Standard name | KEGG_ALDOSTERONE_REGULATED_SODIUM_REABSORPTION
Systematic name | M16473
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Aldosterone-regulated sodium reabsorption
Full description | Sodium transport across the tight epithelia of Na+ reabsorbing tissues such as the distal part of the kidney nephron and colon is the major factor determining total-body Na+ levels, and thus, long-term blood pressure. Aldosterone plays a major role in sodium and potassium metabolism by binding to epithelial mineralocorticoid receptors (MR) in the renal collecting duct cells localized in the distal nephron, promoting sodium resorption and potassium excretion. Aldosterone enters a target cell and binds MR, which translocates into the nucleus and regulates gene transcription. Activation of MR leads to increased expression of Sgk-1, which phosphorylates Nedd4-2, an ubiquitin-ligase which targets ENAC to proteosomal degradation. Phosphorylated Nedd4-2 dissociates from ENAC, increasing its apical membrane abundance. Activation of MR also leads to increased expression of Na+/K+-ATPase, thus causing a net increase in sodium uptake from the renal filtrate. The specificity of MR for aldosterone is provided by 11beta-HSD2 by the rapid conversion of cortisol to cortisone in renal cortical collecting duct cells. Recently, besides genomic effects mediated by activated MR, rapid aldosterone actions that are independent of translation and transcription have been documented.

Standard name | KEGG_VASOPRESSIN_REGULATED_WATER_REABSORPTION
Systematic name | M9011
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Vasopressin-regulated water reabsorption
Full description | In the kidney, the antidiuretic hormone vasopressin (AVP) is a critical regulator of water homeostasis by controlling the water movement from lumen to the interstitium for water reabsorption and adjusting the urinary water excretion. In normal physiology, AVP is secreted into the circulation by the posterior pituitary gland, in response to an increase in serum osmolality or a decrease in effective circulating volume. When reaching the kidney, AVP binds to V2 receptors on the basolateral surface of the collecting duct epithelium, triggering a G-protein-linked signaling cascade, which leads to water channel aquaporin-2 (AQP2) vesicle insertion into the apical plasma membrane. This results in higher water permeability in the collecting duct and, driven by an osmotic gradient, pro-urinary water then passes the membrane through AQP2 and leaves the cell on the basolateral side via AQP3 and AQP4 water channels, which are constitutively expressed on the basolateral side of these cells. When isotonicity is restored, reduced blood AVP levels results in AQP2 internalization, leaving the apical membrane watertight again.

Standard name | KEGG_PROXIMAL_TUBULE_BICARBONATE_RECLAMATION
Systematic name | M4361
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Proximal tubule bicarbonate reclamation
Full description | One of the major tasks of the renal proximal tubule (PT) is to secrete acid into the tubule lumen, thereby reabsorbing approximately 80% of the filtered bicarbonate (HCO3(-)), as well as generating new HCO3(-) for regulating blood pH. In the tubular lumen, filtered HCO3(-) combines with H(+) in a reaction catalyzed by CA IV. The CO2 thus produced rapidly diffuses into the tubular cells and is combined with water to produce intracellular H(+) and HCO3(-), catalyzed by soluble cytoplasmic CA II. HCO3(-) is then cotransported with Na(+) into blood via the NBC-1. The intracellular H(+) produced by CA II is secreted into the tubular lumen predominantly via the NHE-3. The PT creates the new HCO3(-) by taking glutamine and metabolizing it to two molecules each of NH4(+) and HCO3(-). The NH4(+) is excreted into the tubular lumen, and the HCO3(-) , which is new HCO3(-) , is returned to the blood, where it replaces the HCO3(-) lost earlier in the titration of nonvolatile acids.

Standard name | KEGG_ALZHEIMERS_DISEASE
Systematic name | M16024
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Alzheimer's disease
Full description | Alzheimer's disease (AD) is a chronic disorder that slowly destroys neurons and causes serious cognitive disability. AD is associated with senile plaques and neurofibrillary tangles (NFTs). Amyloid-beta (Abeta), a major component of senile plaques, has various pathological effects on cell and organelle function. The extracellular Abeta oligomers may activate caspases through activation of cell surface death receptors. Alternatively, intracellular Abeta may contribute to pathology by facilitating tau hyper-phosphorylation, disrupting mitochondria function, and triggering calcium dysfunction. To date genetic studies have revealed four genes that may be linked to autosomal dominant or familial early onset AD (FAD). These four genes include: amyloid precursor protein (APP), presenilin 1 (PS1), presenilin 2 (PS2) and apolipoprotein E (ApoE). All mutations associated with APP and PS proteins can lead to an increase in the production of Abeta peptides, specifically the more amyloidogenic form, Abeta42. FAD-linked PS1 mutation downregulates the unfolded protein response and leads to vulnerability to ER stress.

Standard name | KEGG_PARKINSONS_DISEASE
Systematic name | M7272
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Parkinson's disease
Full description | Parkinson's disease (PD) is a progressive neurodegenerative movement disorder that results primarily from the death of dopaminergic neurons in the substantia nigra. Mutations in alpha-synuclein, UCHL1 (a ubiquitin carboxy-terminal hydrolase L1), parkin, DJ1 (a parkin-associated protein involved with oxidative stress), and PINK1 (a putative serine threonine kinase) are known to cause early-onset PD. Mutations or altered expression of these proteins contributes to PD pathogenesis through common mechanisms that result in proteasome dysfunction, mitochondrial impairment, and oxidative stress. Point mutations in alpha-synuclein and the recently described Iowan functional duplication of alpha-synuclein lead to excessive intracellular accumulation and protofibril formation. Decrease in the amount of soluble alpha-synuclein tends to increase free cytoplasmic dopamine and the formation of reactive oxygen species (ROS). Indeed, formation of protofibrils or aggregates and Lewy bodies (LBs) diminishes the availability of the physiological forms of alpha-synuclein, favoring an increase in TH (tyrosine hydroxylase) and DAT (dopamine transporter), but diminishes vesicles formation and neuronal plasticity. Modification of parkin and UCHL1 are associated with the ubiquitin-proteasome system pathway and may increase proteotoxic stress. Mutations in parkin, DJ1, and PINK1 may alter mitochondiral activity, potentially impairing proteasomal function. Environmental toxins such as N-methyl-4-phenyl-1,2,3,6-tetrahydropyridine (MPTP) and rotenone can cause mitochondrial dysfunction and oxidative stress.

Standard name | KEGG_AMYOTROPHIC_LATERAL_SCLEROSIS_ALS
Systematic name | M3812
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Amyotrophic lateral sclerosis (ALS)
Full description | Amyotrophic lateral sclerosis (ALS) is a progressive, lethal, degenerative disorder of motor neurons. The hallmark of this disease is the selective death of motor neurons in the brain and spinal cord, leading to paralysis of voluntary muscles. Mutant superoxide dismutase 1 (SOD1), as seen in some familial amyotrophic lateral sclerosis (FALS) cases, may be toxic because it is unstable, forming aggregates in the motor neuron cytoplasm, axoplasm and mitochondria. Within mitochondria, mutant SOD1 may interfere with the anti-apoptotic function of Bcl-2, affect mitochondrial import by interfering with the translocation machinery (TOM/TIM), and generate toxic free radicals (ROS) via aberrant superoxide chemistry. These changes may then result in abnormal mitochondrial energy metabolism, Ca2+ handling, and release of pro-apoptotic factors. Reactive oxygen species (ROS), produced within mitochondria, inhibit the function of EAAT2, the main glial glutamate transporter protein, responsible for most of the reuptake of synaptically released glutamate. Glutamate excess causes neurotoxicity by increasing intracellular calcium, which enhances oxidative stress and mitochondrial damage. Mutant SOD1 can also trigger oxidative reactions by various means including by increasing levels of peroxynitrite, which can then cause damage through the formation of hydroxyl radicals or via nitration of tyrosine residues on proteins. Nitration may target neurofilament proteins, disrupting their phosphorylation and affecting axonal transport. Collectively, these mechanisms (or a combination thereof) are predicted to disturb cellular homeostasis (within glial and/or motor neurons), ultimately triggering motor neuron death.

Standard name | KEGG_HUNTINGTONS_DISEASE
Systematic name | M13486
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Huntington's disease
Full description | Huntington disease (HD) is an autosomal-dominant neurodegenerative disorder that primarily affects medium spiny striatal neurons (MSN). HD is caused by a CAG repeat expansion in the IT15 gene, which results in a long stretch of polyglutamine close to the amino-terminus of the HD protein huntingtin (Htt). Mutant Htt (mHtt) has effects both in the cytoplasm and in the nucleus. In the cytoplasm, full-length mHtt can interfere with BDNF vesicular transport on microtubules. This mutant protein also may lead to abnormal endocytosis and secretion in neurons, because normal Htt form a complex with the proteins Hip1, clathrin and AP2 that are involved in endocytosis. In addition, mHtt affects Ca2+ signaling by sensitizing InsP3R1 to activation by InsP3, stimulating NR2B/NR1 NMDAR activity, and destabilizing mitochondrial Ca2+ handling. As a result, stimulation of glutamate receptors leads to supranormal Ca2+ responses in HD MSN and mitochondrial Ca2+ overload. The mHtt translocates to the nucleus, where it forms intranuclear inclusions, though they are not primarily responsible for toxicity. Nuclear toxicity is believed to be caused by interference with gene transcription, leading to loss of transcription of neuroprotective molecules such as BDNF. While mHtt binds to p53 and upregulates levels of nuclear p53 as well as p53 transcriptional activity. Augmented p53 mediates mitochondrial dysfunction.

Standard name | KEGG_PRION_DISEASES
Systematic name | M13036
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Prion diseases
Full description | Prion diseases, also termed transmissible spongiform encephalopathies (TSEs), are a group of fatal neurodegenerative diseases that affect humans and a number of other animal species. The etiology of these diseases is thought to be associated with the conversion of a normal protein, PrPC, into an infectious, pathogenic form, PrPSc. The conversion is induced by prion infections (for example, variant Creutzfeldt-Jakob disease (vCJD), iatrogenic CJD, Kuru), mutations (familial CJD, Gerstmann-Straussler-Scheinker syndrome, fatal familial insomnia (FFI)) or unknown factors (sporadic CJD (sCJD)), and is thought to occur after PrPC has reached the plasma membrane or is re-internalized for degradation. The PrPSc form shows greater protease resistance than PrPC and accumulates in affected individuals, often in the form of extracellular plaques. Pathways that may lead to neuronal death comprise oxidative stress, regulated activation of complement, ubiquitin-proteasome and endosomal-lysosomal systems, synaptic alterations and dendritic atrophy, corticosteroid response, and endoplasmic reticulum stress. In addition, the conformational transition could lead to the lost of a beneficial activity of the natively folded protein, PrPC.

Standard name | KEGG_VIBRIO_CHOLERAE_INFECTION
Systematic name | M17906
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Vibrio cholerae infection
Full description | Cholera toxin (CTX) is one of the main virulence factors of Vibrio cholerae. Once secreted, CTX B-chain (CTXB) binds to ganglioside GM1 on the surface of the host's cells. After binding takes place, the entire CTX complex is carried from plasma membrane (PM) to endoplasmic reticulum (ER). In the ER, the A-chain (CTXA) is recognized by protein disulfide isomerase (PDI), unfolded, and delivered to the membrane where the membrane-associated ER-oxidase, Ero1, oxidizes PDI to release the CTXA into the protein-conducting channel, Sec61. CTXA is then retro-translocated to the cytosol and induces water and electrolyte secretion by increasing cAMP levels via adenylate cyclase (AC) to exert toxicity. Other than CTX, Vibrio cholerae generates several toxins that are perilous to eukaryotic cells. Zonula occludens toxin (ZOT) causes tight junction disruption through protein kinase C-dependent actin polymerization. RTX toxin (RtxA) causes actin depolymerization by covalently cross-linking actin monomers into dimers, trimers, and higher multimers. Vibrio cholerae cytolysin (VCC) is an important pore-forming toxin. The assembly of VCC anion channels in cells cause vacuolization and lysis.

Standard name | KEGG_EPITHELIAL_CELL_SIGNALING_IN_HELICOBACTER_PYLORI_INFECTION
Systematic name | M16848
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Epithelial cell signaling in Helicobacter pylori infection
Full description | Two major virulence factors of H. pylori are the vacuolating cytotoxin (VacA) and the cag type-IV secretion system (T4SS) and its translocated effector protein, cytotoxin-associated antigen A (CagA). VacA binds to lipid rafts and glycosylphosphatidylinositol-anchored proteins (GPI-APs) of the target cell membrane. After insertion into the plasma membrane, VacA channels are endocytosed and eventually reach late endosomal compartments, increasing their permeability to anions with enhancement of the electrogenic vacuolar ATPase (v-ATPase) proton pump. In the presence of weak bases, osmotically active acidotropic ions will accumulate in the endosomes. This leads to water influx and vesicle swelling, an essential step in vacuole formation. In addition, it is reported that the VacA cleavage product binds to the tyrosine phosphatase receptor zeta (Ptprz) on epithelial cells and the induced signaling leads to the phosphorylation of the G protein-coupled receptor kinase-interactor 1 (Git1) and induces ulcerogenesis in mice. The other virulence factor cag T4SS mediates the translocation of the effector protein CagA, which is subsequently phosphorylated by a Src kinase. Phosphorylated CagA interacts with the protein tyrosine phosphatase SHP-2, thus stimulating its phosphatase activity. Activated SHP-2 is able to induce MAPK signalling through Ras/Raf-dependent and -independent mechanisms. Deregulation of this pathway by CagA may lead to abnormal proliferation and movement of gastric epithelial cells.

Standard name | KEGG_PATHOGENIC_ESCHERICHIA_COLI_INFECTION
Systematic name | M2333
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Pathogenic Escherichia coli infection
Full description | Eenteropathogenic E. coli (EPEC) and enterohemorrhagic E. coli (EHEC) are closely related pathogenic strains of Escherichia coli. The hallmark of EPEC/EHEC infections is induction of attaching and effacing (A/E) lesions that damage intestinal epithelial cells. The capacity to form A/E lesions is encoded mainly by the locus of enterocyte effacement (LEE) pathogenicity island. Tir, Map, EspF, EspG are known LEE-encoded effector proteins secreted via the type III secretion system, which is also LEE-encoded, into the host cell. EPEC and EHEC Tir's link the extracellular bacterium to the cell cytoskeleton. Map and EspF are involved in mitochondrion membrane permeabilization. EspG interacts with tubulins and stimulates microtubule destabilization. LEE-encoded adhesin or intimin (Eae) is exported via the general secretory pathway to the periplasm, where it is inserted into the outer membrane. In addition to Tir, two potential host cell-carried intimin receptors, beta1 integrin (ITGB1) and nucleolin (NCL), have so far been identified. The distinguishing feature of EHEC is the elaboration of Shiga-like toxin (Stx). Stx cleaves ribosomal RNA, thereby disrupting protein synthesis and killing the intoxicated epithelial or endothelial cells.

Standard name | KEGG_LEISHMANIA_INFECTION
Systematic name | M3126
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Leishmania infection
Full description | Leishmania is an intracellular protozoan parasite of macrophages that causes visceral, mucosal, and cutaneous diseases. The parasite is transmitted to humans by sandflies, where they survive and proliferate intracellularly by deactivating the macrophage. Successful infection of Leishmania is achieved by alteration of signaling events in the host cell, leading to enhanced production of the autoinhibitory molecules like TGF-beta and decreased induction of cytokines such as IL12 for protective immunity. Nitric oxide production is also inhibited. In addition, defective expression of major histocompatibility complex (MHC) genes silences subsequent T cell activation mediated by macrophages, resulting in abnormal immune responses.

Standard name | KEGG_PATHWAYS_IN_CANCER
Systematic name | M12868
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Pathways in cancer
Full description |

Standard name | KEGG_COLORECTAL_CANCER
Systematic name | M14631
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Colorectal cancer
Full description | Classically, colorectal cancer (CRC) has been believed to develop from normal mucosa through the premalignant adenoma by the step-wise accumulation of mutations. All CRC display either microsatellite instability (MSI) or chromosome instability (CIN). MSI occurs in 15% of colon cancers and results from inactivation of the DNA mismatch repair (MMR) system by either MMR gene mutations or hypermethylation of the MLH1 promoter. MSI promotes tumorigenesis through generating mutations in target genes that possess coding microsatellite repeats, such as beta-catenin, TGFBR2 and BAX. CIN is found in the majority of colon cancers and leads to a different pattern of gene alterations that contribute to tumor formation. Genes involved in CIN are those coding for APC, K-ras, SMAD4 and p53.

Standard name | KEGG_RENAL_CELL_CARCINOMA
Systematic name | M13266
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Renal cell carcinoma
Full description | Renal cell carcinoma (RCC) is a heterogenous term comprising a group of neoplasms of renal origin. There are 4 major histologic subtypes of RCC: conventional (clear cell RCC, 75%), papillary (15%), chromophobic (5%), and collecting duct (2%). Multiple genes are involved in the molecular pathogenesis of RCC. VHL is a tumor suppressor gene responsible for hereditary (von Hippel-Lindau) and sporadic variants of conventional (clear cell) RCC. In the absence of VHL, hypoxia-inducible factor alpha (HIF-alpha) accumulates, leading to production of several growth factors, including vascular endothelial growth factor and platelet-derived growth factor. An oncogene, MET has been found to be mutant in cases of hereditary papillary renal cancer (HPRC), although the incidence of c-MET mutations is low in sporadic papillary RCC. Once activated, MET mediates a number of biological effects including motility, invasion of extracellular matrix, cellular transformation, prevention of apoptosis and metastasis formation. Mutations in the fumarate hydratase (FH) gene cause hereditary leiomyomatosis and renal cancer syndrome (HLRCC) papillary renal tumors, although the incidence of FH mutations in sporadic tumors is unknown. Loss of functional FH leads to accumulation of fumarate in the cell, triggering inhibition of HPH and preventing targeted pVHL-mediated degradation of HIF-alpha. BHD mutations cause the Birt-Hogg-Dube syndrome and its associated chromophobe, hybrid oncocytic, and conventional (clear cell) RCC. The incidence of BHD mutations in sporadic renal tumors is not known.

Standard name | KEGG_PANCREATIC_CANCER
Systematic name | M9726
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Pancreatic cancer
Full description | Normal duct epithelium progresses to infiltrating cancer through a series of histologically defined precursors (PanINs). The overexpression of HER-2/neu and activating point mutations in the K-ras gene occur early, inactivation of the p16 gene at an intermediate stage, and the inactivation of p53, SMAD4, and BRCA2 occur relatively late. Activated K-ras engages multiple effector pathways. Although EGF receptors are conventionally regarded as upstream activators of RAS proteins, they can also act as RAS signal transducers via RAS-induced autocrine activation of the EGFR family ligands. Pancreatic ductal adenocarcinoma (PDA) show elevated expression of EGF receptors (e.g. HER2/neu) and their ligands (e.g.TGF-alpha) consistent with the presence of this autocrine loop. Moreover, PDA shows extensive genomic instability and aneuploidy. Telomere attrition and mutations in p53 and BRCA2 are likely to contribute to these phenotypes. Inactivation of the SMAD4 tumour suppressor gene leads to loss of the inhibitory influence of the transforming growth factor-beta signalling pathway.

Standard name | KEGG_ENDOMETRIAL_CANCER
Systematic name | M19877
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Endometrial cancer
Full description | Two types of endometrial carcinoma are distinguished with respect to biology and clinical course. Type-I carcinoma is related to hyperestrogenism by association with endometrial hyperplasia, frequent expression of estrogen and progesterone receptors and younger age, whereas type-II carcinoma is unrelated to estrogen, associated with atrophic endometrium, frequent lack of estrogen and progesterone receptors and older age. This classification has also been justified at the molecular level with Type 1 tumours being more commonly associated with abnormalities of DNA-mismatch repair genes, K-ras, PTEN and beta-catenin, and Type 2 tumours with abnormalities of p53 and HER2/neu.

Standard name | KEGG_GLIOMA
Systematic name | M1835
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Glioma
Full description | Glioblastoma multiforme (GBM) formation is either de novo (primary GBMs) or due to the progression of a lower grade glioma to a higher grade one through the acquisition of additional mutations (secondary GBMs). In primary GBM, disruption of the p53 pathway often occurs through loss of ARF, or less frequently through amplification of MDM2. Disruption of the RB pathway occurs through loss of INK4A. Amplification and/or mutation of the epidermal growth factor receptor (EGFR) is the most frequently detected genetic defect that is associated with primary GBM. In secondary GBM, loss of p53 and activation of the growth-factorreceptor-tyrosine-kinase signalling pathway (such as through overexpression of PDGF/PDGFR ) initiates tumour formation,whereas disruption of the retinoblastoma (RB) pathway contributes to the progression of tumour development. Loss of PTEN has been implicated in both pathways, although it is much more common in the pathogenesis of primary GBM.

Standard name | KEGG_PROSTATE_CANCER
Systematic name | M13191
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Prostate cancer
Full description | The identification of key molecular alterations in prostate-cancer cells implicates carcinogen defenses (GSTP1), growth-factor-signaling pathways (NKX3.1, PTEN, and p27), and androgens (AR) as critical determinants of the phenotype of prostate-cancer cells. Glutathione S-transferases (GSTP1) are detoxifying enzymes that catalyze conjunction of glutathione with harmful, electrophilic molecules, thereby protecting cells from carcinogenic factors. Cells of prostatic intraepithelial neoplasia, devoid of GSTP1, undergo genomic damage mediated by such carcinogens. NKX3.1, PTEN, and p27 regulate the growth and survival of prostate cells in the normal prostate. Inadequate levels of PTEN and NKX3.1 lead to a reduction in p27 levels and to increased proliferation and decreased apoptosis. After therapeutic reduction in the levels of testosterone and dihydrotestosterone, the emergence of androgen-independent prostate cancer has been associated with mutations in the androgen receptor (AR) that permit receptor activation by other ligands, increased expression of androgen receptors accompanying AR amplification, and ligand-independent androgen-receptor activation.

Standard name | KEGG_THYROID_CANCER
Systematic name | M523
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Thyroid cancer
Full description | Papillary thyroid carcinoma (PTC), the most frequent neoplasia originating from the thyroid epithelium, accounts for about 80% of all thyroid cancers. Chimeric oncogenes, created by chromosomal rearrangements involving prevalently RET and, to a less extent, NTRK1 loci, are implicated in the development of papillary carcinoma.These are inappropriately expressed and stimulate constitutive signaling, bypassing the need for receptor activation by growth factors. Alternatively, mutant RAS directly stimulates BRAF, whereas mutant BRAF directly stimulates MEK. Of all thyroid cancers, 15-20% are follicular thyroid carcinoma (FTC). The most distinctive molecular features of follicular carcinoma are the prominence of aneuploidy and the high prevalence of RAS mutations and PAX8-PPAR-gamma rearrangements. The PPAR-gamma rearrangement functions through a dominant-negative effect on the transcriptional activity of wild-type PPAR-gamma. The fusion oncoprotein contributes to malignant transformation by targeting several cellular pathways, some of which are normally engaged by PPAR-gamma. Most poorly differentiated and undifferentiated thyroid carcinomas are considered to derive from pre-existing well-differentiated thyroid carcinoma through additional genetic events, including beta-catenin nuclear accumulation and p53 inactivation, but de novo occurrence might also occur.

Standard name | KEGG_BASAL_CELL_CARCINOMA
Systematic name | M17807
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Basal cell carcinoma
Full description | The development of basal cell carcinoma is associated with constitutive activation of sonic hedgehog signaling. Normally, ligand-dependent signaling by Hedgehog (Hh) homologs proceeds through binding to the Patched receptor. This binding relieves the Patched-mediated inhibition of signaling through the Smoothened (SMOH) gene product. This signaling ultimately results in the dissociation of the Gli1 transcription factor from an inhibitory complex in the cytoplasm, its subsequent translocation to the nucleus, and activation of target gene expression. The mutations in SMOH, PTCH1, and SHH in BCCs result in continuous activation of target genes. At a cellular level, sonic hedgehog signaling promotes cell proliferation. Mutations in TP53 are also found with high frequency (>50%) in sporadic BCC.

Standard name | KEGG_MELANOMA
Systematic name | M15798
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Melanoma
Full description | Five distinct stages have been proposed in the evolution of melanoma on the basis of histological criteria: common acquired and congenital nevi without dysplastic changes; dysplastic nevi with structural and architectural atypia; radial-growth phase (RGP) melanoma; vertical-growth phase (VGP) melanoma; and metastatic melanoma. Oncogenic NRAS mutations activate both effector pathways Raf-MEK-ERK and PI3K-Akt. The Raf-MEK-ERK pathway may also be activated via mutations in the BRAF gene. The PI3K-Akt pathway may be activated through loss or mutation of the inhibitory tumor suppressor gene PTEN. These mutations arise early during melanoma pathogenesis and are preserved throughout tumor progression. Moreover, melanoma development is strongly associated with inactivation of the p16INK4a/CDK4,6/pRb and p14ARF/HMD2/p53 tumor suppressor pathways. The vertical-growth phase and metastatic melanoma are notable for striking changes in the control of cell adhesion. Recently, amplification of the MITF gene was demonstrated in 10% of primary melanomas and 20% of metastatic melanomas, suggesting that MITF is a melanoma oncogene.

Standard name | KEGG_BLADDER_CANCER
Systematic name | M19096
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Bladder cancer
Full description | Bladder cancer arise and progress along two distinctive pathways. The first of these is often preceded by simple and papillary hyperplasia and exhibits a tumour morphology that is low-grade, superficial and papillary. Papillary carcinoma has a tendency to recur locally, but rarely invades and metastasizes. These tumors frequently show a constitutive activation of the receptor tyrosine kinase-Ras pathway, exhibiting activating mutations in the HRAS and fibroblast growth factor receptor 3 (FGFR3) genes. The second tumour pathway is characterized by high-grade muscle-invasive tumours, which either originate from flat carcinoma in situ (CIS)/severe dysplasia or arise de novo. Over half of these tumours show defects in the tumour suppressors p53 and/or the retinoblastoma protein (RB) genes and pathways, and over 50% of these tumours progress to local and distant metastases. Some of the cell cycle-related molecules show evidence of epigenetic modulation through aberrant promoter hypermethylation in invasive bladder cancer. Invasion and metastases are promoted by several factors that alter the tumour microenvironment, including the aberrant expression of E-cadherins (E-cad), matrix metalloproteinases (MMPs), angiogenic factors such as vascular endothelial growth factor (VEGF).

Standard name | KEGG_CHRONIC_MYELOID_LEUKEMIA
Systematic name | M321
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Chronic myeloid leukemia
Full description | Chronic myelogenous leukaemia (CML) is a biphasic disease, initiated by expression of the BCR/ABL fusion gene product in self-renewing, haematopoietic stem cells (HSCs). HSCs can differentiate into common myeloid progenitors (CMPs), which then differentiate into granulocyte/macrophage progenitors (GMPs). HSCs can also differentiate into common lymphoid progenitors (CLPs), which are the progenitors of lymphocytes such as T cells and B cells. The initial chronic phase of CML (CML-CP) is characterized by a massive expansion of the granulocytic-cell series. Acquisition of additional genetic mutations beyond expression of BCR/ABL causes the progression of CML from chronic phase to blast phase (CML-BP), characterized by an accumulation of myeloid or lymphoid blast cells. The BCR/ABL fusion gene encodes p210BCR/ABL, an oncoprotein, which, unlike the normal p145 c-Abl, has constitutive tyrosine kinase activity and is predominantly localized in the cytoplasm. The tyrosine kinase activity is essential for cell transformation and the cytoplasmic localization of BCR/ABL allows the assembly of phosphorylated substrates in multiprotein complexes that transmit mitogenic and antiapoptotic signals. Additional cytogenetic and molecular changes are frequently found in patients with CML during the progression of the disease from chronic to blast phase. Some of the genetic changes include mutations in TP53, RB, and CDKN2A (also known as p16INK4A), or overexpression of genes such as EVI1. Additional chromosome translocations are also observed, such as t(3;21)(q26;q22), which generates AML1/EVI1. AML1/EVI-1 represses TGF-beta-mediated growth inhibitory signal.

Standard name | KEGG_ACUTE_MYELOID_LEUKEMIA
Systematic name | M19888
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Acute myeloid leukemia
Full description | Two major types of genetic events are crucial for the molecular pathogenesis of acute myeloid leukemias (AML) : activating mutations of signal transduction intermediates and alterations in myeloid transcription factors governing hematopoietic differentiation. Both aberrant and constitutive activation of signal transduction molecules are found in about 50% of primary AML bone marrow samples, and seem to contribute to the increased proliferation and apoptosis resistance. The most common of these activating events were observed in the RTK Flt3, in N-Ras and K-Ras, in Kit, and sporadically in other RTKs. Specific haematopoietic transcription factors are crucial for differentiation to particular lineages during normal differentiation, but are frequently disrupted in AML. Some mechanisms of disruption involve the effect of fusion proteins that are generated by chromosomal translocations on haematopoietic transcription factors. In other cases, the transcription factors themselves are mutated.

Standard name | KEGG_SMALL_CELL_LUNG_CANCER
Systematic name | M3228
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Small cell lung cancer
Full description | Small cell lung carcinoma (SCLC) is a highly aggressive neoplasm, which accounts for approximately 20% of all lung cancer cases. Molecular mechanisms altered in SCLC include induced expression of oncogene, MYC, and loss of tumorsuppressor genes, such as p53, PTEN, RB, and FHIT. The overexpression of MYC proteins in SCLC is largely a result of gene amplification. Such overexpression leads to more rapid proliferation and loss of terminal differentiation. Mutation or deletion of p53 or PTEN can lead to more rapid proliferation and reduced apoptosis. The retinoblastoma gene RB1 encodes a nuclear phosphoprotein that helps to regulate cell-cycle progression. The fragile histidine triad gene FHIT encodes the enzyme diadenosine triphosphate hydrolase, which is thought to have an indirect role in proapoptosis and cell-cycle control.

Standard name | KEGG_NON_SMALL_CELL_LUNG_CANCER
Systematic name | M19818
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Non-small cell lung cancer
Full description | Non-small-cell lung cancer (NSCLC) accounts for approximately 80% of lung cancer and represents a heterogeneous group of cancers, consisting mainly of squamous cell (SCC), adeno (AC) and large-cell carcinoma. Molecular mechanisms altered in NSCLC include activation of oncogenes, such as K-RAS and c-erbB-2, and inactivation of tumorsuppressor genes, such as p53, p16INK4a, RAR-beta, and RASSF1. Point mutations within the K-RAS gene inactivate GTPase activity and the p21-RAS protein continuously transmits growth signals to the nucleus. Overexpression of c-erbB-2 or EGFR leads to a proliferative advantage. Inactivating mutation of p53 can lead to more rapid proliferation and reduced apoptosis. The protein encoded by the p16INK4a inhibits formation of CDK-cyclin-D complexes by competitive binding of CDK4 and CDK6. Loss of p16INK4a expression is a common feature of NSCLC RAR-beta is a nuclear receptor that bears vitamin-A-dependent transcriptional activity. RASSF1A is able to form heterodimers with Nore-1, an RAS effector.Therefore loss of RASSF1A might shift the balance of RAS activity towards a growth-promoting effect.

Standard name | KEGG_ASTHMA
Systematic name | M13950
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Asthma
Full description | Inhaled allergens encounter antigen presenting cells (APC) that line the airway. Upon recognition of the antigen and activation by APC, naive T cells differentiate into TH2 cells, a process that is promoted by interleukin 4 (IL-4). Activated TH2 cells stimulate B cells to produce IgE antibodies in response to IL-4 and IL-13. IgE binds the high affinity IgE receptor at the surface of mast cells, the proliferation and differentiation of which is promoted by IL-9.The crosslinking of mast-cell-bound IgE by allergens leads to the release of biologically active mediators (histamine, leukotrienes) by means of degranulation and, so, to the immediate symptoms of allergy. Activated mast cells and Th2 cells also induce the production of IL-5. IL-5 travels to the bone marrow and regulates the differentiation and egress of eosinophils from the bone marrow into the blood. Moreover activated mast cells and Th2 cells in the lung generate the cytokines interleukin IL-4, IL-13 and tumour necrosis factor (TNF)-alpha. These cytokines stimulate the generation of eotaxin by lung epithelial cells, fibroblasts and smooth muscle cells. Eotaxin then stimulates the selective recruitment of eosinophils from the airway microvessels into the lung tissue. The activation of eosinophils leads to release of toxic granules and oxygen free radicals that lead to tissue damage and promote the development of chronic inflammation.

Standard name | KEGG_AUTOIMMUNE_THYROID_DISEASE
Systematic name | M13103
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Autoimmune thyroid disease
Full description | The classification of autoimmune throid disease (AITD) includes Hashimoto's thyroiditis (HT) or chronic autoimmune thyroiditis and its variants, Graves' disease (GD) and autoimmune atrophic thyroiditis or primary myxedema. HT is characterized by the presence of goitre, thyroid autoantibodies against thyroid peroxidase (TPO) and thyroglobulin (Tg) in serum and varying degrees of thyroid dysfunction. During HT, self-reactive CD4+ T lymphocytes (Th) recruit B cells and CD8+ T cells (CTL) into the thyroid. Disease progression leads to the death of thyroid cells and hypothyroidism. Both autoantibodies and thyroid-specific cytotoxic T lymphocytes (CTLs) have been proposed to be responsible for autoimmune thyrocyte depletion. In GD, the TSH-R is the most important autoantigen. Antibodies directed against it mimic the effects of the hormone on thyroid cells, TSH, stimulating autonomous production of thyroxine and triiodothyronine and causing hyperthyroidism. The presence of TSH-R-blocking antibodies that bind the TSH receptor in a similar fashion to the antibodies in patients with Graves' disease but that block rather than activate the receptor explains some cases of atrophic hypothyroidism.

Standard name | KEGG_SYSTEMIC_LUPUS_ERYTHEMATOSUS
Systematic name | M4741
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Systemic lupus erythematosus
Full description | Systemic lupus erythematosus (SLE) is characterized by circulating IgG autoantibodies that are specific for self-antigens, such as DNA, nuclear proteins and certain cytoplasmic components. Immune complexes comprising autoantibody and self-antigen is deposited particulary in the renal glomeruli and mediate a systemic inflammatory response by activating complement or via Fc-gamma-R-mediated neutrophil and macrophage activation. Activation of complement leads to injury both through formation of the membrane attack complex (C5b-9) or by generation of the anaphylatoxin and cell activator C5a. Neutrophils and macrophages cause tissue injury by the release of oxidants and proteases.

Standard name | KEGG_ALLOGRAFT_REJECTION
Systematic name | M18615
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Allograft rejection
Full description | After transplantation of organ allografts, there are two pathways of antigen presentation. In the direct pathway, recipient T cells react to intact allogeneic MHC molecules expressed on the surface of donor cells. This pathway would activate host CD4 or CD8 T cells. In contrast, donor MHC molecules (and all other proteins) shed from the graft can be taken up by host APCs and presented to recipient T cells in the context of self-MHC molecules - the indirect pathway. Such presentation activates predominantly CD4 T cells. A direct cytotoxic T-cell attack on graft cells can be made only by T cells that recognize the graft MHC molecules directly. Nontheless, T cells with indirect allospecificity can contribute to graft rejection by activating macrophages, which cause tissue injury and fibrosis, and are also likely to be important in the development of an alloantibody response to graft.

Standard name | KEGG_GRAFT_VERSUS_HOST_DISEASE
Systematic name | M13519
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Graft-versus-host disease
Full description | Graft-versus-host disease (GVHD) pathophysiology can be summerized in a three-step process. During step 1, the conditioning regimen (irradiation and/or chemotherapy) leads to damage, activation of host tissues and induction of inflammatory cytokines secretion. Increased expression of major histocompatibility complex (MHC) antigens and adhesion molecules leads to enhancement of the recognition of host MHC and/or minor histocompatibility antigens by mature donor T cells. Donor T-cell activation in step II is characterized by the predominance of Th1 cells and the secretion of IL-2 and IFN-gamma. These cytokines induce further T-cell expansion, induce cytotoxic T lymphocytes (CTL) and natural killer (NK) cells responses and prime additional mononuclear phagocytes to produce TNF-alpha and IL-1. Also, nitric oxide (NO) is produced by activated macrophages, and it may contribute to the tissue damage seen during step 3. Lipopolysaccharide (LPS), which leaks through the intestinal mucosa that was damaged during step 1, together with IFN-gamma, from step 2, further stimulate macrophages to secrete cytokines and NO. During step 3, the effector phase, activated CTL and NK cells mediate cytotoxicity against target host cells through Fas-Fas ligand interactions and perforin-granzyme B.

Standard name | KEGG_PRIMARY_IMMUNODEFICIENCY
Systematic name | M4085
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Primary immunodeficiency
Full description | Primary immunodeficiencies (PIs) are a heterogeneous group of disorders, which affect cellular and humoral immunity or non-specific host defense mechanisms mediated by complement proteins, and cells such as phagocytes and natural killer (NK) cells. These disorders of the immune system cause increased susceptibility to infection, autoimmune disease, and malignancy. Most of PIs are due to genetic defects that affect cell maturation or function at different levels during hematopoiesis. Disruption of the cellular immunity is observed in patients with defects in T cells or both T and B cells. These cellular immunodeficiencies comprise 20% of all PIs. Disorders of humoral immunity affect B-cell differentiation and antibody production. They account for 70% of all PIs.

Standard name | KEGG_HYPERTROPHIC_CARDIOMYOPATHY_HCM
Systematic name | M8728
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Hypertrophic cardiomyopathy (HCM)
Full description | Hypertrophic cardiomyopathy (HCM) is a primary myocardial disorder with an autosomal dominant pattern of inheritance that is characterized by hypertrophy of the left ventricles with histological features of myocyte hypertrophy, myofibrillar disarray, and interstitial fibrosis. HCM is one of the most common inherited cardiac disorders, with a prevalence in young adults of 1 in 500. Hundreds of mutations in 11 genes that encode protein constituents of the sarcomere have been identified in HCM. These mutations increase the Ca2+ sensitivity of cardiac myofilaments. Increased myofilament Ca2+ sensitivity is expected to increase the ATP utilization by actomyosin at submaximal Ca2+ concentrations, which might cause an imbalance in energy supply and demand in the heart under severe stress. The inefficient use of ATP suggests that an inability to maintain normal ATP levels could be the central abnormality. This theory might be supported by the discovery of the role of a mutant PRKAG2 gene in HCM, which in active form acts as a central sensing mechanism protecting cells from depletion of ATP supplies. The increase in the myofilament Ca2+ sensitivity well account for the diastolic dysfunction of model animals as well as human patients of HCM. It has been widely proposed that left ventricular hypertrophy is not a primary manifestation but develops as compensatory response to sarcomere dysfunction.

Standard name | KEGG_ARRHYTHMOGENIC_RIGHT_VENTRICULAR_CARDIOMYOPATHY_ARVC
Systematic name | M16376
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Arrhythmogenic right ventricular cardiomyopathy (ARVC)
Full description | Arrhythmogenic right ventricular cardiomyopathy (ARVC) is an inherited heart muscle disease that may result in arrhythmia, heart failure, and sudden death. The hallmark pathological findings are progressive myocyte loss and fibrofatty replacement, with a predilection for the right ventricle. A number of genetic studies have identified mutations in various components of the cardiac desmosome that have important roles in the pathogenesis of ARVD/C. Disruption of desmosomal function by defective proteins might lead to death of myocytes under mechanical stress. The myocardial injury may be accompanied by inflammation. Since regeneration of cardiac myocytes is limited, repair by fibrofatty replacement occurs. Several studies have implicated that desmosome dysfunction results in the delocalization and nuclear translocation of plakoglobin. As a result, competition between plakoglobin and beta-catenin will lead to the inhibition of Wnt/beta-catenin signaling, resulting in a shift from a myocyte fate towards an adipocyte fate of cells. The ryanodine receptor plays a crucial part in electromechanical coupling by control of release of calcium from the sarcoplasmic reticulum into the cytosol. Therefore, defects in this receptor could result in an imbalance of calcium homeostasis that might trigger cell death.

Standard name | KEGG_DILATED_CARDIOMYOPATHY
Systematic name | M835
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Dilated cardiomyopathy
Full description | Dilated cardiomyopathy (DCM) is a heart muscle disease characterised by dilation and impaired contraction of the left or both ventricles that results in progressive heart failure and sudden cardiac death from ventricular arrhythmia. Genetically inherited forms of DCM (familial DCM) have been identified in 25-35% of patients presenting with this disease, and the inherited gene defects are an important cause of familial DCM. The pathophysiology may be separated into two categories: defects in force generation and defects in force transmission. In cases where an underlying pathology cannot be identified, the patient is diagnosed with an idiopathic DCM. Current hypotheses regarding causes of idiopathic DCM focus on chronic viral myocarditis and/or on autoimmune abnormalities. Viral myocarditis may progress to an autoimmune phase and then to progressive cardiac dilatation. Antibodies to the beta1-adrenergic receptor (beta1AR), which are detected in a substantial number of patients with idiopathic DCM, may increase the concentration of intracellular cAMP and intracellular Ca2+, a condition often leading to a transient hyper-performance of the heart followed by depressed heart function and heart failure.

Standard name | KEGG_VIRAL_MYOCARDITIS
Systematic name | M12294
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP:KEGG
Brief description | Viral myocarditis
Full description | Myocarditis is a cardiac disease associated with inflammation and injury of the myocardium. It results from various etiologies, both noninfectious and infectious, but coxsackievirus B3 (CVB3) is still considered the dominant etiological agent. Myocarditis may be caused by direct cytopathic effects of virus, a pathologic immune response to persistent virus, or autoimmunity triggered by the viral infection. The virus enters the myocyte through internalization of the coxsackie-adenoviral receptor (CAR) and its coreceptor, decay-accelerating factor (DAF). Viral proteases cleave various proteins in the host cell. One example is viral protease 2A, which cleaves eukaryote initiation factor 4G (eIF4G) and the dystrophin protein, resulting in a complete shutdown of cap-dependent RNA translation and cytoskeletal destruction in infected cardiomyocytes, respectively. CVB3 also cleaves the member of the Bcl-2 family Bid, leading to apoptosis. CVB3 infection also induces the cleavage of cyclin D protein through a proteasome-dependent pathway, leading to the host cell-growth arrest. Viral infection and necrosis of myocytes may lead to the release of intracellular antigens, resulting in activation of self-reactive T cells. CVB infection is a significant cause of dilated cardiomyopathy (DCM) as well as myocarditis. Epidemiologically, myocarditis underlies a significant portion of patients with DCM.

Standard name | PID_FANCONI_PATHWAY
Systematic name | M1
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Fanconi anemia pathway
Full description |

Standard name | PID_SMAD2_3NUCLEAR_PATHWAY
Systematic name | M2
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of nuclear SMAD2/3 signaling
Full description |

Standard name | PID_FCER1_PATHWAY
Systematic name | M7
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Fc-epsilon receptor I signaling in mast cells
Full description |

Standard name | PID_ENDOTHELIN_PATHWAY
Systematic name | M8
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Endothelins
Full description |

Standard name | PID_BCR_5PATHWAY
Systematic name | M10
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | BCR signaling pathway
Full description |

Standard name | PID_PRL_SIGNALING_EVENTS_PATHWAY
Systematic name | M11
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by PRL
Full description |

Standard name | PID_RHOA_PATHWAY
Systematic name | M12
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | RhoA signaling pathway
Full description |

Standard name | PID_ERBB4_PATHWAY
Systematic name | M13
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | ErbB4 signaling events
Full description |

Standard name | PID_AURORA_B_PATHWAY
Systematic name | M14
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Aurora B signaling
Full description |

Standard name | PID_LYSOPHOSPHOLIPID_PATHWAY
Systematic name | M15
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | LPA receptor mediated events
Full description |

Standard name | PID_INSULIN_PATHWAY
Systematic name | M16
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Insulin Pathway
Full description |

Standard name | PID_NOTCH_PATHWAY
Systematic name | M17
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Notch signaling pathway
Full description |

Standard name | PID_INTEGRIN1_PATHWAY
Systematic name | M18
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Beta1 integrin cell surface interactions
Full description |

Standard name | PID_P73PATHWAY
Systematic name | M19
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | p73 transcription factor network
Full description |

Standard name | PID_P38_MKK3_6PATHWAY
Systematic name | M20
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | p38 MAPK signaling pathway
Full description |

Standard name | PID_GMCSF_PATHWAY
Systematic name | M22
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | GMCSF-mediated signaling events
Full description |

Standard name | PID_WNT_NONCANONICAL_PATHWAY
Systematic name | M23
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Noncanonical Wnt signaling pathway
Full description |

Standard name | PID_NFKAPPAB_ATYPICAL_PATHWAY
Systematic name | M26
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Atypical NF-kappaB pathway
Full description |

Standard name | PID_IL4_2PATHWAY
Systematic name | M28
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL4-mediated signaling events
Full description |

Standard name | PID_HDAC_CLASSII_PATHWAY
Systematic name | M30
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by HDAC Class II
Full description |

Standard name | PID_BETA_CATENIN_DEG_PATHWAY
Systematic name | M31
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Degradation of beta catenin
Full description |

Standard name | PID_HDAC_CLASSIII_PATHWAY
Systematic name | M32
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by HDAC Class III
Full description |

Standard name | PID_GLYPICAN_1PATHWAY
Systematic name | M33
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Glypican 1 network
Full description |

Standard name | PID_TCR_PATHWAY
Systematic name | M34
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | TCR signaling in na&#xef;ve CD4+ T cells
Full description |

Standard name | PID_IL27_PATHWAY
Systematic name | M36
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL27-mediated signaling events
Full description |

Standard name | PID_NFKAPPAB_CANONICAL_PATHWAY
Systematic name | M37
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Canonical NF-kappaB pathway
Full description |

Standard name | PID_E2F_PATHWAY
Systematic name | M40
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | E2F transcription factor network
Full description |

Standard name | PID_ER_NONGENOMIC_PATHWAY
Systematic name | M41
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Plasma membrane estrogen receptor signaling
Full description |

Standard name | PID_DNA_PK_PATHWAY
Systematic name | M42
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | DNA-PK pathway in nonhomologous end joining
Full description |

Standard name | PID_HIF2PATHWAY
Systematic name | M44
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | HIF-2-alpha transcription factor network
Full description |

Standard name | PID_CD40_PATHWAY
Systematic name | M45
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | CD40/CD40L signaling
Full description |

Standard name | PID_ATR_PATHWAY
Systematic name | M46
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | ATR signaling pathway
Full description |

Standard name | PID_INTEGRIN_CS_PATHWAY
Systematic name | M47
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Integrin family cell surface interactions
Full description |

Standard name | PID_MET_PATHWAY
Systematic name | M48
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by Hepatocyte Growth Factor Receptor (c-Met)
Full description |

Standard name | PID_PTP1B_PATHWAY
Systematic name | M50
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by PTP1B
Full description |

Standard name | PID_INTEGRIN3_PATHWAY
Systematic name | M53
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Beta3 integrin cell surface interactions
Full description |

Standard name | PID_IL12_2PATHWAY
Systematic name | M54
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL12-mediated signaling events
Full description |

Standard name | PID_S1P_S1P3_PATHWAY
Systematic name | M55
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | S1P3 pathway
Full description |

Standard name | PID_LPA4_PATHWAY
Systematic name | M56
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | LPA4-mediated signaling events
Full description |

Standard name | PID_AR_PATHWAY
Systematic name | M58
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Coregulation of Androgen receptor activity
Full description |

Standard name | PID_NFAT_TFPATHWAY
Systematic name | M60
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Calcineurin-regulated NFAT-dependent transcription in lymphocytes
Full description |

Standard name | PID_EPHB_FWD_PATHWAY
Systematic name | M62
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | EPHB forward signaling
Full description |

Standard name | PID_AVB3_OPN_PATHWAY
Systematic name | M63
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Osteopontin-mediated events
Full description |

Standard name | PID_S1P_S1P4_PATHWAY
Systematic name | M64
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | S1P4 pathway
Full description |

Standard name | PID_FRA_PATHWAY
Systematic name | M65
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Validated transcriptional targets of AP1 family members Fra1 and Fra2
Full description |

Standard name | PID_MYC_ACTIV_PATHWAY
Systematic name | M66
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Validated targets of C-MYC transcriptional activation
Full description |

Standard name | PID_ARF6_TRAFFICKING_PATHWAY
Systematic name | M67
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Arf6 trafficking events
Full description |

Standard name | PID_RHOA_REG_PATHWAY
Systematic name | M68
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of RhoA activity
Full description |

Standard name | PID_REELIN_PATHWAY
Systematic name | M69
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Reelin signaling pathway
Full description |

Standard name | PID_PS1_PATHWAY
Systematic name | M70
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Presenilin action in Notch and Wnt signaling
Full description |

Standard name | PID_ILK_PATHWAY
Systematic name | M71
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Integrin-linked kinase signaling
Full description |

Standard name | PID_NECTIN_PATHWAY
Systematic name | M72
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Nectin adhesion pathway
Full description |

Standard name | PID_P38_ALPHA_BETA_PATHWAY
Systematic name | M76
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of p38-alpha and p38-beta
Full description |

Standard name | PID_WNT_SIGNALING_PATHWAY
Systematic name | M77
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Wnt signaling network
Full description |

Standard name | PID_TRAIL_PATHWAY
Systematic name | M79
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | TRAIL signaling pathway
Full description |

Standard name | PID_CDC42_PATHWAY
Systematic name | M81
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | CDC42 signaling events
Full description |

Standard name | PID_RET_PATHWAY
Systematic name | M82
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events regulated by Ret tyrosine kinase
Full description |

Standard name | PID_CDC42_REG_PATHWAY
Systematic name | M83
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of CDC42 activity
Full description |

Standard name | PID_ATM_PATHWAY
Systematic name | M84
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | ATM pathway
Full description |

Standard name | PID_ARF6_PATHWAY
Systematic name | M86
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Arf6 signaling events
Full description |

Standard name | PID_LKB1_PATHWAY
Systematic name | M87
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | LKB1 signaling events
Full description |

Standard name | PID_CD8_TCR_PATHWAY
Systematic name | M88
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | TCR signaling in na&#xef;ve CD8+ T cells
Full description |

Standard name | PID_WNT_CANONICAL_PATHWAY
Systematic name | M90
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Canonical Wnt signaling pathway
Full description |

Standard name | PID_TCPTP_PATHWAY
Systematic name | M91
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by TCPTP
Full description |

Standard name | PID_ANGIOPOIETIN_RECEPTOR_PATHWAY
Systematic name | M92
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Angiopoietin receptor Tie2-mediated signaling
Full description |

Standard name | PID_FAS_PATHWAY
Systematic name | M94
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | FAS (CD95) signaling pathway
Full description |

Standard name | PID_CIRCADIAN_PATHWAY
Systematic name | M95
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Circadian rhythm pathway
Full description |

Standard name | PID_TXA2PATHWAY
Systematic name | M99
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Thromboxane A2 receptor signaling
Full description |

Standard name | PID_SHP2_PATHWAY
Systematic name | M100
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | SHP2 signaling
Full description |

Standard name | PID_HDAC_CLASSI_PATHWAY
Systematic name | M101
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by HDAC Class I
Full description |

Standard name | PID_S1P_S1P1_PATHWAY
Systematic name | M103
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | S1P1 pathway
Full description |

Standard name | PID_TELOMERASE_PATHWAY
Systematic name | M105
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of Telomerase
Full description |

Standard name | PID_HNF3B_PATHWAY
Systematic name | M106
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | FOXA2 and FOXA3 transcription factor networks
Full description |

Standard name | PID_NETRIN_PATHWAY
Systematic name | M108
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Netrin-mediated signaling events
Full description |

Standard name | PID_IL1_PATHWAY
Systematic name | M110
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL1-mediated signaling events
Full description |

Standard name | PID_NFAT_3PATHWAY
Systematic name | M113
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Role of Calcineurin-dependent NFAT signaling in lymphocytes
Full description |

Standard name | PID_REG_GR_PATHWAY
Systematic name | M115
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Glucocorticoid receptor regulatory network
Full description |

Standard name | PID_CONE_PATHWAY
Systematic name | M117
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Visual signal transduction: Cones
Full description |

Standard name | PID_INTEGRIN_A9B1_PATHWAY
Systematic name | M118
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Alpha9 beta1 integrin signaling events
Full description |

Standard name | PID_ERB_GENOMIC_PATHWAY
Systematic name | M119
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Validated nuclear estrogen receptor beta network
Full description |

Standard name | PID_ARF6_DOWNSTREAM_PATHWAY
Systematic name | M120
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Arf6 downstream pathway
Full description |

Standard name | PID_MTOR_4PATHWAY
Systematic name | M121
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | mTOR signaling pathway
Full description |

Standard name | PID_IL2_1PATHWAY
Systematic name | M122
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL2-mediated signaling events
Full description |

Standard name | PID_CXCR4_PATHWAY
Systematic name | M124
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | CXCR4-mediated signaling events
Full description |

Standard name | PID_IGF1_PATHWAY
Systematic name | M125
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IGF1 pathway
Full description |

Standard name | PID_ERBB1_RECEPTOR_PROXIMAL_PATHWAY
Systematic name | M127
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | EGF receptor (ErbB1) signaling pathway
Full description |

Standard name | PID_TNF_PATHWAY
Systematic name | M128
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | TNF receptor signaling pathway
Full description |

Standard name | PID_PLK1_PATHWAY
Systematic name | M129
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | PLK1 signaling events
Full description |

Standard name | PID_TCR_RAS_PATHWAY
Systematic name | M134
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Ras signaling in the CD4+ TCR pathway
Full description |

Standard name | PID_IL5_PATHWAY
Systematic name | M135
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL5-mediated signaling events
Full description |

Standard name | PID_FOXO_PATHWAY
Systematic name | M136
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | FoxO family signaling
Full description |

Standard name | PID_VEGF_VEGFR_PATHWAY
Systematic name | M137
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | VEGF and VEGFR signaling network
Full description |

Standard name | PID_THROMBIN_PAR4_PATHWAY
Systematic name | M138
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | PAR4-mediated thrombin signaling events
Full description |

Standard name | PID_MYC_PATHWAY
Systematic name | M139
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | C-MYC pathway
Full description |

Standard name | PID_RANBP2_PATHWAY
Systematic name | M140
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Sumoylation by RanBP2 regulates transcriptional repression
Full description |

Standard name | PID_PI3KCI_PATHWAY
Systematic name | M141
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Class I PI3K signaling events
Full description |

Standard name | PID_AJDISS_2PATHWAY
Systematic name | M142
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Posttranslational regulation of adherens junction stability and dissassembly
Full description |

Standard name | PID_IL2_PI3K_PATHWAY
Systematic name | M143
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL2 signaling events mediated by PI3K
Full description |

Standard name | PID_CERAMIDE_PATHWAY
Systematic name | M144
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Ceramide signaling pathway
Full description |

Standard name | PID_P53_DOWNSTREAM_PATHWAY
Systematic name | M145
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Direct p53 effectors
Full description |

Standard name | PID_AR_TF_PATHWAY
Systematic name | M151
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of Androgen receptor activity
Full description |

Standard name | PID_P75_NTR_PATHWAY
Systematic name | M153
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | p75(NTR)-mediated signaling
Full description |

Standard name | PID_S1P_META_PATHWAY
Systematic name | M155
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Sphingosine 1-phosphate (S1P) pathway
Full description |

Standard name | PID_ECADHERIN_NASCENT_AJ_PATHWAY
Systematic name | M156
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | E-cadherin signaling in the nascent adherens junction
Full description |

Standard name | PID_INTEGRIN4_PATHWAY
Systematic name | M158
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Alpha6 beta4 integrin-ligand interactions
Full description |

Standard name | PID_AMB2_NEUTROPHILS_PATHWAY
Systematic name | M159
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | amb2 Integrin signaling
Full description |

Standard name | PID_AVB3_INTEGRIN_PATHWAY
Systematic name | M160
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Integrins in angiogenesis
Full description |

Standard name | PID_IFNG_PATHWAY
Systematic name | M161
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IFN-gamma pathway
Full description |

Standard name | PID_RXR_VDR_PATHWAY
Systematic name | M162
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | RXR and RAR heterodimerization with other nuclear receptor
Full description |

Standard name | PID_LIS1_PATHWAY
Systematic name | M163
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Lissencephaly gene (LIS1) in neuronal migration and development
Full description |

Standard name | PID_ERBB1_DOWNSTREAM_PATHWAY
Systematic name | M164
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | ErbB1 downstream signaling
Full description |

Standard name | PID_SYNDECAN_4_PATHWAY
Systematic name | M165
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Syndecan-4-mediated signaling events
Full description |

Standard name | PID_ATF2_PATHWAY
Systematic name | M166
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | ATF-2 transcription factor network
Full description |

Standard name | PID_AP1_PATHWAY
Systematic name | M167
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | AP-1 transcription factor network
Full description |

Standard name | PID_INTEGRIN2_PATHWAY
Systematic name | M169
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Beta2 integrin cell surface interactions
Full description |

Standard name | PID_UPA_UPAR_PATHWAY
Systematic name | M174
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Urokinase-type plasminogen activator (uPA) and uPAR-mediated signaling
Full description |

Standard name | PID_ERBB2_ERBB3_PATHWAY
Systematic name | M175
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | ErbB2/ErbB3 signaling events
Full description |

Standard name | PID_FOXM1_PATHWAY
Systematic name | M176
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | FOXM1 transcription factor network
Full description |

Standard name | PID_EPHA_FWDPATHWAY
Systematic name | M177
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | EPHA forward signaling
Full description |

Standard name | PID_HIF1A_PATHWAY
Systematic name | M180
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Hypoxic and oxygen homeostasis regulation of HIF-1-alpha
Full description |

Standard name | PID_BMP_PATHWAY
Systematic name | M181
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | BMP receptor signaling
Full description |

Standard name | PID_IL3_PATHWAY
Systematic name | M182
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL3-mediated signaling events
Full description |

Standard name | PID_IL6_7_PATHWAY
Systematic name | M183
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL6-mediated signaling events
Full description |

Standard name | PID_ECADHERIN_KERATINOCYTE_PATHWAY
Systematic name | M184
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | E-cadherin signaling in keratinocytes
Full description |

Standard name | PID_ALK1_PATHWAY
Systematic name | M185
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | ALK1 signaling events
Full description |

Standard name | PID_PDGFRB_PATHWAY
Systematic name | M186
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | PDGFR-beta signaling pathway
Full description |

Standard name | PID_TRKR_PATHWAY
Systematic name | M187
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Neurotrophic factor-mediated Trk receptor signaling
Full description |

Standard name | PID_TCR_JNK_PATHWAY
Systematic name | M190
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | JNK signaling in the CD4+ TCR pathway
Full description |

Standard name | PID_NEPHRIN_NEPH1_PATHWAY
Systematic name | M193
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Nephrin/Neph1 signaling in the kidney podocyte
Full description |

Standard name | PID_CMYB_PATHWAY
Systematic name | M195
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | C-MYB transcription factor network
Full description |

Standard name | PID_IL23_PATHWAY
Systematic name | M196
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL23-mediated signaling events
Full description |

Standard name | PID_HIV_NEF_PATHWAY
Systematic name | M197
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | HIV-1 Nef: Negative effector of Fas and TNF-alpha
Full description |

Standard name | PID_SYNDECAN_1_PATHWAY
Systematic name | M198
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Syndecan-1-mediated signaling events
Full description |

Standard name | PID_P38_MK2_PATHWAY
Systematic name | M199
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | p38 signaling mediated by MAPKAP kinases
Full description |

Standard name | PID_ERA_GENOMIC_PATHWAY
Systematic name | M200
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Validated nuclear estrogen receptor alpha network
Full description |

Standard name | PID_ERBB_NETWORK_PATHWAY
Systematic name | M201
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | ErbB receptor signaling network
Full description |

Standard name | PID_ALK2_PATHWAY
Systematic name | M203
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | ALK2 signaling events
Full description |

Standard name | PID_RHODOPSIN_PATHWAY
Systematic name | M204
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Visual signal transduction: Rods
Full description |

Standard name | PID_PDGFRA_PATHWAY
Systematic name | M206
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | PDGFR-alpha signaling pathway
Full description |

Standard name | PID_RETINOIC_ACID_PATHWAY
Systematic name | M207
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Retinoic acid receptors-mediated signaling
Full description |

Standard name | PID_P38_GAMMA_DELTA_PATHWAY
Systematic name | M209
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling mediated by p38-gamma and p38-delta
Full description |

Standard name | PID_IL8_CXCR2_PATHWAY
Systematic name | M210
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL8- and CXCR2-mediated signaling events
Full description |

Standard name | PID_HEDGEHOG_2PATHWAY
Systematic name | M211
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by the Hedgehog family
Full description |

Standard name | PID_INTEGRIN5_PATHWAY
Systematic name | M212
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Beta5 beta6 beta7 and beta8 integrin cell surface interactions
Full description |

Standard name | PID_AR_NONGENOMIC_PATHWAY
Systematic name | M213
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Nongenotropic Androgen signaling
Full description |

Standard name | PID_ERBB1_INTERNALIZATION_PATHWAY
Systematic name | M214
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Internalization of ErbB1
Full description |

Standard name | PID_HEDGEHOG_GLI_PATHWAY
Systematic name | M219
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Hedgehog signaling events mediated by Gli proteins
Full description |

Standard name | PID_CASPASE_PATHWAY
Systematic name | M220
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Caspase cascade in apoptosis
Full description |

Standard name | PID_CXCR3_PATHWAY
Systematic name | M222
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | CXCR3-mediated signaling events
Full description |

Standard name | PID_BETA_CATENIN_NUC_PATHWAY
Systematic name | M223
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of nuclear beta catenin signaling and target gene transcription
Full description |

Standard name | PID_VEGFR1_PATHWAY
Systematic name | M226
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | VEGFR1 specific signals
Full description |

Standard name | PID_SMAD2_3PATHWAY
Systematic name | M228
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of cytoplasmic and nuclear SMAD2/3 signaling
Full description |

Standard name | PID_P38_ALPHA_BETA_DOWNSTREAM_PATHWAY
Systematic name | M229
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling mediated by p38-alpha and p38-beta
Full description |

Standard name | PID_KIT_PATHWAY
Systematic name | M231
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by Stem cell factor receptor (c-Kit)
Full description |

Standard name | PID_ECADHERIN_STABILIZATION_PATHWAY
Systematic name | M232
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Stabilization and expansion of the E-cadherin adherens junction
Full description |

Standard name | PID_EPO_PATHWAY
Systematic name | M233
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | EPO signaling pathway
Full description |

Standard name | PID_IL2_STAT5_PATHWAY
Systematic name | M234
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL2 signaling events mediated by STAT5
Full description |

Standard name | PID_TCR_CALCIUM_PATHWAY
Systematic name | M235
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Calcium signaling in the CD4+ TCR pathway
Full description |

Standard name | PID_DELTA_NP63_PATHWAY
Systematic name | M236
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Validated transcriptional targets of deltaNp63 isoforms
Full description |

Standard name | PID_VEGFR1_2_PATHWAY
Systematic name | M237
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by VEGFR1 and VEGFR2
Full description |

Standard name | PID_THROMBIN_PAR1_PATHWAY
Systematic name | M238
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | PAR1-mediated thrombin signaling events
Full description |

Standard name | PID_A6B1_A6B4_INTEGRIN_PATHWAY
Systematic name | M239
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | a6b1 and a6b4 Integrin signaling
Full description |

Standard name | PID_SYNDECAN_2_PATHWAY
Systematic name | M240
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Syndecan-2-mediated signaling events
Full description |

Standard name | PID_RAC1_REG_PATHWAY
Systematic name | M241
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of RAC1 activity
Full description |

Standard name | PID_AURORA_A_PATHWAY
Systematic name | M242
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Aurora A signaling
Full description |

Standard name | PID_ARF_3PATHWAY
Systematic name | M243
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Arf1 pathway
Full description |

Standard name | PID_INSULIN_GLUCOSE_PATHWAY
Systematic name | M247
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Insulin-mediated glucose transport
Full description |

Standard name | PID_PI3KCI_AKT_PATHWAY
Systematic name | M249
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Class I PI3K signaling events mediated by Akt
Full description |

Standard name | PID_SYNDECAN_3_PATHWAY
Systematic name | M251
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Syndecan-3-mediated signaling events
Full description |

Standard name | PID_IL8_CXCR1_PATHWAY
Systematic name | M252
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL8- and CXCR1-mediated signaling events
Full description |

Standard name | PID_MYC_REPRESS_PATHWAY
Systematic name | M254
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Validated targets of C-MYC transcriptional repression
Full description |

Standard name | PID_HIF1_TFPATHWAY
Systematic name | M255
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | HIF-1-alpha transcription factor network
Full description |

Standard name | PID_TAP63_PATHWAY
Systematic name | M256
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Validated transcriptional targets of TAp63 isoforms
Full description |

Standard name | PID_EPHRINB_REV_PATHWAY
Systematic name | M257
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Ephrin B reverse signaling
Full description |

Standard name | PID_BARD1_PATHWAY
Systematic name | M258
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | BARD1 signaling events
Full description |

Standard name | PID_P53_REGULATION_PATHWAY
Systematic name | M261
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | p53 pathway
Full description |

Standard name | PID_TOLL_ENDOGENOUS_PATHWAY
Systematic name | M264
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Endogenous TLR signaling
Full description |

Standard name | PID_NCADHERIN_PATHWAY
Systematic name | M266
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | N-cadherin signaling events
Full description |

Standard name | PID_ANTHRAX_PATHWAY
Systematic name | M267
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Cellular roles of Anthrax toxin
Full description |

Standard name | PID_S1P_S1P2_PATHWAY
Systematic name | M268
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | S1P2 pathway
Full description |

Standard name | PID_RAS_PATHWAY
Systematic name | M269
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of Ras family activation
Full description |

Standard name | PID_MAPK_TRK_PATHWAY
Systematic name | M270
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Trk receptor signaling mediated by the MAPK pathway
Full description |

Standard name | PID_PI3K_PLC_TRK_PATHWAY
Systematic name | M271
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Trk receptor signaling mediated by PI3K and PLC-gamma
Full description |

Standard name | PID_CD8_TCR_DOWNSTREAM_PATHWAY
Systematic name | M272
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Downstream signaling in na&#xef;ve CD8+ T cells
Full description |

Standard name | PID_EPHA2_FWD_PATHWAY
Systematic name | M273
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | EPHA2 forward signaling
Full description |

Standard name | PID_LYMPH_ANGIOGENESIS_PATHWAY
Systematic name | M274
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | VEGFR3 signaling in lymphatic endothelium
Full description |

Standard name | PID_ALPHA_SYNUCLEIN_PATHWAY
Systematic name | M275
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Alpha-synuclein signaling
Full description |

Standard name | PID_FGF_PATHWAY
Systematic name | M276
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | FGF signaling pathway
Full description |

Standard name | PID_INTEGRIN_A4B1_PATHWAY
Systematic name | M277
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Alpha4 beta1 integrin signaling events
Full description |

Standard name | PID_RAC1_PATHWAY
Systematic name | M278
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | RAC1 signaling pathway
Full description |

Standard name | PID_RB_1PATHWAY
Systematic name | M279
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Regulation of retinoblastoma protein
Full description |

Standard name | PID_FAK_PATHWAY
Systematic name | M281
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Signaling events mediated by focal adhesion kinase
Full description |

Standard name | PID_HNF3A_PATHWAY
Systematic name | M285
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | FOXA1 transcription factor network
Full description |

Standard name | PID_TGFBR_PATHWAY
Systematic name | M286
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | TGF-beta receptor signaling
Full description |

Standard name | PID_HES_HEY_PATHWAY
Systematic name | M288
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | Notch-mediated HES/HEY network
Full description |

Standard name | PID_IL12_STAT4_PATHWAY
Systematic name | M290
Organism | Homo sapiens
PMID | 18832364
Authors | Schaefer CF,Anthony K,Krupa S,Buchoff J,Day M,Hannay T,Buetow KH
Category | C2
Sub-category | CP:PID
Brief description | IL12 signaling mediated by STAT4
Full description |

Standard name | SA_B_CELL_RECEPTOR_COMPLEXES
Systematic name | M17200
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Antigen binding to B cell receptors activates protein tyrosine kinases, such as the Src family, which ultimate activate MAP kinases.
Full description |

Standard name | SIG_CD40PATHWAYMAP
Systematic name | M12705
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Genes related to CD40 signaling
Full description |

Standard name | SIG_PIP3_SIGNALING_IN_CARDIAC_MYOCTES
Systematic name | M295
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Genes related to PIP3 signaling in cardiac myocytes
Full description |

Standard name | SA_CASPASE_CASCADE
Systematic name | M7997
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Apoptosis is mediated by caspases, cysteine proteases arranged in a proteolytic cascade.
Full description |

Standard name | SIG_CHEMOTAXIS
Systematic name | M5193
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Genes related to chemotaxis
Full description |

Standard name | SIG_IL4RECEPTOR_IN_B_LYPHOCYTES
Systematic name | M1718
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Genes related to IL4 rceptor signaling in B lymphocytes
Full description |

Standard name | WNT_SIGNALING
Systematic name | M5493
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Genes related to Wnt-mediated signal transduction
Full description |

Standard name | SIG_REGULATION_OF_THE_ACTIN_CYTOSKELETON_BY_RHO_GTPASES
Systematic name | M16801
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Genes related to regulation of the actin cytoskeleton
Full description |

Standard name | SA_FAS_SIGNALING
Systematic name | M5060
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | The TNF-type receptor Fas induces apoptosis on ligand binding.
Full description |

Standard name | SA_G1_AND_S_PHASES
Systematic name | M1529
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Cdk2, 4, and 6 bind cyclin D in G1, while cdk2/cyclin E promotes the G1/S transition.
Full description |

Standard name | SIG_INSULIN_RECEPTOR_PATHWAY_IN_CARDIAC_MYOCYTES
Systematic name | M7955
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Genes related to the insulin receptor pathway
Full description |

Standard name | SIG_PIP3_SIGNALING_IN_B_LYMPHOCYTES
Systematic name | M1315
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Genes related to PIP3 signaling in B lymphocytes
Full description |

Standard name | SIG_BCR_SIGNALING_PATHWAY
Systematic name | M8626
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Members of the BCR signaling pathway
Full description |

Standard name | SA_G2_AND_M_PHASES
Systematic name | M10154
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Cdc25 activates the cdc2/cyclin B complex to induce the G2/M transition.
Full description |

Standard name | SA_MMP_CYTOKINE_CONNECTION
Systematic name | M11736
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Cytokines can induce activation of matrix metalloproteinases, which degrade extracellular matrix.
Full description |

Standard name | SA_PROGRAMMED_CELL_DEATH
Systematic name | M13096
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Programmed cell death, or apoptosis, eliminates damaged or unneeded cells.
Full description |

Standard name | SA_PTEN_PATHWAY
Systematic name | M12771
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | PTEN is a tumor suppressor that dephosphorylates the lipid messenger phosphatidylinositol triphosphate.
Full description |

Standard name | SA_REG_CASCADE_OF_CYCLIN_EXPR
Systematic name | M3686
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | Expression of cyclins regulates progression through the cell cycle by activating cyclin-dependent kinases.
Full description |

Standard name | SA_TRKA_RECEPTOR
Systematic name | M18895
Organism | Homo sapiens
PMID |
Authors |
Category | C2
Sub-category | CP
Brief description | The TrkA receptor binds nerve growth factor to activate MAP kinase pathways and promote cell growth.
Full description |

Standard name | NABA_COLLAGENS
Systematic name | M3005
Organism | Homo sapiens
PMID | 22159717
Authors | Naba A,Clauser KR,Hoersch S,Liu H,Carr SA,Hynes RO
Category | C2
Sub-category | CP
Brief description | Genes encoding collagen proteins
Full description | One hallmark of ECM proteins is their domain-based structure. Exploiting this characteristic, we established a list of diagnostic InterPro domains commonly found in ECM proteins. This domain list was used to screen the UniProt protein database. We know that some of the domains used to select positively for ECM proteins are also found in transmembrane receptors and proteins involved in cell adhesion (growth factor receptors, integrins, etc) that do not belong to the ECM. These families of proteins also display a subset of specific domains and transmembrane domains incompatible with definition as “extracellular matrix” proteins. Therefore, a second step comprised a negative selection using another set of domains and a transmembrane domain prediction. Manual curation of the matrisome lists also allowed us to add a very few known ECM proteins that do not contain any known domains. Protein-centric predictions were then converted to gene-centric lists. Finally, knowledge-based annotation of these gene lists allowed us to define subcategories within the core matrisome; namely, ECM glycoproteins, collagens, and proteoglycans. We also defined separate lists of domains commonly found in 1) ECM-affiliated proteins (proteins that share either some architectural similarities with ECM proteins or that are known to be associated with ECM proteins; 2) ECM regulators: ECM-remodeling enzymes, crosslinkers, proteases, regulators etc.; 3) secreted factors, many of which are known to bind to ECM and others that may. As for the core matrisome list, we also defined lists of domains that excluded mis-assigned proteins from these categories. Using similar bioinformatic pipelines as for the core matrisome, we defined three categories of “matrisome-associated” proteins: ECM-affiliated proteins, ECM regulators, and secreted factors.

Standard name | NABA_ECM_GLYCOPROTEINS
Systematic name | M3008
Organism | Homo sapiens
PMID | 22159717
Authors | Naba A,Clauser KR,Hoersch S,Liu H,Carr SA,Hynes RO
Category | C2
Sub-category | CP
Brief description | Genes encoding structural ECM glycoproteins
Full description | One hallmark of ECM proteins is their domain-based structure. Exploiting this characteristic, we established a list of diagnostic InterPro domains commonly found in ECM proteins. This domain list was used to screen the UniProt protein database. We know that some of the domains used to select positively for ECM proteins are also found in transmembrane receptors and proteins involved in cell adhesion (growth factor receptors, integrins, etc) that do not belong to the ECM. These families of proteins also display a subset of specific domains and transmembrane domains incompatible with definition as “extracellular matrix” proteins. Therefore, a second step comprised a negative selection using another set of domains and a transmembrane domain prediction. Manual curation of the matrisome lists also allowed us to add a very few known ECM proteins that do not contain any known domains. Protein-centric predictions were then converted to gene-centric lists. Finally, knowledge-based annotation of these gene lists allowed us to define subcategories within the core matrisome; namely, ECM glycoproteins, collagens, and proteoglycans. We also defined separate lists of domains commonly found in 1) ECM-affiliated proteins (proteins that share either some architectural similarities with ECM proteins or that are known to be associated with ECM proteins; 2) ECM regulators: ECM-remodeling enzymes, crosslinkers, proteases, regulators etc.; 3) secreted factors, many of which are known to bind to ECM and others that may. As for the core matrisome list, we also defined lists of domains that excluded mis-assigned proteins from these categories. Using similar bioinformatic pipelines as for the core matrisome, we defined three categories of “matrisome-associated” proteins: ECM-affiliated proteins, ECM regulators, and secreted factors.

Standard name | NABA_ECM_REGULATORS
Systematic name | M3468
Organism | Homo sapiens
PMID | 22159717
Authors | Naba A,Clauser KR,Hoersch S,Liu H,Carr SA,Hynes RO
Category | C2
Sub-category | CP
Brief description | Genes encoding enzymes and their regulators involved in the remodeling of the extracellular matrix
Full description | One hallmark of ECM proteins is their domain-based structure. Exploiting this characteristic, we established a list of diagnostic InterPro domains commonly found in ECM proteins. This domain list was used to screen the UniProt protein database. We know that some of the domains used to select positively for ECM proteins are also found in transmembrane receptors and proteins involved in cell adhesion (growth factor receptors, integrins, etc) that do not belong to the ECM. These families of proteins also display a subset of specific domains and transmembrane domains incompatible with definition as “extracellular matrix” proteins. Therefore, a second step comprised a negative selection using another set of domains and a transmembrane domain prediction. Manual curation of the matrisome lists also allowed us to add a very few known ECM proteins that do not contain any known domains. Protein-centric predictions were then converted to gene-centric lists. Finally, knowledge-based annotation of these gene lists allowed us to define subcategories within the core matrisome; namely, ECM glycoproteins, collagens, and proteoglycans. We also defined separate lists of domains commonly found in 1) ECM-affiliated proteins (proteins that share either some architectural similarities with ECM proteins or that are known to be associated with ECM proteins; 2) ECM regulators: ECM-remodeling enzymes, crosslinkers, proteases, regulators etc.; 3) secreted factors, many of which are known to bind to ECM and others that may. As for the core matrisome list, we also defined lists of domains that excluded mis-assigned proteins from these categories. Using similar bioinformatic pipelines as for the core matrisome, we defined three categories of “matrisome-associated” proteins: ECM-affiliated proteins, ECM regulators, and secreted factors.

Standard name | NABA_ECM_AFFILIATED
Systematic name | M5880
Organism | Homo sapiens
PMID | 22159717
Authors | Naba A,Clauser KR,Hoersch S,Liu H,Carr SA,Hynes RO
Category | C2
Sub-category | CP
Brief description | Genes encoding proteins affiliated structurally or functionally to extracellular matrix proteins
Full description | One hallmark of ECM proteins is their domain-based structure. Exploiting this characteristic, we established a list of diagnostic InterPro domains commonly found in ECM proteins. This domain list was used to screen the UniProt protein database. We know that some of the domains used to select positively for ECM proteins are also found in transmembrane receptors and proteins involved in cell adhesion (growth factor receptors, integrins, etc) that do not belong to the ECM. These families of proteins also display a subset of specific domains and transmembrane domains incompatible with definition as “extracellular matrix” proteins. Therefore, a second step comprised a negative selection using another set of domains and a transmembrane domain prediction. Manual curation of the matrisome lists also allowed us to add a very few known ECM proteins that do not contain any known domains. Protein-centric predictions were then converted to gene-centric lists. Finally, knowledge-based annotation of these gene lists allowed us to define subcategories within the core matrisome; namely, ECM glycoproteins, collagens, and proteoglycans. We also defined separate lists of domains commonly found in 1) ECM-affiliated proteins (proteins that share either some architectural similarities with ECM proteins or that are known to be associated with ECM proteins; 2) ECM regulators: ECM-remodeling enzymes, crosslinkers, proteases, regulators etc.; 3) secreted factors, many of which are known to bind to ECM and others that may. As for the core matrisome list, we also defined lists of domains that excluded mis-assigned proteins from these categories. Using similar bioinformatic pipelines as for the core matrisome, we defined three categories of “matrisome-associated” proteins: ECM-affiliated proteins, ECM regulators, and secreted factors.

Standard name | NABA_PROTEOGLYCANS
Systematic name | M5882
Organism | Homo sapiens
PMID | 22159717
Authors | Naba A,Clauser KR,Hoersch S,Liu H,Carr SA,Hynes RO
Category | C2
Sub-category | CP
Brief description | Genes encoding proteoglycans
Full description | One hallmark of ECM proteins is their domain-based structure. Exploiting this characteristic, we established a list of diagnostic InterPro domains commonly found in ECM proteins. This domain list was used to screen the UniProt protein database. We know that some of the domains used to select positively for ECM proteins are also found in transmembrane receptors and proteins involved in cell adhesion (growth factor receptors, integrins, etc) that do not belong to the ECM. These families of proteins also display a subset of specific domains and transmembrane domains incompatible with definition as “extracellular matrix” proteins. Therefore, a second step comprised a negative selection using another set of domains and a transmembrane domain prediction. Manual curation of the matrisome lists also allowed us to add a very few known ECM proteins that do not contain any known domains. Protein-centric predictions were then converted to gene-centric lists. Finally, knowledge-based annotation of these gene lists allowed us to define subcategories within the core matrisome; namely, ECM glycoproteins, collagens, and proteoglycans. We also defined separate lists of domains commonly found in 1) ECM-affiliated proteins (proteins that share either some architectural similarities with ECM proteins or that are known to be associated with ECM proteins; 2) ECM regulators: ECM-remodeling enzymes, crosslinkers, proteases, regulators etc.; 3) secreted factors, many of which are known to bind to ECM and others that may. As for the core matrisome list, we also defined lists of domains that excluded mis-assigned proteins from these categories. Using similar bioinformatic pipelines as for the core matrisome, we defined three categories of “matrisome-associated” proteins: ECM-affiliated proteins, ECM regulators, and secreted factors.

Standard name | NABA_SECRETED_FACTORS
Systematic name | M5883
Organism | Homo sapiens
PMID | 22159717
Authors | Naba A,Clauser KR,Hoersch S,Liu H,Carr SA,Hynes RO
Category | C2
Sub-category | CP
Brief description | Genes encoding secreted soluble factors
Full description | One hallmark of ECM proteins is their domain-based structure. Exploiting this characteristic, we established a list of diagnostic InterPro domains commonly found in ECM proteins. This domain list was used to screen the UniProt protein database. We know that some of the domains used to select positively for ECM proteins are also found in transmembrane receptors and proteins involved in cell adhesion (growth factor receptors, integrins, etc) that do not belong to the ECM. These families of proteins also display a subset of specific domains and transmembrane domains incompatible with definition as “extracellular matrix” proteins. Therefore, a second step comprised a negative selection using another set of domains and a transmembrane domain prediction. Manual curation of the matrisome lists also allowed us to add a very few known ECM proteins that do not contain any known domains. Protein-centric predictions were then converted to gene-centric lists. Finally, knowledge-based annotation of these gene lists allowed us to define subcategories within the core matrisome; namely, ECM glycoproteins, collagens, and proteoglycans. We also defined separate lists of domains commonly found in 1) ECM-affiliated proteins (proteins that share either some architectural similarities with ECM proteins or that are known to be associated with ECM proteins; 2) ECM regulators: ECM-remodeling enzymes, crosslinkers, proteases, regulators etc.; 3) secreted factors, many of which are known to bind to ECM and others that may. As for the core matrisome list, we also defined lists of domains that excluded mis-assigned proteins from these categories. Using similar bioinformatic pipelines as for the core matrisome, we defined three categories of “matrisome-associated” proteins: ECM-affiliated proteins, ECM regulators, and secreted factors.

Standard name | NABA_CORE_MATRISOME
Systematic name | M5884
Organism | Homo sapiens
PMID | 22159717
Authors | Naba A,Clauser KR,Hoersch S,Liu H,Carr SA,Hynes RO
Category | C2
Sub-category | CP
Brief description | Ensemble of genes encoding core extracellular matrix including ECM glycoproteins, collagens and proteoglycans
Full description | One hallmark of ECM proteins is their domain-based structure. Exploiting this characteristic, we established a list of diagnostic InterPro domains commonly found in ECM proteins. This domain list was used to screen the UniProt protein database. We know that some of the domains used to select positively for ECM proteins are also found in transmembrane receptors and proteins involved in cell adhesion (growth factor receptors, integrins, etc) that do not belong to the ECM. These families of proteins also display a subset of specific domains and transmembrane domains incompatible with definition as “extracellular matrix” proteins. Therefore, a second step comprised a negative selection using another set of domains and a transmembrane domain prediction. Manual curation of the matrisome lists also allowed us to add a very few known ECM proteins that do not contain any known domains. Protein-centric predictions were then converted to gene-centric lists. Finally, knowledge-based annotation of these gene lists allowed us to define subcategories within the core matrisome; namely, ECM glycoproteins, collagens, and proteoglycans. We also defined separate lists of domains commonly found in 1) ECM-affiliated proteins (proteins that share either some architectural similarities with ECM proteins or that are known to be associated with ECM proteins; 2) ECM regulators: ECM-remodeling enzymes, crosslinkers, proteases, regulators etc.; 3) secreted factors, many of which are known to bind to ECM and others that may. As for the core matrisome list, we also defined lists of domains that excluded mis-assigned proteins from these categories. Using similar bioinformatic pipelines as for the core matrisome, we defined three categories of “matrisome-associated” proteins: ECM-affiliated proteins, ECM regulators, and secreted factors.

Standard name | NABA_MATRISOME_ASSOCIATED
Systematic name | M5885
Organism | Homo sapiens
PMID | 22159717
Authors | Naba A,Clauser KR,Hoersch S,Liu H,Carr SA,Hynes RO
Category | C2
Sub-category | CP
Brief description | Ensemble of genes encoding ECM-associated proteins including ECM-affilaited proteins, ECM regulators and secreted factors
Full description | One hallmark of ECM proteins is their domain-based structure. Exploiting this characteristic, we established a list of diagnostic InterPro domains commonly found in ECM proteins. This domain list was used to screen the UniProt protein database. We know that some of the domains used to select positively for ECM proteins are also found in transmembrane receptors and proteins involved in cell adhesion (growth factor receptors, integrins, etc) that do not belong to the ECM. These families of proteins also display a subset of specific domains and transmembrane domains incompatible with definition as “extracellular matrix” proteins. Therefore, a second step comprised a negative selection using another set of domains and a transmembrane domain prediction. Manual curation of the matrisome lists also allowed us to add a very few known ECM proteins that do not contain any known domains. Protein-centric predictions were then converted to gene-centric lists. Finally, knowledge-based annotation of these gene lists allowed us to define subcategories within the core matrisome; namely, ECM glycoproteins, collagens, and proteoglycans. We also defined separate lists of domains commonly found in 1) ECM-affiliated proteins (proteins that share either some architectural similarities with ECM proteins or that are known to be associated with ECM proteins; 2) ECM regulators: ECM-remodeling enzymes, crosslinkers, proteases, regulators etc.; 3) secreted factors, many of which are known to bind to ECM and others that may. As for the core matrisome list, we also defined lists of domains that excluded mis-assigned proteins from these categories. Using similar bioinformatic pipelines as for the core matrisome, we defined three categories of “matrisome-associated” proteins: ECM-affiliated proteins, ECM regulators, and secreted factors.

Standard name | NABA_BASEMENT_MEMBRANES
Systematic name | M5887
Organism | Homo sapiens
PMID | 22159717
Authors | Naba A,Clauser KR,Hoersch S,Liu H,Carr SA,Hynes RO
Category | C2
Sub-category | CP
Brief description | Genes encoding structural components of basement membranes
Full description | One hallmark of ECM proteins is their domain-based structure. Exploiting this characteristic, we established a list of diagnostic InterPro domains commonly found in ECM proteins. This domain list was used to screen the UniProt protein database. We know that some of the domains used to select positively for ECM proteins are also found in transmembrane receptors and proteins involved in cell adhesion (growth factor receptors, integrins, etc) that do not belong to the ECM. These families of proteins also display a subset of specific domains and transmembrane domains incompatible with definition as “extracellular matrix” proteins. Therefore, a second step comprised a negative selection using another set of domains and a transmembrane domain prediction. Manual curation of the matrisome lists also allowed us to add a very few known ECM proteins that do not contain any known domains. Protein-centric predictions were then converted to gene-centric lists. Finally, knowledge-based annotation of these gene lists allowed us to define subcategories within the core matrisome; namely, ECM glycoproteins, collagens, and proteoglycans. We also defined separate lists of domains commonly found in 1) ECM-affiliated proteins (proteins that share either some architectural similarities with ECM proteins or that are known to be associated with ECM proteins; 2) ECM regulators: ECM-remodeling enzymes, crosslinkers, proteases, regulators etc.; 3) secreted factors, many of which are known to bind to ECM and others that may. As for the core matrisome list, we also defined lists of domains that excluded mis-assigned proteins from these categories. Using similar bioinformatic pipelines as for the core matrisome, we defined three categories of “matrisome-associated” proteins: ECM-affiliated proteins, ECM regulators, and secreted factors.

Standard name | NABA_MATRISOME
Systematic name | M5889
Organism | Homo sapiens
PMID | 22159717
Authors | Naba A,Clauser KR,Hoersch S,Liu H,Carr SA,Hynes RO
Category | C2
Sub-category | CP
Brief description | Ensemble of genes encoding extracellular matrix and extracellular matrix-associated proteins
Full description | One hallmark of ECM proteins is their domain-based structure. Exploiting this characteristic, we established a list of diagnostic InterPro domains commonly found in ECM proteins. This domain list was used to screen the UniProt protein database. We know that some of the domains used to select positively for ECM proteins are also found in transmembrane receptors and proteins involved in cell adhesion (growth factor receptors, integrins, etc) that do not belong to the ECM. These families of proteins also display a subset of specific domains and transmembrane domains incompatible with definition as “extracellular matrix” proteins. Therefore, a second step comprised a negative selection using another set of domains and a transmembrane domain prediction. Manual curation of the matrisome lists also allowed us to add a very few known ECM proteins that do not contain any known domains. Protein-centric predictions were then converted to gene-centric lists. Finally, knowledge-based annotation of these gene lists allowed us to define subcategories within the core matrisome; namely, ECM glycoproteins, collagens, and proteoglycans. We also defined separate lists of domains commonly found in 1) ECM-affiliated proteins (proteins that share either some architectural similarities with ECM proteins or that are known to be associated with ECM proteins; 2) ECM regulators: ECM-remodeling enzymes, crosslinkers, proteases, regulators etc.; 3) secreted factors, many of which are known to bind to ECM and others that may. As for the core matrisome list, we also defined lists of domains that excluded mis-assigned proteins from these categories. Using similar bioinformatic pipelines as for the core matrisome, we defined three categories of “matrisome-associated” proteins: ECM-affiliated proteins, ECM regulators, and secreted factors.

Standard name | MIR153_5P
Systematic name | M30412
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-153-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8485
Systematic name | M30413
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8485 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3662
Systematic name | M30414
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3662 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR607
Systematic name | M30415
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-607 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR616_5P
Systematic name | M30416
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-616-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR371B_5P
Systematic name | M30417
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-371b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR373_5P
Systematic name | M30418
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-373-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6867_5P
Systematic name | M30419
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6867-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12136
Systematic name | M30420
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12136 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AJ_3P_MIR548X_3P
Systematic name | M30421
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548aj-3p, hsa-miR-548x-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3646
Systematic name | M30422
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3646 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1277_5P
Systematic name | M30423
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1277-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR651_3P
Systematic name | M30424
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-651-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR335_3P
Systematic name | M30425
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-335-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR520D_5P
Systematic name | M30426
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-520d-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR524_5P
Systematic name | M30427
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-524-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AE_3P_MIR548AQ_3P
Systematic name | M30428
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ae-3p, hsa-miR-548aq-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AH_3P_MIR548AM_3P
Systematic name | M30429
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ah-3p, hsa-miR-548am-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548J_3P
Systematic name | M30430
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548j-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3658
Systematic name | M30431
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3658 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR570_3P
Systematic name | M30432
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-570-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5688
Systematic name | M30433
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5688 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4795_3P
Systematic name | M30434
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4795-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548E_5P
Systematic name | M30435
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548e-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5696
Systematic name | M30436
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5696 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR340_5P
Systematic name | M30437
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-340-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7A_3P
Systematic name | M30438
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4262
Systematic name | M30439
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4262 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR30B_5P_MIR30C_5P
Systematic name | M30440
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-30b-5p, hsa-miR-30c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR30D_5P
Systematic name | M30441
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-30d-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR30E_5P
Systematic name | M30442
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-30e-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR98_3P
Systematic name | M30443
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-98-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR30A_5P
Systematic name | M30444
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-30a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7F_1_3P
Systematic name | M30445
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7f-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7B_3P
Systematic name | M30446
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR495_3P
Systematic name | M30447
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-495-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5582_3P
Systematic name | M30448
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5582-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4729
Systematic name | M30449
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4729 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4659A_3P_MIR4659B_3P
Systematic name | M30450
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4659a-3p, hsa-miR-4659b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7_1_3P
Systematic name | M30451
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7_2_3P
Systematic name | M30452
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3671
Systematic name | M30453
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3671 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4698
Systematic name | M30454
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4698 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR95_5P
Systematic name | M30455
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-95-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1468_3P
Systematic name | M30456
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1468-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548N
Systematic name | M30457
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548n in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4328
Systematic name | M30458
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4328 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548D_3P
Systematic name | M30459
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548d-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548H_3P_MIR548Z
Systematic name | M30460
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548h-3p, hsa-miR-548z in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR302C_5P
Systematic name | M30461
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-302c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548BB_3P
Systematic name | M30462
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548bb-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AC
Systematic name | M30463
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ac in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548P
Systematic name | M30464
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR23A_3P_MIR23B_3P
Systematic name | M30465
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-23a-3p, hsa-miR-23b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR23C
Systematic name | M30466
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-23c in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6809_3P
Systematic name | M30467
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6809-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR559
Systematic name | M30468
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-559 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3121_3P
Systematic name | M30469
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3121-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1297
Systematic name | M30470
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1297 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AR_3P
Systematic name | M30471
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ar-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10527_5P
Systematic name | M30472
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10527-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3529_3P
Systematic name | M30473
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3529-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4728_5P
Systematic name | M30474
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4728-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR19A_3P
Systematic name | M30475
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-19a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AW
Systematic name | M30476
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548aw in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR106B_5P
Systematic name | M30477
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-106b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR19B_3P
Systematic name | M30478
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-19b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AA_MIR548AP_3P_MIR548T_3P
Systematic name | M30479
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548aa, hsa-miR-548ap-3p, hsa-miR-548t-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR20A_5P
Systematic name | M30480
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-20a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9983_3P
Systematic name | M30481
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9983-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR506_3P
Systematic name | M30482
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-506-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR579_3P
Systematic name | M30483
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-579-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR124_3P
Systematic name | M30484
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-124-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3680_3P
Systematic name | M30485
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3680-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR664B_3P
Systematic name | M30486
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-664b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR186_5P
Systematic name | M30487
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-186-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR181A_5P_MIR181B_5P
Systematic name | M30488
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-181a-5p, hsa-miR-181b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR181D_5P
Systematic name | M30489
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-181d-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR181C_5P
Systematic name | M30490
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-181c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4719
Systematic name | M30491
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4719 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4753_3P
Systematic name | M30492
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4753-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4666A_3P
Systematic name | M30493
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4666a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR126_5P
Systematic name | M30494
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-126-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548Y
Systematic name | M30495
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548y in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4668_5P
Systematic name | M30496
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4668-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR551B_5P
Systematic name | M30497
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-551b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548BB_5P
Systematic name | M30498
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548bb-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AR_5P
Systematic name | M30499
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ar-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7C_3P
Systematic name | M30500
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AD_5P_MIR548AE_5P_MIR548AY_5P_MIR548B_5P_MIR548D_5P
Systematic name | M30501
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ad-5p, hsa-miR-548ae-5p, hsa-miR-548ay-5p, hsa-miR-548b-5p, hsa-miR-548d-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AK_MIR548AM_5P_MIR548C_5P_MIR548H_5P_MIR548O_5P_MIR548AU_5P
Systematic name | M30502
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ak, hsa-miR-548am-5p, hsa-miR-548c-5p, hsa-miR-548h-5p, hsa-miR-548o-5p, hsa-miR-548au-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548O_5P_MIR548W
Systematic name | M30503
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548o-5p, hsa-miR-548w in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR144_3P
Systematic name | M30504
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-144-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AB
Systematic name | M30505
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ab in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AS_5P
Systematic name | M30506
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548as-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1250_3P
Systematic name | M30507
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1250-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548A_5P
Systematic name | M30508
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AQ_5P
Systematic name | M30509
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548aq-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR513A_3P_MIR513C_3P
Systematic name | M30510
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-513a-3p, hsa-miR-513c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548I
Systematic name | M30511
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548i in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AP_5P_MIR548J_5P
Systematic name | M30512
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ap-5p, hsa-miR-548j-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4482_3P
Systematic name | M30513
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4482-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR106A_5P
Systematic name | M30514
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-106a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6785_5P
Systematic name | M30515
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6785-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR17_5P
Systematic name | M30516
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-17-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR561_3P
Systematic name | M30517
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-561-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR627_3P
Systematic name | M30518
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-627-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR429
Systematic name | M30519
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-429 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR182_5P
Systematic name | M30520
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-182-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1305
Systematic name | M30521
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1305 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR20B_5P
Systematic name | M30522
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-20b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR27A_3P_MIR27B_3P
Systematic name | M30523
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-27a-3p, hsa-miR-27b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR93_5P
Systematic name | M30524
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-93-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR526B_3P
Systematic name | M30525
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-526b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR519D_3P
Systematic name | M30526
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-519d-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9985
Systematic name | M30527
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9985 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3133
Systematic name | M30528
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3133 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR450B_5P
Systematic name | M30529
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-450b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548F_3P
Systematic name | M30530
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548f-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3143
Systematic name | M30531
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3143 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4803
Systematic name | M30532
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4803 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548BC
Systematic name | M30533
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548bc in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AZ_3P
Systematic name | M30534
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548az-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548A_3P
Systematic name | M30535
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4306
Systematic name | M30536
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4306 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR15A_5P
Systematic name | M30537
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-15a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4495
Systematic name | M30538
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4495 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548E_3P
Systematic name | M30539
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548e-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR195_5P
Systematic name | M30540
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-195-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR15B_5P
Systematic name | M30541
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-15b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR200B_3P
Systematic name | M30542
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-200b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR16_5P
Systematic name | M30543
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-16-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR200C_3P
Systematic name | M30544
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-200c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3065_5P
Systematic name | M30545
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3065-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR137_3P
Systematic name | M30546
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-137-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12123
Systematic name | M30547
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12123 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1283
Systematic name | M30548
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1283 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR338_5P
Systematic name | M30549
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-338-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3688_3P
Systematic name | M30550
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3688-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4422
Systematic name | M30551
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4422 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR300
Systematic name | M30552
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-300 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4261
Systematic name | M30553
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4261 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR101_3P
Systematic name | M30554
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-101-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR381_3P
Systematic name | M30555
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-381-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR655_3P
Systematic name | M30556
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-655-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR374C_5P
Systematic name | M30557
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-374c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4307
Systematic name | M30558
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4307 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR656_3P
Systematic name | M30559
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-656-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5680
Systematic name | M30560
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5680 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR129_5P
Systematic name | M30561
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-129-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6124
Systematic name | M30562
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6124 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7110_3P
Systematic name | M30563
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7110-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548F_5P
Systematic name | M30564
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548f-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AJ_5P_MIR548G_5P_MIR548X_5P
Systematic name | M30565
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548aj-5p, hsa-miR-548g-5p, hsa-miR-548x-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR494_3P
Systematic name | M30566
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-494-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR196A_1_3P
Systematic name | M30567
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-196a-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR32_5P
Systematic name | M30568
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-32-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR33A_3P
Systematic name | M30569
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-33a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6838_5P
Systematic name | M30570
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6838-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR92A_3P
Systematic name | M30571
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-92a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8068
Systematic name | M30572
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8068 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR374A_5P
Systematic name | M30573
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-374a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR92B_3P
Systematic name | M30574
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-92b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3606_3P
Systematic name | M30575
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3606-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR944
Systematic name | M30576
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-944 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6833_3P
Systematic name | M30577
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6833-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6825_5P
Systematic name | M30578
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6825-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR26A_5P
Systematic name | M30579
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-26a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR149_3P
Systematic name | M30580
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-149-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR26B_5P
Systematic name | M30581
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-26b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR424_5P
Systematic name | M30582
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-424-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR497_5P
Systematic name | M30583
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-497-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6885_3P
Systematic name | M30584
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6885-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AZ_5P
Systematic name | M30585
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548az-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548T_5P
Systematic name | M30586
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548t-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5692B_MIR5692C
Systematic name | M30587
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5692b, hsa-miR-5692c in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4672
Systematic name | M30588
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4672 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR205_3P
Systematic name | M30589
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-205-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4500
Systematic name | M30590
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4500 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6835_3P
Systematic name | M30591
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6835-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR493_5P
Systematic name | M30592
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-493-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR141_3P
Systematic name | M30593
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-141-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR200A_3P
Systematic name | M30594
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-200a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4531
Systematic name | M30595
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4531 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR466
Systematic name | M30596
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-466 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7159_5P
Systematic name | M30597
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7159-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6875_3P
Systematic name | M30598
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6875-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR664A_3P
Systematic name | M30599
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-664a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR545_3P
Systematic name | M30600
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-545-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4492
Systematic name | M30601
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4492 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4311
Systematic name | M30602
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4311 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR539_5P
Systematic name | M30603
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-539-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6873_3P
Systematic name | M30604
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6873-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6883_5P
Systematic name | M30605
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6883-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7856_5P
Systematic name | M30606
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7856-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4699_3P
Systematic name | M30607
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4699-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9_5P
Systematic name | M30608
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4251
Systematic name | M30609
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4251 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4799_5P
Systematic name | M30610
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4799-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR302E
Systematic name | M30611
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-302e in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR128_3P
Systematic name | M30612
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-128-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4755_5P
Systematic name | M30613
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4755-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR510_3P
Systematic name | M30614
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-510-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR216A_3P
Systematic name | M30615
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-216a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR367_3P
Systematic name | M30616
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-367-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR363_3P
Systematic name | M30617
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-363-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4789_3P
Systematic name | M30618
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4789-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR582_5P
Systematic name | M30619
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-582-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR454_3P
Systematic name | M30620
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-454-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5006_3P
Systematic name | M30621
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5006-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR25_3P
Systematic name | M30622
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-25-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AT_5P
Systematic name | M30623
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548at-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1185_1_3P_MIR1185_2_3P
Systematic name | M30624
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1185-1-3p, hsa-miR-1185-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR203A_3P
Systematic name | M30625
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-203a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR576_5P
Systematic name | M30626
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-576-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR30D_3P
Systematic name | M30627
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-30d-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR204_5P
Systematic name | M30628
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-204-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR211_5P
Systematic name | M30629
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-211-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AN
Systematic name | M30630
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548an in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4789_5P
Systematic name | M30631
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4789-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR587
Systematic name | M30632
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-587 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR96_5P
Systematic name | M30633
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-96-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548L
Systematic name | M30634
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548l in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR30E_3P
Systematic name | M30635
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-30e-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR30A_3P
Systematic name | M30636
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-30a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1827
Systematic name | M30637
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1827 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1252_5P
Systematic name | M30638
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1252-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7F_2_3P
Systematic name | M30639
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7f-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8063
Systematic name | M30640
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8063 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6507_5P
Systematic name | M30641
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6507-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4477A
Systematic name | M30642
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4477a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3924
Systematic name | M30643
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3924 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4465
Systematic name | M30644
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4465 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4652_3P
Systematic name | M30645
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4652-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3941
Systematic name | M30646
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3941 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR374B_5P
Systematic name | M30647
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-374b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4291
Systematic name | M30648
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4291 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6504_3P
Systematic name | M30649
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6504-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR130A_3P
Systematic name | M30650
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-130a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5590_3P
Systematic name | M30651
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5590-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3714
Systematic name | M30652
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3714 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR142_5P
Systematic name | M30653
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-142-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4533
Systematic name | M30654
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4533 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR130A_5P
Systematic name | M30655
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-130a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3119
Systematic name | M30656
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3119 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR130B_3P
Systematic name | M30657
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-130b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7106_5P
Systematic name | M30658
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7106-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3120_3P
Systematic name | M30659
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3120-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4295
Systematic name | M30660
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4295 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4694_3P
Systematic name | M30661
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4694-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3059_5P
Systematic name | M30662
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3059-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR301A_3P
Systematic name | M30663
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-301a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR301B_3P
Systematic name | M30664
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-301b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6721_5P
Systematic name | M30665
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6721-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4768_5P
Systematic name | M30666
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4768-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10399_5P
Systematic name | M30667
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10399-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3910
Systematic name | M30668
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3910 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3666
Systematic name | M30669
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3666 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4516
Systematic name | M30670
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4516 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6508_5P
Systematic name | M30671
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6508-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR448
Systematic name | M30672
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-448 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1299
Systematic name | M30673
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1299 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6844
Systematic name | M30674
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6844 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1207_5P
Systematic name | M30675
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1207-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR147B_5P
Systematic name | M30676
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-147b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3686
Systematic name | M30677
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3686 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR511_5P
Systematic name | M30678
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-511-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4319
Systematic name | M30679
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4319 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR218_5P
Systematic name | M30680
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-218-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3942_3P
Systematic name | M30681
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3942-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1323
Systematic name | M30682
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1323 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR410_3P
Systematic name | M30683
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-410-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR29B_3P_MIR29C_3P
Systematic name | M30684
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-29b-3p, hsa-miR-29c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR29A_3P
Systematic name | M30685
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-29a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR369_3P
Systematic name | M30686
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-369-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1271_5P
Systematic name | M30687
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1271-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3609
Systematic name | M30688
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3609 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR206
Systematic name | M30689
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-206 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR519C_3P
Systematic name | M30690
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-519c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4760_3P
Systematic name | M30691
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4760-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12133
Systematic name | M30692
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12133 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR519A_3P_MIR519B_3P
Systematic name | M30693
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-519a-3p, hsa-miR-519b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR148A_3P
Systematic name | M30694
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-148a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1_3P
Systematic name | M30695
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR513A_5P
Systematic name | M30696
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-513a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR152_3P
Systematic name | M30697
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-152-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR148B_3P
Systematic name | M30698
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-148b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4446_5P
Systematic name | M30699
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4446-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9_3P
Systematic name | M30700
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3681_3P
Systematic name | M30701
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3681-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5010_3P
Systematic name | M30702
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5010-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AH_5P
Systematic name | M30703
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ah-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5700
Systematic name | M30704
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5700 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4503
Systematic name | M30705
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4503 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5584_5P
Systematic name | M30706
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5584-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR875_3P
Systematic name | M30707
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-875-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6780B_5P
Systematic name | M30708
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6780b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR545_5P
Systematic name | M30709
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-545-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4725_3P
Systematic name | M30710
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4725-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4447
Systematic name | M30711
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4447 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1252_3P
Systematic name | M30712
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1252-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR519E_5P
Systematic name | M30713
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-519e-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR330_3P
Systematic name | M30714
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-330-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AV_5P_MIR548K
Systematic name | M30715
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548av-5p, hsa-miR-548k in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4310
Systematic name | M30716
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4310 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3692_3P
Systematic name | M30717
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3692-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12124
Systematic name | M30718
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12124 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3919
Systematic name | M30719
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3919 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4766_5P
Systematic name | M30720
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4766-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR515_5P
Systematic name | M30721
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-515-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8054
Systematic name | M30722
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8054 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4668_3P
Systematic name | M30723
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4668-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR543
Systematic name | M30724
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-543 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR670_3P
Systematic name | M30725
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-670-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4762_3P
Systematic name | M30726
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4762-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7B_5P
Systematic name | M30727
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR577
Systematic name | M30728
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-577 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7A_5P_LET_7C_5P_LET_7E_5P
Systematic name | M30729
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7a-5p, hsa-let-7c-5p, hsa-let-7e-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7I_5P
Systematic name | M30730
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7i-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7F_5P
Systematic name | M30731
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7f-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7G_5P
Systematic name | M30732
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7g-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR98_5P
Systematic name | M30733
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-98-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6868_3P
Systematic name | M30734
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6868-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4441
Systematic name | M30735
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4441 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR208B_5P
Systematic name | M30736
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-208b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8067
Systematic name | M30737
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8067 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5003_3P
Systematic name | M30738
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5003-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1275
Systematic name | M30739
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1275 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5196_5P
Systematic name | M30740
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5196-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR208A_5P
Systematic name | M30741
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-208a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3180_5P
Systematic name | M30742
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3180-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR892C_5P
Systematic name | M30743
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-892c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR586
Systematic name | M30744
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-586 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR513B_5P
Systematic name | M30745
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-513b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4644
Systematic name | M30746
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4644 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548O_3P
Systematic name | M30747
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548o-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1290
Systematic name | M30748
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1290 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5582_5P
Systematic name | M30749
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5582-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR32_3P
Systematic name | M30750
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-32-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR153_3P
Systematic name | M30751
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-153-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR185_5P
Systematic name | M30752
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-185-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4263
Systematic name | M30753
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4263 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1200
Systematic name | M30754
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1200 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR889_3P
Systematic name | M30755
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-889-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR34A_5P
Systematic name | M30756
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-34a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6074
Systematic name | M30757
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6074 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR449A
Systematic name | M30758
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-449a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6739_5P
Systematic name | M30759
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6739-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6083
Systematic name | M30760
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6083 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3619_5P
Systematic name | M30761
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3619-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR380_3P
Systematic name | M30762
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-380-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR613
Systematic name | M30763
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-613 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR195_3P
Systematic name | M30764
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-195-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR16_2_3P
Systematic name | M30765
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-16-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6733_5P
Systematic name | M30766
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6733-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4747_5P
Systematic name | M30767
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4747-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7151_3P
Systematic name | M30768
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7151-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR302A_3P_MIR302B_3P_MIR302C_3P_MIR302D_3P
Systematic name | M30769
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-302a-3p, hsa-miR-302b-3p, hsa-miR-302c-3p, hsa-miR-302d-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4677_5P
Systematic name | M30770
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4677-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AS_3P
Systematic name | M30771
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548as-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4505
Systematic name | M30772
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4505 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7154_5P
Systematic name | M30773
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7154-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5195_3P
Systematic name | M30774
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5195-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3617_5P
Systematic name | M30775
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3617-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3202
Systematic name | M30776
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3202 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9902
Systematic name | M30777
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9902 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR641
Systematic name | M30778
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-641 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4458
Systematic name | M30779
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4458 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3973
Systematic name | M30780
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3973 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7A_2_3P
Systematic name | M30781
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7a-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR105_5P
Systematic name | M30782
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-105-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4477B
Systematic name | M30783
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4477b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5580_3P
Systematic name | M30784
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5580-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR320A_3P_MIR320B_MIR320C_MIR320D
Systematic name | M30785
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-320a-3p, hsa-miR-320b, hsa-miR-320c, hsa-miR-320d in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7D_5P
Systematic name | M30786
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7d-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7152_5P
Systematic name | M30787
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7152-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR145_5P
Systematic name | M30788
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-145-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4429
Systematic name | M30789
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4429 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4801
Systematic name | M30790
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4801 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7G_3P
Systematic name | M30791
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7g-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7853_5P
Systematic name | M30792
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7853-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4528
Systematic name | M30793
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4528 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2115_3P
Systematic name | M30794
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2115-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3145_3P
Systematic name | M30795
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3145-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR507
Systematic name | M30796
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-507 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3125
Systematic name | M30797
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3125 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4276
Systematic name | M30798
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4276 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4496
Systematic name | M30799
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4496 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR372_5P
Systematic name | M30800
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-372-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7159_3P
Systematic name | M30801
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7159-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5787
Systematic name | M30802
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5787 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR888_5P
Systematic name | M30803
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-888-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR497_3P
Systematic name | M30804
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-497-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1284
Systematic name | M30805
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1284 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4680_3P
Systematic name | M30806
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4680-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4778_3P
Systematic name | M30807
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4778-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR580_5P
Systematic name | M30808
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-580-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR765
Systematic name | M30809
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-765 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6756_5P
Systematic name | M30810
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6756-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR568
Systematic name | M30811
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-568 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR135A_5P
Systematic name | M30812
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-135a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3978
Systematic name | M30813
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3978 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR24_3P
Systematic name | M30814
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-24-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR589_3P
Systematic name | M30815
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-589-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR520A_3P
Systematic name | M30816
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-520a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR372_3P
Systematic name | M30817
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-372-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4303
Systematic name | M30818
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4303 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR520D_3P
Systematic name | M30819
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-520d-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3182
Systematic name | M30820
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3182 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4427
Systematic name | M30821
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4427 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4325
Systematic name | M30822
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4325 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548G_3P
Systematic name | M30823
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548g-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR520B_3P_MIR520C_3P_MIR520E_3P
Systematic name | M30824
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-520b-3p, hsa-miR-520c-3p, hsa-miR-520e-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2052
Systematic name | M30825
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2052 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3123
Systematic name | M30826
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3123 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR135B_5P
Systematic name | M30827
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-135b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5002_5P
Systematic name | M30828
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5002-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7_5P
Systematic name | M30829
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR518A_5P_MIR527
Systematic name | M30830
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-518a-5p, hsa-miR-527 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5093
Systematic name | M30831
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5093 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR519D_5P
Systematic name | M30832
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-519d-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4666A_5P
Systematic name | M30833
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4666a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR373_3P
Systematic name | M30834
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-373-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4731_5P
Systematic name | M30835
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4731-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4763_3P
Systematic name | M30836
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4763-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR377_3P
Systematic name | M30837
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-377-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5683
Systematic name | M30838
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5683 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4723_5P
Systematic name | M30839
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4723-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12135
Systematic name | M30840
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12135 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR125B_5P
Systematic name | M30841
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-125b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR125A_5P
Systematic name | M30842
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-125a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3916
Systematic name | M30843
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3916 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6870_5P
Systematic name | M30844
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6870-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6832_3P
Systematic name | M30845
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6832-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6766_5P
Systematic name | M30846
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6766-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2113
Systematic name | M30847
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2113 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10522_5P
Systematic name | M30848
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10522-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR520F_5P
Systematic name | M30849
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-520f-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3140_3P
Systematic name | M30850
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3140-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR205_5P
Systematic name | M30851
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-205-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR214_3P
Systematic name | M30852
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-214-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6878_5P
Systematic name | M30853
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6878-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4524A_3P
Systematic name | M30854
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4524a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4703_5P
Systematic name | M30855
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4703-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6859_5P
Systematic name | M30856
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6859-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7157_5P
Systematic name | M30857
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7157-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR323A_3P
Systematic name | M30858
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-323a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR498_5P
Systematic name | M30859
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-498-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6077
Systematic name | M30860
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6077 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4742_3P
Systematic name | M30861
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4742-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR659_3P
Systematic name | M30862
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-659-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7111_5P
Systematic name | M30863
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7111-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3915
Systematic name | M30864
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3915 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR539_3P
Systematic name | M30865
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-539-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5698
Systematic name | M30866
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5698 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6764_5P
Systematic name | M30867
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6764-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4498
Systematic name | M30868
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4498 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3124_3P
Systematic name | M30869
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3124-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR766_5P
Systematic name | M30870
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-766-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6778_3P
Systematic name | M30871
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6778-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR485_3P
Systematic name | M30872
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-485-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR181B_2_3P_MIR181B_3P
Systematic name | M30873
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-181b-2-3p, hsa-miR-181b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10523_5P
Systematic name | M30874
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10523-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6817_3P
Systematic name | M30875
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6817-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR519A_2_5P_MIR520B_5P
Systematic name | M30876
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-519a-2-5p, hsa-miR-520b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR625_5P
Systematic name | M30877
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-625-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR670_5P
Systematic name | M30878
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-670-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6780A_5P
Systematic name | M30879
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6780a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR761
Systematic name | M30880
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-761 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6830_5P
Systematic name | M30881
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6830-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4271
Systematic name | M30882
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4271 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8085
Systematic name | M30883
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8085 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR557
Systematic name | M30884
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-557 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6731_5P
Systematic name | M30885
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6731-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8084
Systematic name | M30886
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8084 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4470
Systematic name | M30887
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4470 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4517
Systematic name | M30888
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4517 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR580_3P
Systematic name | M30889
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-580-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4692
Systematic name | M30890
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4692 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR130B_5P
Systematic name | M30891
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-130b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7977
Systematic name | M30892
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7977 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3153
Systematic name | M30893
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3153 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4743_3P
Systematic name | M30894
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4743-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6516_5P
Systematic name | M30895
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6516-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR450A_1_3P
Systematic name | M30896
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-450a-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR942_5P
Systematic name | M30897
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-942-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR29B_2_5P
Systematic name | M30898
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-29b-2-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR452_5P
Systematic name | M30899
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-452-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR34C_5P
Systematic name | M30900
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-34c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR155_5P
Systematic name | M30901
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-155-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4420
Systematic name | M30902
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4420 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3160_5P
Systematic name | M30903
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3160-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7160_5P
Systematic name | M30904
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7160-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3185
Systematic name | M30905
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3185 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4731_3P
Systematic name | M30906
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4731-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4272
Systematic name | M30907
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4272 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548M
Systematic name | M30908
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548m in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6876_5P
Systematic name | M30909
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6876-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4279
Systematic name | M30910
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4279 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR605_3P
Systematic name | M30911
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-605-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1303
Systematic name | M30912
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1303 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4760_5P
Systematic name | M30913
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4760-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR146A_3P
Systematic name | M30914
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-146a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR449B_5P
Systematic name | M30915
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-449b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6783_3P
Systematic name | M30916
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6783-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR302F
Systematic name | M30917
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-302f in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR92A_2_5P
Systematic name | M30918
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-92a-2-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR488_3P
Systematic name | M30919
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-488-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR518C_5P
Systematic name | M30920
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-518c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12131
Systematic name | M30921
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12131 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR298
Systematic name | M30922
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-298 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4476
Systematic name | M30923
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4476 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR892C_3P
Systematic name | M30924
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-892c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR302B_5P
Systematic name | M30925
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-302b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4267
Systematic name | M30926
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4267 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6830_3P
Systematic name | M30927
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6830-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6127
Systematic name | M30928
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6127 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6515_3P
Systematic name | M30929
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6515-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12122
Systematic name | M30930
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12122 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5003_5P
Systematic name | M30931
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5003-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR544A
Systematic name | M30932
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-544a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4676_3P
Systematic name | M30933
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4676-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR578
Systematic name | M30934
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-578 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR29A_5P
Systematic name | M30935
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-29a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4324
Systematic name | M30936
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4324 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4700_5P
Systematic name | M30937
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4700-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR302D_5P
Systematic name | M30938
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-302d-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR133A_3P_MIR133B
Systematic name | M30939
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-133a-3p, hsa-miR-133b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR212_3P
Systematic name | M30940
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-212-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3685
Systematic name | M30941
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3685 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AV_3P
Systematic name | M30942
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548av-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR877_3P
Systematic name | M30943
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-877-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4744
Systematic name | M30944
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4744 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4524A_5P
Systematic name | M30945
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4524a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4524B_5P
Systematic name | M30946
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4524b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3942_5P
Systematic name | M30947
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3942-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR224_3P
Systematic name | M30948
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-224-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6505_5P
Systematic name | M30949
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6505-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR183_5P
Systematic name | M30950
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-183-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5703
Systematic name | M30951
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5703 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR302A_5P
Systematic name | M30952
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-302a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6853_3P
Systematic name | M30953
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6853-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR552_5P
Systematic name | M30954
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-552-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR194_5P
Systematic name | M30955
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-194-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6739_3P
Systematic name | M30956
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6739-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR132_3P
Systematic name | M30957
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-132-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR122B_5P
Systematic name | M30958
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-122b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR221_3P
Systematic name | M30959
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-221-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR608
Systematic name | M30960
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-608 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4768_3P
Systematic name | M30961
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4768-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4651
Systematic name | M30962
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4651 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4773
Systematic name | M30963
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4773 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR379_3P_MIR411_3P
Systematic name | M30964
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-379-3p, hsa-miR-411-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR522_3P
Systematic name | M30965
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-522-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7515
Systematic name | M30966
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7515 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR222_3P
Systematic name | M30967
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-222-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR202_3P
Systematic name | M30968
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-202-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR629_3P
Systematic name | M30969
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-629-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1285_3P
Systematic name | M30970
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1285-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2053
Systematic name | M30971
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2053 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR103A_3P_MIR107
Systematic name | M30972
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-103a-3p, hsa-miR-107 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4434
Systematic name | M30973
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4434 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4283
Systematic name | M30974
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4283 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR217_5P
Systematic name | M30975
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-217-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4297
Systematic name | M30976
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4297 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR16_1_3P
Systematic name | M30977
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-16-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR499A_5P
Systematic name | M30978
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-499a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4796_3P
Systematic name | M30979
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4796-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR183_3P
Systematic name | M30980
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-183-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR636
Systematic name | M30981
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-636 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR139_5P
Systematic name | M30982
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-139-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR345_3P
Systematic name | M30983
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-345-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4782_5P
Systematic name | M30984
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4782-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12120
Systematic name | M30985
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12120 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6129
Systematic name | M30986
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6129 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5706
Systematic name | M30987
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5706 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6133
Systematic name | M30988
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6133 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR20A_3P
Systematic name | M30989
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-20a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7161_5P
Systematic name | M30990
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7161-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4735_5P
Systematic name | M30991
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4735-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4510
Systematic name | M30992
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4510 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4643
Systematic name | M30993
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4643 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6130
Systematic name | M30994
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6130 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6722_3P
Systematic name | M30995
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6722-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3065_3P
Systematic name | M30996
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3065-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1276
Systematic name | M30997
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1276 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4684_5P
Systematic name | M30998
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4684-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6768_5P
Systematic name | M30999
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6768-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR361_5P
Systematic name | M31000
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-361-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4742_5P
Systematic name | M31001
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4742-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8065
Systematic name | M31002
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8065 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1236_3P
Systematic name | M31003
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1236-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4713_5P
Systematic name | M31004
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4713-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5701
Systematic name | M31005
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5701 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6797_5P
Systematic name | M31006
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6797-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3679_3P
Systematic name | M31007
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3679-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4778_5P
Systematic name | M31008
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4778-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR514B_5P
Systematic name | M31009
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-514b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR11181_3P
Systematic name | M31010
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-11181-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR187_5P
Systematic name | M31011
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-187-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4802_3P
Systematic name | M31012
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4802-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR520E_5P
Systematic name | M31013
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-520e-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6882_5P
Systematic name | M31014
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6882-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8061
Systematic name | M31015
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8061 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6881_3P
Systematic name | M31016
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6881-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1249_5P
Systematic name | M31017
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1249-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5197_5P
Systematic name | M31018
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5197-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6852_5P
Systematic name | M31019
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6852-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8066
Systematic name | M31020
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8066 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1273H_5P
Systematic name | M31021
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1273h-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4534
Systematic name | M31022
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4534 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10394_5P
Systematic name | M31023
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10394-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2054
Systematic name | M31024
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2054 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR138_2_3P
Systematic name | M31025
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-138-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7162_3P
Systematic name | M31026
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7162-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4738_3P
Systematic name | M31027
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4738-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6808_5P
Systematic name | M31028
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6808-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR513C_5P
Systematic name | M31029
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-513c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6815_3P
Systematic name | M31030
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6815-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4704_3P
Systematic name | M31031
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4704-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7157_3P
Systematic name | M31032
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7157-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6893_5P
Systematic name | M31033
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6893-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3158_5P
Systematic name | M31034
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3158-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6715B_5P
Systematic name | M31035
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6715b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR603
Systematic name | M31036
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-603 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR520G_3P_MIR520H
Systematic name | M31037
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-520g-3p, hsa-miR-520h in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR421
Systematic name | M31038
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-421 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR583
Systematic name | M31039
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-583 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR486_3P
Systematic name | M31040
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-486-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6511A_5P
Systematic name | M31041
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6511a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4671_3P
Systematic name | M31042
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4671-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AO_5P_MIR548AX
Systematic name | M31043
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ao-5p, hsa-miR-548ax in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR143_3P_MIR4770
Systematic name | M31044
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-143-3p, hsa-miR-4770 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6737_3P
Systematic name | M31045
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6737-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4709_3P
Systematic name | M31046
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4709-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR297
Systematic name | M31047
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-297 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR940
Systematic name | M31048
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-940 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7844_5P
Systematic name | M31049
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7844-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2110
Systematic name | M31050
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2110 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7110_5P
Systematic name | M31051
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7110-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR138_5P
Systematic name | M31052
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-138-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4514
Systematic name | M31053
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4514 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4270
Systematic name | M31054
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4270 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4478
Systematic name | M31055
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4478 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1208
Systematic name | M31056
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1208 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5189_5P
Systematic name | M31057
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5189-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5689
Systematic name | M31058
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5689 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12119
Systematic name | M31059
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12119 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR150_5P
Systematic name | M31060
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-150-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8087
Systematic name | M31061
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8087 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1205
Systematic name | M31062
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1205 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1915_3P
Systematic name | M31063
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1915-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9500
Systematic name | M31064
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9500 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3925_3P
Systematic name | M31065
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3925-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4269
Systematic name | M31066
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4269 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR224_5P
Systematic name | M31067
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-224-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1910_3P
Systematic name | M31068
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1910-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4649_3P
Systematic name | M31069
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4649-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4255
Systematic name | M31070
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4255 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6128
Systematic name | M31071
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6128 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR544B
Systematic name | M31072
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-544b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6770_5P
Systematic name | M31073
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6770-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3064_3P
Systematic name | M31074
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3064-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3926
Systematic name | M31075
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3926 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4288
Systematic name | M31076
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4288 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR520F_3P
Systematic name | M31077
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-520f-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR299_5P
Systematic name | M31078
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-299-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6071
Systematic name | M31079
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6071 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5197_3P
Systematic name | M31080
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5197-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3175
Systematic name | M31081
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3175 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR499B_3P
Systematic name | M31082
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-499b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR646
Systematic name | M31083
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-646 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548BA
Systematic name | M31084
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ba in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AI_MIR570_5P
Systematic name | M31085
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ai, hsa-miR-570-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6828_5P
Systematic name | M31086
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6828-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR499A_3P
Systematic name | M31087
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-499a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR676_5P
Systematic name | M31088
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-676-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8070
Systematic name | M31089
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8070 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1279
Systematic name | M31090
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1279 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7113_5P
Systematic name | M31091
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7113-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6779_5P
Systematic name | M31092
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6779-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6842_5P
Systematic name | M31093
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6842-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AG
Systematic name | M31094
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ag in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6887_3P
Systematic name | M31095
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6887-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4275
Systematic name | M31096
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4275 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2681_5P
Systematic name | M31097
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2681-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1343_3P
Systematic name | M31098
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1343-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5193
Systematic name | M31099
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5193 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR19A_5P
Systematic name | M31100
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-19a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5682
Systematic name | M31101
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5682 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7162_5P
Systematic name | M31102
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7162-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5571_5P
Systematic name | M31103
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5571-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR19B_1_5P_MIR19B_2_5P
Systematic name | M31104
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-19b-1-5p, hsa-miR-19b-2-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4443
Systematic name | M31105
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4443 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR511_3P
Systematic name | M31106
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-511-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR330_5P
Systematic name | M31107
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-330-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5589_3P
Systematic name | M31108
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5589-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5581_3P
Systematic name | M31109
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5581-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR501_5P
Systematic name | M31110
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-501-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR516A_3P_MIR516B_3P
Systematic name | M31111
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-516a-3p, hsa-miR-516b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2467_3P
Systematic name | M31112
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2467-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3977
Systematic name | M31113
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3977 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4784
Systematic name | M31114
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4784 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR498_3P
Systematic name | M31115
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-498-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR142_3P
Systematic name | M31116
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-142-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR371A_5P
Systematic name | M31117
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-371a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7114_5P
Systematic name | M31118
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7114-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3191_5P
Systematic name | M31119
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3191-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR29B_1_5P
Systematic name | M31120
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-29b-1-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3150B_3P
Systematic name | M31121
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3150b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR30B_3P
Systematic name | M31122
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-30b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR513B_3P
Systematic name | M31123
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-513b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR509_5P
Systematic name | M31124
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-509-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR223_5P
Systematic name | M31125
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-223-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5009_3P
Systematic name | M31126
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5009-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR103A_2_5P
Systematic name | M31127
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-103a-2-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4786_3P
Systematic name | M31128
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4786-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3689A_3P_MIR3689B_3P_MIR3689C
Systematic name | M31129
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3689a-3p, hsa-miR-3689b-3p, hsa-miR-3689c in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4426
Systematic name | M31130
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4426 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR222_5P
Systematic name | M31131
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-222-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR22_5P
Systematic name | M31132
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-22-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548U
Systematic name | M31133
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548u in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4762_5P
Systematic name | M31134
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4762-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4451
Systematic name | M31135
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4451 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4679
Systematic name | M31136
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4679 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3611
Systematic name | M31137
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3611 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12132
Systematic name | M31138
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12132 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6761_5P
Systematic name | M31139
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6761-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR509_3_5P
Systematic name | M31140
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-509-3-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR451B
Systematic name | M31141
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-451b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR922
Systematic name | M31142
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-922 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR619_5P
Systematic name | M31143
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-619-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4753_5P
Systematic name | M31144
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4753-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR103A_1_5P
Systematic name | M31145
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-103a-1-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5681A
Systematic name | M31146
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5681a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4452
Systematic name | M31147
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4452 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR939_3P
Systematic name | M31148
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-939-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1184
Systematic name | M31149
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1184 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR500A_5P
Systematic name | M31150
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-500a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR30C_2_3P
Systematic name | M31151
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-30c-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4504
Systematic name | M31152
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4504 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR374B_3P
Systematic name | M31153
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-374b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3925_5P
Systematic name | M31154
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3925-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1245B_3P
Systematic name | M31155
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1245b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR561_5P
Systematic name | M31156
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-561-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR762
Systematic name | M31157
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-762 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR376C_3P
Systematic name | M31158
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-376c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4666B
Systematic name | M31159
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4666b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6807_3P
Systematic name | M31160
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6807-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6740_3P
Systematic name | M31161
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6740-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6792_5P
Systematic name | M31162
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6792-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4667_5P
Systematic name | M31163
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4667-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6795_5P
Systematic name | M31164
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6795-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR936
Systematic name | M31165
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-936 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4511
Systematic name | M31166
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4511 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR767_5P
Systematic name | M31167
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-767-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR504_3P
Systematic name | M31168
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-504-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR374A_3P
Systematic name | M31169
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-374a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR188_3P
Systematic name | M31170
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-188-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548V
Systematic name | M31171
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548v in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6887_5P
Systematic name | M31172
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6887-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5001_5P
Systematic name | M31173
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5001-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6516_3P
Systematic name | M31174
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6516-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6839_3P
Systematic name | M31175
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6839-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6780A_3P
Systematic name | M31176
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6780a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3192_5P
Systematic name | M31177
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3192-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR423_5P
Systematic name | M31178
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-423-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7156_5P
Systematic name | M31179
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7156-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3667_3P
Systematic name | M31180
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3667-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR216A_5P
Systematic name | M31181
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-216a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4665_5P
Systematic name | M31182
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4665-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6513_3P
Systematic name | M31183
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6513-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR185_3P
Systematic name | M31184
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-185-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4646_5P
Systematic name | M31185
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4646-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4424
Systematic name | M31186
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4424 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2116_5P
Systematic name | M31187
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2116-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4776_3P
Systematic name | M31188
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4776-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3664_3P
Systematic name | M31189
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3664-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR199A_5P
Systematic name | M31190
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-199a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR30C_1_3P
Systematic name | M31191
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-30c-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6847_5P
Systematic name | M31192
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6847-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6715A_3P
Systematic name | M31193
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6715a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5584_3P
Systematic name | M31194
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5584-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR199B_5P
Systematic name | M31195
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-199b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10393_5P
Systematic name | M31196
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10393-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR642A_3P_MIR642B_3P
Systematic name | M31197
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-642a-3p, hsa-miR-642b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR122B_3P
Systematic name | M31198
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-122b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3652
Systematic name | M31199
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3652 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3187_5P
Systematic name | M31200
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3187-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR661
Systematic name | M31201
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-661 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4499
Systematic name | M31202
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4499 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR186_3P
Systematic name | M31203
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-186-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AU_3P
Systematic name | M31204
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548au-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4481
Systematic name | M31205
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4481 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR21_5P
Systematic name | M31206
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-21-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6752_3P
Systematic name | M31207
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6752-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10395_3P
Systematic name | M31208
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10395-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3177_5P
Systematic name | M31209
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3177-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR21_3P
Systematic name | M31210
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-21-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8089
Systematic name | M31211
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8089 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR876_5P
Systematic name | M31212
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-876-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4766_3P
Systematic name | M31213
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4766-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR520A_5P
Systematic name | M31214
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-520a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6788_5P
Systematic name | M31215
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6788-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3920
Systematic name | M31216
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3920 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4682
Systematic name | M31217
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4682 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1253
Systematic name | M31218
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1253 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR633
Systematic name | M31219
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-633 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5008_3P
Systematic name | M31220
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5008-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4436B_5P
Systematic name | M31221
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4436b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR496
Systematic name | M31222
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-496 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6840_3P
Systematic name | M31223
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6840-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR556_3P
Systematic name | M31224
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-556-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2276_3P
Systematic name | M31225
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2276-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR766_3P
Systematic name | M31226
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-766-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12128
Systematic name | M31227
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12128 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR892A
Systematic name | M31228
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-892a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR525_5P
Systematic name | M31229
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-525-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6509_3P
Systematic name | M31230
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6509-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1251_3P
Systematic name | M31231
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1251-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR329_5P
Systematic name | M31232
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-329-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9851_3P
Systematic name | M31233
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9851-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR150_3P
Systematic name | M31234
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-150-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2117
Systematic name | M31235
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2117 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR891B
Systematic name | M31236
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-891b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4779
Systematic name | M31237
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4779 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4430
Systematic name | M31238
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4430 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR190A_5P
Systematic name | M31239
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-190a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3606_5P
Systematic name | M31240
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3606-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR433_3P
Systematic name | M31241
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-433-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4635
Systematic name | M31242
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4635 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4677_3P
Systematic name | M31243
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4677-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6728_3P
Systematic name | M31244
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6728-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4318
Systematic name | M31245
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4318 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6818_3P
Systematic name | M31246
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6818-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR376A_3P_MIR376B_3P
Systematic name | M31247
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-376a-3p, hsa-miR-376b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3692_5P
Systematic name | M31248
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3692-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6860
Systematic name | M31249
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6860 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1909_3P
Systematic name | M31250
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1909-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6088
Systematic name | M31251
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6088 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR542_3P
Systematic name | M31252
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-542-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4670_3P
Systematic name | M31253
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4670-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6512_5P
Systematic name | M31254
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6512-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4716_5P
Systematic name | M31255
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4716-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR190B_5P
Systematic name | M31256
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-190b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR190B_3P
Systematic name | M31257
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-190b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6799_5P
Systematic name | M31258
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6799-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR204_3P
Systematic name | M31259
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-204-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6852_3P
Systematic name | M31260
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6852-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR653_3P
Systematic name | M31261
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-653-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4724_5P
Systematic name | M31262
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4724-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5006_5P
Systematic name | M31263
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5006-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6752_5P
Systematic name | M31264
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6752-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4640_5P
Systematic name | M31265
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4640-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6791_5P
Systematic name | M31266
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6791-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6733_3P
Systematic name | M31267
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6733-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4705
Systematic name | M31268
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4705 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5001_3P
Systematic name | M31269
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5001-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1237_3P
Systematic name | M31270
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1237-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3128
Systematic name | M31271
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3128 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3689A_5P_MIR3689B_5P_MIR3689E_MIR3689F
Systematic name | M31272
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3689a-5p, hsa-miR-3689b-5p, hsa-miR-3689e, hsa-miR-3689f in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6719_3P
Systematic name | M31273
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6719-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4673
Systematic name | M31274
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4673 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4722_5P
Systematic name | M31275
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4722-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5691_MIR6805_3P
Systematic name | M31276
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5691, hsa-miR-6805-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6809_5P
Systematic name | M31277
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6809-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6783_5P
Systematic name | M31278
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6783-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6501_3P
Systematic name | M31279
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6501-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6884_5P
Systematic name | M31280
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6884-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6716_5P
Systematic name | M31281
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6716-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6730_5P
Systematic name | M31282
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6730-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR491_3P
Systematic name | M31283
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-491-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR612
Systematic name | M31284
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-612 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3129_5P
Systematic name | M31285
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3129-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5579_3P
Systematic name | M31286
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5579-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4653_5P
Systematic name | M31287
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4653-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR17_3P
Systematic name | M31288
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-17-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR33A_5P_MIR33B_5P
Systematic name | M31289
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-33a-5p, hsa-miR-33b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4684_3P
Systematic name | M31290
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4684-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12129
Systematic name | M31291
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12129 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR623
Systematic name | M31292
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-623 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR935
Systematic name | M31293
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-935 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR199A_3P_MIR199B_3P
Systematic name | M31294
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-199a-3p, hsa-miR-199b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4456
Systematic name | M31295
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4456 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3149
Systematic name | M31296
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3149 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4797_5P
Systematic name | M31297
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4797-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR342_3P
Systematic name | M31298
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-342-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8076
Systematic name | M31299
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8076 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1207_3P
Systematic name | M31300
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1207-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3921
Systematic name | M31301
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3921 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1294
Systematic name | M31302
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1294 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR125B_2_3P
Systematic name | M31303
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-125b-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR708_3P
Systematic name | M31304
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-708-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3168
Systematic name | M31305
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3168 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR197_3P
Systematic name | M31306
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-197-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5590_5P
Systematic name | M31307
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5590-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3678_3P
Systematic name | M31308
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3678-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7111_3P
Systematic name | M31309
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7111-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2115_5P
Systematic name | M31310
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2115-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8082
Systematic name | M31311
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8082 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR605_5P
Systematic name | M31312
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-605-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3184_5P
Systematic name | M31313
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3184-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4418
Systematic name | M31314
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4418 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9986
Systematic name | M31315
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9986 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR567
Systematic name | M31316
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-567 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4530
Systematic name | M31317
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4530 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4292
Systematic name | M31318
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4292 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR337_3P
Systematic name | M31319
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-337-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4755_3P
Systematic name | M31320
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4755-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR593_3P
Systematic name | M31321
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-593-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR516B_5P
Systematic name | M31322
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-516b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6079
Systematic name | M31323
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6079 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR34B_3P
Systematic name | M31324
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-34b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR760
Systematic name | M31325
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-760 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3976
Systematic name | M31326
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3976 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR181A_2_3P
Systematic name | M31327
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-181a-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6132
Systematic name | M31328
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6132 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR593_5P
Systematic name | M31329
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-593-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1825
Systematic name | M31330
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1825 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR450A_2_3P
Systematic name | M31331
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-450a-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1321
Systematic name | M31332
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1321 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6738_3P
Systematic name | M31333
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6738-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR223_3P
Systematic name | M31334
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-223-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4316
Systematic name | M31335
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4316 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6845_3P
Systematic name | M31336
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6845-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4660
Systematic name | M31337
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4660 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR219A_5P
Systematic name | M31338
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-219a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6766_3P
Systematic name | M31339
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6766-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR888_3P
Systematic name | M31340
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-888-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4782_3P
Systematic name | M31341
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4782-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4691_3P
Systematic name | M31342
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4691-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4739
Systematic name | M31343
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4739 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4701_5P
Systematic name | M31344
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4701-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR588
Systematic name | M31345
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-588 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3688_5P
Systematic name | M31346
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3688-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3674
Systematic name | M31347
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3674 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1913
Systematic name | M31348
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1913 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6165
Systematic name | M31349
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6165 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5190
Systematic name | M31350
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5190 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6836_5P
Systematic name | M31351
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6836-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4428
Systematic name | M31352
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4428 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6720_5P
Systematic name | M31353
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6720-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR148A_5P
Systematic name | M31354
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-148a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4257
Systematic name | M31355
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4257 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR31_5P
Systematic name | M31356
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-31-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR671_5P
Systematic name | M31357
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-671-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR485_5P
Systematic name | M31358
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-485-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3074_5P
Systematic name | M31359
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3074-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3085_3P
Systematic name | M31360
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3085-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4756_5P
Systematic name | M31361
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4756-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3064_5P
Systematic name | M31362
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3064-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6792_3P
Systematic name | M31363
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6792-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6512_3P
Systematic name | M31364
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6512-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR758_3P
Systematic name | M31365
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-758-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1304_5P
Systematic name | M31366
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1304-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8080
Systematic name | M31367
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8080 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR452_3P
Systematic name | M31368
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-452-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3190_3P
Systematic name | M31369
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3190-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR651_5P
Systematic name | M31370
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-651-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4277
Systematic name | M31371
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4277 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1179
Systematic name | M31372
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1179 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR600
Systematic name | M31373
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-600 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6715B_3P
Systematic name | M31374
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6715b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1248
Systematic name | M31375
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1248 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR93_3P
Systematic name | M31376
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-93-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6842_3P
Systematic name | M31377
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6842-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3663_3P
Systematic name | M31378
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3663-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4685_3P
Systematic name | M31379
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4685-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4645_3P
Systematic name | M31380
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4645-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5585_5P
Systematic name | M31381
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5585-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5007_3P
Systematic name | M31382
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5007-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2355_5P
Systematic name | M31383
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2355-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4693_5P
Systematic name | M31384
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4693-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6891_5P
Systematic name | M31385
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6891-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4287
Systematic name | M31386
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4287 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4720_3P
Systematic name | M31387
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4720-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR216B_3P
Systematic name | M31388
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-216b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR143_5P
Systematic name | M31389
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-143-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR215_3P
Systematic name | M31390
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-215-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6760_5P
Systematic name | M31391
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6760-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6134
Systematic name | M31392
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6134 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4777_5P
Systematic name | M31393
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4777-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR140_3P
Systematic name | M31394
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-140-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5004_3P
Systematic name | M31395
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5004-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR887_5P
Systematic name | M31396
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-887-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3179
Systematic name | M31397
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3179 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1264
Systematic name | M31398
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1264 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6504_5P
Systematic name | M31399
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6504-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1343_5P
Systematic name | M31400
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1343-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3154
Systematic name | M31401
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3154 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4314
Systematic name | M31402
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4314 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1304_3P
Systematic name | M31403
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1304-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4302
Systematic name | M31404
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4302 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6768_3P
Systematic name | M31405
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6768-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR491_5P
Systematic name | M31406
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-491-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1324
Systematic name | M31407
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1324 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR487A_3P
Systematic name | M31408
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-487a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8062
Systematic name | M31409
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8062 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4691_5P
Systematic name | M31410
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4691-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4520_2_3P
Systematic name | M31411
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4520-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR505_3P
Systematic name | M31412
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-505-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6839_5P
Systematic name | M31413
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6839-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4650_3P
Systematic name | M31414
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4650-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR154_3P
Systematic name | M31415
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-154-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1206
Systematic name | M31416
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1206 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4728_3P
Systematic name | M31417
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4728-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR653_5P
Systematic name | M31418
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-653-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6749_3P
Systematic name | M31419
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6749-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR802
Systematic name | M31420
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-802 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3167
Systematic name | M31421
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3167 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR590_5P
Systematic name | M31422
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-590-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3129_3P
Systematic name | M31423
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3129-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR149_5P
Systematic name | M31424
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-149-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6499_3P
Systematic name | M31425
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6499-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4472
Systematic name | M31426
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4472 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4457
Systematic name | M31427
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4457 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4308
Systematic name | M31428
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4308 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7153_5P
Systematic name | M31429
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7153-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4667_3P
Systematic name | M31430
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4667-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3140_5P
Systematic name | M31431
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3140-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6734_3P
Systematic name | M31432
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6734-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR939_5P
Systematic name | M31433
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-939-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR665
Systematic name | M31434
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-665 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1301_3P_MIR5047
Systematic name | M31435
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1301-3p, hsa-miR-5047 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR889_5P
Systematic name | M31436
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-889-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1257
Systematic name | M31437
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1257 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6833_5P
Systematic name | M31438
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6833-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4699_5P
Systematic name | M31439
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4699-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9718
Systematic name | M31440
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9718 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5088_3P
Systematic name | M31441
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5088-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR660_3P
Systematic name | M31442
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-660-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR196A_3P
Systematic name | M31443
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-196a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR384
Systematic name | M31444
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-384 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR629_5P
Systematic name | M31445
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-629-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR136_5P
Systematic name | M31446
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-136-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6837_5P
Systematic name | M31447
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6837-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5697
Systematic name | M31448
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5697 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR133A_5P
Systematic name | M31449
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-133a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3157_5P
Systematic name | M31450
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3157-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7850_5P
Systematic name | M31451
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7850-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR146A_5P
Systematic name | M31452
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-146a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6873_5P
Systematic name | M31453
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6873-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4455
Systematic name | M31454
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4455 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4756_3P
Systematic name | M31455
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4756-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR146B_5P
Systematic name | M31456
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-146b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR326
Systematic name | M31457
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-326 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR890
Systematic name | M31458
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-890 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5583_5P
Systematic name | M31459
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5583-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4273
Systematic name | M31460
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4273 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR338_3P
Systematic name | M31461
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-338-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR124_5P
Systematic name | M31462
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-124-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR200A_5P
Systematic name | M31463
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-200a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR200B_5P
Systematic name | M31464
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-200b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR378A_5P
Systematic name | M31465
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-378a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6081
Systematic name | M31466
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6081 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3908
Systematic name | M31467
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3908 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR942_3P
Systematic name | M31468
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-942-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6776_5P
Systematic name | M31469
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6776-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR767_3P
Systematic name | M31470
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-767-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1537_5P
Systematic name | M31471
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1537-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6818_5P
Systematic name | M31472
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6818-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12125
Systematic name | M31473
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12125 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR217_3P
Systematic name | M31474
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-217-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR335_5P
Systematic name | M31475
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-335-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR526B_5P
Systematic name | M31476
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-526b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR585_5P
Systematic name | M31477
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-585-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4685_5P
Systematic name | M31478
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4685-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548S
Systematic name | M31479
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548s in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5089_5P
Systematic name | M31480
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5089-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR361_3P
Systematic name | M31481
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-361-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4709_5P
Systematic name | M31482
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4709-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR541_5P
Systematic name | M31483
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-541-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3682_5P
Systematic name | M31484
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3682-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4436B_3P
Systematic name | M31485
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4436b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR449C_5P
Systematic name | M31486
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-449c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR506_5P
Systematic name | M31487
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-506-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6787_3P
Systematic name | M31488
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6787-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6814_5P
Systematic name | M31489
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6814-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR582_3P
Systematic name | M31490
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-582-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4483
Systematic name | M31491
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4483 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6754_5P
Systematic name | M31492
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6754-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8060
Systematic name | M31493
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8060 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7112_3P
Systematic name | M31494
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7112-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR18A_5P_MIR18B_5P
Systematic name | M31495
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-18a-5p, hsa-miR-18b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3164
Systematic name | M31496
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3164 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR873_5P
Systematic name | M31497
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-873-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6879_5P
Systematic name | M31498
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6879-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR34B_5P
Systematic name | M31499
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-34b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4796_5P
Systematic name | M31500
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4796-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR365A_3P_MIR365B_3P
Systematic name | M31501
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-365a-3p, hsa-miR-365b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5087
Systematic name | M31502
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5087 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5004_5P
Systematic name | M31503
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5004-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6757_3P
Systematic name | M31504
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6757-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4700_3P
Systematic name | M31505
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4700-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9851_5P
Systematic name | M31506
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9851-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR487A_5P
Systematic name | M31507
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-487a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3668
Systematic name | M31508
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3668 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6507_3P
Systematic name | M31509
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6507-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3159
Systematic name | M31510
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3159 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR487B_5P
Systematic name | M31511
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-487b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6889_3P
Systematic name | M31512
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6889-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3660
Systematic name | M31513
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3660 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR597_3P
Systematic name | M31514
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-597-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR891A_3P
Systematic name | M31515
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-891a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6867_3P
Systematic name | M31516
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6867-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR362_3P
Systematic name | M31517
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-362-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR499B_5P
Systematic name | M31518
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-499b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6735_5P
Systematic name | M31519
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6735-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4526
Systematic name | M31520
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4526 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR876_3P
Systematic name | M31521
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-876-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3911
Systematic name | M31522
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3911 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1183
Systematic name | M31523
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1183 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4727_5P
Systematic name | M31524
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4727-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6828_3P
Systematic name | M31525
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6828-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6758_3P
Systematic name | M31526
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6758-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5690
Systematic name | M31527
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5690 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6778_5P
Systematic name | M31528
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6778-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4999_5P
Systematic name | M31529
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4999-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6824_3P
Systematic name | M31530
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6824-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR432_5P
Systematic name | M31531
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-432-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR155_3P
Systematic name | M31532
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-155-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6758_5P
Systematic name | M31533
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6758-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR329_3P
Systematic name | M31534
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-329-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6764_3P
Systematic name | M31535
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6764-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1227_5P
Systematic name | M31536
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1227-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10A_5P_MIR10B_5P
Systematic name | M31537
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10a-5p, hsa-miR-10b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6736_3P
Systematic name | M31538
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6736-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7849_3P
Systematic name | M31539
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7849-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4697_3P
Systematic name | M31540
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4697-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR558
Systematic name | M31541
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-558 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2467_5P
Systematic name | M31542
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2467-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2355_3P
Systematic name | M31543
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2355-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR301B_5P
Systematic name | M31544
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-301b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6762_3P
Systematic name | M31545
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6762-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6747_3P
Systematic name | M31546
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6747-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6509_5P
Systematic name | M31547
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6509-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7161_3P
Systematic name | M31548
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7161-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4736
Systematic name | M31549
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4736 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6073
Systematic name | M31550
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6073 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5187_5P
Systematic name | M31551
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5187-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1233_5P
Systematic name | M31552
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1233-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR106A_3P
Systematic name | M31553
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-106a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3116
Systematic name | M31554
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3116 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4326
Systematic name | M31555
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4326 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6820_3P
Systematic name | M31556
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6820-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5580_5P
Systematic name | M31557
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5580-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4317
Systematic name | M31558
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4317 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6513_5P
Systematic name | M31559
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6513-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4716_3P
Systematic name | M31560
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4716-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6794_5P
Systematic name | M31561
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6794-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR654_5P
Systematic name | M31562
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-654-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3612
Systematic name | M31563
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3612 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR301A_5P
Systematic name | M31564
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-301a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7843_5P
Systematic name | M31565
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7843-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6506_5P
Systematic name | M31566
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6506-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5699_5P
Systematic name | M31567
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5699-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4645_5P
Systematic name | M31568
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4645-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6799_3P
Systematic name | M31569
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6799-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6760_3P
Systematic name | M31570
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6760-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12113
Systematic name | M31571
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12113 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4264
Systematic name | M31572
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4264 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1_5P
Systematic name | M31573
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7150
Systematic name | M31574
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7150 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR650
Systematic name | M31575
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-650 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR885_5P
Systematic name | M31576
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-885-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6126
Systematic name | M31577
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6126 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1272
Systematic name | M31578
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1272 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4735_3P
Systematic name | M31579
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4735-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR541_3P
Systematic name | M31580
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-541-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4656
Systematic name | M31581
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4656 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6727_3P
Systematic name | M31582
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6727-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR216B_5P
Systematic name | M31583
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-216b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4293
Systematic name | M31584
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4293 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3944_5P
Systematic name | M31585
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3944-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4718
Systematic name | M31586
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4718 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4711_5P
Systematic name | M31587
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4711-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4797_3P
Systematic name | M31588
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4797-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6892_5P
Systematic name | M31589
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6892-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1197
Systematic name | M31590
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1197 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR449B_3P
Systematic name | M31591
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-449b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6505_3P
Systematic name | M31592
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6505-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4469
Systematic name | M31593
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4469 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7155_5P
Systematic name | M31594
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7155-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR202_5P
Systematic name | M31595
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-202-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR198
Systematic name | M31596
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-198 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR584_3P
Systematic name | M31597
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-584-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6851_5P
Systematic name | M31598
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6851-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6817_5P
Systematic name | M31599
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6817-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6759_3P
Systematic name | M31600
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6759-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5187_3P
Systematic name | M31601
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5187-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1291
Systematic name | M31602
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1291 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR486_5P
Systematic name | M31603
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-486-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1972
Systematic name | M31604
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1972 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1266_5P
Systematic name | M31605
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1266-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR324_3P
Systematic name | M31606
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-324-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR320A_5P
Systematic name | M31607
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-320a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6868_5P
Systematic name | M31608
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6868-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3618
Systematic name | M31609
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3618 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3135B
Systematic name | M31610
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3135b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5695
Systematic name | M31611
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5695 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4769_3P
Systematic name | M31612
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4769-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR484
Systematic name | M31613
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-484 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4772_3P
Systematic name | M31614
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4772-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3934_3P
Systematic name | M31615
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3934-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5100
Systematic name | M31616
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5100 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR26B_3P
Systematic name | M31617
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-26b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR22_3P
Systematic name | M31618
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-22-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4632_5P
Systematic name | M31619
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4632-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR628_5P
Systematic name | M31620
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-628-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6837_3P
Systematic name | M31621
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6837-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4726_5P
Systematic name | M31622
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4726-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4786_5P
Systematic name | M31623
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4786-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7854_3P
Systematic name | M31624
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7854-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4642
Systematic name | M31625
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4642 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4733_5P
Systematic name | M31626
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4733-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4745_5P
Systematic name | M31627
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4745-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR514A_3P_MIR514B_3P
Systematic name | M31628
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-514a-3p, hsa-miR-514b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10526_3P
Systematic name | M31629
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10526-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3173_5P
Systematic name | M31630
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3173-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR192_3P
Systematic name | M31631
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-192-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR382_3P
Systematic name | M31632
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-382-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2278
Systematic name | M31633
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2278 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3675_3P
Systematic name | M31634
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3675-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR129_1_3P_MIR129_2_3P
Systematic name | M31635
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-129-1-3p, hsa-miR-129-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1255B_2_3P
Systematic name | M31636
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1255b-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR425_5P
Systematic name | M31637
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-425-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR512_3P
Systematic name | M31638
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-512-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4468
Systematic name | M31639
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4468 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6856_5P
Systematic name | M31640
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6856-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6826_3P
Systematic name | M31641
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6826-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4647_MIR4662B
Systematic name | M31642
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4647, hsa-miR-4662b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4425
Systematic name | M31643
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4425 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1226_3P
Systematic name | M31644
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1226-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR218_1_3P
Systematic name | M31645
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-218-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4423_3P
Systematic name | M31646
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4423-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6763_5P
Systematic name | M31647
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6763-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3166
Systematic name | M31648
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3166 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4774_5P
Systematic name | M31649
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4774-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4518
Systematic name | M31650
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4518 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR383_3P
Systematic name | M31651
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-383-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12118
Systematic name | M31652
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12118 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6880_5P
Systematic name | M31653
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6880-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7843_3P
Systematic name | M31654
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7843-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5587_5P
Systematic name | M31655
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5587-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6806_3P
Systematic name | M31656
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6806-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6515_5P
Systematic name | M31657
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6515-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR599
Systematic name | M31658
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-599 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR488_5P
Systematic name | M31659
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-488-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3173_3P
Systematic name | M31660
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3173-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5094
Systematic name | M31661
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5094 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4284
Systematic name | M31662
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4284 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548B_3P
Systematic name | M31663
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6773_3P
Systematic name | M31664
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6773-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1273H_3P
Systematic name | M31665
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1273h-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6892_3P
Systematic name | M31666
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6892-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7855_5P
Systematic name | M31667
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7855-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR141_5P
Systematic name | M31668
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-141-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3617_3P
Systematic name | M31669
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3617-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6801_5P
Systematic name | M31670
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6801-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1912_3P
Systematic name | M31671
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1912-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3121_5P
Systematic name | M31672
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3121-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4490
Systematic name | M31673
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4490 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8075
Systematic name | M31674
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8075 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4266
Systematic name | M31675
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4266 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2682_5P
Systematic name | M31676
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2682-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2861
Systematic name | M31677
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2861 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3928_5P
Systematic name | M31678
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3928-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3127_3P
Systematic name | M31679
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3127-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR211_3P
Systematic name | M31680
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-211-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3974
Systematic name | M31681
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3974 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3190_5P
Systematic name | M31682
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3190-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1244
Systematic name | M31683
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1244 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR584_5P
Systematic name | M31684
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-584-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3074_3P
Systematic name | M31685
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3074-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3145_5P
Systematic name | M31686
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3145-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR212_5P
Systematic name | M31687
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-212-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5702
Systematic name | M31688
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5702 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3689D
Systematic name | M31689
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3689d in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR549A_3P
Systematic name | M31690
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-549a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6742_3P
Systematic name | M31691
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6742-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1260A_MIR1260B
Systematic name | M31692
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1260a, hsa-miR-1260b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR508_3P
Systematic name | M31693
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-508-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6888_3P
Systematic name | M31694
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6888-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR624_3P
Systematic name | M31695
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-624-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4520_3P
Systematic name | M31696
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4520-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6782_3P
Systematic name | M31697
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6782-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR518D_5P_MIR518F_5P_MIR520C_5P_MIR526A_5P
Systematic name | M31698
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-518d-5p, hsa-miR-518f-5p, hsa-miR-520c-5p, hsa-miR-526a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4639_5P
Systematic name | M31699
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4639-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4714_5P
Systematic name | M31700
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4714-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6756_3P
Systematic name | M31701
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6756-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4752
Systematic name | M31702
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4752 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3171
Systematic name | M31703
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3171 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12117
Systematic name | M31704
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12117 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4711_3P
Systematic name | M31705
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4711-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5585_3P
Systematic name | M31706
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5585-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10393_3P
Systematic name | M31707
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10393-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7703
Systematic name | M31708
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7703 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4662A_5P
Systematic name | M31709
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4662a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4678
Systematic name | M31710
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4678 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR152_5P
Systematic name | M31711
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-152-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4659B_5P
Systematic name | M31712
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4659b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3605_5P
Systematic name | M31713
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3605-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5572
Systematic name | M31714
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5572 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR606
Systematic name | M31715
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-606 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3622A_3P_MIR3622B_3P
Systematic name | M31716
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3622a-3p, hsa-miR-3622b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5000_5P
Systematic name | M31717
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5000-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4680_5P
Systematic name | M31718
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4680-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6846_5P
Systematic name | M31719
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6846-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR628_3P
Systematic name | M31720
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-628-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1267
Systematic name | M31721
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1267 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6829_5P
Systematic name | M31722
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6829-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6748_3P
Systematic name | M31723
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6748-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6882_3P
Systematic name | M31724
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6882-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7852_3P
Systematic name | M31725
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7852-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3922_5P
Systematic name | M31726
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3922-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR618
Systematic name | M31727
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-618 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5693
Systematic name | M31728
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5693 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR96_3P
Systematic name | M31729
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-96-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3201
Systematic name | M31730
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3201 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR581
Systematic name | M31731
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-581 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3913_5P
Systematic name | M31732
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3913-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6754_3P
Systematic name | M31733
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6754-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6819_5P
Systematic name | M31734
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6819-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6804_5P
Systematic name | M31735
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6804-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR624_5P
Systematic name | M31736
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-624-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4708_3P
Systematic name | M31737
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4708-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7152_3P
Systematic name | M31738
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7152-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4286
Systematic name | M31739
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4286 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR637
Systematic name | M31740
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-637 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5000_3P
Systematic name | M31741
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5000-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR378J
Systematic name | M31742
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-378j in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR654_3P
Systematic name | M31743
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-654-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR610
Systematic name | M31744
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-610 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3150A_3P
Systematic name | M31745
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3150a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR455_3P
Systematic name | M31746
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-455-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4710
Systematic name | M31747
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4710 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR409_3P
Systematic name | M31748
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-409-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5581_5P
Systematic name | M31749
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5581-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7976
Systematic name | M31750
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7976 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6831_5P
Systematic name | M31751
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6831-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10397_5P
Systematic name | M31752
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10397-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6730_3P
Systematic name | M31753
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6730-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6871_3P
Systematic name | M31754
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6871-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6796_5P
Systematic name | M31755
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6796-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR532_3P
Systematic name | M31756
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-532-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6745
Systematic name | M31757
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6745 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3928_3P
Systematic name | M31758
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3928-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4793_5P
Systematic name | M31759
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4793-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR892B
Systematic name | M31760
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-892b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR642A_5P
Systematic name | M31761
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-642a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6737_5P
Systematic name | M31762
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6737-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6794_3P
Systematic name | M31763
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6794-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR367_5P
Systematic name | M31764
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-367-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4502
Systematic name | M31765
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4502 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR383_5P
Systematic name | M31766
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-383-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4330
Systematic name | M31767
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4330 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6849_3P
Systematic name | M31768
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6849-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR127_5P
Systematic name | M31769
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-127-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3918
Systematic name | M31770
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3918 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR573
Systematic name | M31771
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-573 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6771_3P
Systematic name | M31772
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6771-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4696
Systematic name | M31773
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4696 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5579_5P
Systematic name | M31774
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5579-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6848_5P
Systematic name | M31775
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6848-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4539
Systematic name | M31776
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4539 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR370_3P
Systematic name | M31777
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-370-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4294
Systematic name | M31778
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4294 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR134_3P
Systematic name | M31779
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-134-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3156_3P
Systematic name | M31780
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3156-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR622
Systematic name | M31781
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-622 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6750_3P
Systematic name | M31782
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6750-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1178_3P
Systematic name | M31783
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1178-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4695_3P
Systematic name | M31784
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4695-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR532_5P
Systematic name | M31785
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-532-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1912_5P
Systematic name | M31786
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1912-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1286
Systematic name | M31787
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1286 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6864_5P
Systematic name | M31788
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6864-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR592
Systematic name | M31789
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-592 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1261
Systematic name | M31790
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1261 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4437
Systematic name | M31791
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4437 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5583_3P
Systematic name | M31792
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5583-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6732_3P
Systematic name | M31793
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6732-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7113_3P
Systematic name | M31794
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7113-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7978
Systematic name | M31795
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7978 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4254
Systematic name | M31796
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4254 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3162_5P
Systematic name | M31797
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3162-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3682_3P
Systematic name | M31798
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3682-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6793_3P
Systematic name | M31799
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6793-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3616_5P
Systematic name | M31800
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3616-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4689
Systematic name | M31801
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4689 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6781_3P
Systematic name | M31802
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6781-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8055
Systematic name | M31803
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8055 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR518E_5P_MIR519A_5P_MIR519B_5P_MIR519C_5P_MIR522_5P_MIR523_5P
Systematic name | M31804
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-518e-5p, hsa-miR-519a-5p, hsa-miR-519b-5p, hsa-miR-519c-5p, hsa-miR-522-5p, hsa-miR-523-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4329
Systematic name | M31805
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4329 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3155A_MIR3155B
Systematic name | M31806
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3155a, hsa-miR-3155b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR630
Systematic name | M31807
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-630 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4289
Systematic name | M31808
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4289 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR508_5P
Systematic name | M31809
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-508-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR770_5P
Systematic name | M31810
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-770-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4686
Systematic name | M31811
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4686 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6748_5P
Systematic name | M31812
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6748-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1228_3P
Systematic name | M31813
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1228-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6529_3P
Systematic name | M31814
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6529-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR145_3P
Systematic name | M31815
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-145-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR589_5P
Systematic name | M31816
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-589-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4712_5P
Systematic name | M31817
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4712-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1285_5P
Systematic name | M31818
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1285-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR203B_3P
Systematic name | M31819
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-203b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4252
Systematic name | M31820
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4252 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR122_5P
Systematic name | M31821
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-122-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6874_3P
Systematic name | M31822
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6874-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6832_5P
Systematic name | M31823
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6832-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4501
Systematic name | M31824
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4501 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6893_3P
Systematic name | M31825
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6893-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1202
Systematic name | M31826
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1202 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4662A_3P
Systematic name | M31827
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4662a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4794
Systematic name | M31828
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4794 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR148B_5P
Systematic name | M31829
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-148b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4435
Systematic name | M31830
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4435 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6857_5P
Systematic name | M31831
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6857-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR495_5P
Systematic name | M31832
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-495-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR647
Systematic name | M31833
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-647 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR517_5P
Systematic name | M31834
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-517-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5588_5P
Systematic name | M31835
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5588-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6827_3P
Systematic name | M31836
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6827-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3194_3P
Systematic name | M31837
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3194-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR182_3P
Systematic name | M31838
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-182-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4790_3P
Systematic name | M31839
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4790-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4687_3P
Systematic name | M31840
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4687-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3192_3P
Systematic name | M31841
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3192-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR26A_1_3P
Systematic name | M31842
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-26a-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR26A_2_3P
Systematic name | M31843
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-26a-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR15B_3P
Systematic name | M31844
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-15b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6514_3P
Systematic name | M31845
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6514-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10B_3P
Systematic name | M31846
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6501_5P
Systematic name | M31847
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6501-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10524_5P
Systematic name | M31848
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10524-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4695_5P
Systematic name | M31849
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4695-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6731_3P
Systematic name | M31850
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6731-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10525_3P
Systematic name | M31851
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10525-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR455_5P
Systematic name | M31852
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-455-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR597_5P
Systematic name | M31853
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-597-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6510_5P
Systematic name | M31854
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6510-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR323B_3P
Systematic name | M31855
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-323b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3156_5P
Systematic name | M31856
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3156-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4491
Systematic name | M31857
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4491 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR31_3P
Systematic name | M31858
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-31-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1236_5P
Systematic name | M31859
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1236-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3613_5P
Systematic name | M31860
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3613-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4657
Systematic name | M31861
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4657 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3922_3P
Systematic name | M31862
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3922-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4804_3P
Systematic name | M31863
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4804-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4464
Systematic name | M31864
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4464 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1302
Systematic name | M31865
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1302 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3927_3P
Systematic name | M31866
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3927-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR510_5P
Systematic name | M31867
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-510-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3972
Systematic name | M31868
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3972 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR194_3P
Systematic name | M31869
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-194-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10401_5P
Systematic name | M31870
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10401-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4720_5P
Systematic name | M31871
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4720-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4748
Systematic name | M31872
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4748 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1229_3P
Systematic name | M31873
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1229-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5586_3P
Systematic name | M31874
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5586-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7158_5P
Systematic name | M31875
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7158-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8073
Systematic name | M31876
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8073 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7974
Systematic name | M31877
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7974 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4445_5P
Systematic name | M31878
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4445-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4799_3P
Systematic name | M31879
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4799-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5008_5P
Systematic name | M31880
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5008-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4722_3P
Systematic name | M31881
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4722-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7156_3P
Systematic name | M31882
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7156-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4664_5P
Systematic name | M31883
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4664-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6827_5P
Systematic name | M31884
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6827-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4717_3P
Systematic name | M31885
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4717-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4774_3P
Systematic name | M31886
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4774-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6823_5P
Systematic name | M31887
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6823-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3909
Systematic name | M31888
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3909 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4473
Systematic name | M31889
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4473 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3161
Systematic name | M31890
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3161 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4717_5P
Systematic name | M31891
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4717-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR138_1_3P
Systematic name | M31892
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-138-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6131
Systematic name | M31893
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6131 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR489_3P
Systematic name | M31894
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-489-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4519
Systematic name | M31895
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4519 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6765_3P
Systematic name | M31896
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6765-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5586_5P
Systematic name | M31897
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5586-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6755_3P
Systematic name | M31898
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6755-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR569
Systematic name | M31899
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-569 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4460
Systematic name | M31900
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4460 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4527
Systematic name | M31901
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4527 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4436A
Systematic name | M31902
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4436a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR500B_3P
Systematic name | M31903
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-500b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5089_3P
Systematic name | M31904
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5089-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4726_3P
Systematic name | M31905
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4726-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4795_5P
Systematic name | M31906
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4795-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4701_3P
Systematic name | M31907
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4701-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR934
Systematic name | M31908
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-934 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7109_5P
Systematic name | M31909
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7109-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR221_5P
Systematic name | M31910
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-221-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR675_3P
Systematic name | M31911
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-675-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6872_3P
Systematic name | M31912
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6872-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1295B_5P
Systematic name | M31913
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1295b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6829_3P
Systematic name | M31914
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6829-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3136_5P
Systematic name | M31915
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3136-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR140_5P
Systematic name | M31916
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-140-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3679_5P
Systematic name | M31917
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3679-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3935
Systematic name | M31918
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3935 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1976
Systematic name | M31919
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1976 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR219A_2_3P
Systematic name | M31920
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-219a-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1246
Systematic name | M31921
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1246 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6791_3P
Systematic name | M31922
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6791-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5589_5P
Systematic name | M31923
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5589-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6886_3P
Systematic name | M31924
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6886-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1199_5P
Systematic name | M31925
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1199-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6751_3P
Systematic name | M31926
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6751-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4474_3P
Systematic name | M31927
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4474-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6500_3P
Systematic name | M31928
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6500-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR643
Systematic name | M31929
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-643 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4493
Systematic name | M31930
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4493 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR634
Systematic name | M31931
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-634 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR649
Systematic name | M31932
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-649 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6861_5P
Systematic name | M31933
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6861-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6854_5P
Systematic name | M31934
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6854-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3929
Systematic name | M31935
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3929 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6890_3P
Systematic name | M31936
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6890-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1262
Systematic name | M31937
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1262 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4296
Systematic name | M31938
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4296 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3138
Systematic name | M31939
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3138 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR125A_3P
Systematic name | M31940
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-125a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR657
Systematic name | M31941
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-657 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6810_5P
Systematic name | M31942
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6810-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR378G
Systematic name | M31943
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-378g in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR644A
Systematic name | M31944
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-644a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR660_5P
Systematic name | M31945
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-660-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12127
Systematic name | M31946
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12127 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3132
Systematic name | M31947
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3132 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR18A_3P
Systematic name | M31948
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-18a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4724_3P
Systematic name | M31949
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4724-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5694
Systematic name | M31950
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5694 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6736_5P
Systematic name | M31951
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6736-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4764_5P
Systematic name | M31952
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4764-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6728_5P
Systematic name | M31953
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6728-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4450
Systematic name | M31954
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4450 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR642B_5P
Systematic name | M31955
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-642b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3912_5P
Systematic name | M31956
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3912-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR331_5P
Systematic name | M31957
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-331-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4708_5P
Systematic name | M31958
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4708-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6810_3P
Systematic name | M31959
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6810-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6734_5P
Systematic name | M31960
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6734-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR376A_5P
Systematic name | M31961
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-376a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR193A_3P_MIR193B_3P
Systematic name | M31962
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-193a-3p, hsa-miR-193b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10395_5P
Systematic name | M31963
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10395-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4327
Systematic name | M31964
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4327 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6072
Systematic name | M31965
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6072 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4439
Systematic name | M31966
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4439 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1910_5P
Systematic name | M31967
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1910-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4463
Systematic name | M31968
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4463 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR376A_2_5P
Systematic name | M31969
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-376a-2-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7847_3P
Systematic name | M31970
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7847-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3664_5P
Systematic name | M31971
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3664-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6855_5P
Systematic name | M31972
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6855-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4639_3P
Systematic name | M31973
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4639-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8069
Systematic name | M31974
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8069 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR550A_3P
Systematic name | M31975
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-550a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4772_5P
Systematic name | M31976
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4772-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR744_3P
Systematic name | M31977
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-744-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8077
Systematic name | M31978
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8077 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6894_3P
Systematic name | M31979
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6894-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1224_5P
Systematic name | M31980
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1224-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR188_5P
Systematic name | M31981
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-188-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12115
Systematic name | M31982
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12115 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4777_3P
Systematic name | M31983
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4777-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3187_3P
Systematic name | M31984
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3187-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1270
Systematic name | M31985
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1270 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6866_3P
Systematic name | M31986
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6866-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6895_3P
Systematic name | M31987
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6895-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3134
Systematic name | M31988
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3134 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4690_5P
Systematic name | M31989
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4690-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR432_3P
Systematic name | M31990
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-432-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1255A_MIR1255B_5P
Systematic name | M31991
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1255a, hsa-miR-1255b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4704_5P
Systematic name | M31992
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4704-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6804_3P
Systematic name | M31993
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6804-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8081
Systematic name | M31994
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8081 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4650_5P
Systematic name | M31995
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4650-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7155_3P
Systematic name | M31996
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7155-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6843_3P
Systematic name | M31997
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6843-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2116_3P
Systematic name | M31998
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2116-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR412_3P
Systematic name | M31999
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-412-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8057
Systematic name | M32000
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8057 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR574_5P
Systematic name | M32001
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-574-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR20B_3P
Systematic name | M32002
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-20b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3184_3P
Systematic name | M32003
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3184-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3118
Systematic name | M32004
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3118 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4471
Systematic name | M32005
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4471 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6848_3P
Systematic name | M32006
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6848-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6744_5P
Systematic name | M32007
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6744-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR550B_3P
Systematic name | M32008
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-550b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR197_5P
Systematic name | M32009
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-197-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3188
Systematic name | M32010
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3188 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3661
Systematic name | M32011
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3661 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6812_5P
Systematic name | M32012
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6812-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR193B_5P
Systematic name | M32013
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-193b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3122
Systematic name | M32014
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3122 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7109_3P
Systematic name | M32015
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7109-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR877_5P
Systematic name | M32016
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-877-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6775_3P
Systematic name | M32017
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6775-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR196A_5P_MIR196B_5P
Systematic name | M32018
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-196a-5p, hsa-miR-196b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6769B_5P
Systematic name | M32019
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6769b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR147A
Systematic name | M32020
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-147a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR520G_5P
Systematic name | M32021
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-520g-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1322
Systematic name | M32022
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1322 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2392
Systematic name | M32023
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2392 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3189_3P
Systematic name | M32024
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3189-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1224_3P
Systematic name | M32025
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1224-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3152_3P
Systematic name | M32026
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3152-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10398_5P
Systematic name | M32027
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10398-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4653_3P
Systematic name | M32028
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4653-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6729_3P
Systematic name | M32029
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6729-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3913_3P
Systematic name | M32030
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3913-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6769B_3P
Systematic name | M32031
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6769b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR144_5P
Systematic name | M32032
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-144-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4487
Systematic name | M32033
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4487 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6857_3P
Systematic name | M32034
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6857-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3169
Systematic name | M32035
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3169 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3136_3P
Systematic name | M32036
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3136-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5196_3P
Systematic name | M32037
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5196-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6772_3P
Systematic name | M32038
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6772-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4290
Systematic name | M32039
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4290 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR937_5P
Systematic name | M32040
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-937-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7151_5P
Systematic name | M32041
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7151-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8064
Systematic name | M32042
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8064 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6750_5P
Systematic name | M32043
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6750-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4723_3P
Systematic name | M32044
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4723-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR11399
Systematic name | M32045
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-11399 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6824_5P
Systematic name | M32046
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6824-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1227_3P
Systematic name | M32047
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1227-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3194_5P
Systematic name | M32048
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3194-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4432
Systematic name | M32049
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4432 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2276_5P
Systematic name | M32050
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2276-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6822_5P
Systematic name | M32051
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6822-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3183
Systematic name | M32052
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3183 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR502_5P
Systematic name | M32053
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-502-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR620
Systematic name | M32054
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-620 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4256
Systematic name | M32055
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4256 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR500A_3P
Systematic name | M32056
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-500a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4299
Systematic name | M32057
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4299 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6806_5P
Systematic name | M32058
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6806-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6866_5P
Systematic name | M32059
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6866-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6875_5P
Systematic name | M32060
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6875-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10226
Systematic name | M32061
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10226 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR134_5P
Systematic name | M32062
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-134-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3176
Systematic name | M32063
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3176 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4648
Systematic name | M32064
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4648 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1843
Systematic name | M32065
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1843 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR339_5P
Systematic name | M32066
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-339-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4646_3P
Systematic name | M32067
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4646-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR591
Systematic name | M32068
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-591 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR550A_3_5P_MIR550A_5P
Systematic name | M32069
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-550a-3-5p, hsa-miR-550a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4764_3P
Systematic name | M32070
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4764-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5685
Systematic name | M32071
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5685 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR595
Systematic name | M32072
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-595 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR483_3P
Systematic name | M32073
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-483-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6797_3P
Systematic name | M32074
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6797-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3659
Systematic name | M32075
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3659 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR363_5P
Systematic name | M32076
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-363-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR938
Systematic name | M32077
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-938 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4690_3P
Systematic name | M32078
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4690-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6831_3P
Systematic name | M32079
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6831-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4712_3P
Systematic name | M32080
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4712-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4521
Systematic name | M32081
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4521 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4663
Systematic name | M32082
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4663 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1271_3P
Systematic name | M32083
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1271-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4802_5P
Systematic name | M32084
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4802-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5699_3P
Systematic name | M32085
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5699-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3672
Systematic name | M32086
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3672 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR11181_5P
Systematic name | M32087
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-11181-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3126_5P
Systematic name | M32088
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3126-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3200_5P
Systematic name | M32089
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3200-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4791
Systematic name | M32090
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4791 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR154_5P
Systematic name | M32091
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-154-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4732_3P
Systematic name | M32092
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4732-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6856_3P
Systematic name | M32093
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6856-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2682_3P
Systematic name | M32094
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2682-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1256
Systematic name | M32095
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1256 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3127_5P
Systematic name | M32096
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3127-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6779_3P
Systematic name | M32097
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6779-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4740_5P
Systematic name | M32098
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4740-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR219A_1_3P
Systematic name | M32099
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-219a-1-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4793_3P
Systematic name | M32100
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4793-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3117_5P
Systematic name | M32101
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3117-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4509
Systematic name | M32102
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4509 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR549A_5P
Systematic name | M32103
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-549a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR34A_3P
Systematic name | M32104
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-34a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR616_3P
Systematic name | M32105
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-616-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4761_5P
Systematic name | M32106
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4761-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5681B
Systematic name | M32107
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5681b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4771
Systematic name | M32108
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4771 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR655_5P
Systematic name | M32109
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-655-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3160_3P
Systematic name | M32110
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3160-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR100_3P
Systematic name | M32111
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-100-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1278
Systematic name | M32112
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1278 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR571
Systematic name | M32113
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-571 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5591_5P
Systematic name | M32114
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5591-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6751_5P
Systematic name | M32115
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6751-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1293
Systematic name | M32116
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1293 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4641
Systematic name | M32117
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4641 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3144_3P
Systematic name | M32118
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3144-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6529_5P
Systematic name | M32119
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6529-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4298
Systematic name | M32120
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4298 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3120_5P
Systematic name | M32121
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3120-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3622B_5P
Systematic name | M32122
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3622b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1587
Systematic name | M32123
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1587 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR617
Systematic name | M32124
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-617 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6871_5P
Systematic name | M32125
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6871-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6793_5P
Systematic name | M32126
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6793-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6811_3P
Systematic name | M32127
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6811-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6503_5P
Systematic name | M32128
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6503-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4637
Systematic name | M32129
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4637 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4659A_5P
Systematic name | M32130
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4659a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR509_3P
Systematic name | M32131
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-509-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6891_3P
Systematic name | M32132
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6891-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4260
Systematic name | M32133
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4260 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR664A_5P
Systematic name | M32134
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-664a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR219B_3P
Systematic name | M32135
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-219b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3938
Systematic name | M32136
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3938 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6883_3P
Systematic name | M32137
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6883-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6759_5P
Systematic name | M32138
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6759-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6511A_3P_MIR6511B_3P
Systematic name | M32139
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6511a-3p, hsa-miR-6511b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3691_3P
Systematic name | M32140
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3691-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6881_5P
Systematic name | M32141
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6881-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR562
Systematic name | M32142
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-562 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4300
Systematic name | M32143
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4300 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR493_3P
Systematic name | M32144
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-493-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3152_5P
Systematic name | M32145
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3152-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1266_3P
Systematic name | M32146
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1266-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6870_3P
Systematic name | M32147
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6870-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4305
Systematic name | M32148
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4305 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6753_3P
Systematic name | M32149
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6753-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6884_3P
Systematic name | M32150
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6884-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3616_3P
Systematic name | M32151
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3616-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6780B_3P
Systematic name | M32152
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6780b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR759
Systematic name | M32153
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-759 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12116
Systematic name | M32154
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12116 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR873_3P
Systematic name | M32155
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-873-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1185_5P
Systematic name | M32156
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1185-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6740_5P
Systematic name | M32157
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6740-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR382_5P
Systematic name | M32158
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-382-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4513
Systematic name | M32159
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4513 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3923
Systematic name | M32160
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3923 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6823_3P
Systematic name | M32161
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6823-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3934_5P
Systematic name | M32162
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3934-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR632
Systematic name | M32163
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-632 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4654
Systematic name | M32164
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4654 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR34C_3P
Systematic name | M32165
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-34c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4761_3P
Systematic name | M32166
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4761-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1288_5P
Systematic name | M32167
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1288-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR874_5P
Systematic name | M32168
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-874-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR328_5P
Systematic name | M32169
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-328-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR626
Systematic name | M32170
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-626 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR299_3P
Systematic name | M32171
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-299-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6811_5P
Systematic name | M32172
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6811-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6511B_5P
Systematic name | M32173
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6511b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR514A_5P
Systematic name | M32174
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-514a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7107_3P
Systematic name | M32175
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7107-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8059
Systematic name | M32176
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8059 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3137
Systematic name | M32177
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3137 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4524B_3P
Systematic name | M32178
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4524b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3139
Systematic name | M32179
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3139 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3614_3P
Systematic name | M32180
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3614-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7845_5P
Systematic name | M32181
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7845-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4693_3P
Systematic name | M32182
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4693-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6762_5P
Systematic name | M32183
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6762-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4733_3P
Systematic name | M32184
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4733-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR370_5P
Systematic name | M32185
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-370-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR631
Systematic name | M32186
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-631 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR345_5P
Systematic name | M32187
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-345-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR342_5P
Systematic name | M32188
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-342-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6774_5P
Systematic name | M32189
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6774-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4721
Systematic name | M32190
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4721 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4448
Systematic name | M32191
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4448 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR576_3P
Systematic name | M32192
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-576-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR200C_5P
Systematic name | M32193
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-200c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6847_3P
Systematic name | M32194
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6847-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6841_3P
Systematic name | M32195
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6841-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR28_3P
Systematic name | M32196
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-28-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6865_5P
Systematic name | M32197
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6865-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1258
Systematic name | M32198
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1258 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1233_3P
Systematic name | M32199
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1233-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4683
Systematic name | M32200
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4683 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3665
Systematic name | M32201
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3665 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3614_5P
Systematic name | M32202
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3614-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6869_5P
Systematic name | M32203
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6869-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3975
Systematic name | M32204
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3975 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6876_3P
Systematic name | M32205
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6876-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6801_3P
Systematic name | M32206
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6801-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7851_3P
Systematic name | M32207
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7851-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1263
Systematic name | M32208
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1263 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4741
Systematic name | M32209
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4741 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6815_5P
Systematic name | M32210
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6815-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8056
Systematic name | M32211
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8056 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4474_5P
Systematic name | M32212
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4474-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR664B_5P
Systematic name | M32213
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-664b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1243
Systematic name | M32214
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1243 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8083
Systematic name | M32215
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8083 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3914
Systematic name | M32216
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3914 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4515
Systematic name | M32217
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4515 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6864_3P
Systematic name | M32218
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6864-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6834_5P
Systematic name | M32219
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6834-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4522
Systematic name | M32220
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4522 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3170
Systematic name | M32221
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3170 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR505_5P
Systematic name | M32222
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-505-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR320E
Systematic name | M32223
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-320e in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6845_5P
Systematic name | M32224
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6845-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4433B_5P
Systematic name | M32225
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4433b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4749_3P
Systematic name | M32226
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4749-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6858_5P
Systematic name | M32227
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6858-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6796_3P
Systematic name | M32228
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6796-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6744_3P
Systematic name | M32229
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6744-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3059_3P
Systematic name | M32230
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3059-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3130_3P
Systematic name | M32231
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3130-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3620_5P
Systematic name | M32232
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3620-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6803_5P
Systematic name | M32233
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6803-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6807_5P
Systematic name | M32234
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6807-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4480
Systematic name | M32235
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4480 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1226_5P
Systematic name | M32236
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1226-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4433A_3P
Systematic name | M32237
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4433a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4446_3P
Systematic name | M32238
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4446-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6798_5P
Systematic name | M32239
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6798-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7154_3P
Systematic name | M32240
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7154-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR346
Systematic name | M32241
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-346 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3620_3P
Systematic name | M32242
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3620-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9898
Systematic name | M32243
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9898 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR501_3P_MIR502_3P
Systematic name | M32244
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-501-3p, hsa-miR-502-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6858_3P
Systematic name | M32245
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6858-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4757_5P
Systematic name | M32246
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4757-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4475
Systematic name | M32247
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4475 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4438
Systematic name | M32248
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4438 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9903
Systematic name | M32249
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9903 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR503_5P
Systematic name | M32250
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-503-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4715_5P
Systematic name | M32251
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4715-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7158_3P
Systematic name | M32252
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7158-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR449C_3P
Systematic name | M32253
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-449c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR146B_3P
Systematic name | M32254
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-146b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4638_3P
Systematic name | M32255
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4638-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4676_5P
Systematic name | M32256
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4676-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6851_3P
Systematic name | M32257
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6851-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3130_5P
Systematic name | M32258
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3130-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3189_5P
Systematic name | M32259
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3189-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6885_5P
Systematic name | M32260
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6885-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4274
Systematic name | M32261
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4274 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6076
Systematic name | M32262
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6076 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4320
Systematic name | M32263
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4320 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR575
Systematic name | M32264
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-575 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR431_5P
Systematic name | M32265
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-431-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR921
Systematic name | M32266
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-921 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6878_3P
Systematic name | M32267
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6878-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6776_3P
Systematic name | M32268
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6776-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4714_3P
Systematic name | M32269
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4714-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR380_5P
Systematic name | M32270
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-380-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4715_3P
Systematic name | M32271
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4715-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1287_5P
Systematic name | M32272
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1287-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR331_3P
Systematic name | M32273
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-331-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5704
Systematic name | M32274
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5704 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR512_5P
Systematic name | M32275
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-512-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3654
Systematic name | M32276
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3654 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR552_3P
Systematic name | M32277
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-552-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1288_3P
Systematic name | M32278
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1288-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR203B_5P
Systematic name | M32279
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-203b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3936
Systematic name | M32280
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3936 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6772_5P
Systematic name | M32281
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6772-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR374C_3P
Systematic name | M32282
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-374c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6838_3P
Systematic name | M32283
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6838-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6757_5P
Systematic name | M32284
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6757-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR340_3P
Systematic name | M32285
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-340-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR504_5P
Systematic name | M32286
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-504-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR764
Systematic name | M32287
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-764 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR924
Systematic name | M32288
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-924 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR218_2_3P
Systematic name | M32289
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-218-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR635
Systematic name | M32290
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-635 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1914_5P
Systematic name | M32291
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1914-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4725_5P
Systematic name | M32292
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4725-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7702
Systematic name | M32293
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7702 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR619_3P
Systematic name | M32294
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-619-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5009_5P
Systematic name | M32295
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5009-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1225_3P
Systematic name | M32296
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1225-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6502_5P
Systematic name | M32297
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6502-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6861_3P
Systematic name | M32298
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6861-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4529_5P
Systematic name | M32299
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4529-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR640
Systematic name | M32300
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-640 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AT_3P
Systematic name | M32301
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548at-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR377_5P
Systematic name | M32302
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-377-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6718_5P
Systematic name | M32303
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6718-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3663_5P
Systematic name | M32304
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3663-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2909
Systematic name | M32305
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2909 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4675
Systematic name | M32306
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4675 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1301_5P
Systematic name | M32307
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1301-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5189_3P
Systematic name | M32308
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5189-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR101_5P
Systematic name | M32309
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-101-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR214_5P
Systematic name | M32310
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-214-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10397_3P
Systematic name | M32311
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10397-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7705
Systematic name | M32312
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7705 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3198
Systematic name | M32313
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3198 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4268
Systematic name | M32314
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4268 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR450B_3P
Systematic name | M32315
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-450b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR500B_5P
Systematic name | M32316
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-500b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR210_5P
Systematic name | M32317
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-210-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3690
Systematic name | M32318
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3690 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR519E_3P
Systematic name | M32319
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-519e-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR296_5P
Systematic name | M32320
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-296-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4253
Systematic name | M32321
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4253 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6514_5P
Systematic name | M32322
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6514-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR676_3P
Systematic name | M32323
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-676-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6826_5P
Systematic name | M32324
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6826-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1231
Systematic name | M32325
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1231 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1245B_5P
Systematic name | M32326
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1245b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6777_3P
Systematic name | M32327
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6777-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR362_5P
Systematic name | M32328
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-362-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6502_3P
Systematic name | M32329
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6502-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4540
Systematic name | M32330
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4540 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7114_3P
Systematic name | M32331
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7114-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR515_3P
Systematic name | M32332
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-515-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6862_5P
Systematic name | M32333
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6862-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5007_5P
Systematic name | M32334
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5007-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR874_3P
Systematic name | M32335
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-874-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6822_3P
Systematic name | M32336
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6822-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3199
Systematic name | M32337
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3199 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6086
Systematic name | M32338
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6086 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1265
Systematic name | M32339
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1265 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3144_5P
Systematic name | M32340
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3144-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6834_3P
Systematic name | M32341
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6834-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR33B_3P
Systematic name | M32342
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-33b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6800_5P
Systematic name | M32343
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6800-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6888_5P
Systematic name | M32344
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6888-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3691_5P
Systematic name | M32345
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3691-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR668_3P
Systematic name | M32346
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-668-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3146
Systematic name | M32347
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3146 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6836_3P
Systematic name | M32348
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6836-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR490_5P
Systematic name | M32349
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-490-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR378H
Systematic name | M32350
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-378h in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR203A_5P
Systematic name | M32351
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-203a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5011_3P
Systematic name | M32352
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5011-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4489
Systematic name | M32353
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4489 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4309
Systematic name | M32354
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4309 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4759
Systematic name | M32355
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4759 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3667_5P
Systematic name | M32356
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3667-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3650
Systematic name | M32357
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3650 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4765
Systematic name | M32358
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4765 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5192
Systematic name | M32359
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5192 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3142
Systematic name | M32360
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3142 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR18B_3P
Systematic name | M32361
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-18b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR24_1_5P_MIR24_2_5P
Systematic name | M32362
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-24-1-5p, hsa-miR-24-2-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4758_3P
Systematic name | M32363
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4758-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4280
Systematic name | M32364
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4280 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5186
Systematic name | M32365
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5186 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1289
Systematic name | M32366
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1289 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7975
Systematic name | M32367
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7975 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4763_5P
Systematic name | M32368
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4763-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8052
Systematic name | M32369
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8052 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR379_5P
Systematic name | M32370
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-379-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3151_5P
Systematic name | M32371
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3151-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6855_3P
Systematic name | M32372
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6855-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6821_3P
Systematic name | M32373
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6821-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4494
Systematic name | M32374
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4494 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3907
Systematic name | M32375
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3907 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR875_5P
Systematic name | M32376
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-875-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR708_5P
Systematic name | M32377
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-708-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6080
Systematic name | M32378
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6080 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3657
Systematic name | M32379
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3657 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR411_5P
Systematic name | M32380
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-411-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR135A_2_3P
Systematic name | M32381
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-135a-2-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AY_3P
Systematic name | M32382
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ay-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR376B_5P_MIR376C_5P
Systematic name | M32383
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-376b-5p, hsa-miR-376c-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1306_5P
Systematic name | M32384
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1306-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6865_3P
Systematic name | M32385
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6865-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2114_3P
Systematic name | M32386
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2114-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR135B_3P
Systematic name | M32387
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-135b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4265
Systematic name | M32388
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4265 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR490_3P
Systematic name | M32389
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-490-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4769_5P
Systematic name | M32390
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4769-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR28_5P
Systematic name | M32391
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-28-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1238_5P_MIR4758_5P
Systematic name | M32392
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1238-5p, hsa-miR-4758-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4688
Systematic name | M32393
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4688 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3927_5P
Systematic name | M32394
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3927-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5588_3P
Systematic name | M32395
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5588-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4259
Systematic name | M32396
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4259 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3165
Systematic name | M32397
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3165 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4322
Systematic name | M32398
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4322 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR625_3P
Systematic name | M32399
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-625-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4421
Systematic name | M32400
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4421 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR378E
Systematic name | M32401
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-378e in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4301
Systematic name | M32402
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4301 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1915_5P
Systematic name | M32403
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1915-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4506
Systematic name | M32404
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4506 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR27B_5P
Systematic name | M32405
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-27b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5571_3P
Systematic name | M32406
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5571-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3115
Systematic name | M32407
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3115 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5194
Systematic name | M32408
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5194 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR943
Systematic name | M32409
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-943 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR378A_3P_MIR378C_MIR378D_MIR378I
Systematic name | M32410
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-378a-3p, hsa-miR-378c, hsa-miR-378d, hsa-miR-378i in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6798_3P
Systematic name | M32411
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6798-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR324_5P
Systematic name | M32412
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-324-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1269A_MIR1269B
Systematic name | M32413
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1269a, hsa-miR-1269b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6747_5P
Systematic name | M32414
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6747-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6802_3P
Systematic name | M32415
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6802-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR378B
Systematic name | M32416
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-378b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR422A
Systematic name | M32417
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-422a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR556_5P
Systematic name | M32418
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-556-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6769A_5P
Systematic name | M32419
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6769a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5002_3P
Systematic name | M32420
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5002-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3945
Systematic name | M32421
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3945 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3151_3P
Systematic name | M32422
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3151-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4312
Systematic name | M32423
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4312 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6879_3P
Systematic name | M32424
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6879-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1911_3P
Systematic name | M32425
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1911-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR378F
Systematic name | M32426
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-378f in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR769_5P
Systematic name | M32427
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-769-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR323A_5P
Systematic name | M32428
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-323a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR219B_5P
Systematic name | M32429
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-219b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1225_5P
Systematic name | M32430
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1225-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR193A_5P
Systematic name | M32431
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-193a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4536_5P
Systematic name | M32432
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4536-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6742_5P
Systematic name | M32433
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6742-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6790_5P
Systematic name | M32434
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6790-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1287_3P
Systematic name | M32435
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1287-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3619_3P
Systematic name | M32436
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3619-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6085
Systematic name | M32437
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6085 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR920
Systematic name | M32438
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-920 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6841_5P
Systematic name | M32439
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6841-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR92A_1_5P
Systematic name | M32440
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-92a-1-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6894_5P
Systematic name | M32441
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6894-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7108_5P
Systematic name | M32442
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7108-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1298_5P
Systematic name | M32443
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1298-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1180_5P
Systematic name | M32444
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1180-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4658
Systematic name | M32445
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4658 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR648
Systematic name | M32446
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-648 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4776_5P
Systematic name | M32447
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4776-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR323B_5P
Systematic name | M32448
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-323b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6726_5P
Systematic name | M32449
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6726-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4713_3P
Systematic name | M32450
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4713-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR23B_5P
Systematic name | M32451
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-23b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4433A_5P
Systematic name | M32452
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4433a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6508_3P
Systematic name | M32453
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6508-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12126
Systematic name | M32454
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12126 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR555
Systematic name | M32455
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-555 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4529_3P
Systematic name | M32456
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4529-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR103B
Systematic name | M32457
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-103b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR410_5P
Systematic name | M32458
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-410-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR494_5P
Systematic name | M32459
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-494-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6808_3P
Systematic name | M32460
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6808-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1296_3P
Systematic name | M32461
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1296-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6773_5P
Systematic name | M32462
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6773-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4633_5P
Systematic name | M32463
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4633-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1193
Systematic name | M32464
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1193 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR627_5P
Systematic name | M32465
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-627-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4694_5P
Systematic name | M32466
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4694-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6895_5P
Systematic name | M32467
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6895-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7153_3P
Systematic name | M32468
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7153-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR550B_2_5P
Systematic name | M32469
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-550b-2-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3670
Systematic name | M32470
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3670 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6784_3P
Systematic name | M32471
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6784-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6743_5P
Systematic name | M32472
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6743-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3135A
Systematic name | M32473
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3135a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6819_3P
Systematic name | M32474
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6819-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4482_5P
Systematic name | M32475
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4482-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR711
Systematic name | M32476
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-711 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6813_5P
Systematic name | M32477
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6813-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR621
Systematic name | M32478
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-621 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3174
Systematic name | M32479
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3174 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6877_3P
Systematic name | M32480
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6877-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR656_5P
Systematic name | M32481
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-656-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3117_3P
Systematic name | M32482
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3117-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2681_3P
Systematic name | M32483
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2681-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1298_3P
Systematic name | M32484
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1298-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR409_5P
Systematic name | M32485
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-409-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR424_3P
Systematic name | M32486
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-424-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1909_5P
Systematic name | M32487
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1909-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3675_5P
Systematic name | M32488
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3675-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR563
Systematic name | M32489
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-563 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4703_3P
Systematic name | M32490
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4703-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4661_5P
Systematic name | M32491
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4661-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1229_5P
Systematic name | M32492
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1229-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6813_3P
Systematic name | M32493
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6813-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR645
Systematic name | M32494
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-645 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12114
Systematic name | M32495
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12114 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR652_5P
Systematic name | M32496
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-652-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3943
Systematic name | M32497
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3943 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR215_5P
Systematic name | M32498
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-215-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1245A
Systematic name | M32499
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1245a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6874_5P
Systematic name | M32500
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6874-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR375_3P
Systematic name | M32501
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-375-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR15A_3P
Systematic name | M32502
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-15a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR609
Systematic name | M32503
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-609 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6816_3P
Systematic name | M32504
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6816-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6755_5P
Systematic name | M32505
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6755-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR135A_3P
Systematic name | M32506
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-135a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3126_3P
Systematic name | M32507
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3126-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR192_5P
Systematic name | M32508
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-192-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9900
Systematic name | M32509
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9900 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4323
Systematic name | M32510
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4323 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR296_3P
Systematic name | M32511
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-296-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4687_5P
Systematic name | M32512
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4687-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7106_3P
Systematic name | M32513
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7106-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548Q
Systematic name | M32514
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548q in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1296_5P
Systematic name | M32515
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1296-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4652_5P
Systematic name | M32516
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4652-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4781_3P
Systematic name | M32517
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4781-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR208B_3P
Systematic name | M32518
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-208b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4780
Systematic name | M32519
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4780 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR503_3P
Systematic name | M32520
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-503-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12130
Systematic name | M32521
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12130 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5591_3P
Systematic name | M32522
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5591-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8079
Systematic name | M32523
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8079 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6846_3P
Systematic name | M32524
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6846-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR208A_3P
Systematic name | M32525
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-208a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6859_3P
Systematic name | M32526
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6859-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR328_3P
Systematic name | M32527
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-328-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6890_5P
Systematic name | M32528
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6890-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3157_3P
Systematic name | M32529
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3157-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3529_5P
Systematic name | M32530
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3529-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5088_5P
Systematic name | M32531
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5088-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR151A_3P
Systematic name | M32532
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-151a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2114_5P
Systematic name | M32533
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2114-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7973
Systematic name | M32534
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7973 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR758_5P
Systematic name | M32535
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-758-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6805_5P
Systematic name | M32536
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6805-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3158_3P
Systematic name | M32537
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3158-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8071
Systematic name | M32538
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8071 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4507
Systematic name | M32539
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4507 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10400_3P_MIR4674
Systematic name | M32540
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10400-3p, hsa-miR-4674 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3085_5P
Systematic name | M32541
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3085-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5684
Systematic name | M32542
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5684 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6738_5P
Systematic name | M32543
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6738-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3940_5P
Systematic name | M32544
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3940-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1178_5P
Systematic name | M32545
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1178-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6782_5P
Systematic name | M32546
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6782-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AD_3P
Systematic name | M32547
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ad-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR769_3P
Systematic name | M32548
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-769-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR601
Systematic name | M32549
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-601 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8058
Systematic name | M32550
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8058 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR27A_5P
Systematic name | M32551
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-27a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3622A_5P
Systematic name | M32552
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3622a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR663B
Systematic name | M32553
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-663b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10A_3P
Systematic name | M32554
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5010_5P
Systematic name | M32555
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5010-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR615_5P
Systematic name | M32556
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-615-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1914_3P
Systematic name | M32557
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1914-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4999_3P
Systematic name | M32558
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4999-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6735_3P
Systematic name | M32559
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6735-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4633_3P_MIR6500_5P
Systematic name | M32560
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4633-3p, hsa-miR-6500-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3684
Systematic name | M32561
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3684 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4525
Systematic name | M32562
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4525 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4750_3P
Systematic name | M32563
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4750-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR23A_5P
Systematic name | M32564
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-23a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4278
Systematic name | M32565
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4278 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5191
Systematic name | M32566
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5191 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6732_5P
Systematic name | M32567
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6732-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1911_5P
Systematic name | M32568
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1911-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3681_5P
Systematic name | M32569
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3681-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6835_5P
Systematic name | M32570
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6835-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4800_5P
Systematic name | M32571
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4800-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3147
Systematic name | M32572
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3147 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4751
Systematic name | M32573
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4751 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4433B_3P
Systematic name | M32574
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4433b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4423_5P
Systematic name | M32575
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4423-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6862_3P
Systematic name | M32576
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6862-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6503_3P
Systematic name | M32577
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6503-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR454_5P
Systematic name | M32578
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-454-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6849_5P
Systematic name | M32579
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6849-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4535
Systematic name | M32580
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4535 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR371B_3P
Systematic name | M32581
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-371b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4486
Systematic name | M32582
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4486 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6069
Systematic name | M32583
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6069 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR554
Systematic name | M32584
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-554 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3680_5P
Systematic name | M32585
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3680-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR492
Systematic name | M32586
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-492 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1238_3P
Systematic name | M32587
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1238-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4732_5P
Systematic name | M32588
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4732-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4727_3P
Systematic name | M32589
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4727-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8078
Systematic name | M32590
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8078 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR151A_5P_MIR151B
Systematic name | M32591
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-151a-5p, hsa-miR-151b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR325
Systematic name | M32592
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-325 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6802_5P
Systematic name | M32593
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6802-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR365B_5P
Systematic name | M32594
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-365b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1182
Systematic name | M32595
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1182 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7160_3P
Systematic name | M32596
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7160-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6082
Systematic name | M32597
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6082 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR596
Systematic name | M32598
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-596 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR12121
Systematic name | M32599
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-12121 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR365A_5P
Systematic name | M32600
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-365a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4661_3P
Systematic name | M32601
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4661-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6800_3P
Systematic name | M32602
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6800-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6767_3P
Systematic name | M32603
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6767-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7848_3P
Systematic name | M32604
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7848-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6724_5P
Systematic name | M32605
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6724-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4453
Systematic name | M32607
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4453 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1295B_3P
Systematic name | M32608
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1295b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3180_MIR3180_3P
Systematic name | M32609
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3180, hsa-miR-3180-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3649
Systematic name | M32610
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3649 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4538
Systematic name | M32611
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4538 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6787_5P
Systematic name | M32612
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6787-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3677_5P
Systematic name | M32613
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3677-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR659_5P
Systematic name | M32614
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-659-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3191_3P
Systematic name | M32615
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3191-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6753_5P
Systematic name | M32616
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6753-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3200_3P
Systematic name | M32617
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3200-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR744_5P
Systematic name | M32618
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-744-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6816_5P
Systematic name | M32619
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6816-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR885_3P
Systematic name | M32620
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-885-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5195_5P
Systematic name | M32621
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5195-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3162_3P
Systematic name | M32622
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3162-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4484
Systematic name | M32623
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4484 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6741_5P
Systematic name | M32624
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6741-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1282
Systematic name | M32625
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1282 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1251_5P
Systematic name | M32626
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1251-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8086
Systematic name | M32627
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8086 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6789_5P
Systematic name | M32628
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6789-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1468_5P
Systematic name | M32629
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1468-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR191_5P
Systematic name | M32630
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-191-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1277_3P
Systematic name | M32631
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1277-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3196
Systematic name | M32632
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3196 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4313
Systematic name | M32633
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4313 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5687
Systematic name | M32634
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5687 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR517A_3P_MIR517B_3P_MIR517C_3P
Systematic name | M32635
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-517a-3p, hsa-miR-517b-3p, hsa-miR-517c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10396B_5P
Systematic name | M32636
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10396b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4790_5P
Systematic name | M32637
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4790-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4697_5P
Systematic name | M32638
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4697-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4512
Systematic name | M32639
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4512 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR663A
Systematic name | M32640
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-663a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4640_3P
Systematic name | M32641
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4640-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR564
Systematic name | M32642
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-564 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AO_3P
Systematic name | M32643
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548ao-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3651
Systematic name | M32644
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3651 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR339_3P
Systematic name | M32645
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-339-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR604
Systematic name | M32646
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-604 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1908_5P
Systematic name | M32647
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1908-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1281
Systematic name | M32648
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1281 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3678_5P
Systematic name | M32649
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3678-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4462
Systematic name | M32650
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4462 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR598_5P
Systematic name | M32651
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-598-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6889_5P
Systematic name | M32652
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6889-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6769A_3P
Systematic name | M32653
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6769a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR139_3P
Systematic name | M32654
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-139-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1237_5P_MIR4488
Systematic name | M32655
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1237-5p, hsa-miR-4488 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8088
Systematic name | M32656
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8088 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR524_3P_MIR525_3P
Systematic name | M32657
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-524-3p, hsa-miR-525-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6863
Systematic name | M32658
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6863 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4536_3P
Systematic name | M32659
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4536-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4707_5P
Systematic name | M32660
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4707-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR210_3P
Systematic name | M32661
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-210-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6506_3P
Systematic name | M32662
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6506-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR2277_3P
Systematic name | M32663
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-2277-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1292_5P
Systematic name | M32664
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1292-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR933
Systematic name | M32665
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-933 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR181C_3P
Systematic name | M32666
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-181c-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4730
Systematic name | M32667
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4730 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4281
Systematic name | M32668
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4281 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1470
Systematic name | M32669
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1470 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR598_3P
Systematic name | M32670
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-598-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4787_5P
Systematic name | M32671
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4787-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8074
Systematic name | M32672
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8074 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR128_1_5P
Systematic name | M32673
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-128-1-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR548AL
Systematic name | M32674
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-548al in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6795_3P
Systematic name | M32675
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6795-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6765_5P
Systematic name | M32676
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6765-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3960_MIR8072
Systematic name | M32677
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3960, hsa-miR-8072 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR100_5P_MIR99A_5P_MIR99B_5P
Systematic name | M32678
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-100-5p, hsa-miR-99a-5p, hsa-miR-99b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7112_5P
Systematic name | M32679
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7112-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR128_2_5P
Systematic name | M32680
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-128-2-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4445_3P
Systematic name | M32681
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4445-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4315
Systematic name | M32682
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4315 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR136_3P
Systematic name | M32683
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-136-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6854_3P
Systematic name | M32684
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6854-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4497
Systematic name | M32685
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4497 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10396A_5P
Systematic name | M32686
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10396a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6089
Systematic name | M32687
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6089 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7108_3P
Systematic name | M32688
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7108-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR483_5P
Systematic name | M32689
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-483-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6729_5P
Systematic name | M32690
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6729-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10399_3P
Systematic name | M32691
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10399-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7706
Systematic name | M32692
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7706 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR122_3P
Systematic name | M32693
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-122-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6125
Systematic name | M32694
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6125 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6820_5P
Systematic name | M32695
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6820-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4520_5P
Systematic name | M32696
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4520-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4798_3P
Systematic name | M32697
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4798-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4442
Systematic name | M32698
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4442 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1180_3P
Systematic name | M32700
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1180-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4781_5P
Systematic name | M32701
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4781-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3193
Systematic name | M32702
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3193 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR371A_3P
Systematic name | M32703
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-371a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6090
Systematic name | M32704
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6090 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR95_3P
Systematic name | M32705
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-95-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR487B_3P
Systematic name | M32706
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-487b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR433_5P
Systematic name | M32707
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-433-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7D_3P
Systematic name | M32708
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7d-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3912_3P
Systematic name | M32709
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3912-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4485_5P
Systematic name | M32710
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4485-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4669
Systematic name | M32711
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4669 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR602
Systematic name | M32712
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-602 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR887_3P
Systematic name | M32713
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-887-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5739
Systematic name | M32714
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5739 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR553
Systematic name | M32715
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-553 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR92B_5P
Systematic name | M32716
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-92b-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR11401
Systematic name | M32717
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-11401 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4746_5P
Systematic name | M32720
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4746-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6814_3P_MIR6872_5P
Systematic name | M32721
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6814-3p, hsa-miR-6872-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR184
Systematic name | M32722
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-184 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10392_3P
Systematic name | M32723
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10392-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR8053
Systematic name | M32724
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-8053 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR132_5P
Systematic name | M32725
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-132-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6788_3P
Systematic name | M32726
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6788-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR147B_3P
Systematic name | M32727
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-147b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR11400
Systematic name | M32728
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-11400 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1204
Systematic name | M32729
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1204 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1268A_MIR1268B
Systematic name | M32730
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1268a, hsa-miR-1268b in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6853_5P
Systematic name | M32731
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6853-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3615
Systematic name | M32734
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3615 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5092
Systematic name | M32735
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5092 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10401_3P
Systematic name | M32736
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10401-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6886_5P
Systematic name | M32737
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6886-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4804_5P
Systematic name | M32739
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4804-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6777_5P
Systematic name | M32740
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6777-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1537_3P
Systematic name | M32741
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1537-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR551A_MIR551B_3P
Systematic name | M32742
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-551a, hsa-miR-551b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10398_3P
Systematic name | M32744
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10398-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4649_5P
Systematic name | M32745
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4649-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1539
Systematic name | M32746
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1539 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1250_5P
Systematic name | M32748
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1250-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR518A_3P_MIR518B_MIR518C_3P_MIR518D_3P_MIR518F_3P_MIR526A_3P
Systematic name | M32749
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-518a-3p, hsa-miR-518b, hsa-miR-518c-3p, hsa-miR-518d-3p, hsa-miR-518f-3p, hsa-miR-526a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR381_5P
Systematic name | M32751
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-381-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4671_5P
Systematic name | M32752
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4671-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1973
Systematic name | M32753
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1973 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR5705
Systematic name | M32754
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-5705 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4740_3P
Systematic name | M32755
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4740-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6775_5P
Systematic name | M32757
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6775-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3197
Systematic name | M32758
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3197 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3186_5P
Systematic name | M32759
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3186-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6774_3P
Systematic name | M32760
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6774-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3683
Systematic name | M32763
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3683 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR181A_3P
Systematic name | M32764
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-181a-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4636
Systematic name | M32765
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4636 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR7704
Systematic name | M32766
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-7704 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4321
Systematic name | M32767
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4321 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3677_3P
Systematic name | M32768
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3677-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR615_3P
Systematic name | M32769
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-615-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4681
Systematic name | M32770
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4681 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6717_5P
Systematic name | M32773
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6717-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR3177_3P
Systematic name | M32776
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-3177-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR101_2_5P
Systematic name | M32779
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-101-2-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR196B_3P
Systematic name | M32780
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-196b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4258
Systematic name | M32781
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4258 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4537
Systematic name | M32783
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4537 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR516A_5P
Systematic name | M32786
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-516a-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1247_5P
Systematic name | M32788
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1247-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4737
Systematic name | M32789
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4737 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR105_3P
Systematic name | M32790
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-105-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR662
Systematic name | M32791
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-662 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4444
Systematic name | M32792
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4444 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1273C
Systematic name | M32793
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1273c in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR652_3P
Systematic name | M32795
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-652-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR1203
Systematic name | M32796
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-1203 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR127_3P
Systematic name | M32797
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-127-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR10396A_3P_MIR10396B_3P
Systematic name | M32798
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-10396a-3p, hsa-miR-10396b-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6746_5P
Systematic name | M32800
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6746-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR25_5P
Systematic name | M32810
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-25-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7E_3P
Systematic name | M32812
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7e-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6770_3P
Systematic name | M32813
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6770-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR9899
Systematic name | M32816
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-9899 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR412_5P
Systematic name | M32817
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-412-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR451A
Systematic name | M32818
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-451a in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR574_3P
Systematic name | M32822
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-574-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4749_5P
Systematic name | M32825
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4749-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6741_3P
Systematic name | M32828
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6741-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4638_5P
Systematic name | M32830
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4638-5p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR6790_3P
Systematic name | M32838
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-6790-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | MIR4440
Systematic name | M32839
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-miR-4440 in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | LET_7I_3P
Systematic name | M32840
Organism | Homo sapiens
PMID | 31504780
Authors |
Category | C3
Sub-category | MIR:MIRDB
Brief description | Genes predicted to be targets of miRBase v22 microRNA hsa-let-7i-3p in miRDB v6.0 with MirTarget v4 prediction scores > 80 (high confidence targets).
Full description |

Standard name | AGCACTT_MIR93_MIR302A_MIR302B_MIR302C_MIR302D_MIR372_MIR373_MIR520E_MIR520A_MIR526B_MIR520B_MIR520C_MIR520D
Systematic name | M7785
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGCACTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-93, hsa-miR-302a, hsa-miR-302b, hsa-miR-302c, hsa-miR-302d, hsa-miR-372, hsa-miR-373, hsa-miR-520e, hsa-miR-520a, hsa-miR-526b*, hsa-miR-520b, hsa-miR-520c and hsa-miR-520d (v7.1 miRBase).
Full description |

Standard name | CTACCTC_LET7A_LET7B_LET7C_LET7D_LET7E_LET7F_MIR98_LET7G_LET7I
Systematic name | M6394
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTACCTC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-let-7a, hsa-let-7b, hsa-let-7c, hsa-let-7d, hsa-let-7e, hsa-let-7f, hsa-miR-98, hsa-let-7g and hsa-let-7i (v7.1 miRBase).
Full description |

Standard name | GCACTTT_MIR175P_MIR20A_MIR106A_MIR106B_MIR20B_MIR519D
Systematic name | M18759
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCACTTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-17-5p, hsa-miR-20a, hsa-miR-106a, hsa-miR-106b, hsa-miR-20b and hsa-miR-519d (v7.1 miRBase).
Full description |

Standard name | TGCTGCT_MIR15A_MIR16_MIR15B_MIR195_MIR424_MIR497
Systematic name | M10635
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGCTGCT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-15a, hsa-miR-16, hsa-miR-15b, hsa-miR-195, hsa-miR-424 and hsa-miR-497 (v7.1 miRBase).
Full description |

Standard name | TGTTTAC_MIR30A5P_MIR30C_MIR30D_MIR30B_MIR30E5P
Systematic name | M14709
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGTTTAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-30a-5p, hsa-miR-30c, hsa-miR-30d, hsa-miR-30b and hsa-miR-30e-5p (v7.1 miRBase).
Full description |

Standard name | GTGCAAT_MIR25_MIR32_MIR92_MIR363_MIR367
Systematic name | M4820
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTGCAAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-25, hsa-miR-32, hsa-miR-92, hsa-miR-363 and hsa-miR-367 (v7.1 miRBase).
Full description |

Standard name | TGAATGT_MIR181A_MIR181B_MIR181C_MIR181D
Systematic name | M7677
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGAATGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-181a, hsa-miR-181b, hsa-miR-181c and hsa-miR-181d (v7.1 miRBase).
Full description |

Standard name | GCGCTTT_MIR518B_MIR518C_MIR518D
Systematic name | M11751
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCGCTTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-518b, hsa-miR-518c and hsa-miR-518d (v7.1 miRBase).
Full description |

Standard name | TGGTGCT_MIR29A_MIR29B_MIR29C
Systematic name | M10105
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGGTGCT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-29a, hsa-miR-29b and hsa-miR-29c (v7.1 miRBase).
Full description |

Standard name | TGCACTG_MIR148A_MIR152_MIR148B
Systematic name | M5012
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGCACTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-148a, hsa-miR-152 and hsa-miR-148b (v7.1 miRBase).
Full description |

Standard name | CACTGCC_MIR34A_MIR34C_MIR449
Systematic name | M19534
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CACTGCC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-34a, hsa-miR-34c and hsa-miR-449 (v7.1 miRBase).
Full description |

Standard name | TACGGGT_MIR99A_MIR100_MIR99B
Systematic name | M7768
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TACGGGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-99a, hsa-miR-100 and hsa-miR-99b (v7.1 miRBase).
Full description |

Standard name | CTCTAGA_MIR526C_MIR518F_MIR526A
Systematic name | M12019
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTCTAGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-526c, hsa-miR-518f* and hsa-miR-526a (v7.1 miRBase).
Full description |

Standard name | TTGCACT_MIR130A_MIR301_MIR130B
Systematic name | M8862
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TTGCACT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-130a, hsa-miR-301 and hsa-miR-130b (v7.1 miRBase).
Full description |

Standard name | TGCACTT_MIR519C_MIR519B_MIR519A
Systematic name | M10705
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGCACTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-519c, hsa-miR-519b and hsa-miR-519a (v7.1 miRBase).
Full description |

Standard name | AGCGCTT_MIR518F_MIR518E_MIR518A
Systematic name | M12158
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGCGCTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-518f, hsa-miR-518e and hsa-miR-518a (v7.1 miRBase).
Full description |

Standard name | CAGTATT_MIR200B_MIR200C_MIR429
Systematic name | M19078
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAGTATT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-200b, hsa-miR-200c and hsa-miR-429 (v7.1 miRBase).
Full description |

Standard name | ACATTCC_MIR1_MIR206
Systematic name | M13555
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACATTCC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-1 and hsa-miR-206 (v7.1 miRBase).
Full description |

Standard name | AAGTCCA_MIR422B_MIR422A
Systematic name | M10743
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AAGTCCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-422b and hsa-miR-422a (v7.1 miRBase).
Full description |

Standard name | AAAGGGA_MIR204_MIR211
Systematic name | M13700
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AAAGGGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-204 and hsa-miR-211 (v7.1 miRBase).
Full description |

Standard name | AATGTGA_MIR23A_MIR23B
Systematic name | M8758
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AATGTGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-23a and hsa-miR-23b (v7.1 miRBase).
Full description |

Standard name | CACTGTG_MIR128A_MIR128B
Systematic name | M7662
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CACTGTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-128a and hsa-miR-128b (v7.1 miRBase).
Full description |

Standard name | ACTGAAA_MIR30A3P_MIR30E3P
Systematic name | M5238
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACTGAAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-30a-3p and hsa-miR-30e-3p (v7.1 miRBase).
Full description |

Standard name | CTCAGGG_MIR125B_MIR125A
Systematic name | M3398
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTCAGGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-125b and hsa-miR-125a (v7.1 miRBase).
Full description |

Standard name | TACTTGA_MIR26A_MIR26B
Systematic name | M9307
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TACTTGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-26a and hsa-miR-26b (v7.1 miRBase).
Full description |

Standard name | TCTATGA_MIR376A_MIR376B
Systematic name | M8740
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCTATGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-376a and hsa-miR-376b (v7.1 miRBase).
Full description |

Standard name | GTATGAT_MIR154_MIR487
Systematic name | M15360
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTATGAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-154* and hsa-miR-487 (v7.1 miRBase).
Full description |

Standard name | CAGTGTT_MIR141_MIR200A
Systematic name | M19022
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAGTGTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-141 and hsa-miR-200a (v7.1 miRBase).
Full description |

Standard name | AGTTCTC_MIR146A_MIR146B
Systematic name | M981
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGTTCTC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-146a and hsa-miR-146b (v7.1 miRBase).
Full description |

Standard name | TAGGTCA_MIR192_MIR215
Systematic name | M8771
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TAGGTCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-192 and hsa-miR-215 (v7.1 miRBase).
Full description |

Standard name | ATGTAGC_MIR221_MIR222
Systematic name | M17985
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATGTAGC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-221 and hsa-miR-222 (v7.1 miRBase).
Full description |

Standard name | ACTGTGA_MIR27A_MIR27B
Systematic name | M8329
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACTGTGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-27a and hsa-miR-27b (v7.1 miRBase).
Full description |

Standard name | TGCACGA_MIR517A_MIR517C
Systematic name | M7557
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGCACGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-517a and hsa-miR-517c (v7.1 miRBase).
Full description |

Standard name | TTTGCAC_MIR19A_MIR19B
Systematic name | M16238
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TTTGCAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-19a and hsa-miR-19b (v7.1 miRBase).
Full description |

Standard name | ACTACCT_MIR196A_MIR196B
Systematic name | M10291
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACTACCT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-196a and hsa-miR-196b (v7.1 miRBase).
Full description |

Standard name | TTGGAGA_MIR5155P_MIR519E
Systematic name | M1425
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TTGGAGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-515-5p and hsa-miR-519e* (v7.1 miRBase).
Full description |

Standard name | CACTTTG_MIR520G_MIR520H
Systematic name | M698
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CACTTTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-520g and hsa-miR-520h (v7.1 miRBase).
Full description |

Standard name | GGGACCA_MIR133A_MIR133B
Systematic name | M10098
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGGACCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-133a and hsa-miR-133b (v7.1 miRBase).
Full description |

Standard name | GACTGTT_MIR212_MIR132
Systematic name | M8005
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GACTGTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-212 and hsa-miR-132 (v7.1 miRBase).
Full description |

Standard name | AAGCCAT_MIR135A_MIR135B
Systematic name | M10975
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AAGCCAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-135a and hsa-miR-135b (v7.1 miRBase).
Full description |

Standard name | ATGCTGC_MIR103_MIR107
Systematic name | M6070
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATGCTGC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-103 and hsa-miR-107 (v7.1 miRBase).
Full description |

Standard name | ACAGGGT_MIR10A_MIR10B
Systematic name | M9409
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACAGGGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-10a and hsa-miR-10b (v7.1 miRBase).
Full description |

Standard name | CTCTGGA_MIR520A_MIR525
Systematic name | M4317
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTCTGGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-520a* and hsa-miR-525 (v7.1 miRBase).
Full description |

Standard name | GCGCCTT_MIR525_MIR524
Systematic name | M7085
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCGCCTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-525* and hsa-miR-524 (v7.1 miRBase).
Full description |

Standard name | ACACTGG_MIR199A_MIR199B
Systematic name | M19379
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACACTGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-199a and hsa-miR-199b (v7.1 miRBase).
Full description |

Standard name | GCACCTT_MIR18A_MIR18B
Systematic name | M1010
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCACCTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-18a and hsa-miR-18b (v7.1 miRBase).
Full description |

Standard name | GGCCAGT_MIR193A_MIR193B
Systematic name | M2722
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGCCAGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNAs hsa-miR-193a and hsa-miR-193b (v7.1 miRBase).
Full description |

Standard name | CGCTGCT_MIR503
Systematic name | M19501
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CGCTGCT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-503 (v7.1 miRBase).
Full description |

Standard name | TCTGATC_MIR383
Systematic name | M19087
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCTGATC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-383 (v7.1 miRBase).
Full description |

Standard name | GTGCCTT_MIR506
Systematic name | M12100
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTGCCTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-506 (v7.1 miRBase).
Full description |

Standard name | ACAACTT_MIR382
Systematic name | M7604
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACAACTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-382 (v7.1 miRBase).
Full description |

Standard name | ATGTTAA_MIR302C
Systematic name | M11880
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATGTTAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-302c* (v7.1 miRBase).
Full description |

Standard name | GGATCCG_MIR127
Systematic name | M16800
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGATCCG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-127 (v7.1 miRBase).
Full description |

Standard name | CATTTCA_MIR203
Systematic name | M1248
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CATTTCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-203 (v7.1 miRBase).
Full description |

Standard name | TCCAGAT_MIR5165P
Systematic name | M14510
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCCAGAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-516-5p (v7.1 miRBase).
Full description |

Standard name | AGTCAGC_MIR345
Systematic name | M15251
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGTCAGC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-345 (v7.1 miRBase).
Full description |

Standard name | ACACTCC_MIR122A
Systematic name | M16508
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACACTCC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-122a (v7.1 miRBase).
Full description |

Standard name | GTGTGAG_MIR342
Systematic name | M16629
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTGTGAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-342 (v7.1 miRBase).
Full description |

Standard name | CTAGGAA_MIR384
Systematic name | M12179
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTAGGAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-384 (v7.1 miRBase).
Full description |

Standard name | CTATGCA_MIR153
Systematic name | M11567
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTATGCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-153 (v7.1 miRBase).
Full description |

Standard name | AGGGCAG_MIR18A
Systematic name | M9715
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGGGCAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-18a* (v7.1 miRBase).
Full description |

Standard name | GTGCCAT_MIR183
Systematic name | M9559
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTGCCAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-183 (v7.1 miRBase).
Full description |

Standard name | ACTGCAG_MIR173P
Systematic name | M11571
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACTGCAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-17-3p (v7.1 miRBase).
Full description |

Standard name | GTTTGTT_MIR495
Systematic name | M6405
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTTTGTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-495 (v7.1 miRBase).
Full description |

Standard name | TATTATA_MIR374
Systematic name | M11229
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TATTATA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-374 (v7.1 miRBase).
Full description |

Standard name | CTTGTAT_MIR381
Systematic name | M7348
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTTGTAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-381 (v7.1 miRBase).
Full description |

Standard name | AAAGGAT_MIR501
Systematic name | M3708
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AAAGGAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-501 (v7.1 miRBase).
Full description |

Standard name | GGGGCCC_MIR296
Systematic name | M18279
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGGGCCC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-296 (v7.1 miRBase).
Full description |

Standard name | CTACTGT_MIR199A
Systematic name | M3598
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTACTGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-199a* (v7.1 miRBase).
Full description |

Standard name | CAAGGAT_MIR362
Systematic name | M14975
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAAGGAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-362 (v7.1 miRBase).
Full description |

Standard name | GTGTTGA_MIR505
Systematic name | M13162
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTGTTGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-505 (v7.1 miRBase).
Full description |

Standard name | ATACTGT_MIR144
Systematic name | M19058
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATACTGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-144 (v7.1 miRBase).
Full description |

Standard name | TGTATGA_MIR4853P
Systematic name | M7949
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGTATGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-485-3p (v7.1 miRBase).
Full description |

Standard name | GTATTAT_MIR3693P
Systematic name | M18289
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTATTAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-369-3p (v7.1 miRBase).
Full description |

Standard name | TCCCCAC_MIR491
Systematic name | M13344
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCCCCAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-491 (v7.1 miRBase).
Full description |

Standard name | GCTTGAA_MIR498
Systematic name | M5894
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCTTGAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-498 (v7.1 miRBase).
Full description |

Standard name | GTGGTGA_MIR197
Systematic name | M6598
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTGGTGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-197 (v7.1 miRBase).
Full description |

Standard name | GGGCATT_MIR365
Systematic name | M12358
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGGCATT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-365 (v7.1 miRBase).
Full description |

Standard name | TGAGATT_MIR216
Systematic name | M14678
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGAGATT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-216 (v7.1 miRBase).
Full description |

Standard name | GTCAACC_MIR3805P
Systematic name | M18851
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTCAACC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-380-5p (v7.1 miRBase).
Full description |

Standard name | GGTGAAG_MIR412
Systematic name | M15246
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGTGAAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-412 (v7.1 miRBase).
Full description |

Standard name | AGGGCCA_MIR328
Systematic name | M8607
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGGGCCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-328 (v7.1 miRBase).
Full description |

Standard name | GTGACTT_MIR224
Systematic name | M15750
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTGACTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-224 (v7.1 miRBase).
Full description |

Standard name | GAGACTG_MIR452
Systematic name | M5794
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GAGACTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-452* (v7.1 miRBase).
Full description |

Standard name | CAGGGTC_MIR504
Systematic name | M4054
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAGGGTC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-504 (v7.1 miRBase).
Full description |

Standard name | GCTCTTG_MIR335
Systematic name | M19315
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCTCTTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-335 (v7.1 miRBase).
Full description |

Standard name | TCGATGG_MIR213
Systematic name | M11990
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCGATGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-213 (v7.1 miRBase).
Full description |

Standard name | GTCTTCC_MIR7
Systematic name | M9541
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTCTTCC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-7 (v7.1 miRBase).
Full description |

Standard name | ATAACCT_MIR154
Systematic name | M14869
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATAACCT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-154 (v7.1 miRBase).
Full description |

Standard name | TCTAGAG_MIR517
Systematic name | M2373
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCTAGAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-517* (v7.1 miRBase).
Full description |

Standard name | GGCAGAC_MIR346
Systematic name | M6914
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGCAGAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-346 (v7.1 miRBase).
Full description |

Standard name | AGGCACT_MIR5153P
Systematic name | M11881
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGGCACT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-515-3p (v7.1 miRBase).
Full description |

Standard name | ATAGGAA_MIR202
Systematic name | M7292
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATAGGAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-202* (v7.1 miRBase).
Full description |

Standard name | CCAGGTT_MIR490
Systematic name | M15045
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CCAGGTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-490 (v7.1 miRBase).
Full description |

Standard name | TTGCCAA_MIR182
Systematic name | M3916
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TTGCCAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-182 (v7.1 miRBase).
Full description |

Standard name | CGGTGTG_MIR220
Systematic name | M18675
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CGGTGTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-220 (v7.1 miRBase).
Full description |

Standard name | TAGCTTT_MIR9
Systematic name | M4376
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TAGCTTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-9* (v7.1 miRBase).
Full description |

Standard name | CTGAGCC_MIR24
Systematic name | M17346
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTGAGCC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-24 (v7.1 miRBase).
Full description |

Standard name | TTGGGAG_MIR150
Systematic name | M11872
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TTGGGAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-150 (v7.1 miRBase).
Full description |

Standard name | AAACCAC_MIR140
Systematic name | M12609
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AAACCAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-140 (v7.1 miRBase).
Full description |

Standard name | CCCACAT_MIR2993P
Systematic name | M43
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CCCACAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-299-3p (v7.1 miRBase).
Full description |

Standard name | ATGTTTC_MIR494
Systematic name | M16831
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATGTTTC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-494 (v7.1 miRBase).
Full description |

Standard name | GTACTGT_MIR101
Systematic name | M4725
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTACTGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-101 (v7.1 miRBase).
Full description |

Standard name | CAGGTCC_MIR492
Systematic name | M11517
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAGGTCC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-492 (v7.1 miRBase).
Full description |

Standard name | GAGCCTG_MIR484
Systematic name | M7743
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GAGCCTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-484 (v7.1 miRBase).
Full description |

Standard name | GTAAGAT_MIR200A
Systematic name | M8557
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTAAGAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-200a* (v7.1 miRBase).
Full description |

Standard name | TCCGTCC_MIR184
Systematic name | M1672
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCCGTCC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-184 (v7.1 miRBase).
Full description |

Standard name | CACGTTT_MIR302A
Systematic name | M5140
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CACGTTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-302a* (v7.1 miRBase).
Full description |

Standard name | TATCTGG_MIR488
Systematic name | M13828
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TATCTGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-488 (v7.1 miRBase).
Full description |

Standard name | AGGAAGC_MIR5163P
Systematic name | M10126
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGGAAGC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-516-3p (v7.1 miRBase).
Full description |

Standard name | ACGCACA_MIR210
Systematic name | M9471
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACGCACA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-210 (v7.1 miRBase).
Full description |

Standard name | ATATGCA_MIR448
Systematic name | M8437
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATATGCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-448 (v7.1 miRBase).
Full description |

Standard name | AATGGAG_MIR136
Systematic name | M1161
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AATGGAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-136 (v7.1 miRBase).
Full description |

Standard name | CCTGTGA_MIR513
Systematic name | M13164
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CCTGTGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-513 (v7.1 miRBase).
Full description |

Standard name | AACGGTT_MIR451
Systematic name | M4394
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AACGGTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-451 (v7.1 miRBase).
Full description |

Standard name | ATGAAGG_MIR205
Systematic name | M19591
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATGAAGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-205 (v7.1 miRBase).
Full description |

Standard name | CTCAAGA_MIR526B
Systematic name | M15899
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTCAAGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-526b (v7.1 miRBase).
Full description |

Standard name | GGCAGCT_MIR22
Systematic name | M8640
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGCAGCT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-22 (v7.1 miRBase).
Full description |

Standard name | TCTGGAC_MIR198
Systematic name | M9601
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCTGGAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-198 (v7.1 miRBase).
Full description |

Standard name | CAGCTTT_MIR320
Systematic name | M17789
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAGCTTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-320 (v7.1 miRBase).
Full description |

Standard name | CCATCCA_MIR432
Systematic name | M11746
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CCATCCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-432* (v7.1 miRBase).
Full description |

Standard name | CATGTAA_MIR496
Systematic name | M3125
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CATGTAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-496 (v7.1 miRBase).
Full description |

Standard name | AAGCACA_MIR218
Systematic name | M18083
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AAGCACA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-218 (v7.1 miRBase).
Full description |

Standard name | GCAAGAC_MIR431
Systematic name | M2165
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCAAGAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-431 (v7.1 miRBase).
Full description |

Standard name | ATGTCAC_MIR489
Systematic name | M15505
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATGTCAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-489 (v7.1 miRBase).
Full description |

Standard name | CCTGCTG_MIR214
Systematic name | M3043
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CCTGCTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-214 (v7.1 miRBase).
Full description |

Standard name | GTCTACC_MIR379
Systematic name | M11030
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTCTACC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-379 (v7.1 miRBase).
Full description |

Standard name | CTACTAG_MIR325
Systematic name | M9976
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTACTAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-325 (v7.1 miRBase).
Full description |

Standard name | CCTGAGT_MIR510
Systematic name | M1853
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CCTGAGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-510 (v7.1 miRBase).
Full description |

Standard name | GACAGGG_MIR339
Systematic name | M2190
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GACAGGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-339 (v7.1 miRBase).
Full description |

Standard name | ATACCTC_MIR202
Systematic name | M10873
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATACCTC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-202 (v7.1 miRBase).
Full description |

Standard name | GGCAGTG_MIR3243P
Systematic name | M1385
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGCAGTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-324-3p (v7.1 miRBase).
Full description |

Standard name | GAGCCAG_MIR149
Systematic name | M2014
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GAGCCAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-149 (v7.1 miRBase).
Full description |

Standard name | TCTCTCC_MIR185
Systematic name | M9681
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCTCTCC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-185 (v7.1 miRBase).
Full description |

Standard name | AGCATTA_MIR155
Systematic name | M16199
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGCATTA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-155 (v7.1 miRBase).
Full description |

Standard name | GCAAAAA_MIR129
Systematic name | M3056
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCAAAAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-129 (v7.1 miRBase).
Full description |

Standard name | GGCACAT_MIR455
Systematic name | M869
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGCACAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-455 (v7.1 miRBase).
Full description |

Standard name | GTCGATC_MIR3695P
Systematic name | M16348
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTCGATC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-369-5p (v7.1 miRBase).
Full description |

Standard name | GGCGGCA_MIR371
Systematic name | M15158
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGCGGCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-371 (v7.1 miRBase).
Full description |

Standard name | CTTTGTA_MIR524
Systematic name | M1567
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTTTGTA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-524* (v7.1 miRBase).
Full description |

Standard name | CTGTTAC_MIR194
Systematic name | M18709
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTGTTAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-194 (v7.1 miRBase).
Full description |

Standard name | ATGCAGT_MIR217
Systematic name | M11416
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATGCAGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-217 (v7.1 miRBase).
Full description |

Standard name | ATGCTGG_MIR338
Systematic name | M13945
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATGCTGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-338 (v7.1 miRBase).
Full description |

Standard name | ACATATC_MIR190
Systematic name | M13961
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACATATC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-190 (v7.1 miRBase).
Full description |

Standard name | CTCCAAG_MIR432
Systematic name | M4329
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTCCAAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-432 (v7.1 miRBase).
Full description |

Standard name | AAGCAAT_MIR137
Systematic name | M10261
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AAGCAAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-137 (v7.1 miRBase).
Full description |

Standard name | ACCAAAG_MIR9
Systematic name | M9822
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACCAAAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-9 (v7.1 miRBase).
Full description |

Standard name | TTTGTAG_MIR520D
Systematic name | M10821
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TTTGTAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-520d* (v7.1 miRBase).
Full description |

Standard name | TGCCTTA_MIR124A
Systematic name | M15942
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGCCTTA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-124a (v7.1 miRBase).
Full description |

Standard name | AACTGAC_MIR223
Systematic name | M8369
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AACTGAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-223 (v7.1 miRBase).
Full description |

Standard name | AAAGACA_MIR511
Systematic name | M13551
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AAAGACA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-511 (v7.1 miRBase).
Full description |

Standard name | ATAAGCT_MIR21
Systematic name | M19659
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATAAGCT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-21 (v7.1 miRBase).
Full description |

Standard name | TCTGATA_MIR361
Systematic name | M4881
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCTGATA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-361 (v7.1 miRBase).
Full description |

Standard name | TACAATC_MIR508
Systematic name | M11441
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TACAATC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-508 (v7.1 miRBase).
Full description |

Standard name | ACTTTAT_MIR1425P
Systematic name | M14923
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACTTTAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-142-5p (v7.1 miRBase).
Full description |

Standard name | TTTGCAG_MIR518A2
Systematic name | M2229
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TTTGCAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-518a-2* (v7.1 miRBase).
Full description |

Standard name | AACATTC_MIR4093P
Systematic name | M17222
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AACATTC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-409-3p (v7.1 miRBase).
Full description |

Standard name | ACAACCT_MIR453
Systematic name | M5402
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACAACCT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-453 (v7.1 miRBase).
Full description |

Standard name | GTGCCAA_MIR96
Systematic name | M7598
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTGCCAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-96 (v7.1 miRBase).
Full description |

Standard name | TCATCTC_MIR143
Systematic name | M8732
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCATCTC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-143 (v7.1 miRBase).
Full description |

Standard name | GAGCTGG_MIR337
Systematic name | M3637
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GAGCTGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-337 (v7.1 miRBase).
Full description |

Standard name | AGTCTAG_MIR151
Systematic name | M4826
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGTCTAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-151 (v7.1 miRBase).
Full description |

Standard name | AGTCTTA_MIR499
Systematic name | M12207
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGTCTTA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-499 (v7.1 miRBase).
Full description |

Standard name | CCCAGAG_MIR326
Systematic name | M1505
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CCCAGAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-326 (v7.1 miRBase).
Full description |

Standard name | GCTGAGT_MIR5125P
Systematic name | M6666
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCTGAGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-512-5p (v7.1 miRBase).
Full description |

Standard name | ACCATTT_MIR522
Systematic name | M4610
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACCATTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-522 (v7.1 miRBase).
Full description |

Standard name | AGCTCCT_MIR28
Systematic name | M1622
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGCTCCT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-28 (v7.1 miRBase).
Full description |

Standard name | AGCGCAG_MIR191
Systematic name | M15646
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGCGCAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-191* (v7.1 miRBase).
Full description |

Standard name | ACTGCCT_MIR34B
Systematic name | M7082
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACTGCCT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-34b (v7.1 miRBase).
Full description |

Standard name | GTTAAAG_MIR302B
Systematic name | M11305
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTTAAAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-302b* (v7.1 miRBase).
Full description |

Standard name | GACAATC_MIR219
Systematic name | M7344
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GACAATC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-219 (v7.1 miRBase).
Full description |

Standard name | CGCAAAA_MIR450
Systematic name | M14128
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CGCAAAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-450 (v7.1 miRBase).
Full description |

Standard name | AACTGGA_MIR145
Systematic name | M15956
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AACTGGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-145 (v7.1 miRBase).
Full description |

Standard name | AAGCACT_MIR520F
Systematic name | M7004
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AAGCACT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-520f (v7.1 miRBase).
Full description |

Standard name | AGGAGTG_MIR483
Systematic name | M13581
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGGAGTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-483 (v7.1 miRBase).
Full description |

Standard name | GTGTCAA_MIR514
Systematic name | M2735
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTGTCAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-514 (v7.1 miRBase).
Full description |

Standard name | GCAAGGA_MIR502
Systematic name | M11180
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCAAGGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-502 (v7.1 miRBase).
Full description |

Standard name | AGGTGCA_MIR500
Systematic name | M18275
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGGTGCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-500 (v7.1 miRBase).
Full description |

Standard name | ACTGTAG_MIR139
Systematic name | M5550
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACTGTAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-139 (v7.1 miRBase).
Full description |

Standard name | GTGCAAA_MIR507
Systematic name | M2865
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTGCAAA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-507 (v7.1 miRBase).
Full description |

Standard name | TGCTTTG_MIR330
Systematic name | M4556
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGCTTTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-330 (v7.1 miRBase).
Full description |

Standard name | TTTTGAG_MIR373
Systematic name | M681
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TTTTGAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-373* (v7.1 miRBase).
Full description |

Standard name | TAGAACC_MIR182
Systematic name | M8902
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TAGAACC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-182* (v7.1 miRBase).
Full description |

Standard name | GGGATGC_MIR3245P
Systematic name | M18563
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGGATGC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-324-5p (v7.1 miRBase).
Full description |

Standard name | CCAGGGG_MIR331
Systematic name | M15492
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CCAGGGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-331 (v7.1 miRBase).
Full description |

Standard name | ACCAATC_MIR509
Systematic name | M12356
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACCAATC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-509 (v7.1 miRBase).
Full description |

Standard name | GGCACTT_MIR519E
Systematic name | M9714
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGCACTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-519e (v7.1 miRBase).
Full description |

Standard name | ATGTACA_MIR493
Systematic name | M17260
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATGTACA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-493 (v7.1 miRBase).
Full description |

Standard name | GCATTTG_MIR105
Systematic name | M6957
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GCATTTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-105 (v7.1 miRBase).
Full description |

Standard name | CAGTCAC_MIR134
Systematic name | M9656
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAGTCAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-134 (v7.1 miRBase).
Full description |

Standard name | TCCAGAG_MIR518C
Systematic name | M1468
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TCCAGAG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-518c* (v7.1 miRBase).
Full description |

Standard name | CACCAGC_MIR138
Systematic name | M11557
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CACCAGC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-138 (v7.1 miRBase).
Full description |

Standard name | CAGCACT_MIR5123P
Systematic name | M7107
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAGCACT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-512-3p (v7.1 miRBase).
Full description |

Standard name | GTACAGG_MIR486
Systematic name | M11599
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTACAGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-486 (v7.1 miRBase).
Full description |

Standard name | GTTATAT_MIR410
Systematic name | M8718
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTTATAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-410 (v7.1 miRBase).
Full description |

Standard name | GTCAGGA_MIR378
Systematic name | M15734
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTCAGGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-378 (v7.1 miRBase).
Full description |

Standard name | ACACTAC_MIR1423P
Systematic name | M6643
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACACTAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-142-3p (v7.1 miRBase).
Full description |

Standard name | ATTCTTT_MIR186
Systematic name | M13688
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATTCTTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-186 (v7.1 miRBase).
Full description |

Standard name | CTCTATG_MIR368
Systematic name | M16260
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTCTATG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-368 (v7.1 miRBase).
Full description |

Standard name | ACCGAGC_MIR423
Systematic name | M15670
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ACCGAGC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-423 (v7.1 miRBase).
Full description |

Standard name | TGTGTGA_MIR377
Systematic name | M1329
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGTGTGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-377 (v7.1 miRBase).
Full description |

Standard name | ATCATGA_MIR433
Systematic name | M14789
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATCATGA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-433 (v7.1 miRBase).
Full description |

Standard name | CAGCAGG_MIR370
Systematic name | M12382
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAGCAGG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-370 (v7.1 miRBase).
Full description |

Standard name | CTTTGCA_MIR527
Systematic name | M2927
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CTTTGCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-527 (v7.1 miRBase).
Full description |

Standard name | GGTGTGT_MIR329
Systematic name | M10403
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGTGTGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-329 (v7.1 miRBase).
Full description |

Standard name | ATTACAT_MIR3803P
Systematic name | M13326
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATTACAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-380-3p (v7.1 miRBase).
Full description |

Standard name | CGTCTTA_MIR208
Systematic name | M15737
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CGTCTTA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-208 (v7.1 miRBase).
Full description |

Standard name | ATCTTGC_MIR31
Systematic name | M17589
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATCTTGC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-31 (v7.1 miRBase).
Full description |

Standard name | AAGGGAT_MIR188
Systematic name | M4681
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AAGGGAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-188 (v7.1 miRBase).
Full description |

Standard name | TGCAAAC_MIR452
Systematic name | M9999
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TGCAAAC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-452 (v7.1 miRBase).
Full description |

Standard name | CAGCCTC_MIR4855P
Systematic name | M16058
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAGCCTC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-485-5p (v7.1 miRBase).
Full description |

Standard name | GTAAACC_MIR2995P
Systematic name | M16323
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTAAACC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-299-5p (v7.1 miRBase).
Full description |

Standard name | GGTAACC_MIR4095P
Systematic name | M9561
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GGTAACC in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-409-5p (v7.1 miRBase).
Full description |

Standard name | TAATAAT_MIR126
Systematic name | M10318
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TAATAAT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-126* (v7.1 miRBase).
Full description |

Standard name | ATGCACG_MIR517B
Systematic name | M18425
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif ATGCACG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-517b (v7.1 miRBase).
Full description |

Standard name | CCACACA_MIR147
Systematic name | M2305
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CCACACA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-147 (v7.1 miRBase).
Full description |

Standard name | TAATGTG_MIR323
Systematic name | M15124
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TAATGTG in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-323 (v7.1 miRBase).
Full description |

Standard name | TTCCGTT_MIR191
Systematic name | M10745
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif TTCCGTT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-191 (v7.1 miRBase).
Full description |

Standard name | AGTGCGT_MIR521
Systematic name | M7945
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif AGTGCGT in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-521 (v7.1 miRBase).
Full description |

Standard name | CAATGCA_MIR33
Systematic name | M13234
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif CAATGCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-33 (v7.1 miRBase).
Full description |

Standard name | GTAGGCA_MIR189
Systematic name | M7364
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | MIR:MIR_Legacy
Brief description | Genes having at least one occurence of the motif GTAGGCA in their 3' untranslated region. The motif represents putative target (that is, seed match) of human mature miRNA hsa-miR-189 (v7.1 miRBase).
Full description |

Standard name | AAANWWTGC_UNKNOWN
Systematic name | M3128
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M144 AAANWWTGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | AAAYRNCTG_UNKNOWN
Systematic name | M11607
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M77 AAAYRNCTG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | MYOD_01
Systematic name | M12599
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYOD_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E47_01
Systematic name | M5067
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E47_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CMYB_01
Systematic name | M10817
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CMYB_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP4_01
Systematic name | M16694
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AACTTT_UNKNOWN
Systematic name | M14463
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M17 AACTTT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | MEF2_01
Systematic name | M2501
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MEF2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ELK1_01
Systematic name | M14686
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ELK1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SP1_01
Systematic name | M4831
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SP1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | EVI1_06
Systematic name | M349
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EVI1_06 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ATF_01
Systematic name | M16213
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ATF_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HOX13_01
Systematic name | M9036
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HOX13_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F_01
Systematic name | M9995
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ELK1_02
Systematic name | M19224
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ELK1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | RSRFC4_01
Systematic name | M574
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$RSRFC4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CETS1P54_01
Systematic name | M16231
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CETS1P54_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AACWWCAANK_UNKNOWN
Systematic name | M11894
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M108 AACWWCAANK in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | P300_01
Systematic name | M14862
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$P300_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NFE2_01
Systematic name | M1608
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFE2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CREB_01
Systematic name | M17180
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREB_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CREBP1_01
Systematic name | M15359
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREBP1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CREBP1CJUN_01
Systematic name | M16699
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREBP1CJUN_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SOX5_01
Systematic name | M15623
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SOX5_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E4BP4_01
Systematic name | M18078
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E4BP4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F_02
Systematic name | M17867
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NFKAPPAB65_01
Systematic name | M2315
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFKAPPAB65_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CREL_01
Systematic name | M10143
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREL_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AACYNNNNTTCCS_UNKNOWN
Systematic name | M11289
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M113 AACYNNNNTTCCS in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | NFKAPPAB_01
Systematic name | M9949
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFKAPPAB_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NMYC_01
Systematic name | M8509
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NMYC_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYOGNF1_01
Systematic name | M3872
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYOGNF1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | COMP1_01
Systematic name | M3994
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$COMP1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HEN1_02
Systematic name | M3794
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HEN1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | YY1_01
Systematic name | M1517
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$YY1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | IRF1_01
Systematic name | M2709
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$IRF1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | IRF2_01
Systematic name | M17687
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$IRF2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TAL1BETAE47_01
Systematic name | M16414
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TAL1BETAE47_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TAL1ALPHAE47_01
Systematic name | M11439
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TAL1ALPHAE47_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AAGWWRNYGGC_UNKNOWN
Systematic name | M18044
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M63 AAGWWRNYGGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | HEN1_01
Systematic name | M1321
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HEN1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | YY1_02
Systematic name | M12880
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$YY1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TAL1BETAITF2_01
Systematic name | M19390
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TAL1BETAITF2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E47_02
Systematic name | M2389
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E47_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CP2_01
Systematic name | M17000
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CP2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATA1_01
Systematic name | M13199
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATA2_01
Systematic name | M14521
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATA3_01
Systematic name | M12580
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | EVI1_01
Systematic name | M1372
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EVI1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | EVI1_02
Systematic name | M1855
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EVI1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ACAWNRNSRCGG_UNKNOWN
Systematic name | M6726
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M103 ACAWNRNSRCGG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | EVI1_03
Systematic name | M16364
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EVI1_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | EVI1_04
Systematic name | M16585
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EVI1_04 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | EVI1_05
Systematic name | M12043
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EVI1_05 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MZF1_01
Systematic name | M18765
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MZF1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MZF1_02
Systematic name | M18254
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MZF1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ZID_01
Systematic name | M8684
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ZID_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | IK1_01
Systematic name | M5959
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$IK1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | IK2_01
Systematic name | M14778
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$IK2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | IK3_01
Systematic name | M15551
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$IK3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CDP_01
Systematic name | M12297
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CDP_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ACAWYAAAG_UNKNOWN
Systematic name | M329
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M142 ACAWYAAAG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | PBX1_01
Systematic name | M3651
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PBX1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX6_01
Systematic name | M17373
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX2_01
Systematic name | M11949
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | S8_01
Systematic name | M2528
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$S8_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CDP_02
Systematic name | M2852
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CDP_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CDPCR1_01
Systematic name | M19642
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CDPCR1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CDPCR3_01
Systematic name | M7737
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CDPCR3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CDPCR3HD_01
Systematic name | M15128
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CDPCR3HD_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NRF2_01
Systematic name | M14948
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NRF2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CEBPB_01
Systematic name | M11821
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CEBPB_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ACCTGTTG_UNKNOWN
Systematic name | M9142
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M57 ACCTGTTG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CREB_02
Systematic name | M6342
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREB_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TAXCREB_01
Systematic name | M5608
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TAXCREB_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TAXCREB_02
Systematic name | M8270
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TAXCREB_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CEBPA_01
Systematic name | M4896
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CEBPA_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CEBPB_02
Systematic name | M19588
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CEBPB_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYCMAX_01
Systematic name | M12874
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYCMAX_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MAX_01
Systematic name | M18224
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MAX_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | USF_01
Systematic name | M13190
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$USF_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | USF_02
Systematic name | M14900
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$USF_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYCMAX_02
Systematic name | M3024
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYCMAX_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ACTAYRNNNCCCR_UNKNOWN
Systematic name | M7165
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M4 ACTAYRNNNCCCR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | PBX1_02
Systematic name | M6465
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PBX1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATA1_02
Systematic name | M15185
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATA1_03
Systematic name | M14186
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA1_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATA1_04
Systematic name | M14012
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA1_04 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HFH1_01
Systematic name | M14230
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HFH1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FOXD3_01
Systematic name | M11838
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FOXD3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF3B_01
Systematic name | M6136
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF3B_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF1_01
Systematic name | M15429
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TST1_01
Systematic name | M19088
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TST1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF4_01
Systematic name | M13672
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ACTWSNACTNY_UNKNOWN
Systematic name | M1698
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M105 ACTWSNACTNY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | OCT1_01
Systematic name | M9612
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | OCT1_02
Systematic name | M7213
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | OCT1_03
Systematic name | M13016
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT1_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | OCT1_04
Systematic name | M9034
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT1_04 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AHR_01
Systematic name | M9986
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AHR_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | LYF1_01
Systematic name | M14276
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$LYF1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX5_01
Systematic name | M8536
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX5_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX5_02
Systematic name | M18203
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX5_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | BRN2_01
Systematic name | M12934
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$BRN2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HSF1_01
Systematic name | M19734
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HSF1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AGCYRWTTC_UNKNOWN
Systematic name | M17392
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M135 AGCYRWTTC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | HSF2_01
Systematic name | M18963
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HSF2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SRY_01
Systematic name | M492
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SRY_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SRF_01
Systematic name | M12047
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SRF_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ARP1_01
Systematic name | M9965
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ARP1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | RORA1_01
Systematic name | M10652
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$RORA1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | RORA2_01
Systematic name | M19808
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$RORA2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | COUP_01
Systematic name | M11913
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$COUP_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CEBP_01
Systematic name | M8695
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CEBP_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SRY_02
Systematic name | M9329
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SRY_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | OCT1_05
Systematic name | M5708
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT1_05 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ARGGGTTAA_UNKNOWN
Systematic name | M13773
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M65 ARGGGTTAA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | OCT1_06
Systematic name | M13594
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT1_06 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP1FJ_Q2
Systematic name | M16919
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP1FJ_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP1_Q2
Systematic name | M9376
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP1_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP1_Q6
Systematic name | M9431
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP4_Q5
Systematic name | M9026
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP4_Q5 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP4_Q6
Systematic name | M11345
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP4_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CREB_Q2
Systematic name | M19129
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREB_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CREB_Q4
Systematic name | M12023
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREB_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CREBP1_Q2
Systematic name | M11370
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREBP1_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYB_Q6
Systematic name | M18645
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYB_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ATCMNTCCGY_UNKNOWN
Systematic name | M9974
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M99 ATCMNTCCGY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | MYOD_Q6
Systematic name | M14000
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYOD_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NFY_Q6
Systematic name | M9868
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFY_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SRF_Q6
Systematic name | M9364
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SRF_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | USF_Q6
Systematic name | M4183
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$USF_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP1_Q4
Systematic name | M5440
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP1_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP2_Q6
Systematic name | M18558
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP2_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CEBP_Q2
Systematic name | M12298
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CEBP_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ER_Q6
Systematic name | M6101
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ER_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GR_Q6
Systematic name | M7038
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GR_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NF1_Q6
Systematic name | M4803
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NF1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ATGGYGGA_UNKNOWN
Systematic name | M18484
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M102 ATGGYGGA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | NFKB_Q6
Systematic name | M11921
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFKB_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | OCT1_Q6
Systematic name | M6170
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SP1_Q6
Systematic name | M9525
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SP1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP1_C
Systematic name | M7937
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP1_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CEBP_C
Systematic name | M958
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CEBP_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATA_C
Systematic name | M18920
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GRE_C
Systematic name | M13457
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GRE_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF1_C
Systematic name | M14593
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF1_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NFKB_C
Systematic name | M12240
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFKB_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NFY_C
Systematic name | M5954
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFY_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CAGNWMCNNNGAC_UNKNOWN
Systematic name | M8059
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M143 CAGNWMCNNNGAC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | OCT_C
Systematic name | M4238
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SEF1_C
Systematic name | M6173
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SEF1_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SRF_C
Systematic name | M12443
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SRF_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TATA_C
Systematic name | M14357
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TATA_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | USF_C
Systematic name | M11610
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$USF_C (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SREBP1_01
Systematic name | M826
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SREBP1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SREBP1_02
Systematic name | M11849
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SREBP1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HAND1E47_01
Systematic name | M15061
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HAND1E47_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT_01
Systematic name | M5
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT1_01
Systematic name | M17627
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CAGNYGKNAAA_UNKNOWN
Systematic name | M6441
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M160 CAGNYGKNAAA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | STAT3_01
Systematic name | M11595
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MEF2_02
Systematic name | M11407
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MEF2_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MEF2_03
Systematic name | M17361
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MEF2_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MEF2_04
Systematic name | M19969
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MEF2_04 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AHRARNT_01
Systematic name | M10057
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AHRARNT_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ARNT_01
Systematic name | M18461
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ARNT_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AHRARNT_02
Systematic name | M6637
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AHRARNT_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NKX25_01
Systematic name | M14389
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NKX25_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NKX25_02
Systematic name | M10704
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NKX25_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PPARA_01
Systematic name | M14641
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PPARA_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CATRRAGC_UNKNOWN
Systematic name | M1230
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M134 CATRRAGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | EGR1_01
Systematic name | M1532
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EGR1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NGFIC_01
Systematic name | M8101
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NGFIC_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | EGR3_01
Systematic name | M545
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EGR3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | EGR2_01
Systematic name | M5667
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EGR2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | OCT1_07
Systematic name | M13600
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT1_07 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CHOP_01
Systematic name | M9852
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CHOP_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GFI1_01
Systematic name | M14626
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GFI1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | XBP1_01
Systematic name | M18693
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$XBP1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TATA_01
Systematic name | M3150
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TATA_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NRSF_01
Systematic name | M16822
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NRSF_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CCAATNNSNNNGCG_UNKNOWN
Systematic name | M3938
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M104 CCAATNNSNNNGCG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RREB1_01
Systematic name | M2610
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$RREB1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ISRE_01
Systematic name | M16200
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ISRE_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HLF_01
Systematic name | M7355
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HLF_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | OLF1_01
Systematic name | M4873
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OLF1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AML1_01
Systematic name | M15241
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AML1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | P53_02
Systematic name | M19017
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$P53_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | LMO2COM_01
Systematic name | M7236
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$LMO2COM_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | LMO2COM_02
Systematic name | M9264
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$LMO2COM_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MIF1_01
Systematic name | M7179
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MIF1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | RFX1_01
Systematic name | M17588
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$RFX1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CCANNAGRKGGC_UNKNOWN
Systematic name | M12308
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M45 CCANNAGRKGGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RFX1_02
Systematic name | M15101
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$RFX1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TCF11MAFG_01
Systematic name | M4121
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TCF11MAFG_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TCF11_01
Systematic name | M133
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TCF11_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NFY_01
Systematic name | M4225
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFY_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HFH3_01
Systematic name | M13641
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HFH3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FREAC2_01
Systematic name | M1031
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FREAC2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FREAC3_01
Systematic name | M12637
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FREAC3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FREAC4_01
Systematic name | M14649
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FREAC4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FREAC7_01
Systematic name | M15556
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FREAC7_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HFH8_01
Systematic name | M13279
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HFH8_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CCAWNWWNNNGGC_UNKNOWN
Systematic name | M17978
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M165 CCAWNWWNNNGGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | NFAT_Q6
Systematic name | M18699
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFAT_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYCMAX_B
Systematic name | M5164
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYCMAX_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX3_B
Systematic name | M2034
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX3_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX8_B
Systematic name | M12142
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX8_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | WHN_B
Systematic name | M15010
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$WHN_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ZF5_B
Systematic name | M6359
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ZF5_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ATF_B
Systematic name | M10046
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ATF_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ETS1_B
Systematic name | M5568
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ETS1_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ETS2_B
Systematic name | M3956
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ETS2_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GABP_B
Systematic name | M6985
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GABP_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CCAWYNNGAAR_UNKNOWN
Systematic name | M10518
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M124 CCAWYNNGAAR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | OCT1_B
Systematic name | M15558
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT1_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATA1_05
Systematic name | M2958
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA1_05 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX3_01
Systematic name | M19407
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX4_01
Systematic name | M10493
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX4_02
Systematic name | M8816
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX4_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX4_03
Systematic name | M3147
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX4_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX4_04
Systematic name | M4215
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX4_04 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MSX1_01
Systematic name | M9413
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MSX1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HOXA3_01
Systematic name | M6642
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HOXA3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | EN1_01
Systematic name | M8413
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EN1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CCCNNNNNNAAGWT_UNKNOWN
Systematic name | M13995
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M158 CCCNNNNNNAAGWT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | AMEF2_Q6
Systematic name | M3489
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AMEF2_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MMEF2_Q6
Systematic name | M19101
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MMEF2_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HMEF2_Q6
Systematic name | M9129
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HMEF2_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | RSRFC4_Q2
Systematic name | M9937
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$RSRFC4_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SOX9_B1
Systematic name | M12520
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SOX9_B1 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF4_01_B
Systematic name | M5866
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF4_01_B (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AREB6_01
Systematic name | M11244
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AREB6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AREB6_02
Systematic name | M6885
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AREB6_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AREB6_03
Systematic name | M10921
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AREB6_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AREB6_04
Systematic name | M8549
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AREB6_04 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CCGNMNNTNACG_UNKNOWN
Systematic name | M18233
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M106 CCGNMNNTNACG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CART1_01
Systematic name | M15595
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CART1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TGIF_01
Systematic name | M13313
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TGIF_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MEIS1_01
Systematic name | M7689
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MEIS1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MEIS1AHOXA9_01
Systematic name | M5279
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MEIS1AHOXA9_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MEIS1BHOXA9_01
Systematic name | M8376
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MEIS1BHOXA9_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FOXJ2_01
Systematic name | M13325
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FOXJ2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FOXJ2_02
Systematic name | M15440
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FOXJ2_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NKX61_01
Systematic name | M11968
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NKX61_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F_Q3
Systematic name | M12497
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F_Q4
Systematic name | M10115
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CCTNTMAGA_UNKNOWN
Systematic name | M2651
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M167 CCTNTMAGA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | E2F_Q6
Systematic name | M19064
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F1_Q3
Systematic name | M1485
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F1_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F1_Q4
Systematic name | M5000
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F1_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F1_Q6
Systematic name | M9279
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TITF1_Q3
Systematic name | M4580
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TITF1_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HMX1_01
Systematic name | M7827
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HMX1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | IPF1_Q4
Systematic name | M6490
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$IPF1_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CHX10_01
Systematic name | M11587
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CHX10_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | VDR_Q3
Systematic name | M14782
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$VDR_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SPZ1_01
Systematic name | M17319
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SPZ1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CGGAARNGGCNG_UNKNOWN
Systematic name | M10936
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M81 CGGAARNGGCNG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | AR_Q2
Systematic name | M16805
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AR_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ZIC1_01
Systematic name | M13482
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ZIC1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ZIC2_01
Systematic name | M7797
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ZIC2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ZIC3_01
Systematic name | M7622
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ZIC3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NKX3A_01
Systematic name | M16345
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NKX3A_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | IRF7_01
Systematic name | M12258
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$IRF7_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FAC1_01
Systematic name | M8826
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FAC1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT5A_01
Systematic name | M17883
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT5A_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT5B_01
Systematic name | M6144
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT5B_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT5A_02
Systematic name | M18386
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT5A_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CRGAARNNNNCGA_UNKNOWN
Systematic name | M2688
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M100 CRGAARNNNNCGA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GATA6_01
Systematic name | M13052
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | POU3F2_01
Systematic name | M3720
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$POU3F2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | POU3F2_02
Systematic name | M14960
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$POU3F2_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | POU6F1_01
Systematic name | M6135
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$POU6F1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HIF1_Q5
Systematic name | M5320
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HIF1_Q5 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ROAZ_01
Systematic name | M5297
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ROAZ_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP2REP_01
Systematic name | M4134
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP2REP_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP2ALPHA_01
Systematic name | M18732
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP2ALPHA_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP2GAMMA_01
Systematic name | M16396
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP2GAMMA_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TBP_01
Systematic name | M6994
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TBP_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CTCNANGTGNY_UNKNOWN
Systematic name | M6054
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M171 CTCNANGTGNY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | FOXO4_01
Systematic name | M11461
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FOXO4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FOXO1_01
Systematic name | M11512
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FOXO1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FOXO1_02
Systematic name | M4774
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FOXO1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FOXO4_02
Systematic name | M16417
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FOXO4_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FOXO3_01
Systematic name | M19851
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FOXO3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CDC5_01
Systematic name | M19327
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CDC5_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AR_01
Systematic name | M16670
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AR_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PITX2_Q2
Systematic name | M16280
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PITX2_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ATF6_01
Systematic name | M5987
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ATF6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NCX_01
Systematic name | M9896
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NCX_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CTGCAGY_UNKNOWN
Systematic name | M9769
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M101 CTGCAGY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | NKX22_01
Systematic name | M14350
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NKX22_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX2_02
Systematic name | M17779
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX2_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NKX62_Q2
Systematic name | M12379
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NKX62_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | BACH2_01
Systematic name | M13237
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$BACH2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MAZR_01
Systematic name | M4453
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MAZR_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT1_02
Systematic name | M17769
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT1_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT5A_03
Systematic name | M8720
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT5A_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT6_01
Systematic name | M2490
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | BACH1_01
Systematic name | M6969
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$BACH1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT1_03
Systematic name | M2146
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT1_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CTGRYYYNATT_UNKNOWN
Systematic name | M3285
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M153 CTGRYYYNATT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | STAT3_02
Systematic name | M3263
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT3_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT4_01
Systematic name | M3339
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT5A_04
Systematic name | M4372
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT5A_04 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT6_02
Systematic name | M7994
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT6_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | LHX3_01
Systematic name | M11495
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$LHX3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ERR1_Q2
Systematic name | M2489
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ERR1_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PPARG_01
Systematic name | M17278
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PPARG_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ATF3_Q6
Systematic name | M13967
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ATF3_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ATF4_Q2
Systematic name | M14402
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ATF4_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F_03
Systematic name | M4220
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CTGYNNCTYTAA_UNKNOWN
Systematic name | M15647
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M82 CTGYNNCTYTAA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | AP1_01
Systematic name | M10220
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PPARA_02
Systematic name | M3739
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PPARA_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GNCF_01
Systematic name | M3011
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GNCF_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NERF_Q2
Systematic name | M1607
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NERF_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | RP58_01
Systematic name | M2120
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$RP58_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HTF_01
Systematic name | M14002
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HTF_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ARNT_02
Systematic name | M9795
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ARNT_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYCMAX_03
Systematic name | M17944
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYCMAX_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AFP1_Q6
Systematic name | M14351
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AFP1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ALX4_01
Systematic name | M2518
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ALX4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CTTTAAR_UNKNOWN
Systematic name | M3684
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M29 CTTTAAR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CEBPDELTA_Q6
Systematic name | M8474
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CEBPDELTA_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CEBPGAMMA_Q6
Systematic name | M3741
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CEBPGAMMA_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CRX_Q4
Systematic name | M7023
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CRX_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | DBP_Q6
Systematic name | M15349
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$DBP_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | EFC_Q6
Systematic name | M1181
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EFC_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FOXM1_01
Systematic name | M4468
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FOXM1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FXR_Q3
Systematic name | M9731
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FXR_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATA4_Q3
Systematic name | M15522
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA4_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GCM_Q2
Systematic name | M955
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GCM_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF4ALPHA_Q6
Systematic name | M18844
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF4ALPHA_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CYTAGCAAY_UNKNOWN
Systematic name | M13977
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M34 CYTAGCAAY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | HNF6_Q6
Systematic name | M8172
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF6_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HOXA4_Q2
Systematic name | M16178
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HOXA4_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HSF_Q6
Systematic name | M7806
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HSF_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | LBP1_Q6
Systematic name | M2998
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$LBP1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | LFA1_Q6
Systematic name | M10767
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$LFA1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | LXR_Q3
Systematic name | M14687
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$LXR_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MAF_Q6
Systematic name | M14583
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MAF_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MAZ_Q6
Systematic name | M11022
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MAZ_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MTF1_Q4
Systematic name | M2463
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MTF1_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NFMUE1_Q6
Systematic name | M3265
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFMUE1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GAANYNYGACNY_UNKNOWN
Systematic name | M10627
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M137 GAANYNYGACNY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | NRF1_Q6
Systematic name | M2907
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NRF1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PEA3_Q6
Systematic name | M9287
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PEA3_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PTF1BETA_Q6
Systematic name | M15389
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PTF1BETA_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PU1_Q6
Systematic name | M14376
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PU1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SP3_Q3
Systematic name | M10836
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SP3_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TCF1P_Q6
Systematic name | M4088
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TCF1P_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TCF4_Q5
Systematic name | M1224
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TCF4_Q5 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TEF_Q6
Systematic name | M19671
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TEF_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TEL2_Q6
Systematic name | M5155
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TEL2_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ALPHACP1_01
Systematic name | M8797
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ALPHACP1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATGKMRGCG_UNKNOWN
Systematic name | M16653
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M148 GATGKMRGCG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | AP3_Q6
Systematic name | M498
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP3_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ATF1_Q6
Systematic name | M12826
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ATF1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E12_Q6
Systematic name | M15183
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E12_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E4F1_Q6
Systematic name | M13493
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E4F1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ETF_Q6
Systematic name | M17024
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ETF_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HEB_Q6
Systematic name | M18576
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HEB_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ICSBP_Q6
Systematic name | M2727
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ICSBP_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SMAD3_Q6
Systematic name | M6325
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SMAD3_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TEF1_Q6
Systematic name | M551
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TEF1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | TFIII_Q6
Systematic name | M7338
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TFIII_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GCCNNNWTAAR_UNKNOWN
Systematic name | M1779
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M95 GCCNNNWTAAR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TFIIA_Q6
Systematic name | M8585
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TFIIA_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYOGENIN_Q6
Systematic name | M10411
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYOGENIN_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ZF5_01
Systematic name | M1793
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ZF5_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX8_01
Systematic name | M3139
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX8_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CACBINDINGPROTEIN_Q6
Systematic name | M2209
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CACBINDINGPROTEIN_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CACCCBINDINGFACTOR_Q6
Systematic name | M6446
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CACCCBINDINGFACTOR_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | COREBINDINGFACTOR_Q6
Systematic name | M4770
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$COREBINDINGFACTOR_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF3ALPHA_Q6
Systematic name | M10428
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF3ALPHA_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HP1SITEFACTOR_Q6
Systematic name | M13584
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HP1SITEFACTOR_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | USF2_Q6
Systematic name | M17508
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$USF2_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GCGNNANTTCC_UNKNOWN
Systematic name | M401
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M48 GCGNNANTTCC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | SF1_Q6
Systematic name | M8812
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SF1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CDX2_Q5
Systematic name | M8062
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CDX2_Q5 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | OSF2_Q6
Systematic name | M17644
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OSF2_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SMAD4_Q6
Systematic name | M18670
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SMAD4_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CIZ_01
Systematic name | M3799
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CIZ_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F1DP1_01
Systematic name | M12402
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F1DP1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F1DP2_01
Systematic name | M12555
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F1DP2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F4DP1_01
Systematic name | M10526
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F4DP1_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F4DP2_01
Systematic name | M19298
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F4DP2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F1DP1RB_01
Systematic name | M5768
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F1DP1RB_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GCGSCMNTTT_UNKNOWN
Systematic name | M17426
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M164 GCGSCMNTTT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | HFH4_01
Systematic name | M1341
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HFH4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | POU1F1_Q6
Systematic name | M3902
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$POU1F1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | LEF1_Q6
Systematic name | M14944
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$LEF1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ELF1_Q6
Systematic name | M9902
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ELF1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | IRF1_Q6
Systematic name | M13173
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$IRF1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SREBP1_Q6
Systematic name | M19265
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SREBP1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HMGIY_Q6
Systematic name | M19147
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HMGIY_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AML1_Q6
Systematic name | M6002
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AML1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | P53_DECAMER_Q2
Systematic name | M16079
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$P53_DECAMER_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | DR1_Q3
Systematic name | M4644
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$DR1_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GCTNWTTGK_UNKNOWN
Systematic name | M8942
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M78 GCTNWTTGK in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | PPAR_DR1_Q2
Systematic name | M13889
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PPAR_DR1_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF4_DR1_Q3
Systematic name | M13332
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF4_DR1_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | COUP_DR1_Q6
Systematic name | M18594
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$COUP_DR1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | LXR_DR4_Q3
Systematic name | M5331
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$LXR_DR4_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FXR_IR1_Q6
Systematic name | M1013
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FXR_IR1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AML_Q6
Systematic name | M12818
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AML_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CEBP_Q3
Systematic name | M3109
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CEBP_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ETS_Q4
Systematic name | M18230
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ETS_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | IRF_Q6
Systematic name | M14066
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$IRF_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYB_Q3
Systematic name | M14466
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYB_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GGAANCGGAANY_UNKNOWN
Systematic name | M12891
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M21 GGAANCGGAANY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | NFKB_Q6_01
Systematic name | M2549
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFKB_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NFY_Q6_01
Systematic name | M2409
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFY_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SREBP_Q3
Systematic name | M2814
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SREBP_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | STAT_Q6
Systematic name | M3437
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$STAT_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AHR_Q5
Systematic name | M17378
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AHR_Q5 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GATA_Q6
Systematic name | M16459
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GATA_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF1_Q6
Systematic name | M11442
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF3_Q6
Systematic name | M17512
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF3_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SMAD_Q6
Systematic name | M1903
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SMAD_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | YY1_Q6
Systematic name | M11698
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$YY1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GGAMTNNNNNTCCY_UNKNOWN
Systematic name | M11597
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M74 GGAMTNNNNNTCCY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TTF1_Q6
Systematic name | M6331
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$TTF1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | OCT_Q6
Systematic name | M2211
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | USF_Q6_01
Systematic name | M8895
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$USF_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HIF1_Q3
Systematic name | M14011
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HIF1_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYC_Q2
Systematic name | M17805
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYC_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP2_Q3
Systematic name | M11469
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP2_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CREB_Q3
Systematic name | M14786
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREB_Q3 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PIT1_Q6
Systematic name | M15591
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PIT1_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F_Q2
Systematic name | M4155
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2A_Q2
Systematic name | M17596
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2A_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GGARNTKYCCA_UNKNOWN
Systematic name | M13187
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M163 GGARNTKYCCA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | LEF1_Q2
Systematic name | M3572
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$LEF1_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NF1_Q6_01
Systematic name | M12915
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NF1_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | EGR_Q6
Systematic name | M2459
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$EGR_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PAX_Q6
Systematic name | M9426
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PAX_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | FOX_Q2
Systematic name | M1643
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$FOX_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SRF_Q4
Systematic name | M5479
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SRF_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NRF2_Q4
Systematic name | M14141
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NRF2_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CEBP_Q2_01
Systematic name | M6830
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CEBP_Q2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYB_Q5_01
Systematic name | M16722
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYB_Q5_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ER_Q6_01
Systematic name | M19434
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ER_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GGCKCATGS_UNKNOWN
Systematic name | M13780
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M159 GGCKCATGS in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | AP2_Q6_01
Systematic name | M16207
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP2_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CREB_Q2_01
Systematic name | M13982
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREB_Q2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CREB_Q4_01
Systematic name | M3410
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CREB_Q4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F_Q3_01
Systematic name | M17117
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F_Q3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F_Q4_01
Systematic name | M102
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F_Q4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F_Q6_01
Systematic name | M15729
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GR_Q6_01
Systematic name | M3647
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GR_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SRF_Q5_01
Systematic name | M11934
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SRF_Q5_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP1_Q2_01
Systematic name | M7477
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP1_Q2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP1_Q6_01
Systematic name | M2054
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP1_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GGCNKCCATNK_UNKNOWN
Systematic name | M11715
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M88 GGCNKCCATNK in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | AP1_Q4_01
Systematic name | M12460
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP1_Q4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AP4_Q6_01
Systematic name | M2685
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AP4_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MYOD_Q6_01
Systematic name | M4998
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MYOD_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | OCT1_Q5_01
Systematic name | M9638
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$OCT1_Q5_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SP1_Q6_01
Systematic name | M9557
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SP1_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SP1_Q4_01
Systematic name | M9300
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SP1_Q4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | SP1_Q2_01
Systematic name | M11791
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$SP1_Q2_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | NFAT_Q4_01
Systematic name | M8280
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$NFAT_Q4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F1_Q3_01
Systematic name | M17736
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F1_Q3_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | E2F1_Q4_01
Systematic name | M8998
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F1_Q4_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GGCNNMSMYNTTG_UNKNOWN
Systematic name | M15570
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M123 GGCNNMSMYNTTG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | E2F1_Q6_01
Systematic name | M3037
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$E2F1_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | MEF2_Q6_01
Systematic name | M15929
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$MEF2_Q6_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | CP2_02
Systematic name | M560
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$CP2_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AR_02
Systematic name | M3586
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AR_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PR_01
Systematic name | M19455
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PR_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GR_01
Systematic name | M8603
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$GR_01 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AR_03
Systematic name | M2274
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AR_03 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PR_02
Systematic name | M6097
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PR_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | ER_Q6_02
Systematic name | M17968
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$ER_Q6_02 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PR_Q2
Systematic name | M19331
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PR_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GGCNRNWCTTYS_UNKNOWN
Systematic name | M4631
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M118 GGCNRNWCTTYS in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | VDR_Q6
Systematic name | M217
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$VDR_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | AR_Q6
Systematic name | M19962
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$AR_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | T3R_Q6
Systematic name | M4061
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$T3R_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | PXR_Q2
Systematic name | M4153
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$PXR_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | DR4_Q2
Systematic name | M4321
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$DR4_Q2 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | DR3_Q4
Systematic name | M1631
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$DR3_Q4 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | HNF4_Q6
Systematic name | M8634
Organism | Homo sapiens
PMID |
Authors |
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the transcription factor binding site V$HNF4_Q6 (v7.4 TRANSFAC) in the regions spanning up to 4 kb around their transcription starting sites.
Full description |

Standard name | GGGNRMNNYCAT_UNKNOWN
Systematic name | M1064
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M119 GGGNRMNNYCAT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GGGYGTGNY_UNKNOWN
Systematic name | M9645
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M31 GGGYGTGNY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GKCGCNNNNNNNTGAYG_UNKNOWN
Systematic name | M2826
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M19 GKCGCNNNNNNNTGAYG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GTCNYYATGR_UNKNOWN
Systematic name | M8013
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M98 GTCNYYATGR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GTGGGTGK_UNKNOWN
Systematic name | M6628
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M91 GTGGGTGK in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GTTGNYNNRGNAAC_UNKNOWN
Systematic name | M7220
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M43 GTTGNYNNRGNAAC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GTTNYYNNGGTNA_UNKNOWN
Systematic name | M7386
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M89 GTTNYYNNGGTNA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GTTRYCATRR_UNKNOWN
Systematic name | M8756
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M37 GTTRYCATRR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | KCCGNSWTTT_UNKNOWN
Systematic name | M1946
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M157 KCCGNSWTTT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | KMCATNNWGGA_UNKNOWN
Systematic name | M13127
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M116 KMCATNNWGGA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | KRCTCNNNNMANAGC_UNKNOWN
Systematic name | M9024
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M120 KRCTCNNNNMANAGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | KTGGYRSGAA_UNKNOWN
Systematic name | M3383
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M112 KTGGYRSGAA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | MCAATNNNNNGCG_UNKNOWN
Systematic name | M12550
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M110 MCAATNNNNNGCG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | MYAATNNNNNNNGGC_UNKNOWN
Systematic name | M10166
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M138 MYAATNNNNNNNGGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RAAGNYNNCTTY_UNKNOWN
Systematic name | M1716
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M125 RAAGNYNNCTTY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RACTNNRTTTNC_UNKNOWN
Systematic name | M9140
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M66 RACTNNRTTTNC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RNCTGNYNRNCTGNY_UNKNOWN
Systematic name | M17692
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M154 RNCTGNYNRNCTGNY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RNGTGGGC_UNKNOWN
Systematic name | M10112
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M140 RNGTGGGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RNTCANNRNNYNATTW_UNKNOWN
Systematic name | M7513
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M122 RNTCANNRNNYNATTW in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RRAGTTGT_UNKNOWN
Systematic name | M10206
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M129 RRAGTTGT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RRCCGTTA_UNKNOWN
Systematic name | M4778
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M146 RRCCGTTA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RTTTNNNYTGGM_UNKNOWN
Systematic name | M9412
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M107 RTTTNNNYTGGM in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RYAAAKNNNNNNTTGW_UNKNOWN
Systematic name | M6869
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M151 RYAAAKNNNNNNTTGW in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RYCACNNRNNRNCAG_UNKNOWN
Systematic name | M5027
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M128 RYCACNNRNNRNCAG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RYTAAWNNNTGAY_UNKNOWN
Systematic name | M13510
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M133 RYTAAWNNNTGAY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RYTGCNWTGGNR_UNKNOWN
Systematic name | M17216
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M87 RYTGCNWTGGNR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | SMTTTTGT_UNKNOWN
Systematic name | M399
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M62 SMTTTTGT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | SNACANNNYSYAGA_UNKNOWN
Systematic name | M2268
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M80 SNACANNNYSYAGA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | SYATTGTG_UNKNOWN
Systematic name | M3888
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M71 SYATTGTG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TAANNYSGCG_UNKNOWN
Systematic name | M1656
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M162 TAANNYSGCG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TAAYNRNNTCC_UNKNOWN
Systematic name | M6093
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M136 TAAYNRNNTCC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TCCATTKW_UNKNOWN
Systematic name | M7173
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M132 TCCATTKW in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TCCCRNNRTGC_UNKNOWN
Systematic name | M1728
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M39 TCCCRNNRTGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGACATY_UNKNOWN
Systematic name | M13849
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M42 TGACATY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGCGCANK_UNKNOWN
Systematic name | M10498
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M22 TGCGCANK in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGCTGAY_UNKNOWN
Systematic name | M13012
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M92 TGCTGAY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGGNNNNNNKCCAR_UNKNOWN
Systematic name | M1460
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M27 TGGNNNNNNKCCAR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGTYNNNNNRGCARM_UNKNOWN
Systematic name | M16032
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M117 TGTYNNNNNRGCARM in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TMTCGCGANR_UNKNOWN
Systematic name | M9573
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M8 TMTCGCGANR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TNCATNTCCYR_UNKNOWN
Systematic name | M5721
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M75 TNCATNTCCYR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TTANTCA_UNKNOWN
Systematic name | M3980
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M64 TTANTCA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TTANWNANTGGM_UNKNOWN
Systematic name | M9684
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M161 TTANWNANTGGM in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TTCYRGAA_UNKNOWN
Systematic name | M402
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M72 TTCYRGAA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TTTNNANAGCYR_UNKNOWN
Systematic name | M15966
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M169 TTTNNANAGCYR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | WCAANNNYCAG_UNKNOWN
Systematic name | M8368
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M152 WCAANNNYCAG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | WCTCNATGGY_UNKNOWN
Systematic name | M12984
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M59 WCTCNATGGY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | WGTTNNNNNAAA_UNKNOWN
Systematic name | M17712
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M155 WGTTNNNNNAAA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | WTGAAAT_UNKNOWN
Systematic name | M1328
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M174 WTGAAAT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | WTTGKCTG_UNKNOWN
Systematic name | M4815
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M46 WTTGKCTG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | WWTAAGGC_UNKNOWN
Systematic name | M10416
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M127 WWTAAGGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | WYAAANNRNNNGCG_UNKNOWN
Systematic name | M7349
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M126 WYAAANNRNNNGCG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YAATNANRNNNCAG_UNKNOWN
Systematic name | M8935
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M147 YAATNANRNNNCAG in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YAATNRNNNYNATT_UNKNOWN
Systematic name | M10288
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M90 YAATNRNNNYNATT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YATTNATC_UNKNOWN
Systematic name | M435
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M97 YATTNATC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YCATTAA_UNKNOWN
Systematic name | M6052
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M58 YCATTAA in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YGACNNYACAR_UNKNOWN
Systematic name | M12349
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M149 YGACNNYACAR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YGCANTGCR_UNKNOWN
Systematic name | M19578
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M96 YGCANTGCR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YGCGYRCGC_UNKNOWN
Systematic name | M17342
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M30 YGCGYRCGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YGTCCTTGR_UNKNOWN
Systematic name | M849
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M109 YGTCCTTGR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YKACATTT_UNKNOWN
Systematic name | M1830
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M145 YKACATTT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YNGTTNNNATT_UNKNOWN
Systematic name | M16291
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M170 YNGTTNNNATT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YNTTTNNNANGCARM_UNKNOWN
Systematic name | M18600
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M166 YNTTTNNNANGCARM in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YRCCAKNNGNCGC_UNKNOWN
Systematic name | M19571
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M156 YRCCAKNNGNCGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YRTCANNRCGC_UNKNOWN
Systematic name | M14861
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M115 YRTCANNRCGC in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YTAAYNGCT_UNKNOWN
Systematic name | M1856
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M168 YTAAYNGCT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YTCCCRNNAGGY_UNKNOWN
Systematic name | M2330
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M114 YTCCCRNNAGGY in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YTTCCNNNGGAMR_UNKNOWN
Systematic name | M5789
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M150 YTTCCNNNGGAMR in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YWATTWNNRGCT_UNKNOWN
Systematic name | M4384
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M173 YWATTWNNRGCT in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YYCATTCAWW_UNKNOWN
Systematic name | M15719
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M52 YYCATTCAWW in the region spanning up to 4 kb around their transcription start sites. The motif does not match any known transcription factor binding site (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RACCACAR_AML_Q6
Systematic name | M11390
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M111 RACCACAR sites. The motif matches transcription factor binding site V$AML_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGANTCA_AP1_C
Systematic name | M13826
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M7 TGANTCA sites. The motif matches transcription factor binding site V$AP1_C (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CAGCTG_AP4_Q5
Systematic name | M11668
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M15 CAGCTG sites. The motif matches transcription factor binding site V$AP4_Q5 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CAGGTA_AREB6_01
Systematic name | M9772
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M76 CAGGTA sites. The motif matches transcription factor binding site V$AREB6_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGACGTCA_ATF3_Q6
Systematic name | M17997
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M14 TGACGTCA sites. The motif matches transcription factor binding site V$ATF3_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGAYRTCA_ATF3_Q6
Systematic name | M9955
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M9 TGAYRTCA sites. The motif matches transcription factor binding site V$ATF3_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TTGCWCAAY_CEBPB_02
Systematic name | M11820
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M172 TTGCWCAAY sites. The motif matches transcription factor binding site V$CEBPB_02 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TAATTA_CHX10_01
Systematic name | M17214
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M23 TAATTA sites. The motif matches transcription factor binding site V$CHX10_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | SGCGSSAAA_E2F1DP2_01
Systematic name | M1905
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M69 SGCGSSAAA sites. The motif matches transcription factor binding site V$E2F1DP2_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TTAYRTAA_E4BP4_01
Systematic name | M6422
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M26 TTAYRTAA sites. The motif matches transcription factor binding site V$E4BP4_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GTGACGY_E4F1_Q6
Systematic name | M3403
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M20 GTGACGY sites. The motif matches transcription factor binding site V$E4F1_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | SCGGAAGY_ELK1_02
Systematic name | M17817
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M3 SCGGAAGY sites. The motif matches transcription factor binding site V$ELK1_02 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGACCTY_ERR1_Q2
Systematic name | M11396
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M25 TGACCTY sites. The motif matches transcription factor binding site V$ERR1_Q2 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RYTTCCTG_ETS2_B
Systematic name | M14654
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M16 RYTTCCTG sites. The motif matches transcription factor binding site V$ETS2_B (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RTAAACA_FREAC2_01
Systematic name | M3746
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M36 RTAAACA sites. The motif matches transcription factor binding site V$FREAC2_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | MGGAAGTG_GABP_B
Systematic name | M17925
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M11 MGGAAGTG sites. The motif matches transcription factor binding site V$GABP_B (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GATAAGR_GATA_C
Systematic name | M7093
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M131 GATAAGR sites. The motif matches transcription factor binding site V$GATA_C (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGATTTRY_GFI1_01
Systematic name | M19368
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M94 TGATTTRY sites. The motif matches transcription factor binding site V$GFI1_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | AAAYWAACM_HFH4_01
Systematic name | M6517
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M139 AAAYWAACM sites. The motif matches transcription factor binding site V$HFH4_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RGTTAMWNATT_HNF1_01
Systematic name | M12675
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M84 RGTTAMWNATT sites. The motif matches transcription factor binding site V$HNF1_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGTTTGY_HNF3_Q6
Systematic name | M4764
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M83 TGTTTGY sites. The motif matches transcription factor binding site V$HNF3_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TTCNRGNNNNTTC_HSF_Q6
Systematic name | M16482
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M141 TTCNRGNNNNTTC sites. The motif matches transcription factor binding site V$HSF_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RGAANNTTC_HSF1_01
Systematic name | M8746
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M68 RGAANNTTC sites. The motif matches transcription factor binding site V$HSF1_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | STTTCRNTTT_IRF_Q6
Systematic name | M533
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M85 STTTCRNTTT sites. The motif matches transcription factor binding site V$IRF_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CTTTGA_LEF1_Q2
Systematic name | M482
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M73 CTTTGA sites. The motif matches transcription factor binding site V$LEF1_Q2 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YTAATTAA_LHX3_01
Systematic name | M829
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M61 YTAATTAA sites. The motif matches transcription factor binding site V$LHX3_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YTATTTTNR_MEF2_02
Systematic name | M822
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M33 YTATTTTNR sites. The motif matches transcription factor binding site V$MEF2_02 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGACAGNY_MEIS1_01
Systematic name | M3643
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M41 TGACAGNY sites. The motif matches transcription factor binding site V$MEIS1_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RYTGCNNRGNAAC_MIF1_01
Systematic name | M9581
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M53 RYTGCNNRGNAAC sites. The motif matches transcription factor binding site V$MIF1_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CACGTG_MYC_Q2
Systematic name | M8402
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M2 CACGTG sites. The motif matches transcription factor binding site V$MYC_Q2 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GCANCTGNY_MYOD_Q6
Systematic name | M10806
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M35 GCANCTGNY sites. The motif matches transcription factor binding site V$MYOD_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGCCAAR_NF1_Q6
Systematic name | M572
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M47 TGCCAAR sites. The motif matches transcription factor binding site V$NF1_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGGAAA_NFAT_Q4_01
Systematic name | M16911
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M55 TGGAAA sites. The motif matches transcription factor binding site V$NFAT_Q4_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGASTMAGC_NFE2_01
Systematic name | M8004
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M32 TGASTMAGC sites. The motif matches transcription factor binding site V$NFE2_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GGGNNTTTCC_NFKB_Q6_01
Systematic name | M1365
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M86 GGGNNTTTCC sites. The motif matches transcription factor binding site V$NFKB_Q6_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GATTGGY_NFY_Q6_01
Systematic name | M9947
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M5 GATTGGY sites. The motif matches transcription factor binding site V$NFY_Q6_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RCGCANGCGY_NRF1_Q6
Systematic name | M9394
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M1 RCGCANGCGY sites. The motif matches transcription factor binding site V$NRF1_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | YATGNWAAT_OCT_C
Systematic name | M18169
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M44 YATGNWAAT sites. The motif matches transcription factor binding site V$OCT_C (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CCCNNGGGAR_OLF1_01
Systematic name | M15675
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M130 CCCNNGGGAR sites. The motif matches transcription factor binding site V$OLF1_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CGTSACG_PAX3_B
Systematic name | M17318
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M70 CGTSACG sites. The motif matches transcription factor binding site V$PAX3_B (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GGGTGGRR_PAX4_03
Systematic name | M1159
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M56 GGGTGGRR sites. The motif matches transcription factor binding site V$PAX4_03 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GGATTA_PITX2_Q2
Systematic name | M946
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M93 GGATTA sites. The motif matches transcription factor binding site V$PITX2_Q2 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | RGAGGAARY_PU1_Q6
Systematic name | M15616
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M50 RGAGGAARY sites. The motif matches transcription factor binding site V$PU1_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CTAWWWATA_RSRFC4_Q2
Systematic name | M16022
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M28 CTAWWWATA sites. The motif matches transcription factor binding site V$RSRFC4_Q2 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TAAWWATAG_RSRFC4_Q2
Systematic name | M6568
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M54 TAAWWATAG sites. The motif matches transcription factor binding site V$RSRFC4_Q2 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGACCTTG_SF1_Q6
Systematic name | M1630
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M38 TGACCTTG sites. The motif matches transcription factor binding site V$SF1_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CATTGTYY_SOX9_B1
Systematic name | M7691
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M49 CATTGTYY sites. The motif matches transcription factor binding site V$SOX9_B1 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TCANNTGAY_SREBP1_01
Systematic name | M18894
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M18 TCANNTGAY sites. The motif matches transcription factor binding site V$SREBP1_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | CCAWWNAAGG_SRF_Q4
Systematic name | M3827
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M121 CCAWWNAAGG sites. The motif matches transcription factor binding site V$SRF_Q4 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TTCYNRGAA_STAT5B_01
Systematic name | M6378
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M40 TTCYNRGAA sites. The motif matches transcription factor binding site V$STAT5B_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TATAAA_TATA_01
Systematic name | M7521
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M51 TATAAA sites. The motif matches transcription factor binding site V$TATA_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | TGANNYRGCA_TCF11MAFG_01
Systematic name | M613
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M67 TGANNYRGCA sites. The motif matches transcription factor binding site V$TCF11MAFG_01 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | WGGAATGY_TEF1_Q6
Systematic name | M17420
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M79 WGGAATGY sites. The motif matches transcription factor binding site V$TEF1_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | GCCATNTTG_YY1_Q6
Systematic name | M171
Organism | Homo sapiens
PMID | 15735639
Authors | Xie X,Lu J,Kulbokas EJ,Golub TR,Mootha V,Lindblad-Toh K,Lander ES,Kellis M
Category | C3
Sub-category | TFT:TFT_Legacy
Brief description | Genes having at least one occurence of the highly conserved motif M10 GCCATNTTG sites. The motif matches transcription factor binding site V$YY1_Q6 (v7.4 TRANSFAC).
Full description | Comprehensive identification of all functional elements encoded in the human genome is a fundamental need in biomedical research. Here, we present a comparative analysis of the human, mouse, rat and dog genomes to create a systematic catalogue of common regulatory motifs in promoters and 3' untranslated regions (3' UTRs). The promoter analysis yields 174 candidate motifs, including most previously known transcription-factor binding sites and 105 new motifs. The 3'-UTR analysis yields 106 motifs likely to be involved in post-transcriptional regulation. Nearly one-half are associated with microRNAs (miRNAs), leading to the discovery of many new miRNA genes and their likely target genes. Our results suggest that previous estimates of the number of human miRNA genes were low, and that miRNAs regulate at least 20% of human genes. The overall results provide a systematic view of gene regulation in the human, which will be refined as additional mammalian genomes become available.

Standard name | MORF_ATRX
Systematic name | M10988
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ATRX
Full description | Neighborhood of ATRX alpha thalassemia/mental retardation syndrome X-linked (RAD54 homolog, S. cerevisiae) in the MORF expression compendium

Standard name | MORF_ATOX1
Systematic name | M12803
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ATOX1
Full description | Neighborhood of ATOX1 ATX1 antioxidant protein 1 homolog (yeast) in the MORF expression compendium

Standard name | MORF_BCL2
Systematic name | M19723
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BCL2
Full description | Neighborhood of BCL2 B-cell CLL/lymphoma 2 in the MORF expression compendium

Standard name | MORF_BNIP1
Systematic name | M2795
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BNIP1
Full description | Neighborhood of BNIP1 BCL2/adenovirus E1B 19kDa interacting protein 1 in the MORF expression compendium

Standard name | MORF_BAG5
Systematic name | M5380
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BAG5
Full description | Neighborhood of BAG5 BCL2-associated athanogene 5 in the MORF expression compendium

Standard name | MORF_BCL2L11
Systematic name | M15901
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BCL2L11
Full description | Neighborhood of BCL2L11 BCL2-like 11 (apoptosis facilitator) in the MORF expression compendium

Standard name | MORF_BECN1
Systematic name | M5038
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BECN1
Full description | Neighborhood of BECN1 beclin 1 (coiled-coil, myosin-like BCL2 interacting protein) in the MORF expression compendium

Standard name | MORF_BRCA1
Systematic name | M1094
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BRCA1
Full description | Neighborhood of BRCA1 breast cancer 1, early onset in the MORF expression compendium

Standard name | MORF_BUB1
Systematic name | M10554
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BUB1
Full description | Neighborhood of BUB1 BUB1 budding uninhibited by benzimidazoles 1 homolog (yeast) in the MORF expression compendium

Standard name | MORF_BUB3
Systematic name | M13419
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BUB3
Full description | Neighborhood of BUB3 BUB3 budding uninhibited by benzimidazoles 3 homolog (yeast) in the MORF expression compendium

Standard name | MORF_CTBP1
Systematic name | M12947
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CTBP1
Full description | Neighborhood of CTBP1 C-terminal binding protein 1 in the MORF expression compendium

Standard name | MORF_CCNF
Systematic name | M18220
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CCNF
Full description | Neighborhood of CCNF cyclin F in the MORF expression compendium

Standard name | MORF_CCNI
Systematic name | M12733
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CCNI
Full description | Neighborhood of CCNI cyclin I in the MORF expression compendium

Standard name | MORF_DNMT1
Systematic name | M10146
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DNMT1
Full description | Neighborhood of DNMT1 DNA (cytosine-5-)-methyltransferase 1 in the MORF expression compendium

Standard name | MORF_ERCC2
Systematic name | M404
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ERCC2
Full description | Neighborhood of ERCC2 excision repair cross-complementing rodent repair deficiency, complementation group 2 (xeroderma pigmentosum D) in the MORF expression compendium

Standard name | MORF_ESPL1
Systematic name | M10414
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ESPL1
Full description | Neighborhood of ESPL1 extra spindle poles like 1 (S. cerevisiae) in the MORF expression compendium

Standard name | MORF_FDXR
Systematic name | M6229
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FDXR
Full description | Neighborhood of FDXR ferredoxin reductase in the MORF expression compendium

Standard name | MORF_FEN1
Systematic name | M4
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FEN1
Full description | Neighborhood of FEN1 flap structure-specific endonuclease 1 in the MORF expression compendium

Standard name | MORF_GPX4
Systematic name | M14152
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of GPX4
Full description | Neighborhood of GPX4 glutathione peroxidase 4 (phospholipid hydroperoxidase) in the MORF expression compendium

Standard name | MORF_HAT1
Systematic name | M446
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HAT1
Full description | Neighborhood of HAT1 histone acetyltransferase 1 in the MORF expression compendium

Standard name | MORF_HDAC1
Systematic name | M11080
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HDAC1
Full description | Neighborhood of HDAC1 histone deacetylase 1 in the MORF expression compendium

Standard name | MORF_HDAC2
Systematic name | M11406
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HDAC2
Full description | Neighborhood of HDAC2 histone deacetylase 2 in the MORF expression compendium

Standard name | MORF_MDM2
Systematic name | M5734
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MDM2
Full description | Neighborhood of MDM2 Mdm2, transformed 3T3 cell double minute 2, p53 binding protein (mouse) in the MORF expression compendium

Standard name | MORF_MT4
Systematic name | M15921
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MT4
Full description | Neighborhood of MT4 metallothionein IV in the MORF expression compendium

Standard name | MORF_MSH2
Systematic name | M17234
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MSH2
Full description | Neighborhood of MSH2 mutS homolog 2, colon cancer, nonpolyposis type 1 (E. coli) in the MORF expression compendium

Standard name | MORF_MSH3
Systematic name | M10529
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MSH3
Full description | Neighborhood of MSH3 mutS homolog 3 (E. coli) in the MORF expression compendium

Standard name | MORF_NF1
Systematic name | M6373
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of NF1
Full description | Neighborhood of NF1 neurofibromin 1 (neurofibromatosis, von Recklinghausen disease, Watson disease) in the MORF expression compendium

Standard name | MORF_PRDX3
Systematic name | M3784
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PRDX3
Full description | Neighborhood of PRDX3 peroxiredoxin 3 in the MORF expression compendium

Standard name | MORF_PCNA
Systematic name | M14632
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PCNA
Full description | Neighborhood of PCNA proliferating cell nuclear antigen in the MORF expression compendium

Standard name | MORF_PSMC1
Systematic name | M19325
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PSMC1
Full description | Neighborhood of PSMC1 proteasome (prosome, macropain) 26S subunit, ATPase, 1 in the MORF expression compendium

Standard name | MORF_PSMC2
Systematic name | M11641
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PSMC2
Full description | Neighborhood of PSMC2 proteasome (prosome, macropain) 26S subunit, ATPase, 2 in the MORF expression compendium

Standard name | MORF_PSMF1
Systematic name | M9093
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PSMF1
Full description | Neighborhood of PSMF1 proteasome (prosome, macropain) inhibitor subunit 1 (PI31) in the MORF expression compendium

Standard name | MORF_PRKDC
Systematic name | M13609
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PRKDC
Full description | Neighborhood of PRKDC protein kinase, DNA-activated, catalytic polypeptide in the MORF expression compendium

Standard name | MORF_RAD21
Systematic name | M11132
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAD21
Full description | Neighborhood of RAD21 RAD21 homolog (S. pombe) in the MORF expression compendium

Standard name | MORF_RAD23A
Systematic name | M7309
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAD23A
Full description | Neighborhood of RAD23A RAD23 homolog A (S. cerevisiae) in the MORF expression compendium

Standard name | MORF_RAD23B
Systematic name | M18803
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAD23B
Full description | Neighborhood of RAD23B RAD23 homolog B (S. cerevisiae) in the MORF expression compendium

Standard name | MORF_RAD51L3
Systematic name | M11755
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAD51L3
Full description | Neighborhood of RAD51L3 RAD51-like 3 (S. cerevisiae) in the MORF expression compendium

Standard name | MORF_RAD54L
Systematic name | M7887
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAD54L
Full description | Neighborhood of RAD54L RAD54-like (S. cerevisiae) in the MORF expression compendium

Standard name | MORF_RFC1
Systematic name | M17368
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RFC1
Full description | Neighborhood of RFC1 replication factor C (activator 1) 1, 145kDa in the MORF expression compendium

Standard name | MORF_RFC4
Systematic name | M13545
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RFC4
Full description | Neighborhood of RFC4 replication factor C (activator 1) 4, 37kDa in the MORF expression compendium

Standard name | MORF_RFC5
Systematic name | M18618
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RFC5
Full description | Neighborhood of RFC5 replication factor C (activator 1) 5, 36.5kDa in the MORF expression compendium

Standard name | MORF_RPA1
Systematic name | M17665
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RPA1
Full description | Neighborhood of RPA1 replication protein A1, 70kDa in the MORF expression compendium

Standard name | MORF_RPA2
Systematic name | M7462
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RPA2
Full description | Neighborhood of RPA2 replication protein A2, 32kDa in the MORF expression compendium

Standard name | MORF_RRM1
Systematic name | M1104
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RRM1
Full description | Neighborhood of RRM1 ribonucleotide reductase M1 polypeptide in the MORF expression compendium

Standard name | MORF_STK17A
Systematic name | M5671
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of STK17A
Full description | Neighborhood of STK17A serine/threonine kinase 17a (apoptosis-inducing) in the MORF expression compendium

Standard name | MORF_SMC1L1
Systematic name | M1046
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SMC1L1
Full description | Neighborhood of SMC1L1 NULL in the MORF expression compendium

Standard name | MORF_SP3
Systematic name | M14834
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SP3
Full description | Neighborhood of SP3 Sp3 transcription factor in the MORF expression compendium

Standard name | MORF_SOD1
Systematic name | M7895
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SOD1
Full description | Neighborhood of SOD1 superoxide dismutase 1, soluble (amyotrophic lateral sclerosis 1 (adult)) in the MORF expression compendium

Standard name | MORF_TERF1
Systematic name | M1209
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TERF1
Full description | Neighborhood of TERF1 telomeric repeat binding factor (NIMA-interacting) 1 in the MORF expression compendium

Standard name | MORF_TERF2IP
Systematic name | M7126
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TERF2IP
Full description | Neighborhood of TERF2IP telomeric repeat binding factor 2, interacting protein in the MORF expression compendium

Standard name | MORF_TFDP2
Systematic name | M2022
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TFDP2
Full description | Neighborhood of TFDP2 transcription factor Dp-2 (E2F dimerization partner 2) in the MORF expression compendium

Standard name | MORF_UNG
Systematic name | M6530
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of UNG
Full description | Neighborhood of UNG uracil-DNA glycosylase in the MORF expression compendium

Standard name | MORF_MYC
Systematic name | M17328
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MYC
Full description | Neighborhood of MYC v-myc myelocytomatosis viral oncogene homolog (avian) in the MORF expression compendium

Standard name | MORF_XPC
Systematic name | M1715
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of XPC
Full description | Neighborhood of XPC xeroderma pigmentosum, complementation group C in the MORF expression compendium

Standard name | MORF_XRCC5
Systematic name | M18997
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of XRCC5
Full description | Neighborhood of XRCC5 X-ray repair complementing defective repair in Chinese hamster cells 5 (double-strand-break rejoining; Ku autoantigen, 80kDa) in the MORF expression compendium

Standard name | MORF_AATF
Systematic name | M15222
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of AATF
Full description | Neighborhood of AATF apoptosis antagonizing transcription factor in the MORF expression compendium

Standard name | MORF_ACP1
Systematic name | M2705
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ACP1
Full description | Neighborhood of ACP1 acid phosphatase 1, soluble in the MORF expression compendium

Standard name | MORF_ACTG1
Systematic name | M1958
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ACTG1
Full description | Neighborhood of ACTG1 actin, gamma 1 in the MORF expression compendium

Standard name | MORF_ANP32B
Systematic name | M19884
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ANP32B
Full description | Neighborhood of ANP32B acidic (leucine-rich) nuclear phosphoprotein 32 family, member B in the MORF expression compendium

Standard name | MORF_AP2M1
Systematic name | M2967
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of AP2M1
Full description | Neighborhood of AP2M1 adaptor-related protein complex 2, mu 1 subunit in the MORF expression compendium

Standard name | MORF_AP3D1
Systematic name | M16449
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of AP3D1
Full description | Neighborhood of AP3D1 adaptor-related protein complex 3, delta 1 subunit in the MORF expression compendium

Standard name | MORF_ARAF1
Systematic name | M5175
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ARAF1
Full description | Neighborhood of ARAF1 NULL in the MORF expression compendium

Standard name | MORF_ARL3
Systematic name | M4363
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ARL3
Full description | Neighborhood of ARL3 ADP-ribosylation factor-like 3 in the MORF expression compendium

Standard name | MORF_ATF2
Systematic name | M15658
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ATF2
Full description | Neighborhood of ATF2 activating transcription factor 2 in the MORF expression compendium

Standard name | MORF_BMI1
Systematic name | M6571
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BMI1
Full description | Neighborhood of BMI1 B lymphoma Mo-MLV insertion region (mouse) in the MORF expression compendium

Standard name | MORF_BMPR2
Systematic name | M14272
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BMPR2
Full description | Neighborhood of BMPR2 bone morphogenetic protein receptor, type II (serine/threonine kinase) in the MORF expression compendium

Standard name | MORF_BUB1B
Systematic name | M5625
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BUB1B
Full description | Neighborhood of BUB1B BUB1 budding uninhibited by benzimidazoles 1 homolog beta (yeast) in the MORF expression compendium

Standard name | MORF_CAMK4
Systematic name | M2749
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CAMK4
Full description | Neighborhood of CAMK4 calcium/calmodulin-dependent protein kinase IV in the MORF expression compendium

Standard name | MORF_CASP10
Systematic name | M5177
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CASP10
Full description | Neighborhood of CASP10 caspase 10, apoptosis-related cysteine peptidase in the MORF expression compendium

Standard name | MORF_CASP2
Systematic name | M8508
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CASP2
Full description | Neighborhood of CASP2 caspase 2, apoptosis-related cysteine peptidase (neural precursor cell expressed, developmentally down-regulated 2) in the MORF expression compendium

Standard name | MORF_CD8A
Systematic name | M7117
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CD8A
Full description | Neighborhood of CD8A CD8a molecule in the MORF expression compendium

Standard name | MORF_CDC10
Systematic name | M3665
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDC10
Full description | Neighborhood of CDC10 NULL in the MORF expression compendium

Standard name | MORF_CDC16
Systematic name | M19935
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDC16
Full description | Neighborhood of CDC16 CDC16 cell division cycle 16 homolog (S. cerevisiae) in the MORF expression compendium

Standard name | MORF_CDC2L5
Systematic name | M18796
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDC2L5
Full description | Neighborhood of CDC2L5 cell division cycle 2-like 5 (cholinesterase-related cell division controller) in the MORF expression compendium

Standard name | MORF_CDH4
Systematic name | M2671
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDH4
Full description | Neighborhood of CDH4 cadherin 4, type 1, R-cadherin (retinal) in the MORF expression compendium

Standard name | MORF_CDK2
Systematic name | M11176
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDK2
Full description | Neighborhood of CDK2 cyclin-dependent kinase 2 in the MORF expression compendium

Standard name | MORF_CNTN1
Systematic name | M18998
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CNTN1
Full description | Neighborhood of CNTN1 contactin 1 in the MORF expression compendium

Standard name | MORF_CSNK1D
Systematic name | M8523
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CSNK1D
Full description | Neighborhood of CSNK1D casein kinase 1, delta in the MORF expression compendium

Standard name | MORF_CSNK2B
Systematic name | M18002
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CSNK2B
Full description | Neighborhood of CSNK2B casein kinase 2, beta polypeptide in the MORF expression compendium

Standard name | MORF_CTSB
Systematic name | M12869
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CTSB
Full description | Neighborhood of CTSB cathepsin B in the MORF expression compendium

Standard name | MORF_CUL1
Systematic name | M9579
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CUL1
Full description | Neighborhood of CUL1 cullin 1 in the MORF expression compendium

Standard name | MORF_DAP
Systematic name | M1893
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DAP
Full description | Neighborhood of DAP death-associated protein in the MORF expression compendium

Standard name | MORF_DAP3
Systematic name | M6058
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DAP3
Full description | Neighborhood of DAP3 death associated protein 3 in the MORF expression compendium

Standard name | MORF_DCC
Systematic name | M16569
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DCC
Full description | Neighborhood of DCC deleted in colorectal carcinoma in the MORF expression compendium

Standard name | MORF_DDB1
Systematic name | M5047
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DDB1
Full description | Neighborhood of DDB1 damage-specific DNA binding protein 1, 127kDa in the MORF expression compendium

Standard name | MORF_DDX11
Systematic name | M19243
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DDX11
Full description | Neighborhood of DDX11 DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 11 (CHL1-like helicase homolog, S. cerevisiae) in the MORF expression compendium

Standard name | MORF_DEAF1
Systematic name | M4797
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DEAF1
Full description | Neighborhood of DEAF1 deformed epidermal autoregulatory factor 1 (Drosophila) in the MORF expression compendium

Standard name | MORF_DEK
Systematic name | M7191
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DEK
Full description | Neighborhood of DEK DEK oncogene (DNA binding) in the MORF expression compendium

Standard name | MORF_DMPK
Systematic name | M19725
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DMPK
Full description | Neighborhood of DMPK dystrophia myotonica-protein kinase in the MORF expression compendium

Standard name | MORF_EI24
Systematic name | M382
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of EI24
Full description | Neighborhood of EI24 etoposide induced 2.4 mRNA in the MORF expression compendium

Standard name | MORF_EIF3S2
Systematic name | M18698
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of EIF3S2
Full description | Neighborhood of EIF3S2 eukaryotic translation initiation factor 3, subunit 2 beta, 36kDa in the MORF expression compendium

Standard name | MORF_EIF3S6
Systematic name | M4246
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of EIF3S6
Full description | Neighborhood of EIF3S6 eukaryotic translation initiation factor 3, subunit 6 48kDa in the MORF expression compendium

Standard name | MORF_EIF4A2
Systematic name | M334
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of EIF4A2
Full description | Neighborhood of EIF4A2 eukaryotic translation initiation factor 4A, isoform 2 in the MORF expression compendium

Standard name | MORF_EIF4E
Systematic name | M18743
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of EIF4E
Full description | Neighborhood of EIF4E eukaryotic translation initiation factor 4E in the MORF expression compendium

Standard name | MORF_EPHA7
Systematic name | M14153
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of EPHA7
Full description | Neighborhood of EPHA7 EPH receptor A7 in the MORF expression compendium

Standard name | MORF_ERCC4
Systematic name | M19749
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ERCC4
Full description | Neighborhood of ERCC4 excision repair cross-complementing rodent repair deficiency, complementation group 4 in the MORF expression compendium

Standard name | MORF_ERH
Systematic name | M16184
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ERH
Full description | Neighborhood of ERH enhancer of rudimentary homolog (Drosophila) in the MORF expression compendium

Standard name | MORF_ESR1
Systematic name | M11486
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ESR1
Full description | Neighborhood of ESR1 estrogen receptor 1 in the MORF expression compendium

Standard name | MORF_ETV3
Systematic name | M14346
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ETV3
Full description | Neighborhood of ETV3 ets variant gene 3 in the MORF expression compendium

Standard name | MORF_FANCG
Systematic name | M12979
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FANCG
Full description | Neighborhood of FANCG Fanconi anemia, complementation group G in the MORF expression compendium

Standard name | MORF_FBL
Systematic name | M6545
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FBL
Full description | Neighborhood of FBL fibrillarin in the MORF expression compendium

Standard name | MORF_FLT1
Systematic name | M10328
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FLT1
Full description | Neighborhood of FLT1 fms-related tyrosine kinase 1 (vascular endothelial growth factor/vascular permeability factor receptor) in the MORF expression compendium

Standard name | MORF_FOSL1
Systematic name | M6407
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FOSL1
Full description | Neighborhood of FOSL1 FOS-like antigen 1 in the MORF expression compendium

Standard name | MORF_FRK
Systematic name | M18116
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FRK
Full description | Neighborhood of FRK fyn-related kinase in the MORF expression compendium

Standard name | MORF_FSHR
Systematic name | M230
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FSHR
Full description | Neighborhood of FSHR follicle stimulating hormone receptor in the MORF expression compendium

Standard name | MORF_G22P1
Systematic name | M19767
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of G22P1
Full description | Neighborhood of G22P1 NULL in the MORF expression compendium

Standard name | MORF_GMPS
Systematic name | M18524
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of GMPS
Full description | Neighborhood of GMPS guanine monphosphate synthetase in the MORF expression compendium

Standard name | MORF_GNB1
Systematic name | M18398
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of GNB1
Full description | Neighborhood of GNB1 guanine nucleotide binding protein (G protein), beta polypeptide 1 in the MORF expression compendium

Standard name | MORF_GSPT1
Systematic name | M8616
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of GSPT1
Full description | Neighborhood of GSPT1 G1 to S phase transition 1 in the MORF expression compendium

Standard name | MORF_HEAB
Systematic name | M18270
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HEAB
Full description | Neighborhood of HEAB - in the MORF expression compendium

Standard name | MORF_IFNA1
Systematic name | M6409
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IFNA1
Full description | Neighborhood of IFNA1 interferon, alpha 1 in the MORF expression compendium

Standard name | MORF_IKBKG
Systematic name | M15203
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IKBKG
Full description | Neighborhood of IKBKG inhibitor of kappa light polypeptide gene enhancer in B-cells, kinase gamma in the MORF expression compendium

Standard name | MORF_IL13
Systematic name | M3810
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IL13
Full description | Neighborhood of IL13 interleukin 13 in the MORF expression compendium

Standard name | MORF_IL16
Systematic name | M19290
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IL16
Full description | Neighborhood of IL16 interleukin 16 (lymphocyte chemoattractant factor) in the MORF expression compendium

Standard name | MORF_IL4
Systematic name | M13205
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IL4
Full description | Neighborhood of IL4 interleukin 4 in the MORF expression compendium

Standard name | MORF_IL9
Systematic name | M16016
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IL9
Full description | Neighborhood of IL9 interleukin 9 in the MORF expression compendium

Standard name | MORF_ITGA2
Systematic name | M10073
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ITGA2
Full description | Neighborhood of ITGA2 integrin, alpha 2 (CD49B, alpha 2 subunit of VLA-2 receptor) in the MORF expression compendium

Standard name | MORF_JAG1
Systematic name | M4711
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of JAG1
Full description | Neighborhood of JAG1 jagged 1 (Alagille syndrome) in the MORF expression compendium

Standard name | MORF_JAK3
Systematic name | M7497
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of JAK3
Full description | Neighborhood of JAK3 Janus kinase 3 (a protein tyrosine kinase, leukocyte) in the MORF expression compendium

Standard name | MORF_JUND
Systematic name | M4651
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of JUND
Full description | Neighborhood of JUND jun D proto-oncogene in the MORF expression compendium

Standard name | MORF_KDR
Systematic name | M17652
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of KDR
Full description | Neighborhood of KDR kinase insert domain receptor (a type III receptor tyrosine kinase) in the MORF expression compendium

Standard name | MORF_LCAT
Systematic name | M4019
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of LCAT
Full description | Neighborhood of LCAT lecithin-cholesterol acyltransferase in the MORF expression compendium

Standard name | MORF_LMO1
Systematic name | M3617
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of LMO1
Full description | Neighborhood of LMO1 LIM domain only 1 (rhombotin 1) in the MORF expression compendium

Standard name | MORF_LTK
Systematic name | M3336
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of LTK
Full description | Neighborhood of LTK leukocyte tyrosine kinase in the MORF expression compendium

Standard name | MORF_MAGEA8
Systematic name | M8350
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAGEA8
Full description | Neighborhood of MAGEA8 melanoma antigen family A, 8 in the MORF expression compendium

Standard name | MORF_MAGEA9
Systematic name | M3103
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAGEA9
Full description | Neighborhood of MAGEA9 melanoma antigen family A, 9 in the MORF expression compendium

Standard name | MORF_MAP2K2
Systematic name | M6287
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAP2K2
Full description | Neighborhood of MAP2K2 mitogen-activated protein kinase kinase 2 in the MORF expression compendium

Standard name | MORF_MAP2K7
Systematic name | M18921
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAP2K7
Full description | Neighborhood of MAP2K7 mitogen-activated protein kinase kinase 7 in the MORF expression compendium

Standard name | MORF_MAP3K14
Systematic name | M4205
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAP3K14
Full description | Neighborhood of MAP3K14 mitogen-activated protein kinase kinase kinase 14 in the MORF expression compendium

Standard name | MORF_MBD4
Systematic name | M10404
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MBD4
Full description | Neighborhood of MBD4 methyl-CpG binding domain protein 4 in the MORF expression compendium

Standard name | MORF_MLLT10
Systematic name | M426
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MLLT10
Full description | Neighborhood of MLLT10 myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila); translocated to, 10 in the MORF expression compendium

Standard name | MORF_MTA1
Systematic name | M10071
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MTA1
Full description | Neighborhood of MTA1 metastasis associated 1 in the MORF expression compendium

Standard name | MORF_MYL3
Systematic name | M1890
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MYL3
Full description | Neighborhood of MYL3 myosin, light chain 3, alkali; ventricular, skeletal, slow in the MORF expression compendium

Standard name | MORF_MYST2
Systematic name | M17492
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MYST2
Full description | Neighborhood of MYST2 MYST histone acetyltransferase 2 in the MORF expression compendium

Standard name | MORF_NME2
Systematic name | M19908
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of NME2
Full description | Neighborhood of NME2 non-metastatic cells 2, protein (NM23B) expressed in in the MORF expression compendium

Standard name | MORF_NOS2A
Systematic name | M8621
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of NOS2A
Full description | Neighborhood of NOS2A nitric oxide synthase 2A (inducible, hepatocytes) in the MORF expression compendium

Standard name | MORF_NPM1
Systematic name | M9993
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of NPM1
Full description | Neighborhood of NPM1 nucleophosmin (nucleolar phosphoprotein B23, numatrin) in the MORF expression compendium

Standard name | MORF_ORC1L
Systematic name | M17184
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ORC1L
Full description | Neighborhood of ORC1L origin recognition complex, subunit 1-like (yeast) in the MORF expression compendium

Standard name | MORF_PAPSS1
Systematic name | M15846
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PAPSS1
Full description | Neighborhood of PAPSS1 3'-phosphoadenosine 5'-phosphosulfate synthase 1 in the MORF expression compendium

Standard name | MORF_PAX7
Systematic name | M18287
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PAX7
Full description | Neighborhood of PAX7 paired box gene 7 in the MORF expression compendium

Standard name | MORF_PDCD1
Systematic name | M7867
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PDCD1
Full description | Neighborhood of PDCD1 programmed cell death 1 in the MORF expression compendium

Standard name | MORF_PDPK1
Systematic name | M15051
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PDPK1
Full description | Neighborhood of PDPK1 3-phosphoinositide dependent protein kinase-1 in the MORF expression compendium

Standard name | MORF_PHB
Systematic name | M7493
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PHB
Full description | Neighborhood of PHB prohibitin in the MORF expression compendium

Standard name | MORF_PML
Systematic name | M14596
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PML
Full description | Neighborhood of PML promyelocytic leukemia in the MORF expression compendium

Standard name | MORF_PPP1CA
Systematic name | M7181
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPP1CA
Full description | Neighborhood of PPP1CA protein phosphatase 1, catalytic subunit, alpha isoform in the MORF expression compendium

Standard name | MORF_PPP1CC
Systematic name | M18610
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPP1CC
Full description | Neighborhood of PPP1CC protein phosphatase 1, catalytic subunit, gamma isoform in the MORF expression compendium

Standard name | MORF_PPP2CA
Systematic name | M16886
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPP2CA
Full description | Neighborhood of PPP2CA protein phosphatase 2 (formerly 2A), catalytic subunit, alpha isoform in the MORF expression compendium

Standard name | MORF_PPP2R4
Systematic name | M13790
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPP2R4
Full description | Neighborhood of PPP2R4 protein phosphatase 2A, regulatory subunit B' (PR 53) in the MORF expression compendium

Standard name | MORF_PPP2R5B
Systematic name | M16012
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPP2R5B
Full description | Neighborhood of PPP2R5B protein phosphatase 2, regulatory subunit B (B56), beta isoform in the MORF expression compendium

Standard name | MORF_PPP2R5E
Systematic name | M9981
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPP2R5E
Full description | Neighborhood of PPP2R5E protein phosphatase 2, regulatory subunit B (B56), epsilon isoform in the MORF expression compendium

Standard name | MORF_PPP5C
Systematic name | M1283
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPP5C
Full description | Neighborhood of PPP5C protein phosphatase 5, catalytic subunit in the MORF expression compendium

Standard name | MORF_PPP6C
Systematic name | M13621
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPP6C
Full description | Neighborhood of PPP6C protein phosphatase 6, catalytic subunit in the MORF expression compendium

Standard name | MORF_PRKACA
Systematic name | M16604
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PRKACA
Full description | Neighborhood of PRKACA protein kinase, cAMP-dependent, catalytic, alpha in the MORF expression compendium

Standard name | MORF_PRKAG1
Systematic name | M1964
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PRKAG1
Full description | Neighborhood of PRKAG1 protein kinase, AMP-activated, gamma 1 non-catalytic subunit in the MORF expression compendium

Standard name | MORF_PRKAR1A
Systematic name | M18071
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PRKAR1A
Full description | Neighborhood of PRKAR1A protein kinase, cAMP-dependent, regulatory, type I, alpha (tissue specific extinguisher 1) in the MORF expression compendium

Standard name | MORF_PRKCA
Systematic name | M13322
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PRKCA
Full description | Neighborhood of PRKCA protein kinase C, alpha in the MORF expression compendium

Standard name | MORF_PTEN
Systematic name | M17366
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTEN
Full description | Neighborhood of PTEN phosphatase and tensin homolog (mutated in multiple advanced cancers 1) in the MORF expression compendium

Standard name | MORF_PTPN11
Systematic name | M7770
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTPN11
Full description | Neighborhood of PTPN11 protein tyrosine phosphatase, non-receptor type 11 (Noonan syndrome 1) in the MORF expression compendium

Standard name | MORF_PTPN9
Systematic name | M3297
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTPN9
Full description | Neighborhood of PTPN9 protein tyrosine phosphatase, non-receptor type 9 in the MORF expression compendium

Standard name | MORF_PTPRB
Systematic name | M8747
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTPRB
Full description | Neighborhood of PTPRB protein tyrosine phosphatase, receptor type, B in the MORF expression compendium

Standard name | MORF_PTPRR
Systematic name | M17931
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTPRR
Full description | Neighborhood of PTPRR protein tyrosine phosphatase, receptor type, R in the MORF expression compendium

Standard name | MORF_RAB11A
Systematic name | M8951
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAB11A
Full description | Neighborhood of RAB11A RAB11A, member RAS oncogene family in the MORF expression compendium

Standard name | MORF_RAB1A
Systematic name | M9350
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAB1A
Full description | Neighborhood of RAB1A RAB1A, member RAS oncogene family in the MORF expression compendium

Standard name | MORF_RAB3A
Systematic name | M14210
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAB3A
Full description | Neighborhood of RAB3A RAB3A, member RAS oncogene family in the MORF expression compendium

Standard name | MORF_RAB5A
Systematic name | M10545
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAB5A
Full description | Neighborhood of RAB5A RAB5A, member RAS oncogene family in the MORF expression compendium

Standard name | MORF_RAB6A
Systematic name | M12962
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAB6A
Full description | Neighborhood of RAB6A RAB6A, member RAS oncogene family in the MORF expression compendium

Standard name | MORF_RAC1
Systematic name | M5796
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAC1
Full description | Neighborhood of RAC1 ras-related C3 botulinum toxin substrate 1 (rho family, small GTP binding protein Rac1) in the MORF expression compendium

Standard name | MORF_RAF1
Systematic name | M1232
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAF1
Full description | Neighborhood of RAF1 v-raf-1 murine leukemia viral oncogene homolog 1 in the MORF expression compendium

Standard name | MORF_RAGE
Systematic name | M1006
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAGE
Full description | Neighborhood of RAGE renal tumor antigen in the MORF expression compendium

Standard name | MORF_RAN
Systematic name | M17615
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAN
Full description | Neighborhood of RAN RAN, member RAS oncogene family in the MORF expression compendium

Standard name | MORF_RAP1A
Systematic name | M14149
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAP1A
Full description | Neighborhood of RAP1A RAP1A, member of RAS oncogene family in the MORF expression compendium

Standard name | MORF_RBBP8
Systematic name | M2430
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RBBP8
Full description | Neighborhood of RBBP8 retinoblastoma binding protein 8 in the MORF expression compendium

Standard name | MORF_RBM8A
Systematic name | M18101
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RBM8A
Full description | Neighborhood of RBM8A RNA binding motif protein 8A in the MORF expression compendium

Standard name | MORF_REV3L
Systematic name | M887
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of REV3L
Full description | Neighborhood of REV3L REV3-like, catalytic subunit of DNA polymerase zeta (yeast) in the MORF expression compendium

Standard name | MORF_RUNX1
Systematic name | M5518
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RUNX1
Full description | Neighborhood of RUNX1 runt-related transcription factor 1 (acute myeloid leukemia 1; aml1 oncogene) in the MORF expression compendium

Standard name | MORF_SART1
Systematic name | M15851
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SART1
Full description | Neighborhood of SART1 squamous cell carcinoma antigen recognised by T cells in the MORF expression compendium

Standard name | MORF_SKP1A
Systematic name | M12287
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SKP1A
Full description | Neighborhood of SKP1A S-phase kinase-associated protein 1A (p19A) in the MORF expression compendium

Standard name | MORF_SNRP70
Systematic name | M10882
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SNRP70
Full description | Neighborhood of SNRP70 small nuclear ribonucleoprotein 70kDa polypeptide (RNP antigen) in the MORF expression compendium

Standard name | MORF_SS18
Systematic name | M18185
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SS18
Full description | Neighborhood of SS18 synovial sarcoma translocation, chromosome 18 in the MORF expression compendium

Standard name | MORF_SUPT3H
Systematic name | M7214
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SUPT3H
Full description | Neighborhood of SUPT3H suppressor of Ty 3 homolog (S. cerevisiae) in the MORF expression compendium

Standard name | MORF_THPO
Systematic name | M14178
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of THPO
Full description | Neighborhood of THPO thrombopoietin (myeloproliferative leukemia virus oncogene ligand, megakaryocyte growth and development factor) in the MORF expression compendium

Standard name | MORF_THRA
Systematic name | M9866
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of THRA
Full description | Neighborhood of THRA thyroid hormone receptor, alpha (erythroblastic leukemia viral (v-erb-a) oncogene homolog, avian) in the MORF expression compendium

Standard name | MORF_TNFRSF25
Systematic name | M18296
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TNFRSF25
Full description | Neighborhood of TNFRSF25 tumor necrosis factor receptor superfamily, member 25 in the MORF expression compendium

Standard name | MORF_TNFRSF6
Systematic name | M3745
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TNFRSF6
Full description | Neighborhood of TNFRSF6 NULL in the MORF expression compendium

Standard name | MORF_TPR
Systematic name | M6400
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TPR
Full description | Neighborhood of TPR translocated promoter region (to activated MET oncogene) in the MORF expression compendium

Standard name | MORF_TPT1
Systematic name | M775
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TPT1
Full description | Neighborhood of TPT1 tumor protein, translationally-controlled 1 in the MORF expression compendium

Standard name | MORF_TTN
Systematic name | M6334
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TTN
Full description | Neighborhood of TTN titin in the MORF expression compendium

Standard name | MORF_UBE2A
Systematic name | M173
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of UBE2A
Full description | Neighborhood of UBE2A ubiquitin-conjugating enzyme E2A (RAD6 homolog) in the MORF expression compendium

Standard name | MORF_UBE2I
Systematic name | M10939
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of UBE2I
Full description | Neighborhood of UBE2I ubiquitin-conjugating enzyme E2I (UBC9 homolog, yeast) in the MORF expression compendium

Standard name | MORF_UBE2N
Systematic name | M1109
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of UBE2N
Full description | Neighborhood of UBE2N ubiquitin-conjugating enzyme E2N (UBC13 homolog, yeast) in the MORF expression compendium

Standard name | MORF_USP5
Systematic name | M19913
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of USP5
Full description | Neighborhood of USP5 ubiquitin specific peptidase 5 (isopeptidase T) in the MORF expression compendium

Standard name | MORF_WNT1
Systematic name | M15256
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of WNT1
Full description | Neighborhood of WNT1 wingless-type MMTV integration site family, member 1 in the MORF expression compendium

Standard name | MORF_ZNF10
Systematic name | M12422
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ZNF10
Full description | Neighborhood of ZNF10 zinc finger protein 10 in the MORF expression compendium

Standard name | GCM_ATM
Systematic name | M14967
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ATM
Full description | Neighborhood of ATM ataxia telangiectasia mutated (includes complementation groups A, C and D) in the GCM expression compendium

Standard name | GCM_BNIP1
Systematic name | M19295
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BNIP1
Full description | Neighborhood of BNIP1 BCL2/adenovirus E1B 19kDa interacting protein 1 in the GCM expression compendium

Standard name | GCM_BAG5
Systematic name | M5900
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BAG5
Full description | Neighborhood of BAG5 BCL2-associated athanogene 5 in the GCM expression compendium

Standard name | GCM_BCL2L1
Systematic name | M11853
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BCL2L1
Full description | Neighborhood of BCL2L1 BCL2-like 1 in the GCM expression compendium

Standard name | GCM_BECN1
Systematic name | M16495
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BECN1
Full description | Neighborhood of BECN1 beclin 1 (coiled-coil, myosin-like BCL2 interacting protein) in the GCM expression compendium

Standard name | GCM_ERBB2IP
Systematic name | M7699
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ERBB2IP
Full description | Neighborhood of ERBB2IP erbb2 interacting protein in the GCM expression compendium

Standard name | GCM_GSTA4
Systematic name | M686
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of GSTA4
Full description | Neighborhood of GSTA4 glutathione S-transferase A4 in the GCM expression compendium

Standard name | GCM_HDAC1
Systematic name | M3292
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HDAC1
Full description | Neighborhood of HDAC1 histone deacetylase 1 in the GCM expression compendium

Standard name | GCM_PSME1
Systematic name | M12304
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PSME1
Full description | Neighborhood of PSME1 proteasome (prosome, macropain) activator subunit 1 (PA28 alpha) in the GCM expression compendium

Standard name | GCM_RAD21
Systematic name | M6582
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAD21
Full description | Neighborhood of RAD21 RAD21 homolog (S. pombe) in the GCM expression compendium

Standard name | GCM_SIRT2
Systematic name | M1706
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SIRT2
Full description | Neighborhood of SIRT2 sirtuin (silent mating type information regulation 2 homolog) 2 (S. cerevisiae) in the GCM expression compendium

Standard name | GCM_TINF2
Systematic name | M5829
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TINF2
Full description | Neighborhood of TINF2 TERF1 (TRF1)-interacting nuclear factor 2 in the GCM expression compendium

Standard name | GCM_ACTG1
Systematic name | M16486
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ACTG1
Full description | Neighborhood of ACTG1 actin, gamma 1 in the GCM expression compendium

Standard name | GCM_AIP
Systematic name | M18347
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of AIP
Full description | Neighborhood of AIP aryl hydrocarbon receptor interacting protein in the GCM expression compendium

Standard name | GCM_ANP32B
Systematic name | M14741
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ANP32B
Full description | Neighborhood of ANP32B acidic (leucine-rich) nuclear phosphoprotein 32 family, member B in the GCM expression compendium

Standard name | GCM_APEX1
Systematic name | M15698
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of APEX1
Full description | Neighborhood of APEX1 APEX nuclease (multifunctional DNA repair enzyme) 1 in the GCM expression compendium

Standard name | GCM_AQP4
Systematic name | M4537
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of AQP4
Full description | Neighborhood of AQP4 aquaporin 4 in the GCM expression compendium

Standard name | GCM_BMPR2
Systematic name | M18257
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BMPR2
Full description | Neighborhood of BMPR2 bone morphogenetic protein receptor, type II (serine/threonine kinase) in the GCM expression compendium

Standard name | GCM_CALM1
Systematic name | M15207
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CALM1
Full description | Neighborhood of CALM1 calmodulin 1 (phosphorylase kinase, delta) in the GCM expression compendium

Standard name | GCM_CASP2
Systematic name | M6471
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CASP2
Full description | Neighborhood of CASP2 caspase 2, apoptosis-related cysteine peptidase (neural precursor cell expressed, developmentally down-regulated 2) in the GCM expression compendium

Standard name | GCM_CBFB
Systematic name | M19743
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CBFB
Full description | Neighborhood of CBFB core-binding factor, beta subunit in the GCM expression compendium

Standard name | GCM_CDH5
Systematic name | M15856
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDH5
Full description | Neighborhood of CDH5 cadherin 5, type 2, VE-cadherin (vascular epithelium) in the GCM expression compendium

Standard name | GCM_CHUK
Systematic name | M4609
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CHUK
Full description | Neighborhood of CHUK conserved helix-loop-helix ubiquitous kinase in the GCM expression compendium

Standard name | GCM_CRKL
Systematic name | M7608
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CRKL
Full description | Neighborhood of CRKL v-crk sarcoma virus CT10 oncogene homolog (avian)-like in the GCM expression compendium

Standard name | GCM_CSNK1A1
Systematic name | M18653
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CSNK1A1
Full description | Neighborhood of CSNK1A1 casein kinase 1, alpha 1 in the GCM expression compendium

Standard name | GCM_CSNK1D
Systematic name | M723
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CSNK1D
Full description | Neighborhood of CSNK1D casein kinase 1, delta in the GCM expression compendium

Standard name | GCM_CSNK2B
Systematic name | M9810
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CSNK2B
Full description | Neighborhood of CSNK2B casein kinase 2, beta polypeptide in the GCM expression compendium

Standard name | GCM_DDX11
Systematic name | M13886
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DDX11
Full description | Neighborhood of DDX11 DEAD/H (Asp-Glu-Ala-Asp/His) box polypeptide 11 (CHL1-like helicase homolog, S. cerevisiae) in the GCM expression compendium

Standard name | GCM_DDX5
Systematic name | M1646
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DDX5
Full description | Neighborhood of DDX5 DEAD (Asp-Glu-Ala-Asp) box polypeptide 5 in the GCM expression compendium

Standard name | GCM_DEAF1
Systematic name | M9098
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DEAF1
Full description | Neighborhood of DEAF1 deformed epidermal autoregulatory factor 1 (Drosophila) in the GCM expression compendium

Standard name | GCM_DENR
Systematic name | M2663
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DENR
Full description | Neighborhood of DENR density-regulated protein in the GCM expression compendium

Standard name | GCM_DFFA
Systematic name | M9388
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DFFA
Full description | Neighborhood of DFFA DNA fragmentation factor, 45kDa, alpha polypeptide in the GCM expression compendium

Standard name | GCM_DLG1
Systematic name | M19545
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DLG1
Full description | Neighborhood of DLG1 discs, large homolog 1 (Drosophila) in the GCM expression compendium

Standard name | GCM_DPF2
Systematic name | M1312
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DPF2
Full description | Neighborhood of DPF2 D4, zinc and double PHD fingers family 2 in the GCM expression compendium

Standard name | GCM_ERCC4
Systematic name | M4608
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ERCC4
Full description | Neighborhood of ERCC4 excision repair cross-complementing rodent repair deficiency, complementation group 4 in the GCM expression compendium

Standard name | GCM_FANCC
Systematic name | M2127
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FANCC
Full description | Neighborhood of FANCC Fanconi anemia, complementation group C in the GCM expression compendium

Standard name | GCM_FANCL
Systematic name | M4184
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FANCL
Full description | Neighborhood of FANCL Fanconi anemia, complementation group L in the GCM expression compendium

Standard name | GCM_FCGR2B
Systematic name | M13116
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FCGR2B
Full description | Neighborhood of FCGR2B Fc fragment of IgG, low affinity IIb, receptor (CD32) in the GCM expression compendium

Standard name | GCM_GSPT1
Systematic name | M10555
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of GSPT1
Full description | Neighborhood of GSPT1 G1 to S phase transition 1 in the GCM expression compendium

Standard name | GCM_HBP1
Systematic name | M5741
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HBP1
Full description | Neighborhood of HBP1 HMG-box transcription factor 1 in the GCM expression compendium

Standard name | GCM_HMGA2
Systematic name | M2495
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HMGA2
Full description | Neighborhood of HMGA2 high mobility group AT-hook 2 in the GCM expression compendium

Standard name | GCM_IL6ST
Systematic name | M19045
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IL6ST
Full description | Neighborhood of IL6ST interleukin 6 signal transducer (gp130, oncostatin M receptor) in the GCM expression compendium

Standard name | GCM_ING1
Systematic name | M4890
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ING1
Full description | Neighborhood of ING1 inhibitor of growth family, member 1 in the GCM expression compendium

Standard name | GCM_LTK
Systematic name | M1621
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of LTK
Full description | Neighborhood of LTK leukocyte tyrosine kinase in the GCM expression compendium

Standard name | GCM_MAP1B
Systematic name | M16631
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAP1B
Full description | Neighborhood of MAP1B microtubule-associated protein 1B in the GCM expression compendium

Standard name | GCM_MAP4K4
Systematic name | M10191
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAP4K4
Full description | Neighborhood of MAP4K4 mitogen-activated protein kinase kinase kinase kinase 4 in the GCM expression compendium

Standard name | GCM_MAPK10
Systematic name | M15252
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAPK10
Full description | Neighborhood of MAPK10 mitogen-activated protein kinase 10 in the GCM expression compendium

Standard name | GCM_MAX
Systematic name | M19116
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAX
Full description | Neighborhood of MAX MYC associated factor X in the GCM expression compendium

Standard name | GCM_MLL
Systematic name | M2457
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MLL
Full description | Neighborhood of MLL myeloid/lymphoid or mixed-lineage leukemia (trithorax homolog, Drosophila) in the GCM expression compendium

Standard name | GCM_MSN
Systematic name | M10646
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MSN
Full description | Neighborhood of MSN moesin in the GCM expression compendium

Standard name | GCM_MYCL1
Systematic name | M11890
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MYCL1
Full description | Neighborhood of MYCL1 v-myc myelocytomatosis viral oncogene homolog 1, lung carcinoma derived (avian) in the GCM expression compendium

Standard name | GCM_MYST2
Systematic name | M8150
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MYST2
Full description | Neighborhood of MYST2 MYST histone acetyltransferase 2 in the GCM expression compendium

Standard name | GCM_NCAM1
Systematic name | M3543
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of NCAM1
Full description | Neighborhood of NCAM1 neural cell adhesion molecule 1 in the GCM expression compendium

Standard name | GCM_NF2
Systematic name | M15007
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of NF2
Full description | Neighborhood of NF2 neurofibromin 2 (bilateral acoustic neuroma) in the GCM expression compendium

Standard name | GCM_NPM1
Systematic name | M1086
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of NPM1
Full description | Neighborhood of NPM1 nucleophosmin (nucleolar phosphoprotein B23, numatrin) in the GCM expression compendium

Standard name | GCM_NUMA1
Systematic name | M1374
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of NUMA1
Full description | Neighborhood of NUMA1 nuclear mitotic apparatus protein 1 in the GCM expression compendium

Standard name | GCM_PFN1
Systematic name | M18404
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PFN1
Full description | Neighborhood of PFN1 profilin 1 in the GCM expression compendium

Standard name | GCM_PPM1D
Systematic name | M11233
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPM1D
Full description | Neighborhood of PPM1D protein phosphatase 1D magnesium-dependent, delta isoform in the GCM expression compendium

Standard name | GCM_PPP1CC
Systematic name | M12309
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPP1CC
Full description | Neighborhood of PPP1CC protein phosphatase 1, catalytic subunit, gamma isoform in the GCM expression compendium

Standard name | GCM_PRKAG1
Systematic name | M6594
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PRKAG1
Full description | Neighborhood of PRKAG1 protein kinase, AMP-activated, gamma 1 non-catalytic subunit in the GCM expression compendium

Standard name | GCM_PRKCG
Systematic name | M12006
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PRKCG
Full description | Neighborhood of PRKCG protein kinase C, gamma in the GCM expression compendium

Standard name | GCM_PTK2
Systematic name | M17046
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTK2
Full description | Neighborhood of PTK2 PTK2 protein tyrosine kinase 2 in the GCM expression compendium

Standard name | GCM_PTPRD
Systematic name | M10475
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTPRD
Full description | Neighborhood of PTPRD protein tyrosine phosphatase, receptor type, D in the GCM expression compendium

Standard name | GCM_PTPRU
Systematic name | M931
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTPRU
Full description | Neighborhood of PTPRU protein tyrosine phosphatase, receptor type, U in the GCM expression compendium

Standard name | GCM_RAB10
Systematic name | M2731
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAB10
Full description | Neighborhood of RAB10 RAB10, member RAS oncogene family in the GCM expression compendium

Standard name | GCM_RAF1
Systematic name | M7638
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAF1
Full description | Neighborhood of RAF1 v-raf-1 murine leukemia viral oncogene homolog 1 in the GCM expression compendium

Standard name | GCM_RAN
Systematic name | M2150
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAN
Full description | Neighborhood of RAN RAN, member RAS oncogene family in the GCM expression compendium

Standard name | GCM_RAP2A
Systematic name | M24
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAP2A
Full description | Neighborhood of RAP2A RAP2A, member of RAS oncogene family in the GCM expression compendium

Standard name | GCM_RBM8A
Systematic name | M16691
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RBM8A
Full description | Neighborhood of RBM8A RNA binding motif protein 8A in the GCM expression compendium

Standard name | GCM_RING1
Systematic name | M12365
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RING1
Full description | Neighborhood of RING1 ring finger protein 1 in the GCM expression compendium

Standard name | GCM_SMARCC1
Systematic name | M6968
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SMARCC1
Full description | Neighborhood of SMARCC1 SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily c, member 1 in the GCM expression compendium

Standard name | GCM_SMARCD1
Systematic name | M3031
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SMARCD1
Full description | Neighborhood of SMARCD1 SWI/SNF related, matrix associated, actin dependent regulator of chromatin, subfamily d, member 1 in the GCM expression compendium

Standard name | GCM_SMO
Systematic name | M5110
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SMO
Full description | Neighborhood of SMO smoothened homolog (Drosophila) in the GCM expression compendium

Standard name | GCM_SUFU
Systematic name | M14067
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SUFU
Full description | Neighborhood of SUFU suppressor of fused homolog (Drosophila) in the GCM expression compendium

Standard name | GCM_SUPT4H1
Systematic name | M3473
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SUPT4H1
Full description | Neighborhood of SUPT4H1 suppressor of Ty 4 homolog 1 (S. cerevisiae) in the GCM expression compendium

Standard name | GCM_TEC
Systematic name | M14585
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TEC
Full description | Neighborhood of TEC tec protein tyrosine kinase in the GCM expression compendium

Standard name | GCM_TPR
Systematic name | M3625
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TPR
Full description | Neighborhood of TPR translocated promoter region (to activated MET oncogene) in the GCM expression compendium

Standard name | GCM_TPT1
Systematic name | M19770
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TPT1
Full description | Neighborhood of TPT1 tumor protein, translationally-controlled 1 in the GCM expression compendium

Standard name | GCM_UBE2N
Systematic name | M5805
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of UBE2N
Full description | Neighborhood of UBE2N ubiquitin-conjugating enzyme E2N (UBC13 homolog, yeast) in the GCM expression compendium

Standard name | GCM_USP6
Systematic name | M191
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of USP6
Full description | Neighborhood of USP6 ubiquitin specific peptidase 6 (Tre-2 oncogene) in the GCM expression compendium

Standard name | GCM_VAV1
Systematic name | M16249
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of VAV1
Full description | Neighborhood of VAV1 vav 1 oncogene in the GCM expression compendium

Standard name | GCM_ZNF198
Systematic name | M1101
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ZNF198
Full description | Neighborhood of ZNF198 NULL in the GCM expression compendium

Standard name | CAR_HPX
Systematic name | M6913
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HPX
Full description | Neighborhood of HPX hemopexin in the CAR expression compendium

Standard name | CAR_IGFBP1
Systematic name | M18034
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IGFBP1
Full description | Neighborhood of IGFBP1 insulin-like growth factor binding protein 1 in the CAR expression compendium

Standard name | CAR_MLANA
Systematic name | M14144
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MLANA
Full description | Neighborhood of MLANA melan-A in the CAR expression compendium

Standard name | CAR_MYST2
Systematic name | M13370
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MYST2
Full description | Neighborhood of MYST2 MYST histone acetyltransferase 2 in the CAR expression compendium

Standard name | CAR_TNFRSF25
Systematic name | M10340
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TNFRSF25
Full description | Neighborhood of TNFRSF25 tumor necrosis factor receptor superfamily, member 25 in the CAR expression compendium

Standard name | CAR_WBSCR22
Systematic name | M2326
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of WBSCR22
Full description | Neighborhood of WBSCR22 Williams Beuren syndrome chromosome region 22 in the CAR expression compendium

Standard name | GNF2_ATM
Systematic name | M8057
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ATM
Full description | Neighborhood of ATM ataxia telangiectasia mutated (includes complementation groups A, C and D) in the GNF2 expression compendium

Standard name | GNF2_BNIP2
Systematic name | M10599
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BNIP2
Full description | Neighborhood of BNIP2 BCL2/adenovirus E1B 19kDa interacting protein 2 in the GNF2 expression compendium

Standard name | GNF2_BNIP3L
Systematic name | M9058
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BNIP3L
Full description | Neighborhood of BNIP3L BCL2/adenovirus E1B 19kDa interacting protein 3-like in the GNF2 expression compendium

Standard name | GNF2_BUB1
Systematic name | M7629
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BUB1
Full description | Neighborhood of BUB1 BUB1 budding uninhibited by benzimidazoles 1 homolog (yeast) in the GNF2 expression compendium

Standard name | GNF2_BUB3
Systematic name | M19951
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BUB3
Full description | Neighborhood of BUB3 BUB3 budding uninhibited by benzimidazoles 3 homolog (yeast) in the GNF2 expression compendium

Standard name | GNF2_CARD15
Systematic name | M7032
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CARD15
Full description | Neighborhood of CARD15 caspase recruitment domain family, member 15 in the GNF2 expression compendium

Standard name | GNF2_CDC20
Systematic name | M17151
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDC20
Full description | Neighborhood of CDC20 CDC20 cell division cycle 20 homolog (S. cerevisiae) in the GNF2 expression compendium

Standard name | GNF2_CDC2
Systematic name | M13566
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDC2
Full description | Neighborhood of CDC2 cell division cycle 2, G1 to S and G2 to M in the GNF2 expression compendium

Standard name | GNF2_CENPE
Systematic name | M5265
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CENPE
Full description | Neighborhood of CENPE centromere protein E, 312kDa in the GNF2 expression compendium

Standard name | GNF2_CENPF
Systematic name | M10439
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CENPF
Full description | Neighborhood of CENPF centromere protein F, 350/400ka (mitosin) in the GNF2 expression compendium

Standard name | GNF2_CCNA1
Systematic name | M13841
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CCNA1
Full description | Neighborhood of CCNA1 cyclin A1 in the GNF2 expression compendium

Standard name | GNF2_CCNA2
Systematic name | M7419
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CCNA2
Full description | Neighborhood of CCNA2 cyclin A2 in the GNF2 expression compendium

Standard name | GNF2_CCNB2
Systematic name | M15766
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CCNB2
Full description | Neighborhood of CCNB2 cyclin B2 in the GNF2 expression compendium

Standard name | GNF2_ESPL1
Systematic name | M664
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ESPL1
Full description | Neighborhood of ESPL1 extra spindle poles like 1 (S. cerevisiae) in the GNF2 expression compendium

Standard name | GNF2_FEN1
Systematic name | M14325
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FEN1
Full description | Neighborhood of FEN1 flap structure-specific endonuclease 1 in the GNF2 expression compendium

Standard name | GNF2_GSTM1
Systematic name | M10693
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of GSTM1
Full description | Neighborhood of GSTM1 glutathione S-transferase M1 in the GNF2 expression compendium

Standard name | GNF2_H2AFX
Systematic name | M112
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of H2AFX
Full description | Neighborhood of H2AFX H2A histone family, member X in the GNF2 expression compendium

Standard name | GNF2_HPX
Systematic name | M14108
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HPX
Full description | Neighborhood of HPX hemopexin in the GNF2 expression compendium

Standard name | GNF2_HAT1
Systematic name | M16298
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HAT1
Full description | Neighborhood of HAT1 histone acetyltransferase 1 in the GNF2 expression compendium

Standard name | GNF2_HDAC1
Systematic name | M5178
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HDAC1
Full description | Neighborhood of HDAC1 histone deacetylase 1 in the GNF2 expression compendium

Standard name | GNF2_TDG
Systematic name | M14651
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TDG
Full description | Neighborhood of TDG thymine-DNA glycosylase in the GNF2 expression compendium

Standard name | GNF2_MLH1
Systematic name | M18640
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MLH1
Full description | Neighborhood of MLH1 mutL homolog 1, colon cancer, nonpolyposis type 2 (E. coli) in the GNF2 expression compendium

Standard name | GNF2_MSH2
Systematic name | M10242
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MSH2
Full description | Neighborhood of MSH2 mutS homolog 2, colon cancer, nonpolyposis type 1 (E. coli) in the GNF2 expression compendium

Standard name | GNF2_MSH6
Systematic name | M16421
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MSH6
Full description | Neighborhood of MSH6 mutS homolog 6 (E. coli) in the GNF2 expression compendium

Standard name | GNF2_PRDX2
Systematic name | M10458
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PRDX2
Full description | Neighborhood of PRDX2 peroxiredoxin 2 in the GNF2 expression compendium

Standard name | GNF2_PCNA
Systematic name | M17279
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PCNA
Full description | Neighborhood of PCNA proliferating cell nuclear antigen in the GNF2 expression compendium

Standard name | GNF2_RAD23A
Systematic name | M19158
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAD23A
Full description | Neighborhood of RAD23A RAD23 homolog A (S. cerevisiae) in the GNF2 expression compendium

Standard name | GNF2_RFC3
Systematic name | M13406
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RFC3
Full description | Neighborhood of RFC3 replication factor C (activator 1) 3, 38kDa in the GNF2 expression compendium

Standard name | GNF2_RFC4
Systematic name | M5444
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RFC4
Full description | Neighborhood of RFC4 replication factor C (activator 1) 4, 37kDa in the GNF2 expression compendium

Standard name | GNF2_RPA1
Systematic name | M6308
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RPA1
Full description | Neighborhood of RPA1 replication protein A1, 70kDa in the GNF2 expression compendium

Standard name | GNF2_RRM1
Systematic name | M11786
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RRM1
Full description | Neighborhood of RRM1 ribonucleotide reductase M1 polypeptide in the GNF2 expression compendium

Standard name | GNF2_RRM2
Systematic name | M11613
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RRM2
Full description | Neighborhood of RRM2 ribonucleotide reductase M2 polypeptide in the GNF2 expression compendium

Standard name | GNF2_SMC1L1
Systematic name | M5308
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SMC1L1
Full description | Neighborhood of SMC1L1 NULL in the GNF2 expression compendium

Standard name | GNF2_SMC2L1
Systematic name | M6962
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SMC2L1
Full description | Neighborhood of SMC2L1 NULL in the GNF2 expression compendium

Standard name | GNF2_SMC4L1
Systematic name | M12856
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SMC4L1
Full description | Neighborhood of SMC4L1 NULL in the GNF2 expression compendium

Standard name | GNF2_TST
Systematic name | M17919
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TST
Full description | Neighborhood of TST thiosulfate sulfurtransferase (rhodanese) in the GNF2 expression compendium

Standard name | GNF2_XRCC5
Systematic name | M1332
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of XRCC5
Full description | Neighborhood of XRCC5 X-ray repair complementing defective repair in Chinese hamster cells 5 (double-strand-break rejoining; Ku autoantigen, 80kDa) in the GNF2 expression compendium

Standard name | GNF2_AF1Q
Systematic name | M3849
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of AF1Q
Full description | Neighborhood of AF1Q NULL in the GNF2 expression compendium

Standard name | GNF2_ANK1
Systematic name | M11900
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ANK1
Full description | Neighborhood of ANK1 ankyrin 1, erythrocytic in the GNF2 expression compendium

Standard name | GNF2_ANP32B
Systematic name | M12593
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ANP32B
Full description | Neighborhood of ANP32B acidic (leucine-rich) nuclear phosphoprotein 32 family, member B in the GNF2 expression compendium

Standard name | GNF2_APEX1
Systematic name | M8078
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of APEX1
Full description | Neighborhood of APEX1 APEX nuclease (multifunctional DNA repair enzyme) 1 in the GNF2 expression compendium

Standard name | GNF2_BUB1B
Systematic name | M8304
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of BUB1B
Full description | Neighborhood of BUB1B BUB1 budding uninhibited by benzimidazoles 1 homolog beta (yeast) in the GNF2 expression compendium

Standard name | GNF2_CASP1
Systematic name | M4396
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CASP1
Full description | Neighborhood of CASP1 caspase 1, apoptosis-related cysteine peptidase (interleukin 1, beta, convertase) in the GNF2 expression compendium

Standard name | GNF2_CASP4
Systematic name | M782
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CASP4
Full description | Neighborhood of CASP4 caspase 4, apoptosis-related cysteine peptidase in the GNF2 expression compendium

Standard name | GNF2_CASP8
Systematic name | M1057
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CASP8
Full description | Neighborhood of CASP8 caspase 8, apoptosis-related cysteine peptidase in the GNF2 expression compendium

Standard name | GNF2_CBFB
Systematic name | M7512
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CBFB
Full description | Neighborhood of CBFB core-binding factor, beta subunit in the GNF2 expression compendium

Standard name | GNF2_CD14
Systematic name | M718
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CD14
Full description | Neighborhood of CD14 CD14 molecule in the GNF2 expression compendium

Standard name | GNF2_CD1D
Systematic name | M12582
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CD1D
Full description | Neighborhood of CD1D CD1d molecule in the GNF2 expression compendium

Standard name | GNF2_CD33
Systematic name | M8373
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CD33
Full description | Neighborhood of CD33 CD33 molecule in the GNF2 expression compendium

Standard name | GNF2_CD48
Systematic name | M909
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CD48
Full description | Neighborhood of CD48 CD48 molecule in the GNF2 expression compendium

Standard name | GNF2_CD53
Systematic name | M17909
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CD53
Full description | Neighborhood of CD53 CD53 molecule in the GNF2 expression compendium

Standard name | GNF2_CD7
Systematic name | M245
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CD7
Full description | Neighborhood of CD7 CD7 molecule in the GNF2 expression compendium

Standard name | GNF2_CD97
Systematic name | M14477
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CD97
Full description | Neighborhood of CD97 CD97 molecule in the GNF2 expression compendium

Standard name | GNF2_CDC27
Systematic name | M7470
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDC27
Full description | Neighborhood of CDC27 cell division cycle 27 in the GNF2 expression compendium

Standard name | GNF2_CDH11
Systematic name | M12987
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDH11
Full description | Neighborhood of CDH11 cadherin 11, type 2, OB-cadherin (osteoblast) in the GNF2 expression compendium

Standard name | GNF2_CDH3
Systematic name | M17677
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDH3
Full description | Neighborhood of CDH3 cadherin 3, type 1, P-cadherin (placental) in the GNF2 expression compendium

Standard name | GNF2_CDKN1C
Systematic name | M14550
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CDKN1C
Full description | Neighborhood of CDKN1C cyclin-dependent kinase inhibitor 1C (p57, Kip2) in the GNF2 expression compendium

Standard name | GNF2_CEBPA
Systematic name | M3221
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CEBPA
Full description | Neighborhood of CEBPA CCAAT/enhancer binding protein (C/EBP), alpha in the GNF2 expression compendium

Standard name | GNF2_CKS1B
Systematic name | M10065
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CKS1B
Full description | Neighborhood of CKS1B CDC28 protein kinase regulatory subunit 1B in the GNF2 expression compendium

Standard name | GNF2_CKS2
Systematic name | M3537
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CKS2
Full description | Neighborhood of CKS2 CDC28 protein kinase regulatory subunit 2 in the GNF2 expression compendium

Standard name | GNF2_CYP2B6
Systematic name | M19409
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of CYP2B6
Full description | Neighborhood of CYP2B6 cytochrome P450, family 2, subfamily B, polypeptide 6 in the GNF2 expression compendium

Standard name | GNF2_DAP3
Systematic name | M3928
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DAP3
Full description | Neighborhood of DAP3 death associated protein 3 in the GNF2 expression compendium

Standard name | GNF2_DDX5
Systematic name | M15135
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DDX5
Full description | Neighborhood of DDX5 DEAD (Asp-Glu-Ala-Asp) box polypeptide 5 in the GNF2 expression compendium

Standard name | GNF2_DEK
Systematic name | M15612
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DEK
Full description | Neighborhood of DEK DEK oncogene (DNA binding) in the GNF2 expression compendium

Standard name | GNF2_DENR
Systematic name | M7368
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DENR
Full description | Neighborhood of DENR density-regulated protein in the GNF2 expression compendium

Standard name | GNF2_DNM1
Systematic name | M3373
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of DNM1
Full description | Neighborhood of DNM1 dynamin 1 in the GNF2 expression compendium

Standard name | GNF2_EGFR
Systematic name | M4193
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of EGFR
Full description | Neighborhood of EGFR epidermal growth factor receptor (erythroblastic leukemia viral (v-erb-b) oncogene homolog, avian) in the GNF2 expression compendium

Standard name | GNF2_EIF3S6
Systematic name | M3758
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of EIF3S6
Full description | Neighborhood of EIF3S6 eukaryotic translation initiation factor 3, subunit 6 48kDa in the GNF2 expression compendium

Standard name | GNF2_ELAC2
Systematic name | M14913
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ELAC2
Full description | Neighborhood of ELAC2 elaC homolog 2 (E. coli) in the GNF2 expression compendium

Standard name | GNF2_FBL
Systematic name | M1339
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FBL
Full description | Neighborhood of FBL fibrillarin in the GNF2 expression compendium

Standard name | GNF2_FGR
Systematic name | M5798
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FGR
Full description | Neighborhood of FGR Gardner-Rasheed feline sarcoma viral (v-fgr) oncogene homolog in the GNF2 expression compendium

Standard name | GNF2_FOS
Systematic name | M19427
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of FOS
Full description | Neighborhood of FOS v-fos FBJ murine osteosarcoma viral oncogene homolog in the GNF2 expression compendium

Standard name | GNF2_G22P1
Systematic name | M4536
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of G22P1
Full description | Neighborhood of G22P1 NULL in the GNF2 expression compendium

Standard name | GNF2_GLTSCR2
Systematic name | M8167
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of GLTSCR2
Full description | Neighborhood of GLTSCR2 glioma tumor suppressor candidate region gene 2 in the GNF2 expression compendium

Standard name | GNF2_HCK
Systematic name | M14338
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HCK
Full description | Neighborhood of HCK hemopoietic cell kinase in the GNF2 expression compendium

Standard name | GNF2_HLA_C
Systematic name | M5267
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HLA-C
Full description | Neighborhood of HLA-C major histocompatibility complex, class I, C in the GNF2 expression compendium

Standard name | GNF2_HMMR
Systematic name | M12521
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HMMR
Full description | Neighborhood of HMMR hyaluronan-mediated motility receptor (RHAMM) in the GNF2 expression compendium

Standard name | GNF2_HPN
Systematic name | M10917
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of HPN
Full description | Neighborhood of HPN hepsin (transmembrane protease, serine 1) in the GNF2 expression compendium

Standard name | GNF2_ICAM3
Systematic name | M12772
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ICAM3
Full description | Neighborhood of ICAM3 intercellular adhesion molecule 3 in the GNF2 expression compendium

Standard name | GNF2_IGF1
Systematic name | M16314
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IGF1
Full description | Neighborhood of IGF1 insulin-like growth factor 1 (somatomedin C) in the GNF2 expression compendium

Standard name | GNF2_IGFBP1
Systematic name | M9592
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IGFBP1
Full description | Neighborhood of IGFBP1 insulin-like growth factor binding protein 1 in the GNF2 expression compendium

Standard name | GNF2_IL2RB
Systematic name | M13733
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of IL2RB
Full description | Neighborhood of IL2RB interleukin 2 receptor, beta in the GNF2 expression compendium

Standard name | GNF2_INPP5D
Systematic name | M9268
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of INPP5D
Full description | Neighborhood of INPP5D inositol polyphosphate-5-phosphatase, 145kDa in the GNF2 expression compendium

Standard name | GNF2_ITGAL
Systematic name | M5802
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ITGAL
Full description | Neighborhood of ITGAL integrin, alpha L (antigen CD11A (p180), lymphocyte function-associated antigen 1; alpha polypeptide) in the GNF2 expression compendium

Standard name | GNF2_ITGB2
Systematic name | M1953
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ITGB2
Full description | Neighborhood of ITGB2 integrin, beta 2 (complement component 3 receptor 3 and 4 subunit) in the GNF2 expression compendium

Standard name | GNF2_JAK1
Systematic name | M16276
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of JAK1
Full description | Neighborhood of JAK1 Janus kinase 1 (a protein tyrosine kinase) in the GNF2 expression compendium

Standard name | GNF2_KISS1
Systematic name | M14039
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of KISS1
Full description | Neighborhood of KISS1 KiSS-1 metastasis-suppressor in the GNF2 expression compendium

Standard name | GNF2_KPNB1
Systematic name | M3736
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of KPNB1
Full description | Neighborhood of KPNB1 karyopherin (importin) beta 1 in the GNF2 expression compendium

Standard name | GNF2_LCAT
Systematic name | M132
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of LCAT
Full description | Neighborhood of LCAT lecithin-cholesterol acyltransferase in the GNF2 expression compendium

Standard name | GNF2_LYN
Systematic name | M11485
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of LYN
Full description | Neighborhood of LYN v-yes-1 Yamaguchi sarcoma viral related oncogene homolog in the GNF2 expression compendium

Standard name | GNF2_MAP2K3
Systematic name | M1670
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAP2K3
Full description | Neighborhood of MAP2K3 mitogen-activated protein kinase kinase 3 in the GNF2 expression compendium

Standard name | GNF2_MAPT
Systematic name | M8546
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MAPT
Full description | Neighborhood of MAPT microtubule-associated protein tau in the GNF2 expression compendium

Standard name | GNF2_MATK
Systematic name | M1849
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MATK
Full description | Neighborhood of MATK megakaryocyte-associated tyrosine kinase in the GNF2 expression compendium

Standard name | GNF2_MBD4
Systematic name | M4837
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MBD4
Full description | Neighborhood of MBD4 methyl-CpG binding domain protein 4 in the GNF2 expression compendium

Standard name | GNF2_MCL1
Systematic name | M1250
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MCL1
Full description | Neighborhood of MCL1 myeloid cell leukemia sequence 1 (BCL2-related) in the GNF2 expression compendium

Standard name | GNF2_MCM4
Systematic name | M17594
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MCM4
Full description | Neighborhood of MCM4 MCM4 minichromosome maintenance deficient 4 (S. cerevisiae) in the GNF2 expression compendium

Standard name | GNF2_MCM5
Systematic name | M11522
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MCM5
Full description | Neighborhood of MCM5 MCM5 minichromosome maintenance deficient 5, cell division cycle 46 (S. cerevisiae) in the GNF2 expression compendium

Standard name | GNF2_MKI67
Systematic name | M6132
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MKI67
Full description | Neighborhood of MKI67 antigen identified by monoclonal antibody Ki-67 in the GNF2 expression compendium

Standard name | GNF2_MLF1
Systematic name | M9069
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MLF1
Full description | Neighborhood of MLF1 myeloid leukemia factor 1 in the GNF2 expression compendium

Standard name | GNF2_MMP1
Systematic name | M5587
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MMP1
Full description | Neighborhood of MMP1 matrix metallopeptidase 1 (interstitial collagenase) in the GNF2 expression compendium

Standard name | GNF2_MMP11
Systematic name | M989
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MMP11
Full description | Neighborhood of MMP11 matrix metallopeptidase 11 (stromelysin 3) in the GNF2 expression compendium

Standard name | GNF2_MSN
Systematic name | M10388
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MSN
Full description | Neighborhood of MSN moesin in the GNF2 expression compendium

Standard name | GNF2_MYD88
Systematic name | M13614
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MYD88
Full description | Neighborhood of MYD88 myeloid differentiation primary response gene (88) in the GNF2 expression compendium

Standard name | GNF2_MYL2
Systematic name | M8715
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MYL2
Full description | Neighborhood of MYL2 myosin, light chain 2, regulatory, cardiac, slow in the GNF2 expression compendium

Standard name | GNF2_MYL3
Systematic name | M11742
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of MYL3
Full description | Neighborhood of MYL3 myosin, light chain 3, alkali; ventricular, skeletal, slow in the GNF2 expression compendium

Standard name | GNF2_NPM1
Systematic name | M9226
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of NPM1
Full description | Neighborhood of NPM1 nucleophosmin (nucleolar phosphoprotein B23, numatrin) in the GNF2 expression compendium

Standard name | GNF2_NS
Systematic name | M18354
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of NS
Full description | Neighborhood of NS NULL in the GNF2 expression compendium

Standard name | GNF2_PA2G4
Systematic name | M218
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PA2G4
Full description | Neighborhood of PA2G4 proliferation-associated 2G4, 38kDa in the GNF2 expression compendium

Standard name | GNF2_PAK2
Systematic name | M13540
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PAK2
Full description | Neighborhood of PAK2 p21 (CDKN1A)-activated kinase 2 in the GNF2 expression compendium

Standard name | GNF2_PCAF
Systematic name | M14349
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PCAF
Full description | Neighborhood of PCAF p300/CBP-associated factor in the GNF2 expression compendium

Standard name | GNF2_PECAM1
Systematic name | M17265
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PECAM1
Full description | Neighborhood of PECAM1 platelet/endothelial cell adhesion molecule (CD31 antigen) in the GNF2 expression compendium

Standard name | GNF2_PPP6C
Systematic name | M5537
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PPP6C
Full description | Neighborhood of PPP6C protein phosphatase 6, catalytic subunit in the GNF2 expression compendium

Standard name | GNF2_PTPN4
Systematic name | M16951
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTPN4
Full description | Neighborhood of PTPN4 protein tyrosine phosphatase, non-receptor type 4 (megakaryocyte) in the GNF2 expression compendium

Standard name | GNF2_PTPN6
Systematic name | M7957
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTPN6
Full description | Neighborhood of PTPN6 protein tyrosine phosphatase, non-receptor type 6 in the GNF2 expression compendium

Standard name | GNF2_PTPRC
Systematic name | M15369
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTPRC
Full description | Neighborhood of PTPRC protein tyrosine phosphatase, receptor type, C in the GNF2 expression compendium

Standard name | GNF2_PTX3
Systematic name | M11282
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of PTX3
Full description | Neighborhood of PTX3 pentraxin-related gene, rapidly induced by IL-1 beta in the GNF2 expression compendium

Standard name | GNF2_RAB3A
Systematic name | M15601
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAB3A
Full description | Neighborhood of RAB3A RAB3A, member RAS oncogene family in the GNF2 expression compendium

Standard name | GNF2_RAB7L1
Systematic name | M7421
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAB7L1
Full description | Neighborhood of RAB7L1 RAB7, member RAS oncogene family-like 1 in the GNF2 expression compendium

Standard name | GNF2_RAN
Systematic name | M7487
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAN
Full description | Neighborhood of RAN RAN, member RAS oncogene family in the GNF2 expression compendium

Standard name | GNF2_RAP1B
Systematic name | M9756
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RAP1B
Full description | Neighborhood of RAP1B RAP1B, member of RAS oncogene family in the GNF2 expression compendium

Standard name | GNF2_RBBP6
Systematic name | M4107
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RBBP6
Full description | Neighborhood of RBBP6 retinoblastoma binding protein 6 in the GNF2 expression compendium

Standard name | GNF2_RTN1
Systematic name | M10137
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of RTN1
Full description | Neighborhood of RTN1 reticulon 1 in the GNF2 expression compendium

Standard name | GNF2_S100A4
Systematic name | M13076
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of S100A4
Full description | Neighborhood of S100A4 S100 calcium binding protein A4 in the GNF2 expression compendium

Standard name | GNF2_SELL
Systematic name | M9200
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SELL
Full description | Neighborhood of SELL selectin L (lymphocyte adhesion molecule 1) in the GNF2 expression compendium

Standard name | GNF2_SERPINB5
Systematic name | M9365
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SERPINB5
Full description | Neighborhood of SERPINB5 serpin peptidase inhibitor, clade B (ovalbumin), member 5 in the GNF2 expression compendium

Standard name | GNF2_SERPINI2
Systematic name | M5062
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SERPINI2
Full description | Neighborhood of SERPINI2 serpin peptidase inhibitor, clade I (pancpin), member 2 in the GNF2 expression compendium

Standard name | GNF2_SNRK
Systematic name | M15392
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SNRK
Full description | Neighborhood of SNRK SNF related kinase in the GNF2 expression compendium

Standard name | GNF2_SPI1
Systematic name | M9
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SPI1
Full description | Neighborhood of SPI1 spleen focus forming virus (SFFV) proviral integration oncogene spi1 in the GNF2 expression compendium

Standard name | GNF2_SPINK1
Systematic name | M8706
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SPINK1
Full description | Neighborhood of SPINK1 serine peptidase inhibitor, Kazal type 1 in the GNF2 expression compendium

Standard name | GNF2_SPRR1B
Systematic name | M2266
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SPRR1B
Full description | Neighborhood of SPRR1B small proline-rich protein 1B (cornifin) in the GNF2 expression compendium

Standard name | GNF2_SPTA1
Systematic name | M13711
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SPTA1
Full description | Neighborhood of SPTA1 spectrin, alpha, erythrocytic 1 (elliptocytosis 2) in the GNF2 expression compendium

Standard name | GNF2_SPTB
Systematic name | M5633
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of SPTB
Full description | Neighborhood of SPTB spectrin, beta, erythrocytic (includes spherocytosis, clinical type I) in the GNF2 expression compendium

Standard name | GNF2_ST13
Systematic name | M148
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ST13
Full description | Neighborhood of ST13 suppression of tumorigenicity 13 (colon carcinoma) (Hsp70 interacting protein) in the GNF2 expression compendium

Standard name | GNF2_STAT6
Systematic name | M8633
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of STAT6
Full description | Neighborhood of STAT6 signal transducer and activator of transcription 6, interleukin-4 induced in the GNF2 expression compendium

Standard name | GNF2_TAL1
Systematic name | M19762
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TAL1
Full description | Neighborhood of TAL1 T-cell acute lymphocytic leukemia 1 in the GNF2 expression compendium

Standard name | GNF2_TIMP2
Systematic name | M18883
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TIMP2
Full description | Neighborhood of TIMP2 TIMP metallopeptidase inhibitor 2 in the GNF2 expression compendium

Standard name | GNF2_TM4SF2
Systematic name | M13367
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TM4SF2
Full description | Neighborhood of TM4SF2 NULL in the GNF2 expression compendium

Standard name | GNF2_TNFRSF1B
Systematic name | M356
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TNFRSF1B
Full description | Neighborhood of TNFRSF1B tumor necrosis factor receptor superfamily, member 1B in the GNF2 expression compendium

Standard name | GNF2_TNFSF10
Systematic name | M5552
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TNFSF10
Full description | Neighborhood of TNFSF10 tumor necrosis factor (ligand) superfamily, member 10 in the GNF2 expression compendium

Standard name | GNF2_TPT1
Systematic name | M10746
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TPT1
Full description | Neighborhood of TPT1 tumor protein, translationally-controlled 1 in the GNF2 expression compendium

Standard name | GNF2_TTK
Systematic name | M4598
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TTK
Full description | Neighborhood of TTK TTK protein kinase in the GNF2 expression compendium

Standard name | GNF2_TTN
Systematic name | M8295
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TTN
Full description | Neighborhood of TTN titin in the GNF2 expression compendium

Standard name | GNF2_TYK2
Systematic name | M3455
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of TYK2
Full description | Neighborhood of TYK2 tyrosine kinase 2 in the GNF2 expression compendium

Standard name | GNF2_UBE2I
Systematic name | M4591
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of UBE2I
Full description | Neighborhood of UBE2I ubiquitin-conjugating enzyme E2I (UBC9 homolog, yeast) in the GNF2 expression compendium

Standard name | GNF2_VAV1
Systematic name | M17314
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of VAV1
Full description | Neighborhood of VAV1 vav 1 oncogene in the GNF2 expression compendium

Standard name | GNF2_ZAP70
Systematic name | M1169
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CGN
Brief description | Neighborhood of ZAP70
Full description | Neighborhood of ZAP70 zeta-chain (TCR) associated protein kinase 70kDa in the GNF2 expression compendium

Standard name | MODULE_1
Systematic name | M4051
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Ovary genes.
Full description |

Standard name | MODULE_2
Systematic name | M9982
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | DRG (dorsal root ganglia) genes.
Full description |

Standard name | MODULE_3
Systematic name | M9199
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 3.
Full description |

Standard name | MODULE_4
Systematic name | M19318
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 4.
Full description |

Standard name | MODULE_5
Systematic name | M7383
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Lung genes.
Full description |

Standard name | MODULE_6
Systematic name | M15336
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Trachea genes.
Full description |

Standard name | MODULE_7
Systematic name | M18890
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 7.
Full description |

Standard name | MODULE_8
Systematic name | M956
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 8.
Full description |

Standard name | MODULE_9
Systematic name | M3451
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 9.
Full description |

Standard name | MODULE_11
Systematic name | M15730
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 11.
Full description |

Standard name | MODULE_12
Systematic name | M18929
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Spinal cord (neuro-development) genes.
Full description |

Standard name | MODULE_13
Systematic name | M1814
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 12.
Full description |

Standard name | MODULE_14
Systematic name | M9798
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 13.
Full description |

Standard name | MODULE_15
Systematic name | M19542
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 14.
Full description |

Standard name | MODULE_16
Systematic name | M11489
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 15.
Full description |

Standard name | MODULE_17
Systematic name | M4409
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 17.
Full description |

Standard name | MODULE_18
Systematic name | M15619
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 18.
Full description |

Standard name | MODULE_19
Systematic name | M2667
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Adrenal gland - metabolic genes.
Full description |

Standard name | MODULE_20
Systematic name | M15863
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 20.
Full description |

Standard name | MODULE_21
Systematic name | M1971
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 21.
Full description |

Standard name | MODULE_22
Systematic name | M2625
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 22.
Full description |

Standard name | MODULE_23
Systematic name | M1872
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Liver genes - metabolism and xenobiotics.
Full description |

Standard name | MODULE_24
Systematic name | M5702
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Fetal liver genes - metabolism and xenobiotics.
Full description |

Standard name | MODULE_25
Systematic name | M6259
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 25.
Full description |

Standard name | MODULE_26
Systematic name | M4874
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 26.
Full description |

Standard name | MODULE_27
Systematic name | M688
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 27.
Full description |

Standard name | MODULE_28
Systematic name | M16869
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 28.
Full description |

Standard name | MODULE_29
Systematic name | M15897
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 29.
Full description |

Standard name | MODULE_32
Systematic name | M7466
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 32.
Full description |

Standard name | MODULE_33
Systematic name | M7360
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Immune / stress response genes.
Full description |

Standard name | MODULE_35
Systematic name | M18546
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 35.
Full description |

Standard name | MODULE_36
Systematic name | M3482
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 36.
Full description |

Standard name | MODULE_37
Systematic name | M2507
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 37.
Full description |

Standard name | MODULE_38
Systematic name | M16071
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Placenta genes.
Full description |

Standard name | MODULE_39
Systematic name | M2971
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 39.
Full description |

Standard name | MODULE_40
Systematic name | M9683
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Organic acid metabolism.
Full description |

Standard name | MODULE_41
Systematic name | M2283
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 41.
Full description |

Standard name | MODULE_42
Systematic name | M15800
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 42.
Full description |

Standard name | MODULE_43
Systematic name | M5974
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Energy pathways.
Full description |

Standard name | MODULE_44
Systematic name | M3463
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Thymus genes.
Full description |

Standard name | MODULE_45
Systematic name | M10888
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Whole blood genes.
Full description |

Standard name | MODULE_46
Systematic name | M15983
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 46.
Full description |

Standard name | MODULE_47
Systematic name | M16395
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | ECM and collagens.
Full description |

Standard name | MODULE_48
Systematic name | M15656
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 48.
Full description |

Standard name | MODULE_49
Systematic name | M19386
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 49.
Full description |

Standard name | MODULE_50
Systematic name | M922
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 50.
Full description |

Standard name | MODULE_51
Systematic name | M3541
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 51.
Full description |

Standard name | MODULE_52
Systematic name | M10190
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Cell line expressed genes.
Full description |

Standard name | MODULE_53
Systematic name | M8921
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Cell line expressed genes.
Full description |

Standard name | MODULE_54
Systematic name | M5468
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Cell cycle (expression cluster).
Full description |

Standard name | MODULE_55
Systematic name | M17558
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 55.
Full description |

Standard name | MODULE_56
Systematic name | M10672
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Cell cycle (KEGG, GenMapp).
Full description |

Standard name | MODULE_57
Systematic name | M582
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 57.
Full description |

Standard name | MODULE_58
Systematic name | M14677
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 58.
Full description |

Standard name | MODULE_59
Systematic name | M11886
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 59.
Full description |

Standard name | MODULE_60
Systematic name | M15763
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Heart genes.
Full description |

Standard name | MODULE_61
Systematic name | M7855
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 61.
Full description |

Standard name | MODULE_62
Systematic name | M16474
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 62.
Full description |

Standard name | MODULE_63
Systematic name | M5770
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Porins / transporters.
Full description |

Standard name | MODULE_64
Systematic name | M10899
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Membranal receptors.
Full description |

Standard name | MODULE_65
Systematic name | M11146
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 65.
Full description |

Standard name | MODULE_66
Systematic name | M12065
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 66.
Full description |

Standard name | MODULE_67
Systematic name | M7663
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 67.
Full description |

Standard name | MODULE_68
Systematic name | M19014
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 68.
Full description |

Standard name | MODULE_69
Systematic name | M17524
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 69.
Full description |

Standard name | MODULE_70
Systematic name | M11806
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 70.
Full description |

Standard name | MODULE_71
Systematic name | M13595
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 71.
Full description |

Standard name | MODULE_72
Systematic name | M5260
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Testis genes.
Full description |

Standard name | MODULE_73
Systematic name | M18643
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 73.
Full description |

Standard name | MODULE_75
Systematic name | M12401
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Immune response.
Full description |

Standard name | MODULE_76
Systematic name | M17322
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Inflammatory response.
Full description |

Standard name | MODULE_77
Systematic name | M10738
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 77.
Full description |

Standard name | MODULE_78
Systematic name | M3887
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | AA metabolism.
Full description |

Standard name | MODULE_79
Systematic name | M8286
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 79.
Full description |

Standard name | MODULE_80
Systematic name | M16640
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 80.
Full description |

Standard name | MODULE_81
Systematic name | M8114
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 81.
Full description |

Standard name | MODULE_82
Systematic name | M16146
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 82.
Full description |

Standard name | MODULE_83
Systematic name | M4842
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 83.
Full description |

Standard name | MODULE_84
Systematic name | M8838
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Immune (humoral) and inflammatory response.
Full description |

Standard name | MODULE_85
Systematic name | M19421
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 85.
Full description |

Standard name | MODULE_86
Systematic name | M13925
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Small monomeric GTPases.
Full description |

Standard name | MODULE_87
Systematic name | M5631
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 87.
Full description |

Standard name | MODULE_88
Systematic name | M14358
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Heart, liver, kidney and pancreas metabolic and xenobiotic response genes.
Full description |

Standard name | MODULE_89
Systematic name | M9919
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 89.
Full description |

Standard name | MODULE_90
Systematic name | M5869
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 90.
Full description |

Standard name | MODULE_91
Systematic name | M4414
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Proteasome.
Full description |

Standard name | MODULE_92
Systematic name | M10197
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Secreted signaling molecules.
Full description |

Standard name | MODULE_93
Systematic name | M10134
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Oxidoreductases.
Full description |

Standard name | MODULE_94
Systematic name | M8806
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Signaling.
Full description |

Standard name | MODULE_95
Systematic name | M15941
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 95.
Full description |

Standard name | MODULE_96
Systematic name | M5123
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 96.
Full description |

Standard name | MODULE_97
Systematic name | M10167
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 97.
Full description |

Standard name | MODULE_98
Systematic name | M14843
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 98.
Full description |

Standard name | MODULE_99
Systematic name | M13472
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 99.
Full description |

Standard name | MODULE_100
Systematic name | M19344
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 100.
Full description |

Standard name | MODULE_101
Systematic name | M9144
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 101.
Full description |

Standard name | MODULE_102
Systematic name | M18840
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Nucleotide (purine) biosynthesis.
Full description |

Standard name | MODULE_103
Systematic name | M3611
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 103.
Full description |

Standard name | MODULE_104
Systematic name | M17233
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 104.
Full description |

Standard name | MODULE_105
Systematic name | M6479
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 105.
Full description |

Standard name | MODULE_106
Systematic name | M5646
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Cytochrome P450.
Full description |

Standard name | MODULE_107
Systematic name | M17376
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 107.
Full description |

Standard name | MODULE_108
Systematic name | M6482
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 108.
Full description |

Standard name | MODULE_109
Systematic name | M13003
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Serine proteases.
Full description |

Standard name | MODULE_110
Systematic name | M14643
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 110.
Full description |

Standard name | MODULE_111
Systematic name | M8074
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 111.
Full description |

Standard name | MODULE_112
Systematic name | M16447
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 112.
Full description |

Standard name | MODULE_113
Systematic name | M14588
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 113.
Full description |

Standard name | MODULE_114
Systematic name | M16804
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Protein biosynthesis and ribosomes.
Full description |

Standard name | MODULE_115
Systematic name | M1580
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 115.
Full description |

Standard name | MODULE_116
Systematic name | M9417
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 116.
Full description |

Standard name | MODULE_117
Systematic name | M8950
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Signaling.
Full description |

Standard name | MODULE_118
Systematic name | M12108
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | cell line expressed genes.
Full description |

Standard name | MODULE_119
Systematic name | M7315
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 119.
Full description |

Standard name | MODULE_120
Systematic name | M12285
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 120.
Full description |

Standard name | MODULE_121
Systematic name | M18183
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 121.
Full description |

Standard name | MODULE_122
Systematic name | M414
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Adhesion molecules.
Full description |

Standard name | MODULE_123
Systematic name | M13751
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 123.
Full description |

Standard name | MODULE_124
Systematic name | M16174
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Transcription.
Full description |

Standard name | MODULE_125
Systematic name | M15402
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 125.
Full description |

Standard name | MODULE_126
Systematic name | M7614
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Lymphoma and immune response expression clusters.
Full description |

Standard name | MODULE_127
Systematic name | M17337
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 127.
Full description |

Standard name | MODULE_128
Systematic name | M11185
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 128.
Full description |

Standard name | MODULE_129
Systematic name | M2175
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Signaling.
Full description |

Standard name | MODULE_130
Systematic name | M14084
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Complement.
Full description |

Standard name | MODULE_131
Systematic name | M8116
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Blood coagulation factors.
Full description |

Standard name | MODULE_132
Systematic name | M2028
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 132.
Full description |

Standard name | MODULE_133
Systematic name | M6534
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 133.
Full description |

Standard name | MODULE_134
Systematic name | M3544
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 134.
Full description |

Standard name | MODULE_135
Systematic name | M8592
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 135.
Full description |

Standard name | MODULE_136
Systematic name | M8360
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 136.
Full description |

Standard name | MODULE_137
Systematic name | M2519
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | CNS genes.
Full description |

Standard name | MODULE_138
Systematic name | M7029
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 138.
Full description |

Standard name | MODULE_139
Systematic name | M19525
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 139.
Full description |

Standard name | MODULE_141
Systematic name | M17013
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 141.
Full description |

Standard name | MODULE_143
Systematic name | M11830
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 143.
Full description |

Standard name | MODULE_145
Systematic name | M5881
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 145.
Full description |

Standard name | MODULE_146
Systematic name | M6672
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 146.
Full description |

Standard name | MODULE_147
Systematic name | M14443
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | GPCR.
Full description |

Standard name | MODULE_148
Systematic name | M17934
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 148.
Full description |

Standard name | MODULE_149
Systematic name | M11552
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Translation factors.
Full description |

Standard name | MODULE_150
Systematic name | M11059
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Ttranslation elongation.
Full description |

Standard name | MODULE_151
Systematic name | M10736
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 151.
Full description |

Standard name | MODULE_152
Systematic name | M19044
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Oxidative phosphorylation and ATP synthesis.
Full description |

Standard name | MODULE_153
Systematic name | M18849
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 153.
Full description |

Standard name | MODULE_154
Systematic name | M18170
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Intermediate filaments.
Full description |

Standard name | MODULE_155
Systematic name | M3370
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 155.
Full description |

Standard name | MODULE_156
Systematic name | M6864
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 156.
Full description |

Standard name | MODULE_157
Systematic name | M13779
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 157.
Full description |

Standard name | MODULE_158
Systematic name | M6330
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | DNA replication.
Full description |

Standard name | MODULE_159
Systematic name | M18480
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Translation regulation.
Full description |

Standard name | MODULE_160
Systematic name | M7381
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | tRNA synthesis.
Full description |

Standard name | MODULE_162
Systematic name | M10538
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 162.
Full description |

Standard name | MODULE_163
Systematic name | M2624
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 163.
Full description |

Standard name | MODULE_164
Systematic name | M6257
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Enzyme inhibitors (esp serine proteases).
Full description |

Standard name | MODULE_165
Systematic name | M14121
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 165.
Full description |

Standard name | MODULE_166
Systematic name | M1771
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 166.
Full description |

Standard name | MODULE_168
Systematic name | M7225
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 168.
Full description |

Standard name | MODULE_169
Systematic name | M10511
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Immune response.
Full description |

Standard name | MODULE_170
Systematic name | M2944
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Immune response.
Full description |

Standard name | MODULE_171
Systematic name | M13121
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 171.
Full description |

Standard name | MODULE_172
Systematic name | M10041
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 172.
Full description |

Standard name | MODULE_173
Systematic name | M12150
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 173.
Full description |

Standard name | MODULE_174
Systematic name | M4843
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 174.
Full description |

Standard name | MODULE_175
Systematic name | M15076
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 175.
Full description |

Standard name | MODULE_176
Systematic name | M9347
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Signaling.
Full description |

Standard name | MODULE_177
Systematic name | M4337
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 177.
Full description |

Standard name | MODULE_178
Systematic name | M17345
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 178.
Full description |

Standard name | MODULE_179
Systematic name | M753
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Blood cells and cancer expression cancer.
Full description |

Standard name | MODULE_180
Systematic name | M8449
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 180.
Full description |

Standard name | MODULE_181
Systematic name | M19241
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 181.
Full description |

Standard name | MODULE_182
Systematic name | M11300
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 182.
Full description |

Standard name | MODULE_183
Systematic name | M8084
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | RNA splicing.
Full description |

Standard name | MODULE_184
Systematic name | M2966
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 184.
Full description |

Standard name | MODULE_186
Systematic name | M9415
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 186.
Full description |

Standard name | MODULE_188
Systematic name | M15538
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 188.
Full description |

Standard name | MODULE_189
Systematic name | M4657
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 189.
Full description |

Standard name | MODULE_190
Systematic name | M17118
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | IGFBPs.
Full description |

Standard name | MODULE_191
Systematic name | M17192
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 191.
Full description |

Standard name | MODULE_192
Systematic name | M17252
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 192.
Full description |

Standard name | MODULE_194
Systematic name | M146
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 194.
Full description |

Standard name | MODULE_195
Systematic name | M12600
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Breast cancer expression clusters.
Full description |

Standard name | MODULE_196
Systematic name | M2815
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 196.
Full description |

Standard name | MODULE_197
Systematic name | M4092
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 197.
Full description |

Standard name | MODULE_198
Systematic name | M17658
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 198.
Full description |

Standard name | MODULE_199
Systematic name | M17161
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 199.
Full description |

Standard name | MODULE_200
Systematic name | M17727
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 200.
Full description |

Standard name | MODULE_201
Systematic name | M6788
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 201.
Full description |

Standard name | MODULE_202
Systematic name | M12699
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 202.
Full description |

Standard name | MODULE_203
Systematic name | M15264
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 203.
Full description |

Standard name | MODULE_204
Systematic name | M16712
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 204.
Full description |

Standard name | MODULE_205
Systematic name | M12453
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 205.
Full description |

Standard name | MODULE_206
Systematic name | M13176
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 206.
Full description |

Standard name | MODULE_207
Systematic name | M1575
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 207.
Full description |

Standard name | MODULE_208
Systematic name | M8807
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 208.
Full description |

Standard name | MODULE_209
Systematic name | M15716
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Catabolic peptidases.
Full description |

Standard name | MODULE_210
Systematic name | M13268
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 210.
Full description |

Standard name | MODULE_211
Systematic name | M15032
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 211.
Full description |

Standard name | MODULE_212
Systematic name | M2027
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Catalytic activities / metabolism.
Full description |

Standard name | MODULE_213
Systematic name | M13635
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | NCI cell lines expression clusters.
Full description |

Standard name | MODULE_214
Systematic name | M2627
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Ion channels.
Full description |

Standard name | MODULE_215
Systematic name | M3806
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Neurotransmitter (GABA) receptor.
Full description |

Standard name | MODULE_218
Systematic name | M16754
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 218.
Full description |

Standard name | MODULE_219
Systematic name | M908
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 219.
Full description |

Standard name | MODULE_220
Systematic name | M1846
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Developmental processes.
Full description |

Standard name | MODULE_221
Systematic name | M6995
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Fatty acid metabolism.
Full description |

Standard name | MODULE_222
Systematic name | M375
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 222.
Full description |

Standard name | MODULE_223
Systematic name | M1653
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Immune (defense) response.
Full description |

Standard name | MODULE_226
Systematic name | M14348
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 226.
Full description |

Standard name | MODULE_227
Systematic name | M586
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 227.
Full description |

Standard name | MODULE_229
Systematic name | M11605
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 229.
Full description |

Standard name | MODULE_233
Systematic name | M18951
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 233.
Full description |

Standard name | MODULE_234
Systematic name | M4082
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Bone remodeling.
Full description |

Standard name | MODULE_235
Systematic name | M3789
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | AA and sulfur metabolism.
Full description |

Standard name | MODULE_236
Systematic name | M14916
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 236.
Full description |

Standard name | MODULE_237
Systematic name | M5605
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 237.
Full description |

Standard name | MODULE_238
Systematic name | M7201
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 238.
Full description |

Standard name | MODULE_239
Systematic name | M12657
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 239.
Full description |

Standard name | MODULE_240
Systematic name | M5578
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 240.
Full description |

Standard name | MODULE_241
Systematic name | M7788
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 241.
Full description |

Standard name | MODULE_242
Systematic name | M15442
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 242.
Full description |

Standard name | MODULE_243
Systematic name | M9518
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 243.
Full description |

Standard name | MODULE_244
Systematic name | M949
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Response to DNA damage.
Full description |

Standard name | MODULE_245
Systematic name | M19205
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 245.
Full description |

Standard name | MODULE_247
Systematic name | M57
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Xenobiotic metabolism.
Full description |

Standard name | MODULE_248
Systematic name | M18786
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 248.
Full description |

Standard name | MODULE_249
Systematic name | M4582
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 249.
Full description |

Standard name | MODULE_252
Systematic name | M4550
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | TFs and nuclear.
Full description |

Standard name | MODULE_253
Systematic name | M8466
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Intracellular transport (MT cytoskeleton and motors).
Full description |

Standard name | MODULE_254
Systematic name | M667
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 254.
Full description |

Standard name | MODULE_255
Systematic name | M10615
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 255.
Full description |

Standard name | MODULE_256
Systematic name | M131
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 256.
Full description |

Standard name | MODULE_257
Systematic name | M6320
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 257.
Full description |

Standard name | MODULE_259
Systematic name | M13974
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | RTK signaling.
Full description |

Standard name | MODULE_261
Systematic name | M444
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 262.
Full description |

Standard name | MODULE_262
Systematic name | M4637
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Cell ion homeostasis / chemokines.
Full description |

Standard name | MODULE_263
Systematic name | M7015
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Chemotaxis (chemokines).
Full description |

Standard name | MODULE_264
Systematic name | M11287
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 264.
Full description |

Standard name | MODULE_265
Systematic name | M6286
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Caner module 265: IL receptors.
Full description |

Standard name | MODULE_267
Systematic name | M17393
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 267.
Full description |

Standard name | MODULE_272
Systematic name | M12644
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 272.
Full description |

Standard name | MODULE_273
Systematic name | M413
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Phosphate metabolism.
Full description |

Standard name | MODULE_274
Systematic name | M10420
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Vesicular transport / synapse genes.
Full description |

Standard name | MODULE_275
Systematic name | M19458
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 275.
Full description |

Standard name | MODULE_277
Systematic name | M15917
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 277.
Full description |

Standard name | MODULE_278
Systematic name | M150
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Ubiquitin ligases.
Full description |

Standard name | MODULE_279
Systematic name | M7956
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 279.
Full description |

Standard name | MODULE_280
Systematic name | M19173
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Metal ion (zinc) binding.
Full description |

Standard name | MODULE_281
Systematic name | M15268
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Phosphatase regulators.
Full description |

Standard name | MODULE_284
Systematic name | M14481
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 284.
Full description |

Standard name | MODULE_285
Systematic name | M1288
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 285.
Full description |

Standard name | MODULE_286
Systematic name | M18033
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 286
Full description |

Standard name | MODULE_287
Systematic name | M15255
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 287.
Full description |

Standard name | MODULE_288
Systematic name | M491
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 288.
Full description |

Standard name | MODULE_289
Systematic name | M12584
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 289.
Full description |

Standard name | MODULE_291
Systematic name | M19922
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | B-cell malignancies expression clusters.
Full description |

Standard name | MODULE_292
Systematic name | M19614
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 292.
Full description |

Standard name | MODULE_293
Systematic name | M19264
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 293.
Full description |

Standard name | MODULE_294
Systematic name | M13043
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 294.
Full description |

Standard name | MODULE_295
Systematic name | M14893
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 295.
Full description |

Standard name | MODULE_297
Systematic name | M4992
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 297.
Full description |

Standard name | MODULE_298
Systematic name | M13118
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Keratin.
Full description |

Standard name | MODULE_299
Systematic name | M4634
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 299.
Full description |

Standard name | MODULE_300
Systematic name | M4219
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Programmed cell death.
Full description |

Standard name | MODULE_301
Systematic name | M13275
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 301.
Full description |

Standard name | MODULE_303
Systematic name | M3615
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 303.
Full description |

Standard name | MODULE_305
Systematic name | M9927
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | CoA and fatty acid metabolism.
Full description |

Standard name | MODULE_306
Systematic name | M18792
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Glycolysis and TCA cycle.
Full description |

Standard name | MODULE_307
Systematic name | M13513
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Oxidative phosphorylation (COX and ATPases).
Full description |

Standard name | MODULE_308
Systematic name | M11526
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Pol II transcription.
Full description |

Standard name | MODULE_310
Systematic name | M3693
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | ROS metabolism.
Full description |

Standard name | MODULE_311
Systematic name | M3341
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 311.
Full description |

Standard name | MODULE_312
Systematic name | M17030
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Viral anti-apoptotic evasion mechanisms.
Full description |

Standard name | MODULE_313
Systematic name | M11826
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 313.
Full description |

Standard name | MODULE_315
Systematic name | M5597
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Spindle and kinetochore.
Full description |

Standard name | MODULE_316
Systematic name | M785
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Ion channels.
Full description |

Standard name | MODULE_317
Systematic name | M11172
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 317.
Full description |

Standard name | MODULE_318
Systematic name | M16797
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 318.
Full description |

Standard name | MODULE_320
Systematic name | M18242
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Cancer module 320: M phase.
Full description |

Standard name | MODULE_321
Systematic name | M3272
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 321.
Full description |

Standard name | MODULE_322
Systematic name | M280
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 322.
Full description |

Standard name | MODULE_323
Systematic name | M6113
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 323.
Full description |

Standard name | MODULE_324
Systematic name | M4515
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Metal / Ca ion binding.
Full description |

Standard name | MODULE_325
Systematic name | M19221
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 325.
Full description |

Standard name | MODULE_326
Systematic name | M18006
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 326.
Full description |

Standard name | MODULE_327
Systematic name | M741
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 327.
Full description |

Standard name | MODULE_328
Systematic name | M10350
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | AcetylCholine receptors.
Full description |

Standard name | MODULE_329
Systematic name | M11492
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 329.
Full description |

Standard name | MODULE_330
Systematic name | M18555
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 330.
Full description |

Standard name | MODULE_331
Systematic name | M12162
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 331.
Full description |

Standard name | MODULE_332
Systematic name | M16765
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 332.
Full description |

Standard name | MODULE_333
Systematic name | M15757
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 333.
Full description |

Standard name | MODULE_334
Systematic name | M6879
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 334.
Full description |

Standard name | MODULE_335
Systematic name | M1136
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 335.
Full description |

Standard name | MODULE_337
Systematic name | M6448
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Nucleotide metabolism.
Full description |

Standard name | MODULE_340
Systematic name | M3442
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 340.
Full description |

Standard name | MODULE_341
Systematic name | M5912
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 341.
Full description |

Standard name | MODULE_342
Systematic name | M16667
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 342.
Full description |

Standard name | MODULE_343
Systematic name | M18696
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Nitrogen metabolism.
Full description |

Standard name | MODULE_345
Systematic name | M786
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Immune response and Ag processing and presentation.
Full description |

Standard name | MODULE_346
Systematic name | M7110
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 346.
Full description |

Standard name | MODULE_349
Systematic name | M3018
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 349.
Full description |

Standard name | MODULE_350
Systematic name | M7158
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 350.
Full description |

Standard name | MODULE_352
Systematic name | M11473
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Nuclear pore complex.
Full description |

Standard name | MODULE_354
Systematic name | M9013
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | AA biosynthesis.
Full description |

Standard name | MODULE_355
Systematic name | M4563
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Protein folding.
Full description |

Standard name | MODULE_356
Systematic name | M16406
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 356.
Full description |

Standard name | MODULE_357
Systematic name | M9185
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Intermediate filaments and keratins.
Full description |

Standard name | MODULE_358
Systematic name | M2032
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | B lymphoma expression clusters.
Full description |

Standard name | MODULE_360
Systematic name | M15029
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 360.
Full description |

Standard name | MODULE_361
Systematic name | M5305
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | B lymphoma expression clusters.
Full description |

Standard name | MODULE_362
Systematic name | M7112
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Angiogenesis.
Full description |

Standard name | MODULE_363
Systematic name | M17449
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 363.
Full description |

Standard name | MODULE_366
Systematic name | M876
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Breast cancer expression clusters.
Full description |

Standard name | MODULE_367
Systematic name | M18076
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 367.
Full description |

Standard name | MODULE_368
Systematic name | M12507
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Peptide and AA transporters.
Full description |

Standard name | MODULE_371
Systematic name | M5502
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 371.
Full description |

Standard name | MODULE_372
Systematic name | M9465
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 372.
Full description |

Standard name | MODULE_373
Systematic name | M14076
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Oxidoreductases.
Full description |

Standard name | MODULE_375
Systematic name | M19754
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | GPCR signaling pathways (immune and neuro).
Full description |

Standard name | MODULE_377
Systematic name | M443
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Energy pathways and carbohydrate metabolism.
Full description |

Standard name | MODULE_378
Systematic name | M809
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 378.
Full description |

Standard name | MODULE_379
Systematic name | M12622
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 379.
Full description |

Standard name | MODULE_381
Systematic name | M12229
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 381.
Full description |

Standard name | MODULE_382
Systematic name | M17631
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Peptide hormones.
Full description |

Standard name | MODULE_385
Systematic name | M19777
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Heparin binding.
Full description |

Standard name | MODULE_387
Systematic name | M15550
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 387.
Full description |

Standard name | MODULE_388
Systematic name | M12083
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Spliceosome.
Full description |

Standard name | MODULE_389
Systematic name | M9103
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Breast cancer expression clusters.
Full description |

Standard name | MODULE_392
Systematic name | M14316
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | rRNA processing and DNA repair.
Full description |

Standard name | MODULE_395
Systematic name | M342
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 395.
Full description |

Standard name | MODULE_396
Systematic name | M15002
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 396.
Full description |

Standard name | MODULE_397
Systematic name | M15502
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 397.
Full description |

Standard name | MODULE_399
Systematic name | M3301
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 399.
Full description |

Standard name | MODULE_400
Systematic name | M15504
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 400.
Full description |

Standard name | MODULE_401
Systematic name | M17170
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 401.
Full description |

Standard name | MODULE_402
Systematic name | M5757
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 402.
Full description |

Standard name | MODULE_403
Systematic name | M5464
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | DNA damage response.
Full description |

Standard name | MODULE_404
Systematic name | M11630
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Steroid hormone receptors and binding proteins.
Full description |

Standard name | MODULE_407
Systematic name | M3595
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Growth suppressors.
Full description |

Standard name | MODULE_408
Systematic name | M14707
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 408.
Full description |

Standard name | MODULE_410
Systematic name | M13673
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Cell adhesion.
Full description |

Standard name | MODULE_411
Systematic name | M7639
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 411.
Full description |

Standard name | MODULE_412
Systematic name | M11942
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 412.
Full description |

Standard name | MODULE_414
Systematic name | M17989
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 414.
Full description |

Standard name | MODULE_415
Systematic name | M6383
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 415.
Full description |

Standard name | MODULE_416
Systematic name | M10181
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 416.
Full description |

Standard name | MODULE_417
Systematic name | M4487
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 417.
Full description |

Standard name | MODULE_418
Systematic name | M10909
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 418.
Full description |

Standard name | MODULE_419
Systematic name | M2119
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 419.
Full description |

Standard name | MODULE_421
Systematic name | M16942
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Chromatin.
Full description |

Standard name | MODULE_424
Systematic name | M6026
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 424.
Full description |

Standard name | MODULE_426
Systematic name | M2707
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 426.
Full description |

Standard name | MODULE_427
Systematic name | M16806
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 427.
Full description |

Standard name | MODULE_429
Systematic name | M18758
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 429.
Full description |

Standard name | MODULE_430
Systematic name | M7540
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 430.
Full description |

Standard name | MODULE_431
Systematic name | M5121
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Eicosanoid metabolism.
Full description |

Standard name | MODULE_432
Systematic name | M763
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 432.
Full description |

Standard name | MODULE_433
Systematic name | M7888
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Cytokines and GFs.
Full description |

Standard name | MODULE_436
Systematic name | M4595
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 436.
Full description |

Standard name | MODULE_438
Systematic name | M17509
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Intermediate filaments and MT.
Full description |

Standard name | MODULE_439
Systematic name | M7114
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 439.
Full description |

Standard name | MODULE_440
Systematic name | M14910
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Urea cycle metabolism.
Full description |

Standard name | MODULE_444
Systematic name | M575
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 444.
Full description |

Standard name | MODULE_445
Systematic name | M11007
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 445.
Full description |

Standard name | MODULE_447
Systematic name | M15631
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 447.
Full description |

Standard name | MODULE_448
Systematic name | M467
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 448.
Full description |

Standard name | MODULE_451
Systematic name | M10327
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 451.
Full description |

Standard name | MODULE_453
Systematic name | M11422
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 453.
Full description |

Standard name | MODULE_454
Systematic name | M7787
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 454.
Full description |

Standard name | MODULE_455
Systematic name | M16117
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 455.
Full description |

Standard name | MODULE_456
Systematic name | M18856
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | B lymphoma expression clusters.
Full description |

Standard name | MODULE_457
Systematic name | M4320
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 457.
Full description |

Standard name | MODULE_458
Systematic name | M59
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 458.
Full description |

Standard name | MODULE_459
Systematic name | M4403
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 459.
Full description |

Standard name | MODULE_462
Systematic name | M6532
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Eicosanoid metabolism (and related carboxylic acid biosynthesis).
Full description |

Standard name | MODULE_464
Systematic name | M14482
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Oxidoreductases.
Full description |

Standard name | MODULE_465
Systematic name | M8711
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 465.
Full description |

Standard name | MODULE_470
Systematic name | M19085
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 470.
Full description |

Standard name | MODULE_471
Systematic name | M15191
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 471.
Full description |

Standard name | MODULE_474
Systematic name | M4172
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 474.
Full description |

Standard name | MODULE_478
Systematic name | M1119
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 478.
Full description |

Standard name | MODULE_480
Systematic name | M13238
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Breast cancer expression clusters.
Full description |

Standard name | MODULE_481
Systematic name | M2653
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 481.
Full description |

Standard name | MODULE_484
Systematic name | M4544
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 484.
Full description |

Standard name | MODULE_485
Systematic name | M7862
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 485.
Full description |

Standard name | MODULE_486
Systematic name | M3505
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 486.
Full description |

Standard name | MODULE_488
Systematic name | M19433
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Growth inhibitory genes.
Full description |

Standard name | MODULE_489
Systematic name | M8555
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 489.
Full description |

Standard name | MODULE_491
Systematic name | M15916
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 491.
Full description |

Standard name | MODULE_492
Systematic name | M1212
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 492.
Full description |

Standard name | MODULE_493
Systematic name | M11162
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 493.
Full description |

Standard name | MODULE_495
Systematic name | M19250
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 495.
Full description |

Standard name | MODULE_497
Systematic name | M14302
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | CNS development.
Full description |

Standard name | MODULE_500
Systematic name | M7693
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 500.
Full description |

Standard name | MODULE_501
Systematic name | M9805
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 501.
Full description |

Standard name | MODULE_503
Systematic name | M11728
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 503.
Full description |

Standard name | MODULE_505
Systematic name | M2738
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Steroid hormone and heme metabolism.
Full description |

Standard name | MODULE_509
Systematic name | M7391
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 509.
Full description |

Standard name | MODULE_511
Systematic name | M11160
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 511.
Full description |

Standard name | MODULE_512
Systematic name | M5499
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Muscle genes.
Full description |

Standard name | MODULE_514
Systematic name | M19454
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 514.
Full description |

Standard name | MODULE_516
Systematic name | M10264
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 516.
Full description |

Standard name | MODULE_519
Systematic name | M8613
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Oxidoreductases.
Full description |

Standard name | MODULE_521
Systematic name | M18720
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | T-cell proliferation genes.
Full description |

Standard name | MODULE_522
Systematic name | M10866
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Immune response genes.
Full description |

Standard name | MODULE_524
Systematic name | M14260
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Actin cytoskeleton binding.
Full description |

Standard name | MODULE_525
Systematic name | M2320
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 525.
Full description |

Standard name | MODULE_528
Systematic name | M11380
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 528.
Full description |

Standard name | MODULE_530
Systematic name | M5428
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | ROS (glutathione, ox stress).
Full description |

Standard name | MODULE_532
Systematic name | M3090
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Blood cells and cancer expression clusters.
Full description |

Standard name | MODULE_533
Systematic name | M1901
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 533.
Full description |

Standard name | MODULE_534
Systematic name | M17809
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 534.
Full description |

Standard name | MODULE_537
Systematic name | M18949
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Anti-apoptosis.
Full description |

Standard name | MODULE_539
Systematic name | M17504
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 539.
Full description |

Standard name | MODULE_540
Systematic name | M15748
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Iron ion homeostasis.
Full description |

Standard name | MODULE_543
Systematic name | M9280
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Annexin, MHCII, and lectins.
Full description |

Standard name | MODULE_544
Systematic name | M14630
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 544.
Full description |

Standard name | MODULE_545
Systematic name | M10747
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | IL-1 signaling.
Full description |

Standard name | MODULE_547
Systematic name | M3349
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 547.
Full description |

Standard name | MODULE_552
Systematic name | M8168
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Chromatin and nucleosomes.
Full description |

Standard name | MODULE_557
Systematic name | M8387
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 557.
Full description |

Standard name | MODULE_560
Systematic name | M4265
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 560.
Full description |

Standard name | MODULE_562
Systematic name | M19072
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | MMPs.
Full description |

Standard name | MODULE_563
Systematic name | M10977
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 563.
Full description |

Standard name | MODULE_567
Systematic name | M5090
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 567.
Full description |

Standard name | MODULE_568
Systematic name | M1566
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 568.
Full description |

Standard name | MODULE_571
Systematic name | M10542
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 571.
Full description |

Standard name | MODULE_573
Systematic name | M17027
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Cell cycle regulators and carbohydrate transporters.
Full description |

Standard name | MODULE_575
Systematic name | M9202
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Complement and cAMP signaling.
Full description |

Standard name | MODULE_576
Systematic name | M4064
Organism | Homo sapiens
PMID |
Authors |
Category | C4
Sub-category | CM
Brief description | Genes in the cancer module 576.
Full description |

Standard name | GLI1_UP.V1_DN
Systematic name | M2622
Organism | Rattus norvegicus
PMID | 11719506
Authors | Yoon JW,Kita Y,Frank DJ,Majewski RR,Konicek BA,Nobrega MA,Jacob H,Walterhouse D,Iannaccone P
Category | C6
Sub-category |
Brief description | Genes down-regulated in RK3E cells (kidney epithelium) over-expressing GLI1 [Gene ID=2735].
Full description | The zinc finger transcription factor GLI1, which mediates Sonic hedgehog signaling during development, is expressed in several human cancers, including basal cell carcinoma, medulloblastoma, and sarcomas. We identified 147 genes whose levels of expression were significantly altered in RNA obtained from cells demonstrating a transformed phenotype with stable GLI1 expression or stable Ha-ras expression. Comparison of expression profiles from GLI1- and Ha-ras-expressing cells established a set of genes unique to GLI1-induced cell transformation. Thirty genes were altered by stable GLI1 expression, and 124 genes were changed by stable Ha-ras expression. Seven genes had altered expression levels in both GLI1- and Ha-ras-expressing cells. Genes whose expression was altered by GLI1 included cell cycle genes, cell adhesion genes, signal transduction genes, and genes regulating apoptosis. GLI1 consensus DNA-binding sequences were identified in the 5' regions of cyclin D2, IGFBP-6, osteopontin, and plakoglobin, suggesting that these genes represent immediate downstream targets. Gel shift analysis confirmed the ability of the GLI1 protein to bind these sequences. Up-regulation of cyclin D2 and down-regulation of plakoglobin were demonstrated in GLI1-amplified compared with non-amplified human rhabdomyosarcoma cells. Many of the GLI1 targets with known function identified in this study increase cell proliferation, indicating that GLI1-induced cell transformation occurs through multiple downstream pathways.

Standard name | GLI1_UP.V1_UP
Systematic name | M2628
Organism | Rattus norvegicus
PMID | 11719506
Authors | Yoon JW,Kita Y,Frank DJ,Majewski RR,Konicek BA,Nobrega MA,Jacob H,Walterhouse D,Iannaccone P
Category | C6
Sub-category |
Brief description | Genes up-regulated in RK3E cells (kidney epithelium) over-expressing GLI1 [Gene ID=2735].
Full description | The zinc finger transcription factor GLI1, which mediates Sonic hedgehog signaling during development, is expressed in several human cancers, including basal cell carcinoma, medulloblastoma, and sarcomas. We identified 147 genes whose levels of expression were significantly altered in RNA obtained from cells demonstrating a transformed phenotype with stable GLI1 expression or stable Ha-ras expression. Comparison of expression profiles from GLI1- and Ha-ras-expressing cells established a set of genes unique to GLI1-induced cell transformation. Thirty genes were altered by stable GLI1 expression, and 124 genes were changed by stable Ha-ras expression. Seven genes had altered expression levels in both GLI1- and Ha-ras-expressing cells. Genes whose expression was altered by GLI1 included cell cycle genes, cell adhesion genes, signal transduction genes, and genes regulating apoptosis. GLI1 consensus DNA-binding sequences were identified in the 5' regions of cyclin D2, IGFBP-6, osteopontin, and plakoglobin, suggesting that these genes represent immediate downstream targets. Gel shift analysis confirmed the ability of the GLI1 protein to bind these sequences. Up-regulation of cyclin D2 and down-regulation of plakoglobin were demonstrated in GLI1-amplified compared with non-amplified human rhabdomyosarcoma cells. Many of the GLI1 targets with known function identified in this study increase cell proliferation, indicating that GLI1-induced cell transformation occurs through multiple downstream pathways.

Standard name | E2F1_UP.V1_DN
Systematic name | M2630
Organism | Mus musculus
PMID | 11888208
Authors | Ma Y,Croxton R,Moorer RL Jr,Cress WD
Category | C6
Sub-category |
Brief description | Genes down-regulated in mouse fibroblasts over-expressing E2F1 [Gene ID=1869] gene.
Full description | Identification of E2F1-regulated genes that modulate the transition from quiescence into DNA synthesis, or have roles in apoptosis, signal transduction, membrane biology, and transcription repression.

Standard name | E2F1_UP.V1_UP
Systematic name | M2632
Organism | Mus musculus
PMID | 11888208
Authors | Ma Y,Croxton R,Moorer RL Jr,Cress WD
Category | C6
Sub-category |
Brief description | Genes up-regulated in mouse fibroblasts over-expressing E2F1 [Gene ID=1869] gene.
Full description | Identification of E2F1-regulated genes that modulate the transition from quiescence into DNA synthesis, or have roles in apoptosis, signal transduction, membrane biology, and transcription repression.

Standard name | EGFR_UP.V1_DN
Systematic name | M2633
Organism | Homo sapiens
PMID | 16585219
Authors | Ma Y,Croxton R,Moorer RL Jr,Cress WD
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) positive for ESR1 [Gene ID=2099] and engineered to express ligand-activatable EGFR [Gene ID=1956].
Full description | Profiling of MCF-7 cell lines stably overexpressing ligand-activatable EGFR as models of overexpressed growth factor signaling, as well as control vector transfected cells (coMCF-7) and control vector transfected cells long-term adapted for estrogen-independent growth (coMCF-7/lt-E2).

Standard name | EGFR_UP.V1_UP
Systematic name | M2634
Organism | Homo sapiens
PMID | 16585219
Authors | Ma Y,Croxton R,Moorer RL Jr,Cress WD
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) positive for ESR1 [Gene ID=2099] and engineered to express ligand-activatable EGFR [Gene ID=1956].
Full description | Profiling of MCF-7 cell lines stably overexpressing ligand-activatable EGFR as models of overexpressed growth factor signaling, as well as control vector transfected cells (coMCF-7) and control vector transfected cells long-term adapted for estrogen-independent growth (coMCF-7/lt-E2).

Standard name | ERBB2_UP.V1_DN
Systematic name | M2635
Organism | Homo sapiens
PMID | 16585219
Authors | Ma Y,Croxton R,Moorer RL Jr,Cress WD
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) positive for ESR1 [Gene ID=2099] and engineered to express ligand-activatable ERBB2 [Gene ID=2064].
Full description | Profiling of MCF-7 cell lines stably overexpressing constitutively active c-erbB-2 as well as control vector transfected cells (coMCF-7) and control vector transfected cells long-term adapted for estrogen-independent growth (coMCF-7/lt-E2).

Standard name | ERBB2_UP.V1_UP
Systematic name | M2636
Organism | Homo sapiens
PMID | 16585219
Authors | Ma Y,Croxton R,Moorer RL Jr,Cress WD
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) positive for ESR1 [Gene ID=2099] and engineered to express ligand-activatable ERBB2 [Gene ID=2064].
Full description | Profiling of MCF-7 cell lines stably overexpressing constitutively active c-erbB-2 as well as control vector transfected cells (coMCF-7) and control vector transfected cells long-term adapted for estrogen-independent growth (coMCF-7/lt-E2).

Standard name | GCNP_SHH_UP_EARLY.V1_DN
Systematic name | M2638
Organism | Mus musculus
PMID | 11960025
Authors | Zhao Q,Kho A,Kenney AM,Yuk Di DI,Kohane I,Rowitch DH
Category | C6
Sub-category |
Brief description | Genes down-regulated in granule cell neuron precursors (GCNPs) after stimulation with Shh for 3h.
Full description | Hedgehog pathway activation is required for proliferation of cerebellar granule cell neuron precursors during development and is etiologic in certain cerebellar tumors. To identify genes expressed specifically in granule cell neuron precursors, we used oligonucleotide microarrays to analyze regulation of 13,179 genes/expressed sequence tags in heterogeneous primary cultures of neonatal mouse cerebellum that respond to the mitogen Sonic hedgehog. In conjunction, we applied experiment-specific noise models to render a gene-by-gene robust indication of up-regulation in Sonic hedgehog-treated cultures. Twelve genes so identified were tested, and 10 (83%) showed appropriate expression in the external granular layer (EGL) of the postnatal day (PN) 7 cerebellum and down-regulation by PN 15, as verified by in situ hybridization. Whole-organ profiling of the developing cerebellum was carried out from PN 1 to 30 to generate a database of temporal gene regulation profiles (TRPs). From the database an algorithm was developed to capture the TRP typical of EGL-specific genes. The "TRP-EGL" accurately predicted expression in vivo of an additional 18 genes/expressed sequence tags with a sensitivity of 80% and a specificity of 88%. We then compared the positive predictive value of our analytical procedure with other widely used methods, as verified by the TRP-EGL in silico. These findings suggest that replicate experiments and incorporation of noise models increase analytical specificity. They further show that genome-wide methods are an effective means to identify stage-specific gene expression in the developing granule cell lineage.

Standard name | GCNP_SHH_UP_EARLY.V1_UP
Systematic name | M2639
Organism | Mus musculus
PMID | 11960025
Authors | Zhao Q,Kho A,Kenney AM,Yuk Di DI,Kohane I,Rowitch DH
Category | C6
Sub-category |
Brief description | Genes up-regulated in granule cell neuron precursors (GCNPs) after stimulation with Shh for 3h.
Full description | Hedgehog pathway activation is required for proliferation of cerebellar granule cell neuron precursors during development and is etiologic in certain cerebellar tumors. To identify genes expressed specifically in granule cell neuron precursors, we used oligonucleotide microarrays to analyze regulation of 13,179 genes/expressed sequence tags in heterogeneous primary cultures of neonatal mouse cerebellum that respond to the mitogen Sonic hedgehog. In conjunction, we applied experiment-specific noise models to render a gene-by-gene robust indication of up-regulation in Sonic hedgehog-treated cultures. Twelve genes so identified were tested, and 10 (83%) showed appropriate expression in the external granular layer (EGL) of the postnatal day (PN) 7 cerebellum and down-regulation by PN 15, as verified by in situ hybridization. Whole-organ profiling of the developing cerebellum was carried out from PN 1 to 30 to generate a database of temporal gene regulation profiles (TRPs). From the database an algorithm was developed to capture the TRP typical of EGL-specific genes. The "TRP-EGL" accurately predicted expression in vivo of an additional 18 genes/expressed sequence tags with a sensitivity of 80% and a specificity of 88%. We then compared the positive predictive value of our analytical procedure with other widely used methods, as verified by the TRP-EGL in silico. These findings suggest that replicate experiments and incorporation of noise models increase analytical specificity. They further show that genome-wide methods are an effective means to identify stage-specific gene expression in the developing granule cell lineage.

Standard name | GCNP_SHH_UP_LATE.V1_DN
Systematic name | M2640
Organism | Mus musculus
PMID | 11960025
Authors | Zhao Q,Kho A,Kenney AM,Yuk Di DI,Kohane I,Rowitch DH
Category | C6
Sub-category |
Brief description | Genes down-regulated in granule cell neuron precursors (GCNPs) after stimulation with Shh for 24h.
Full description | Hedgehog pathway activation is required for proliferation of cerebellar granule cell neuron precursors during development and is etiologic in certain cerebellar tumors. To identify genes expressed specifically in granule cell neuron precursors, we used oligonucleotide microarrays to analyze regulation of 13,179 genes/expressed sequence tags in heterogeneous primary cultures of neonatal mouse cerebellum that respond to the mitogen Sonic hedgehog. In conjunction, we applied experiment-specific noise models to render a gene-by-gene robust indication of up-regulation in Sonic hedgehog-treated cultures. Twelve genes so identified were tested, and 10 (83%) showed appropriate expression in the external granular layer (EGL) of the postnatal day (PN) 7 cerebellum and down-regulation by PN 15, as verified by in situ hybridization. Whole-organ profiling of the developing cerebellum was carried out from PN 1 to 30 to generate a database of temporal gene regulation profiles (TRPs). From the database an algorithm was developed to capture the TRP typical of EGL-specific genes. The "TRP-EGL" accurately predicted expression in vivo of an additional 18 genes/expressed sequence tags with a sensitivity of 80% and a specificity of 88%. We then compared the positive predictive value of our analytical procedure with other widely used methods, as verified by the TRP-EGL in silico. These findings suggest that replicate experiments and incorporation of noise models increase analytical specificity. They further show that genome-wide methods are an effective means to identify stage-specific gene expression in the developing granule cell lineage.

Standard name | GCNP_SHH_UP_LATE.V1_UP
Systematic name | M2641
Organism | Mus musculus
PMID | 11960025
Authors | Zhao Q,Kho A,Kenney AM,Yuk Di DI,Kohane I,Rowitch DH
Category | C6
Sub-category |
Brief description | Genes up-regulated in granule cell neuron precursors (GCNPs) after stimulation with Shh for 24h.
Full description | Hedgehog pathway activation is required for proliferation of cerebellar granule cell neuron precursors during development and is etiologic in certain cerebellar tumors. To identify genes expressed specifically in granule cell neuron precursors, we used oligonucleotide microarrays to analyze regulation of 13,179 genes/expressed sequence tags in heterogeneous primary cultures of neonatal mouse cerebellum that respond to the mitogen Sonic hedgehog. In conjunction, we applied experiment-specific noise models to render a gene-by-gene robust indication of up-regulation in Sonic hedgehog-treated cultures. Twelve genes so identified were tested, and 10 (83%) showed appropriate expression in the external granular layer (EGL) of the postnatal day (PN) 7 cerebellum and down-regulation by PN 15, as verified by in situ hybridization. Whole-organ profiling of the developing cerebellum was carried out from PN 1 to 30 to generate a database of temporal gene regulation profiles (TRPs). From the database an algorithm was developed to capture the TRP typical of EGL-specific genes. The "TRP-EGL" accurately predicted expression in vivo of an additional 18 genes/expressed sequence tags with a sensitivity of 80% and a specificity of 88%. We then compared the positive predictive value of our analytical procedure with other widely used methods, as verified by the TRP-EGL in silico. These findings suggest that replicate experiments and incorporation of noise models increase analytical specificity. They further show that genome-wide methods are an effective means to identify stage-specific gene expression in the developing granule cell lineage.

Standard name | RAPA_EARLY_UP.V1_DN
Systematic name | M2643
Organism | Homo sapiens
PMID | 12101249
Authors | Peng T,Golub TR,Sabatini DM
Category | C6
Sub-category |
Brief description | Genes down-regulated in BJAB (lymphoma) cells by rapamycin (sirolimus) [PubChem = 6610346].
Full description | RAFT1/FRAP/mTOR is a key regulator of cell growth and division and the mammalian target of rapamycin, an immunosuppressive and anticancer drug. Rapamycin deprivation and nutrient deprivation have similar effects on the activity of S6 kinase 1 (S6K1) and 4E-BP1, two downstream effectors of RAFT1, but the relationship between nutrient- and rapamycin-sensitive pathways is unknown. Using transcriptional profiling, we show that, in human BJAB B-lymphoma cells and murine CTLL-2 T lymphocytes, rapamycin treatment affects the expression of many genes involved in nutrient and protein metabolism. The rapamycin-induced transcriptional profile is distinct from those induced by glucose, glutamine, or leucine deprivation but is most similar to that induced by amino acid deprivation. In particular, rapamycin treatment and amino acid deprivation up-regulate genes involved in nutrient catabolism and energy production and down-regulate genes participating in lipid and nucleotide synthesis and in protein synthesis, turnover, and folding. Surprisingly, however, rapamycin had effects opposite from those of amino acid starvation on the expression of a large group of genes involved in the synthesis, transport, and use of amino acids. Supported by measurements of nutrient use, the data suggest that RAFT1 is an energy and nutrient sensor and that rapamycin mimics a signal generated by the starvation of amino acids but that the signal is unlikely to be the absence of amino acids themselves. These observations underscore the importance of metabolism in controlling lymphocyte proliferation and offer a novel explanation for immunosuppression by rapamycin.

Standard name | RAPA_EARLY_UP.V1_UP
Systematic name | M2644
Organism | Homo sapiens
PMID | 12101249
Authors | Peng T,Golub TR,Sabatini DM
Category | C6
Sub-category |
Brief description | Genes up-regulated in BJAB (lymphoma) cells by rapamycin (sirolimus) [PubChem = 6610346].
Full description | RAFT1/FRAP/mTOR is a key regulator of cell growth and division and the mammalian target of rapamycin, an immunosuppressive and anticancer drug. Rapamycin deprivation and nutrient deprivation have similar effects on the activity of S6 kinase 1 (S6K1) and 4E-BP1, two downstream effectors of RAFT1, but the relationship between nutrient- and rapamycin-sensitive pathways is unknown. Using transcriptional profiling, we show that, in human BJAB B-lymphoma cells and murine CTLL-2 T lymphocytes, rapamycin treatment affects the expression of many genes involved in nutrient and protein metabolism. The rapamycin-induced transcriptional profile is distinct from those induced by glucose, glutamine, or leucine deprivation but is most similar to that induced by amino acid deprivation. In particular, rapamycin treatment and amino acid deprivation up-regulate genes involved in nutrient catabolism and energy production and down-regulate genes participating in lipid and nucleotide synthesis and in protein synthesis, turnover, and folding. Surprisingly, however, rapamycin had effects opposite from those of amino acid starvation on the expression of a large group of genes involved in the synthesis, transport, and use of amino acids. Supported by measurements of nutrient use, the data suggest that RAFT1 is an energy and nutrient sensor and that rapamycin mimics a signal generated by the starvation of amino acids but that the signal is unlikely to be the absence of amino acids themselves. These observations underscore the importance of metabolism in controlling lymphocyte proliferation and offer a novel explanation for immunosuppression by rapamycin.

Standard name | HINATA_NFKB_IMMU_INF
Systematic name | M2645
Organism | Homo sapiens
PMID | 12673201
Authors | Hinata K,Gervin AM,Jennifer Zhang Y,Khavari PA
Category | C6
Sub-category |
Brief description | Immune or inflammatory genes induced by NF-kappaB in primary keratinocytes and fibroblasts.
Full description | NF-kappa B regulates normal and pathological processes, including neoplasia, in a tissue-context-dependent manner. In skin, NF-kappa B is implicated in epidermal homeostasis as well as in the pathogenesis of squamous cell carcinoma; however, its function in the underlying mesenchymal dermis has been unclear. To gain insight into NF-kappa B roles in these two adjacent cutaneous tissue compartments, NF-kappa B effects on expression of 12 435 genes were determined in epidermal keratinocytes and dermal fibroblasts. Although NF-kappa B induced proinflammatory and antiapoptotic genes in both settings, it exhibited divergent effects on growth regulatory genes. In keratinocytes, but not in fibroblasts, NF-kappa B induced p21(CIP1), which was sufficient to inhibit growth of both cell types. Levels of growth inhibitory factor (GIF), in contrast, were increased by NF-kappa B in both settings but inhibited growth only in keratinocytes. These findings indicate that transcription factors such as NF-kappa B can program tissue-selective effects via both differential target gene induction as well as by inducing common targets that exert differing effects depending on cellular lineage.

Standard name | HINATA_NFKB_MATRIX
Systematic name | M2646
Organism | Homo sapiens
PMID | 12673201
Authors | Hinata K,Gervin AM,Jennifer Zhang Y,Khavari PA
Category | C6
Sub-category |
Brief description | Matrix, adhesion or cytoskeleton genes induced by NF-kappaB in primary keratinocytes and fibroblasts.
Full description | NF-kappa B regulates normal and pathological processes, including neoplasia, in a tissue-context-dependent manner. In skin, NF-kappa B is implicated in epidermal homeostasis as well as in the pathogenesis of squamous cell carcinoma; however, its function in the underlying mesenchymal dermis has been unclear. To gain insight into NF-kappa B roles in these two adjacent cutaneous tissue compartments, NF-kappa B effects on expression of 12 435 genes were determined in epidermal keratinocytes and dermal fibroblasts. Although NF-kappa B induced proinflammatory and antiapoptotic genes in both settings, it exhibited divergent effects on growth regulatory genes. In keratinocytes, but not in fibroblasts, NF-kappa B induced p21(CIP1), which was sufficient to inhibit growth of both cell types. Levels of growth inhibitory factor (GIF), in contrast, were increased by NF-kappa B in both settings but inhibited growth only in keratinocytes. These findings indicate that transcription factors such as NF-kappa B can program tissue-selective effects via both differential target gene induction as well as by inducing common targets that exert differing effects depending on cellular lineage.

Standard name | CYCLIN_D1_KE_.V1_DN
Systematic name | M2647
Organism | Homo sapiens
PMID | 12914697
Authors | Lamb J,Ramaswamy S,Ford HL,Contreras B,Martinez RV,Kittrell FS,Zahnow CA,Patterson N,Golub TR,Ewen ME
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) over-expressing a mutant K112E form of CCND1 [Gene ID=595] gene.
Full description | Here we describe how patterns of gene expression in human tumors have been deconvoluted to reveal a mechanism of action for the cyclin D1 oncogene. Computational analysis of the expression patterns of thousands of genes across hundreds of tumor specimens suggested that a transcription factor, C/EBPbeta/Nf-Il6, participates in the consequences of cyclin D1 overexpression. Functional analyses confirmed the involvement of C/EBPbeta in the regulation of genes affected by cyclin D1 and established this protein as an indispensable effector of a potentially important facet of cyclin D1 biology. This work demonstrates that tumor gene expression databases can be used to study the function of a human oncogene in situ.

Standard name | CYCLIN_D1_KE_.V1_UP
Systematic name | M2648
Organism | Homo sapiens
PMID | 12914697
Authors | Lamb J,Ramaswamy S,Ford HL,Contreras B,Martinez RV,Kittrell FS,Zahnow CA,Patterson N,Golub TR,Ewen ME
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) over-expressing a mutant K112E form of CCND1 [Gene ID=595] gene.
Full description | Here we describe how patterns of gene expression in human tumors have been deconvoluted to reveal a mechanism of action for the cyclin D1 oncogene. Computational analysis of the expression patterns of thousands of genes across hundreds of tumor specimens suggested that a transcription factor, C/EBPbeta/Nf-Il6, participates in the consequences of cyclin D1 overexpression. Functional analyses confirmed the involvement of C/EBPbeta in the regulation of genes affected by cyclin D1 and established this protein as an indispensable effector of a potentially important facet of cyclin D1 biology. This work demonstrates that tumor gene expression databases can be used to study the function of a human oncogene in situ.

Standard name | CYCLIN_D1_UP.V1_DN
Systematic name | M2652
Organism | Homo sapiens
PMID | 12914697
Authors | Lamb J,Ramaswamy S,Ford HL,Contreras B,Martinez RV,Kittrell FS,Zahnow CA,Patterson N,Golub TR,Ewen ME
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) over-expressing CCND1 [Gene ID=595] gene.
Full description | Here we describe how patterns of gene expression in human tumors have been deconvoluted to reveal a mechanism of action for the cyclin D1 oncogene. Computational analysis of the expression patterns of thousands of genes across hundreds of tumor specimens suggested that a transcription factor, C/EBPbeta/Nf-Il6, participates in the consequences of cyclin D1 overexpression. Functional analyses confirmed the involvement of C/EBPbeta in the regulation of genes affected by cyclin D1 and established this protein as an indispensable effector of a potentially important facet of cyclin D1 biology. This work demonstrates that tumor gene expression databases can be used to study the function of a human oncogene in situ.

Standard name | CYCLIN_D1_UP.V1_UP
Systematic name | M2654
Organism | Homo sapiens
PMID | 12914697
Authors | Lamb J,Ramaswamy S,Ford HL,Contreras B,Martinez RV,Kittrell FS,Zahnow CA,Patterson N,Golub TR,Ewen ME
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) over-expressing CCND1 [Gene ID=595] gene.
Full description | Here we describe how patterns of gene expression in human tumors have been deconvoluted to reveal a mechanism of action for the cyclin D1 oncogene. Computational analysis of the expression patterns of thousands of genes across hundreds of tumor specimens suggested that a transcription factor, C/EBPbeta/Nf-Il6, participates in the consequences of cyclin D1 overexpression. Functional analyses confirmed the involvement of C/EBPbeta in the regulation of genes affected by cyclin D1 and established this protein as an indispensable effector of a potentially important facet of cyclin D1 biology. This work demonstrates that tumor gene expression databases can be used to study the function of a human oncogene in situ.

Standard name | CSR_EARLY_UP.V1_DN
Systematic name | M2655
Organism | Homo sapiens
PMID | 14737219
Authors | Chang HY,Sneddon JB,Alizadeh AA,Sood R,West RB,Montgomery K,Chi JT,van de Rijn M,Botstein D,Brown PO
Category | C6
Sub-category |
Brief description | Genes down-regulated in early serum response of CRL 2091 cells (foreskin fibroblasts).
Full description | Foreskin fibroblasts CRL 2091 (ATCC) were serum starved for 48 hours, and harvested at the indicated time points after switching to media with 10% FBS essentially as described (Iyer et al., 1999). RNA from all of the sampled time points were pooled as reference RNA to compare with RNA from individual time points as described (Iyer et al., 1999)

Standard name | CSR_EARLY_UP.V1_UP
Systematic name | M2656
Organism | Homo sapiens
PMID | 14737219
Authors | Chang HY,Sneddon JB,Alizadeh AA,Sood R,West RB,Montgomery K,Chi JT,van de Rijn M,Botstein D,Brown PO
Category | C6
Sub-category |
Brief description | Genes up-regulated in early serum response of CRL 2091 cells (foreskin fibroblasts).
Full description | Foreskin fibroblasts CRL 2091 (ATCC) were serum starved for 48 hours, and harvested at the indicated time points after switching to media with 10% FBS essentially as described (Iyer et al., 1999). RNA from all of the sampled time points were pooled as reference RNA to compare with RNA from individual time points as described (Iyer et al., 1999)

Standard name | CSR_LATE_UP.V1_DN
Systematic name | M2659
Organism | Homo sapiens
PMID | 14737219
Authors | Chang HY,Sneddon JB,Alizadeh AA,Sood R,West RB,Montgomery K,Chi JT,van de Rijn M,Botstein D,Brown PO
Category | C6
Sub-category |
Brief description | Genes down-regulated in late serum response of CRL 2091 cells (foreskin fibroblasts).
Full description | Foreskin fibroblasts CRL 2091 (ATCC) were serum starved for 48 hours, and harvested at the indicated time points after switching to media with 10% FBS essentially as described (Iyer et al., 1999). RNA from all of the sampled time points were pooled as reference RNA to compare with RNA from individual time points as described (Iyer et al., 1999)

Standard name | CSR_LATE_UP.V1_UP
Systematic name | M2660
Organism | Homo sapiens
PMID | 14737219
Authors | Chang HY,Sneddon JB,Alizadeh AA,Sood R,West RB,Montgomery K,Chi JT,van de Rijn M,Botstein D,Brown PO
Category | C6
Sub-category |
Brief description | Genes up-regulated in late serum response of CRL 2091 cells (foreskin fibroblasts).
Full description | Foreskin fibroblasts CRL 2091 (ATCC) were serum starved for 48 hours, and harvested at the indicated time points after switching to media with 10% FBS essentially as described (Iyer et al., 1999). RNA from all of the sampled time points were pooled as reference RNA to compare with RNA from individual time points as described (Iyer et al., 1999)

Standard name | AKT_UP_MTOR_DN.V1_DN
Systematic name | M2664
Organism | Mus musculus
PMID | 15156201
Authors | Majumder PK,Febbo PG,Bickoff R,Berger R,Xue Q,McMahon LM,Manola J,McDonnell TJ,Loda M,Lane HA,Sellers WR
Category | C6
Sub-category |
Brief description | Genes down-regulated by everolimus [PubChem = 6442177] in mouse prostate tissue transgenically expressing human AKT1 gene [Gene ID=207] vs untreated controls.
Full description | Transgenic (Probasin driven Myr-AKT) or wild-type littermates were treated with RAD001 or placebo and sacrificed at 12 and 48 hours following the beginning of treatment

Standard name | AKT_UP_MTOR_DN.V1_UP
Systematic name | M2665
Organism | Mus musculus
PMID | 15156201
Authors | Majumder PK,Febbo PG,Bickoff R,Berger R,Xue Q,McMahon LM,Manola J,McDonnell TJ,Loda M,Lane HA,Sellers WR
Category | C6
Sub-category |
Brief description | Genes up-regulated by everolimus [PubChem = 6442177] in mouse prostate tissue transgenically expressing human AKT1 gene [Gene ID=207] vs untreated controls.
Full description | Transgenic (Probasin driven Myr-AKT) or wild-type littermates were treated with RAD001 or placebo and sacrificed at 12 and 48 hours following the beginning of treatment

Standard name | AKT_UP.V1_DN
Systematic name | M2666
Organism | Mus musculus
PMID | 15156201
Authors | Majumder PK,Febbo PG,Bickoff R,Berger R,Xue Q,McMahon LM,Manola J,McDonnell TJ,Loda M,Lane HA,Sellers WR
Category | C6
Sub-category |
Brief description | Genes down-regulated in mouse prostate by transgenic expression of human AKT1 gene [Gene ID=207] vs controls.
Full description | Transgenic (Probasin driven Myr-AKT) or wild-type littermates were treated with RAD001 or placebo and sacrificed at 12 and 48 h following the beginning of treatment.

Standard name | AKT_UP.V1_UP
Systematic name | M2669
Organism | Mus musculus
PMID | 15156201
Authors | Majumder PK,Febbo PG,Bickoff R,Berger R,Xue Q,McMahon LM,Manola J,McDonnell TJ,Loda M,Lane HA,Sellers WR
Category | C6
Sub-category |
Brief description | Genes up-regulated in mouse prostate by transgenic expression of human AKT1 gene [Gene ID=207] vs controls.
Full description | Transgenic (Probasin driven Myr-AKT) or wild-type littermates were treated with RAD001 or placebo and sacrificed at 12 and 48 h following the beginning of treatment.

Standard name | MTOR_UP.V1_DN
Systematic name | M2670
Organism | Mus musculus
PMID | 15156201
Authors | Majumder PK,Febbo PG,Bickoff R,Berger R,Xue Q,McMahon LM,Manola J,McDonnell TJ,Loda M,Lane HA,Sellers WR
Category | C6
Sub-category |
Brief description | Genes down-regulated by everolimus [PubChem = 6442177] in prostate tissue.
Full description | Wild-type littermates were treated with RAD001 or placebo and sacrificed at 12 and 48 h following the beginning of treatment.

Standard name | MTOR_UP.V1_UP
Systematic name | M2672
Organism | Mus musculus
PMID | 15156201
Authors | Majumder PK,Febbo PG,Bickoff R,Berger R,Xue Q,McMahon LM,Manola J,McDonnell TJ,Loda M,Lane HA,Sellers WR
Category | C6
Sub-category |
Brief description | Genes up-regulated by everolimus [PubChem = 6442177] in prostate tissue.
Full description | Wild-type littermates were treated with RAD001 or placebo and sacrificed at 12 and 48 h following the beginning of treatment.

Standard name | PIGF_UP.V1_DN
Systematic name | M2673
Organism | Homo sapiens
PMID | 15516835
Authors | Schoenfeld J,Lessan K,Johnson NA,Charnock-Jones DS,Evans A,Vourvouhaki E,Scott L,Stephens R,Freeman TC,Saidi SA,Tom B,Weston GC,Rogers P,Smith SK,Print CG
Category | C6
Sub-category |
Brief description | Genes down-regulated in HUVEC cells (endothelium) by treatment with PIGF [Gene ID=5281].
Full description | HUVECs (human umbilical cord vein endothelial cells) are treated with the angiogenic factor PlGF (placental growth factor) in low or high serum media.

Standard name | PIGF_UP.V1_UP
Systematic name | M2674
Organism | Homo sapiens
PMID | 15516835
Authors | Schoenfeld J,Lessan K,Johnson NA,Charnock-Jones DS,Evans A,Vourvouhaki E,Scott L,Stephens R,Freeman TC,Saidi SA,Tom B,Weston GC,Rogers P,Smith SK,Print CG
Category | C6
Sub-category |
Brief description | Genes up-regulated in HUVEC cells (endothelium) by treatment with PIGF [Gene ID=5281].
Full description | HUVECs (human umbilical cord vein endothelial cells) are treated with the angiogenic factor PlGF (placental growth factor) in low or high serum media.

Standard name | VEGF_A_UP.V1_DN
Systematic name | M2675
Organism | Homo sapiens
PMID | 15516835
Authors | Schoenfeld J,Lessan K,Johnson NA,Charnock-Jones DS,Evans A,Vourvouhaki E,Scott L,Stephens R,Freeman TC,Saidi SA,Tom B,Weston GC,Rogers P,Smith SK,Print CG
Category | C6
Sub-category |
Brief description | Genes down-regulated in HUVEC cells (endothelium) by treatment with VEGFA [Gene ID=7422].
Full description | HUVECs (human umbilical cord vein endothelial cells) are treated with the angiogenic factor VEGF-A in low or high serum media.

Standard name | VEGF_A_UP.V1_UP
Systematic name | M2676
Organism | Homo sapiens
PMID | 15516835
Authors | Schoenfeld J,Lessan K,Johnson NA,Charnock-Jones DS,Evans A,Vourvouhaki E,Scott L,Stephens R,Freeman TC,Saidi SA,Tom B,Weston GC,Rogers P,Smith SK,Print CG
Category | C6
Sub-category |
Brief description | Genes up-regulated in HUVEC cells (endothelium) by treatment with VEGFA [Gene ID=7422].
Full description | HUVECs (human umbilical cord vein endothelial cells) are treated with the angiogenic factor VEGF-A in low or high serum media.

Standard name | BCAT_GDS748_DN
Systematic name | M2677
Organism | Homo sapiens
PMID | 15592430
Authors | Chamorro MN,Schwartz DR,Vonica A,Brivanlou AH,Cho KR,Varmus HE
Category | C6
Sub-category |
Brief description | Genes down-regulated in HEK293 cells (kidney fibroblasts) expressing constitutively active form of CTNNB1 [Gene ID=1499] gene.
Full description | 293 cells, infected with RCAS-beta-cateninS37A or RCAS-GFP

Standard name | BCAT_GDS748_UP
Systematic name | M2678
Organism | Homo sapiens
PMID | 15592430
Authors | Chamorro MN,Schwartz DR,Vonica A,Brivanlou AH,Cho KR,Varmus HE
Category | C6
Sub-category |
Brief description | Genes up-regulated in HEK293 cells (kidney fibroblasts) expressing constitutively active form of CTNNB1 [Gene ID=1499] gene.
Full description | 293 cells, infected with RCAS-beta-cateninS37A or RCAS-GFP

Standard name | BCAT.100_UP.V1_DN
Systematic name | M2679
Organism | Homo sapiens
PMID | 15592430
Authors | Chamorro MN,Schwartz DR,Vonica A,Brivanlou AH,Cho KR,Varmus HE
Category | C6
Sub-category |
Brief description | Genes down-regulated in HEK293 cells (kidney fibroblasts) expressing constitutively active form of CTNNB1 [Gene ID=1499] gene.
Full description | 293 cells, infected with RCAS-beta-cateninS37A or RCAS-GFP

Standard name | BCAT.100_UP.V1_UP
Systematic name | M2680
Organism | Homo sapiens
PMID | 15592430
Authors | Chamorro MN,Schwartz DR,Vonica A,Brivanlou AH,Cho KR,Varmus HE
Category | C6
Sub-category |
Brief description | Genes up-regulated in HEK293 cells (kidney fibroblasts) expressing constitutively active form of CTNNB1 [Gene ID=1499] gene.
Full description | 293 cells, infected with RCAS-beta-cateninS37A or RCAS-GFP

Standard name | ATF2_S_UP.V1_DN
Systematic name | M2681
Organism | Homo sapiens
PMID | 15691874
Authors | Bailey J,Tyson-Capper AJ,Gilmore K,Robson SC,Europe-Finner GN
Category | C6
Sub-category |
Brief description | Genes down-regulated in myometrial cells over-expressing a shortened splice form of ATF2 [Gene ID=1386] gene.
Full description | Human myometrial cells taken from biopsies of pre-menopausal non-cancerous non-pregnant uteri were cultured in complete MEM D-valine medium plus 10% FCS, and stably-transfected with the pcDNA3.1/V5-His TOPO vector (Invitrogen) harbouring ATF2-small gene or a control empty-vector.

Standard name | ATF2_S_UP.V1_UP
Systematic name | M2682
Organism | Homo sapiens
PMID | 15691874
Authors | Bailey J,Tyson-Capper AJ,Gilmore K,Robson SC,Europe-Finner GN
Category | C6
Sub-category |
Brief description | Genes up-regulated in myometrial cells over-expressing a shortened splice form of ATF2 [Gene ID=1386] gene.
Full description | Human myometrial cells taken from biopsies of pre-menopausal non-cancerous non-pregnant uteri were cultured in complete MEM D-valine medium plus 10% FCS, and stably-transfected with the pcDNA3.1/V5-His TOPO vector (Invitrogen) harbouring ATF2-small gene or a control empty-vector.

Standard name | ATF2_UP.V1_DN
Systematic name | M2684
Organism | Homo sapiens
PMID | 15691874
Authors | Bailey J,Tyson-Capper AJ,Gilmore K,Robson SC,Europe-Finner GN
Category | C6
Sub-category |
Brief description | Genes down-regulated in myometrial cells over-expressing ATF2 [Gene ID=1386] gene.
Full description | Human myometrial cells taken from biopsies of pre-menopausal non-cancerous non-pregnant uteri were cultured in complete MEM D-valine medium plus 10% FCS, and stably-transfected with the pcDNA3.1/V5-His TOPO vector (Invitrogen) harbouring ATF2 gene or a control empty-vector.

Standard name | ATF2_UP.V1_UP
Systematic name | M2686
Organism | Homo sapiens
PMID | 15691874
Authors | Bailey J,Tyson-Capper AJ,Gilmore K,Robson SC,Europe-Finner GN
Category | C6
Sub-category |
Brief description | Genes up-regulated in myometrial cells over-expressing ATF2 [Gene ID=1386] gene.
Full description | Human myometrial cells taken from biopsies of pre-menopausal non-cancerous non-pregnant uteri were cultured in complete MEM D-valine medium plus 10% FCS, and stably-transfected with the pcDNA3.1/V5-His TOPO vector (Invitrogen) harbouring ATF2 gene or a control empty-vector.

Standard name | WNT_UP.V1_DN
Systematic name | M2689
Organism | Mus musculus
PMID | 15794748
Authors | Ziegler S,Roehrs S,Tickenbrock L,Moeroey T,Klein-Hitpass L,Vetter IR,Mueller O
Category | C6
Sub-category |
Brief description | Genes down-regulated in C57MG cells (mammary epithelium) by over-expression of WNT1 [Gene ID=7471] gene.
Full description | Targets of Wnt-1 in C57MG. RNA from murine mammary C57MG cells transfected with an empty control vector (PLNCx) or an expression vector encoding Wnt-1 was isolated and analyzed on Affymetrix MG-U74Av2 arrays.

Standard name | WNT_UP.V1_UP
Systematic name | M2690
Organism | Mus musculus
PMID | 15794748
Authors | Ziegler S,Roehrs S,Tickenbrock L,Moeroey T,Klein-Hitpass L,Vetter IR,Mueller O
Category | C6
Sub-category |
Brief description | Genes up-regulated in C57MG cells (mammary epithelium) by over-expression of WNT1 [Gene ID=7471] gene.
Full description | Targets of Wnt-1 in C57MG. RNA from murine mammary C57MG cells transfected with an empty control vector (PLNCx) or an expression vector encoding Wnt-1 was isolated and analyzed on Affymetrix MG-U74Av2 arrays.

Standard name | ATM_DN.V1_DN
Systematic name | M2691
Organism | Homo sapiens
PMID | 15892871
Authors | Elkon R,Rashi-Elkeles S,Lerenthal Y,Linhart C,Tenne T,Amariglio N,Rechavi G,Shamir R,Shiloh Y
Category | C6
Sub-category |
Brief description | Genes down-regulated in HEK293 cells (kidney fibroblasts) upon knockdown of ATM [Gene ID=472] gene by RNAi.
Full description | Expression profiling of cells knocked-down for ATM and control un-infected cells and cells infected with siRNA against LacZ.

Standard name | ATM_DN.V1_UP
Systematic name | M2692
Organism | Homo sapiens
PMID | 15892871
Authors | Elkon R,Rashi-Elkeles S,Lerenthal Y,Linhart C,Tenne T,Amariglio N,Rechavi G,Shamir R,Shiloh Y
Category | C6
Sub-category |
Brief description | Genes up-regulated in HEK293 cells (kidney fibroblasts) upon knockdown of ATM [Gene ID=472] gene by RNAi.
Full description | Expression profiling of cells knocked-down for ATM and control un-infected cells and cells infected with siRNA against LacZ.

Standard name | P53_DN.V2_DN
Systematic name | M2693
Organism | Homo sapiens
PMID | 15892871
Authors | Elkon R,Rashi-Elkeles S,Lerenthal Y,Linhart C,Tenne T,Amariglio N,Rechavi G,Shamir R,Shiloh Y
Category | C6
Sub-category |
Brief description | Genes down-regulated in HEK293 cells (kidney fibroblasts) upon knockdown of TP53 [Gene ID=7157] gene by RNAi.
Full description | Expression profiling of cells knocked-down for p53 and control un-infected cells and cells infected with siRNA against LacZ.

Standard name | P53_DN.V2_UP
Systematic name | M2694
Organism | Homo sapiens
PMID | 15892871
Authors | Elkon R,Rashi-Elkeles S,Lerenthal Y,Linhart C,Tenne T,Amariglio N,Rechavi G,Shamir R,Shiloh Y
Category | C6
Sub-category |
Brief description | Genes up-regulated in HEK293 cells (kidney fibroblasts) upon knockdown of TP53 [Gene ID=7157] gene by RNAi.
Full description | Expression profiling of cells knocked-down for p53 and control un-infected cells and cells infected with siRNA against LacZ.

Standard name | RELA_DN.V1_DN
Systematic name | M2695
Organism | Homo sapiens
PMID | 15892871
Authors | Elkon R,Rashi-Elkeles S,Lerenthal Y,Linhart C,Tenne T,Amariglio N,Rechavi G,Shamir R,Shiloh Y
Category | C6
Sub-category |
Brief description | Genes down-regulated in HEK293 cells (kidney fibroblasts) upon knockdown of RELA [Gene ID=5970] gene by RNAi.
Full description | Expression profiling of cells knocked-down for RelA and control un-infected cells and cells infected with siRNA against LacZ.

Standard name | RELA_DN.V1_UP
Systematic name | M2696
Organism | Homo sapiens
PMID | 15892871
Authors | Elkon R,Rashi-Elkeles S,Lerenthal Y,Linhart C,Tenne T,Amariglio N,Rechavi G,Shamir R,Shiloh Y
Category | C6
Sub-category |
Brief description | Genes up-regulated in HEK293 cells (kidney fibroblasts) upon knockdown of RELA [Gene ID=5970] gene by RNAi.
Full description | Expression profiling of cells knocked-down for RelA and control un-infected cells and cells infected with siRNA against LacZ.

Standard name | P53_DN.V1_DN
Systematic name | M2697
Organism | Homo sapiens
PMID | 16199517
Authors | Subramanian A,Tamayo P,Mootha VK,Mukherjee S,Ebert BL,Gillette MA,Paulovich A,Pomeroy SL,Golub TR,Lander ES,Mesirov JP
Category | C6
Sub-category |
Brief description | Genes down-regulated in NCI-60 panel of cell lines with mutated TP53 [Gene ID=7157].
Full description | We examined gene expression patterns from the NCI-60 collection of cancer cell lines. We sought to use these data to identify targets of the transcription factor p53, which regulates gene expression in response to various signals of cellular stress. The mutational status of the p53 gene has been reported for 50 of the NCI-60 cell lines, with 17 being classified as normal and 33 as carrying mutations in the gene.

Standard name | P53_DN.V1_UP
Systematic name | M2698
Organism | Homo sapiens
PMID | 16199517
Authors | Subramanian A,Tamayo P,Mootha VK,Mukherjee S,Ebert BL,Gillette MA,Paulovich A,Pomeroy SL,Golub TR,Lander ES,Mesirov JP
Category | C6
Sub-category |
Brief description | Genes up-regulated in NCI-60 panel of cell lines with mutated TP53 [Gene ID=7157].
Full description | We examined gene expression patterns from the NCI-60 collection of cancer cell lines. We sought to use these data to identify targets of the transcription factor p53, which regulates gene expression in response to various signals of cellular stress. The mutational status of the p53 gene has been reported for 50 of the NCI-60 cell lines, with 17 being classified as normal and 33 as carrying mutations in the gene.

Standard name | BCAT_BILD_ET_AL_DN
Systematic name | M2702
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C6
Sub-category |
Brief description | Genes down-regulated in primary epithelial breast cancer cell culture over-expressing activated CTNNB1 [Gene ID=1499] gene.
Full description | RNA was extracted from human mammary epithelial cells expressing oncogenes (or GFP control) for gene array analysis. Experiment was performed in replicate.

Standard name | BCAT_BILD_ET_AL_UP
Systematic name | M2703
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C6
Sub-category |
Brief description | Genes up-regulated in primary epithelial breast cancer cell culture over-expressing activated CTNNB1 [Gene ID=1499] gene.
Full description | RNA was extracted from human mammary epithelial cells expressing oncogenes (or GFP control) for gene array analysis. Experiment was performed in replicate.

Standard name | E2F3_UP.V1_DN
Systematic name | M2704
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C6
Sub-category |
Brief description | Genes down-regulated in primary epithelial breast cancer cell culture over-expressing E2F3 [Gene ID=1871] gene.
Full description | RNA was extracted from human mammary epithelial cells expressing oncogenes (or GFP control) for gene array analysis. Experiment was performed in replicate.

Standard name | E2F3_UP.V1_UP
Systematic name | M2706
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C6
Sub-category |
Brief description | Genes up-regulated in primary epithelial breast cancer cell culture over-expressing E2F3 [Gene ID=1871] gene.
Full description | RNA was extracted from human mammary epithelial cells expressing oncogenes (or GFP control) for gene array analysis. Experiment was performed in replicate.

Standard name | MYC_UP.V1_DN
Systematic name | M2708
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C6
Sub-category |
Brief description | Genes down-regulated in primary epithelial breast cancer cell culture over-expressing MYC [Gene ID=4609] gene.
Full description | RNA was extracted from human mammary epithelial cells expressing oncogenes (or GFP control) for gene array analysis. Experiment was performed in replicate.

Standard name | MYC_UP.V1_UP
Systematic name | M2711
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C6
Sub-category |
Brief description | Genes up-regulated in primary epithelial breast cancer cell culture over-expressing MYC [Gene ID=4609] gene.
Full description | RNA was extracted from human mammary epithelial cells expressing oncogenes (or GFP control) for gene array analysis. Experiment was performed in replicate.

Standard name | SRC_UP.V1_DN
Systematic name | M2713
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C6
Sub-category |
Brief description | Genes down-regulated in primary epithelial breast cancer cell culture over-expressing SRC [Gene ID=6714] gene.
Full description | RNA was extracted from human mammary epithelial cells expressing oncogenes (or GFP control) for gene array analysis. Experiment was performed in replicate.

Standard name | SRC_UP.V1_UP
Systematic name | M2714
Organism | Homo sapiens
PMID | 16273092
Authors | Bild AH,Yao G,Chang JT,Wang Q,Potti A,Chasse D,Joshi MB,Harpole D,Lancaster JM,Berchuck A,Olson JA Jr,Marks JR,Dressman HK,West M,Nevins JR
Category | C6
Sub-category |
Brief description | Genes up-regulated in primary epithelial breast cancer cell culture over-expressing SRC [Gene ID=6714] gene.
Full description | RNA was extracted from human mammary epithelial cells expressing oncogenes (or GFP control) for gene array analysis. Experiment was performed in replicate.

Standard name | SNF5_DN.V1_DN
Systematic name | M2715
Organism | Mus musculus
PMID | 16301525
Authors | Isakoff MS,Sansam CG,Tamayo P,Subramanian A,Evans JA,Fillmore CM,Wang X,Biegel JA,Pomeroy SL,Mesirov JP,Roberts CW
Category | C6
Sub-category |
Brief description | Genes down-regulated in MEF cells (embryonic fibroblasts) with knockout of SNF5 [Gene ID=6598] gene.
Full description | Snf5 (Ini1/Baf47/Smarcb1), a core member of the Swi/Snf chromatin remodeling complex, is a potent tumor suppressor whose mechanism of action is largely unknown. Biallelic loss of Snf5 leads to the onset of aggressive cancers in both humans and mice. We have developed an innovative and widely applicable analytical technique for cross-species validation of cancer models and show that the gene expression profiles of our Snf5 murine models closely resemble those of human Snf5-deficient rhabdoid tumors. We exploit this system to produce what we believe to be the first report documenting the effects on gene expression of inactivating a Swi/Snf subunit in normal mammalian cells and to identify the transcriptional pathways regulated by Snf5. We demonstrate that the tumor suppressor activity of Snf5 depends on its regulation of cell cycle progression; Snf5 inactivation leads to aberrant up-regulation of E2F targets and increased levels of p53 that are accompanied by apoptosis, polyploidy, and growth arrest. Further, conditional mouse models demonstrate that inactivation of p16Ink4a or Rb (retinoblastoma) does not accelerate tumor formation in Snf5 conditional mice, whereas mutation of p53 leads to a dramatic acceleration of tumor formation.

Standard name | SNF5_DN.V1_UP
Systematic name | M2718
Organism | Mus musculus
PMID | 16301525
Authors | Isakoff MS,Sansam CG,Tamayo P,Subramanian A,Evans JA,Fillmore CM,Wang X,Biegel JA,Pomeroy SL,Mesirov JP,Roberts CW
Category | C6
Sub-category |
Brief description | Genes up-regulated in MEF cells (embryonic fibroblasts) with knockout of SNF5 [Gene ID=6598] gene.
Full description | Snf5 (Ini1/Baf47/Smarcb1), a core member of the Swi/Snf chromatin remodeling complex, is a potent tumor suppressor whose mechanism of action is largely unknown. Biallelic loss of Snf5 leads to the onset of aggressive cancers in both humans and mice. We have developed an innovative and widely applicable analytical technique for cross-species validation of cancer models and show that the gene expression profiles of our Snf5 murine models closely resemble those of human Snf5-deficient rhabdoid tumors. We exploit this system to produce what we believe to be the first report documenting the effects on gene expression of inactivating a Swi/Snf subunit in normal mammalian cells and to identify the transcriptional pathways regulated by Snf5. We demonstrate that the tumor suppressor activity of Snf5 depends on its regulation of cell cycle progression; Snf5 inactivation leads to aberrant up-regulation of E2F targets and increased levels of p53 that are accompanied by apoptosis, polyploidy, and growth arrest. Further, conditional mouse models demonstrate that inactivation of p16Ink4a or Rb (retinoblastoma) does not accelerate tumor formation in Snf5 conditional mice, whereas mutation of p53 leads to a dramatic acceleration of tumor formation.

Standard name | CAMP_UP.V1_DN
Systematic name | M2719
Organism | Homo sapiens
PMID | 16381821
Authors | van Staveren WC,Solis DW,Delys L,Venet D,Cappello M,Andry G,Dumont JE,Libert F,Detours V,Maenhaut C
Category | C6
Sub-category |
Brief description | Genes down-regulated in primary thyrocyte cultures in response to cAMP signaling pathway activation by thyrotropin (TSH).
Full description |

Standard name | CAMP_UP.V1_UP
Systematic name | M2720
Organism | Homo sapiens
PMID | 16381821
Authors | van Staveren WC,Solis DW,Delys L,Venet D,Cappello M,Andry G,Dumont JE,Libert F,Detours V,Maenhaut C
Category | C6
Sub-category |
Brief description | Genes up-regulated in primary thyrocyte cultures in response to cAMP signaling pathway activation by thyrotropin (TSH).
Full description |

Standard name | LTE2_UP.V1_DN
Systematic name | M2721
Organism | Homo sapiens
PMID | 16585219
Authors | Creighton CJ,Hilger AM,Murthy S,Rae JM,Chinnaiyan AM,El-Ashry D
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) positive for ESR1 [Gene ID=2099] MCF-7 cells (breast cancer) and long-term adapted for estrogen-independent growth.
Full description | Profiling of control vector transfected cells (coMCF-7) and control vector transfected cells long-term adapted for estrogen-independent growth (coMCF-7/lt-E2).

Standard name | LTE2_UP.V1_UP
Systematic name | M2723
Organism | Homo sapiens
PMID | 16585219
Authors | Creighton CJ,Hilger AM,Murthy S,Rae JM,Chinnaiyan AM,El-Ashry D
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) positive for ESR1 [Gene ID=2099] MCF-7 cells (breast cancer) and long-term adapted for estrogen-independent growth.
Full description | Profiling of control vector transfected cells (coMCF-7) and control vector transfected cells long-term adapted for estrogen-independent growth (coMCF-7/lt-E2).

Standard name | MEK_UP.V1_DN
Systematic name | M2724
Organism | Homo sapiens
PMID | 16585219
Authors | Creighton CJ,Hilger AM,Murthy S,Rae JM,Chinnaiyan AM,El-Ashry D
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) positive for ESR1 [Gene ID=2099] MCF-7 cells (breast cancer) stably over-expressing constitutively active MAP2K1 [Gene ID=5604] gene.
Full description | Profiling of MCF-7 cell lines stably overexpressing constitutively active MEK as a model of overexpressed growth factor signaling, as well as control vector transfected cells (coMCF-7).

Standard name | MEK_UP.V1_UP
Systematic name | M2725
Organism | Homo sapiens
PMID | 16585219
Authors | Creighton CJ,Hilger AM,Murthy S,Rae JM,Chinnaiyan AM,El-Ashry D
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) positive for ESR1 [Gene ID=2099] MCF-7 cells (breast cancer) stably over-expressing constitutively active MAP2K1 [Gene ID=5604] gene.
Full description | Profiling of MCF-7 cell lines stably overexpressing constitutively active MEK as a model of overexpressed growth factor signaling, as well as control vector transfected cells (coMCF-7).

Standard name | RAF_UP.V1_DN
Systematic name | M2726
Organism | Homo sapiens
PMID | 16585219
Authors | Creighton CJ,Hilger AM,Murthy S,Rae JM,Chinnaiyan AM,El-Ashry D
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF-7 cells (breast cancer) positive for ESR1 [Gene ID=2099] MCF-7 cells (breast cancer) stably over-expressing constitutively active RAF1 [Gene ID=5894] gene.
Full description | Profiling of MCF-7 cell lines stably overexpressing constitutively active Raf-1 as a model of overexpressed growth factor signaling, as well as control vector transfected cells (coMCF-7).

Standard name | RAF_UP.V1_UP
Systematic name | M2728
Organism | Homo sapiens
PMID | 16585219
Authors | Creighton CJ,Hilger AM,Murthy S,Rae JM,Chinnaiyan AM,El-Ashry D
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF-7 cells (breast cancer) positive for ESR1 [Gene ID=2099] MCF-7 cells (breast cancer) stably over-expressing constitutively active RAF1 [Gene ID=5894] gene.
Full description | Profiling of MCF-7 cell lines stably overexpressing constitutively active Raf-1 as a model of overexpressed growth factor signaling, as well as control vector transfected cells (coMCF-7).

Standard name | PRC1_BMI_UP.V1_DN
Systematic name | M2730
Organism | Homo sapiens
PMID | 16618801
Authors | Bracken AP,Dietrich N,Pasini D,Hansen KH,Helin K
Category | C6
Sub-category |
Brief description | Genes down-regulated in TIG3 cells (fibroblasts) upon knockdown of BMI1 [Gene ID=648] gene.
Full description | The identification of gene expression changes in human embryonic fibroblast cells depleted of BMI-1.

Standard name | PRC1_BMI_UP.V1_UP
Systematic name | M2732
Organism | Homo sapiens
PMID | 16618801
Authors | Bracken AP,Dietrich N,Pasini D,Hansen KH,Helin K
Category | C6
Sub-category |
Brief description | Genes up-regulated in TIG3 cells (fibroblasts) upon knockdown of BMI1 [Gene ID=648] gene.
Full description | The identification of gene expression changes in human embryonic fibroblast cells depleted of BMI-1.

Standard name | PRC2_EED_UP.V1_DN
Systematic name | M2734
Organism | Homo sapiens
PMID | 16618801
Authors | Bracken AP,Dietrich N,Pasini D,Hansen KH,Helin K
Category | C6
Sub-category |
Brief description | Genes down-regulated in TIG3 cells (fibroblasts) upon knockdown of EED [Gene ID=8726] gene.
Full description | The identification of gene expression changes in human embryonic fibroblast cells depleted of EED.

Standard name | PRC2_EED_UP.V1_UP
Systematic name | M2736
Organism | Homo sapiens
PMID | 16618801
Authors | Bracken AP,Dietrich N,Pasini D,Hansen KH,Helin K
Category | C6
Sub-category |
Brief description | Genes up-regulated in TIG3 cells (fibroblasts) upon knockdown of EED [Gene ID=8726] gene.
Full description | The identification of gene expression changes in human embryonic fibroblast cells depleted of EED.

Standard name | PRC2_EZH2_UP.V1_DN
Systematic name | M2737
Organism | Homo sapiens
PMID | 16618801
Authors | Bracken AP,Dietrich N,Pasini D,Hansen KH,Helin K
Category | C6
Sub-category |
Brief description | Genes down-regulated in TIG3 cells (fibroblasts) upon knockdown of EZH2 [Gene ID=2146] gene.
Full description | The identification of gene expression changes in human embryonic fibroblast cells depleted of EZH2.

Standard name | PRC2_EZH2_UP.V1_UP
Systematic name | M2739
Organism | Homo sapiens
PMID | 16618801
Authors | Bracken AP,Dietrich N,Pasini D,Hansen KH,Helin K
Category | C6
Sub-category |
Brief description | Genes up-regulated in TIG3 cells (fibroblasts) upon knockdown of EZH2 [Gene ID=2146] gene.
Full description | The identification of gene expression changes in human embryonic fibroblast cells depleted of EZH2.

Standard name | PRC2_SUZ12_UP.V1_DN
Systematic name | M2740
Organism | Homo sapiens
PMID | 16618801
Authors | Bracken AP,Dietrich N,Pasini D,Hansen KH,Helin K
Category | C6
Sub-category |
Brief description | Genes down-regulated in TIG3 cells (fibroblasts) upon knockdown of SUZ12 [Gene ID=23512] gene.
Full description | The identification of gene expression changes in human embryonic fibroblast cells depleted of SUZ12.

Standard name | PRC2_SUZ12_UP.V1_UP
Systematic name | M2741
Organism | Homo sapiens
PMID | 16618801
Authors | Bracken AP,Dietrich N,Pasini D,Hansen KH,Helin K
Category | C6
Sub-category |
Brief description | Genes up-regulated in TIG3 cells (fibroblasts) upon knockdown of SUZ12 [Gene ID=23512] gene.
Full description | The identification of gene expression changes in human embryonic fibroblast cells depleted of SUZ12.

Standard name | JNK_DN.V1_DN
Systematic name | M2745
Organism | Homo sapiens
PMID | 16648634
Authors | Gazel A,Banno T,Walsh R,Blumenberg M
Category | C6
Sub-category |
Brief description | Genes down-regulated in JNK inhibitor-treated (SP600125[PubChem=8515]) keratinocytes.
Full description | Keratinocytes are grown to ~75% confluence and either treated with 5nM SP600125, or left untreated. Samples are harvested 1, 4, 24 and 48 h post-treatment.

Standard name | JNK_DN.V1_UP
Systematic name | M2746
Organism | Homo sapiens
PMID | 16648634
Authors | Gazel A,Banno T,Walsh R,Blumenberg M
Category | C6
Sub-category |
Brief description | Genes up-regulated in JNK inhibitor-treated (SP600125[PubChem=8515]) keratinocytes.
Full description | Keratinocytes are grown to ~75% confluence and either treated with 5nM SP600125, or left untreated. Samples are harvested 1, 4, 24 and 48 h post-treatment.

Standard name | BRCA1_DN.V1_DN
Systematic name | M2747
Organism | Homo sapiens
PMID | 16843262
Authors | Furuta S,Wang JM,Wei S,Jeng YM,Jiang X,Gu B,Chen PL,Lee EY,Lee WH
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF10A cells (breast cancer) upon knockdown of BRCA1 [Gene ID=672] gene by RNAi.
Full description | MCF10A cells in 3-D culture for 15 h after treatment with BRCA1-RNAi vs Luc-RNAi adenovirus

Standard name | BRCA1_DN.V1_UP
Systematic name | M2748
Organism | Homo sapiens
PMID | 16843262
Authors | Furuta S,Wang JM,Wei S,Jeng YM,Jiang X,Gu B,Chen PL,Lee EY,Lee WH
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF10A cells (breast cancer) upon knockdown of BRCA1 [Gene ID=672] gene by RNAi.
Full description | MCF10A cells in 3-D culture for 15 h after treatment with BRCA1-RNAi vs Luc-RNAi adenovirus

Standard name | CTIP_DN.V1_DN
Systematic name | M2751
Organism | Homo sapiens
PMID | 16843262
Authors | Furuta S,Wang JM,Wei S,Jeng YM,Jiang X,Gu B,Chen PL,Lee EY,Lee WH
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF10A cells (breast cancer) upon knockdown of RBBP8 [Gene ID=RBBP8] gene by RNAi.
Full description | MCF10A cells in 3-D culture for 15 h after treatment with CtIP-RNAi vs Luc-RNAi adenovirus.

Standard name | CTIP_DN.V1_UP
Systematic name | M2752
Organism | Homo sapiens
PMID | 16843262
Authors | Furuta S,Wang JM,Wei S,Jeng YM,Jiang X,Gu B,Chen PL,Lee EY,Lee WH
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF10A cells (breast cancer) upon knockdown of RBBP8 [Gene ID=RBBP8] gene by RNAi.
Full description | MCF10A cells in 3-D culture for 15 h after treatment with CtIP-RNAi vs Luc-RNAi adenovirus.

Standard name | PKCA_DN.V1_DN
Systematic name | M2754
Organism | Mus musculus
PMID | 16849539
Authors | Oster H,Leitges M
Category | C6
Sub-category |
Brief description | Genes down-regulated in small intenstine in PRKCA [Gene ID=5578] knockout mice.
Full description | PKCa -/- vs wt small intestine

Standard name | PKCA_DN.V1_UP
Systematic name | M2755
Organism | Mus musculus
PMID | 16849539
Authors | Oster H,Leitges M
Category | C6
Sub-category |
Brief description | Genes up-regulated in small intenstine in PRKCA [Gene ID=5578] knockout mice.
Full description | PKCa -/- vs wt small intestine

Standard name | MTOR_UP.N4.V1_DN
Systematic name | M2756
Organism | Homo sapiens
PMID | 17010674
Authors | Wei G,Twomey D,Lamb J,Schlis K,Agarwal J,Stam RW,Opferman JT,Sallan SE,den Boer ML,Pieters R,Golub TR,Armstrong SA
Category | C6
Sub-category |
Brief description | Genes down-regulated in CEM-C1 cells (T-CLL) in comparison of control vs rapamycin (sirolimus) [PubChem=6610346], an mTOR pathway inhibitor.
Full description | CEM-C1 cells were treated with 10 nM rapamycin or DMSO and harvested for microarray analysis at 24 hours

Standard name | MTOR_UP.N4.V1_UP
Systematic name | M2757
Organism | Homo sapiens
PMID | 17010674
Authors | Wei G,Twomey D,Lamb J,Schlis K,Agarwal J,Stam RW,Opferman JT,Sallan SE,den Boer ML,Pieters R,Golub TR,Armstrong SA
Category | C6
Sub-category |
Brief description | Genes up-regulated in CEM-C1 cells (T-CLL) in comparison of control vs rapamycin (sirolimus) [PubChem=6610346], an mTOR pathway inhibitor.
Full description | CEM-C1 cells were treated with 10 nM rapamycin or DMSO and harvested for microarray analysis at 24 hours

Standard name | PTEN_DN.V2_DN
Systematic name | M2758
Organism | Homo sapiens
PMID | 17060456
Authors | Kim JS,Lee C,Bonifant CL,Ressom H,Waldman T
Category | C6
Sub-category |
Brief description | Genes down-regulated in HCT116 cells (colon carcinoma) upon knockdown of PTEN [Gene ID=5728] by RNAi.
Full description | Two HCT116 PTEN+/+ cell lines (parental cells and a clone with random integration of the targeting vector) and three independently-derived HCT116 PTEN-/- cell lines were studied

Standard name | PTEN_DN.V2_UP
Systematic name | M2759
Organism | Homo sapiens
PMID | 17060456
Authors | Kim JS,Lee C,Bonifant CL,Ressom H,Waldman T
Category | C6
Sub-category |
Brief description | Genes up-regulated in HCT116 cells (colon carcinoma) upon knockdown of PTEN [Gene ID=5728] by RNAi.
Full description | Two HCT116 PTEN+/+ cell lines (parental cells and a clone with random integration of the targeting vector) and three independently-derived HCT116 PTEN-/- cell lines were studied

Standard name | DCA_UP.V1_DN
Systematic name | M2760
Organism | Homo sapiens
PMID | 17222789
Authors | Bonnet S,Archer SL,Allalunis-Turner J,Haromy A,Beaulieu C,Thompson R,Lee CT,Lopaschuk GD,Puttagunta L,Bonnet S,Harry G,Hashimoto K,Porter CJ,Andrade MA,Thebaud B,Michelakis ED
Category | C6
Sub-category |
Brief description | Genes down-regulated in A549 lung carcinoma and M059K glioblastoma cells treated with dichloroacetate [PubChem=6597].
Full description | Analysis of A549 lung carcinoma and M059K glioblastoma cells treated with dichloroacetate (DCA), an inhibitor of the mitochondrial pyruvate dehydrogenase kinase. DCA shifts metabolism from glycolysis to glucose oxidation and decreases mitochondrial membrane potential in cancer cells.

Standard name | DCA_UP.V1_UP
Systematic name | M2762
Organism | Homo sapiens
PMID | 17222789
Authors | Bonnet S,Archer SL,Allalunis-Turner J,Haromy A,Beaulieu C,Thompson R,Lee CT,Lopaschuk GD,Puttagunta L,Bonnet S,Harry G,Hashimoto K,Porter CJ,Andrade MA,Thebaud B,Michelakis ED
Category | C6
Sub-category |
Brief description | Genes up-regulated in A549 lung carcinoma and M059K glioblastoma cells treated with dichloroacetate [PubChem=6597].
Full description | Analysis of A549 lung carcinoma and M059K glioblastoma cells treated with dichloroacetate (DCA), an inhibitor of the mitochondrial pyruvate dehydrogenase kinase. DCA shifts metabolism from glycolysis to glucose oxidation and decreases mitochondrial membrane potential in cancer cells.

Standard name | ESC_J1_UP_EARLY.V1_DN
Systematic name | M2763
Organism | Mus musculus
PMID | 17394647
Authors | Hailesellasse Sene K,Porter CJ,Palidwor G,Perez-Iratxeta C,Muro EM,Campbell PA,Rudnicki MA,Andrade-Navarro MA
Category | C6
Sub-category |
Brief description | Genes down-regulated during early stages of differentiation of embryoid bodies from J1 embryonic stem cells.
Full description | An 11-point time course study on differentiating embryoid bodies from a murine J1 embryonic stem cell line. The time course includes 0 hr, 6 hr, 12 hr, 18 hr, 24 hr, 36 hr, 48 hr, 4 days, 7 days, 9 days and 14 days.

Standard name | ESC_J1_UP_EARLY.V1_UP
Systematic name | M2764
Organism | Mus musculus
PMID | 17394647
Authors | Hailesellasse Sene K,Porter CJ,Palidwor G,Perez-Iratxeta C,Muro EM,Campbell PA,Rudnicki MA,Andrade-Navarro MA
Category | C6
Sub-category |
Brief description | Genes up-regulated during early stages of differentiation of embryoid bodies from J1 embryonic stem cells.
Full description | An 11-point time course study on differentiating embryoid bodies from a murine J1 embryonic stem cell line. The time course includes 0 hr, 6 hr, 12 hr, 18 hr, 24 hr, 36 hr, 48 hr, 4 days, 7 days, 9 days and 14 days.

Standard name | ESC_J1_UP_LATE.V1_DN
Systematic name | M2765
Organism | Mus musculus
PMID | 17394647
Authors | Hailesellasse Sene K,Porter CJ,Palidwor G,Perez-Iratxeta C,Muro EM,Campbell PA,Rudnicki MA,Andrade-Navarro MA
Category | C6
Sub-category |
Brief description | Genes down-regulated during late stages of differentiation of embryoid bodies from J1 embryonic stem cells.
Full description | An 11-point time course study on differentiating embryoid bodies from a murine J1 embryonic stem cell line. The time course includes 0 hr, 6 hr, 12 hr, 18 hr, 24 hr, 36 hr, 48 hr, 4 days, 7 days, 9 days and 14 days.

Standard name | ESC_J1_UP_LATE.V1_UP
Systematic name | M2768
Organism | Mus musculus
PMID | 17394647
Authors | Hailesellasse Sene K,Porter CJ,Palidwor G,Perez-Iratxeta C,Muro EM,Campbell PA,Rudnicki MA,Andrade-Navarro MA
Category | C6
Sub-category |
Brief description | Genes up-regulated during late stages of differentiation of embryoid bodies from J1 embryonic stem cells.
Full description | An 11-point time course study on differentiating embryoid bodies from a murine J1 embryonic stem cell line. The time course includes 0 hr, 6 hr, 12 hr, 18 hr, 24 hr, 36 hr, 48 hr, 4 days, 7 days, 9 days and 14 days.

Standard name | ESC_V6.5_UP_EARLY.V1_DN
Systematic name | M2769
Organism | Mus musculus
PMID | 17394647
Authors | Hailesellasse Sene K,Porter CJ,Palidwor G,Perez-Iratxeta C,Muro EM,Campbell PA,Rudnicki MA,Andrade-Navarro MA
Category | C6
Sub-category |
Brief description | Genes down-regulated during early stages of differentiation of embryoid bodies from V6.5 embryonic stem cells.
Full description | An 11-point time course study comparing V6.5 embryonic stem cells versus embryoid bodies. Time course 0 hours, 6 hours, 12 hours, 18 hours, 24 hours, 36 hours, 48 hours, 4 days, 7 days, 9 days, and 14 days.

Standard name | ESC_V6.5_UP_EARLY.V1_UP
Systematic name | M2770
Organism | Mus musculus
PMID | 17394647
Authors | Hailesellasse Sene K,Porter CJ,Palidwor G,Perez-Iratxeta C,Muro EM,Campbell PA,Rudnicki MA,Andrade-Navarro MA
Category | C6
Sub-category |
Brief description | Genes up-regulated during early stages of differentiation of embryoid bodies from V6.5 embryonic stem cells.
Full description | An 11-point time course study comparing V6.5 embryonic stem cells versus embryoid bodies. Time course 0 hours, 6 hours, 12 hours, 18 hours, 24 hours, 36 hours, 48 hours, 4 days, 7 days, 9 days, and 14 days.

Standard name | ESC_V6.5_UP_LATE.V1_DN
Systematic name | M2771
Organism | Mus musculus
PMID | 17394647
Authors | Hailesellasse Sene K,Porter CJ,Palidwor G,Perez-Iratxeta C,Muro EM,Campbell PA,Rudnicki MA,Andrade-Navarro MA
Category | C6
Sub-category |
Brief description | Genes down-regulated during late stages of differentiation of embryoid bodies from V6.5 embryonic stem cells.
Full description | An 11-point time course study comparing V6.5 embryonic stem cells versus embryoid bodies. Time course 0 hours, 6 hours, 12 hours, 18 hours, 24 hours, 36 hours, 48 hours, 4 days, 7 days, 9 days, and 14 days.

Standard name | ESC_V6.5_UP_LATE.V1_UP
Systematic name | M2772
Organism | Mus musculus
PMID | 17394647
Authors | Hailesellasse Sene K,Porter CJ,Palidwor G,Perez-Iratxeta C,Muro EM,Campbell PA,Rudnicki MA,Andrade-Navarro MA
Category | C6
Sub-category |
Brief description | Genes up-regulated during late stages of differentiation of embryoid bodies from V6.5 embryonic stem cells.
Full description | An 11-point time course study comparing V6.5 embryonic stem cells versus embryoid bodies. Time course 0 hours, 6 hours, 12 hours, 18 hours, 24 hours, 36 hours, 48 hours, 4 days, 7 days, 9 days, and 14 days.

Standard name | ALK_DN.V1_DN
Systematic name | M2773
Organism | Homo sapiens
PMID | 17452456
Authors | Wiederschain D,Chen L,Johnson B,Bettano K
Category | C6
Sub-category |
Brief description | Genes down-regulated in DAOY cells (medulloblastoma) upon knockdown of ALK [Gene ID=238] gene by RNAi.
Full description | Analysis of DAOY medulloblastoma cells following RNAi knockdown of Alk.

Standard name | ALK_DN.V1_UP
Systematic name | M2774
Organism | Homo sapiens
PMID | 17452456
Authors | Wiederschain D,Chen L,Johnson B,Bettano K
Category | C6
Sub-category |
Brief description | Genes up-regulated in DAOY cells (medulloblastoma) upon knockdown of ALK [Gene ID=238] gene by RNAi.
Full description | Analysis of DAOY medulloblastoma cells following RNAi knockdown of Alk.

Standard name | BMI1_DN_MEL18_DN.V1_DN
Systematic name | M2775
Organism | Homo sapiens
PMID | 17452456
Authors | Wiederschain D,Chen L,Johnson B,Bettano K,Jackson D,Taraszka J,Wang YK,Jones MD,Morrissey M,Deeds J,Mosher R,Fordjour P,Lengauer C,Benson JD
Category | C6
Sub-category |
Brief description | Genes down-regulated in DAOY cells (medulloblastoma) upon knockdown of BMI1 and PCGF2 [Gene ID=648, 7703] genes by RNAi.
Full description | Analysis of DAOY medulloblastoma cells following RNAi knockdown of Bmi-1 and Mel-18.

Standard name | BMI1_DN_MEL18_DN.V1_UP
Systematic name | M2779
Organism | Homo sapiens
PMID | 17452456
Authors | Wiederschain D,Chen L,Johnson B,Bettano K,Jackson D,Taraszka J,Wang YK,Jones MD,Morrissey M,Deeds J,Mosher R,Fordjour P,Lengauer C,Benson JD
Category | C6
Sub-category |
Brief description | Genes up-regulated in DAOY cells (medulloblastoma) upon knockdown of BMI1 and PCGF2 [Gene ID=648, 7703] genes by RNAi.
Full description | Analysis of DAOY medulloblastoma cells following RNAi knockdown of Bmi-1 and Mel-18.

Standard name | BMI1_DN.V1_DN
Systematic name | M2781
Organism | Homo sapiens
PMID | 17452456
Authors | Wiederschain D,Chen L,Johnson B,Bettano K,Jackson D,Taraszka J,Wang YK,Jones MD,Morrissey M,Deeds J,Mosher R,Fordjour P,Lengauer C,Benson JD
Category | C6
Sub-category |
Brief description | Genes down-regulated in DAOY cells (medulloblastoma) upon knockdown of BMI1 [Gene ID=648] gene by RNAi.
Full description | Analysis of DAOY medulloblastoma cells following RNAi knockdown of Bmi-1.

Standard name | BMI1_DN.V1_UP
Systematic name | M2782
Organism | Homo sapiens
PMID | 17452456
Authors | Wiederschain D,Chen L,Johnson B,Bettano K,Jackson D,Taraszka J,Wang YK,Jones MD,Morrissey M,Deeds J,Mosher R,Fordjour P,Lengauer C,Benson JD
Category | C6
Sub-category |
Brief description | Genes up-regulated in DAOY cells (medulloblastoma) upon knockdown of BMI1 [Gene ID=648] gene by RNAi.
Full description | Analysis of DAOY medulloblastoma cells following RNAi knockdown of Bmi-1.

Standard name | MEL18_DN.V1_DN
Systematic name | M2783
Organism | Homo sapiens
PMID | 17452456
Authors | Wiederschain D,Chen L,Johnson B,Bettano K,Jackson D,Taraszka J,Wang YK,Jones MD,Morrissey M,Deeds J,Mosher R,Fordjour P,Lengauer C,Benson JD
Category | C6
Sub-category |
Brief description | Genes down-regulated in DAOY cells (medulloblastoma) upon knockdown of PCGF2 [Gene ID=7703] gene by RNAi.
Full description | Analysis of DAOY medulloblastoma cells following RNAi knockdown of Mel-18.

Standard name | MEL18_DN.V1_UP
Systematic name | M2784
Organism | Homo sapiens
PMID | 17452456
Authors | Wiederschain D,Chen L,Johnson B,Bettano K,Jackson D,Taraszka J,Wang YK,Jones MD,Morrissey M,Deeds J,Mosher R,Fordjour P,Lengauer C,Benson JD
Category | C6
Sub-category |
Brief description | Genes up-regulated in DAOY cells (medulloblastoma) upon knockdown of PCGF2 [Gene ID=7703] gene by RNAi.
Full description | Analysis of DAOY medulloblastoma cells following RNAi knockdown of Mel-18.

Standard name | PTEN_DN.V1_DN
Systematic name | M2786
Organism | Homo sapiens
PMID | 17560336
Authors | Vivanco I,Palaskas N,Tran C,Finn SP,Getz G,Kennedy NJ,Jiao J,Rose J,Xie W,Loda M,Golub T,Mellinghoff IK,Davis RJ,Wu H,Sawyers CL
Category | C6
Sub-category |
Brief description | Genes down-regulated upon knockdown of PTEN [Gene ID=5728] by RNAi.
Full description | A431, HCC827 and SKBR-3 cells were retrovirally and stably transduced with a small hairpin RNA targeting human PTEN. PTEN knockdown was confirmed at the protein level by western blot to be approximately 90%. PTEN-deficient sublines were named by adding the suffix PR(for PTEN RNAi) at the end of each of the parental cell line names. For example, PTEN deficient A431 cells are called A431-PR. RNA was extracted from each of the parental and PTEN-deificient lines. Each sample was done in duplicate (ie two chips per sample) for a total of twelve samples.

Standard name | PTEN_DN.V1_UP
Systematic name | M2787
Organism | Homo sapiens
PMID | 17560336
Authors | Vivanco I,Palaskas N,Tran C,Finn SP,Getz G,Kennedy NJ,Jiao J,Rose J,Xie W,Loda M,Golub T,Mellinghoff IK,Davis RJ,Wu H,Sawyers CL
Category | C6
Sub-category |
Brief description | Genes up-regulated upon knockdown of PTEN [Gene ID=5728] by RNAi.
Full description | A431, HCC827 and SKBR-3 cells were retrovirally and stably transduced with a small hairpin RNA targeting human PTEN. PTEN knockdown was confirmed at the protein level by western blot to be approximately 90%. PTEN-deficient sublines were named by adding the suffix PR(for PTEN RNAi) at the end of each of the parental cell line names. For example, PTEN deficient A431 cells are called A431-PR. RNA was extracted from each of the parental and PTEN-deificient lines. Each sample was done in duplicate (ie two chips per sample) for a total of twelve samples.

Standard name | NOTCH_DN.V1_DN
Systematic name | M2788
Organism | Homo sapiens
PMID | 17560996
Authors | Dohda T,Maljukova A,Liu L,Heyman M,Grander D,Brodin D,Sangfelt O,Lendahl U
Category | C6
Sub-category |
Brief description | Genes down-regulated in MOLT4 cells (T-ALL) by DAPT [PubChem=16219261], an inhibitor of NOTCH signaling pathway.
Full description | NOTCH signaling in T-ALL cell lines. Three independent cultures of the MOLT4 cell line before and 48 hours after addition of the gamma-secretase inhibitor DAPT (5 uM).

Standard name | NOTCH_DN.V1_UP
Systematic name | M2789
Organism | Homo sapiens
PMID | 17560996
Authors | Dohda T,Maljukova A,Liu L,Heyman M,Grander D,Brodin D,Sangfelt O,Lendahl U
Category | C6
Sub-category |
Brief description | Genes up-regulated in MOLT4 cells (T-ALL) by DAPT [PubChem=16219261], an inhibitor of NOTCH signaling pathway.
Full description | NOTCH signaling in T-ALL cell lines. Three independent cultures of the MOLT4 cell line before and 48 hours after addition of the gamma-secretase inhibitor DAPT (5 uM).

Standard name | EIF4E_DN
Systematic name | M2790
Organism | Homo sapiens
PMID | 17638893
Authors | Larsson O,Li S,Issaenko OA,Avdulov S,Peterson M,Smith K,Bitterman PB,Polunovsky VA
Category | C6
Sub-category |
Brief description | Genes down-regulated in HMEC cells (primary mammary epithelium) upon over-expression of EIF4E [Gene ID=1977] gene.
Full description | Translation initiation factor 4E confers primary human cells with neoplastic properties. A comparison of HMEC/hTERT and HMEC/hTERT/eIF4E cells using both total and polyribosoaml associated RNA.

Standard name | EIF4E_UP
Systematic name | M2791
Organism | Homo sapiens
PMID | 17638893
Authors | Larsson O,Li S,Issaenko OA,Avdulov S,Peterson M,Smith K,Bitterman PB,Polunovsky VA
Category | C6
Sub-category |
Brief description | Genes up-regulated in HMEC cells (primary mammary epithelium) upon over-expression of EIF4E [Gene ID=1977] gene.
Full description | Translation initiation factor 4E confers primary human cells with neoplastic properties. A comparison of HMEC/hTERT and HMEC/hTERT/eIF4E cells using both total and polyribosoaml associated RNA.

Standard name | CRX_DN.V1_DN
Systematic name | M2792
Organism | Mus musculus
PMID | 17653270
Authors | Hsiau TH,Diaconu C,Myers CA,Lee J,Cepko CL,Corbo JC
Category | C6
Sub-category |
Brief description | Genes down-regulated in retina cells from CRX [Gene ID=1406] knockout mice.
Full description | Complete microarray datasets for wild-type vs. Crx-/- comparison at P21 are in Supplementary Table S5. This table contains the full microarray datasets from six microarray hybridizations (three biological replicates each from wild-type (129S6/SvEv) and Crx-/- retinas at P21). The data from each of the individual microarray experiments are labeled with the following prefixes:Crx-mut_#1i etc. and129-wt-P21-#1i etc.

Standard name | CRX_DN.V1_UP
Systematic name | M2793
Organism | Mus musculus
PMID | 17653270
Authors | Hsiau TH,Diaconu C,Myers CA,Lee J,Cepko CL,Corbo JC
Category | C6
Sub-category |
Brief description | Genes up-regulated in retina cells from CRX [Gene ID=1406] knockout mice.
Full description | Complete microarray datasets for wild-type vs. Crx-/- comparison at P21 are in Supplementary Table S5. This table contains the full microarray datasets from six microarray hybridizations (three biological replicates each from wild-type (129S6/SvEv) and Crx-/- retinas at P21). The data from each of the individual microarray experiments are labeled with the following prefixes:Crx-mut_#1i etc. and129-wt-P21-#1i etc.

Standard name | CRX_NRL_DN.V1_DN
Systematic name | M2794
Organism | Mus musculus
PMID | 17653270
Authors | Hsiau TH,Diaconu C,Myers CA,Lee J,Cepko CL,Corbo JC
Category | C6
Sub-category |
Brief description | Genes down-regulated in retina cells from CRX and NRL [Gene ID=1406, 4901] double knockout mice.
Full description | Complete microarray datasets for wild-type vs. Crx-/-; Nrl-/- comparison at P21 are in Supplementary Table S6. This table contains the full microarray datasets from nine microarray hybridizations (three biological replicates each from wild-type (C57BL/6), wild-type (129S6/SvEv) and Crx-/-; Nrl-/- retinas at P21). Since Crx-/-; Nrl-/- is on a mixed 129 X B6 background, we present comparisons between both of the individual wild-type mutant backgrounds (as data from the mixed control background were not available). The data from each of the individual microarray experiments are labeled with the following prefixes:Crx-mut_#1i etc.,B6-wt-P21-#1i etc. and129-wt-P21-#1i etc.

Standard name | CRX_NRL_DN.V1_UP
Systematic name | M2796
Organism | Mus musculus
PMID | 17653270
Authors | Hsiau TH,Diaconu C,Myers CA,Lee J,Cepko CL,Corbo JC
Category | C6
Sub-category |
Brief description | Genes up-regulated in retina cells from CRX and NRL [Gene ID=1406, 4901] double knockout mice.
Full description | Complete microarray datasets for wild-type vs. Crx-/-; Nrl-/- comparison at P21 are in Supplementary Table S6. This table contains the full microarray datasets from nine microarray hybridizations (three biological replicates each from wild-type (C57BL/6), wild-type (129S6/SvEv) and Crx-/-; Nrl-/- retinas at P21). Since Crx-/-; Nrl-/- is on a mixed 129 X B6 background, we present comparisons between both of the individual wild-type mutant backgrounds (as data from the mixed control background were not available). The data from each of the individual microarray experiments are labeled with the following prefixes:Crx-mut_#1i etc.,B6-wt-P21-#1i etc. and129-wt-P21-#1i etc.

Standard name | NRL_DN.V1_DN
Systematic name | M2797
Organism | Mus musculus
PMID | 17653270
Authors | Hsiau TH,Diaconu C,Myers CA,Lee J,Cepko CL,Corbo JC
Category | C6
Sub-category |
Brief description | Genes down-regulated in retina cells from NRL [Gene ID=4901] knockout mice.
Full description | The photoreceptor cells of the retina are subject to a greater number of genetic diseases than any other cell type in the human body. The majority of more than 120 cloned human blindness genes are highly expressed in photoreceptors. In order to establish an integrative framework in which to understand these diseases, we have undertaken an experimental and computational analysis of the network controlled by the mammalian photoreceptor transcription factors, Crx, Nrl, and Nr2e3. Using microarray and in situ hybridization datasets we have produced a model of this network which contains over 600 genes, including numerous retinal disease loci as well as previously uncharacterized photoreceptor transcription factors. To elucidate the connectivity of this network, we devised a computational algorithm to identify the photoreceptor-specific cis-regulatory elements (CREs) mediating the interactions between these transcription factors and their target genes. In vivo validation of our computational predictions resulted in the discovery of 19 novel photoreceptor-specific CREs near retinal disease genes. Examination of these CREs permitted the definition of a simple cis-regulatory grammar rule associated with high-level expression. To test the generality of this rule, we used an expanded form of it as a selection filter to evolve photoreceptor CREs from random DNA sequences in silico. When fused to fluorescent reporters, these evolved CREs drove strong, photoreceptor-specific expression in vivo. This study represents the first systematic identification and in vivo validation of CREs in a mammalian neuronal cell type and lays the groundwork for a systems biology of photoreceptor transcriptional regulation.

Standard name | NRL_DN.V1_UP
Systematic name | M2798
Organism | Mus musculus
PMID | 17653270
Authors | Hsiau TH,Diaconu C,Myers CA,Lee J,Cepko CL,Corbo JC
Category | C6
Sub-category |
Brief description | Genes up-regulated in retina cells from NRL [Gene ID=4901] knockout mice.
Full description | The photoreceptor cells of the retina are subject to a greater number of genetic diseases than any other cell type in the human body. The majority of more than 120 cloned human blindness genes are highly expressed in photoreceptors. In order to establish an integrative framework in which to understand these diseases, we have undertaken an experimental and computational analysis of the network controlled by the mammalian photoreceptor transcription factors, Crx, Nrl, and Nr2e3. Using microarray and in situ hybridization datasets we have produced a model of this network which contains over 600 genes, including numerous retinal disease loci as well as previously uncharacterized photoreceptor transcription factors. To elucidate the connectivity of this network, we devised a computational algorithm to identify the photoreceptor-specific cis-regulatory elements (CREs) mediating the interactions between these transcription factors and their target genes. In vivo validation of our computational predictions resulted in the discovery of 19 novel photoreceptor-specific CREs near retinal disease genes. Examination of these CREs permitted the definition of a simple cis-regulatory grammar rule associated with high-level expression. To test the generality of this rule, we used an expanded form of it as a selection filter to evolve photoreceptor CREs from random DNA sequences in silico. When fused to fluorescent reporters, these evolved CREs drove strong, photoreceptor-specific expression in vivo. This study represents the first systematic identification and in vivo validation of CREs in a mammalian neuronal cell type and lays the groundwork for a systems biology of photoreceptor transcriptional regulation.

Standard name | RB_DN.V1_DN
Systematic name | M2799
Organism | Mus musculus
PMID | 17932948
Authors | Lara MF,Garcia-Escudero R,Ruiz S,Santos M,Moral M,Martinez-Cruz AB,Segrelles C,Lorz C,Paramio JM
Category | C6
Sub-category |
Brief description | Genes down-regulated in primary keratinocytes from RB1 [Gene ID=5925] skin specific knockout mice.
Full description | The epidermal-specific ablation of Rb gene leads to increased proliferation, aberrant differentiation, and the disengagement of these processes in vivo and in vitro. These differences in phenotype are more severe with the loss of p107, demonstrating the functional compensation between pRb and p107. As p107 and p130 also exert overlapping functions in epidermis, we have generated Rb(F19/F19)K14cre;Rbl2-/- (pRb-;p130-) mice to analyze possible functional redundancies between pRb and p130. The epidermal phenotype was very similar between pRb- and pRb-;p130- mice, suggesting that pRb and p130 activities are not redundant in epidermis. Importantly, we can correlate the proliferation differences with specific changes in gene expression between pRb-, pRb-;p107- and pRb-;p130- primary keratinocytes using microarray analysis, and explain the phenotypes in the context of altered E2F expression and functionality. Our findings support a model in which the distinct retinoblastoma family members, in conjunction with E2F members, play a central role in regulating epidermal homeostasis through specific or overlapping activities.

Standard name | RB_DN.V1_UP
Systematic name | M2800
Organism | Mus musculus
PMID | 17932948
Authors | Lara MF,Garcia-Escudero R,Ruiz S,Santos M,Moral M,Martinez-Cruz AB,Segrelles C,Lorz C,Paramio JM
Category | C6
Sub-category |
Brief description | Genes up-regulated in primary keratinocytes from RB1 [Gene ID=5925] skin specific knockout mice.
Full description | The epidermal-specific ablation of Rb gene leads to increased proliferation, aberrant differentiation, and the disengagement of these processes in vivo and in vitro. These differences in phenotype are more severe with the loss of p107, demonstrating the functional compensation between pRb and p107. As p107 and p130 also exert overlapping functions in epidermis, we have generated Rb(F19/F19)K14cre;Rbl2-/- (pRb-;p130-) mice to analyze possible functional redundancies between pRb and p130. The epidermal phenotype was very similar between pRb- and pRb-;p130- mice, suggesting that pRb and p130 activities are not redundant in epidermis. Importantly, we can correlate the proliferation differences with specific changes in gene expression between pRb-, pRb-;p107- and pRb-;p130- primary keratinocytes using microarray analysis, and explain the phenotypes in the context of altered E2F expression and functionality. Our findings support a model in which the distinct retinoblastoma family members, in conjunction with E2F members, play a central role in regulating epidermal homeostasis through specific or overlapping activities.

Standard name | RB_P107_DN.V1_DN
Systematic name | M2801
Organism | Mus musculus
PMID | 17932948
Authors | Lara MF,Garcia-Escudero R,Ruiz S,Santos M,Moral M,Martinez-Cruz AB,Segrelles C,Lorz C,Paramio JM
Category | C6
Sub-category |
Brief description | Genes down-regulated in primary keratinocytes from RB1 and RBL1 [Gene ID=5925, 5933] skin specific knockout mice.
Full description | The epidermal-specific ablation of Rb gene leads to increased proliferation, aberrant differentiation, and the disengagement of these processes in vivo and in vitro. These differences in phenotype are more severe with the loss of p107, demonstrating the functional compensation between pRb and p107. As p107 and p130 also exert overlapping functions in epidermis, we have generated Rb(F19/F19)K14cre;Rbl2-/- (pRb-;p130-) mice to analyze possible functional redundancies between pRb and p130. The epidermal phenotype was very similar between pRb- and pRb-;p130- mice, suggesting that pRb and p130 activities are not redundant in epidermis. Importantly, we can correlate the proliferation differences with specific changes in gene expression between pRb-, pRb-;p107- and pRb-;p130- primary keratinocytes using microarray analysis, and explain the phenotypes in the context of altered E2F expression and functionality. Our findings support a model in which the distinct retinoblastoma family members, in conjunction with E2F members, play a central role in regulating epidermal homeostasis through specific or overlapping activities.

Standard name | RB_P107_DN.V1_UP
Systematic name | M2802
Organism | Mus musculus
PMID | 17932948
Authors | Lara MF,Garcia-Escudero R,Ruiz S,Santos M,Moral M,Martinez-Cruz AB,Segrelles C,Lorz C,Paramio JM
Category | C6
Sub-category |
Brief description | Genes up-regulated in primary keratinocytes from RB1 and RBL1 [Gene ID=5925, 5933] skin specific knockout mice.
Full description | The epidermal-specific ablation of Rb gene leads to increased proliferation, aberrant differentiation, and the disengagement of these processes in vivo and in vitro. These differences in phenotype are more severe with the loss of p107, demonstrating the functional compensation between pRb and p107. As p107 and p130 also exert overlapping functions in epidermis, we have generated Rb(F19/F19)K14cre;Rbl2-/- (pRb-;p130-) mice to analyze possible functional redundancies between pRb and p130. The epidermal phenotype was very similar between pRb- and pRb-;p130- mice, suggesting that pRb and p130 activities are not redundant in epidermis. Importantly, we can correlate the proliferation differences with specific changes in gene expression between pRb-, pRb-;p107- and pRb-;p130- primary keratinocytes using microarray analysis, and explain the phenotypes in the context of altered E2F expression and functionality. Our findings support a model in which the distinct retinoblastoma family members, in conjunction with E2F members, play a central role in regulating epidermal homeostasis through specific or overlapping activities.

Standard name | RB_P130_DN.V1_DN
Systematic name | M2803
Organism | Mus musculus
PMID | 17932948
Authors | Lara MF,Garcia-Escudero R,Ruiz S,Santos M,Moral M,Martinez-Cruz AB,Segrelles C,Lorz C,Paramio JM
Category | C6
Sub-category |
Brief description | Genes down-regulated in primary keratinocytes from RB1 and RBL2 [Gene ID=5925, 5934] skin specific knockout mice.
Full description | The epidermal-specific ablation of Rb gene leads to increased proliferation, aberrant differentiation, and the disengagement of these processes in vivo and in vitro. These differences in phenotype are more severe with the loss of p107, demonstrating the functional compensation between pRb and p107. As p107 and p130 also exert overlapping functions in epidermis, we have generated Rb(F19/F19)K14cre;Rbl2-/- (pRb-;p130-) mice to analyze possible functional redundancies between pRb and p130. The epidermal phenotype was very similar between pRb- and pRb-;p130- mice, suggesting that pRb and p130 activities are not redundant in epidermis. Importantly, we can correlate the proliferation differences with specific changes in gene expression between pRb-, pRb-;p107- and pRb-;p130- primary keratinocytes using microarray analysis, and explain the phenotypes in the context of altered E2F expression and functionality. Our findings support a model in which the distinct retinoblastoma family members, in conjunction with E2F members, play a central role in regulating epidermal homeostasis through specific or overlapping activities.

Standard name | RB_P130_DN.V1_UP
Systematic name | M2805
Organism | Mus musculus
PMID | 17932948
Authors | Lara MF,Garcia-Escudero R,Ruiz S,Santos M,Moral M,Martinez-Cruz AB,Segrelles C,Lorz C,Paramio JM
Category | C6
Sub-category |
Brief description | Genes up-regulated in primary keratinocytes from RB1 and RBL2 [Gene ID=5925, 5934] skin specific knockout mice.
Full description | The epidermal-specific ablation of Rb gene leads to increased proliferation, aberrant differentiation, and the disengagement of these processes in vivo and in vitro. These differences in phenotype are more severe with the loss of p107, demonstrating the functional compensation between pRb and p107. As p107 and p130 also exert overlapping functions in epidermis, we have generated Rb(F19/F19)K14cre;Rbl2-/- (pRb-;p130-) mice to analyze possible functional redundancies between pRb and p130. The epidermal phenotype was very similar between pRb- and pRb-;p130- mice, suggesting that pRb and p130 activities are not redundant in epidermis. Importantly, we can correlate the proliferation differences with specific changes in gene expression between pRb-, pRb-;p107- and pRb-;p130- primary keratinocytes using microarray analysis, and explain the phenotypes in the context of altered E2F expression and functionality. Our findings support a model in which the distinct retinoblastoma family members, in conjunction with E2F members, play a central role in regulating epidermal homeostasis through specific or overlapping activities.

Standard name | CAHOY_ASTROCYTIC
Systematic name | M2806
Organism | Mus musculus
PMID | 18171944
Authors | Cahoy JD,Emery B,Kaushal A,Foo LC,Zamanian JL,Christopherson KS,Xing Y,Lubischer JL,Krieg PA,Krupenko SA,Thompson WJ,Barres BA
Category | C6
Sub-category |
Brief description | Genes up-regulated in astrocytes.
Full description | A Transcriptome Database for Astrocytes, Neurons, and Oligodendrocytes

Standard name | CAHOY_ASTROGLIAL
Systematic name | M2807
Organism | Mus musculus
PMID | 18171944
Authors | Cahoy JD,Emery B,Kaushal A,Foo LC,Zamanian JL,Christopherson KS,Xing Y,Lubischer JL,Krieg PA,Krupenko SA,Thompson WJ,Barres BA
Category | C6
Sub-category |
Brief description | Genes up-regulated in astrogia cells.
Full description | A Transcriptome Database for Astrocytes, Neurons, and Oligodendrocytes

Standard name | CAHOY_NEURONAL
Systematic name | M2808
Organism | Mus musculus
PMID | 18171944
Authors | Cahoy JD,Emery B,Kaushal A,Foo LC,Zamanian JL,Christopherson KS,Xing Y,Lubischer JL,Krieg PA,Krupenko SA,Thompson WJ,Barres BA
Category | C6
Sub-category |
Brief description | Genes up-regulated in neurons.
Full description | A Transcriptome Database for Astrocytes, Neurons, and Oligodendrocytes

Standard name | CAHOY_OLIGODENDROCUTIC
Systematic name | M2809
Organism | Mus musculus
PMID | 18171944
Authors | Cahoy JD,Emery B,Kaushal A,Foo LC,Zamanian JL,Christopherson KS,Xing Y,Lubischer JL,Krieg PA,Krupenko SA,Thompson WJ,Barres BA
Category | C6
Sub-category |
Brief description | Genes up-regulated in oligodendrocytes.
Full description | A Transcriptome Database for Astrocytes, Neurons, and Oligodendrocytes

Standard name | RPS14_DN.V1_DN
Systematic name | M2812
Organism | Homo sapiens
PMID | 18202658
Authors | Ebert BL,Pretz J,Bosco J,Chang CY
Category | C6
Sub-category |
Brief description | Genes down-regulated in CD34+ hematopoietic progenitor cells after knockdown of RPS14 [Gene ID=6208] by RNAi.
Full description | We performed genome-wide expression profiling of cells infected with control or RPS14 shRNAs.

Standard name | RPS14_DN.V1_UP
Systematic name | M2816
Organism | Homo sapiens
PMID | 18202658
Authors | Ebert BL,Pretz J,Bosco J,Chang CY
Category | C6
Sub-category |
Brief description | Genes up-regulated in CD34+ hematopoietic progenitor cells after knockdown of RPS14 [Gene ID=6208] by RNAi.
Full description | We performed genome-wide expression profiling of cells infected with control or RPS14 shRNAs.

Standard name | IL15_UP.V1_DN
Systematic name | M2818
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C6
Sub-category |
Brief description | Genes down-regulated in Sez-4 cells (T lymphocyte) that were first starved of IL2 [Gene ID=3558] and then stimulated with IL15 [Gene ID=3600].
Full description | Sez-4 cell line was starved of IL2 for 16h, washed twice and placed into 6-well plates in 10ml RPMI (10% FBS) for 2 h followed by addition of IL-15 (20ng/mL) or medium alone for 4 h.

Standard name | IL15_UP.V1_UP
Systematic name | M2819
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C6
Sub-category |
Brief description | Genes up-regulated in Sez-4 cells (T lymphocyte) that were first starved of IL2 [Gene ID=3558] and then stimulated with IL15 [Gene ID=3600].
Full description | Sez-4 cell line was starved of IL2 for 16h, washed twice and placed into 6-well plates in 10ml RPMI (10% FBS) for 2 h followed by addition of IL-15 (20ng/mL) or medium alone for 4 h.

Standard name | IL2_UP.V1_DN
Systematic name | M2820
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C6
Sub-category |
Brief description | Genes down-regulated in Sez-4 cells (T lymphocyte) that were first starved of IL2 [Gene ID=3558] and then stimulated with IL2 [Gene ID=3558].
Full description | Sez-4 cell line was starved of IL2 for 16h, washed twice and placed into 6-well plates in 10ml RPMI (10% FBS) for 2 h followed by addition of IL-2 (200U) or medium alone for 4 h.

Standard name | IL2_UP.V1_UP
Systematic name | M2822
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C6
Sub-category |
Brief description | Genes up-regulated in Sez-4 cells (T lymphocyte) that were first starved of IL2 [Gene ID=3558] and then stimulated with IL2 [Gene ID=3558].
Full description | Sez-4 cell line was starved of IL2 for 16h, washed twice and placed into 6-well plates in 10ml RPMI (10% FBS) for 2 h followed by addition of IL-2 (200U) or medium alone for 4 h.

Standard name | IL21_UP.V1_DN
Systematic name | M2824
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C6
Sub-category |
Brief description | Genes down-regulated in Sez-4 cells (T lymphocyte) that were first starved of IL2 [Gene ID=3558] and then stimulated with IL21 [Gene ID=59067].
Full description | Sez-4 cell line was starved of IL2 for 16h, washed twice and placed into 6-well plates in 10ml RPMI (10% FBS) for 2 h followed by addition of IL-21 (100 ng/ml) or medium alone for 4 h.

Standard name | IL21_UP.V1_UP
Systematic name | M2827
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C6
Sub-category |
Brief description | Genes up-regulated in Sez-4 cells (T lymphocyte) that were first starved of IL2 [Gene ID=3558] and then stimulated with IL21 [Gene ID=59067].
Full description | Sez-4 cell line was starved of IL2 for 16h, washed twice and placed into 6-well plates in 10ml RPMI (10% FBS) for 2 h followed by addition of IL-21 (100 ng/ml) or medium alone for 4 h.

Standard name | PDGF_ERK_DN.V1_DN
Systematic name | M2828
Organism | Homo sapiens
PMID | 18312689
Authors | Antipova AA,Stockwell BR,Golub TR
Category | C6
Sub-category |
Brief description | Genes down-regulated in SH-SY5Y cells (neuroblastoma) in response to PDGF [Gene ID=] stimulation after pre-treatment with the ERK inhibitors U0126 and PD98059 [PubChem=3006531, 4713].
Full description | To define ERK/PDGFR activation signature, SH-SY5Y cells were grown to confluence and starved overnight in serum-free medium in order to silence any sustained effects from growth factor signaling. Prior to induction with 50ng/ml PDGF, cells were treated with pathway inhibitors 74 mM Apigenin or 50 mM U0126, or with DMSO (carrier) for 60 minutes. Total RNA was isolated 30 minutes after PDGF addition. Experiments were performed in duplicate. The RNA was processed and hybridized with Affymetrix U133A GeneChips.

Standard name | PDGF_ERK_DN.V1_UP
Systematic name | M2830
Organism | Homo sapiens
PMID | 18312689
Authors | Antipova AA,Stockwell BR,Golub TR
Category | C6
Sub-category |
Brief description | Genes up-regulated in SH-SY5Y cells (neuroblastoma) in response to PDGF [Gene ID=] stimulation after pre-treatment with the ERK inhibitors U0126 and PD98059 [PubChem=3006531, 4713].
Full description | To define ERK/PDGFR activation signature, SH-SY5Y cells were grown to confluence and starved overnight in serum-free medium in order to silence any sustained effects from growth factor signaling. Prior to induction with 50ng/ml PDGF, cells were treated with pathway inhibitors 74 mM Apigenin or 50 mM U0126, or with DMSO (carrier) for 60 minutes. Total RNA was isolated 30 minutes after PDGF addition. Experiments were performed in duplicate. The RNA was processed and hybridized with Affymetrix U133A GeneChips.

Standard name | PDGF_UP.V1_DN
Systematic name | M2832
Organism | Homo sapiens
PMID | 18312689
Authors | Antipova AA,Stockwell BR,Golub TR
Category | C6
Sub-category |
Brief description | Genes down-regulated in SH-SY5Y cells (neuroblastoma) in response to PDGF [Gene ID=] stimulation.
Full description | To define ERK/PDGFR activation signature, SH-SY5Y cells were grown to confluence and starved overnight in serum-free medium in order to silence any sustained effects from growth factor signaling. Prior to induction with 50ng/ml PDGF, cells were treated with pathway inhibitors 74 mM Apigenin or 50 mM U0126, or with DMSO (carrier) for 60 minutes. Total RNA was isolated 30 minutes after PDGF addition. Experiments were performed in duplicate. The RNA was processed and hybridized with Affymetrix U133A GeneChips.

Standard name | PDGF_UP.V1_UP
Systematic name | M2834
Organism | Homo sapiens
PMID | 18312689
Authors | Antipova AA,Stockwell BR,Golub TR
Category | C6
Sub-category |
Brief description | Genes up-regulated in SH-SY5Y cells (neuroblastoma) in response to PDGF [Gene ID=] stimulation.
Full description | To define ERK/PDGFR activation signature, SH-SY5Y cells were grown to confluence and starved overnight in serum-free medium in order to silence any sustained effects from growth factor signaling. Prior to induction with 50ng/ml PDGF, cells were treated with pathway inhibitors 74 mM Apigenin or 50 mM U0126, or with DMSO (carrier) for 60 minutes. Total RNA was isolated 30 minutes after PDGF addition. Experiments were performed in duplicate. The RNA was processed and hybridized with Affymetrix U133A GeneChips.

Standard name | TGFB_UP.V1_DN
Systematic name | M2838
Organism | Homo sapiens
PMID | 18394990
Authors | Padua D,Zhang XH,Wang Q,Nadal C,Gerald WL,Gomis RR,Massagué J
Category | C6
Sub-category |
Brief description | Genes down-regulated in a panel of epithelial cell lines by TGFB1 [Gene ID=7040].
Full description | A gene expression signature typifying the TGFbeta response in human epithelial cells was obtained from transcriptomic analysis of four human cell lines (Figure 1A, Supplementary Figure 1). These cell lines include HaCaT keratinocytes, HPL1 immortalized lung epithelial cells, MCF10A breast epithelial cells, and MDA-MB-231 breast carcinoma cells. The cells were treated with TGFB1 for 3 h in order to capture direct TGFbeta gene responses .

Standard name | TGFB_UP.V1_UP
Systematic name | M2839
Organism | Homo sapiens
PMID | 18394990
Authors | Padua D,Zhang XH,Wang Q,Nadal C,Gerald WL,Gomis RR,Massagué J
Category | C6
Sub-category |
Brief description | Genes up-regulated in a panel of epithelial cell lines by TGFB1 [Gene ID=7040].
Full description | A gene expression signature typifying the TGFbeta response in human epithelial cells was obtained from transcriptomic analysis of four human cell lines (Figure 1A, Supplementary Figure 1). These cell lines include HaCaT keratinocytes, HPL1 immortalized lung epithelial cells, MCF10A breast epithelial cells, and MDA-MB-231 breast carcinoma cells. The cells were treated with TGFB1 for 3 h in order to capture direct TGFbeta gene responses .

Standard name | YAP1_DN
Systematic name | M2841
Organism | Homo sapiens
PMID | 18413746
Authors | Zhang J,Smolen GA,Haber DA
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF10A cells (breast cancer) over-expressing YAP1 [Gene ID=10413] gene.
Full description | MCF10A cells were infected with retrovirus constructs (vector or YAP) and puromycin was used to select for transduced cells. Cells were split and grown to ~60-75%% confluency at which point they were harvested for RNA. Vector vs. YAP comparison was done in duplicate.

Standard name | YAP1_UP
Systematic name | M2845
Organism | Homo sapiens
PMID | 18413746
Authors | Zhang J,Smolen GA,Haber DA
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF10A cells (breast cancer) over-expressing YAP1 [Gene ID=10413] gene.
Full description | MCF10A cells were infected with retrovirus constructs (vector or YAP) and puromycin was used to select for transduced cells. Cells were split and grown to ~60-75%% confluency at which point they were harvested for RNA. Vector vs. YAP comparison was done in duplicate.

Standard name | SIRNA_EIF4GI_DN
Systematic name | M2846
Organism | Homo sapiens
PMID | 18426977
Authors | Ramirez-Valle F,Braunstein S,Zavadil J,Formenti SC,Schneider RJ
Category | C6
Sub-category |
Brief description | Genes down-regulated in MCF10A cells vs knockdown of EIF4G1 [Gene ID=1981] gene by RNAi.
Full description | eIF4GI Links Nutrient Sensing by mTOR to Cell Proliferation and Inhibition of Autophagy. Two sets of experiments are presented. First, overall transcriptome changes were determined for control or eIF4GI silenced cells. Next, mRNAs associated with polysomes were compared between control and eIF4GI silenced cells.

Standard name | SIRNA_EIF4GI_UP
Systematic name | M2847
Organism | Homo sapiens
PMID | 18426977
Authors | Ramirez-Valle F,Braunstein S,Zavadil J,Formenti SC,Schneider RJ
Category | C6
Sub-category |
Brief description | Genes up-regulated in MCF10A cells vs knockdown of EIF4G1 [Gene ID=1981] gene by RNAi.
Full description | eIF4GI Links Nutrient Sensing by mTOR to Cell Proliferation and Inhibition of Autophagy. Two sets of experiments are presented. First, overall transcriptome changes were determined for control or eIF4GI silenced cells. Next, mRNAs associated with polysomes were compared between control and eIF4GI silenced cells.

Standard name | HOXA9_DN.V1_DN
Systematic name | M2848
Organism | Homo sapiens
PMID | 19056693
Authors | Faber J,Krivtsov AV,Stubbs MC,Wright R,Davis TN,van den Heuvel-Eibrink M,Zwaan CM,Kung AL,Armstrong SA
Category | C6
Sub-category |
Brief description | Genes down-regulated in MOLM-14 cells (AML) with knockdown of HOXA9 [Gene ID=3205] gene by RNAi vs controls.
Full description | RNA was purified from t(9;11) MOLM-14 AML cells 44h after transduction in triplicates with 2 of the two most effective HOXA9shRNA constructs (3 x 1F3-HOXA9shRNA; 3 x 2A5-HOXA9shRNA) or GFP-controlshRNA (6x).

Standard name | HOXA9_DN.V1_UP
Systematic name | M2850
Organism | Homo sapiens
PMID | 19056693
Authors | Faber J,Krivtsov AV,Stubbs MC,Wright R,Davis TN,van den Heuvel-Eibrink M,Zwaan CM,Kung AL,Armstrong SA
Category | C6
Sub-category |
Brief description | Genes up-regulated in MOLM-14 cells (AML) with knockdown of HOXA9 [Gene ID=3205] gene by RNAi vs controls.
Full description | RNA was purified from t(9;11) MOLM-14 AML cells 44h after transduction in triplicates with 2 of the two most effective HOXA9shRNA constructs (3 x 1F3-HOXA9shRNA; 3 x 2A5-HOXA9shRNA) or GFP-controlshRNA (6x).

Standard name | SINGH_KRAS_DEPENDENCY_SIGNATURE
Systematic name | M2851
Organism | Homo sapiens
PMID | 19477428
Authors | Singh A,Greninger P,Rhodes D,Koopman L,Violette S,Bardeesy N,Settleman J
Category | C6
Sub-category |
Brief description | Genes defining the KRAS [Gene ID=3845] dependency signature.
Full description | K-ras mutations occur frequently in epithelial cancers. Using short hairpin RNAs to deplete K-Ras in lung and pancreatic cancer cell lines harboring K-ras mutations, two classes were identified-lines that do or do not require K-Ras to maintain viability. Comparing these two classes of cancer cells revealed a gene expression signature in K-Ras-dependent cells, associated with a well-differentiated epithelial phenotype, which was also seen in primary tumors. Several of these genes encode pharmacologically tractable proteins, such as Syk and Ron kinases and integrin beta6, depletion of which induces epithelial-mesenchymal transformation (EMT) and apoptosis specifically in K-Ras-dependent cells. These findings indicate that epithelial differentiation and tumor cell viability are associated, and that EMT regulators in K-Ras-addicted cancers represent candidate therapeutic targets.

Standard name | STK33_DN
Systematic name | M2853
Organism | Homo sapiens
PMID | 19490892
Authors | Scholl C,Froehling S,Dunn IF,Schinzel AC,Barbie DA,Kim SY,Silver SJ,Tamayo P,Wadlow RC,Ramaswamy S,Doehner K,Bullinger L,Sandy P,Boehm JS,Root DE,Jacks T,Hahn WC,Gilliland DG
Category | C6
Sub-category |
Brief description | Genes down-regulated in NOMO-1 and SKM-1 cells (AML) after knockdown of STK33 [Gene ID=65975] by RNAi.
Full description | NOMO-1 and SKM-1 acute myeloid leukemia (AML) cells were stably transduced with different pLKO.1puro lentiviral shRNA vectors targeting STK33 or a nontargeting control shRNA. VSV-G-pseudotyped lentiviral particles were produced by cotransfection of 293T cells with pLKO.1 constructs and the compatible packaging plasmids pMD.G and pCMVR8.91. Virus was harvested 48 and 72 hours after transfection, cells were incubated with lentiviral supernatants for 30 hours, and infected cells were selected with 2ug/ml puromycin. RNA was isolated after 2 days of puromycin selection and isolation of viable cells by density gradient centrifugation, and gene expression was profiled using GeneChip Human Genome U133 Plus 2.0 microarrays (Affymetrix).

Standard name | STK33_NOMO_DN
Systematic name | M2854
Organism | Homo sapiens
PMID | 19490892
Authors | Scholl C,Froehling S,Dunn IF,Schinzel AC,Barbie DA,Kim SY,Silver SJ,Tamayo P,Wadlow RC,Ramaswamy S,Doehner K,Bullinger L,Sandy P,Boehm JS,Root DE,Jacks T,Hahn WC,Gilliland DG
Category | C6
Sub-category |
Brief description | Genes down-regulated in NOMO-1 cells (AML) after knockdown of STK33 [Gene ID=65975] by RNAi.
Full description | NOMO-1 acute myeloid leukemia (AML) cells were stably transduced with different pLKO.1puro lentiviral shRNA vectors targeting STK33 or a nontargeting control shRNA. VSV-G-pseudotyped lentiviral particles were produced by cotransfection of 293T cells with pLKO.1 constructs and the compatible packaging plasmids pMD.G and pCMVR8.91. Virus was harvested 48 and 72 hours after transfection, cells were incubated with lentiviral supernatants for 30 hours, and infected cells were selected with 2ug/ml puromycin. RNA was isolated after 2 days of puromycin selection and isolation of viable cells by density gradient centrifugation, and gene expression was profiled using GeneChip Human Genome U133 Plus 2.0 microarrays (Affymetrix).

Standard name | STK33_NOMO_UP
Systematic name | M2855
Organism | Homo sapiens
PMID | 19490892
Authors | Scholl C,Froehling S,Dunn IF,Schinzel AC,Barbie DA,Kim SY,Silver SJ,Tamayo P,Wadlow RC,Ramaswamy S,Doehner K,Bullinger L,Sandy P,Boehm JS,Root DE,Jacks T,Hahn WC,Gilliland DG
Category | C6
Sub-category |
Brief description | Genes up-regulated in NOMO-1 cells (AML) after knockdown of STK33 [Gene ID=65975] by RNAi.
Full description | NOMO-1 acute myeloid leukemia (AML) cells were stably transduced with different pLKO.1puro lentiviral shRNA vectors targeting STK33 or a nontargeting control shRNA. VSV-G-pseudotyped lentiviral particles were produced by cotransfection of 293T cells with pLKO.1 constructs and the compatible packaging plasmids pMD.G and pCMVR8.91. Virus was harvested 48 and 72 hours after transfection, cells were incubated with lentiviral supernatants for 30 hours, and infected cells were selected with 2ug/ml puromycin. RNA was isolated after 2 days of puromycin selection and isolation of viable cells by density gradient centrifugation, and gene expression was profiled using GeneChip Human Genome U133 Plus 2.0 microarrays (Affymetrix).

Standard name | STK33_SKM_DN
Systematic name | M2856
Organism | Homo sapiens
PMID | 19490892
Authors | Scholl C,Froehling S,Dunn IF,Schinzel AC,Barbie DA,Kim SY,Silver SJ,Tamayo P,Wadlow RC,Ramaswamy S,Doehner K,Bullinger L,Sandy P,Boehm JS,Root DE,Jacks T,Hahn WC,Gilliland DG
Category | C6
Sub-category |
Brief description | Genes down-regulated in SKM-1 cells (AML) after knockdown of STK33 [Gene ID=65975] by RNAi.
Full description | SKM-1 acute myeloid leukemia (AML) cells were stably transduced with different pLKO.1puro lentiviral shRNA vectors targeting STK33 or a nontargeting control shRNA. VSV-G-pseudotyped lentiviral particles were produced by cotransfection of 293T cells with pLKO.1 constructs and the compatible packaging plasmids pMD.G and pCMVR8.91. Virus was harvested 48 and 72 hours after transfection, cells were incubated with lentiviral supernatants for 30 hours, and infected cells were selected with 2ug/ml puromycin. RNA was isolated after 2 days of puromycin selection and isolation of viable cells by density gradient centrifugation, and gene expression was profiled using GeneChip Human Genome U133 Plus 2.0 microarrays (Affymetrix).

Standard name | STK33_SKM_UP
Systematic name | M2857
Organism | Homo sapiens
PMID | 19490892
Authors | Scholl C,Froehling S,Dunn IF,Schinzel AC,Barbie DA,Kim SY,Silver SJ,Tamayo P,Wadlow RC,Ramaswamy S,Doehner K,Bullinger L,Sandy P,Boehm JS,Root DE,Jacks T,Hahn WC,Gilliland DG
Category | C6
Sub-category |
Brief description | Genes up-regulated in SKM-1 cells (AML) after knockdown of STK33 [Gene ID=65975] by RNAi.
Full description | SKM-1 acute myeloid leukemia (AML) cells were stably transduced with different pLKO.1puro lentiviral shRNA vectors targeting STK33 or a nontargeting control shRNA. VSV-G-pseudotyped lentiviral particles were produced by cotransfection of 293T cells with pLKO.1 constructs and the compatible packaging plasmids pMD.G and pCMVR8.91. Virus was harvested 48 and 72 hours after transfection, cells were incubated with lentiviral supernatants for 30 hours, and infected cells were selected with 2ug/ml puromycin. RNA was isolated after 2 days of puromycin selection and isolation of viable cells by density gradient centrifugation, and gene expression was profiled using GeneChip Human Genome U133 Plus 2.0 microarrays (Affymetrix).

Standard name | STK33_UP
Systematic name | M2858
Organism | Homo sapiens
PMID | 19490892
Authors | Scholl C,Froehling S,Dunn IF,Schinzel AC,Barbie DA,Kim SY,Silver SJ,Tamayo P,Wadlow RC,Ramaswamy S,Doehner K,Bullinger L,Sandy P,Boehm JS,Root DE,Jacks T,Hahn WC,Gilliland DG
Category | C6
Sub-category |
Brief description | Genes up-regulated in NOMO-1 and SKM-1 cells (AML) after knockdown of STK33 [Gene ID=65975] by RNAi.
Full description | NOMO-1 and SKM-1 acute myeloid leukemia (AML) cells were stably transduced with different pLKO.1puro lentiviral shRNA vectors targeting STK33 or a nontargeting control shRNA. VSV-G-pseudotyped lentiviral particles were produced by cotransfection of 293T cells with pLKO.1 constructs and the compatible packaging plasmids pMD.G and pCMVR8.91. Virus was harvested 48 and 72 hours after transfection, cells were incubated with lentiviral supernatants for 30 hours, and infected cells were selected with 2ug/ml puromycin. RNA was isolated after 2 days of puromycin selection and isolation of viable cells by density gradient centrifugation, and gene expression was profiled using GeneChip Human Genome U133 Plus 2.0 microarrays (Affymetrix).

Standard name | KRAS.AMP.LUNG_UP.V1_DN
Systematic name | M2859
Organism | Homo sapiens
PMID | GSE17643
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes down-regulated in epithelial lung cancer cell lines over-expressing KRAS [Gene ID=3845] gene.
Full description | Profiling of immortalized human lung epithelial cells following oncogenic KRAS expression and TBK1 suppression. The purpose of the dataset is to analyze expression of genes induced by KRAS and regulated by TBK1. The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. An alternative strategy for targeting KRAS is to identify gene products that, when suppressed or inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference (RNAi) to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkB kinase, TBK1, was selectively essential in cells that harbor mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving cREL and BCL-XL that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations identify TBK1 as a potential therapeutic target in KRAS mutant tumors and establish a general approach for the rational identification of co-dependent pathways in cancer. Knock out of TBK1 in the contect of KRAS activation (mutant) and control (WT).

Standard name | KRAS.AMP.LUNG_UP.V1_UP
Systematic name | M2860
Organism | Homo sapiens
PMID | GSE17643
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes up-regulated in epithelial lung cancer cell lines over-expressing KRAS [Gene ID=3845] gene.
Full description | Profiling of immortalized human lung epithelial cells following oncogenic KRAS expression and TBK1 suppression. The purpose of the dataset is to analyze expression of genes induced by KRAS and regulated by TBK1. The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. An alternative strategy for targeting KRAS is to identify gene products that, when suppressed or inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference (RNAi) to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkB kinase, TBK1, was selectively essential in cells that harbor mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving cREL and BCL-XL that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations identify TBK1 as a potential therapeutic target in KRAS mutant tumors and establish a general approach for the rational identification of co-dependent pathways in cancer. Knock out of TBK1 in the contect of KRAS activation (mutant) and control (WT).

Standard name | KRAS.DF.V1_DN
Systematic name | M2861
Organism | Homo sapiens
PMID | GSE17643
Authors | Barbie DA,Tamayo P,Boehm JS,Kim SY,Moody SE,Dunn IF,Schinzel AC,Sandy P,Meylan E,Scholl C,Froehling S,Chan EM,Sos ML,Michel K,Mermel C,Silver SJ,Weir BA,Reiling JH,Sheng Q,Gupta PB,Wadlow RC,Le H,Hoersch S,Wittner BS,Ramaswamy S,Livingston DM,Sabatini DM,Meyerson M,Thomas RK,Lander ES,Mesirov JP,Root DE,Gilliland DG,Jacks T,Hahn WC
Category | C6
Sub-category |
Brief description | Genes down-regulated in epithelial lung cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description | Profiling of immortalized human lung epithelial cells following oncogenic KRAS expression and TBK1 suppression. The purpose of the dataset is to analyze expression of genes induced by KRAS and regulated by TBK1. The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. An alternative strategy for targeting KRAS is to identify gene products that, when suppressed or inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference (RNAi) to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkB kinase, TBK1, was selectively essential in cells that harbor mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving cREL and BCL-XL that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations identify TBK1 as a potential therapeutic target in KRAS mutant tumors and establish a general approach for the rational identification of co-dependent pathways in cancer. Knock out of TBK1 in the contect of KRAS activation (mutant) and control (WT).

Standard name | KRAS.DF.V1_UP
Systematic name | M2863
Organism | Homo sapiens
PMID | GSE17643
Authors | Barbie DA,Tamayo P,Boehm JS,Kim SY,Moody SE,Dunn IF,Schinzel AC,Sandy P,Meylan E,Scholl C,Froehling S,Chan EM,Sos ML,Michel K,Mermel C,Silver SJ,Weir BA,Reiling JH,Sheng Q,Gupta PB,Wadlow RC,Le H,Hoersch S,Wittner BS,Ramaswamy S,Livingston DM,Sabatini DM,Meyerson M,Thomas RK,Lander ES,Mesirov JP,Root DE,Gilliland DG,Jacks T,Hahn WC
Category | C6
Sub-category |
Brief description | Genes up-regulated in epithelial lung cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description | Profiling of immortalized human lung epithelial cells following oncogenic KRAS expression and TBK1 suppression. The purpose of the dataset is to analyze expression of genes induced by KRAS and regulated by TBK1. The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. An alternative strategy for targeting KRAS is to identify gene products that, when suppressed or inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference (RNAi) to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkB kinase, TBK1, was selectively essential in cells that harbor mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving cREL and BCL-XL that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations identify TBK1 as a potential therapeutic target in KRAS mutant tumors and establish a general approach for the rational identification of co-dependent pathways in cancer. Knock out of TBK1 in the contect of KRAS activation (mutant) and control (WT).

Standard name | TBK1.DF_DN
Systematic name | M2864
Organism | Homo sapiens
PMID | GSE17643
Authors | Barbie DA,Tamayo P,Boehm JS,Kim SY,Moody SE,Dunn IF,Schinzel AC,Sandy P,Meylan E,Scholl C,Froehling S,Chan EM,Sos ML,Michel K,Mermel C,Silver SJ,Weir BA,Reiling JH,Sheng Q,Gupta PB,Wadlow RC,Le H,Hoersch S,Wittner BS,Ramaswamy S,Livingston DM,Sabatini DM,Meyerson M,Thomas RK,Lander ES,Mesirov JP,Root DE,Gilliland DG,Jacks T,Hahn WC
Category | C6
Sub-category |
Brief description | Genes down-regulated in epithelial lung cancer cell lines upon over-expression of an oncogenic form of KRAS [Gene ID=3845] gene and knockdown of TBK1 [Gene ID=29110] gene by RNAi.
Full description | Profiling of immortalized human lung epithelial cells following oncogenic KRAS expression and TBK1 suppression. The purpose of the dataset is to analyze expression of genes induced by KRAS and regulated by TBK1. The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. An alternative strategy for targeting KRAS is to identify gene products that, when suppressed or inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference (RNAi) to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkB kinase, TBK1, was selectively essential in cells that harbor mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving cREL and BCL-XL that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations identify TBK1 as a potential therapeutic target in KRAS mutant tumors and establish a general approach for the rational identification of co-dependent pathways in cancer. Knock out of TBK1 in the contect of KRAS activation (mutant) and control (WT).

Standard name | TBK1.DF_UP
Systematic name | M2867
Organism | Homo sapiens
PMID | GSE17643
Authors | Barbie DA,Tamayo P,Boehm JS,Kim SY,Moody SE,Dunn IF,Schinzel AC,Sandy P,Meylan E,Scholl C,Froehling S,Chan EM,Sos ML,Michel K,Mermel C,Silver SJ,Weir BA,Reiling JH,Sheng Q,Gupta PB,Wadlow RC,Le H,Hoersch S,Wittner BS,Ramaswamy S,Livingston DM,Sabatini DM,Meyerson M,Thomas RK,Lander ES,Mesirov JP,Root DE,Gilliland DG,Jacks T,Hahn WC
Category | C6
Sub-category |
Brief description | Genes up-regulated in epithelial lung cancer cell lines upon over-expression of an oncogenic form of KRAS [Gene ID=3845] gene and knockdown of TBK1 [Gene ID=29110] gene by RNAi.
Full description | Profiling of immortalized human lung epithelial cells following oncogenic KRAS expression and TBK1 suppression. The purpose of the dataset is to analyze expression of genes induced by KRAS and regulated by TBK1. The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. An alternative strategy for targeting KRAS is to identify gene products that, when suppressed or inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference (RNAi) to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkB kinase, TBK1, was selectively essential in cells that harbor mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving cREL and BCL-XL that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations identify TBK1 as a potential therapeutic target in KRAS mutant tumors and establish a general approach for the rational identification of co-dependent pathways in cancer. Knock out of TBK1 in the contect of KRAS activation (mutant) and control (WT).

Standard name | TBK1.DN.48HRS_DN
Systematic name | M2868
Organism | Homo sapiens
PMID | GSE17643
Authors | Barbie DA,Tamayo P,Boehm JS,Kim SY,Moody SE,Dunn IF,Schinzel AC,Sandy P,Meylan E,Scholl C,Froehling S,Chan EM,Sos ML,Michel K,Mermel C,Silver SJ,Weir BA,Reiling JH,Sheng Q,Gupta PB,Wadlow RC,Le H,Hoersch S,Wittner BS,Ramaswamy S,Livingston DM,Sabatini DM,Meyerson M,Thomas RK,Lander ES,Mesirov JP,Root DE,Gilliland DG,Jacks T,Hahn WC
Category | C6
Sub-category |
Brief description | Genes down-regulated in epithelial lung cancer cell lines upon over-expression of an oncogenic form of KRAS [Gene ID=3845] gene and knockdown of TBK1 [Gene ID=29110] gene by RNAi.
Full description | Profiling of immortalized human lung epithelial cells following oncogenic KRAS expression and TBK1 suppression. The purpose of the dataset is to analyze expression of genes induced by KRAS and regulated by TBK1. The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. An alternative strategy for targeting KRAS is to identify gene products that, when suppressed or inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference (RNAi) to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkB kinase, TBK1, was selectively essential in cells that harbor mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving cREL and BCL-XL that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations identify TBK1 as a potential therapeutic target in KRAS mutant tumors and establish a general approach for the rational identification of co-dependent pathways in cancer. Knock out of TBK1 in the contect of KRAS activation (mutant) and control (WT).

Standard name | TBK1.DN.48HRS_UP
Systematic name | M2869
Organism | Homo sapiens
PMID | GSE17643
Authors | Barbie DA,Tamayo P,Boehm JS,Kim SY,Moody SE,Dunn IF,Schinzel AC,Sandy P,Meylan E,Scholl C,Froehling S,Chan EM,Sos ML,Michel K,Mermel C,Silver SJ,Weir BA,Reiling JH,Sheng Q,Gupta PB,Wadlow RC,Le H,Hoersch S,Wittner BS,Ramaswamy S,Livingston DM,Sabatini DM,Meyerson M,Thomas RK,Lander ES,Mesirov JP,Root DE,Gilliland DG,Jacks T,Hahn WC
Category | C6
Sub-category |
Brief description | Genes up-regulated in epithelial lung cancer cell lines upon over-expression of an oncogenic form of KRAS [Gene ID=3845] gene and knockdown of TBK1 [Gene ID=29110] gene by RNAi.
Full description | Profiling of immortalized human lung epithelial cells following oncogenic KRAS expression and TBK1 suppression. The purpose of the dataset is to analyze expression of genes induced by KRAS and regulated by TBK1. The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. An alternative strategy for targeting KRAS is to identify gene products that, when suppressed or inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference (RNAi) to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkB kinase, TBK1, was selectively essential in cells that harbor mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving cREL and BCL-XL that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations identify TBK1 as a potential therapeutic target in KRAS mutant tumors and establish a general approach for the rational identification of co-dependent pathways in cancer. Knock out of TBK1 in the contect of KRAS activation (mutant) and control (WT).

Standard name | NFE2L2.V2
Systematic name | M2870
Organism | Mus musculus
PMID | 27088724
Authors | Kim JW,Botvinnik OB,Abudayyeh O,Birger C,Rosenbluh J,Shrestha Y,Abazeed ME,Hammerman PS,DiCara D,Konieczkowski DJ,Johannessen CM,Liberzon A,Alizad-Rahvar AR,Alexe G,Aguirre A,Ghandi M,Greulich H,Vazquez F,Weir BA,Van Allen EM,Tsherniak A,Shao DD,Zack TI,Noble M,Getz G,Beroukhim R,Garraway LA,Ardakani M,Romualdi C,Sales G,Barbie DA,Boehm JS,Hahn WC,Mesirov JP,Tamayo P
Category | C6
Sub-category |
Brief description | Genes down-regulated in MEF cells (embryonic fibroblasts) after knockout of NFE2L2 [Gene ID=4780] gene.
Full description | The transcription factor NRF2 (NFE2L2), induces a cytoprotective response to oxidative stresses and its mutations confer constitutive activation in cancer. We generated a gene set representing activation of NFE2L2, as represented by genes downregulated by NFE2L2 knockout using the data from Malhotra et al. D, et al. Nucleic Acids Res. 2010;38:5718-5734.

Standard name | CORDENONSI_YAP_CONSERVED_SIGNATURE
Systematic name | M2871
Organism | Homo sapiens
PMID | 22078877
Authors | Cordenonsi M,Zanconato F,Azzolin L,Forcato M,Rosato A,Frasson C,Inui M,Montagner M,Parenti AR,Poletti A,Daidone MG,Dupont S,Basso G,Bicciato S,Piccolo S
Category | C6
Sub-category |
Brief description | YAP conserved signature.
Full description | Cancer stem cells (CSCs) are proposed to drive tumor initiation and progression. Yet, our understanding of the cellular and molecular mechanisms that underlie CSC properties is limited. Here we show that the activity of TAZ, a transducer of the Hippo pathway, is required to sustain self-renewal and tumor-initiation capacities in breast CSCs. TAZ protein levels and activity are elevated in prospective CSCs and in poorly differentiated human tumors and have prognostic value. Gain of TAZ endows self-renewal capacity to non-CSCs. In epithelial cells, TAZ forms a complex with the cell-polarity determinant Scribble, and loss of Scribble--or induction of the epithelial-mesenchymal transition (EMT)--disrupts the inhibitory association of TAZ with the core Hippo kinases MST and LATS. This study links the CSC concept to the Hippo pathway in breast cancer and reveals a mechanistic basis of the control of Hippo kinases by cell polarity

Standard name | JAK2_DN.V1_DN
Systematic name | M2872
Organism | Homo sapiens
PMID |
Authors | Ebert B
Category | C6
Sub-category |
Brief description | Genes down-regulated in HEL cells (erythroleukemia) after knockdown of JAK2 [Gene ID=3717] gene by RNAi.
Full description |

Standard name | JAK2_DN.V1_UP
Systematic name | M2873
Organism | Homo sapiens
PMID |
Authors | Ebert B
Category | C6
Sub-category |
Brief description | Genes up-regulated in HEL cells (erythroleukemia) after knockdown of JAK2 [Gene ID=3717] gene by RNAi.
Full description |

Standard name | KRAS.300_UP.V1_DN
Systematic name | M2874
Organism | Homo sapiens
PMID | 19847166
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes down-regulated in four lineages of epithelial cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description | The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. A complementary strategy for targeting KRAS is to identify gene products that, when inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkappaB kinase TBK1 was selectively essential in cells that contain mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving c-Rel and BCL-XL (also known as BCL2L1) that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations indicate that TBK1 and NF-kappaB signalling are essential in KRAS mutant tumours, and establish a general approach for the rational identification of co-dependent pathways in cancer.

Standard name | KRAS.300_UP.V1_UP
Systematic name | M2875
Organism | Homo sapiens
PMID | 19847166
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes up-regulated in four lineages of epithelial cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description | The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. A complementary strategy for targeting KRAS is to identify gene products that, when inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkappaB kinase TBK1 was selectively essential in cells that contain mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving c-Rel and BCL-XL (also known as BCL2L1) that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations indicate that TBK1 and NF-kappaB signalling are essential in KRAS mutant tumours, and establish a general approach for the rational identification of co-dependent pathways in cancer.

Standard name | KRAS.50_UP.V1_DN
Systematic name | M2876
Organism | Homo sapiens
PMID | 19847166
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes down-regulated in four lineages of epithelial cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description | The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. A complementary strategy for targeting KRAS is to identify gene products that, when inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkappaB kinase TBK1 was selectively essential in cells that contain mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving c-Rel and BCL-XL (also known as BCL2L1) that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations indicate that TBK1 and NF-kappaB signalling are essential in KRAS mutant tumours, and establish a general approach for the rational identification of co-dependent pathways in cancer.

Standard name | KRAS.50_UP.V1_UP
Systematic name | M2878
Organism | Homo sapiens
PMID | 19847166
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes up-regulated in four lineages of epithelial cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description | The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. A complementary strategy for targeting KRAS is to identify gene products that, when inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkappaB kinase TBK1 was selectively essential in cells that contain mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving c-Rel and BCL-XL (also known as BCL2L1) that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations indicate that TBK1 and NF-kappaB signalling are essential in KRAS mutant tumours, and establish a general approach for the rational identification of co-dependent pathways in cancer.

Standard name | KRAS.600_UP.V1_DN
Systematic name | M2880
Organism | Homo sapiens
PMID | 19847166
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes down-regulated in four lineages of epithelial cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description | The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. A complementary strategy for targeting KRAS is to identify gene products that, when inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkappaB kinase TBK1 was selectively essential in cells that contain mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving c-Rel and BCL-XL (also known as BCL2L1) that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations indicate that TBK1 and NF-kappaB signalling are essential in KRAS mutant tumours, and establish a general approach for the rational identification of co-dependent pathways in cancer.

Standard name | KRAS.600_UP.V1_UP
Systematic name | M2882
Organism | Homo sapiens
PMID | 19847166
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes up-regulated in four lineages of epithelial cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description | The proto-oncogene KRAS is mutated in a wide array of human cancers, most of which are aggressive and respond poorly to standard therapies. Although the identification of specific oncogenes has led to the development of clinically effective, molecularly targeted therapies in some cases, KRAS has remained refractory to this approach. A complementary strategy for targeting KRAS is to identify gene products that, when inhibited, result in cell death only in the presence of an oncogenic allele. Here we have used systematic RNA interference to detect synthetic lethal partners of oncogenic KRAS and found that the non-canonical IkappaB kinase TBK1 was selectively essential in cells that contain mutant KRAS. Suppression of TBK1 induced apoptosis specifically in human cancer cell lines that depend on oncogenic KRAS expression. In these cells, TBK1 activated NF-kappaB anti-apoptotic signals involving c-Rel and BCL-XL (also known as BCL2L1) that were essential for survival, providing mechanistic insights into this synthetic lethal interaction. These observations indicate that TBK1 and NF-kappaB signalling are essential in KRAS mutant tumours, and establish a general approach for the rational identification of co-dependent pathways in cancer.

Standard name | KRAS.600.LUNG.BREAST_UP.V1_DN
Systematic name | M2885
Organism | Homo sapiens
PMID |
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes down-regulated in epithelial lung and breast cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | KRAS.600.LUNG.BREAST_UP.V1_UP
Systematic name | M2886
Organism | Homo sapiens
PMID |
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes up-regulated in epithelial lung and breast cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | KRAS.BREAST_UP.V1_DN
Systematic name | M2887
Organism | Homo sapiens
PMID |
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes down-regulated in epithelial breast cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | KRAS.BREAST_UP.V1_UP
Systematic name | M2888
Organism | Homo sapiens
PMID |
Authors | Boehm J
Category | C6
Sub-category |
Brief description | Genes up-regulated in epithelial breast cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | KRAS.KIDNEY_UP.V1_DN
Systematic name | M2889
Organism | Homo sapiens
PMID |
Authors |
Category | C6
Sub-category |
Brief description | Genes down-regulated in epithelial kidney cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | KRAS.KIDNEY_UP.V1_UP
Systematic name | M2892
Organism | Homo sapiens
PMID |
Authors |
Category | C6
Sub-category |
Brief description | Genes up-regulated in epithelial kidney cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | KRAS.LUNG_UP.V1_DN
Systematic name | M2893
Organism | Homo sapiens
PMID |
Authors |
Category | C6
Sub-category |
Brief description | Genes down-regulated in epithelial lung cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | KRAS.LUNG_UP.V1_UP
Systematic name | M2897
Organism | Homo sapiens
PMID |
Authors |
Category | C6
Sub-category |
Brief description | Genes up-regulated in epithelial lung cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | KRAS.LUNG.BREAST_UP.V1_DN
Systematic name | M2898
Organism | Homo sapiens
PMID |
Authors |
Category | C6
Sub-category |
Brief description | Genes down-regulated in epithelial breast cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845 gene].
Full description |

Standard name | KRAS.LUNG.BREAST_UP.V1_UP
Systematic name | M2900
Organism | Homo sapiens
PMID |
Authors |
Category | C6
Sub-category |
Brief description | Genes up-regulated in epithelial lung and breast cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | KRAS.PROSTATE_UP.V1_DN
Systematic name | M2901
Organism | Homo sapiens
PMID |
Authors |
Category | C6
Sub-category |
Brief description | Genes down-regulated in epithelial prostate cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | KRAS.PROSTATE_UP.V1_UP
Systematic name | M2902
Organism | Homo sapiens
PMID |
Authors |
Category | C6
Sub-category |
Brief description | Genes up-regulated in epithelial prostate cancer cell lines over-expressing an oncogenic form of KRAS [Gene ID=3845] gene.
Full description |

Standard name | LEF1_UP.V1_DN
Systematic name | M2903
Organism | Homo sapiens
PMID |
Authors | Medici D,Hay E,Olsen B
Category | C6
Sub-category |
Brief description | Genes down-regulated in DLD1 cells (colon carcinoma) over-expressing LEF1 [Gene ID=51176].
Full description | We treated DLD1 cells with an adenoviral LEF-1 expression construct, which induced EMT within 48 hours. RNA was then extracted from these cells along with untreated DLD1 cells, then subjected to microarray analysis.

Standard name | LEF1_UP.V1_UP
Systematic name | M2905
Organism | Homo sapiens
PMID |
Authors | Medici D,Hay E,Olsen B
Category | C6
Sub-category |
Brief description | Genes up-regulated in DLD1 cells (colon carcinoma) over-expressing LEF1 [Gene ID=51176].
Full description | We treated DLD1 cells with an adenoviral LEF-1 expression construct, which induced EMT within 48 hours. RNA was then extracted from these cells along with untreated DLD1 cells, then subjected to microarray analysis.

Standard name | KAECH_NAIVE_VS_DAY8_EFF_CD8_TCELL_UP
Systematic name | M3012
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve CD8 T cells compared to effector CD8 T cells at the peak expansion phase (day 8 after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_NAIVE_VS_DAY8_EFF_CD8_TCELL_DN
Systematic name | M3013
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve CD8 T cells compared to effector CD8 T cells at the peak expansion phase (day 8 after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_NAIVE_VS_DAY15_EFF_CD8_TCELL_UP
Systematic name | M3014
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve CD8 T cells compared to effector CD8 T cells at contraction phase (day 15 after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_NAIVE_VS_DAY15_EFF_CD8_TCELL_DN
Systematic name | M3017
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve CD8 T cells compared to effector CD8 T cells at contraction phase (day 15 after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_NAIVE_VS_MEMORY_CD8_TCELL_UP
Systematic name | M3020
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve CD8 T cells compared to memory CD8 T cells (day 40+ after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_NAIVE_VS_MEMORY_CD8_TCELL_DN
Systematic name | M3022
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve CD8 T cells compared to memory CD8 T cells (day 40+ after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_DAY8_EFF_VS_DAY15_EFF_CD8_TCELL_UP
Systematic name | M3023
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in effector CD8 T cells at the peak expansion phase (day 8 after LCMV-Armstrong infection) compared to effector CD8 T cells at contraction phase (day 15 after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_DAY8_EFF_VS_DAY15_EFF_CD8_TCELL_DN
Systematic name | M3025
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in effector CD8 T cells at the peak expansion phase (day 8 after LCMV-Armstrong infection) compared to effector CD8 T cells at contraction phase (day 15 after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_DAY8_EFF_VS_MEMORY_CD8_TCELL_UP
Systematic name | M3027
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in effector CD8 T cells at the peak expansion phase (day 8 after LCMV-Armstrong infection) compared to memory CD8 T cells (day 40+ after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_DAY8_EFF_VS_MEMORY_CD8_TCELL_DN
Systematic name | M3028
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in effector CD8 T cells at the peak expansion phase (day 8 after LCMV-Armstrong infection) compared to memory CD8 T cells (day 40+ after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_DAY15_EFF_VS_MEMORY_CD8_TCELL_UP
Systematic name | M3030
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in effector CD8 T cells at contraction phase (day 15 after LCMV-Armstrong infection) compared to memory CD8 T cells (day 40+ after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | KAECH_DAY15_EFF_VS_MEMORY_CD8_TCELL_DN
Systematic name | M3032
Organism | Mus musculus
PMID | 12526810
Authors | Kaech SM,Hemby S,Kersh E,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in effector CD8 T cells at contraction phase (day 15 after LCMV-Armstrong infection) compared to memory CD8 T cells (day 40+ after LCMV-Armstrong infection).
Full description | How and when memory T cells form during an immune response are long-standing questions. To better understand memory CD8 T cell development, a time course of gene expression and functional changes in antigen-specific T cells during viral infection was evaluated. The expression of many genes continued to change after viral clearance in accordance with changes in CD8 T cell functional properties. Even though memory cell precursors were present at the peak of the immune response, these cells did not display hallmark functional traits of memory T cells. However, these cells gradually acquired the memory cell qualities of self-renewal and rapid recall to antigen suggesting the model that antigen-specific CD8 T cells progressively differentiate into memory cells following viral infection.

Standard name | GOLDRATH_NAIVE_VS_EFF_CD8_TCELL_UP
Systematic name | M3035
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naïve CD8 T cells versus effector CD8 T cells.
Full description | The only cells of the hematopoietic system that undergo self-renewal for the lifetime of the organism are long-term hematopoietic stem cells and memory T and B cells. To determine whether there is a shared transcriptional program among these self-renewing populations, we first compared the gene-expression profiles of naïve, effector and memory CD8(+) T cells with those of long-term hematopoietic stem cells, short-term hematopoietic stem cells, and lineage-committed progenitors. Transcripts augmented in memory CD8(+) T cells relative to naïve and effector T cells were selectively enriched in long-term hematopoietic stem cells and were progressively lost in their short-term and lineage-committed counterparts. Furthermore, transcripts selectively decreased in memory CD8(+) T cells were selectively down-regulated in long-term hematopoietic stem cells and progressively increased with differentiation. To confirm that this pattern was a general property of immunologic memory, we turned to independently generated gene expression profiles of memory, naïve, germinal center, and plasma B cells. Once again, memory-enriched and -depleted transcripts were also appropriately augmented and diminished in long-term hematopoietic stem cells, and their expression correlated with progressive loss of self-renewal function. Thus, there appears to be a common signature of both up- and down-regulated transcripts shared between memory T cells, memory B cells, and long-term hematopoietic stem cells. This signature was not consistently enriched in neural or embryonic stem cell populations and, therefore, appears to be restricted to the hematopoeitic system. These observations provide evidence that the shared phenotype of self-renewal in the hematopoietic system is linked at the molecular level.

Standard name | GOLDRATH_NAIVE_VS_EFF_CD8_TCELL_DN
Systematic name | M3036
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naïve CD8 T cells versus effector CD8 T cells.
Full description | The only cells of the hematopoietic system that undergo self-renewal for the lifetime of the organism are long-term hematopoietic stem cells and memory T and B cells. To determine whether there is a shared transcriptional program among these self-renewing populations, we first compared the gene-expression profiles of naïve, effector and memory CD8(+) T cells with those of long-term hematopoietic stem cells, short-term hematopoietic stem cells, and lineage-committed progenitors. Transcripts augmented in memory CD8(+) T cells relative to naïve and effector T cells were selectively enriched in long-term hematopoietic stem cells and were progressively lost in their short-term and lineage-committed counterparts. Furthermore, transcripts selectively decreased in memory CD8(+) T cells were selectively down-regulated in long-term hematopoietic stem cells and progressively increased with differentiation. To confirm that this pattern was a general property of immunologic memory, we turned to independently generated gene expression profiles of memory, naïve, germinal center, and plasma B cells. Once again, memory-enriched and -depleted transcripts were also appropriately augmented and diminished in long-term hematopoietic stem cells, and their expression correlated with progressive loss of self-renewal function. Thus, there appears to be a common signature of both up- and down-regulated transcripts shared between memory T cells, memory B cells, and long-term hematopoietic stem cells. This signature was not consistently enriched in neural or embryonic stem cell populations and, therefore, appears to be restricted to the hematopoeitic system. These observations provide evidence that the shared phenotype of self-renewal in the hematopoietic system is linked at the molecular level.

Standard name | GOLDRATH_NAIVE_VS_MEMORY_CD8_TCELL_UP
Systematic name | M3038
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus memory CD8 T cells.
Full description | The only cells of the hematopoietic system that undergo self-renewal for the lifetime of the organism are long-term hematopoietic stem cells and memory T and B cells. To determine whether there is a shared transcriptional program among these self-renewing populations, we first compared the gene-expression profiles of naïve, effector and memory CD8(+) T cells with those of long-term hematopoietic stem cells, short-term hematopoietic stem cells, and lineage-committed progenitors. Transcripts augmented in memory CD8(+) T cells relative to naïve and effector T cells were selectively enriched in long-term hematopoietic stem cells and were progressively lost in their short-term and lineage-committed counterparts. Furthermore, transcripts selectively decreased in memory CD8(+) T cells were selectively down-regulated in long-term hematopoietic stem cells and progressively increased with differentiation. To confirm that this pattern was a general property of immunologic memory, we turned to independently generated gene expression profiles of memory, naïve, germinal center, and plasma B cells. Once again, memory-enriched and -depleted transcripts were also appropriately augmented and diminished in long-term hematopoietic stem cells, and their expression correlated with progressive loss of self-renewal function. Thus, there appears to be a common signature of both up- and down-regulated transcripts shared between memory T cells, memory B cells, and long-term hematopoietic stem cells. This signature was not consistently enriched in neural or embryonic stem cell populations and, therefore, appears to be restricted to the hematopoeitic system. These observations provide evidence that the shared phenotype of self-renewal in the hematopoietic system is linked at the molecular level.

Standard name | GOLDRATH_NAIVE_VS_MEMORY_CD8_TCELL_DN
Systematic name | M3039
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus memory CD8 T cells.
Full description | The only cells of the hematopoietic system that undergo self-renewal for the lifetime of the organism are long-term hematopoietic stem cells and memory T and B cells. To determine whether there is a shared transcriptional program among these self-renewing populations, we first compared the gene-expression profiles of naïve, effector and memory CD8(+) T cells with those of long-term hematopoietic stem cells, short-term hematopoietic stem cells, and lineage-committed progenitors. Transcripts augmented in memory CD8(+) T cells relative to naïve and effector T cells were selectively enriched in long-term hematopoietic stem cells and were progressively lost in their short-term and lineage-committed counterparts. Furthermore, transcripts selectively decreased in memory CD8(+) T cells were selectively down-regulated in long-term hematopoietic stem cells and progressively increased with differentiation. To confirm that this pattern was a general property of immunologic memory, we turned to independently generated gene expression profiles of memory, naïve, germinal center, and plasma B cells. Once again, memory-enriched and -depleted transcripts were also appropriately augmented and diminished in long-term hematopoietic stem cells, and their expression correlated with progressive loss of self-renewal function. Thus, there appears to be a common signature of both up- and down-regulated transcripts shared between memory T cells, memory B cells, and long-term hematopoietic stem cells. This signature was not consistently enriched in neural or embryonic stem cell populations and, therefore, appears to be restricted to the hematopoeitic system. These observations provide evidence that the shared phenotype of self-renewal in the hematopoietic system is linked at the molecular level.

Standard name | GOLDRATH_EFF_VS_MEMORY_CD8_TCELL_UP
Systematic name | M3041
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effector CD8 T cells versus memory CD8 T cells.
Full description | The only cells of the hematopoietic system that undergo self-renewal for the lifetime of the organism are long-term hematopoietic stem cells and memory T and B cells. To determine whether there is a shared transcriptional program among these self-renewing populations, we first compared the gene-expression profiles of naïve, effector and memory CD8(+) T cells with those of long-term hematopoietic stem cells, short-term hematopoietic stem cells, and lineage-committed progenitors. Transcripts augmented in memory CD8(+) T cells relative to naïve and effector T cells were selectively enriched in long-term hematopoietic stem cells and were progressively lost in their short-term and lineage-committed counterparts. Furthermore, transcripts selectively decreased in memory CD8(+) T cells were selectively down-regulated in long-term hematopoietic stem cells and progressively increased with differentiation. To confirm that this pattern was a general property of immunologic memory, we turned to independently generated gene expression profiles of memory, naïve, germinal center, and plasma B cells. Once again, memory-enriched and -depleted transcripts were also appropriately augmented and diminished in long-term hematopoietic stem cells, and their expression correlated with progressive loss of self-renewal function. Thus, there appears to be a common signature of both up- and down-regulated transcripts shared between memory T cells, memory B cells, and long-term hematopoietic stem cells. This signature was not consistently enriched in neural or embryonic stem cell populations and, therefore, appears to be restricted to the hematopoeitic system. These observations provide evidence that the shared phenotype of self-renewal in the hematopoietic system is linked at the molecular level.

Standard name | GOLDRATH_EFF_VS_MEMORY_CD8_TCELL_DN
Systematic name | M3044
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effector CD8 T cells versus memory CD8 T cells.
Full description | The only cells of the hematopoietic system that undergo self-renewal for the lifetime of the organism are long-term hematopoietic stem cells and memory T and B cells. To determine whether there is a shared transcriptional program among these self-renewing populations, we first compared the gene-expression profiles of naïve, effector and memory CD8(+) T cells with those of long-term hematopoietic stem cells, short-term hematopoietic stem cells, and lineage-committed progenitors. Transcripts augmented in memory CD8(+) T cells relative to naïve and effector T cells were selectively enriched in long-term hematopoietic stem cells and were progressively lost in their short-term and lineage-committed counterparts. Furthermore, transcripts selectively decreased in memory CD8(+) T cells were selectively down-regulated in long-term hematopoietic stem cells and progressively increased with differentiation. To confirm that this pattern was a general property of immunologic memory, we turned to independently generated gene expression profiles of memory, naïve, germinal center, and plasma B cells. Once again, memory-enriched and -depleted transcripts were also appropriately augmented and diminished in long-term hematopoietic stem cells, and their expression correlated with progressive loss of self-renewal function. Thus, there appears to be a common signature of both up- and down-regulated transcripts shared between memory T cells, memory B cells, and long-term hematopoietic stem cells. This signature was not consistently enriched in neural or embryonic stem cell populations and, therefore, appears to be restricted to the hematopoeitic system. These observations provide evidence that the shared phenotype of self-renewal in the hematopoietic system is linked at the molecular level.

Standard name | GSE10094_LCMV_VS_LISTERIA_IND_EFF_CD4_TCELL_UP
Systematic name | M3046
Organism | Mus musculus
PMID | 18356084
Authors | Williams MA,Ravkov EV,Bevan MJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells from mice challenged with LCMV versus those challenged with Listeria-gp61.
Full description | Following infection with LCMV, CD4+ SMARTA TCR transgenic cells (specific for the gp61-80 epitope of the LCMV glycoprotein) rapidly expand, become effector cells, and go on to form a long-lived memory population. Following infection with a recombinant Listeria monocytogenes expressing the LCMV epitope gp61-80, SMARTA cells also expand but display defective effector differentiation and fail to form memory. In an attempt to understand the signals required for CD4 T cell memory differentiation, we compared gene expression by SMARTA cells at the peak of the primary response following either Lm-gp61 or LCMV infection.

Standard name | GSE10094_LCMV_VS_LISTERIA_IND_EFF_CD4_TCELL_DN
Systematic name | M3047
Organism | Mus musculus
PMID | 18356084
Authors | Williams MA,Ravkov EV,Bevan MJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells from mice challenged with LCMV versus those challenged with Listeria-gp61.
Full description | Following infection with LCMV, CD4+ SMARTA TCR transgenic cells (specific for the gp61-80 epitope of the LCMV glycoprotein) rapidly expand, become effector cells, and go on to form a long-lived memory population. Following infection with a recombinant Listeria monocytogenes expressing the LCMV epitope gp61-80, SMARTA cells also expand but display defective effector differentiation and fail to form memory. In an attempt to understand the signals required for CD4 T cell memory differentiation, we compared gene expression by SMARTA cells at the peak of the primary response following either Lm-gp61 or LCMV infection.

Standard name | GSE10239_NAIVE_VS_MEMORY_CD8_TCELL_UP
Systematic name | M3048
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus memory CD8 T cells.
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_NAIVE_VS_MEMORY_CD8_TCELL_DN
Systematic name | M3049
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus memory CD8 T cells.
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_NAIVE_VS_KLRG1INT_EFF_CD8_TCELL_UP
Systematic name | M3050
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus effector CD8 T cells KLRG1 Int [GeneID=10219].
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_NAIVE_VS_KLRG1INT_EFF_CD8_TCELL_DN
Systematic name | M3051
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus effector CD8 T cells KLRG1 Int [GeneID=10219].
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_NAIVE_VS_KLRG1HIGH_EFF_CD8_TCELL_UP
Systematic name | M3052
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus effector CD8 T cells KLRG1 high [GeneID=10219].
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_NAIVE_VS_KLRG1HIGH_EFF_CD8_TCELL_DN
Systematic name | M3054
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus effector CD8 T cells KLRG1 high [GeneID=10219].
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_MEMORY_VS_KLRG1INT_EFF_CD8_TCELL_UP
Systematic name | M3055
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells versus effector CD8 T cells KLRG1 intermediate [GeneID=10219].
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_MEMORY_VS_KLRG1INT_EFF_CD8_TCELL_DN
Systematic name | M3059
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells versus effector CD8 T cells KLRG1 intermediate [GeneID=10219].
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_MEMORY_VS_KLRG1HIGH_EFF_CD8_TCELL_UP
Systematic name | M3060
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells versus effector CD8 T cells KLRG1 high [GeneID=10219].
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_MEMORY_VS_KLRG1HIGH_EFF_CD8_TCELL_DN
Systematic name | M3067
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells versus effector CD8 T cells KLRG1 high [GeneID=10219].
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_KLRG1INT_VS_KLRG1HIGH_EFF_CD8_TCELL_UP
Systematic name | M3068
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effector CD8 T cells KRLG1 Int [GeneID=10219] vs those with KRLG1 Hi.
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_KLRG1INT_VS_KLRG1HIGH_EFF_CD8_TCELL_DN
Systematic name | M3070
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effector CD8 T cells KRLG1 Int [GeneID=10219] vs those with KRLG1 Hi.
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_NAIVE_VS_DAY4.5_EFF_CD8_TCELL_UP
Systematic name | M3071
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive vs effector CD8 T cells (4-5 days postinfection).
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_NAIVE_VS_DAY4.5_EFF_CD8_TCELL_DN
Systematic name | M3072
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive vs effector CD8 T cells (4-5 days postinfection).
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_MEMORY_VS_DAY4.5_EFF_CD8_TCELL_UP
Systematic name | M3073
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells versus effector CD8 T cells.
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10239_MEMORY_VS_DAY4.5_EFF_CD8_TCELL_DN
Systematic name | M3074
Organism | Mus musculus
PMID | 18316415
Authors | Sarkar S,Kalia V,Haining WN,Konieczny BT
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells versus effector CD8 T cells.
Full description | Using killer cell lectin-like receptor G1 as a marker to distinguish terminal effector cells from memory precursors, we found that despite their diverse cell fates both subsets possessed remarkably similar gene expression profiles and functioned as equally potent killer cells. However, only the memory precursors were capable of making IL-2 thus defining a novel effector cell that was cytotoxic, expressed granzyme B, and produced inflammatory cytokines in addition to IL-2. This effector population then differentiated into long-lived protective memory T cells capable of self-renewal and rapid re-call responses. Mechanistic studies showed that cells that continued to receive antigenic stimulation during the later stages of infection were more likely to become terminal effectors. Importantly, curtailing antigenic stimulation towards the tail-end of the acute infection enhanced the generation of memory cells. These studies support the decreasing potential model of memory differentiation and show that the duration of antigenic stimulation is a critical regulator of memory formation

Standard name | GSE10325_CD4_TCELL_VS_BCELL_UP
Systematic name | M3076
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of healthy CD4 [GeneID=920] T cells versus healthy CD19 [GeneID=920] B cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_CD4_TCELL_VS_BCELL_DN
Systematic name | M3077
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of healthy CD4 [GeneID=920] T cells versus healthy CD19 [GeneID=920] B cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_CD4_TCELL_VS_MYELOID_UP
Systematic name | M3078
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of healthy CD4 [GeneID=920] T cells versus healthy myeloid cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_CD4_TCELL_VS_MYELOID_DN
Systematic name | M3079
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of healthy CD4 [GeneID=920] T cells versus healthy myeloid cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_BCELL_VS_MYELOID_UP
Systematic name | M3081
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of healthy B cells versus healthy myeloid cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_BCELL_VS_MYELOID_DN
Systematic name | M3082
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of healthy B cells versus healthy myeloid cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_LUPUS_CD4_TCELL_VS_LUPUS_BCELL_UP
Systematic name | M3084
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of systemic lupus erythematosus CD4 [GeneID=920] T cells versus systemic lupus erythematosus B cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_LUPUS_CD4_TCELL_VS_LUPUS_BCELL_DN
Systematic name | M3085
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of systemic lupus erythematosus CD4 [GeneID=920] T cells versus systemic lupus erythematosus B cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_LUPUS_CD4_TCELL_VS_LUPUS_MYELOID_UP
Systematic name | M3087
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of systemic lupus erythematosus CD4 [GeneID=920] T cells versus systemic lupus erythematosus myeloid cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_LUPUS_CD4_TCELL_VS_LUPUS_MYELOID_DN
Systematic name | M3088
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of systemic lupus erythematosus CD4 [GeneID=920] T cells versus systemic lupus erythematosus myeloid cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_LUPUS_BCELL_VS_LUPUS_MYELOID_UP
Systematic name | M3089
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of systemic lupus erythematosus B cells versus systemic lupus erythromatosus myeloid cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_LUPUS_BCELL_VS_LUPUS_MYELOID_DN
Systematic name | M3091
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of systemic lupus erythematosus B cells versus systemic lupus erythromatosus myeloid cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_CD4_TCELL_VS_LUPUS_CD4_TCELL_UP
Systematic name | M3092
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of healthy CD4 [GeneID=920] T cells versus systemic lupus erythematosus CD4 [GeneID=920] T cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_CD4_TCELL_VS_LUPUS_CD4_TCELL_DN
Systematic name | M3093
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of healthy CD4 [GeneID=920] T cells versus systemic lupus erythematosus CD4 [GeneID=920] T cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_BCELL_VS_LUPUS_BCELL_UP
Systematic name | M3094
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of healthy B cells versus systemic lupus erythematosus B cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_BCELL_VS_LUPUS_BCELL_DN
Systematic name | M3095
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of healthy B cells versus systemic lupus erythematosus B cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_MYELOID_VS_LUPUS_MYELOID_UP
Systematic name | M3096
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of healthy myeloid cells versus systemic lupus erythematosus myeloid cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10325_MYELOID_VS_LUPUS_MYELOID_DN
Systematic name | M3097
Organism | Homo sapiens
PMID | 18275831
Authors | Hutcheson J,Scatizzi JC,Siddiqui AM,Haines GK 3rd,Wu T,Li QZ,Davis LS,Mohan C,Perlman H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of healthy myeloid cells versus systemic lupus erythematosus myeloid cells.
Full description | Gene expression profile studies have identified an interferon signature in whole blood or mononuclear cell samples from patients with systemic lupus erythematosus. This study was designed to determine whether specific lymphocyte and myeloid subsets freshly isolated from the blood of systemic lupus erythematosus patients demonstrated unique gene expression profiles compared to subsets isolated from healthy controls.

Standard name | GSE10463_CD40L_AND_VA347_VS_CD40L_IN_DC_UP
Systematic name | M3098
Organism | Homo sapiens
PMID | 18270326
Authors | Lawrence BP,Denison MS,Novak H,Vorderstrasse BA,Harrer N,Neruda W,Reichel C,Woisetschläger M
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells activated in the absense of VAF347 [PubChem=10172275] versus those activated in the presence of VAF347 [PubChem=10172275].
Full description | VAF347 is a low molecular weight compound which inhibits allergic lung inflammation in vivo. This effect is likely due to a block of dendritic cell (DC) function to generate pro-inflammatory T-helper (Th) cells since VAF347 inhibits IL-6, CD86 and HLA-DR expression by human monocyte derived DC, three relevant molecules for Th-cell generation. Here we demonstrate that VAF347 interacts with the aryl hydrocarbon receptor (AhR) protein resulting in activation of the AhR signaling pathway. Functional AhR is responsible for the biological activity of VAF347 since, i) other AhR agonists display an identical activity profile in vitro, ii) gene silencing of wild type AhR expression or forced over-expression of a trans-dominant negative AhR ablates VAF347 activity to inhibit cytokine induced IL-6 expression in a human monocytic cell line and iii) AhR deficient mice are resistant to the compound’s ability to block allergic lung inflammation in vivo. These data identify the AhR protein as key molecular target of VAF347 and its essential role for mediating the anti-inflammatory effects of the compound in vitro and in vivo.

Standard name | GSE10463_CD40L_AND_VA347_VS_CD40L_IN_DC_DN
Systematic name | M3099
Organism | Homo sapiens
PMID | 18270326
Authors | Lawrence BP,Denison MS,Novak H,Vorderstrasse BA,Harrer N,Neruda W,Reichel C,Woisetschläger M
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells activated in the absense of VAF347 [PubChem=10172275] versus those activated in the presence of VAF347 [PubChem=10172275].
Full description | VAF347 is a low molecular weight compound which inhibits allergic lung inflammation in vivo. This effect is likely due to a block of dendritic cell (DC) function to generate pro-inflammatory T-helper (Th) cells since VAF347 inhibits IL-6, CD86 and HLA-DR expression by human monocyte derived DC, three relevant molecules for Th-cell generation. Here we demonstrate that VAF347 interacts with the aryl hydrocarbon receptor (AhR) protein resulting in activation of the AhR signaling pathway. Functional AhR is responsible for the biological activity of VAF347 since, i) other AhR agonists display an identical activity profile in vitro, ii) gene silencing of wild type AhR expression or forced over-expression of a trans-dominant negative AhR ablates VAF347 activity to inhibit cytokine induced IL-6 expression in a human monocytic cell line and iii) AhR deficient mice are resistant to the compound’s ability to block allergic lung inflammation in vivo. These data identify the AhR protein as key molecular target of VAF347 and its essential role for mediating the anti-inflammatory effects of the compound in vitro and in vivo.

Standard name | GSE10856_CTRL_VS_TNFRSF6B_IN_MACROPHAGE_UP
Systematic name | M3100
Organism | Homo sapiens
PMID | 18349319
Authors | Chang YC,Chen TC,Lee CT,Yang CY,Wang HW,Wang CC,Hsieh SL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages treated with control (hIgG1) versus those treated with TNFRSF6B [GeneID=8771].
Full description | Decoy receptor 3 (DcR3) is a member of the TNF receptor superfamily and is up-regulated in tumors that originate from a diversity of lineages. DcR3 is capable of promoting angiogenesis, inducing dendritic cell apoptosis, and modulating macrophage differentiation. Since tumor-associated macrophages (TAMs) are the major infiltrating leukocytes in most malignant tumors, we used microarray technology to investigate whether DcR3 contributes to the development of TAMs. Among the DcR3-modulated genes expressed by TAMs, those that encode proteins involved in MHC class II (MHC-II)-dependent antigen presentation were down-regulated substantially, together with the master regulator of MHC-II expression (the class II transactivator, CIITA). The ERK- and JNK-induced deacetylation of histones associated with the CIITA promoters was responsible for DcR3-mediated down-regulation of MHC-II expression. Furthermore, the expression level of DcR3 in cancer cells correlated inversely with HLA-DR levels on TAMs and with the overall survival time of pancreatic cancer patients. The role of DcR3 in the development of TAMs was further confirmed using transgenic mice over-expressing DcR3. This elucidates the molecular mechanism of impaired MHC-II-mediated antigen presentation by TAMs, and raises the possibility that subversion of TAM-induced immunosuppression via inhibition of DcR3 expression might represent a target for the design of new therapeutics.

Standard name | GSE10856_CTRL_VS_TNFRSF6B_IN_MACROPHAGE_DN
Systematic name | M3101
Organism | Homo sapiens
PMID | 18349319
Authors | Chang YC,Chen TC,Lee CT,Yang CY,Wang HW,Wang CC,Hsieh SL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages treated with control (hIgG1) versus those treated with TNFRSF6B [GeneID=8771].
Full description | Decoy receptor 3 (DcR3) is a member of the TNF receptor superfamily and is up-regulated in tumors that originate from a diversity of lineages. DcR3 is capable of promoting angiogenesis, inducing dendritic cell apoptosis, and modulating macrophage differentiation. Since tumor-associated macrophages (TAMs) are the major infiltrating leukocytes in most malignant tumors, we used microarray technology to investigate whether DcR3 contributes to the development of TAMs. Among the DcR3-modulated genes expressed by TAMs, those that encode proteins involved in MHC class II (MHC-II)-dependent antigen presentation were down-regulated substantially, together with the master regulator of MHC-II expression (the class II transactivator, CIITA). The ERK- and JNK-induced deacetylation of histones associated with the CIITA promoters was responsible for DcR3-mediated down-regulation of MHC-II expression. Furthermore, the expression level of DcR3 in cancer cells correlated inversely with HLA-DR levels on TAMs and with the overall survival time of pancreatic cancer patients. The role of DcR3 in the development of TAMs was further confirmed using transgenic mice over-expressing DcR3. This elucidates the molecular mechanism of impaired MHC-II-mediated antigen presentation by TAMs, and raises the possibility that subversion of TAM-induced immunosuppression via inhibition of DcR3 expression might represent a target for the design of new therapeutics.

Standard name | GSE11057_NAIVE_VS_EFF_MEMORY_CD4_TCELL_UP
Systematic name | M3104
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive T cells versus effector memory T cells.
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_NAIVE_VS_EFF_MEMORY_CD4_TCELL_DN
Systematic name | M3105
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive T cells versus effector memory T cells.
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_NAIVE_VS_CENT_MEMORY_CD4_TCELL_UP
Systematic name | M3106
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive T cells versus central memory T cells.
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_NAIVE_VS_CENT_MEMORY_CD4_TCELL_DN
Systematic name | M3107
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive T cells versus central memory T cells.
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_NAIVE_CD4_VS_PBMC_CD4_TCELL_UP
Systematic name | M3108
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive T cells versus peripheral blood mononuclear cells (PBMC).
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_NAIVE_CD4_VS_PBMC_CD4_TCELL_DN
Systematic name | M3110
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive T cells versus peripheral blood mononuclear cells (PBMC).
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_EFF_MEM_VS_CENT_MEM_CD4_TCELL_UP
Systematic name | M3111
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effector memory T cells versus central memory T cells from peripheral blood mononuclear cells (PBMC).
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_EFF_MEM_VS_CENT_MEM_CD4_TCELL_DN
Systematic name | M3112
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effector memory T cells versus central memory T cells from peripheral blood mononuclear cells (PBMC).
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_CD4_EFF_MEM_VS_PBMC_UP
Systematic name | M3113
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effector memory T cells versus peripheral blood mononuclear cells (PBMC).
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_CD4_EFF_MEM_VS_PBMC_DN
Systematic name | M3114
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comarison of effector memory T cells versus peripheral blood mononuclear cells (PBMC).
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_CD4_CENT_MEM_VS_PBMC_UP
Systematic name | M3116
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of central memory T cells versus peripheral blood mononuclear cells (PBMC).
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_CD4_CENT_MEM_VS_PBMC_DN
Systematic name | M3117
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of central memory T cells versus peripheral blood mononuclear cells (PBMC).
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_NAIVE_VS_MEMORY_CD4_TCELL_UP
Systematic name | M3118
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive T cells versus memory T cells.
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_NAIVE_VS_MEMORY_CD4_TCELL_DN
Systematic name | M3119
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive T cells versus memory T cells.
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_PBMC_VS_MEM_CD4_TCELL_UP
Systematic name | M3120
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral mononuclear blood cells (PBMC) versus memory T cells.
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11057_PBMC_VS_MEM_CD4_TCELL_DN
Systematic name | M3121
Organism | Homo sapiens
PMID | 19568420
Authors | Abbas AR,Wolslegel K,Seshasayee D,Modrusan Z,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral mononuclear blood cells (PBMC) versus memory T cells.
Full description | Microarray deconvolution is a technique for quantifying the relative abundance of constituent cells in a mixture based on that mixture's microarray signature and the signatures of the purified constituents. It has been applied to yeast and other systems but not to blood samples. Here we test the ability of this technique to determine the fractions of subsets of memory T cells in peripheral blood mononuclear cell (PBMC) samples.

Standard name | GSE11864_UNTREATED_VS_CSF1_IN_MAC_UP
Systematic name | M3122
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages versus those cultured with M-CSF [GeneID=1435].
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_UNTREATED_VS_CSF1_IN_MAC_DN
Systematic name | M3123
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages versus those cultured with M-CSF [GeneID=1435].
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_UNTREATED_VS_CSF1_IFNG_IN_MAC_UP
Systematic name | M3124
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages versus those cultured with M-CSF [GeneID=1435] and IFNG [GeneID=3458].
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_UNTREATED_VS_CSF1_IFNG_IN_MAC_DN
Systematic name | M3127
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages versus those cultured with M-CSF [GeneID=1435] and IFNG [GeneID=3458].
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_UNTREATED_VS_CSF1_PAM3CYS_IN_MAC_UP
Systematic name | M3129
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages versus those cultured with M-CSF [GeneID=1435] and Pam3Cys (TLR2 agonist).
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_UNTREATED_VS_CSF1_PAM3CYS_IN_MAC_DN
Systematic name | M3130
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages versus those cultured with M-CSF [GeneID=1435] and Pam3Cys (TLR2 agonist).
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_UNTREATED_VS_CSF1_IFNG_PAM3CYS_IN_MAC_UP
Systematic name | M3131
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages versus those cultured with M-CSF [GeneID=1435], IFNG [GeneID=3458] and Pam3Cys (TLR2 agonist).
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_UNTREATED_VS_CSF1_IFNG_PAM3CYS_IN_MAC_DN
Systematic name | M3132
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages versus those cultured with M-CSF [GeneID=1435], IFNG [GeneID=3458] and Pam3Cys (TLR2 agonist).
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_VS_CSF1_IFNG_IN_MAC_UP
Systematic name | M3133
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] versus macrophages cultured with M-CSF [GeneID=1435] and IFNG [GeneID=3458].
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_VS_CSF1_IFNG_IN_MAC_DN
Systematic name | M3135
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] versus macrophages cultured with M-CSF [GeneID=1435] and IFNG [GeneID=3458].
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_VS_CSF1_PAM3CYS_IN_MAC_UP
Systematic name | M3136
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] versus macrophages cultured with M-CSF [GeneID=1435] and Pam3Cyc.
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_VS_CSF1_PAM3CYS_IN_MAC_DN
Systematic name | M3137
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages cultured with M-CSF[GeneID=1435] versus macrophages cultured with M-CSF [GeneID=1435] and Pam3Cyc.
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_VS_CSF1_IFNG_PAM3CYS_IN_MAC_UP
Systematic name | M3138
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] versus macrophages cultured with M-CSF [GeneID=1435], IFNG [GeneID=3458] and Pam3Cyc.
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_VS_CSF1_IFNG_PAM3CYS_IN_MAC_DN
Systematic name | M3140
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] versus macrophages cultured with M-CSF [GeneID=1435], IFNG [GeneID=3458] and Pam3Cyc.
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_IFNG_VS_CSF1_PAM3CYS_IN_MAC_UP
Systematic name | M3142
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] and IFNG [GeneID=3458] versus macrophages cultured with M-CSF [GeneID=1435] and Pam3Cyc.
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_IFNG_VS_CSF1_PAM3CYS_IN_MAC_DN
Systematic name | M3143
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] and IFNG [GeneID=3458] versus macrophages cultured with M-CSF [GeneID=1435] and Pam3Cyc.
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_IFNG_VS_CSF1_IFNG_PAM3CYS_IN_MAC_UP
Systematic name | M3144
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] and IFNG [GeneID=3458] versus macrophages cultured with M-CSF [GeneID=1435], IFNG [GeneID=3458] and Pam3Cys (TLR2 agonist).
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_IFNG_VS_CSF1_IFNG_PAM3CYS_IN_MAC_DN
Systematic name | M3145
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] and IFNG [GeneID=3458] versus macrophages cultured with M-CSF [GeneID=1435], IFNG [GeneID=3458] and Pam3Cys (TLR2 agonist).
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_PAM3CYS_VS_CSF1_IFNG_PAM3CYS_IN_MAC_UP
Systematic name | M3148
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] and Pam3Cyc versus macrophages cultured with M-CSF [GeneID=1435], IFNG [GeneID=3458] and Pam3Cyc.
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11864_CSF1_PAM3CYS_VS_CSF1_IFNG_PAM3CYS_IN_MAC_DN
Systematic name | M3149
Organism | Homo sapiens
PMID | 18976936
Authors | Hu X,Chung AY,Wu I,Foldi J,Chen J,Ji JD,Tateya T,Kang YJ,Han J,Gessler M,Kageyama R,Ivashkiv LB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages cultured with M-CSF [GeneID=1435] and Pam3Cyc versus macrophages cultured with M-CSF [GeneID=1435], IFNG [GeneID=3458] and Pam3Cyc.
Full description | Gene expression analysis of freshly isolated CD14+ human monocytes and monocytes cultured in the presence or absence of interferon (IFN) -gamma for 24 h and then stimulated with Pam3Cys, a Toll-like receptor (TLR) 2 ligand, for 6 h. Results provide insight into mechanisms by which IFN-gamma reprograms early macrophage differentiation and subsequent response to TLR ligands.

Standard name | GSE11924_TFH_VS_TH1_CD4_TCELL_UP
Systematic name | M3151
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of T follicular helper (Tfh) cells versus Th1 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TFH_VS_TH1_CD4_TCELL_DN
Systematic name | M3152
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of T follicular helper (Tfh) cells versus Th1 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TFH_VS_TH2_CD4_TCELL_UP
Systematic name | M3153
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of T follicular helper (Tfh) cells versus Th2 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TFH_VS_TH2_CD4_TCELL_DN
Systematic name | M3154
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of T follicular helper (Tfh) cells versus Th2 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TFH_VS_TH17_CD4_TCELL_UP
Systematic name | M3156
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of T follicular helper (Tfh) cells versus Th17 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TFH_VS_TH17_CD4_TCELL_DN
Systematic name | M3157
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of T follicular helper (Tfh) cells versus Th17 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TH1_VS_TH2_CD4_TCELL_UP
Systematic name | M3159
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th1 cells versus Th2 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TH1_VS_TH2_CD4_TCELL_DN
Systematic name | M3160
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th1 cells versus Th2 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TH1_VS_TH17_CD4_TCELL_UP
Systematic name | M3161
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th1 cells versus Th17 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TH1_VS_TH17_CD4_TCELL_DN
Systematic name | M3163
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th1 cells versus Th17 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TH2_VS_TH17_CD4_TCELL_UP
Systematic name | M3164
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th2 cells versus Th17 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE11924_TH2_VS_TH17_CD4_TCELL_DN
Systematic name | M3165
Organism | Mus musculus
PMID | 18599325
Authors | Nurieva RI,Chung Y,Hwang D,Yang XO,Kang HS,Ma L,Wang YH,Watowich SS,Jetten AM,Tian Q,Dong C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th2 cells versus Th17 cells.
Full description | After activation, CD4+ helper T (Th) cells differentiate into distinct effector subsets. Although chemokine (C-X-C motif) receptor 5-expressing T follicular helper (Tfh) cells are important in humoral immunity, their developmental regulation is unclear. Here we show that Tfh cells had a distinct gene expression profile and developed in vivo independently of the Th1 or Th2 cell lineages. Tfh cell generation was regulated by ICOS ligand (ICOSL) expressed on B cells and was dependent on interleukin-21 (IL-21), IL-6, and signal transducer and activator of transcription 3. However, unlike Th17 cells, differentiation of Tfh cells did not require transforming growth factor b (TGF-b) or Th17-specific orphan nuclear receptors RORa and RORg in vivo. Finally, naive T cells activated in vitro in the presence of IL-21 but not TGF-b signaling preferentially acquired Tfh gene expression and promoted germinal-center reactions in vivo. This study thus demonstrates that Tfh is a distinct Th cell lineage.

Standard name | GSE12366_GC_BCELL_VS_PLASMA_CELL_UP
Systematic name | M3166
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of germinal center B cells versus plasma cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_GC_BCELL_VS_PLASMA_CELL_DN
Systematic name | M3167
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of germinal center B cells versus plasma cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_GC_VS_NAIVE_BCELL_UP
Systematic name | M3168
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of germinal center B cells versus naive B cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_GC_VS_NAIVE_BCELL_DN
Systematic name | M3170
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of germinal center B cells versus naive B cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_GC_VS_MEMORY_BCELL_UP
Systematic name | M3171
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of germinal center B cells versus memory B cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_GC_VS_MEMORY_BCELL_DN
Systematic name | M3173
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of germinal center B cells versus memory B cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_PLASMA_CELL_VS_NAIVE_BCELL_UP
Systematic name | M3174
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasma cells versus naive B cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_PLASMA_CELL_VS_NAIVE_BCELL_DN
Systematic name | M3175
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasma cells versus naive B cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_PLASMA_CELL_VS_MEMORY_BCELL_UP
Systematic name | M3176
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasma cells versus memory B cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_PLASMA_CELL_VS_MEMORY_BCELL_DN
Systematic name | M3177
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasma cells versus memory B cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_NAIVE_VS_MEMORY_BCELL_UP
Systematic name | M3178
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus memory B cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12366_NAIVE_VS_MEMORY_BCELL_DN
Systematic name | M3181
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus memory B cells.
Full description | Sorted B cells using flow cytometry. CD19 selected B cells were sorted using flow cytometry.

Standard name | GSE12845_IGD_POS_VS_NEG_BLOOD_BCELL_UP
Systematic name | M3182
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of IgD+ B cells versus IgD- B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_POS_VS_NEG_BLOOD_BCELL_DN
Systematic name | M3183
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of IgD+ B cells versus IgD- B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_POS_BLOOD_VS_NAIVE_TONSIL_BCELL_UP
Systematic name | M3184
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of IgD+ peripheral blood B cells versus IgD- naive tonsil B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_POS_BLOOD_VS_NAIVE_TONSIL_BCELL_DN
Systematic name | M3186
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of IgD+ peripheral blood B cells versus IgD- naive tonsil B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_POS_BLOOD_VS_PRE_GC_TONSIL_BCELL_UP
Systematic name | M3187
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of IgD+ B cells from peripheral blood versus CD19 pre-germinal center tonsil B cell
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_POS_BLOOD_VS_PRE_GC_TONSIL_BCELL_DN
Systematic name | M3188
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of IgD+ B cells from peripheral blood versus CD19 pre-germinal center tonsil B cell
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_POS_BLOOD_VS_DARKZONE_GC_TONSIL_BCELL_UP
Systematic name | M3189
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of IgD+ peripheral blood B cells versus dark zone germincal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_POS_BLOOD_VS_DARKZONE_GC_TONSIL_BCELL_DN
Systematic name | M3191
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of IgD+ peripheral blood B cells versus dark zone germincal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_NEG_BLOOD_VS_NAIVE_TONSIL_BCELL_UP
Systematic name | M3192
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of IgD- peripheral blood B cells versus dark zone germinal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_NEG_BLOOD_VS_NAIVE_TONSIL_BCELL_DN
Systematic name | M3193
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of IgD- peripheral blood B cells versus dark zone germinal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_NEG_BLOOD_VS_PRE_GC_TONSIL_BCELL_UP
Systematic name | M3194
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of IgD- peripheral blood B cells versus pre-germinal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_NEG_BLOOD_VS_PRE_GC_TONSIL_BCELL_DN
Systematic name | M3195
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of IgD- peripheral blood B cells versus pre-germinal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_NEG_BLOOD_VS_DARKZONE_GC_TONSIL_BCELL_UP
Systematic name | M3196
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of IgD- peripheral blood B cells versus dark zone germinal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_IGD_NEG_BLOOD_VS_DARKZONE_GC_TONSIL_BCELL_DN
Systematic name | M3197
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of IgD- peripheral blood B cells versus dark zone germinal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_NAIVE_VS_PRE_GC_TONSIL_BCELL_UP
Systematic name | M3198
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cell versus pre-germinal tonsil B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_NAIVE_VS_PRE_GC_TONSIL_BCELL_DN
Systematic name | M3199
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cell versus pre-germinal tonsil B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_NAIVE_VS_DARKZONE_GC_TONSIL_BCELL_UP
Systematic name | M3200
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cell versus dark zone germinal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_NAIVE_VS_DARKZONE_GC_TONSIL_BCELL_DN
Systematic name | M3202
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cell versus dark zone germinal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_PRE_GC_VS_DARKZONE_GC_TONSIL_BCELL_UP
Systematic name | M3203
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of pre-germinal center B cells versus dark zone germinal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE12845_PRE_GC_VS_DARKZONE_GC_TONSIL_BCELL_DN
Systematic name | M3204
Organism | Homo sapiens
PMID | 19023113
Authors | Longo NS,Lugar PL,Yavuz S,Zhang W,Krijger PH,Russ DE,Jima DD,Dave SS,Grammer AC,Lipsky PE.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of pre-germinal center B cells versus dark zone germinal center B cells.
Full description | B cells from human tonsil and blood were sorted using flow cytometry. The human samples were processed immediately ex-vivo using markers for known B cell subsets.

Standard name | GSE13229_IMM_VS_MATURE_NKCELL_UP
Systematic name | M3205
Organism | Mus musculus
PMID | 19234143
Authors | Chiossone L,Chaix J,Fuseri N,Roth C,Vivier E,Walzer T.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of immature NK cells versus mature NK cells.
Full description | Previous reports have defined three subsets of mouse NK cells on the basis of the expression of CD27 and CD11b. The developmental relationship between these subsets was unclear. To address this issue, we evaluated the overall proximity between mouse NK cell subsets defined by CD27 and CD11b expression using pangenomic gene expression profiling. The results suggest that CD27+CD11b-, CD27+CD11b+ and CD27-CD11b+ correspond to three different intermediates stages of NK cell development.

Standard name | GSE13229_IMM_VS_MATURE_NKCELL_DN
Systematic name | M3207
Organism | Mus musculus
PMID | 19234143
Authors | Chiossone L,Chaix J,Fuseri N,Roth C,Vivier E,Walzer T.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of immature NK cells versus mature NK cells.
Full description | Previous reports have defined three subsets of mouse NK cells on the basis of the expression of CD27 and CD11b. The developmental relationship between these subsets was unclear. To address this issue, we evaluated the overall proximity between mouse NK cell subsets defined by CD27 and CD11b expression using pangenomic gene expression profiling. The results suggest that CD27+CD11b-, CD27+CD11b+ and CD27-CD11b+ correspond to three different intermediates stages of NK cell development.

Standard name | GSE13229_IMM_VS_INTMATURE_NKCELL_UP
Systematic name | M3209
Organism | Mus musculus
PMID | 19234143
Authors | Chiossone L,Chaix J,Fuseri N,Roth C,Vivier E,Walzer T.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of immature NK cells versus intermediate mature NK cells.
Full description | Previous reports have defined three subsets of mouse NK cells on the basis of the expression of CD27 and CD11b. The developmental relationship between these subsets was unclear. To address this issue, we evaluated the overall proximity between mouse NK cell subsets defined by CD27 and CD11b expression using pangenomic gene expression profiling. The results suggest that CD27+CD11b-, CD27+CD11b+ and CD27-CD11b+ correspond to three different intermediates stages of NK cell development.

Standard name | GSE13229_IMM_VS_INTMATURE_NKCELL_DN
Systematic name | M3212
Organism | Mus musculus
PMID | 19234143
Authors | Chiossone L,Chaix J,Fuseri N,Roth C,Vivier E,Walzer T.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of immature NK cells versus intermediate mature NK cells.
Full description | Previous reports have defined three subsets of mouse NK cells on the basis of the expression of CD27 and CD11b. The developmental relationship between these subsets was unclear. To address this issue, we evaluated the overall proximity between mouse NK cell subsets defined by CD27 and CD11b expression using pangenomic gene expression profiling. The results suggest that CD27+CD11b-, CD27+CD11b+ and CD27-CD11b+ correspond to three different intermediates stages of NK cell development.

Standard name | GSE13229_MATURE_VS_INTMATURE_NKCELL_UP
Systematic name | M3213
Organism | Mus musculus
PMID | 19234143
Authors | Chiossone L,Chaix J,Fuseri N,Roth C,Vivier E,Walzer T.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mature NK cells versus intermediate mature KN cells.
Full description | Previous reports have defined three subsets of mouse NK cells on the basis of the expression of CD27 and CD11b. The developmental relationship between these subsets was unclear. To address this issue, we evaluated the overall proximity between mouse NK cell subsets defined by CD27 and CD11b expression using pangenomic gene expression profiling. The results suggest that CD27+CD11b-, CD27+CD11b+ and CD27-CD11b+ correspond to three different intermediates stages of NK cell development.

Standard name | GSE13229_MATURE_VS_INTMATURE_NKCELL_DN
Systematic name | M3216
Organism | Mus musculus
PMID | 19234143
Authors | Chiossone L,Chaix J,Fuseri N,Roth C,Vivier E,Walzer T.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mature NK cells versus intermediate mature KN cells.
Full description | Previous reports have defined three subsets of mouse NK cells on the basis of the expression of CD27 and CD11b. The developmental relationship between these subsets was unclear. To address this issue, we evaluated the overall proximity between mouse NK cell subsets defined by CD27 and CD11b expression using pangenomic gene expression profiling. The results suggest that CD27+CD11b-, CD27+CD11b+ and CD27-CD11b+ correspond to three different intermediates stages of NK cell development.

Standard name | GSE13306_LAMINA_PROPRIA_VS_SPLEEN_TREG_UP
Systematic name | M3217
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells activated with lamina propria dendritic cells versus regulatory T cell (Treg).
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_LAMINA_PROPRIA_VS_SPLEEN_TREG_DN
Systematic name | M3219
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells activated with lamina propria dendritic cells versus regulatory T cell (Treg).
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_TREG_VS_TCONV_LAMINA_PROPRIA_UP
Systematic name | M3220
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) versus conventional T cells activated with lamina propria dendritic cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_TREG_VS_TCONV_LAMINA_PROPRIA_DN
Systematic name | M3222
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) versus conventional T cells activated with lamina propria dendritic cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_TREG_VS_TCONV_SPLEEN_UP
Systematic name | M3224
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) versus conventional T cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_TREG_VS_TCONV_SPLEEN_DN
Systematic name | M3225
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) versus conventional T cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_TREG_RA_VS_TCONV_RA_UP
Systematic name | M3226
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in regulatory T cell (Treg) treated with retinoic acid (tretinoin) [PubChem=444795] versus conventional T cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_TREG_RA_VS_TCONV_RA_DN
Systematic name | M3227
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in regulatory T cell (Treg) treated with retinoic acid (tretinoin) [PubChem=444795] versus conventional T cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_TREG_VS_TCONV_UP
Systematic name | M3229
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in regulatory T cell (Treg) versus conventional T cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_TREG_VS_TCONV_DN
Systematic name | M3230
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in regulatory T cell (Treg) versus conventional T cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_RA_VS_UNTREATED_TREG_UP
Systematic name | M3232
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) treated with retinoic acid (tretinoin) [PubChem=444795] versus untreated regulatory T cell (Treg).
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_RA_VS_UNTREATED_TREG_DN
Systematic name | M3233
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) treated with retinoic acid (tretinoin) [PubChem=444795] versus untreated regulatory T cell (Treg).
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_RA_VS_UNTREATED_TCONV_UP
Systematic name | M3234
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of conventional T cells treated with retinoic acid (tretinoin) [PubChem=444795] versus untreated conventional T cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_RA_VS_UNTREATED_TCONV_DN
Systematic name | M3235
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of conventional T cells treated with retinoic acid (tretinoin) [PubChem=444795] versus untreated conventional T cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_RA_VS_UNTREATED_MEM_CD4_TCELL_UP
Systematic name | M3236
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD4 [GeneID=920] T cells treated with retinoic acid (tretinoin) [PubChem=444795] versus untreated memory CD4 [GeneID=920] T cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13306_RA_VS_UNTREATED_MEM_CD4_TCELL_DN
Systematic name | M3237
Organism | Mus musculus
PMID | 19006694
Authors | Hill JA,Hall JA,Sun CM,Cai Q,Ghyselinck N,Chambon P,Belkaid Y,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD4 [GeneID=920] T cells treated with retinoic acid (tretinoin) [PubChem=444795] versus untreated memory CD4 [GeneID=920] T cells.
Full description | CD4(+)Foxp3(+) regulatory T (Treg) cells originate primarily from thymic differentiation, but conversion of mature T lymphocytes to Foxp3 positivity can be elicited by several means, including in vitro activation in the presence of TGF-beta. Retinoic acid (RA) increases TGF-beta-induced expression of Foxp3, through unknown molecular mechanisms. We showed here that, rather than enhancing TGF-beta signaling directly in naive CD4(+) T cells, RA negatively regulated an accompanying population of CD4(+) T cells with a CD44(hi) memory and effector phenotype. These memory cells actively inhibited the TGF-beta-induced conversion of naive CD4(+) T cells through the synthesis of a set of cytokines (IL-4, IL-21, IFN-gamma) whose expression was coordinately curtailed by RA. This indirect effect was evident in vivo and required the expression of the RA receptor alpha. Thus, cytokine-producing CD44(hi) cells actively restrain TGF-beta-mediated Foxp3 expression in naive T cells, and this balance can be shifted or fine-tuned by RA.

Standard name | GSE13411_NAIVE_VS_IGM_MEMORY_BCELL_UP
Systematic name | M3239
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus IgM-memory B cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_NAIVE_VS_IGM_MEMORY_BCELL_DN
Systematic name | M3240
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus IgM-memory B cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_NAIVE_VS_SWITCHED_MEMORY_BCELL_UP
Systematic name | M3241
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus Ig isotype switched memory B cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_NAIVE_VS_SWITCHED_MEMORY_BCELL_DN
Systematic name | M3242
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus Ig isotype switched memory B cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_NAIVE_BCELL_VS_PLASMA_CELL_UP
Systematic name | M3243
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus plasma cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_NAIVE_BCELL_VS_PLASMA_CELL_DN
Systematic name | M3244
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus plasma cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_NAIVE_VS_MEMORY_BCELL_UP
Systematic name | M3245
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus memory B cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_NAIVE_VS_MEMORY_BCELL_DN
Systematic name | M3246
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus memory B cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_IGM_VS_SWITCHED_MEMORY_BCELL_UP
Systematic name | M3247
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of IgM-memory B cells versus Ig isotype switched memory B cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_IGM_VS_SWITCHED_MEMORY_BCELL_DN
Systematic name | M3248
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of IgM-memory B cells versus Ig isotype switched memory B cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_IGM_MEMORY_BCELL_VS_PLASMA_CELL_UP
Systematic name | M3249
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of IgM-memory B cells versus plasma cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_IGM_MEMORY_BCELL_VS_PLASMA_CELL_DN
Systematic name | M3250
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of IgM-memory B cells versus plasma cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_SWITCHED_MEMORY_BCELL_VS_PLASMA_CELL_UP
Systematic name | M3251
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Ig isotype switched memory B cells versus plasma cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_SWITCHED_MEMORY_BCELL_VS_PLASMA_CELL_DN
Systematic name | M3252
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Ig isotype switched memory B cells versus plasma cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_PLASMA_CELL_VS_MEMORY_BCELL_UP
Systematic name | M3253
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of plasma cells versus memory B cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13411_PLASMA_CELL_VS_MEMORY_BCELL_DN
Systematic name | M3255
Organism | Homo sapiens
PMID | 19124732
Authors | Good KL,Avery DT,Tangye SG.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of plasma cells versus memory B cells.
Full description | Enhanced secondary Ab responses are a vital component of adaptive immunity, yet little is understood about the intrinsic and extrinsic regulators of naive and memory B cells that results in differences in their responses to Ag. Microarray analysis, together with surface and intracellular phenotyping, revealed that memory B cells have increased expression of members of the TNF receptor, SLAM, B7 and Bcl2 families, as well as the TLR-related molecule CD180 (RP105). Accordingly, memory B cells exhibited enhanced survival, proliferation and Ig secretion, as well as entered division more rapidly than naïve B cells in response to both T-dependent and T-independent stimuli. Furthermore, both IgM and isotype switched memory B cells, but not naïve B cells, co-stimulated CD4+ T cells in vitro through a mechanism dependent on their constitutive expression of CD80 and CD86. This study demonstrates that upregulation of genes involved in activation, co-stimulation and survival provides memory B cells with a unique ability to produce enhanced immune responses and contributes to the maintenance of the memory B cell pool.

Standard name | GSE13484_UNSTIM_VS_3H_YF17D_VACCINE_STIM_PBMC_UP
Systematic name | M3257
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) cultured for 0 h versus PBMC cultured for 3 h with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_UNSTIM_VS_3H_YF17D_VACCINE_STIM_PBMC_DN
Systematic name | M3260
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) cultured for 0 h versus PBMC cultured for 3 h with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_UNSTIM_VS_12H_YF17D_VACCINE_STIM_PBMC_UP
Systematic name | M3262
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) cultured for 0 h versus PBMC cultured for 12 h with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_UNSTIM_VS_12H_YF17D_VACCINE_STIM_PBMC_DN
Systematic name | M3264
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) cultured for 0 h versus PBMC cultured for 12 h with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_3H_UNSTIM_VS_YF17D_VACCINE_STIM_PBMC_UP
Systematic name | M3266
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) cultured for 3 h versus PBMC cultured for 3 h with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_3H_UNSTIM_VS_YF17D_VACCINE_STIM_PBMC_DN
Systematic name | M3267
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) cultured for 3 h versus PBMC cultured for 3 h with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_12H_UNSTIM_VS_YF17D_VACCINE_STIM_PBMC_UP
Systematic name | M3271
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) cultured for 12 h versus PBMC cultured for 12 h with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_12H_UNSTIM_VS_YF17D_VACCINE_STIM_PBMC_DN
Systematic name | M3273
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) cultured for 12 h versus PBMC cultured for 12 h with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_12H_VS_3H_YF17D_VACCINE_STIM_PBMC_UP
Systematic name | M3275
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) cultured with YF17D vaccine for 12 h versus PBMC cultured for 3 h.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_12H_VS_3H_YF17D_VACCINE_STIM_PBMC_DN
Systematic name | M3276
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) cultured with YF17D vaccine for 12 h versus PBMC cultured for 3 h.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_UNSTIM_VS_YF17D_VACCINE_STIM_PBMC_UP
Systematic name | M3277
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) versus PBMC stimulated with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13484_UNSTIM_VS_YF17D_VACCINE_STIM_PBMC_DN
Systematic name | M3279
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) versus PBMC stimulated with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 11,639 genes in PBMCs from 2 donors cultured with YF-17D vaccine were accessed after 3 and 12 hours.

Standard name | GSE13485_CTRL_VS_DAY1_YF17D_VACCINE_PBMC_UP
Systematic name | M3280
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) versus PBMC 1 day after stimulation with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_CTRL_VS_DAY1_YF17D_VACCINE_PBMC_DN
Systematic name | M3281
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) versus PBMC 1 day after stimulation with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_CTRL_VS_DAY3_YF17D_VACCINE_PBMC_UP
Systematic name | M3282
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) versus PBMC 3 days after stimulation with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_CTRL_VS_DAY3_YF17D_VACCINE_PBMC_DN
Systematic name | M3286
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) versus PBMC 3 days after stimulation with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_CTRL_VS_DAY7_YF17D_VACCINE_PBMC_UP
Systematic name | M3287
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) versus PBMC 7 days after stimulation with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_CTRL_VS_DAY7_YF17D_VACCINE_PBMC_DN
Systematic name | M3288
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) versus PBMC 7 days after stimulation with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_CTRL_VS_DAY21_YF17D_VACCINE_PBMC_UP
Systematic name | M3289
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) versus PBMC 21 days after stimulation with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_CTRL_VS_DAY21_YF17D_VACCINE_PBMC_DN
Systematic name | M3290
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) versus PBMC 21 days after stimulation with YF17D vaccine.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY1_VS_DAY3_YF17D_VACCINE_PBMC_UP
Systematic name | M3291
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 1 day after stimulation with YF17D vaccine versus PBMC 3 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY1_VS_DAY3_YF17D_VACCINE_PBMC_DN
Systematic name | M3294
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 1 day after stimulation with YF17D vaccine versus PBMC 3 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY1_VS_DAY7_YF17D_VACCINE_PBMC_UP
Systematic name | M3295
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 1 day after stimulation with YF17D vaccine versus PBMC 7 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY1_VS_DAY7_YF17D_VACCINE_PBMC_DN
Systematic name | M3296
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 1 day after stimulation with YF17D vaccine versus PBMC 7 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY1_VS_DAY21_YF17D_VACCINE_PBMC_UP
Systematic name | M3298
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 1 day after stimulation with YF17D vaccine versus PBMC 21 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY1_VS_DAY21_YF17D_VACCINE_PBMC_DN
Systematic name | M3299
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 1 day after stimulation with YF17D vaccine versus PBMC 21 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY3_VS_DAY7_YF17D_VACCINE_PBMC_UP
Systematic name | M3300
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 3 days after stimulation with YF17D vaccine versus PBMC 7 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY3_VS_DAY7_YF17D_VACCINE_PBMC_DN
Systematic name | M3302
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 3 days after stimulation with YF17D vaccine versus PBMC 7 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY3_VS_DAY21_YF17D_VACCINE_PBMC_UP
Systematic name | M3303
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 3 days after stimulation with YF17D vaccine versus PBMC 21 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY3_VS_DAY21_YF17D_VACCINE_PBMC_DN
Systematic name | M3306
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 3 days after stimulation with YF17D vaccine versus PBMC 21 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY7_VS_DAY21_YF17D_VACCINE_PBMC_UP
Systematic name | M3307
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 7 days after stimulation with YF17D vaccine versus PBMC 21 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_DAY7_VS_DAY21_YF17D_VACCINE_PBMC_DN
Systematic name | M3308
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated peripheral blood mononuclear cells (PBMC) 7 days after stimulation with YF17D vaccine versus PBMC 21 days after the stimulation.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_PRE_VS_POST_YF17D_VACCINATION_PBMC_UP
Systematic name | M3310
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) before vs after YF17D vaccination.
Full description | The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs. The immune responses generated by YF-17D by profiling 20,077 genes in 25 vaccine recipients were accessed at days 1, 3, 7, and 21 post-vaccination compared to pre-vaccination in PBMCs.

Standard name | GSE13485_PRE_VS_POST_YF17D_VACCINATION_PBMC_DN
Systematic name | M3311
Organism | Homo sapiens
PMID | 19029902
Authors | Querec TD,Akondy RS,Lee EK,Cao W,Nakaya HI,Teuwen D,Pirani A,Gernert K,Deng J,Marzolf B,Kennedy K,Wu H,Bennouna S,Oluoch H,Miller J,Vencio RZ,Mulligan M,Aderem A,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) before vs after YF17D vaccination.
Full description |

Standard name | GSE13493_DP_VS_CD4INTCD8POS_THYMOCYTE_UP
Systematic name | M3312
Organism | Mus musculus
PMID | 19027330
Authors | Choi YI,Duke-Cohan JS,Ahmed WB,Handley MA,Mann F,Epstein JA,Clayton LK,Reinherz EL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus CD4 [GeneID=920] Int CD8 thymocytes.
Full description | T cell development relies on the precise developmental control of various cellular functions for appropriate positive and negative selection. Previously, gene expression profiling of peptide-driven negative selection events in the N15 TCR class I MHC-restricted mouse and D011.10 TCR class II MHC-restricted mouse has offered insights into the coordinate engagement of biological processes affecting thymocyte development. However, there has been little comparable detailed in vivo global genome expression analysis reported for positive selection. We used microarrays to identify the genes differentially expressed during CD8 single positive T cell development in N15 TCR transgenic Rag2 deficient mice.

Standard name | GSE13493_DP_VS_CD4INTCD8POS_THYMOCYTE_DN
Systematic name | M3313
Organism | Mus musculus
PMID | 19027330
Authors | Choi YI,Duke-Cohan JS,Ahmed WB,Handley MA,Mann F,Epstein JA,Clayton LK,Reinherz EL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus CD4 [GeneID=920] Int CD8 thymocytes.
Full description | T cell development relies on the precise developmental control of various cellular functions for appropriate positive and negative selection. Previously, gene expression profiling of peptide-driven negative selection events in the N15 TCR class I MHC-restricted mouse and D011.10 TCR class II MHC-restricted mouse has offered insights into the coordinate engagement of biological processes affecting thymocyte development. However, there has been little comparable detailed in vivo global genome expression analysis reported for positive selection. We used microarrays to identify the genes differentially expressed during CD8 single positive T cell development in N15 TCR transgenic Rag2 deficient mice.

Standard name | GSE13493_DP_VS_CD8POS_THYMOCYTE_UP
Systematic name | M3314
Organism | Mus musculus
PMID | 19027330
Authors | Choi YI,Duke-Cohan JS,Ahmed WB,Handley MA,Mann F,Epstein JA,Clayton LK,Reinherz EL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus CD8 thymocytes.
Full description | T cell development relies on the precise developmental control of various cellular functions for appropriate positive and negative selection. Previously, gene expression profiling of peptide-driven negative selection events in the N15 TCR class I MHC-restricted mouse and D011.10 TCR class II MHC-restricted mouse has offered insights into the coordinate engagement of biological processes affecting thymocyte development. However, there has been little comparable detailed in vivo global genome expression analysis reported for positive selection. We used microarrays to identify the genes differentially expressed during CD8 single positive T cell development in N15 TCR transgenic Rag2 deficient mice.

Standard name | GSE13493_DP_VS_CD8POS_THYMOCYTE_DN
Systematic name | M3315
Organism | Mus musculus
PMID | 19027330
Authors | Choi YI,Duke-Cohan JS,Ahmed WB,Handley MA,Mann F,Epstein JA,Clayton LK,Reinherz EL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus CD8 thymocytes.
Full description | T cell development relies on the precise developmental control of various cellular functions for appropriate positive and negative selection. Previously, gene expression profiling of peptide-driven negative selection events in the N15 TCR class I MHC-restricted mouse and D011.10 TCR class II MHC-restricted mouse has offered insights into the coordinate engagement of biological processes affecting thymocyte development. However, there has been little comparable detailed in vivo global genome expression analysis reported for positive selection. We used microarrays to identify the genes differentially expressed during CD8 single positive T cell development in N15 TCR transgenic Rag2 deficient mice.

Standard name | GSE13493_CD4INTCD8POS_VS_CD8POS_THYMOCYTE_UP
Systematic name | M3316
Organism | Mus musculus
PMID | 19027330
Authors | Choi YI,Duke-Cohan JS,Ahmed WB,Handley MA,Mann F,Epstein JA,Clayton LK,Reinherz EL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] CD8 Int thymocytes versus CD8 thymocytes.
Full description | T cell development relies on the precise developmental control of various cellular functions for appropriate positive and negative selection. Previously, gene expression profiling of peptide-driven negative selection events in the N15 TCR class I MHC-restricted mouse and D011.10 TCR class II MHC-restricted mouse has offered insights into the coordinate engagement of biological processes affecting thymocyte development. However, there has been little comparable detailed in vivo global genome expression analysis reported for positive selection. We used microarrays to identify the genes differentially expressed during CD8 single positive T cell development in N15 TCR transgenic Rag2 deficient mice.

Standard name | GSE13493_CD4INTCD8POS_VS_CD8POS_THYMOCYTE_DN
Systematic name | M3317
Organism | Mus musculus
PMID | 19027330
Authors | Choi YI,Duke-Cohan JS,Ahmed WB,Handley MA,Mann F,Epstein JA,Clayton LK,Reinherz EL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] CD8 Int thymocytes versus CD8 thymocytes.
Full description | T cell development relies on the precise developmental control of various cellular functions for appropriate positive and negative selection. Previously, gene expression profiling of peptide-driven negative selection events in the N15 TCR class I MHC-restricted mouse and D011.10 TCR class II MHC-restricted mouse has offered insights into the coordinate engagement of biological processes affecting thymocyte development. However, there has been little comparable detailed in vivo global genome expression analysis reported for positive selection. We used microarrays to identify the genes differentially expressed during CD8 single positive T cell development in N15 TCR transgenic Rag2 deficient mice.

Standard name | GSE13738_RESTING_VS_TCR_ACTIVATED_CD4_TCELL_UP
Systematic name | M3319
Organism | Homo sapiens
PMID | 19201849
Authors | Bangs SC,Baban D,Cattan HJ,Li CK,McMichael AJ,Xu XN.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of resting CD4 [GeneID=920] T cells versus directly activated CD4 [GeneID=920] T cells.
Full description | There is much evidence that T cells may be activated via mechanisms which act independently of direct TCR ligation. Despite this, the question of whether such forms of ‘bystander’ T cell activation occur during immune responses is hotly debated. To address some outstanding questions, we set up an in vitro system within which to analyse bystander T cell activation in human T cells, in the absence of the possibility for TCR cross-reactivity. In addition, we have investigated the genetic, phenotypic, and functional characteristics of bystander activated T cells. Here, we show that bystander T cell activation is, indeed, observed during a specific immune response, and that it occurs preferentially amongst CD4+ memory T cells. Furthermore, bystander activated T cells display a distinct gene expression profile. The mechanism for bystander T cell activation involves soluble factors, and the outcome is an elevated level of apoptosis. This may provide an explanation for the attrition of T cell memory pools of heterologous specificity during immune responses to pathogens such as viruses.

Standard name | GSE13738_RESTING_VS_TCR_ACTIVATED_CD4_TCELL_DN
Systematic name | M3320
Organism | Homo sapiens
PMID | 19201849
Authors | Bangs SC,Baban D,Cattan HJ,Li CK,McMichael AJ,Xu XN.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of resting CD4 [GeneID=920] T cells versus directly activated CD4 [GeneID=920] T cells.
Full description | There is much evidence that T cells may be activated via mechanisms which act independently of direct TCR ligation. Despite this, the question of whether such forms of ‘bystander’ T cell activation occur during immune responses is hotly debated. To address some outstanding questions, we set up an in vitro system within which to analyse bystander T cell activation in human T cells, in the absence of the possibility for TCR cross-reactivity. In addition, we have investigated the genetic, phenotypic, and functional characteristics of bystander activated T cells. Here, we show that bystander T cell activation is, indeed, observed during a specific immune response, and that it occurs preferentially amongst CD4+ memory T cells. Furthermore, bystander activated T cells display a distinct gene expression profile. The mechanism for bystander T cell activation involves soluble factors, and the outcome is an elevated level of apoptosis. This may provide an explanation for the attrition of T cell memory pools of heterologous specificity during immune responses to pathogens such as viruses.

Standard name | GSE13738_RESTING_VS_BYSTANDER_ACTIVATED_CD4_TCELL_UP
Systematic name | M3321
Organism | Homo sapiens
PMID | 19201849
Authors | Bangs SC,Baban D,Cattan HJ,Li CK,McMichael AJ,Xu XN.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of resting CD4 [GeneID=920] T cells versus bystander activated CD4 [GeneID=920] T cells.
Full description | There is much evidence that T cells may be activated via mechanisms which act independently of direct TCR ligation. Despite this, the question of whether such forms of ‘bystander’ T cell activation occur during immune responses is hotly debated. To address some outstanding questions, we set up an in vitro system within which to analyse bystander T cell activation in human T cells, in the absence of the possibility for TCR cross-reactivity. In addition, we have investigated the genetic, phenotypic, and functional characteristics of bystander activated T cells. Here, we show that bystander T cell activation is, indeed, observed during a specific immune response, and that it occurs preferentially amongst CD4+ memory T cells. Furthermore, bystander activated T cells display a distinct gene expression profile. The mechanism for bystander T cell activation involves soluble factors, and the outcome is an elevated level of apoptosis. This may provide an explanation for the attrition of T cell memory pools of heterologous specificity during immune responses to pathogens such as viruses.

Standard name | GSE13738_RESTING_VS_BYSTANDER_ACTIVATED_CD4_TCELL_DN
Systematic name | M3322
Organism | Homo sapiens
PMID | 19201849
Authors | Bangs SC,Baban D,Cattan HJ,Li CK,McMichael AJ,Xu XN.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of resting CD4 [GeneID=920] T cells versus bystander activated CD4 [GeneID=920] T cells.
Full description | There is much evidence that T cells may be activated via mechanisms which act independently of direct TCR ligation. Despite this, the question of whether such forms of ‘bystander’ T cell activation occur during immune responses is hotly debated. To address some outstanding questions, we set up an in vitro system within which to analyse bystander T cell activation in human T cells, in the absence of the possibility for TCR cross-reactivity. In addition, we have investigated the genetic, phenotypic, and functional characteristics of bystander activated T cells. Here, we show that bystander T cell activation is, indeed, observed during a specific immune response, and that it occurs preferentially amongst CD4+ memory T cells. Furthermore, bystander activated T cells display a distinct gene expression profile. The mechanism for bystander T cell activation involves soluble factors, and the outcome is an elevated level of apoptosis. This may provide an explanation for the attrition of T cell memory pools of heterologous specificity during immune responses to pathogens such as viruses.

Standard name | GSE13738_TCR_VS_BYSTANDER_ACTIVATED_CD4_TCELL_UP
Systematic name | M3324
Organism | Homo sapiens
PMID | 19201849
Authors | Bangs SC,Baban D,Cattan HJ,Li CK,McMichael AJ,Xu XN.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of directly activated CD4 [GeneID=920] T cells versus bystander activated CD4 [GeneID=920] T cells.
Full description | There is much evidence that T cells may be activated via mechanisms which act independently of direct TCR ligation. Despite this, the question of whether such forms of ‘bystander’ T cell activation occur during immune responses is hotly debated. To address some outstanding questions, we set up an in vitro system within which to analyse bystander T cell activation in human T cells, in the absence of the possibility for TCR cross-reactivity. In addition, we have investigated the genetic, phenotypic, and functional characteristics of bystander activated T cells. Here, we show that bystander T cell activation is, indeed, observed during a specific immune response, and that it occurs preferentially amongst CD4+ memory T cells. Furthermore, bystander activated T cells display a distinct gene expression profile. The mechanism for bystander T cell activation involves soluble factors, and the outcome is an elevated level of apoptosis. This may provide an explanation for the attrition of T cell memory pools of heterologous specificity during immune responses to pathogens such as viruses.

Standard name | GSE13738_TCR_VS_BYSTANDER_ACTIVATED_CD4_TCELL_DN
Systematic name | M3325
Organism | Homo sapiens
PMID | 19201849
Authors | Bangs SC,Baban D,Cattan HJ,Li CK,McMichael AJ,Xu XN.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of directly activated CD4 [GeneID=920] T cells versus bystander activated CD4 [GeneID=920] T cells.
Full description | There is much evidence that T cells may be activated via mechanisms which act independently of direct TCR ligation. Despite this, the question of whether such forms of ‘bystander’ T cell activation occur during immune responses is hotly debated. To address some outstanding questions, we set up an in vitro system within which to analyse bystander T cell activation in human T cells, in the absence of the possibility for TCR cross-reactivity. In addition, we have investigated the genetic, phenotypic, and functional characteristics of bystander activated T cells. Here, we show that bystander T cell activation is, indeed, observed during a specific immune response, and that it occurs preferentially amongst CD4+ memory T cells. Furthermore, bystander activated T cells display a distinct gene expression profile. The mechanism for bystander T cell activation involves soluble factors, and the outcome is an elevated level of apoptosis. This may provide an explanation for the attrition of T cell memory pools of heterologous specificity during immune responses to pathogens such as viruses.

Standard name | GSE14000_TRANSLATED_RNA_VS_MRNA_DC_UP
Systematic name | M3326
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of polysome bound (translated) mRNA versus total mRNA in dendritic cells.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_TRANSLATED_RNA_VS_MRNA_DC_DN
Systematic name | M3327
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of polysome bound (translated) mRNA versus total mRNA in dendritic cells.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_TRANSLATED_RNA_VS_MRNA_4H_LPS_DC_UP
Systematic name | M3328
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of polysome bound (translated) mRNA versus total mRNA 4 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_TRANSLATED_RNA_VS_MRNA_4H_LPS_DC_DN
Systematic name | M3329
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of polysome bound (translated) mRNA versus total mRNA 4 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_TRANSLATED_RNA_VS_MRNA_16H_LPS_DC_UP
Systematic name | M3332
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of polysome bound (translated) mRNA versus total mRNA 16 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_TRANSLATED_RNA_VS_MRNA_16H_LPS_DC_DN
Systematic name | M3333
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of polysome bound (translated) mRNA versus total mRNA 16 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_UNSTIM_VS_4H_LPS_DC_TRANSLATED_RNA_UP
Systematic name | M3337
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of polysome bound (translated) mRNA before and 4 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_UNSTIM_VS_4H_LPS_DC_TRANSLATED_RNA_DN
Systematic name | M3338
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of polysome bound (translated) mRNA before and 4 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_UNSTIM_VS_16H_LPS_DC_TRANSLATED_RNA_UP
Systematic name | M3343
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of polysome bound (translated) mRNA before and 16 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_UNSTIM_VS_16H_LPS_DC_TRANSLATED_RNA_DN
Systematic name | M3344
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of polysome bound (translated) mRNA before and 16 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_UNSTIM_VS_4H_LPS_DC_UP
Systematic name | M3345
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) before and 4 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_UNSTIM_VS_4H_LPS_DC_DN
Systematic name | M3347
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) before and 4 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_UNSTIM_VS_16H_LPS_DC_UP
Systematic name | M3348
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) before and 16 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_UNSTIM_VS_16H_LPS_DC_DN
Systematic name | M3350
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) before and 16 h after LPS (TLR4 agonist) stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_4H_VS_16H_LPS_DC_TRANSLATED_RNA_UP
Systematic name | M3351
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of polysome bound (translated) mRNA in dendritic cells (DC) at 4 h after LPS (TLR4 agonist) stimulation versus those at 16 h after the stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_4H_VS_16H_LPS_DC_TRANSLATED_RNA_DN
Systematic name | M3352
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of polysome bound (translated) mRNA in dendritic cells (DC) at 4 h after LPS (TLR4 agonist) stimulation versus those at 16 h after the stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_4H_VS_16H_LPS_DC_UP
Systematic name | M3354
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) at 4 h after LPS (TLR4 agonist) stimulation versus those at 16 h after the stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14000_4H_VS_16H_LPS_DC_DN
Systematic name | M3355
Organism | Homo sapiens
PMID | 19943945
Authors | Ceppi M,Clavarino G,Gatti E,Schmidt EK,de Gassart A,Blankenship D,Ogola G,Banchereau J,Chaussabel D,Pierre P.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) at 4 h after LPS (TLR4 agonist) stimulation versus those at 16 h after the stimulation.
Full description | Dendritic cells (DCs) are the sentinels of the mammalian immune system and they undergo a complex maturation process mediated by activation upon pathogen detection. Recent studies described the analysis of activated DCs by transcriptional profiling, but translation regulation was never taken in account. Therefore, the nature of the mRNAs being translated at various stages of DC activation was determined with the help of translational profiling, which is the sucrose gradient fractionation of polysomal-bound mRNAs combined to microarrays analysis. Total and polysomal-bound mRNA populations were compared in immature (0h) and LPS-stimulated (4h and 16h) human monocyte-derived DCs with the help of Affymetrix microarrays. Biostatistical analysis indicated that 296 mRNA molecules are translationally regulated during DC-activation. The most abundant biological process among the regulated mRNAs was protein biosynthesis, indicating the existence of a negative feedback loop regulating translation. Interestingly, a cluster of 17 ribosomal proteins were part of the regulated mRNAs, indicating that translation may be fine-tuned by particular components of the translational machinery. Our observations highlight the importance of translation regulation during the immune response, and may favour the identification of novel gene clusters or protein networks relevant for immunity. Our study also provides information on the possible absence of correlation between gene expression and real protein production in DCs.

Standard name | GSE14026_TH1_VS_TH17_UP
Systematic name | M3356
Organism | Mus musculus
PMID | 19119024
Authors | Lee YK,Turner H,Maynard CL,Oliver JR,Chen D,Elson CO,Weaver CT.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th1 cells versus Th17 cells.
Full description | This is to compare the gene expression profile of Th1 and Th17 cells.

Standard name | GSE14026_TH1_VS_TH17_DN
Systematic name | M3357
Organism | Mus musculus
PMID | 19119024
Authors | Lee YK,Turner H,Maynard CL,Oliver JR,Chen D,Elson CO,Weaver CT.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th1 cells versus Th17 cells.
Full description | This is to compare the gene expression profile of Th1 and Th17 cells.

Standard name | GSE14308_TH2_VS_TH1_UP
Systematic name | M3359
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th2 cells versus Th1 cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH2_VS_TH1_DN
Systematic name | M3360
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th2 cells versus Th1 cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH2_VS_TH17_UP
Systematic name | M3361
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th2 cells versus Th17 cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH2_VS_TH17_DN
Systematic name | M3363
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th2 cells versus Th17 cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH2_VS_NAIVE_CD4_TCELL_UP
Systematic name | M3364
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th2 cells versus naive CD4 [GeneID=620] T cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH2_VS_NAIVE_CD4_TCELL_DN
Systematic name | M3365
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th2 cells versus naive CD4 [GeneID=620] T cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH2_VS_INDUCED_TREG_UP
Systematic name | M3366
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th2cells versus induced regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH2_VS_INDUCED_TREG_DN
Systematic name | M3367
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th2 cells versus induced regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH2_VS_NATURAL_TREG_UP
Systematic name | M3368
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th2 cells versus natural regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH2_VS_NATURAL_TREG_DN
Systematic name | M3369
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th2 cells versus natural regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH1_VS_TH17_UP
Systematic name | M3371
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th1 cells versus Th17 cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH1_VS_TH17_DN
Systematic name | M3374
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th1 cells versus Th17 cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH1_VS_NAIVE_CD4_TCELL_UP
Systematic name | M3376
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th1 cells versus naive CD4 [GeneID=920] T cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH1_VS_NAIVE_CD4_TCELL_DN
Systematic name | M3377
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th1 cells versus naive CD4 [GeneID=920] T cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH1_VS_INDUCED_TREG_UP
Systematic name | M3378
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th1 cells versus induced regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH1_VS_INDUCED_TREG_DN
Systematic name | M3379
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th1 cells versus induced regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH1_VS_NATURAL_TREG_UP
Systematic name | M3380
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th1 cells versus natural regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH1_VS_NATURAL_TREG_DN
Systematic name | M3381
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th1 cells versus natural regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH17_VS_NAIVE_CD4_TCELL_UP
Systematic name | M3382
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th17 cells versus naive CD4 [GeneID=920] T cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH17_VS_NAIVE_CD4_TCELL_DN
Systematic name | M3384
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th17 cells versus naive CD4 [GeneID=920] T cells.
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH17_VS_INDUCED_TREG_UP
Systematic name | M3385
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th17 cells versus induced regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH17_VS_INDUCED_TREG_DN
Systematic name | M3386
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th17 cells versus induced regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH17_VS_NATURAL_TREG_UP
Systematic name | M3388
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Th17 cells versus natural regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_TH17_VS_NATURAL_TREG_DN
Systematic name | M3390
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Th17 cells versus natural regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_NAIVE_CD4_TCELL_VS_INDUCED_TREG_UP
Systematic name | M3391
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus induced regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_NAIVE_CD4_TCELL_VS_INDUCED_TREG_DN
Systematic name | M3392
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus induced regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_NAIVE_CD4_TCELL_VS_NATURAL_TREG_UP
Systematic name | M3393
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus natural regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_NAIVE_CD4_TCELL_VS_NATURAL_TREG_DN
Systematic name | M3394
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus natural regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_INDUCED_VS_NATURAL_TREG_UP
Systematic name | M3396
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of induced regulatory T cell (Treg) versus natural regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE14308_INDUCED_VS_NATURAL_TREG_DN
Systematic name | M3399
Organism | Mus musculus
PMID | 19144320
Authors | Wei G,Wei L,Zhu J,Zang C,Hu-Li J,Yao Z,Cui K,Kanno Y,Roh TY,Watford WT,Schones DE,Peng W,Sun HW,Paul WE,O'Shea JJ,Zhao K.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of induced regulatory T cell (Treg) versus natural regulatory T cell (Treg).
Full description | Multipotential naïve CD4+ T cells differentiate into distinct lineages including T helper 1 (Th1), Th2, Th17, and inducible T regulatory (iTreg) cells. The remarkable diversity of CD4+ T cells begs the question whether the observed changes reflect terminal differentiation with heritable epigenetic modifications or plasticity in T cell responses. We generated genome-wide histone H3 lysine 4 (H3K4) and lysine 27 (H3K27) trimethylation maps in naïve, Th1, Th2, Th17, iTreg, and natural (n)Treg cells. We found that although modifications of signature cytokine genes (Ifng, Il4, and Il17) partially conform to the expectation of lineage commitment, critical transcription factors such as Tbx21 exhibit a broad spectrum of epigenetic states, consistent with our demonstration of T-bet and IFN-gamma induction in nTreg cells. Our data suggest an epigenetic mechanism underlying the specificity and plasticity of effector and regulatory T cells and also provide a framework for understanding complexity of CD4+ T helper cell differentiation.

Standard name | GSE1432_CTRL_VS_IFNG_1H_MICROGLIA_UP
Systematic name | M3400
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control microglia cells versus those 1 h after stimulation with IFNG [GeneID=3458].
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_CTRL_VS_IFNG_1H_MICROGLIA_DN
Systematic name | M3401
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control microglia cells versus those 1 h after stimulation with IFNG [GeneID=3458].
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_CTRL_VS_IFNG_6H_MICROGLIA_UP
Systematic name | M3404
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control microglia cells versus those 6 h after stimulation with IFNG [GeneID=3458].
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_CTRL_VS_IFNG_6H_MICROGLIA_DN
Systematic name | M3405
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control microglia cells versus those 6 h after stimulation with IFNG [GeneID=3458].
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_CTRL_VS_IFNG_24H_MICROGLIA_UP
Systematic name | M3407
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control microglia cells versus those 24 h after stimulation with IFNG [GeneID=3458].
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_CTRL_VS_IFNG_24H_MICROGLIA_DN
Systematic name | M3408
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control microglia cells versus those 24 h after stimulation with IFNG [GeneID=3458].
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_1H_VS_6H_IFNG_MICROGLIA_UP
Systematic name | M3409
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of microglia cells 1 h after stimulation with IFNG [GeneID=3458] versus microglia cells 6 h after the stimulation.
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_1H_VS_6H_IFNG_MICROGLIA_DN
Systematic name | M3411
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of microglia cells 1 h after stimulation with IFNG [GeneID=3458] versus microglia cells 6 h after the stimulation.
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_1H_VS_24H_IFNG_MICROGLIA_UP
Systematic name | M3413
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of microglia cells 1 h after stimulation with IFNG [GeneID=3458] versus microglia cells 24 h after the stimulation.
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_1H_VS_24H_IFNG_MICROGLIA_DN
Systematic name | M3414
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of microglia cells 1 h after stimulation with IFNG [GeneID=3458] versus microglia cells 24 h after the stimulation.
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_6H_VS_24H_IFNG_MICROGLIA_UP
Systematic name | M3415
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of microglia cells 6 h after stimulation with IFNG [GeneID=3458] versus microglia cells 24 h after the stimulation.
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE1432_6H_VS_24H_IFNG_MICROGLIA_DN
Systematic name | M3416
Organism | Homo sapiens
PMID | 16163375
Authors | Rock RB,Hu S,Deshpande A,Munir S,May BJ,Baker CA,Peterson PK,Kapur V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of microglia cells 6 h after stimulation with IFNG [GeneID=3458] versus microglia cells 24 h after the stimulation.
Full description | Microglial cells are resident macrophages in the central nervous system (CNS) and play a pivotal role in the innate and adaptive immune responses against microbial infections. The immune functions of microglia are regulated by a milieu of cytokines including interferon (IFN)-gamma. We here performed a series of experiments to acertain the transcriptional profile of human fetal microglial cells at 1, 6, and 24 h after IFN-gamma treatment. Primary human microglial cells were either untreated or treated with 200u/ml IFN-gamma. Affymetrix U133A chips were utilized. Four different tissue samples (B18, O, W, and Y20) were analyzed at the three time points.

Standard name | GSE14350_TREG_VS_TEFF_UP
Systematic name | M3417
Organism | Mus musculus
PMID | 19185518
Authors | Yu A,Zhu L,Altman NH,Malek TR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) versus effector T cells.
Full description | Interleukin-2 receptor (IL-2R) signaling is essential for T regulatory (Treg) cell development and homeostasis. Here we show that expression of IL-2Rbeta chains that lack tyrosine residues important for the association of the adaptor Shc and the transcription factor STAT5 in IL-2Rbeta-deficient mice resulted in production of a normal proportion of natural Treg cells that suppressed severe autoimmunity related with deficiency in IL-2 or IL-2R. These mutant IL-2Rbeta chains supported suboptimal and transient STAT5 activation that upregulate the transcription factor Foxp3 to normal amounts in natural, but not induced, Treg cells. Using cells T cell obtained from normal C57BL/6 mice and mice harboring Treg cells with impaired IL-2R signaling, gene expression profiling revealed many targets in peripheral natural Treg cells that were IL-2-dependent and a substantial overlap between the Treg cell IL-2-dependent gene program and the Treg cell transcriptional signature. Collectively, these findings demonstrate that a critical, and perhaps minor, subset of IL-2-dependent targets in Treg cells is indexed to a low IL-2R signaling threshold and that a substantial proportion of the Treg cell gene program is regulated by IL-2. CD4 T effector cells also showed many IL-2R-dependent gene and these also overlapped in a distintive manner with the IL-2-dependent genes of Treg cells and the Treg gene signature.

Standard name | GSE14350_TREG_VS_TEFF_DN
Systematic name | M3418
Organism | Mus musculus
PMID | 19185518
Authors | Yu A,Zhu L,Altman NH,Malek TR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) versus effector T cells.
Full description | Interleukin-2 receptor (IL-2R) signaling is essential for T regulatory (Treg) cell development and homeostasis. Here we show that expression of IL-2Rbeta chains that lack tyrosine residues important for the association of the adaptor Shc and the transcription factor STAT5 in IL-2Rbeta-deficient mice resulted in production of a normal proportion of natural Treg cells that suppressed severe autoimmunity related with deficiency in IL-2 or IL-2R. These mutant IL-2Rbeta chains supported suboptimal and transient STAT5 activation that upregulate the transcription factor Foxp3 to normal amounts in natural, but not induced, Treg cells. Using cells T cell obtained from normal C57BL/6 mice and mice harboring Treg cells with impaired IL-2R signaling, gene expression profiling revealed many targets in peripheral natural Treg cells that were IL-2-dependent and a substantial overlap between the Treg cell IL-2-dependent gene program and the Treg cell transcriptional signature. Collectively, these findings demonstrate that a critical, and perhaps minor, subset of IL-2-dependent targets in Treg cells is indexed to a low IL-2R signaling threshold and that a substantial proportion of the Treg cell gene program is regulated by IL-2. CD4 T effector cells also showed many IL-2R-dependent gene and these also overlapped in a distintive manner with the IL-2-dependent genes of Treg cells and the Treg gene signature.

Standard name | GSE14350_TREG_VS_TEFF_IN_IL2RB_KO_UP
Systematic name | M3419
Organism | Mus musculus
PMID | 19185518
Authors | Yu A,Zhu L,Altman NH,Malek TR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) from IL2RB [GeneID=3560] defficient mice versus effector T cells from IL2RB [GeneID=3560] defficient mice.
Full description | Interleukin-2 receptor (IL-2R) signaling is essential for T regulatory (Treg) cell development and homeostasis. Here we show that expression of IL-2Rbeta chains that lack tyrosine residues important for the association of the adaptor Shc and the transcription factor STAT5 in IL-2Rbeta-deficient mice resulted in production of a normal proportion of natural Treg cells that suppressed severe autoimmunity related with deficiency in IL-2 or IL-2R. These mutant IL-2Rbeta chains supported suboptimal and transient STAT5 activation that upregulate the transcription factor Foxp3 to normal amounts in natural, but not induced, Treg cells. Using cells T cell obtained from normal C57BL/6 mice and mice harboring Treg cells with impaired IL-2R signaling, gene expression profiling revealed many targets in peripheral natural Treg cells that were IL-2-dependent and a substantial overlap between the Treg cell IL-2-dependent gene program and the Treg cell transcriptional signature. Collectively, these findings demonstrate that a critical, and perhaps minor, subset of IL-2-dependent targets in Treg cells is indexed to a low IL-2R signaling threshold and that a substantial proportion of the Treg cell gene program is regulated by IL-2. CD4 T effector cells also showed many IL-2R-dependent gene and these also overlapped in a distintive manner with the IL-2-dependent genes of Treg cells and the Treg gene signature.

Standard name | GSE14350_TREG_VS_TEFF_IN_IL2RB_KO_DN
Systematic name | M3420
Organism | Mus musculus
PMID | 19185518
Authors | Yu A,Zhu L,Altman NH,Malek TR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) from IL2RB [GeneID=3560] defficient mice versus effector T cells from IL2RB [GeneID=3560] defficient mice.
Full description | Interleukin-2 receptor (IL-2R) signaling is essential for T regulatory (Treg) cell development and homeostasis. Here we show that expression of IL-2Rbeta chains that lack tyrosine residues important for the association of the adaptor Shc and the transcription factor STAT5 in IL-2Rbeta-deficient mice resulted in production of a normal proportion of natural Treg cells that suppressed severe autoimmunity related with deficiency in IL-2 or IL-2R. These mutant IL-2Rbeta chains supported suboptimal and transient STAT5 activation that upregulate the transcription factor Foxp3 to normal amounts in natural, but not induced, Treg cells. Using cells T cell obtained from normal C57BL/6 mice and mice harboring Treg cells with impaired IL-2R signaling, gene expression profiling revealed many targets in peripheral natural Treg cells that were IL-2-dependent and a substantial overlap between the Treg cell IL-2-dependent gene program and the Treg cell transcriptional signature. Collectively, these findings demonstrate that a critical, and perhaps minor, subset of IL-2-dependent targets in Treg cells is indexed to a low IL-2R signaling threshold and that a substantial proportion of the Treg cell gene program is regulated by IL-2. CD4 T effector cells also showed many IL-2R-dependent gene and these also overlapped in a distintive manner with the IL-2-dependent genes of Treg cells and the Treg gene signature.

Standard name | GSE14350_IL2RB_KO_VS_WT_TREG_UP
Systematic name | M3421
Organism | Mus musculus
PMID | 19185518
Authors | Yu A,Zhu L,Altman NH,Malek TR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) from IL2RB [GeneID=3560] defficient mice versus regulatory T cell (Treg) from wild type animals.
Full description | Interleukin-2 receptor (IL-2R) signaling is essential for T regulatory (Treg) cell development and homeostasis. Here we show that expression of IL-2Rbeta chains that lack tyrosine residues important for the association of the adaptor Shc and the transcription factor STAT5 in IL-2Rbeta-deficient mice resulted in production of a normal proportion of natural Treg cells that suppressed severe autoimmunity related with deficiency in IL-2 or IL-2R. These mutant IL-2Rbeta chains supported suboptimal and transient STAT5 activation that upregulate the transcription factor Foxp3 to normal amounts in natural, but not induced, Treg cells. Using cells T cell obtained from normal C57BL/6 mice and mice harboring Treg cells with impaired IL-2R signaling, gene expression profiling revealed many targets in peripheral natural Treg cells that were IL-2-dependent and a substantial overlap between the Treg cell IL-2-dependent gene program and the Treg cell transcriptional signature. Collectively, these findings demonstrate that a critical, and perhaps minor, subset of IL-2-dependent targets in Treg cells is indexed to a low IL-2R signaling threshold and that a substantial proportion of the Treg cell gene program is regulated by IL-2. CD4 T effector cells also showed many IL-2R-dependent gene and these also overlapped in a distintive manner with the IL-2-dependent genes of Treg cells and the Treg gene signature.

Standard name | GSE14350_IL2RB_KO_VS_WT_TREG_DN
Systematic name | M3422
Organism | Mus musculus
PMID | 19185518
Authors | Yu A,Zhu L,Altman NH,Malek TR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) from IL2RB [GeneID=3560] defficient mice versus regulatory T cell (Treg) from wild type animals.
Full description | Interleukin-2 receptor (IL-2R) signaling is essential for T regulatory (Treg) cell development and homeostasis. Here we show that expression of IL-2Rbeta chains that lack tyrosine residues important for the association of the adaptor Shc and the transcription factor STAT5 in IL-2Rbeta-deficient mice resulted in production of a normal proportion of natural Treg cells that suppressed severe autoimmunity related with deficiency in IL-2 or IL-2R. These mutant IL-2Rbeta chains supported suboptimal and transient STAT5 activation that upregulate the transcription factor Foxp3 to normal amounts in natural, but not induced, Treg cells. Using cells T cell obtained from normal C57BL/6 mice and mice harboring Treg cells with impaired IL-2R signaling, gene expression profiling revealed many targets in peripheral natural Treg cells that were IL-2-dependent and a substantial overlap between the Treg cell IL-2-dependent gene program and the Treg cell transcriptional signature. Collectively, these findings demonstrate that a critical, and perhaps minor, subset of IL-2-dependent targets in Treg cells is indexed to a low IL-2R signaling threshold and that a substantial proportion of the Treg cell gene program is regulated by IL-2. CD4 T effector cells also showed many IL-2R-dependent gene and these also overlapped in a distintive manner with the IL-2-dependent genes of Treg cells and the Treg gene signature.

Standard name | GSE14350_IL2RB_KO_VS_WT_TEFF_UP
Systematic name | M3423
Organism | Mus musculus
PMID | 19185518
Authors | Yu A,Zhu L,Altman NH,Malek TR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effector T cells from IL2RB [GeneID=3560] defficient mice versus effector T cells from wild type animals.
Full description | Interleukin-2 receptor (IL-2R) signaling is essential for T regulatory (Treg) cell development and homeostasis. Here we show that expression of IL-2Rbeta chains that lack tyrosine residues important for the association of the adaptor Shc and the transcription factor STAT5 in IL-2Rbeta-deficient mice resulted in production of a normal proportion of natural Treg cells that suppressed severe autoimmunity related with deficiency in IL-2 or IL-2R. These mutant IL-2Rbeta chains supported suboptimal and transient STAT5 activation that upregulate the transcription factor Foxp3 to normal amounts in natural, but not induced, Treg cells. Using cells T cell obtained from normal C57BL/6 mice and mice harboring Treg cells with impaired IL-2R signaling, gene expression profiling revealed many targets in peripheral natural Treg cells that were IL-2-dependent and a substantial overlap between the Treg cell IL-2-dependent gene program and the Treg cell transcriptional signature. Collectively, these findings demonstrate that a critical, and perhaps minor, subset of IL-2-dependent targets in Treg cells is indexed to a low IL-2R signaling threshold and that a substantial proportion of the Treg cell gene program is regulated by IL-2. CD4 T effector cells also showed many IL-2R-dependent gene and these also overlapped in a distintive manner with the IL-2-dependent genes of Treg cells and the Treg gene signature.

Standard name | GSE14350_IL2RB_KO_VS_WT_TEFF_DN
Systematic name | M3424
Organism | Mus musculus
PMID | 19185518
Authors | Yu A,Zhu L,Altman NH,Malek TR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effector T cells from IL2RB [GeneID=3560] defficient mice versus effector T cells from wild type animals.
Full description | Interleukin-2 receptor (IL-2R) signaling is essential for T regulatory (Treg) cell development and homeostasis. Here we show that expression of IL-2Rbeta chains that lack tyrosine residues important for the association of the adaptor Shc and the transcription factor STAT5 in IL-2Rbeta-deficient mice resulted in production of a normal proportion of natural Treg cells that suppressed severe autoimmunity related with deficiency in IL-2 or IL-2R. These mutant IL-2Rbeta chains supported suboptimal and transient STAT5 activation that upregulate the transcription factor Foxp3 to normal amounts in natural, but not induced, Treg cells. Using cells T cell obtained from normal C57BL/6 mice and mice harboring Treg cells with impaired IL-2R signaling, gene expression profiling revealed many targets in peripheral natural Treg cells that were IL-2-dependent and a substantial overlap between the Treg cell IL-2-dependent gene program and the Treg cell transcriptional signature. Collectively, these findings demonstrate that a critical, and perhaps minor, subset of IL-2-dependent targets in Treg cells is indexed to a low IL-2R signaling threshold and that a substantial proportion of the Treg cell gene program is regulated by IL-2. CD4 T effector cells also showed many IL-2R-dependent gene and these also overlapped in a distintive manner with the IL-2-dependent genes of Treg cells and the Treg gene signature.

Standard name | GSE1448_CTRL_VS_ANTI_VALPHA2_DP_THYMOCYTE_UP
Systematic name | M3425
Organism | Mus musculus
PMID | 15661827
Authors | Niederberger N,Buehler LK,Ampudia J,Gascoigne NR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control CD4 [GeneID=920] CD8 thymocytes versus those after stimulation with anti-Valpha2 antibodies.
Full description | Comparison of gene expression changes in CD4+CD8+ thymocytes following engagement of TCR with anti-Valpha or Vbeta antibodies

Standard name | GSE1448_CTRL_VS_ANTI_VALPHA2_DP_THYMOCYTE_DN
Systematic name | M3426
Organism | Mus musculus
PMID | 15661827
Authors | Niederberger N,Buehler LK,Ampudia J,Gascoigne NR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control CD4 [GeneID=920] CD8 thymocytes versus those after stimulation with anti-Valpha2 antibodies.
Full description | Comparison of gene expression changes in CD4+CD8+ thymocytes following engagement of TCR with anti-Valpha or Vbeta antibodies

Standard name | GSE1448_CTRL_VS_ANTI_VBETA5_DP_THYMOCYTE_UP
Systematic name | M3428
Organism | Mus musculus
PMID | 15661827
Authors | Niederberger N,Buehler LK,Ampudia J,Gascoigne NR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control CD4 [GeneID=920] CD8 thymocytes versus those after stimulation with anti-Vbeta5 antibodies.
Full description | Comparison of gene expression changes in CD4+CD8+ thymocytes following engagement of TCR with anti-Valpha or Vbeta antibodies

Standard name | GSE1448_CTRL_VS_ANTI_VBETA5_DP_THYMOCYTE_DN
Systematic name | M3429
Organism | Mus musculus
PMID | 15661827
Authors | Niederberger N,Buehler LK,Ampudia J,Gascoigne NR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control CD4 [GeneID=920] CD8 thymocytes versus those after stimulation with anti-Vbeta5 antibodies.
Full description | Comparison of gene expression changes in CD4+CD8+ thymocytes following engagement of TCR with anti-Valpha or Vbeta antibodies

Standard name | GSE1448_ANTI_VALPHA2_VS_VBETA5_DP_THYMOCYTE_UP
Systematic name | M3431
Organism | Mus musculus
PMID | 15661827
Authors | Niederberger N,Buehler LK,Ampudia J,Gascoigne NR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes stimulated with anti-Valpha2 antibodies versus CD4 [GeneID=920] CD8 thymocytes stimulated with anti-beta5 antibodies.
Full description | Comparison of gene expression changes in CD4+CD8+ thymocytes following engagement of TCR with anti-Valpha or Vbeta antibodies

Standard name | GSE1448_ANTI_VALPHA2_VS_VBETA5_DP_THYMOCYTE_DN
Systematic name | M3435
Organism | Mus musculus
PMID | 15661827
Authors | Niederberger N,Buehler LK,Ampudia J,Gascoigne NR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes stimulated with anti-Valpha2 antibodies versus CD4 [GeneID=920] CD8 thymocytes stimulated with anti-beta5 antibodies.
Full description | Comparison of gene expression changes in CD4+CD8+ thymocytes following engagement of TCR with anti-Valpha or Vbeta antibodies

STANDARD_NAME="GSE1460_INTRATHYMIC_T_PROGENITOR_VS_DP_THYMOCYTE_UP" SYSTEMATIC_NAME="M3436" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2133_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of intrathymic T progenitor cells (ITTP) versus CD4 [GeneID=920] CD8 thymocytes. " DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_INTRATHYMIC_T_PROGENITOR_VS_DP_THYMOCYTE_DN" SYSTEMATIC_NAME="M3438" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2133_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of intrathymic T progenitor cells (ITTP) versus CD4 [GeneID=920] CD8 thymocytes. " DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_INTRATHYMIC_T_PROGENITOR_VS_CD4_THYMOCYTE_UP" SYSTEMATIC_NAME="M3439" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2134_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of intrathymic T progenitor cells (ITTP) versus CD4 [GeneID=920] thymocytes." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_INTRATHYMIC_T_PROGENITOR_VS_CD4_THYMOCYTE_DN" SYSTEMATIC_NAME="M3440" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2134_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of intrathymic T progenitor cells (ITTP) versus CD4 [GeneID=920] thymocytes." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_INTRATHYMIC_T_PROGENITOR_VS_NAIVE_CD4_TCELL_CORD_BLOOD_UP" SYSTEMATIC_NAME="M3441" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2135_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of intrathymic T progenitor cells (ITTP) versus naive CD4 [GeneID=920] T cells from cord blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_INTRATHYMIC_T_PROGENITOR_VS_NAIVE_CD4_TCELL_CORD_BLOOD_DN" SYSTEMATIC_NAME="M3445" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2135_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of intrathymic T progenitor cells (ITTP) versus naive CD4 [GeneID=920] T cells from cord blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_INTRATHYMIC_T_PROGENITOR_VS_NAIVE_CD4_TCELL_ADULT_BLOOD_UP" SYSTEMATIC_NAME="M3446" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2136_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of intrathymic T progenitor cells (ITTP) versus naive CD4 [GeneID=920] T cells from adult blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_INTRATHYMIC_T_PROGENITOR_VS_NAIVE_CD4_TCELL_ADULT_BLOOD_DN" SYSTEMATIC_NAME="M3448" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2136_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of intrathymic T progenitor cells (ITTP) versus naive CD4 [GeneID=920] T cells from adult blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_INTRATHYMIC_T_PROGENITOR_VS_THYMIC_STROMAL_CELL_UP" SYSTEMATIC_NAME="M3449" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2137_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of intrathymic T progenitor cells (ITTP) versus thymic stromal cells." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_INTRATHYMIC_T_PROGENITOR_VS_THYMIC_STROMAL_CELL_DN" SYSTEMATIC_NAME="M3450" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2137_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of intrathymic T progenitor cells (ITTP) versus thymic stromal cells." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_DP_VS_CD4_THYMOCYTE_UP" SYSTEMATIC_NAME="M3452" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2138_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus T cells from cord blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_DP_VS_CD4_THYMOCYTE_DN" SYSTEMATIC_NAME="M3454" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2138_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus T cells from cord blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_DP_THYMOCYTE_VS_NAIVE_CD4_TCELL_CORD_BLOOD_UP" SYSTEMATIC_NAME="M3459" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2139_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus naive CD4 [GeneID=920] T cells from cord blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_DP_THYMOCYTE_VS_NAIVE_CD4_TCELL_CORD_BLOOD_DN" SYSTEMATIC_NAME="M3460" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2139_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus naive CD4 [GeneID=920] T cells from cord blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_DP_THYMOCYTE_VS_NAIVE_CD4_TCELL_ADULT_BLOOD_UP" SYSTEMATIC_NAME="M3461" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2140_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus naive CD4 [GeneID=920] T cells from adult blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_DP_THYMOCYTE_VS_NAIVE_CD4_TCELL_ADULT_BLOOD_DN" SYSTEMATIC_NAME="M3465" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2140_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus naive CD4 [GeneID=920] T cells from adult blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_DP_THYMOCYTE_VS_THYMIC_STROMAL_CELL_UP" SYSTEMATIC_NAME="M3467" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2141_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus thymic stromal cells." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_DP_THYMOCYTE_VS_THYMIC_STROMAL_CELL_DN" SYSTEMATIC_NAME="M3469" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2141_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of CD4 [GeneID=920] CD8 thymocytes versus thymic stromal cells." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_CD4_THYMOCYTE_VS_NAIVE_CD4_TCELL_CORD_BLOOD_UP" SYSTEMATIC_NAME="M3470" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2142_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of CD4 [GeneID=920] thymocytes versus naive CD4 [GeneID=920] T cells from cord blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_CD4_THYMOCYTE_VS_NAIVE_CD4_TCELL_CORD_BLOOD_DN" SYSTEMATIC_NAME="M3472" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2142_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of CD4 [GeneID=920] thymocytes versus naive CD4 [GeneID=920] T cells from cord blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_CD4_THYMOCYTE_VS_NAIVE_CD4_TCELL_ADULT_BLOOD_UP" SYSTEMATIC_NAME="M3474" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2143_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of CD4 [GeneID=920] thymocytes versus naive CD4 [GeneID=920] T cells from adult blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_CD4_THYMOCYTE_VS_NAIVE_CD4_TCELL_ADULT_BLOOD_DN" SYSTEMATIC_NAME="M3476" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2143_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of CD4 [GeneID=920] thymocytes versus naive CD4 [GeneID=920] T cells from adult blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_CD4_THYMOCYTE_VS_THYMIC_STROMAL_CELL_UP" SYSTEMATIC_NAME="M3478" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2144_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in comparison of CD4 [GeneID=920] thymocytes versus thymic stromal cells." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_CD4_THYMOCYTE_VS_THYMIC_STROMAL_CELL_DN" SYSTEMATIC_NAME="M3479" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2144_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in comparison of CD4 [GeneID=920] thymocytes versus thymic stromal cells." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_CORD_VS_ADULT_BLOOD_NAIVE_CD4_TCELL_UP" SYSTEMATIC_NAME="M3480" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2145_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in CD4 [GeneID=920] T cells from cord blood versus those from adult blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_CORD_VS_ADULT_BLOOD_NAIVE_CD4_TCELL_DN" SYSTEMATIC_NAME="M3481" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2145_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in CD4 [GeneID=920] T cells from cord blood versus those from adult blood." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_NAIVE_CD4_TCELL_CORD_BLOOD_VS_THYMIC_STROMAL_CELL_UP" SYSTEMATIC_NAME="M3484" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2146_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in naive CD4 [GeneID=920] T cells from cord blood versus thymic stromal cells." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_NAIVE_CD4_TCELL_CORD_BLOOD_VS_THYMIC_STROMAL_CELL_DN" SYSTEMATIC_NAME="M3486" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2146_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in naive CD4 [GeneID=920] T cells from cord blood versus thymic stromal cells." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_NAIVE_CD4_TCELL_ADULT_BLOOD_VS_THYMIC_STROMAL_CELL_UP" SYSTEMATIC_NAME="M3487" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2147_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in naive CD4 [GeneID=920] T cells from adult blood versus thymic stromal cells." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)." STANDARD_NAME="GSE1460_NAIVE_CD4_TCELL_ADULT_BLOOD_VS_THYMIC_STROMAL_CELL_DN" SYSTEMATIC_NAME="M3488" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="15210650" AUTHORS="Lee MS,Hanspers K,Barker CS,Korn AP,McCune JM." GEOID="GSE1460" EXACT_SOURCE="GSE1460_2147_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in naive CD4 [GeneID=920] T cells from adult blood versus thymic stromal cells." DESCRIPTION_FULL="Subpopulations of human fetal thymocyte and circulating naïve T cells were obtained through FACS sorting, including CD3-CD4+CD8- intrathymic T progenitor cells (ITTP), CD3intCD4+CD8+ \double positive\ thymocytes (DP), CD3highCD4+CD8- \single positive\ thymocytes (SP4), CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from cord blood (CB4+), and CD3+CD4+CD8-CD45RA+CD62L+ naive T cells from adult blood (AB4+)."

Standard name | GSE14769_UNSTIM_VS_20MIN_LPS_BMDM_UP
Systematic name | M3490
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 20 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_20MIN_LPS_BMDM_DN
Systematic name | M3491
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 20 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_40MIN_LPS_BMDM_UP
Systematic name | M3493
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 40 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_40MIN_LPS_BMDM_DN
Systematic name | M3497
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 40 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_60MIN_LPS_BMDM_UP
Systematic name | M3498
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 60 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_60MIN_LPS_BMDM_DN
Systematic name | M3499
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 60 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_80MIN_LPS_BMDM_UP
Systematic name | M3500
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 80 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_80MIN_LPS_BMDM_DN
Systematic name | M3502
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 80 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_120MIN_LPS_BMDM_UP
Systematic name | M3503
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 120 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_120MIN_LPS_BMDM_DN
Systematic name | M3504
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 120 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_240MIN_LPS_BMDM_UP
Systematic name | M3507
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 240 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_240MIN_LPS_BMDM_DN
Systematic name | M3508
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 240 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_360MIN_LPS_BMDM_UP
Systematic name | M3509
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 360 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_UNSTIM_VS_360MIN_LPS_BMDM_DN
Systematic name | M3510
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated macrophage cells versus macrophage cells stimulated with LPS (TLR4 agonist) for 360 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_20MIN_VS_360MIN_LPS_BMDM_UP
Systematic name | M3511
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophage cells stimulated with LPS (TLR4 agonist) for 20 min versus macrophage cells stimulated with LPS (TLR4 agonist) for 360 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_20MIN_VS_360MIN_LPS_BMDM_DN
Systematic name | M3513
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophage cells stimulated with LPS (TLR4 agonist) for 20 min versus macrophage cells stimulated with LPS (TLR4 agonist) for 360 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_40MIN_VS_360MIN_LPS_BMDM_UP
Systematic name | M3514
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophage cells stimulated with LPS (TLR4 agonist) for 40 min versus macrophage cells stimulated with LPS (TLR4 agonist) for 360 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE14769_40MIN_VS_360MIN_LPS_BMDM_DN
Systematic name | M3517
Organism | Mus musculus
PMID | 19270711
Authors | Litvak V,Ramsey SA,Rust AG,Zak DE,Kennedy KA,Lampano AE,Nykter M,Shmulevich I,Aderem A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophage cells stimulated with LPS (TLR4 agonist) for 40 min versus macrophage cells stimulated with LPS (TLR4 agonist) for 360 min.
Full description | The innate immune system is a two-edged sword; it is absolutely required for host defense against infection, but if left uncontrolled can trigger a plethora of inflammatory diseases. Here we used systems biology approaches to predict and validate a gene regulatory network involving a dynamic interplay between the transcription factors NF-κB, C/EBPδ, and ATF3 that controls inflammatory responses. We mathematically modeled transcriptional regulation of Il6 and Cebpd genes and experimentally validated the prediction that the combination of an initiator (NF-κB), an amplifier (C/EBPδ) and an attenuator (ATF3) forms a regulatory circuit that discriminates between transient and persistent Toll-like receptor 4-induced signals. Our results suggest a mechanism that enables the innate immune system to detect the duration of infection and to respond appropriately.

Standard name | GSE15215_CD2_POS_VS_NEG_PDC_UP
Systematic name | M3519
Organism | Homo sapiens
PMID | 19454677
Authors | Matsui T,Connolly JE,Michnevitz M,Chaussabel D,Yu CI,Glaser C,Tindle S,Pypaert M,Freitas H,Piqueras B,Banchereau J,Palucka AK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD2+ plasmacytoid dendritic cells (DC) versus CD2- cells.
Full description | Plasmacytoid dendritic cells (pDCs) are key regulators of anti-viral immunity. They rapidly secrete IFN-alpha and cross-present viral antigens thereby launching adaptive immunity. Here we show that activated human pDCs inhibit replication of cancer cells, and kill them in a contact dependent fashion. Expression of CD2 distinguishes two pDC subsets with distinct phenotype and function. Both subsets secrete IFN-alpha and express Granzyme B and TRAIL. CD2high pDCs uniquely express lysozyme and can be found in tonsils and in tumors. Both subsets launch recall T cell response. However, CD2high pDCs secrete higher levels of IL12 p40, express higher levels of co-stimulatory molecule CD80 and are more efficient in triggering proliferation of naïve allogeneic T cells. Thus, human blood pDCs are composed of subsets with specific phenotype and functions.

Standard name | GSE15215_CD2_POS_VS_NEG_PDC_DN
Systematic name | M3521
Organism | Homo sapiens
PMID | 19454677
Authors | Matsui T,Connolly JE,Michnevitz M,Chaussabel D,Yu CI,Glaser C,Tindle S,Pypaert M,Freitas H,Piqueras B,Banchereau J,Palucka AK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD2+ plasmacytoid dendritic cells (DC) versus CD2- cells.
Full description | Plasmacytoid dendritic cells (pDCs) are key regulators of anti-viral immunity. They rapidly secrete IFN-alpha and cross-present viral antigens thereby launching adaptive immunity. Here we show that activated human pDCs inhibit replication of cancer cells, and kill them in a contact dependent fashion. Expression of CD2 distinguishes two pDC subsets with distinct phenotype and function. Both subsets secrete IFN-alpha and express Granzyme B and TRAIL. CD2high pDCs uniquely express lysozyme and can be found in tonsils and in tumors. Both subsets launch recall T cell response. However, CD2high pDCs secrete higher levels of IL12 p40, express higher levels of co-stimulatory molecule CD80 and are more efficient in triggering proliferation of naïve allogeneic T cells. Thus, human blood pDCs are composed of subsets with specific phenotype and functions.

Standard name | GSE15324_NAIVE_VS_ACTIVATED_CD8_TCELL_UP
Systematic name | M3523
Organism | Mus musculus
PMID | 19412182
Authors | Yamada T,Park CS,Mamonkin M,Lacorazza HD.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus activated CD8 T cells.
Full description | Transcription factors that regulate quiescence, proliferation, and homing of lymphocytes are critical for effective immune system function. In the present study, we demonstrated that the transcription factor ELF4 directly activates the tumor suppressor KLF4 downstream of T cell receptor (TCR) signaling to induce cell cycle arrest in naive CD8+ T cells. Elf4- and Klf4-deficient mice accumulated CD8+CD44hi T cells during steady-state conditions and generated more memory T cells after immunization. The homeostatic expansion of CD8+CD44hi T cells in Elf4-null mice resulted in a redistribution of cells to non-lymphoid tissue due to reduced expression of the transcription factor KLF2, and the surface proteins CCR7 and CD62L. This work describes the combinatorial role of lymphocyte-intrinsic factors in the control of T cell homeostasis, activation and homing.

Standard name | GSE15324_NAIVE_VS_ACTIVATED_CD8_TCELL_DN
Systematic name | M3525
Organism | Mus musculus
PMID | 19412182
Authors | Yamada T,Park CS,Mamonkin M,Lacorazza HD.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus activated CD8 T cells.
Full description | Transcription factors that regulate quiescence, proliferation, and homing of lymphocytes are critical for effective immune system function. In the present study, we demonstrated that the transcription factor ELF4 directly activates the tumor suppressor KLF4 downstream of T cell receptor (TCR) signaling to induce cell cycle arrest in naive CD8+ T cells. Elf4- and Klf4-deficient mice accumulated CD8+CD44hi T cells during steady-state conditions and generated more memory T cells after immunization. The homeostatic expansion of CD8+CD44hi T cells in Elf4-null mice resulted in a redistribution of cells to non-lymphoid tissue due to reduced expression of the transcription factor KLF2, and the surface proteins CCR7 and CD62L. This work describes the combinatorial role of lymphocyte-intrinsic factors in the control of T cell homeostasis, activation and homing.

Standard name | GSE15324_NAIVE_VS_ACTIVATED_ELF4_KO_CD8_TCELL_UP
Systematic name | M3526
Organism | Mus musculus
PMID | 19412182
Authors | Yamada T,Park CS,Mamonkin M,Lacorazza HD.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells from ELF4 [GeneID=2000] defficient mice versus activated CD8 T cells from ELF4 [GeneID=2000] defficient animals.
Full description | Transcription factors that regulate quiescence, proliferation, and homing of lymphocytes are critical for effective immune system function. In the present study, we demonstrated that the transcription factor ELF4 directly activates the tumor suppressor KLF4 downstream of T cell receptor (TCR) signaling to induce cell cycle arrest in naive CD8+ T cells. Elf4- and Klf4-deficient mice accumulated CD8+CD44hi T cells during steady-state conditions and generated more memory T cells after immunization. The homeostatic expansion of CD8+CD44hi T cells in Elf4-null mice resulted in a redistribution of cells to non-lymphoid tissue due to reduced expression of the transcription factor KLF2, and the surface proteins CCR7 and CD62L. This work describes the combinatorial role of lymphocyte-intrinsic factors in the control of T cell homeostasis, activation and homing.

Standard name | GSE15324_NAIVE_VS_ACTIVATED_ELF4_KO_CD8_TCELL_DN
Systematic name | M3527
Organism | Mus musculus
PMID | 19412182
Authors | Yamada T,Park CS,Mamonkin M,Lacorazza HD.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells from ELF4 [GeneID=2000] defficient mice versus activated CD8 T cells from ELF4 [GeneID=2000] defficient animals.
Full description | Transcription factors that regulate quiescence, proliferation, and homing of lymphocytes are critical for effective immune system function. In the present study, we demonstrated that the transcription factor ELF4 directly activates the tumor suppressor KLF4 downstream of T cell receptor (TCR) signaling to induce cell cycle arrest in naive CD8+ T cells. Elf4- and Klf4-deficient mice accumulated CD8+CD44hi T cells during steady-state conditions and generated more memory T cells after immunization. The homeostatic expansion of CD8+CD44hi T cells in Elf4-null mice resulted in a redistribution of cells to non-lymphoid tissue due to reduced expression of the transcription factor KLF2, and the surface proteins CCR7 and CD62L. This work describes the combinatorial role of lymphocyte-intrinsic factors in the control of T cell homeostasis, activation and homing.

Standard name | GSE15324_ELF4_KO_VS_WT_NAIVE_CD8_TCELL_UP
Systematic name | M3529
Organism | Mus musculus
PMID | 19412182
Authors | Yamada T,Park CS,Mamonkin M,Lacorazza HD.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells from ELF4 [GeneID=2000] defficient mice versus those from wild type animals.
Full description | Transcription factors that regulate quiescence, proliferation, and homing of lymphocytes are critical for effective immune system function. In the present study, we demonstrated that the transcription factor ELF4 directly activates the tumor suppressor KLF4 downstream of T cell receptor (TCR) signaling to induce cell cycle arrest in naive CD8+ T cells. Elf4- and Klf4-deficient mice accumulated CD8+CD44hi T cells during steady-state conditions and generated more memory T cells after immunization. The homeostatic expansion of CD8+CD44hi T cells in Elf4-null mice resulted in a redistribution of cells to non-lymphoid tissue due to reduced expression of the transcription factor KLF2, and the surface proteins CCR7 and CD62L. This work describes the combinatorial role of lymphocyte-intrinsic factors in the control of T cell homeostasis, activation and homing.

Standard name | GSE15324_ELF4_KO_VS_WT_NAIVE_CD8_TCELL_DN
Systematic name | M3530
Organism | Mus musculus
PMID | 19412182
Authors | Yamada T,Park CS,Mamonkin M,Lacorazza HD.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells from ELF4 [GeneID=2000] defficient mice versus those from wild type animals.
Full description | Transcription factors that regulate quiescence, proliferation, and homing of lymphocytes are critical for effective immune system function. In the present study, we demonstrated that the transcription factor ELF4 directly activates the tumor suppressor KLF4 downstream of T cell receptor (TCR) signaling to induce cell cycle arrest in naive CD8+ T cells. Elf4- and Klf4-deficient mice accumulated CD8+CD44hi T cells during steady-state conditions and generated more memory T cells after immunization. The homeostatic expansion of CD8+CD44hi T cells in Elf4-null mice resulted in a redistribution of cells to non-lymphoid tissue due to reduced expression of the transcription factor KLF2, and the surface proteins CCR7 and CD62L. This work describes the combinatorial role of lymphocyte-intrinsic factors in the control of T cell homeostasis, activation and homing.

Standard name | GSE15324_ELF4_KO_VS_WT_ACTIVATED_CD8_TCELL_UP
Systematic name | M3531
Organism | Mus musculus
PMID | 19412182
Authors | Yamada T,Park CS,Mamonkin M,Lacorazza HD.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of activated CD8 T cells from ELF4 [GeneID=2000] defficient mice versus those from wild type animals.
Full description | Transcription factors that regulate quiescence, proliferation, and homing of lymphocytes are critical for effective immune system function. In the present study, we demonstrated that the transcription factor ELF4 directly activates the tumor suppressor KLF4 downstream of T cell receptor (TCR) signaling to induce cell cycle arrest in naive CD8+ T cells. Elf4- and Klf4-deficient mice accumulated CD8+CD44hi T cells during steady-state conditions and generated more memory T cells after immunization. The homeostatic expansion of CD8+CD44hi T cells in Elf4-null mice resulted in a redistribution of cells to non-lymphoid tissue due to reduced expression of the transcription factor KLF2, and the surface proteins CCR7 and CD62L. This work describes the combinatorial role of lymphocyte-intrinsic factors in the control of T cell homeostasis, activation and homing.

Standard name | GSE15324_ELF4_KO_VS_WT_ACTIVATED_CD8_TCELL_DN
Systematic name | M3533
Organism | Mus musculus
PMID | 19412182
Authors | Yamada T,Park CS,Mamonkin M,Lacorazza HD.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of activated CD8 T cells from ELF4 [GeneID=2000] defficient mice versus those from wild type animals.
Full description | Transcription factors that regulate quiescence, proliferation, and homing of lymphocytes are critical for effective immune system function. In the present study, we demonstrated that the transcription factor ELF4 directly activates the tumor suppressor KLF4 downstream of T cell receptor (TCR) signaling to induce cell cycle arrest in naive CD8+ T cells. Elf4- and Klf4-deficient mice accumulated CD8+CD44hi T cells during steady-state conditions and generated more memory T cells after immunization. The homeostatic expansion of CD8+CD44hi T cells in Elf4-null mice resulted in a redistribution of cells to non-lymphoid tissue due to reduced expression of the transcription factor KLF2, and the surface proteins CCR7 and CD62L. This work describes the combinatorial role of lymphocyte-intrinsic factors in the control of T cell homeostasis, activation and homing.

Standard name | GSE15659_TREG_VS_TCONV_UP
Systematic name | M3534
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) versus conventional T cells.
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_TREG_VS_TCONV_DN
Systematic name | M3535
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) versus conventional T cells.
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_NAIVE_VS_PTPRC_NEG_CD4_TCELL_UP
Systematic name | M3536
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus PTPRC+ [GeneID=5788] CD4 [GeneID=920] T cells.
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_NAIVE_VS_PTPRC_NEG_CD4_TCELL_DN
Systematic name | M3538
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus PTPRC+ [GeneID=5788] CD4 [GeneID=920] T cells.
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_NAIVE_CD4_TCELL_VS_RESTING_TREG_UP
Systematic name | M3540
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus resting regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_NAIVE_CD4_TCELL_VS_RESTING_TREG_DN
Systematic name | M3542
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus resting regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_NAIVE_CD4_TCELL_VS_NONSUPPRESSIVE_TCELL_UP
Systematic name | M3545
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus non-suppressive T cells.
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_NAIVE_CD4_TCELL_VS_NONSUPPRESSIVE_TCELL_DN
Systematic name | M3547
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus non-suppressive T cells.
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_NAIVE_CD4_TCELL_VS_ACTIVATED_TREG_UP
Systematic name | M3549
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus activated regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_NAIVE_CD4_TCELL_VS_ACTIVATED_TREG_DN
Systematic name | M3550
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus activated regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_CD45RA_NEG_CD4_TCELL_VS_RESTING_TREG_UP
Systematic name | M3551
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of PTPRC- [GeneID=5788] CD4 [GeneID=920] T cells versus PTPRC+ [GeneID=5788] resting regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_CD45RA_NEG_CD4_TCELL_VS_RESTING_TREG_DN
Systematic name | M3552
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of PTPRC- [GeneID=5788] CD4 [GeneID=920] T cells versus PTPRC+ [GeneID=5788] resting regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_CD45RA_NEG_CD4_TCELL_VS_NONSUPPRESSIVE_TCELL_UP
Systematic name | M3553
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of PTPRC- [GeneID=5788] CD4 [GeneID=920] T cells versus non-suppressive T cells.
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_CD45RA_NEG_CD4_TCELL_VS_NONSUPPRESSIVE_TCELL_DN
Systematic name | M3554
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of PTPRC- [GeneID=5788] CD4 [GeneID=920] T cells versus non-suppressive T cells.
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_CD45RA_NEG_CD4_TCELL_VS_ACTIVATED_TREG_UP
Systematic name | M3555
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of PTPRC- [GeneID=5788] CD4 [GeneID=920] T cells versus activated regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_CD45RA_NEG_CD4_TCELL_VS_ACTIVATED_TREG_DN
Systematic name | M3557
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of PTPRC- [GeneID=5788] CD4 [GeneID=920] T cells versus activated regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_RESTING_TREG_VS_NONSUPPRESSIVE_TCELL_UP
Systematic name | M3558
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of resting regulatory T cell (Treg) versus non-suppressive T cells.
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_RESTING_TREG_VS_NONSUPPRESSIVE_TCELL_DN
Systematic name | M3560
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of resting regulatory T cell (Treg) versus non-suppressive T cells.
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_RESTING_VS_ACTIVATED_TREG_UP
Systematic name | M3561
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of resting regulatory T cell (Treg) versus activated regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_RESTING_VS_ACTIVATED_TREG_DN
Systematic name | M3563
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of resting regulatory T cell (Treg) versus activated regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_NONSUPPRESSIVE_TCELL_VS_ACTIVATED_TREG_UP
Systematic name | M3566
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of non-suppressive T cells versus activated regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15659_NONSUPPRESSIVE_TCELL_VS_ACTIVATED_TREG_DN
Systematic name | M3567
Organism | Homo sapiens
PMID | 19464196
Authors | Miyara M,Yoshioka Y,Kitoh A,Shima T,Wing K,Niwa A,Parizot C,Taflin C,Heike T,Valeyre D,Mathian A,Nakahata T,Yamaguchi T,Nomura T,Ono M,Amoura Z,Gorochov G,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of non-suppressive T cells versus activated regulatory T cell (Treg).
Full description | Gene expression profiles of subsets of CD4+ T cells according to their expression of FoxP3 and CD45RA were compared. FoxP3 is a key transcription factor for the development and function of natural CD4+ regulatory T cells (Tregs). Here we show that human FoxP3+CD4+ T cells are composed of three phenotypically and functionally distinct subpopulations: CD45RA+FoxP3low resting Tregs (rTregs) and CD45RA-FoxP3high activated Tregs (aTregs), both of which are suppressive in vitro, and cytokine-secreting CD45RA-FoxP3low non-suppressive T cells. The proportion of the three subpopulations characteristically altered in cord blood, aged individuals, and patients with immunological diseases. Terminally differentiated aTregs rapidly die while rTregs proliferate and convert into aTregs in vitro and in vivo as shown by the transfer of rTregs into NOD-scid-common gamma-chain-knockout mice and by TCR sequence-based T cell clonotype tracing in peripheral blood of normal individuals. Taken together, the dissection of FoxP3+ cells into subsets enables one to analyze Treg differentiation dynamics and interactions in normal and disease states, and to control immune responses through manipulating particular FoxP3+ subpopulations.

Standard name | GSE15733_BM_VS_SPLEEN_MEMORY_CD4_TCELL_UP
Systematic name | M3568
Organism | Mus musculus
PMID | 19427242
Authors | Tokoyoda K,Zehentmeier S,Hegazy AN,Albrecht I,Grün JR,Löhning M,Radbruch A
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells from bone marrow versus those from spleen.
Full description | CD4+ T lymphocytes are key to immunological memory, but little is known about the lifestyle of memory CD4+ T lymphocytes. We showed that in the memory phase of specific immune responses to antigens, most of the memory CD4+ T lymphocytes relocated into the bone marrow (BM) within 3-8 weeks after their generation, a process involving integrin a2. Antigen-specific memory CD4+ T lymphocytes expressed Ly-6C to a high degree, unlike most splenic CD44hiCD62L- CD4+ T lymphocytes. In adult mice, more than 80% of Ly-6Chi CD44hiCD62L- memory CD4+ T lymphocytes were in the BM. In the BM, they are located next to IL-7-expressing VCAM-1+ stroma cells, and were in a resting state. Upon challenge with antigen, they rapidly expressed cytokines and CD154 and induced the production of high-affinity antibodies, indicating their functional activity in vivo and marking them as professional memory T helper cells

Standard name | GSE15733_BM_VS_SPLEEN_MEMORY_CD4_TCELL_DN
Systematic name | M3569
Organism | Mus musculus
PMID | 19427242
Authors | Tokoyoda K,Zehentmeier S,Hegazy AN,Albrecht I,Grün JR,Löhning M,Radbruch A
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells from bone marrow versus those from spleen.
Full description | CD4+ T lymphocytes are key to immunological memory, but little is known about the lifestyle of memory CD4+ T lymphocytes. We showed that in the memory phase of specific immune responses to antigens, most of the memory CD4+ T lymphocytes relocated into the bone marrow (BM) within 3-8 weeks after their generation, a process involving integrin a2. Antigen-specific memory CD4+ T lymphocytes expressed Ly-6C to a high degree, unlike most splenic CD44hiCD62L- CD4+ T lymphocytes. In adult mice, more than 80% of Ly-6Chi CD44hiCD62L- memory CD4+ T lymphocytes were in the BM. In the BM, they are located next to IL-7-expressing VCAM-1+ stroma cells, and were in a resting state. Upon challenge with antigen, they rapidly expressed cytokines and CD154 and induced the production of high-affinity antibodies, indicating their functional activity in vivo and marking them as professional memory T helper cells

Standard name | GSE15750_WT_VS_TRAF6KO_DAY6_EFF_CD8_TCELL_UP
Systematic name | M3570
Organism | Mus musculus
PMID | 19494812
Authors | Pearce EL,Walsh MC,Cejas PJ,Harms GM,Shen H,Wang LS,Jones RG,Choi Y.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of wild type CD8 effector T cells at day 6 versus those from mice defficient for TRAF6 [GeneID=7189] at day 6.
Full description | CD8 T cells play a crucial role in immunity to infection and cancer. They are maintained in constant numbers, but upon stimulation with antigen undergo a developmental program characterized by distinct phases encompassing the expansion and then contraction of antigen-specific populations, followed by the persistence of long-lived memory cells. Although this predictable pattern of a CD8 T cell response is well established, the underlying cellular mechanisms regulating the transition to memory remain undefined. Here we show that TRAF6, an adapter protein in the TNF-receptor (TNFR) and IL-1R/TLR superfamily, regulates CD8 T cell memory development following infection by modulating fatty acid metabolism. We show that mice with a T cell-specific deletion of TRAF6 mount robust primary CD8 T cell effector responses, but have a profound defect in their ability to generate memory. This defect is CD8 T cell intrinsic and is characterized by the disappearance of antigen-specific cells in the weeks following primary immunization. Microarray analyses revealed that TRAF6-deficient CD8 T cells from early timepoints following immunization exhibit altered expression of genes that regulate fatty acid metabolism. Consistent with this, activated CD8 T cells lacking TRAF6 are unable to upregulate mitochondrial β-oxidation in response to growth factor withdrawal in vitro. Treatment with drugs that induce fatty acid oxidation enabled CD8 T cell memory generation in the absence of TRAF6. Remarkably, these treatments also increased CD8 T cell memory in wild type mice, and consequently were able to significantly improve the efficacy of an experimental anti-cancer vaccine.

Standard name | GSE15750_WT_VS_TRAF6KO_DAY6_EFF_CD8_TCELL_DN
Systematic name | M3571
Organism | Mus musculus
PMID | 19494812
Authors | Pearce EL,Walsh MC,Cejas PJ,Harms GM,Shen H,Wang LS,Jones RG,Choi Y.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of wild type CD8 effector T cells at day 6 versus those from mice defficient for TRAF6 [GeneID=7189] at day 6.
Full description | CD8 T cells play a crucial role in immunity to infection and cancer. They are maintained in constant numbers, but upon stimulation with antigen undergo a developmental program characterized by distinct phases encompassing the expansion and then contraction of antigen-specific populations, followed by the persistence of long-lived memory cells. Although this predictable pattern of a CD8 T cell response is well established, the underlying cellular mechanisms regulating the transition to memory remain undefined. Here we show that TRAF6, an adapter protein in the TNF-receptor (TNFR) and IL-1R/TLR superfamily, regulates CD8 T cell memory development following infection by modulating fatty acid metabolism. We show that mice with a T cell-specific deletion of TRAF6 mount robust primary CD8 T cell effector responses, but have a profound defect in their ability to generate memory. This defect is CD8 T cell intrinsic and is characterized by the disappearance of antigen-specific cells in the weeks following primary immunization. Microarray analyses revealed that TRAF6-deficient CD8 T cells from early timepoints following immunization exhibit altered expression of genes that regulate fatty acid metabolism. Consistent with this, activated CD8 T cells lacking TRAF6 are unable to upregulate mitochondrial β-oxidation in response to growth factor withdrawal in vitro. Treatment with drugs that induce fatty acid oxidation enabled CD8 T cell memory generation in the absence of TRAF6. Remarkably, these treatments also increased CD8 T cell memory in wild type mice, and consequently were able to significantly improve the efficacy of an experimental anti-cancer vaccine.

Standard name | GSE15750_WT_VS_TRAF6KO_DAY10_EFF_CD8_TCELL_UP
Systematic name | M3573
Organism | Mus musculus
PMID | 19494812
Authors | Pearce EL,Walsh MC,Cejas PJ,Harms GM,Shen H,Wang LS,Jones RG,Choi Y.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of wild type CD8 effector T cells at day 10 versus those from mice defficient for TRAF6 [GeneID=7189] at day 10.
Full description | CD8 T cells play a crucial role in immunity to infection and cancer. They are maintained in constant numbers, but upon stimulation with antigen undergo a developmental program characterized by distinct phases encompassing the expansion and then contraction of antigen-specific populations, followed by the persistence of long-lived memory cells. Although this predictable pattern of a CD8 T cell response is well established, the underlying cellular mechanisms regulating the transition to memory remain undefined. Here we show that TRAF6, an adapter protein in the TNF-receptor (TNFR) and IL-1R/TLR superfamily, regulates CD8 T cell memory development following infection by modulating fatty acid metabolism. We show that mice with a T cell-specific deletion of TRAF6 mount robust primary CD8 T cell effector responses, but have a profound defect in their ability to generate memory. This defect is CD8 T cell intrinsic and is characterized by the disappearance of antigen-specific cells in the weeks following primary immunization. Microarray analyses revealed that TRAF6-deficient CD8 T cells from early timepoints following immunization exhibit altered expression of genes that regulate fatty acid metabolism. Consistent with this, activated CD8 T cells lacking TRAF6 are unable to upregulate mitochondrial β-oxidation in response to growth factor withdrawal in vitro. Treatment with drugs that induce fatty acid oxidation enabled CD8 T cell memory generation in the absence of TRAF6. Remarkably, these treatments also increased CD8 T cell memory in wild type mice, and consequently were able to significantly improve the efficacy of an experimental anti-cancer vaccine.

Standard name | GSE15750_WT_VS_TRAF6KO_DAY10_EFF_CD8_TCELL_DN
Systematic name | M3575
Organism | Mus musculus
PMID | 19494812
Authors | Pearce EL,Walsh MC,Cejas PJ,Harms GM,Shen H,Wang LS,Jones RG,Choi Y.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of wild type CD8 effector T cells at day 10 versus those from mice defficient for TRAF6 [GeneID=7189] at day 10.
Full description | CD8 T cells play a crucial role in immunity to infection and cancer. They are maintained in constant numbers, but upon stimulation with antigen undergo a developmental program characterized by distinct phases encompassing the expansion and then contraction of antigen-specific populations, followed by the persistence of long-lived memory cells. Although this predictable pattern of a CD8 T cell response is well established, the underlying cellular mechanisms regulating the transition to memory remain undefined. Here we show that TRAF6, an adapter protein in the TNF-receptor (TNFR) and IL-1R/TLR superfamily, regulates CD8 T cell memory development following infection by modulating fatty acid metabolism. We show that mice with a T cell-specific deletion of TRAF6 mount robust primary CD8 T cell effector responses, but have a profound defect in their ability to generate memory. This defect is CD8 T cell intrinsic and is characterized by the disappearance of antigen-specific cells in the weeks following primary immunization. Microarray analyses revealed that TRAF6-deficient CD8 T cells from early timepoints following immunization exhibit altered expression of genes that regulate fatty acid metabolism. Consistent with this, activated CD8 T cells lacking TRAF6 are unable to upregulate mitochondrial β-oxidation in response to growth factor withdrawal in vitro. Treatment with drugs that induce fatty acid oxidation enabled CD8 T cell memory generation in the absence of TRAF6. Remarkably, these treatments also increased CD8 T cell memory in wild type mice, and consequently were able to significantly improve the efficacy of an experimental anti-cancer vaccine.

Standard name | GSE15750_DAY6_VS_DAY10_EFF_CD8_TCELL_UP
Systematic name | M3577
Organism | Mus musculus
PMID | 19494812
Authors | Pearce EL,Walsh MC,Cejas PJ,Harms GM,Shen H,Wang LS,Jones RG,Choi Y.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of wild type CD8 effector T cells at day 6 versus those at day 10.
Full description | CD8 T cells play a crucial role in immunity to infection and cancer. They are maintained in constant numbers, but upon stimulation with antigen undergo a developmental program characterized by distinct phases encompassing the expansion and then contraction of antigen-specific populations, followed by the persistence of long-lived memory cells. Although this predictable pattern of a CD8 T cell response is well established, the underlying cellular mechanisms regulating the transition to memory remain undefined. Here we show that TRAF6, an adapter protein in the TNF-receptor (TNFR) and IL-1R/TLR superfamily, regulates CD8 T cell memory development following infection by modulating fatty acid metabolism. We show that mice with a T cell-specific deletion of TRAF6 mount robust primary CD8 T cell effector responses, but have a profound defect in their ability to generate memory. This defect is CD8 T cell intrinsic and is characterized by the disappearance of antigen-specific cells in the weeks following primary immunization. Microarray analyses revealed that TRAF6-deficient CD8 T cells from early timepoints following immunization exhibit altered expression of genes that regulate fatty acid metabolism. Consistent with this, activated CD8 T cells lacking TRAF6 are unable to upregulate mitochondrial β-oxidation in response to growth factor withdrawal in vitro. Treatment with drugs that induce fatty acid oxidation enabled CD8 T cell memory generation in the absence of TRAF6. Remarkably, these treatments also increased CD8 T cell memory in wild type mice, and consequently were able to significantly improve the efficacy of an experimental anti-cancer vaccine.

Standard name | GSE15750_DAY6_VS_DAY10_EFF_CD8_TCELL_DN
Systematic name | M3579
Organism | Mus musculus
PMID | 19494812
Authors | Pearce EL,Walsh MC,Cejas PJ,Harms GM,Shen H,Wang LS,Jones RG,Choi Y.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of wild type CD8 effector T cells at day 6 versus those at day 10.
Full description | CD8 T cells play a crucial role in immunity to infection and cancer. They are maintained in constant numbers, but upon stimulation with antigen undergo a developmental program characterized by distinct phases encompassing the expansion and then contraction of antigen-specific populations, followed by the persistence of long-lived memory cells. Although this predictable pattern of a CD8 T cell response is well established, the underlying cellular mechanisms regulating the transition to memory remain undefined. Here we show that TRAF6, an adapter protein in the TNF-receptor (TNFR) and IL-1R/TLR superfamily, regulates CD8 T cell memory development following infection by modulating fatty acid metabolism. We show that mice with a T cell-specific deletion of TRAF6 mount robust primary CD8 T cell effector responses, but have a profound defect in their ability to generate memory. This defect is CD8 T cell intrinsic and is characterized by the disappearance of antigen-specific cells in the weeks following primary immunization. Microarray analyses revealed that TRAF6-deficient CD8 T cells from early timepoints following immunization exhibit altered expression of genes that regulate fatty acid metabolism. Consistent with this, activated CD8 T cells lacking TRAF6 are unable to upregulate mitochondrial β-oxidation in response to growth factor withdrawal in vitro. Treatment with drugs that induce fatty acid oxidation enabled CD8 T cell memory generation in the absence of TRAF6. Remarkably, these treatments also increased CD8 T cell memory in wild type mice, and consequently were able to significantly improve the efficacy of an experimental anti-cancer vaccine.

Standard name | GSE15750_DAY6_VS_DAY10_TRAF6KO_EFF_CD8_TCELL_UP
Systematic name | M3580
Organism | Mus musculus
PMID | 19494812
Authors | Pearce EL,Walsh MC,Cejas PJ,Harms GM,Shen H,Wang LS,Jones RG,Choi Y.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of wild type CD8 effector T cells at day 6 versus those from mice defficient for TRAF6 [GeneID=7189] at day 10.
Full description | CD8 T cells play a crucial role in immunity to infection and cancer. They are maintained in constant numbers, but upon stimulation with antigen undergo a developmental program characterized by distinct phases encompassing the expansion and then contraction of antigen-specific populations, followed by the persistence of long-lived memory cells. Although this predictable pattern of a CD8 T cell response is well established, the underlying cellular mechanisms regulating the transition to memory remain undefined. Here we show that TRAF6, an adapter protein in the TNF-receptor (TNFR) and IL-1R/TLR superfamily, regulates CD8 T cell memory development following infection by modulating fatty acid metabolism. We show that mice with a T cell-specific deletion of TRAF6 mount robust primary CD8 T cell effector responses, but have a profound defect in their ability to generate memory. This defect is CD8 T cell intrinsic and is characterized by the disappearance of antigen-specific cells in the weeks following primary immunization. Microarray analyses revealed that TRAF6-deficient CD8 T cells from early timepoints following immunization exhibit altered expression of genes that regulate fatty acid metabolism. Consistent with this, activated CD8 T cells lacking TRAF6 are unable to upregulate mitochondrial β-oxidation in response to growth factor withdrawal in vitro. Treatment with drugs that induce fatty acid oxidation enabled CD8 T cell memory generation in the absence of TRAF6. Remarkably, these treatments also increased CD8 T cell memory in wild type mice, and consequently were able to significantly improve the efficacy of an experimental anti-cancer vaccine.

Standard name | GSE15750_DAY6_VS_DAY10_TRAF6KO_EFF_CD8_TCELL_DN
Systematic name | M3583
Organism | Mus musculus
PMID | 19494812
Authors | Pearce EL,Walsh MC,Cejas PJ,Harms GM,Shen H,Wang LS,Jones RG,Choi Y.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of wild type CD8 effector T cells at day 6 versus those from mice defficient for TRAF6 [GeneID=7189] at day 10.
Full description | CD8 T cells play a crucial role in immunity to infection and cancer. They are maintained in constant numbers, but upon stimulation with antigen undergo a developmental program characterized by distinct phases encompassing the expansion and then contraction of antigen-specific populations, followed by the persistence of long-lived memory cells. Although this predictable pattern of a CD8 T cell response is well established, the underlying cellular mechanisms regulating the transition to memory remain undefined. Here we show that TRAF6, an adapter protein in the TNF-receptor (TNFR) and IL-1R/TLR superfamily, regulates CD8 T cell memory development following infection by modulating fatty acid metabolism. We show that mice with a T cell-specific deletion of TRAF6 mount robust primary CD8 T cell effector responses, but have a profound defect in their ability to generate memory. This defect is CD8 T cell intrinsic and is characterized by the disappearance of antigen-specific cells in the weeks following primary immunization. Microarray analyses revealed that TRAF6-deficient CD8 T cells from early timepoints following immunization exhibit altered expression of genes that regulate fatty acid metabolism. Consistent with this, activated CD8 T cells lacking TRAF6 are unable to upregulate mitochondrial β-oxidation in response to growth factor withdrawal in vitro. Treatment with drugs that induce fatty acid oxidation enabled CD8 T cell memory generation in the absence of TRAF6. Remarkably, these treatments also increased CD8 T cell memory in wild type mice, and consequently were able to significantly improve the efficacy of an experimental anti-cancer vaccine.

Standard name | GSE15767_MED_VS_SCS_MAC_LN_UP
Systematic name | M3584
Organism | Mus musculus
PMID | 19503106
Authors | Phan TG,Green JA,Gray EE,Xu Y,Cyster JG.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of medullary macrophages versus subcapsular sinus (SCS) macrophages.
Full description | LN resident macrophages lining the lymphatic sinuses play critical roles in antigen capture and presentation as well as degradation. We used microarray to examine global gene expression profiles to compare SCS and med macrophages to determine the underlying molecular basis of their differential handling of antigens.

Standard name | GSE15767_MED_VS_SCS_MAC_LN_DN
Systematic name | M3585
Organism | Mus musculus
PMID | 19503106
Authors | Phan TG,Green JA,Gray EE,Xu Y,Cyster JG.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of medullary macrophages versus subcapsular sinus (SCS) macrophages.
Full description | LN resident macrophages lining the lymphatic sinuses play critical roles in antigen capture and presentation as well as degradation. We used microarray to examine global gene expression profiles to compare SCS and med macrophages to determine the underlying molecular basis of their differential handling of antigens.

Standard name | GSE15930_NAIVE_VS_24H_IN_VITRO_STIM_CD8_TCELL_UP
Systematic name | M3587
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells at 0 h versus those at 24 h.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_24H_IN_VITRO_STIM_CD8_TCELL_DN
Systematic name | M3588
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells at 0 h versus those at 24 h.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_24H_IN_VITRO_STIM_IL12_CD8_TCELL_UP
Systematic name | M3589
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells at 0 h versus those at 24 h after stimulation with IL12 .
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_24H_IN_VITRO_STIM_IL12_CD8_TCELL_DN
Systematic name | M3591
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells at 0 h versus those at 24 h after stimulation with IL12 .
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_24H_IN_VITRO_STIM_INFAB_CD8_TCELL_UP
Systematic name | M3593
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells at 0 h versus those at 24 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_24H_IN_VITRO_STIM_INFAB_CD8_TCELL_DN
Systematic name | M3594
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells at 0 h versus those at 24 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_48H_IN_VITRO_STIM_CD8_TCELL_UP
Systematic name | M3596
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells at 0 h versus those at 48 h.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_48H_IN_VITRO_STIM_CD8_TCELL_DN
Systematic name | M3597
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells at 0 h versus those at 48 h.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_48H_IN_VITRO_STIM_IL12_CD8_TCELL_UP
Systematic name | M3599
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells at 0 h versus those at 48 h after stimulation with IL12.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_48H_IN_VITRO_STIM_IL12_CD8_TCELL_DN
Systematic name | M3600
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells at 0 h versus those at 48 h after stimulation with IL12.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_48H_IN_VITRO_STIM_IFNAB_CD8_TCELL_UP
Systematic name | M3601
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells at 0 h versus those at 48 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_48H_IN_VITRO_STIM_IFNAB_CD8_TCELL_DN
Systematic name | M3604
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells at 0 h versus those at 48 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_72H_IN_VITRO_STIM_CD8_TCELL_UP
Systematic name | M3605
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells at 0 h versus those at 72 h.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_72H_IN_VITRO_STIM_CD8_TCELL_DN
Systematic name | M3607
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells at 0 h versus those at 72 h.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_72H_IN_VITRO_STIM_IL12_CD8_TCELL_UP
Systematic name | M3608
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells at 0 h versus those at 72 h after stimulation with IL12.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_72H_IN_VITRO_STIM_IL12_CD8_TCELL_DN
Systematic name | M3610
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells at 0 h versus those at 72 h after stimulation with IL12.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_72H_IN_VITRO_STIM_IFNAB_CD8_TCELL_UP
Systematic name | M3612
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells at 0 h versus those at 72 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_72H_IN_VITRO_STIM_IFNAB_CD8_TCELL_DN
Systematic name | M3613
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells at 0 h versus those at 72 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_72H_IN_VITRO_STIM_TRICHOSTATINA_CD8_TCELL_UP
Systematic name | M3614
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells at 0 h versus those at 72 h after treatment with trichostatin A (TSA) [PubChem=5562].
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_NAIVE_VS_72H_IN_VITRO_STIM_TRICHOSTATINA_CD8_TCELL_DN
Systematic name | M3619
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells at 0 h versus those at 72 h after treatment with trichostatin A (TSA) [PubChem=5562].
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IL12_24H_CD8_T_CELL_UP
Systematic name | M3620
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated CD8 T cells at 24 h versus CD8 T cells at 24 h after stimulation with IL12.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IL12_24H_CD8_T_CELL_DN
Systematic name | M3622
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated CD8 T cells at 24 h versus CD8 T cells at 24 h after stimulation with IL12.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IFNAB_24H_CD8_T_CELL_UP
Systematic name | M3623
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated CD8 T cells at 24 h versus CD8 T cells at 24 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IFNAB_24H_CD8_T_CELL_DN
Systematic name | M3626
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated CD8 T cells at 24 h versus CD8 T cells at 24 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_TRICHOSTATINA_24H_CD8_T_CELL_UP
Systematic name | M3627
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated CD8 T cells at 24 h versus CD8 T cells at 24 h after treatment with trichostatin A (TSA) [PubChem=5562].
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_TRICHOSTATINA_24H_CD8_T_CELL_DN
Systematic name | M3628
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated CD8 T cells at 24 h versus CD8 T cells at 24 h after treatment with trichostatin A (TSA) [PubChem=5562].
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IL12_48H_CD8_T_CELL_UP
Systematic name | M3629
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated CD8 T cells at 48 h versus CD8 T cells at 48 h after stimulation with IL12.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IL12_48H_CD8_T_CELL_DN
Systematic name | M3631
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated CD8 T cells at 48 h versus CD8 T cells at 48 h after stimulation with IL12.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IFNAB_48H_CD8_T_CELL_UP
Systematic name | M3633
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated CD8 T cells at 48 h versus CD8 T cells at 48 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IFNAB_48H_CD8_T_CELL_DN
Systematic name | M3635
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated CD8 T cells at 48 h versus CD8 T cells at 48 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_TRICHOSTATINA_48H_CD8_T_CELL_UP
Systematic name | M3636
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated CD8 T cells at 48 h versus CD8 T cells at 48 h after treatment with trichostatin A (TSA) [PubChem=5562].
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_TRICHOSTATINA_48H_CD8_T_CELL_DN
Systematic name | M3638
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated CD8 T cells at 48 h versus CD8 T cells at 48 h after treatment with trichostatin A (TSA) [PubChem=5562].
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IL12_72H_CD8_T_CELL_UP
Systematic name | M3639
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated CD8 T cells at 72 h versus CD8 T cells at 72 h after stimulation with IL12.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IL12_72H_CD8_T_CELL_DN
Systematic name | M3640
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated CD8 T cells at 72 h versus CD8 T cells at 72 h after stimulation with IL12.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IFNAB_72H_CD8_T_CELL_UP
Systematic name | M3641
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated CD8 T cells at 72 h versus CD8 T cells at 72 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_IFNAB_72H_CD8_T_CELL_DN
Systematic name | M3646
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated CD8 T cells at 72 h versus CD8 T cells at 72 h after stimulation with antigen-B7-1.
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_TRICHOSTATINA_72H_CD8_T_CELL_UP
Systematic name | M3648
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated CD8 T cells at 72 h versus CD8 T cells at 72 h after treatment with trichostatin A (TSA) [PubChem=5562].
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE15930_STIM_VS_STIM_AND_TRICHOSTATINA_72H_CD8_T_CELL_DN
Systematic name | M3653
Organism | Mus musculus
PMID | 19592655
Authors | Agarwal P,Raghavan A,Nandiwada SL,Curtsinger JM,Bohjanen PR,Mueller DL,Mescher MF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated CD8 T cells at 72 h versus CD8 T cells at 72 h after treatment with trichostatin A (TSA) [PubChem=5562].
Full description | Differentiation of naive CD8 T cells into cytotoxic effector cells requires three distinct signals- antigen (signal 1), costimulation -B7-1 (signal 2) and cytokine, either interleukin-12 or interferon-a/b (signal 3). Interaction of naive CD8 T cells with antigen and B7-1 programs cell division and proliferation whereas the presence of cytokines- IL-12 or IFNa/b promote survival, differentiation and memory establishment. In the absence of signal 3, the cells interacting with antigen/B7-1 undergo tolerance induction. The objective of this study was to elucidate the mechanisms how the provision of signal 3 promotes differentiation and averts tolerance induction in CD8 T cells. Trichostatin A is a pharmacological agent that inhibits histone deacetylase activity, hence regulating chromatin structure and gene expression and differentiation in many cell types. Gene signature profiles of IL-12, IFNa/b and trichostatin A stimulated cells were compared to elucidate the molecular mechanisms of gene regulation. Oligonucleotide microarray analysis is carried out to determine the extent and molecular nature of the CD8 T cell differentiation program induced by IL-12 or IFNa/b in concert with antigen and B7-1 signal.

Standard name | GSE16522_MEMORY_VS_NAIVE_CD8_TCELL_UP
Systematic name | M3655
Organism | Mus musculus
PMID | 19805141
Authors | Hinrichs CS,Borman ZA,Cassard L,Gattinoni L,Spolski R,Yu Z,Sanchez-Perez L,Muranski P,Kern SJ,Logun C,Palmer DC,Ji Y,Reger RN,Leonard WJ,Danner RL,Rosenberg SA,Restifo NP.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of rested memory CD8 T cells from pmel-1 mice versus rested naive CD8 T cells from pmel-1 mice.
Full description | Effector cells for adoptive immunotherapy can be generated by in vitro stimulation of naïve or memory subsets of CD8+ T cells. While the characteristics of CD8+ T cell subsets are well defined, the heritable influence of those populations on their effector cell progeny is not well understood. We studied effector cells generated from naïve or central memory CD8+ T cells and found that they retained distinct gene expression signatures and developmental programs. Effector cells derived from central memory cells tended to retain their CD62L+ phenotype, but also to acquire KLRG1, an indicator of cellular senescence. In contrast, the effector cell progeny of naïve cells displayed reduced terminal differentiation, and, following infusion, they displayed greater expansion, cytokine production, and tumor destruction. These data indicate that effector cells retain a gene expression imprint conferred by their naïve or central memory progenitors, and they suggest a strategy for enhancing cancer immunotherapy.

Standard name | GSE16522_MEMORY_VS_NAIVE_CD8_TCELL_DN
Systematic name | M3659
Organism | Mus musculus
PMID | 19805141
Authors | Hinrichs CS,Borman ZA,Cassard L,Gattinoni L,Spolski R,Yu Z,Sanchez-Perez L,Muranski P,Kern SJ,Logun C,Palmer DC,Ji Y,Reger RN,Leonard WJ,Danner RL,Rosenberg SA,Restifo NP.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of rested memory CD8 T cells from pmel-1 mice versus rested naive CD8 T cells from pmel-1 mice.
Full description | Effector cells for adoptive immunotherapy can be generated by in vitro stimulation of naïve or memory subsets of CD8+ T cells. While the characteristics of CD8+ T cell subsets are well defined, the heritable influence of those populations on their effector cell progeny is not well understood. We studied effector cells generated from naïve or central memory CD8+ T cells and found that they retained distinct gene expression signatures and developmental programs. Effector cells derived from central memory cells tended to retain their CD62L+ phenotype, but also to acquire KLRG1, an indicator of cellular senescence. In contrast, the effector cell progeny of naïve cells displayed reduced terminal differentiation, and, following infusion, they displayed greater expansion, cytokine production, and tumor destruction. These data indicate that effector cells retain a gene expression imprint conferred by their naïve or central memory progenitors, and they suggest a strategy for enhancing cancer immunotherapy.

Standard name | GSE16522_MEMORY_VS_NAIVE_ANTI_CD3CD28_STIM_CD8_TCELL_UP
Systematic name | M3660
Organism | Mus musculus
PMID | 19805141
Authors | Hinrichs CS,Borman ZA,Cassard L,Gattinoni L,Spolski R,Yu Z,Sanchez-Perez L,Muranski P,Kern SJ,Logun C,Palmer DC,Ji Y,Reger RN,Leonard WJ,Danner RL,Rosenberg SA,Restifo NP.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of stimulated memory CD8 T cells from pmel-1 mice versus stimulated naive CD8 T cells from pmel-1 mice.
Full description | Effector cells for adoptive immunotherapy can be generated by in vitro stimulation of naïve or memory subsets of CD8+ T cells. While the characteristics of CD8+ T cell subsets are well defined, the heritable influence of those populations on their effector cell progeny is not well understood. We studied effector cells generated from naïve or central memory CD8+ T cells and found that they retained distinct gene expression signatures and developmental programs. Effector cells derived from central memory cells tended to retain their CD62L+ phenotype, but also to acquire KLRG1, an indicator of cellular senescence. In contrast, the effector cell progeny of naïve cells displayed reduced terminal differentiation, and, following infusion, they displayed greater expansion, cytokine production, and tumor destruction. These data indicate that effector cells retain a gene expression imprint conferred by their naïve or central memory progenitors, and they suggest a strategy for enhancing cancer immunotherapy.

Standard name | GSE16522_MEMORY_VS_NAIVE_ANTI_CD3CD28_STIM_CD8_TCELL_DN
Systematic name | M3662
Organism | Mus musculus
PMID | 19805141
Authors | Hinrichs CS,Borman ZA,Cassard L,Gattinoni L,Spolski R,Yu Z,Sanchez-Perez L,Muranski P,Kern SJ,Logun C,Palmer DC,Ji Y,Reger RN,Leonard WJ,Danner RL,Rosenberg SA,Restifo NP.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of stimulated memory CD8 T cells from pmel-1 mice versus stimulated naive CD8 T cells from pmel-1 mice.
Full description | Effector cells for adoptive immunotherapy can be generated by in vitro stimulation of naïve or memory subsets of CD8+ T cells. While the characteristics of CD8+ T cell subsets are well defined, the heritable influence of those populations on their effector cell progeny is not well understood. We studied effector cells generated from naïve or central memory CD8+ T cells and found that they retained distinct gene expression signatures and developmental programs. Effector cells derived from central memory cells tended to retain their CD62L+ phenotype, but also to acquire KLRG1, an indicator of cellular senescence. In contrast, the effector cell progeny of naïve cells displayed reduced terminal differentiation, and, following infusion, they displayed greater expansion, cytokine production, and tumor destruction. These data indicate that effector cells retain a gene expression imprint conferred by their naïve or central memory progenitors, and they suggest a strategy for enhancing cancer immunotherapy.

Standard name | GSE16522_ANTI_CD3CD28_STIM_VS_UNSTIM_MEMORY_CD8_TCELL_UP
Systematic name | M3663
Organism | Mus musculus
PMID | 19805141
Authors | Hinrichs CS,Borman ZA,Cassard L,Gattinoni L,Spolski R,Yu Z,Sanchez-Perez L,Muranski P,Kern SJ,Logun C,Palmer DC,Ji Y,Reger RN,Leonard WJ,Danner RL,Rosenberg SA,Restifo NP.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of stimulated memory CD8 T cells from pmel-1 mice versus unstimulated memory CD8 T cells from pmel-1 mice.
Full description | Effector cells for adoptive immunotherapy can be generated by in vitro stimulation of naïve or memory subsets of CD8+ T cells. While the characteristics of CD8+ T cell subsets are well defined, the heritable influence of those populations on their effector cell progeny is not well understood. We studied effector cells generated from naïve or central memory CD8+ T cells and found that they retained distinct gene expression signatures and developmental programs. Effector cells derived from central memory cells tended to retain their CD62L+ phenotype, but also to acquire KLRG1, an indicator of cellular senescence. In contrast, the effector cell progeny of naïve cells displayed reduced terminal differentiation, and, following infusion, they displayed greater expansion, cytokine production, and tumor destruction. These data indicate that effector cells retain a gene expression imprint conferred by their naïve or central memory progenitors, and they suggest a strategy for enhancing cancer immunotherapy.

Standard name | GSE16522_ANTI_CD3CD28_STIM_VS_UNSTIM_MEMORY_CD8_TCELL_DN
Systematic name | M3664
Organism | Mus musculus
PMID | 19805141
Authors | Hinrichs CS,Borman ZA,Cassard L,Gattinoni L,Spolski R,Yu Z,Sanchez-Perez L,Muranski P,Kern SJ,Logun C,Palmer DC,Ji Y,Reger RN,Leonard WJ,Danner RL,Rosenberg SA,Restifo NP.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of stimulated memory CD8 T cells from pmel-1 mice versus unstimulated memory CD8 T cells from pmel-1 mice.
Full description | Effector cells for adoptive immunotherapy can be generated by in vitro stimulation of naïve or memory subsets of CD8+ T cells. While the characteristics of CD8+ T cell subsets are well defined, the heritable influence of those populations on their effector cell progeny is not well understood. We studied effector cells generated from naïve or central memory CD8+ T cells and found that they retained distinct gene expression signatures and developmental programs. Effector cells derived from central memory cells tended to retain their CD62L+ phenotype, but also to acquire KLRG1, an indicator of cellular senescence. In contrast, the effector cell progeny of naïve cells displayed reduced terminal differentiation, and, following infusion, they displayed greater expansion, cytokine production, and tumor destruction. These data indicate that effector cells retain a gene expression imprint conferred by their naïve or central memory progenitors, and they suggest a strategy for enhancing cancer immunotherapy.

Standard name | GSE16522_ANTI_CD3CD28_STIM_VS_UNSTIM_NAIVE_CD8_TCELL_UP
Systematic name | M3666
Organism | Mus musculus
PMID | 19805141
Authors | Hinrichs CS,Borman ZA,Cassard L,Gattinoni L,Spolski R,Yu Z,Sanchez-Perez L,Muranski P,Kern SJ,Logun C,Palmer DC,Ji Y,Reger RN,Leonard WJ,Danner RL,Rosenberg SA,Restifo NP.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of stimulated naive CD8 T cells from pmel-1 mice versus unstimulated naive CD8 T cells from pmel-1 mice.
Full description | Effector cells for adoptive immunotherapy can be generated by in vitro stimulation of naïve or memory subsets of CD8+ T cells. While the characteristics of CD8+ T cell subsets are well defined, the heritable influence of those populations on their effector cell progeny is not well understood. We studied effector cells generated from naïve or central memory CD8+ T cells and found that they retained distinct gene expression signatures and developmental programs. Effector cells derived from central memory cells tended to retain their CD62L+ phenotype, but also to acquire KLRG1, an indicator of cellular senescence. In contrast, the effector cell progeny of naïve cells displayed reduced terminal differentiation, and, following infusion, they displayed greater expansion, cytokine production, and tumor destruction. These data indicate that effector cells retain a gene expression imprint conferred by their naïve or central memory progenitors, and they suggest a strategy for enhancing cancer immunotherapy.

Standard name | GSE16522_ANTI_CD3CD28_STIM_VS_UNSTIM_NAIVE_CD8_TCELL_DN
Systematic name | M3667
Organism | Mus musculus
PMID | 19805141
Authors | Hinrichs CS,Borman ZA,Cassard L,Gattinoni L,Spolski R,Yu Z,Sanchez-Perez L,Muranski P,Kern SJ,Logun C,Palmer DC,Ji Y,Reger RN,Leonard WJ,Danner RL,Rosenberg SA,Restifo NP.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of stimulated naive CD8 T cells from pmel-1 mice versus unstimulated naive CD8 T cells from pmel-1 mice.
Full description | Effector cells for adoptive immunotherapy can be generated by in vitro stimulation of naïve or memory subsets of CD8+ T cells. While the characteristics of CD8+ T cell subsets are well defined, the heritable influence of those populations on their effector cell progeny is not well understood. We studied effector cells generated from naïve or central memory CD8+ T cells and found that they retained distinct gene expression signatures and developmental programs. Effector cells derived from central memory cells tended to retain their CD62L+ phenotype, but also to acquire KLRG1, an indicator of cellular senescence. In contrast, the effector cell progeny of naïve cells displayed reduced terminal differentiation, and, following infusion, they displayed greater expansion, cytokine production, and tumor destruction. These data indicate that effector cells retain a gene expression imprint conferred by their naïve or central memory progenitors, and they suggest a strategy for enhancing cancer immunotherapy.

Standard name | GSE16755_CTRL_VS_IFNA_TREATED_MAC_UP
Systematic name | M3668
Organism | Homo sapiens
PMID | 19556424
Authors | Greenwell-Wild T,Vázquez N,Jin W,Rangel Z,Munson PJ,Wahl SM
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control macrophages versus macrophages treated with interferon alpha.
Full description | To study effects of IFNalpha treatment on monocyte-derived macrophages which may influence susceptibility or resistance to HIV.

Standard name | GSE16755_CTRL_VS_IFNA_TREATED_MAC_DN
Systematic name | M3669
Organism | Homo sapiens
PMID | 19556424
Authors | Greenwell-Wild T,Vázquez N,Jin W,Rangel Z,Munson PJ,Wahl SM
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control macrophages versus macrophages treated with interferon alpha.
Full description | To study effects of IFNalpha treatment on monocyte-derived macrophages which may influence susceptibility or resistance to HIV.

Standard name | GSE17580_TREG_VS_TEFF_UP
Systematic name | M3670
Organism | Mus musculus
PMID | 20007528
Authors | Layland LE,Mages J,Loddenkemper C,Hoerauf A,Wagner H,Lang R,da Costa CU.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) from uninfected mice versus T effector cells from uninfected mice.
Full description | Although several markers have been associated with the characterization of regulatory T cells (Treg) and their function, no studies have investigated the dynamics of their phenotype during infection. Since the necessity of Treg to control immunopathology has been demonstrated, we used the chronic helminth infection model S. mansoni to address the impact on the Treg gene repertoire. Before gene expression profiling we first chose to study the localization and antigen-specific suppressive nature of classically defined Treg during infection. Presence of Foxp3+ cells were found especially in the periphery of granulomas and isolated CD4+CD25hiFoxp3+ Treg from infected mice blocked IFN-gamma and IL-10 cytokine secretion from infected CD4+CD25- effector T cells (Teff). Furthermore the gene expression patterns of Treg and Teff showed that in total 474 genes were significantly regulated during chronic schistosomiasis. Upon k-means clustering we identified genes exclusively regulated in all four populations including Foxp3, CD103, GITR, OX40 and CTLA-4: classical Treg markers. During infection however, several non-classical genes were up-regulated solely within the Treg population such as Slpi, Gzmb, Mt1, Fabp5, Nfil3, Socs2, Gpr177 and Klrg1. Using RT-PCR we confirmed aspects of the microarray data and in addition showed that the expression profile of Treg from S. mansoni-infected mice is simultaneously unique and comparative with Treg derived from other infections

Standard name | GSE17580_TREG_VS_TEFF_DN
Systematic name | M3671
Organism | Mus musculus
PMID | 20007528
Authors | Layland LE,Mages J,Loddenkemper C,Hoerauf A,Wagner H,Lang R,da Costa CU.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) from uninfected mice versus T effector cells from uninfected mice.
Full description | Although several markers have been associated with the characterization of regulatory T cells (Treg) and their function, no studies have investigated the dynamics of their phenotype during infection. Since the necessity of Treg to control immunopathology has been demonstrated, we used the chronic helminth infection model S. mansoni to address the impact on the Treg gene repertoire. Before gene expression profiling we first chose to study the localization and antigen-specific suppressive nature of classically defined Treg during infection. Presence of Foxp3+ cells were found especially in the periphery of granulomas and isolated CD4+CD25hiFoxp3+ Treg from infected mice blocked IFN-gamma and IL-10 cytokine secretion from infected CD4+CD25- effector T cells (Teff). Furthermore the gene expression patterns of Treg and Teff showed that in total 474 genes were significantly regulated during chronic schistosomiasis. Upon k-means clustering we identified genes exclusively regulated in all four populations including Foxp3, CD103, GITR, OX40 and CTLA-4: classical Treg markers. During infection however, several non-classical genes were up-regulated solely within the Treg population such as Slpi, Gzmb, Mt1, Fabp5, Nfil3, Socs2, Gpr177 and Klrg1. Using RT-PCR we confirmed aspects of the microarray data and in addition showed that the expression profile of Treg from S. mansoni-infected mice is simultaneously unique and comparative with Treg derived from other infections

Standard name | GSE17580_TREG_VS_TEFF_S_MANSONI_INF_UP
Systematic name | M3673
Organism | Mus musculus
PMID | 20007528
Authors | Layland LE,Mages J,Loddenkemper C,Hoerauf A,Wagner H,Lang R,da Costa CU.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) from mice infected with S. mansoni versus T effector cells from the infected mice.
Full description | Although several markers have been associated with the characterization of regulatory T cells (Treg) and their function, no studies have investigated the dynamics of their phenotype during infection. Since the necessity of Treg to control immunopathology has been demonstrated, we used the chronic helminth infection model S. mansoni to address the impact on the Treg gene repertoire. Before gene expression profiling we first chose to study the localization and antigen-specific suppressive nature of classically defined Treg during infection. Presence of Foxp3+ cells were found especially in the periphery of granulomas and isolated CD4+CD25hiFoxp3+ Treg from infected mice blocked IFN-gamma and IL-10 cytokine secretion from infected CD4+CD25- effector T cells (Teff). Furthermore the gene expression patterns of Treg and Teff showed that in total 474 genes were significantly regulated during chronic schistosomiasis. Upon k-means clustering we identified genes exclusively regulated in all four populations including Foxp3, CD103, GITR, OX40 and CTLA-4: classical Treg markers. During infection however, several non-classical genes were up-regulated solely within the Treg population such as Slpi, Gzmb, Mt1, Fabp5, Nfil3, Socs2, Gpr177 and Klrg1. Using RT-PCR we confirmed aspects of the microarray data and in addition showed that the expression profile of Treg from S. mansoni-infected mice is simultaneously unique and comparative with Treg derived from other infections

Standard name | GSE17580_TREG_VS_TEFF_S_MANSONI_INF_DN
Systematic name | M3674
Organism | Mus musculus
PMID | 20007528
Authors | Layland LE,Mages J,Loddenkemper C,Hoerauf A,Wagner H,Lang R,da Costa CU.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) from mice infected with S. mansoni versus T effector cells from the infected mice.
Full description | Although several markers have been associated with the characterization of regulatory T cells (Treg) and their function, no studies have investigated the dynamics of their phenotype during infection. Since the necessity of Treg to control immunopathology has been demonstrated, we used the chronic helminth infection model S. mansoni to address the impact on the Treg gene repertoire. Before gene expression profiling we first chose to study the localization and antigen-specific suppressive nature of classically defined Treg during infection. Presence of Foxp3+ cells were found especially in the periphery of granulomas and isolated CD4+CD25hiFoxp3+ Treg from infected mice blocked IFN-gamma and IL-10 cytokine secretion from infected CD4+CD25- effector T cells (Teff). Furthermore the gene expression patterns of Treg and Teff showed that in total 474 genes were significantly regulated during chronic schistosomiasis. Upon k-means clustering we identified genes exclusively regulated in all four populations including Foxp3, CD103, GITR, OX40 and CTLA-4: classical Treg markers. During infection however, several non-classical genes were up-regulated solely within the Treg population such as Slpi, Gzmb, Mt1, Fabp5, Nfil3, Socs2, Gpr177 and Klrg1. Using RT-PCR we confirmed aspects of the microarray data and in addition showed that the expression profile of Treg from S. mansoni-infected mice is simultaneously unique and comparative with Treg derived from other infections

Standard name | GSE17580_UNINFECTED_VS_S_MANSONI_INF_TEFF_UP
Systematic name | M3675
Organism | Mus musculus
PMID | 20007528
Authors | Layland LE,Mages J,Loddenkemper C,Hoerauf A,Wagner H,Lang R,da Costa CU.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of T effector cells from uninfected mice versus T effector cells from mice infected with S. mansoni.
Full description | Although several markers have been associated with the characterization of regulatory T cells (Treg) and their function, no studies have investigated the dynamics of their phenotype during infection. Since the necessity of Treg to control immunopathology has been demonstrated, we used the chronic helminth infection model S. mansoni to address the impact on the Treg gene repertoire. Before gene expression profiling we first chose to study the localization and antigen-specific suppressive nature of classically defined Treg during infection. Presence of Foxp3+ cells were found especially in the periphery of granulomas and isolated CD4+CD25hiFoxp3+ Treg from infected mice blocked IFN-gamma and IL-10 cytokine secretion from infected CD4+CD25- effector T cells (Teff). Furthermore the gene expression patterns of Treg and Teff showed that in total 474 genes were significantly regulated during chronic schistosomiasis. Upon k-means clustering we identified genes exclusively regulated in all four populations including Foxp3, CD103, GITR, OX40 and CTLA-4: classical Treg markers. During infection however, several non-classical genes were up-regulated solely within the Treg population such as Slpi, Gzmb, Mt1, Fabp5, Nfil3, Socs2, Gpr177 and Klrg1. Using RT-PCR we confirmed aspects of the microarray data and in addition showed that the expression profile of Treg from S. mansoni-infected mice is simultaneously unique and comparative with Treg derived from other infections

Standard name | GSE17580_UNINFECTED_VS_S_MANSONI_INF_TEFF_DN
Systematic name | M3676
Organism | Mus musculus
PMID | 20007528
Authors | Layland LE,Mages J,Loddenkemper C,Hoerauf A,Wagner H,Lang R,da Costa CU.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of T effector cells from uninfected mice versus T effector cells from mice infected with S. mansoni.
Full description | Although several markers have been associated with the characterization of regulatory T cells (Treg) and their function, no studies have investigated the dynamics of their phenotype during infection. Since the necessity of Treg to control immunopathology has been demonstrated, we used the chronic helminth infection model S. mansoni to address the impact on the Treg gene repertoire. Before gene expression profiling we first chose to study the localization and antigen-specific suppressive nature of classically defined Treg during infection. Presence of Foxp3+ cells were found especially in the periphery of granulomas and isolated CD4+CD25hiFoxp3+ Treg from infected mice blocked IFN-gamma and IL-10 cytokine secretion from infected CD4+CD25- effector T cells (Teff). Furthermore the gene expression patterns of Treg and Teff showed that in total 474 genes were significantly regulated during chronic schistosomiasis. Upon k-means clustering we identified genes exclusively regulated in all four populations including Foxp3, CD103, GITR, OX40 and CTLA-4: classical Treg markers. During infection however, several non-classical genes were up-regulated solely within the Treg population such as Slpi, Gzmb, Mt1, Fabp5, Nfil3, Socs2, Gpr177 and Klrg1. Using RT-PCR we confirmed aspects of the microarray data and in addition showed that the expression profile of Treg from S. mansoni-infected mice is simultaneously unique and comparative with Treg derived from other infections

Standard name | GSE17580_UNINFECTED_VS_S_MANSONI_INF_TREG_UP
Systematic name | M3677
Organism | Mus musculus
PMID | 20007528
Authors | Layland LE,Mages J,Loddenkemper C,Hoerauf A,Wagner H,Lang R,da Costa CU.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) from uninfected mice versus regulatory T cell (Treg) from mice infected with S. mansoni.
Full description | Although several markers have been associated with the characterization of regulatory T cells (Treg) and their function, no studies have investigated the dynamics of their phenotype during infection. Since the necessity of Treg to control immunopathology has been demonstrated, we used the chronic helminth infection model S. mansoni to address the impact on the Treg gene repertoire. Before gene expression profiling we first chose to study the localization and antigen-specific suppressive nature of classically defined Treg during infection. Presence of Foxp3+ cells were found especially in the periphery of granulomas and isolated CD4+CD25hiFoxp3+ Treg from infected mice blocked IFN-gamma and IL-10 cytokine secretion from infected CD4+CD25- effector T cells (Teff). Furthermore the gene expression patterns of Treg and Teff showed that in total 474 genes were significantly regulated during chronic schistosomiasis. Upon k-means clustering we identified genes exclusively regulated in all four populations including Foxp3, CD103, GITR, OX40 and CTLA-4: classical Treg markers. During infection however, several non-classical genes were up-regulated solely within the Treg population such as Slpi, Gzmb, Mt1, Fabp5, Nfil3, Socs2, Gpr177 and Klrg1. Using RT-PCR we confirmed aspects of the microarray data and in addition showed that the expression profile of Treg from S. mansoni-infected mice is simultaneously unique and comparative with Treg derived from other infections

Standard name | GSE17580_UNINFECTED_VS_S_MANSONI_INF_TREG_DN
Systematic name | M3678
Organism | Mus musculus
PMID | 20007528
Authors | Layland LE,Mages J,Loddenkemper C,Hoerauf A,Wagner H,Lang R,da Costa CU.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) from uninfected mice versus regulatory T cell (Treg) from mice infected with S. mansoni.
Full description | Although several markers have been associated with the characterization of regulatory T cells (Treg) and their function, no studies have investigated the dynamics of their phenotype during infection. Since the necessity of Treg to control immunopathology has been demonstrated, we used the chronic helminth infection model S. mansoni to address the impact on the Treg gene repertoire. Before gene expression profiling we first chose to study the localization and antigen-specific suppressive nature of classically defined Treg during infection. Presence of Foxp3+ cells were found especially in the periphery of granulomas and isolated CD4+CD25hiFoxp3+ Treg from infected mice blocked IFN-gamma and IL-10 cytokine secretion from infected CD4+CD25- effector T cells (Teff). Furthermore the gene expression patterns of Treg and Teff showed that in total 474 genes were significantly regulated during chronic schistosomiasis. Upon k-means clustering we identified genes exclusively regulated in all four populations including Foxp3, CD103, GITR, OX40 and CTLA-4: classical Treg markers. During infection however, several non-classical genes were up-regulated solely within the Treg population such as Slpi, Gzmb, Mt1, Fabp5, Nfil3, Socs2, Gpr177 and Klrg1. Using RT-PCR we confirmed aspects of the microarray data and in addition showed that the expression profile of Treg from S. mansoni-infected mice is simultaneously unique and comparative with Treg derived from other infections

Standard name | GSE17721_CTRL_VS_LPS_0.5H_BMDC_UP
Systematic name | M3679
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 0 h versus those stimulated with LPS (TLR4 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_0.5H_BMDC_DN
Systematic name | M3680
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 0 h versus those stimulated with LPS (TLR4 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_1H_BMDC_UP
Systematic name | M3683
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 1 h versus those stimulated with LPS (TLR4 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_1H_BMDC_DN
Systematic name | M3685
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 1 h versus those stimulated with LPS (TLR4 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_2H_BMDC_UP
Systematic name | M3687
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 2 h versus those stimulated with LPS (TLR4 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_2H_BMDC_DN
Systematic name | M3688
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 2 h versus those stimulated with LPS (TLR4 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_4H_BMDC_UP
Systematic name | M3689
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 4 h versus those stimulated with LPS (TLR4 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_4H_BMDC_DN
Systematic name | M3690
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 4 h versus those stimulated with LPS (TLR4 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_6H_BMDC_UP
Systematic name | M3691
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 6 h versus those stimulated with LPS (TLR4 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_6H_BMDC_DN
Systematic name | M3692
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 6 h versus those stimulated with LPS (TLR4 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_8H_BMDC_UP
Systematic name | M3699
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 8 h versus those stimulated with LPS (TLR4 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_8H_BMDC_DN
Systematic name | M3700
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 8 h versus those stimulated with LPS (TLR4 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_12H_BMDC_UP
Systematic name | M3701
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 12 h versus those stimulated with LPS (TLR4 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_12H_BMDC_DN
Systematic name | M3702
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 12 h versus those stimulated with LPS (TLR4 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_24H_BMDC_UP
Systematic name | M3703
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 24 h versus those stimulated with LPS (TLR4 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_LPS_24H_BMDC_DN
Systematic name | M3704
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 24 h versus those stimulated with LPS (TLR4 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_0.5H_BMDC_UP
Systematic name | M3705
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 0 h versus those stimulated with poly(I:C) (TLR3 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_0.5H_BMDC_DN
Systematic name | M3706
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 0 h versus those stimulated with poly(I:C) (TLR3 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_1H_BMDC_UP
Systematic name | M3707
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 1 h versus those stimulated with poly(I:C) (TLR3 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_1H_BMDC_DN
Systematic name | M3709
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 1 h versus those stimulated with poly(I:C) (TLR3 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_2H_BMDC_UP
Systematic name | M3711
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 2 h versus those stimulated with poly(I:C) (TLR3 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_2H_BMDC_DN
Systematic name | M3712
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 2 h versus those stimulated with poly(I:C) (TLR3 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_4H_BMDC_UP
Systematic name | M3713
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 4 h versus those stimulated with poly(I:C) (TLR3 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_4H_BMDC_DN
Systematic name | M3714
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 4 h versus those stimulated with poly(I:C) (TLR3 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_6H_BMDC_UP
Systematic name | M3715
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 6 h versus those stimulated with poly(I:C) (TLR3 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_6H_BMDC_DN
Systematic name | M3716
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 6 h versus those stimulated with poly(I:C) (TLR3 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_8H_BMDC_UP
Systematic name | M3717
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 8 h versus those stimulated with poly(I:C) (TLR3 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_8H_BMDC_DN
Systematic name | M3718
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 8 h versus those stimulated with poly(I:C) (TLR3 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_12H_BMDC_UP
Systematic name | M3719
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 12 h versus those stimulated with poly(I:C) (TLR3 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_12H_BMDC_DN
Systematic name | M3722
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 12 h versus those stimulated with poly(I:C) (TLR3 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_24H_BMDC_UP
Systematic name | M3723
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 24 h versus those stimulated with poly(I:C) (TLR3 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_POLYIC_24H_BMDC_DN
Systematic name | M3725
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 24 h versus those stimulated with poly(I:C) (TLR3 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_0.5H_BMDC_UP
Systematic name | M3728
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 0 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_0.5H_BMDC_DN
Systematic name | M3729
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 0 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_1H_BMDC_UP
Systematic name | M3730
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 1 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_1H_BMDC_DN
Systematic name | M3731
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 1 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_2H_BMDC_UP
Systematic name | M3733
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 2 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_2H_BMDC_DN
Systematic name | M3734
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 2 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_4H_BMDC_UP
Systematic name | M3735
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 4 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_4H_BMDC_DN
Systematic name | M3738
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 4 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_6H_BMDC_UP
Systematic name | M3740
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 6 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_6H_BMDC_DN
Systematic name | M3742
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 6 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_8H_BMDC_UP
Systematic name | M3743
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 8 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_8H_BMDC_DN
Systematic name | M3747
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 8 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_12H_BMDC_UP
Systematic name | M3749
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 12 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_12H_BMDC_DN
Systematic name | M3750
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 12 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_24H_BMDC_UP
Systematic name | M3751
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 24 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_PAM3CSK4_24H_BMDC_DN
Systematic name | M3752
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 24 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_0.5H_BMDC_UP
Systematic name | M3754
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 0 h versus those stimulated with CpG DNA (TLR9 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_0.5H_BMDC_DN
Systematic name | M3755
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 0 h versus those stimulated with CpG DNA (TLR9 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_1H_BMDC_UP
Systematic name | M3756
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 1 h versus those stimulated with CpG DNA (TLR9 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_1H_BMDC_DN
Systematic name | M3757
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 1 h versus those stimulated with CpG DNA (TLR9 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_2H_BMDC_UP
Systematic name | M3759
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 2 h versus those stimulated with CpG DNA (TLR9 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_2H_BMDC_DN
Systematic name | M3760
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 2 h versus those stimulated with CpG DNA (TLR9 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_4H_BMDC_UP
Systematic name | M3761
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 4 h versus those stimulated with CpG DNA (TLR9 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_4H_BMDC_DN
Systematic name | M3763
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 4 h versus those stimulated with CpG DNA (TLR9 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_6H_BMDC_UP
Systematic name | M3764
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 6 h versus those stimulated with CpG DNA (TLR9 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_6H_BMDC_DN
Systematic name | M3765
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 6 h versus those stimulated with CpG DNA (TLR9 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_8H_BMDC_UP
Systematic name | M3767
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 8 h versus those stimulated with CpG DNA (TLR9 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_8H_BMDC_DN
Systematic name | M3768
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 8 h versus those stimulated with CpG DNA (TLR9 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_12H_BMDC_UP
Systematic name | M3769
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 12 h versus those stimulated with CpG DNA (TLR9 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_12H_BMDC_DN
Systematic name | M3770
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 12 h versus those stimulated with CpG DNA (TLR9 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_24H_BMDC_UP
Systematic name | M3771
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 24 h versus those stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_CPG_24H_BMDC_DN
Systematic name | M3772
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 24 h versus those stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_0.5H_BMDC_UP
Systematic name | M3774
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 0 h versus those stimulated with Gardiquimod (TLR7 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_0.5H_BMDC_DN
Systematic name | M3775
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 0 h versus those stimulated with Gardiquimod (TLR7 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_1H_BMDC_UP
Systematic name | M3776
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 1 h versus those stimulated with Gardiquimod (TLR7 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_1H_BMDC_DN
Systematic name | M3777
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 1 h versus those stimulated with Gardiquimod (TLR7 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_2H_BMDC_UP
Systematic name | M3778
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 2 h versus those stimulated with Gardiquimod (TLR7 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_2H_BMDC_DN
Systematic name | M3779
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 2 h versus those stimulated with Gardiquimod (TLR7 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_4H_BMDC_UP
Systematic name | M3780
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 4 h versus those stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_4H_BMDC_DN
Systematic name | M3781
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 4 h versus those stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_6H_BMDC_UP
Systematic name | M3785
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 6 h versus those stimulated with Gardiquimod (TLR7 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_6H_BMDC_DN
Systematic name | M3787
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 6 h versus those stimulated with Gardiquimod (TLR7 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_8H_BMDC_UP
Systematic name | M3788
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 8 h versus those stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_8H_BMDC_DN
Systematic name | M3790
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 8 h versus those stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_12H_BMDC_UP
Systematic name | M3791
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 12 h versus those stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_12H_BMDC_DN
Systematic name | M3792
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 12 h versus those stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_24H_BMDC_UP
Systematic name | M3793
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control dendritic cells (DC) at 24 h versus those stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CTRL_VS_GARDIQUIMOD_24H_BMDC_DN
Systematic name | M3795
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control dendritic cells (DC) at 24 h versus those stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_0.5H_BMDC_UP
Systematic name | M3796
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_0.5H_BMDC_DN
Systematic name | M3797
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_1H_BMDC_UP
Systematic name | M3798
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 1 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_1H_BMDC_DN
Systematic name | M3800
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 1 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_2H_BMDC_UP
Systematic name | M3801
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_2H_BMDC_DN
Systematic name | M3802
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_4H_BMDC_UP
Systematic name | M3803
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 4 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_4H_BMDC_DN
Systematic name | M3807
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 4 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_6H_BMDC_UP
Systematic name | M3808
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 6 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_6H_BMDC_DN
Systematic name | M3809
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 6 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_8H_BMDC_UP
Systematic name | M3811
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 8 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_8H_BMDC_DN
Systematic name | M3813
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 8 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_12H_BMDC_UP
Systematic name | M3814
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 12 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_12H_BMDC_DN
Systematic name | M3817
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 12 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_16H_BMDC_UP
Systematic name | M3818
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 16 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_16H_BMDC_DN
Systematic name | M3819
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 16 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_24H_BMDC_UP
Systematic name | M3820
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 24 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_POLYIC_24H_BMDC_DN
Systematic name | M3821
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 24 h versus DC cells stimulated with poly(I:C) (TLR3 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_0.5H_BMDC_UP
Systematic name | M3822
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_0.5H_BMDC_DN
Systematic name | M3823
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_1H_BMDC_UP
Systematic name | M3824
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 1 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_1H_BMDC_DN
Systematic name | M3826
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 1 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_2H_BMDC_UP
Systematic name | M3830
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 2 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_2H_BMDC_DN
Systematic name | M3831
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 2 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_4H_BMDC_UP
Systematic name | M3832
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 4 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_4H_BMDC_DN
Systematic name | M3833
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 4 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_6H_BMDC_UP
Systematic name | M3834
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 6 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_6H_BMDC_DN
Systematic name | M3836
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 6 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_8H_BMDC_UP
Systematic name | M3838
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 8 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_8H_BMDC_DN
Systematic name | M3839
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 8 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_12H_BMDC_UP
Systematic name | M3840
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 12 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_12H_BMDC_DN
Systematic name | M3841
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 12 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_16H_BMDC_UP
Systematic name | M3842
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 16 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_16H_BMDC_DN
Systematic name | M3843
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 16 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_24H_BMDC_UP
Systematic name | M3846
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 24 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_PAM3CSK4_24H_BMDC_DN
Systematic name | M3847
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 24 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_0.5H_BMDC_UP
Systematic name | M3850
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_0.5H_BMDC_DN
Systematic name | M3851
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_1H_BMDC_UP
Systematic name | M3852
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 1 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_1H_BMDC_DN
Systematic name | M3853
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 1 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_2H_BMDC_UP
Systematic name | M3857
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 2 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_2H_BMDC_DN
Systematic name | M3858
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 2 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_4H_BMDC_UP
Systematic name | M3860
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 4 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_4H_BMDC_DN
Systematic name | M3861
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 4 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_6H_BMDC_UP
Systematic name | M3863
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 6 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_6H_BMDC_DN
Systematic name | M3864
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 6 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_8H_BMDC_UP
Systematic name | M3865
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 8 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_8H_BMDC_DN
Systematic name | M3866
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 8 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_12H_BMDC_UP
Systematic name | M3867
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_12H_BMDC_DN
Systematic name | M3868
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_16H_BMDC_UP
Systematic name | M3869
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 16 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_16H_BMDC_DN
Systematic name | M3870
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 16 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_24H_BMDC_UP
Systematic name | M3874
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_CPG_24H_BMDC_DN
Systematic name | M3875
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_0.5H_BMDC_UP
Systematic name | M3876
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 0.5 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_0.5H_BMDC_DN
Systematic name | M3877
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 0.5 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_1H_BMDC_UP
Systematic name | M3878
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 1 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_1H_BMDC_DN
Systematic name | M3880
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 1 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_2H_BMDC_UP
Systematic name | M3881
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 2 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_2H_BMDC_DN
Systematic name | M3882
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 2 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_4H_BMDC_UP
Systematic name | M3883
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 4 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_4H_BMDC_DN
Systematic name | M3885
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 4 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_6H_BMDC_UP
Systematic name | M3886
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 6 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_6H_BMDC_DN
Systematic name | M3891
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 6 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_8H_BMDC_UP
Systematic name | M3892
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 8 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_8H_BMDC_DN
Systematic name | M3893
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 8 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_12H_BMDC_UP
Systematic name | M3894
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 12 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_12H_BMDC_DN
Systematic name | M3895
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 12 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_16H_BMDC_UP
Systematic name | M3897
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 16 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_16H_BMDC_DN
Systematic name | M3899
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 16 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_24H_BMDC_UP
Systematic name | M3901
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 24 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_CPG_VS_GARDIQUIMOD_24H_BMDC_DN
Systematic name | M3904
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 24 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_0.5H_BMDC_UP
Systematic name | M3906
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_0.5H_BMDC_DN
Systematic name | M3907
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_1H_BMDC_UP
Systematic name | M3908
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 1 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_1H_BMDC_DN
Systematic name | M3912
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 1 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_2H_BMDC_UP
Systematic name | M3913
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_2H_BMDC_DN
Systematic name | M3914
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_4H_BMDC_UP
Systematic name | M3915
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 4 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_4H_BMDC_DN
Systematic name | M3917
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 4 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_6H_BMDC_UP
Systematic name | M3918
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 6 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_6H_BMDC_DN
Systematic name | M3919
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 6 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_8H_BMDC_UP
Systematic name | M3920
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 8 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_8H_BMDC_DN
Systematic name | M3921
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 8 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_12H_BMDC_UP
Systematic name | M3925
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 12 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_12H_BMDC_DN
Systematic name | M3926
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 12 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_16H_BMDC_UP
Systematic name | M3927
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 16 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_16H_BMDC_DN
Systematic name | M3929
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 16 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_24H_BMDC_UP
Systematic name | M3930
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 24 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_PAM3CSK4_24H_BMDC_DN
Systematic name | M3931
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 24 h versus DC cells stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_0.5H_BMDC_UP
Systematic name | M3932
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_0.5H_BMDC_DN
Systematic name | M3933
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_1H_BMDC_UP
Systematic name | M3934
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 1 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_1H_BMDC_DN
Systematic name | M3936
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 1 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_2H_BMDC_UP
Systematic name | M3937
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 2 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_2H_BMDC_DN
Systematic name | M3939
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 2 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_4H_BMDC_UP
Systematic name | M3940
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 4 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_4H_BMDC_DN
Systematic name | M3942
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 4 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_6H_BMDC_UP
Systematic name | M3943
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 6 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_6H_BMDC_DN
Systematic name | M3944
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 6 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_8H_BMDC_UP
Systematic name | M3945
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 8 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_8H_BMDC_DN
Systematic name | M3947
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 8 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_12H_BMDC_UP
Systematic name | M3948
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 12 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_12H_BMDC_DN
Systematic name | M3949
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 12 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_16H_BMDC_UP
Systematic name | M3950
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 16 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_16H_BMDC_DN
Systematic name | M3951
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 16 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_24H_BMDC_UP
Systematic name | M3953
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 24 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_CPG_24H_BMDC_DN
Systematic name | M3954
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 24 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_0.5H_BMDC_UP
Systematic name | M3957
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_0.5H_BMDC_DN
Systematic name | M3960
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_1H_BMDC_UP
Systematic name | M3962
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 1 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_1H_BMDC_DN
Systematic name | M3963
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 1 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_2H_BMDC_UP
Systematic name | M3964
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 2 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_2H_BMDC_DN
Systematic name | M3965
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 2 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_4H_BMDC_UP
Systematic name | M3968
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 4 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_4H_BMDC_DN
Systematic name | M3969
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 4 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_6H_BMDC_UP
Systematic name | M3970
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 6 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_6H_BMDC_DN
Systematic name | M3971
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 6 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_8H_BMDC_UP
Systematic name | M3972
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 8 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_8H_BMDC_DN
Systematic name | M3973
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 8 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_12H_BMDC_UP
Systematic name | M3974
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_12H_BMDC_DN
Systematic name | M3975
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_16H_BMDC_UP
Systematic name | M3976
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 16 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_16H_BMDC_DN
Systematic name | M3978
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 16 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_24H_BMDC_UP
Systematic name | M3979
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_PAM3CSK4_VS_GADIQUIMOD_24H_BMDC_DN
Systematic name | M3981
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_0.5H_BMDC_UP
Systematic name | M3982
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_0.5H_BMDC_DN
Systematic name | M3983
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_1H_BMDC_UP
Systematic name | M3984
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 1 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_1H_BMDC_DN
Systematic name | M3987
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 1 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_2H_BMDC_UP
Systematic name | M3989
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_2H_BMDC_DN
Systematic name | M3991
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_4H_BMDC_UP
Systematic name | M3995
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 4 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_4H_BMDC_DN
Systematic name | M3997
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 4 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_6H_BMDC_UP
Systematic name | M3998
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 6 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_6H_BMDC_DN
Systematic name | M3999
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 6 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_8H_BMDC_UP
Systematic name | M4003
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 8 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_8H_BMDC_DN
Systematic name | M4004
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 8 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_12H_BMDC_UP
Systematic name | M4005
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 12 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_12H_BMDC_DN
Systematic name | M4006
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 12 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_16H_BMDC_UP
Systematic name | M4007
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 16 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_16H_BMDC_DN
Systematic name | M4009
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 16 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_24H_BMDC_UP
Systematic name | M4010
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 24 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_CPG_24H_BMDC_DN
Systematic name | M4011
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 24 h versus DC cells stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_0.5H_BMDC_UP
Systematic name | M4012
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_0.5H_BMDC_DN
Systematic name | M4015
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_1H_BMDC_UP
Systematic name | M4016
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 1 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_1H_BMDC_DN
Systematic name | M4017
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 1 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_2H_BMDC_UP
Systematic name | M4018
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 2 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_2H_BMDC_DN
Systematic name | M4020
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 2 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_4H_BMDC_UP
Systematic name | M4021
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 4 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_4H_BMDC_DN
Systematic name | M4022
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 4 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_6H_BMDC_UP
Systematic name | M4024
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 6 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_6H_BMDC_DN
Systematic name | M4025
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 6 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_8H_BMDC_UP
Systematic name | M4026
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 8 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_8H_BMDC_DN
Systematic name | M4027
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 8 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_12H_BMDC_UP
Systematic name | M4028
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 12 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_12H_BMDC_DN
Systematic name | M4030
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 12 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_16H_BMDC_UP
Systematic name | M4031
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 16 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_16H_BMDC_DN
Systematic name | M4032
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 16 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_24H_BMDC_UP
Systematic name | M4033
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 24 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_POLYIC_VS_GARDIQUIMOD_24H_BMDC_DN
Systematic name | M4036
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 24 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_0.5H_BMDC_UP
Systematic name | M4037
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_0.5H_BMDC_DN
Systematic name | M4039
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 0.5 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_1H_BMDC_UP
Systematic name | M4040
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 1 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_1H_BMDC_DN
Systematic name | M4041
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 1 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 1 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_2H_BMDC_UP
Systematic name | M4043
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_2H_BMDC_DN
Systematic name | M4044
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 2 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_4H_BMDC_UP
Systematic name | M4048
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 4 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_4H_BMDC_DN
Systematic name | M4049
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 4 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_6H_BMDC_UP
Systematic name | M4050
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 6 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_6H_BMDC_DN
Systematic name | M4055
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 6 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 6 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_8H_BMDC_UP
Systematic name | M4056
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 8 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_8H_BMDC_DN
Systematic name | M4057
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 8 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_12H_BMDC_UP
Systematic name | M4058
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 12 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_12H_BMDC_DN
Systematic name | M4059
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 12 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_16H_BMDC_UP
Systematic name | M4060
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 16 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_16H_BMDC_DN
Systematic name | M4062
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 16 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 16 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_24H_BMDC_UP
Systematic name | M4063
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 24 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_LPS_VS_GARDIQUIMOD_24H_BMDC_DN
Systematic name | M4066
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 24 h versus DC cells stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_12H_LPS_BMDC_UP
Systematic name | M4067
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus those stimulated at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_12H_LPS_BMDC_DN
Systematic name | M4069
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus those stimulated at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_4H_LPS_BMDC_UP
Systematic name | M4070
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus those stimulated at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_4H_LPS_BMDC_DN
Systematic name | M4073
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus those stimulated at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_8H_LPS_BMDC_UP
Systematic name | M4074
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus those stimulated at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_8H_LPS_BMDC_DN
Systematic name | M4075
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus those stimulated at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_24H_LPS_BMDC_UP
Systematic name | M4079
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_24H_LPS_BMDC_DN
Systematic name | M4080
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 0.5 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_12H_VS_24H_LPS_BMDC_UP
Systematic name | M4081
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 12 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_12H_VS_24H_LPS_BMDC_DN
Systematic name | M4083
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 12 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_12H_POLYIC_BMDC_UP
Systematic name | M4084
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus those stimulated at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_12H_POLYIC_BMDC_DN
Systematic name | M4087
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus those stimulated at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_4H_POLYIC_BMDC_UP
Systematic name | M4089
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus those stimulated at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_4H_POLYIC_BMDC_DN
Systematic name | M4091
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus those stimulated at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_8H_POLYIC_BMDC_UP
Systematic name | M4093
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus those stimulated at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_8H_POLYIC_BMDC_DN
Systematic name | M4094
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus those stimulated at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_24H_POLYIC_BMDC_UP
Systematic name | M4096
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_24H_POLYIC_BMDC_DN
Systematic name | M4097
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 0.5 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_4H_VS_24H_POLYIC_BMDC_UP
Systematic name | M4098
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 4 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_4H_VS_24H_POLYIC_BMDC_DN
Systematic name | M4099
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 4 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_12H_VS_24H_POLYIC_BMDC_UP
Systematic name | M4101
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 12 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_12H_VS_24H_POLYIC_BMDC_DN
Systematic name | M4102
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with poly(I:C) (TLR3 agonist) at 12 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_12H_PAM3CSK4_BMDC_UP
Systematic name | M4103
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus those stimulated at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_12H_PAM3CSK4_BMDC_DN
Systematic name | M4104
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus those stimulated at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_4H_PAM3CSK4_BMDC_UP
Systematic name | M4105
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus those stimulated at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_4H_PAM3CSK4_BMDC_DN
Systematic name | M4108
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus those stimulated at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_8H_PAM3CSK4_BMDC_UP
Systematic name | M4110
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus those stimulated at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_8H_PAM3CSK4_BMDC_DN
Systematic name | M4111
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus those stimulated at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_24H_PAM3CSK4_BMDC_UP
Systematic name | M4112
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_24H_PAM3CSK4_BMDC_DN
Systematic name | M4114
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 0.5 h versus those stimulated at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_ALL_VS_24H_PAM3CSK4_BMDC_UP
Systematic name | M4115
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at all time points versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h only.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_ALL_VS_24H_PAM3CSK4_BMDC_DN
Systematic name | M4116
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at all time points versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h only.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_12H_VS_24H_PAM3CSK4_BMDC_UP
Systematic name | M4117
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_12H_VS_24H_PAM3CSK4_BMDC_DN
Systematic name | M4118
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Pam3Csk4 (TLR1/2 agonist) at 12 h versus those stimulated with Pam3Csk4 (TLR1/2 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_12H_CPG_BMDC_UP
Systematic name | M4119
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 0.5 h versus those stimulated with CpG DNA (TLR9 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_12H_CPG_BMDC_DN
Systematic name | M4122
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 0.5 h versus those stimulated with CpG DNA (TLR9 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_4H_CPG_BMDC_UP
Systematic name | M4124
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 0.5 h versus those stimulated with CpG DNA (TLR9 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_4H_CPG_BMDC_DN
Systematic name | M4125
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 0.5 h versus those stimulated with CpG DNA (TLR9 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_8H_CPG_BMDC_UP
Systematic name | M4126
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 0.5 h versus those stimulated with CpG DNA (TLR9 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_8H_CPG_BMDC_DN
Systematic name | M4127
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 0.5 h versus those stimulated with CpG DNA (TLR9 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_24H_CPG_BMDC_UP
Systematic name | M4128
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 0.5 h versus those stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_24H_CPG_BMDC_DN
Systematic name | M4129
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 0.5 h versus those stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_4_VS_24H_CPG_BMDC_UP
Systematic name | M4130
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 4 h versus those stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_4_VS_24H_CPG_BMDC_DN
Systematic name | M4131
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 4 h versus those stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_12H_VS_24H_CPG_BMDC_UP
Systematic name | M4132
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 12 h versus those stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_12H_VS_24H_CPG_BMDC_DN
Systematic name | M4133
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with CpG DNA (TLR9 agonist) at 12 h versus those stimulated with CpG DNA (TLR9 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_12H_GARDIQUIMOD_BMDC_UP
Systematic name | M4135
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 0.5 h versus those stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_12H_GARDIQUIMOD_BMDC_DN
Systematic name | M4136
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 0.5 h versus those stimulated with Gardiquimod (TLR7 agonist) at 12 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_4H_GARDIQUIMOD_BMDC_UP
Systematic name | M4139
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 0.5 h versus those stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_4H_GARDIQUIMOD_BMDC_DN
Systematic name | M4140
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 0.5 h versus those stimulated with Gardiquimod (TLR7 agonist) at 4 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_8H_GARDIQUIMOD_BMDC_UP
Systematic name | M4141
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 0.5 h versus those stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_8H_GARDIQUIMOD_BMDC_DN
Systematic name | M4142
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 0.5 h versus those stimulated with Gardiquimod (TLR7 agonist) at 8 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_24H_GARDIQUIMOD_BMDC_UP
Systematic name | M4143
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 0.5 h versus those stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_0.5H_VS_24H_GARDIQUIMOD_BMDC_DN
Systematic name | M4145
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 0.5 h versus those stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_4_VS_24H_GARDIQUIMOD_BMDC_UP
Systematic name | M4146
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 4 h versus those stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_4_VS_24H_GARDIQUIMOD_BMDC_DN
Systematic name | M4147
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 4 h versus those stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_12H_VS_24H_GARDIQUIMOD_BMDC_UP
Systematic name | M4148
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 12 h versus those stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17721_12H_VS_24H_GARDIQUIMOD_BMDC_DN
Systematic name | M4150
Organism | Mus musculus
PMID | 19729616
Authors | Amit I,Garber M,Chevrier N,Leite AP,Donner Y,Eisenhaure T,Guttman M,Grenier JK,Li W,Zuk O,Schubert LA,Birditt B,Shay T,Goren A,Zhang X,Smith Z,Deering R,McDonald RC,Cabili M,Bernstein BE,Rinn JL,Meissner A,Root DE,Hacohen N,Regev A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with Gardiquimod (TLR7 agonist) at 12 h versus those stimulated with Gardiquimod (TLR7 agonist) at 24 h.
Full description | mouse primary BMDCs were stimulated with tlr ligands and gene expression changes were profiled on Affymetrix arrays

Standard name | GSE17974_0H_VS_0.5H_IN_VITRO_ACT_CD4_TCELL_UP
Systematic name | M4152
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 0.5 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_0.5H_IN_VITRO_ACT_CD4_TCELL_DN
Systematic name | M4154
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 0.5 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_1H_IN_VITRO_ACT_CD4_TCELL_UP
Systematic name | M4156
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 1 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_1H_IN_VITRO_ACT_CD4_TCELL_DN
Systematic name | M4157
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 1 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_2H_IN_VITRO_ACT_CD4_TCELL_UP
Systematic name | M4158
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 2 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_2H_IN_VITRO_ACT_CD4_TCELL_DN
Systematic name | M4159
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 2 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_4H_IN_VITRO_ACT_CD4_TCELL_UP
Systematic name | M4160
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 4 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_4H_IN_VITRO_ACT_CD4_TCELL_DN
Systematic name | M4161
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 4 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_6H_IN_VITRO_ACT_CD4_TCELL_UP
Systematic name | M4164
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 6 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_6H_IN_VITRO_ACT_CD4_TCELL_DN
Systematic name | M4166
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 6 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_12H_IN_VITRO_ACT_CD4_TCELL_UP
Systematic name | M4167
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 12 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_12H_IN_VITRO_ACT_CD4_TCELL_DN
Systematic name | M4168
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 12 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_24H_IN_VITRO_ACT_CD4_TCELL_UP
Systematic name | M4169
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 24 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_24H_IN_VITRO_ACT_CD4_TCELL_DN
Systematic name | M4173
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 24 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_48H_IN_VITRO_ACT_CD4_TCELL_UP
Systematic name | M4174
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 48 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_48H_IN_VITRO_ACT_CD4_TCELL_DN
Systematic name | M4176
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 48 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_72H_IN_VITRO_ACT_CD4_TCELL_UP
Systematic name | M4177
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0H_VS_72H_IN_VITRO_ACT_CD4_TCELL_DN
Systematic name | M4178
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the untreated cells at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_0.5H_CD4_TCELL_UP
Systematic name | M4179
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 0.5 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_0.5H_CD4_TCELL_DN
Systematic name | M4180
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 0.5 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_1H_CD4_TCELL_UP
Systematic name | M4181
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 1 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_1H_CD4_TCELL_DN
Systematic name | M4182
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 1 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_2H_CD4_TCELL_UP
Systematic name | M4185
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 2 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_2H_CD4_TCELL_DN
Systematic name | M4186
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 2 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_4H_CD4_TCELL_UP
Systematic name | M4187
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 4 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_4H_CD4_TCELL_DN
Systematic name | M4188
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 4 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_6H_CD4_TCELL_UP
Systematic name | M4189
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 6 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_6H_CD4_TCELL_DN
Systematic name | M4190
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 6 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_12H_CD4_TCELL_UP
Systematic name | M4192
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 12 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_12H_CD4_TCELL_DN
Systematic name | M4194
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 12 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_24H_CD4_TCELL_UP
Systematic name | M4195
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 24 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_24H_CD4_TCELL_DN
Systematic name | M4197
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 24 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_48H_CD4_TCELL_UP
Systematic name | M4199
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 48 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_48H_CD4_TCELL_DN
Systematic name | M4200
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 48 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_72H_CD4_TCELL_UP
Systematic name | M4201
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_CTRL_VS_ACT_IL4_AND_ANTI_IL12_72H_CD4_TCELL_DN
Systematic name | M4202
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0 h versus the cells treated with IL4 [GeneID=3565] and anti-IL12 at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_0.5H_ACT_CD4_TCELL_UP
Systematic name | M4206
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 0.5 h versus the untreated cells at 0.5 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_0.5H_ACT_CD4_TCELL_DN
Systematic name | M4207
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 0.5 h versus the untreated cells at 0.5 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_1H_ACT_CD4_TCELL_UP
Systematic name | M4208
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 1 h versus the untreated cells at 1 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_1H_ACT_CD4_TCELL_DN
Systematic name | M4209
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 1 h versus the untreated cells at 1 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_2H_ACT_CD4_TCELL_UP
Systematic name | M4211
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 2 h versus the untreated cells at 2 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_2H_ACT_CD4_TCELL_DN
Systematic name | M4212
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 2 h versus the untreated cells at 2 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_4H_ACT_CD4_TCELL_UP
Systematic name | M4213
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 4 h versus the untreated cells at 4 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_4H_ACT_CD4_TCELL_DN
Systematic name | M4214
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 4 h versus the untreated cells at 4 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_6H_ACT_CD4_TCELL_UP
Systematic name | M4216
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 6 h versus the untreated cells at 6 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_6H_ACT_CD4_TCELL_DN
Systematic name | M4218
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 6 h versus the untreated cells at 6 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_12H_ACT_CD4_TCELL_UP
Systematic name | M4221
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 12 h versus the untreated cells at 12 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_12H_ACT_CD4_TCELL_DN
Systematic name | M4222
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 12 h versus the untreated cells at 12 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_24H_ACT_CD4_TCELL_UP
Systematic name | M4224
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 24 h versus the untreated cells at 24 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_24H_ACT_CD4_TCELL_DN
Systematic name | M4227
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 24 h versus the untreated cells at 24 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_48H_ACT_CD4_TCELL_UP
Systematic name | M4228
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 48 h versus the untreated cells at 48 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_48H_ACT_CD4_TCELL_DN
Systematic name | M4231
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 48 h versus the untreated cells at 48 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_72H_ACT_CD4_TCELL_UP
Systematic name | M4232
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 72 h versus the untreated cells at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_IL4_AND_ANTI_IL12_VS_UNTREATED_72H_ACT_CD4_TCELL_DN
Systematic name | M4233
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 72 h versus the untreated cells at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0.5H_VS_72H_UNTREATED_IN_VITRO_CD4_TCELL_UP
Systematic name | M4234
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0.5 h versus the untreated cells at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0.5H_VS_72H_UNTREATED_IN_VITRO_CD4_TCELL_DN
Systematic name | M4236
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 0.5 h versus the untreated cells at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_1H_VS_72H_UNTREATED_IN_VITRO_CD4_TCELL_UP
Systematic name | M4237
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 1 h versus the untreated cells at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_1H_VS_72H_UNTREATED_IN_VITRO_CD4_TCELL_DN
Systematic name | M4239
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 1 h versus the untreated cells at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_2H_VS_72H_UNTREATED_IN_VITRO_CD4_TCELL_UP
Systematic name | M4240
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells at 2 h versus the untreated cells at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_2H_VS_72H_UNTREATED_IN_VITRO_CD4_TCELL_DN
Systematic name | M4243
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells at 2 h versus the untreated cells at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0.5H_VS_72H_IL4_AND_ANTI_IL12_ACT_CD4_TCELL_UP
Systematic name | M4244
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 0.5 h versus those at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_0.5H_VS_72H_IL4_AND_ANTI_IL12_ACT_CD4_TCELL_DN
Systematic name | M4245
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 0.5 h versus those at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_1.5H_VS_72H_IL4_AND_ANTI_IL12_ACT_CD4_TCELL_UP
Systematic name | M4247
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 1.5 h versus those at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_1.5H_VS_72H_IL4_AND_ANTI_IL12_ACT_CD4_TCELL_DN
Systematic name | M4248
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 1.5 h versus those at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_2.5H_VS_72H_IL4_AND_ANTI_IL12_ACT_CD4_TCELL_UP
Systematic name | M4249
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 2 h versus those at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE17974_2.5H_VS_72H_IL4_AND_ANTI_IL12_ACT_CD4_TCELL_DN
Systematic name | M4250
Organism | Homo sapiens
PMID | 20620947
Authors | Elo LL,Järvenpää H,Tuomela S,Raghav S,Ahlfors H,Laurila K,Gupta B,Lund RJ,Tahvanainen J,Hawkins RD,Oresic M,Lähdesmäki H,Rasool O,Rao KV,Aittokallio T,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with IL4 [GeneID=3565] and anti-IL12 at 2 h versus those at 72 h.
Full description | The aim of this dataset was to study in detail the transcription kinetics initiated by cytokine IL-4 in early differentiation of Th2 cells.

Standard name | GSE18148_CBFB_KO_VS_WT_TREG_UP
Systematic name | M4251
Organism | Mus musculus
PMID | 19800266
Authors | Kitoh A,Ono M,Naoe Y,Ohkura N,Yamaguchi T,Yaguchi H,Kitabayashi I,Tsukada T,Nomura T,Miyachi Y,Taniuchi I,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes up-regualted in comparison of regulatory T cell (Treg) from CBFB [GeneID=865] deficient mice versus those from wild type animals.
Full description | Gene expression profiles of Cbfb-deficient and control Treg cells were compared. Naturally arising regulatory T (Treg) cells express the transcription factor FoxP3, which critically controls the development and function of Treg cells. FoxP3 interacts with another transcription factor Runx1 (also known as AML1). Here we showed that Treg cell-specific deficiency of Cbfβ, a cofactor for all Runx proteins, or that of Runx1, but not Runx3, induced lymphoproliferation, autoimmune disease, and hyper-production of IgE. Cbfb-deleted Treg cells exhibited impaired suppressive function in vitro and in vivo, with altered gene expression profiles including attenuated expression of FoxP3 and high expression of interleukin-4. The Runx complex bound to more than 3000 gene loci in Treg cells, including the Foxp3 regulatory regions and the Il4 silencer. In addition, knockdown of RUNX1 showed that RUNX1 is required for the optimal regulation of FoxP3 expression in human T cells. Taken together, our results indicate that the Runx1-Cbfβ heterodimer is indispensable for in vivo Treg cell function, in particular, suppressive activity and optimal expression of FoxP3.

Standard name | GSE18148_CBFB_KO_VS_WT_TREG_DN
Systematic name | M4252
Organism | Mus musculus
PMID | 19800266
Authors | Kitoh A,Ono M,Naoe Y,Ohkura N,Yamaguchi T,Yaguchi H,Kitabayashi I,Tsukada T,Nomura T,Miyachi Y,Taniuchi I,Sakaguchi S.
Category | C7
Sub-category |
Brief description | Genes down-regualted in comparison of regulatory T cell (Treg) from CBFB [GeneID=865] deficient mice versus those from wild type animals.
Full description | Gene expression profiles of Cbfb-deficient and control Treg cells were compared. Naturally arising regulatory T (Treg) cells express the transcription factor FoxP3, which critically controls the development and function of Treg cells. FoxP3 interacts with

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_1H_UP
Systematic name | M4255
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 1 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_1H_DN
Systematic name | M4256
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 1 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_2H_UP
Systematic name | M4257
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 2 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_2H_DN
Systematic name | M4259
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 2 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_4H_UP
Systematic name | M4260
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 4 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_4H_DN
Systematic name | M4261
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 4 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_6H_UP
Systematic name | M4262
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 6 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_6H_DN
Systematic name | M4264
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 6 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_8H_UP
Systematic name | M4266
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 8 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_8H_DN
Systematic name | M4267
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 8 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_10H_UP
Systematic name | M4268
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 10 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_10H_DN
Systematic name | M4269
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 10 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_12H_UP
Systematic name | M4271
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 12 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_12H_DN
Systematic name | M4272
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 12 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_14H_UP
Systematic name | M4274
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 14 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_14H_DN
Systematic name | M4277
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 14 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_16H_UP
Systematic name | M4278
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 16 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_16H_DN
Systematic name | M4279
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 16 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_18H_UP
Systematic name | M4283
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 18 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_CTRL_VS_NEWCASTLE_VIRUS_DC_18H_DN
Systematic name | M4284
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 0 h versus cDCs infected with Newcastle disease virus (NDV) at 18 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_UNSTIM_VS_NEWCATSLE_VIRUS_DC_1H_UP
Systematic name | M4285
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 1 h versus cDCs infected with Newcastle disease virus (NDV) at 1 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_UNSTIM_VS_NEWCATSLE_VIRUS_DC_1H_DN
Systematic name | M4286
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 1 h versus cDCs infected with Newcastle disease virus (NDV) at 1 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_UNSTIM_VS_NEWCATSLE_VIRUS_DC_2H_UP
Systematic name | M4287
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 2 h versus cDCs infected with Newcastle disease virus (NDV) at 2 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_UNSTIM_VS_NEWCATSLE_VIRUS_DC_2H_DN
Systematic name | M4289
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 2 h versus cDCs infected with Newcastle disease virus (NDV) at 2 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_UNSTIM_VS_NEWCATSLE_VIRUS_DC_6H_UP
Systematic name | M4291
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 6 h versus cDCs infected with Newcastle disease virus (NDV) at 6 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_UNSTIM_VS_NEWCATSLE_VIRUS_DC_6H_DN
Systematic name | M4292
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 6 h versus cDCs infected with Newcastle disease virus (NDV) at 6 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_UNSTIM_VS_NEWCATSLE_VIRUS_DC_10H_UP
Systematic name | M4293
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 10 h versus cDCs infected with Newcastle disease virus (NDV) at 10 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_UNSTIM_VS_NEWCATSLE_VIRUS_DC_10H_DN
Systematic name | M4294
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 10 h versus cDCs infected with Newcastle disease virus (NDV) at 10 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_UNSTIM_VS_NEWCATSLE_VIRUS_DC_18H_UP
Systematic name | M4295
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control conventional dendritic cells (cDC) at 18 h versus cDCs infected with Newcastle disease virus (NDV) at 18 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE18791_UNSTIM_VS_NEWCATSLE_VIRUS_DC_18H_DN
Systematic name | M4296
Organism | Homo sapiens
PMID | 20164420
Authors | Zaslavsky E,Hershberg U,Seto J,Pham AM,Marquez S,Duke JL,Wetmur JG,Tenoever BR,Sealfon SC,Kleinstein SH.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control conventional dendritic cells (cDC) at 18 h versus cDCs infected with Newcastle disease virus (NDV) at 18 h.
Full description | The dendritic cell (DC) is a master regulator of immune responses. Pathogenic viruses subvert normal immune function in DCs through the expression of immune antagonists. Understanding how these antagonists interact with the host immune system requires knowledge of the underlying genetic regulatory network that operates during an uninhibited antiviral response. In order to isolate and identify this network, we studied DCs infected with Newcastle Disease Virus (NDV), which is able to stimulate innate immunity and DC maturation through activation of RIG-I signaling, but lacks the ability to evade the human interferon response. To analyze this experimental model, we developed a new approach integrating genome-wide expression kinetics and time-dependent promoter analysis. We found that the genetic program underlying the antiviral cell state transition during the first 18-hours post-infection could be explained by a single regulatory network. Gene expression changes were driven by a step-wise multi-factor cascading control mechanism, where the specific transcription factors controlling expression changed over time. Within this network, most individual genes are regulated by multiple factors, indicating robustness against virus-encoded immune evasion genes. In addition to effectively recapitulating current biological knowledge, we predicted, and validated experimentally, antiviral roles for several novel transcription factors. More generally, our results show how a genetic program can be temporally controlled through a single regulatory network to achieve the large-scale genetic reprogramming characteristic of cell state transitions.

Standard name | GSE19825_NAIVE_VS_IL2RALOW_DAY3_EFF_CD8_TCELL_UP
Systematic name | M4297
Organism | Mus musculus
PMID | 20096608
Authors | Kalia V,Sarkar S,Subramaniam S,Haining WN,Smith KA,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus effector CD8 IL2RA [GeneID=3559] low T cells at.
Full description | CD25, the high affinity interleukin-2 (IL-2) receptor alpha-chain, is rapidly upregulated by antigen-specific CD8+ T cells after T cell receptor stimulation. We demonstrated that during an acute viral infection, CD25 expression was dynamic, and a subset of virus-specific CD8+ T cells sustained CD25 expression longer than the rest. Examination of the in vivo fate of effector CD8+ T cells exhibiting differential responsiveness to IL-2 revealed that CD25lo cells, which were relatively less sensitive to IL-2, preferentially upregulated CD127 and CD62L and gave rise to the functional long-lived memory pool. In contrast, CD25hi cells that accumulate enhanced IL-2 signals, proliferated more rapidly, were prone to apoptosis, exhibited a more pronounced effector phenotype, and appeared to be terminally differentiated. Sustained IL-2 receptor signaling resulted in increased CD8+ T cell proliferation, higher granzyme B expression and exaggerated contraction after antigen clearance. These data support the hypothesis that prolonged IL-2 signals during priming promote terminal effector differentiation of CD8+ T cells.

Standard name | GSE19825_NAIVE_VS_IL2RALOW_DAY3_EFF_CD8_TCELL_DN
Systematic name | M4298
Organism | Mus musculus
PMID | 20096608
Authors | Kalia V,Sarkar S,Subramaniam S,Haining WN,Smith KA,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus effector CD8 IL2RA [GeneID=3559] low T cells at.
Full description | CD25, the high affinity interleukin-2 (IL-2) receptor alpha-chain, is rapidly upregulated by antigen-specific CD8+ T cells after T cell receptor stimulation. We demonstrated that during an acute viral infection, CD25 expression was dynamic, and a subset of virus-specific CD8+ T cells sustained CD25 expression longer than the rest. Examination of the in vivo fate of effector CD8+ T cells exhibiting differential responsiveness to IL-2 revealed that CD25lo cells, which were relatively less sensitive to IL-2, preferentially upregulated CD127 and CD62L and gave rise to the functional long-lived memory pool. In contrast, CD25hi cells that accumulate enhanced IL-2 signals, proliferated more rapidly, were prone to apoptosis, exhibited a more pronounced effector phenotype, and appeared to be terminally differentiated. Sustained IL-2 receptor signaling resulted in increased CD8+ T cell proliferation, higher granzyme B expression and exaggerated contraction after antigen clearance. These data support the hypothesis that prolonged IL-2 signals during priming promote terminal effector differentiation of CD8+ T cells.

Standard name | GSE19825_NAIVE_VS_IL2RAHIGH_DAY3_EFF_CD8_TCELL_UP
Systematic name | M4299
Organism | Mus musculus
PMID | 20096608
Authors | Kalia V,Sarkar S,Subramaniam S,Haining WN,Smith KA,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus effector CD8 IL2RA [GeneID=3559] high T cells at.
Full description | CD25, the high affinity interleukin-2 (IL-2) receptor alpha-chain, is rapidly upregulated by antigen-specific CD8+ T cells after T cell receptor stimulation. We demonstrated that during an acute viral infection, CD25 expression was dynamic, and a subset of virus-specific CD8+ T cells sustained CD25 expression longer than the rest. Examination of the in vivo fate of effector CD8+ T cells exhibiting differential responsiveness to IL-2 revealed that CD25lo cells, which were relatively less sensitive to IL-2, preferentially upregulated CD127 and CD62L and gave rise to the functional long-lived memory pool. In contrast, CD25hi cells that accumulate enhanced IL-2 signals, proliferated more rapidly, were prone to apoptosis, exhibited a more pronounced effector phenotype, and appeared to be terminally differentiated. Sustained IL-2 receptor signaling resulted in increased CD8+ T cell proliferation, higher granzyme B expression and exaggerated contraction after antigen clearance. These data support the hypothesis that prolonged IL-2 signals during priming promote terminal effector differentiation of CD8+ T cells.

Standard name | GSE19825_NAIVE_VS_IL2RAHIGH_DAY3_EFF_CD8_TCELL_DN
Systematic name | M4300
Organism | Mus musculus
PMID | 20096608
Authors | Kalia V,Sarkar S,Subramaniam S,Haining WN,Smith KA,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus effector CD8 IL2RA [GeneID=3559] high T cells at.
Full description | CD25, the high affinity interleukin-2 (IL-2) receptor alpha-chain, is rapidly upregulated by antigen-specific CD8+ T cells after T cell receptor stimulation. We demonstrated that during an acute viral infection, CD25 expression was dynamic, and a subset of virus-specific CD8+ T cells sustained CD25 expression longer than the rest. Examination of the in vivo fate of effector CD8+ T cells exhibiting differential responsiveness to IL-2 revealed that CD25lo cells, which were relatively less sensitive to IL-2, preferentially upregulated CD127 and CD62L and gave rise to the functional long-lived memory pool. In contrast, CD25hi cells that accumulate enhanced IL-2 signals, proliferated more rapidly, were prone to apoptosis, exhibited a more pronounced effector phenotype, and appeared to be terminally differentiated. Sustained IL-2 receptor signaling resulted in increased CD8+ T cell proliferation, higher granzyme B expression and exaggerated contraction after antigen clearance. These data support the hypothesis that prolonged IL-2 signals during priming promote terminal effector differentiation of CD8+ T cells.

Standard name | GSE19825_CD24LOW_VS_IL2RA_HIGH_DAY3_EFF_CD8_TCELL_UP
Systematic name | M4301
Organism | Mus musculus
PMID | 20096608
Authors | Kalia V,Sarkar S,Subramaniam S,Haining WN,Smith KA,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effector CD8 IL2RA [GeneID=3559] low T cells versus effector CD8 IL2RA [GeneID=3559] high cells.
Full description | CD25, the high affinity interleukin-2 (IL-2) receptor alpha-chain, is rapidly upregulated by antigen-specific CD8+ T cells after T cell receptor stimulation. We demonstrated that during an acute viral infection, CD25 expression was dynamic, and a subset of virus-specific CD8+ T cells sustained CD25 expression longer than the rest. Examination of the in vivo fate of effector CD8+ T cells exhibiting differential responsiveness to IL-2 revealed that CD25lo cells, which were relatively less sensitive to IL-2, preferentially upregulated CD127 and CD62L and gave rise to the functional long-lived memory pool. In contrast, CD25hi cells that accumulate enhanced IL-2 signals, proliferated more rapidly, were prone to apoptosis, exhibited a more pronounced effector phenotype, and appeared to be terminally differentiated. Sustained IL-2 receptor signaling resulted in increased CD8+ T cell proliferation, higher granzyme B expression and exaggerated contraction after antigen clearance. These data support the hypothesis that prolonged IL-2 signals during priming promote terminal effector differentiation of CD8+ T cells.

Standard name | GSE19825_CD24LOW_VS_IL2RA_HIGH_DAY3_EFF_CD8_TCELL_DN
Systematic name | M4302
Organism | Mus musculus
PMID | 20096608
Authors | Kalia V,Sarkar S,Subramaniam S,Haining WN,Smith KA,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effector CD8 IL2RA [GeneID=3559] low T cells versus effector CD8 IL2RA [GeneID=3559] high cells.
Full description | CD25, the high affinity interleukin-2 (IL-2) receptor alpha-chain, is rapidly upregulated by antigen-specific CD8+ T cells after T cell receptor stimulation. We demonstrated that during an acute viral infection, CD25 expression was dynamic, and a subset of virus-specific CD8+ T cells sustained CD25 expression longer than the rest. Examination of the in vivo fate of effector CD8+ T cells exhibiting differential responsiveness to IL-2 revealed that CD25lo cells, which were relatively less sensitive to IL-2, preferentially upregulated CD127 and CD62L and gave rise to the functional long-lived memory pool. In contrast, CD25hi cells that accumulate enhanced IL-2 signals, proliferated more rapidly, were prone to apoptosis, exhibited a more pronounced effector phenotype, and appeared to be terminally differentiated. Sustained IL-2 receptor signaling resulted in increased CD8+ T cell proliferation, higher granzyme B expression and exaggerated contraction after antigen clearance. These data support the hypothesis that prolonged IL-2 signals during priming promote terminal effector differentiation of CD8+ T cells.

Standard name | GSE19825_NAIVE_VS_DAY3_EFF_CD8_TCELL_UP
Systematic name | M4305
Organism | Mus musculus
PMID | 20096608
Authors | Kalia V,Sarkar S,Subramaniam S,Haining WN,Smith KA,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive vs effector CD8 T cells (3.5 days postinfection).
Full description | CD25, the high affinity interleukin-2 (IL-2) receptor alpha-chain, is rapidly upregulated by antigen-specific CD8+ T cells after T cell receptor stimulation. We demonstrated that during an acute viral infection, CD25 expression was dynamic, and a subset of virus-specific CD8+ T cells sustained CD25 expression longer than the rest. Examination of the in vivo fate of effector CD8+ T cells exhibiting differential responsiveness to IL-2 revealed that CD25lo cells, which were relatively less sensitive to IL-2, preferentially upregulated CD127 and CD62L and gave rise to the functional long-lived memory pool. In contrast, CD25hi cells that accumulate enhanced IL-2 signals, proliferated more rapidly, were prone to apoptosis, exhibited a more pronounced effector phenotype, and appeared to be terminally differentiated. Sustained IL-2 receptor signaling resulted in increased CD8+ T cell proliferation, higher granzyme B expression and exaggerated contraction after antigen clearance. These data support the hypothesis that prolonged IL-2 signals during priming promote terminal effector differentiation of CD8+ T cells.

Standard name | GSE19825_NAIVE_VS_DAY3_EFF_CD8_TCELL_DN
Systematic name | M4307
Organism | Mus musculus
PMID | 20096608
Authors | Kalia V,Sarkar S,Subramaniam S,Haining WN,Smith KA,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive vs effector CD8 T cells (3.5 days postinfection).
Full description | CD25, the high affinity interleukin-2 (IL-2) receptor alpha-chain, is rapidly upregulated by antigen-specific CD8+ T cells after T cell receptor stimulation. We demonstrated that during an acute viral infection, CD25 expression was dynamic, and a subset of virus-specific CD8+ T cells sustained CD25 expression longer than the rest. Examination of the in vivo fate of effector CD8+ T cells exhibiting differential responsiveness to IL-2 revealed that CD25lo cells, which were relatively less sensitive to IL-2, preferentially upregulated CD127 and CD62L and gave rise to the functional long-lived memory pool. In contrast, CD25hi cells that accumulate enhanced IL-2 signals, proliferated more rapidly, were prone to apoptosis, exhibited a more pronounced effector phenotype, and appeared to be terminally differentiated. Sustained IL-2 receptor signaling resulted in increased CD8+ T cell proliferation, higher granzyme B expression and exaggerated contraction after antigen clearance. These data support the hypothesis that prolonged IL-2 signals during priming promote terminal effector differentiation of CD8+ T cells.

Standard name | GSE20151_CTRL_VS_FUSOBACT_NUCLEATUM_NEUTROPHIL_UP
Systematic name | M4309
Organism | Homo sapiens
PMID | 20663022
Authors | Wright HJ,Chapple IL,Matthews JB,Cooper PR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of contols neutrophils versus those infected with a bacterium (F. nucleatum).
Full description | Neutrophils are known to be stimulated by different periodontal bacteria to produce reactive oxygen species and cytokines. It is inportant to investigate the gene changes made by bacteria of importance, of which, for periodontal disease, fusobaterium nucleatum is one. we used microarrays to investigate gene experssion changes in peripheral blood neutrophils werwhich e stimulated with or with out Fusobacterium Nucleatum (10953).

Standard name | GSE20151_CTRL_VS_FUSOBACT_NUCLEATUM_NEUTROPHIL_DN
Systematic name | M4310
Organism | Homo sapiens
PMID | 20663022
Authors | Wright HJ,Chapple IL,Matthews JB,Cooper PR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of contols neutrophils versus those infected with a bacterium (F. nucleatum).
Full description | Neutrophils are known to be stimulated by different periodontal bacteria to produce reactive oxygen species and cytokines. It is inportant to investigate the gene changes made by bacteria of importance, of which, for periodontal disease, fusobaterium nucleatum is one. we used microarrays to investigate gene experssion changes in peripheral blood neutrophils werwhich e stimulated with or with out Fusobacterium Nucleatum (10953).

Standard name | GSE20366_TREG_VS_TCONV_UP
Systematic name | M4311
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TregCD103-Klrg1 versus TconvLP (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_TREG_VS_TCONV_DN
Systematic name | M4312
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TregCD103-Klrg1 versus TconvLP (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_EX_VIVO_VS_HOMEOSTATIC_CONVERSION_TREG_UP
Systematic name | M4313
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TregLP versus Homeo Convert (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_EX_VIVO_VS_HOMEOSTATIC_CONVERSION_TREG_DN
Systematic name | M4314
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TregLP versus Homeo Convert (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_EX_VIVO_VS_DEC205_CONVERSION_UP
Systematic name | M4316
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TregLP versus DEC-Pept Convert (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_EX_VIVO_VS_DEC205_CONVERSION_DN
Systematic name | M4318
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TregLP versus DEC-Pept Convert (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_EX_VIVO_VS_HOMEOSTATIC_CONVERSION_NAIVE_CD4_TCELL_UP
Systematic name | M4323
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TconvLP versus Homeo Foxp3- (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_EX_VIVO_VS_HOMEOSTATIC_CONVERSION_NAIVE_CD4_TCELL_DN
Systematic name | M4326
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TconvLP versus Homeo Foxp3- (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_EX_VIVO_VS_DEC205_CONVERSION_NAIVE_CD4_TCELL_UP
Systematic name | M4327
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TconvLP versus DEC-Pept CD25- (see Table S1 in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_EX_VIVO_VS_DEC205_CONVERSION_NAIVE_CD4_TCELL_DN
Systematic name | M4328
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TconvLP versus DEC-Pept CD25- (see Table S1 in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_TREG_VS_NAIVE_CD4_TCELL_HOMEOSTATIC_CONVERSION_UP
Systematic name | M4330
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Homeo Convert versus Homeo Foxp3- (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_TREG_VS_NAIVE_CD4_TCELL_HOMEOSTATIC_CONVERSION_DN
Systematic name | M4331
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Homeo Convert versus Homeo Foxp3- (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_TREG_VS_NAIVE_CD4_TCELL_DEC205_CONVERSION_UP
Systematic name | M4332
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of DEC-Pept Convert versus DEC-Pept CD25- (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_TREG_VS_NAIVE_CD4_TCELL_DEC205_CONVERSION_DN
Systematic name | M4334
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of DEC-Pept Convert versus DEC-Pept CD25- (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_CD103_POS_VS_NEG_TREG_KLRG1NEG_UP
Systematic name | M4335
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TregCD103-Klrg1- versus TregCD103+Klrg1- (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_CD103_POS_VS_NEG_TREG_KLRG1NEG_DN
Systematic name | M4338
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TregCD103-Klrg1- versus TregCD103+Klrg1- (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_CD103_KLRG1_DP_VS_DN_TREG_UP
Systematic name | M4341
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TregCD103-Klrg1- versus TregCD103+Klrg1+ (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_CD103_KLRG1_DP_VS_DN_TREG_DN
Systematic name | M4343
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TregCD103-Klrg1- versus TregCD103+Klrg1+ (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_CD103_POS_VS_CD103_KLRG1_DP_TREG_UP
Systematic name | M4344
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TregCD103+Klrg1- versus TregCD103+Klrg1+ (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_CD103_POS_VS_CD103_KLRG1_DP_TREG_DN
Systematic name | M4346
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TregCD103+Klrg1- versus TregCD103+Klrg1+ (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_TREG_VS_NAIVE_CD4_TCELL_UP
Systematic name | M4347
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TregLP versus TconvLP (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20366_TREG_VS_NAIVE_CD4_TCELL_DN
Systematic name | M4348
Organism | Mus musculus
PMID | 20231436
Authors | Feuerer M,Hill JA,Kretschmer K,von Boehmer H,Mathis D,Benoist C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TregLP versus TconvLP (see Table 1S in the paper for details).
Full description | Regulatory T (Treg) cells that express the FoxP3 transcription factor are essential for lymphoid homeostasis and immune tolerance to self. Other non-immunological functions of Treg cells, such as controlling metabolic function in adipose tissue, are also emerging. Treg cells originate primarily in the thymus, but can also be elicited from conventional T cells by in vivo exposure to low-dose antigen or homeostatic expansion, or by activation in the presence of TGFβ in vitro. Treg cells are characterized by a distinct transcriptional signature controlled in part, but not solely, by FoxP3. For a better perspective on transcriptional control in Treg cells, we compared gene expression profiles of a broad panel of Treg cells from various origins or anatomical locations. Treg cells generated by different means form different sub-phenotypes identifiable by particular combinations of transcripts, none of which fully encompass the entire Treg signature. Molecules involved in Treg effector function, chemokine receptors, and the transcription factors that control them are differentially represented in these subphenotypes. Treg cells from the gut proved dissimilar to cells elicited by exposure to TGFβ, but instead they resembled a CD103+Klrg1+ subphenotype preferentially generated in response to lymphopenia.

Standard name | GSE20715_WT_VS_TLR4_KO_LUNG_UP
Systematic name | M4349
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lung tissue from wild type mice versus that from TLR4 [GeneID=7099] deficient animals.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_WT_VS_TLR4_KO_LUNG_DN
Systematic name | M4350
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lung tissue from wild type mice versus that from TLR4 [GeneID=7099] deficient animals.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_WT_VS_TLR4_KO_6H_OZONE_LUNG_UP
Systematic name | M4351
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparson of lung tissue from wild type mice subjected to ozone for 6 h vs that from TLR4 [GeneID=7099] deficient animal subjected to ozone for 6 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_WT_VS_TLR4_KO_6H_OZONE_LUNG_DN
Systematic name | M4352
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparson of lung tissue from wild type mice subjected to ozone for 6 h vs that from TLR4 [GeneID=7099] deficient animal subjected to ozone for 6 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_WT_VS_TLR4_KO_24H_OZONE_LUNG_UP
Systematic name | M4353
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lung tissue from wild type mice subjected to ozone for 24 h versus that from TLR4 [GeneID=7099] deficient mice subjected to ozone for 24 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_WT_VS_TLR4_KO_24H_OZONE_LUNG_DN
Systematic name | M4354
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lung tissue from wild type mice subjected to ozone for 24 h versus that from TLR4 [GeneID=7099] deficient mice subjected to ozone for 24 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_WT_VS_TLR4_KO_48H_OZONE_LUNG_UP
Systematic name | M4355
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lung tissue from wild type mice subjected to ozone for 48 h versus that from TLR4 [GeneID=7099] deficient mice subjected to ozone for 48 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_WT_VS_TLR4_KO_48H_OZONE_LUNG_DN
Systematic name | M4358
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lung tissue from wild type mice subjected to ozone for 48 h versus that from TLR4 [GeneID=7099] deficient mice subjected to ozone for 48 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_6H_OZONE_LUNG_UP
Systematic name | M4360
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from wild type mice subjected to ozone for 6 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_6H_OZONE_LUNG_DN
Systematic name | M4365
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from wild type mice subjected to ozone for 6 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_24H_OZONE_LUNG_UP
Systematic name | M4366
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from wild type mice subjected to ozone for 24 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_24H_OZONE_LUNG_DN
Systematic name | M4367
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from wild type mice subjected to ozone for 24 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_48H_OZONE_LUNG_UP
Systematic name | M4368
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from wild type mice subjected to ozone for 48 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_48H_OZONE_LUNG_DN
Systematic name | M4369
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from wild type mice subjected to ozone for 48 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_6H_OZONE_TLR4_KO_LUNG_UP
Systematic name | M4370
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from TLR4 [GeneID=7099] deficient mice subjected to ozone for 6 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_6H_OZONE_TLR4_KO_LUNG_DN
Systematic name | M4373
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from TLR4 [GeneID=7099] deficient mice subjected to ozone for 6 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_24H_OZONE_TLR4_KO_LUNG_UP
Systematic name | M4374
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from TLR4 [GeneID=7099] deficient mice subjected to ozone for 24 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_24H_OZONE_TLR4_KO_LUNG_DN
Systematic name | M4375
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from TLR4 [GeneID=7099] deficient mice subjected to ozone for 24 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_48H_OZONE_TLR4_KO_LUNG_UP
Systematic name | M4379
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from TLR4 [GeneID=7099] deficient mice subjected to ozone for 48 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE20715_0H_VS_48H_OZONE_TLR4_KO_LUNG_DN
Systematic name | M4386
Organism | Mus musculus
PMID | 21543283
Authors | Bauer AK,Rondini EA,Hummel KA,Degraff LM,Walker C,Jedlicka AE,Kleeberger SR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lung tissue from wild type mice subjected to ozone for 0 h versus that from TLR4 [GeneID=7099] deficient mice subjected to ozone for 48 h.
Full description | We previously identified toll-like receptor 4 (Tlr4) as a candidate gene responsible for ozone (O3)-induced pulmonary hyperpermeability and inflammation. The objective of this study was to determine the mechanism through which TLR4 modulates O3-induced pulmonary responses and to utilize transcriptomics to determine TLR4 effector molecules. C3H/HeJ (HeJ; Tlr4 mutant) and C3H/HeOuJ (OuJ; Tlr4 normal), mice were exposed continuously to 0.3 ppm O3 or filtered air for 6, 24, 48 or 72 hr. Affymetrix Mouse430A_MOE gene arrays were used to analyze lung homogenates from HeJ and OuJ mice followed using a bioinformatic analysis. Inflammation was assessed by bronchoalveolar lavage and molecular analysis by ELISA, immunoblotting, and transcription factor activity. TLR4 signals through both the MYD88-dependent and independent pathways in OuJ mice, which involves MAP kinase activation, NF-kappaB, AP-1, and KC. Microarray analyses identifiedTLR4 responsive genes for strain and time in OuJ versus HeJ mice (p&lt;0.05). One significantly upregulated cluster of genes in OuJ were the heat shock proteins (Hspa1b; Hsp70), Hsp90ab1). Furthermore, O3-induced expression of HSP70 protein was increased in OuJ compared to HeJ mice following 24-48 h O3. Moreover, BAL polymorphonuclear leukocytes (PMN) and total protein were significantly reduced in response to O3 in Hspa1a/Hspa1btm1Dix (Hsp70-/-) compared to Hsp70+/+ mice (p&lt;0.05). TLR4 signaling (MYD88-dependent), ERK1/2, AP-1 activity, and KC protein content were also significantly reduced after O3 exposure in Hsp70-/- compared to Hsp70+/+ mice (p&lt;0.05). These studies suggest that HSP70 is involved in the regulation of O3-induced lung inflammation through the TLR4 pathway and provide evidence that HSP70 is an endogenous in vivo TLR4 ligand.

Standard name | GSE2197_IMMUNOSUPPRESSIVE_DNA_VS_UNTREATED_IN_DC_UP
Systematic name | M4387
Organism | Mus musculus
PMID | 16413926
Authors | Stetson DB,Medzhitov R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) treated with immunosuppressive DNA versus the untreated cells.
Full description | Bone marrow-derived dendritic cells were left untreated or stimulated with lipid-transfected double-stranded DNA or CpG oligonucleotides for four hours before harvesting.

Standard name | GSE2197_IMMUNOSUPPRESSIVE_DNA_VS_UNTREATEDIN_DC_DN
Systematic name | M4390
Organism | Mus musculus
PMID | 16413926
Authors | Stetson DB,Medzhitov R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) treated with immunosuppressive DNA versus the untreated cells.
Full description | Bone marrow-derived dendritic cells were left untreated or stimulated with lipid-transfected double-stranded DNA or CpG oligonucleotides for four hours before harvesting.

Standard name | GSE2197_CPG_DNA_VS_UNTREATED_IN_DC_UP
Systematic name | M4393
Organism | Mus musculus
PMID | 16413926
Authors | Stetson DB,Medzhitov R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) treated with CpG DNA (TLR9 agonist) DNA versus the untreated cells.
Full description | Bone marrow-derived dendritic cells were left untreated or stimulated with lipid-transfected double-stranded DNA or CpG oligonucleotides for four hours before harvesting.

Standard name | GSE2197_CPG_DNA_VS_UNTREATED_IN_DC_DN
Systematic name | M4398
Organism | Mus musculus
PMID | 16413926
Authors | Stetson DB,Medzhitov R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) treated with CpG DNA (TLR9 agonist) DNA versus the untreated cells.
Full description | Bone marrow-derived dendritic cells were left untreated or stimulated with lipid-transfected double-stranded DNA or CpG oligonucleotides for four hours before harvesting.

Standard name | GSE22045_TREG_VS_TCONV_UP
Systematic name | M4400
Organism | Homo sapiens
PMID | 22562448
Authors | Bonacci B,Edwards B,Jia S,Williams CB,Hessner MJ,Gauld SB,Verbsky JW.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cell (Treg) versus conventional T cells.
Full description | Human regulatory T cells (TR) cells have potential for the treatment of immune mediated diseases, such as graft versus host disease, but the anergic phenotype of these cells makes them difficult to expand in vitro. We have examined the requirements for growth and cytokine expression from highly purified human TR cells, and correlated these findings with the signal transduction events of these cells. We demonstrate that these cells do not proliferate or secrete IL-10 even in the presence of high doses of IL-2. Stimulation with a superagonistic anti-CD28 antibody (clone 9D4) and IL-2 partially reversed the proliferative defect, and this correlated with reversal of the defective calcium mobilization in these cells. Dendritic cells were effective at promoting TR cell proliferation, and under these conditions the proliferative capacity of TR cells was comparable to conventional CD4 lymphocytes. Blocking TGF-beta activity abrogated IL-10 expression from these cells, while addition of TGF-beta resulted in IL-10 production. These data demonstrate the ability of dendritic cells to provide proper costimulation to overcome the anergic phenotype of TR cells. In addition, these data demonstrate for the first time that TGF-beta is critical to enable TR cells to express IL-10.

Standard name | GSE22045_TREG_VS_TCONV_DN
Systematic name | M4401
Organism | Homo sapiens
PMID | 22562448
Authors | Bonacci B,Edwards B,Jia S,Williams CB,Hessner MJ,Gauld SB,Verbsky JW.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cell (Treg) versus conventional T cells.
Full description | Human regulatory T cells (TR) cells have potential for the treatment of immune mediated diseases, such as graft versus host disease, but the anergic phenotype of these cells makes them difficult to expand in vitro. We have examined the requirements for growth and cytokine expression from highly purified human TR cells, and correlated these findings with the signal transduction events of these cells. We demonstrate that these cells do not proliferate or secrete IL-10 even in the presence of high doses of IL-2. Stimulation with a superagonistic anti-CD28 antibody (clone 9D4) and IL-2 partially reversed the proliferative defect, and this correlated with reversal of the defective calcium mobilization in these cells. Dendritic cells were effective at promoting TR cell proliferation, and under these conditions the proliferative capacity of TR cells was comparable to conventional CD4 lymphocytes. Blocking TGF-beta activity abrogated IL-10 expression from these cells, while addition of TGF-beta resulted in IL-10 production. These data demonstrate the ability of dendritic cells to provide proper costimulation to overcome the anergic phenotype of TR cells. In addition, these data demonstrate for the first time that TGF-beta is critical to enable TR cells to express IL-10.

Standard name | GSE22886_CD8_VS_CD4_NAIVE_TCELL_UP
Systematic name | M4402
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus naive CD4 [GeneID=920] T cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_CD8_VS_CD4_NAIVE_TCELL_DN
Systematic name | M4404
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus naive CD4 [GeneID=920] T cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD8_TCELL_VS_MEMORY_TCELL_UP
Systematic name | M4405
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus naive CD4 [GeneID=920] CD8 T cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD8_TCELL_VS_MEMORY_TCELL_DN
Systematic name | M4407
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus naive CD4 [GeneID=920] CD8 T cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_UNSTIM_VS_STIM_MEMORY_TCELL_UP
Systematic name | M4408
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated memory CD4 [GeneID=920] CD8 T cells versus stimulated CD4 [GeneID=920] CD8 T cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_UNSTIM_VS_STIM_MEMORY_TCELL_DN
Systematic name | M4410
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated memory CD4 [GeneID=920] CD8 T cells versus stimulated CD4 [GeneID=920] CD8 T cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_MEMORY_TCELL_UP
Systematic name | M4411
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus unstimulated memory CD4 [GeneID=920] CD8 T cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_MEMORY_TCELL_DN
Systematic name | M4412
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus unstimulated memory CD4 [GeneID=920] CD8 T cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_TCELL_VS_NKCELL_UP
Systematic name | M4413
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus unstimulated NK cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_TCELL_VS_NKCELL_DN
Systematic name | M4415
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus unstimulated NK cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_VS_MEMORY_TCELL_UP
Systematic name | M4416
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus unstimulated memory CD4 [GeneID=920] CD8 T cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_VS_MEMORY_TCELL_DN
Systematic name | M4417
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus unstimulated memory CD4 [GeneID=920] CD8 T cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD8_TCELL_VS_NKCELL_UP
Systematic name | M4418
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus unstimulated NK cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD8_TCELL_VS_NKCELL_DN
Systematic name | M4421
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus unstimulated NK cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_NKCELL_UP
Systematic name | M4423
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus unstimulated NK cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_NKCELL_DN
Systematic name | M4424
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus unstimulated NK cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_TCELL_VS_BCELL_NAIVE_UP
Systematic name | M4425
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus naive B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_TCELL_VS_BCELL_NAIVE_DN
Systematic name | M4426
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus naive B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_CD8_TCELL_VS_BCELL_NAIVE_UP
Systematic name | M4427
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus naive B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_CD8_TCELL_VS_BCELL_NAIVE_DN
Systematic name | M4429
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus naive B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_CD4_TCELL_VS_BCELL_NAIVE_UP
Systematic name | M4430
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus naive B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_CD4_TCELL_VS_BCELL_NAIVE_DN
Systematic name | M4431
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus naive B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_VS_IGG_IGA_MEMORY_BCELL_UP
Systematic name | M4432
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus memory IgG IgA B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_VS_IGG_IGA_MEMORY_BCELL_DN
Systematic name | M4433
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus memory IgG IgA B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_VS_IGM_MEMORY_BCELL_UP
Systematic name | M4434
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus memory IgM B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_VS_IGM_MEMORY_BCELL_DN
Systematic name | M4436
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus memory IgM B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IGA_VS_IGM_MEMORY_BCELL_UP
Systematic name | M4437
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory IgG IgA B cells versus memory IgM B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IGA_VS_IGM_MEMORY_BCELL_DN
Systematic name | M4439
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory IgG IgA B cells versus memory IgM B cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_BCELL_VS_BLOOD_PLASMA_CELL_UP
Systematic name | M4440
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus blood plasma cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_BCELL_VS_BLOOD_PLASMA_CELL_DN
Systematic name | M4441
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus blood plasma cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_BCELL_VS_BM_PLASMA_CELL_UP
Systematic name | M4442
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus plasma cells from bone marrow and blood.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_BCELL_VS_BM_PLASMA_CELL_DN
Systematic name | M4443
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus plasma cells from bone marrow and blood.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IGG_IGA_MEMORY_BCELL_VS_BLOOD_PLASMA_CELL_UP
Systematic name | M4444
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory IgG IgA B cells versus blood plasma cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IGG_IGA_MEMORY_BCELL_VS_BLOOD_PLASMA_CELL_DN
Systematic name | M4446
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory IgG IgA B cells versus blood plasma cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IGG_IGA_MEMORY_BCELL_VS_BM_PLASMA_CELL_UP
Systematic name | M4449
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory IgG IgA B cells versus plasma cells from bone marrow and blood.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IGG_IGA_MEMORY_BCELL_VS_BM_PLASMA_CELL_DN
Systematic name | M4450
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory IgG IgA B cells versus plasma cells from bone marrow and blood.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IGM_MEMORY_BCELL_VS_BLOOD_PLASMA_CELL_UP
Systematic name | M4451
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory IgM B cells versus blood plasma cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IGM_MEMORY_BCELL_VS_BLOOD_PLASMA_CELL_DN
Systematic name | M4454
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory IgM B cells versus blood plasma cells.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IGM_MEMORY_BCELL_VS_BM_PLASMA_CELL_UP
Systematic name | M4456
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory IgM B cells versus plasma cells from bone marrow and blood.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IGM_MEMORY_BCELL_VS_BM_PLASMA_CELL_DN
Systematic name | M4457
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory IgM B cells versus plasma cells from bone marrow and blood.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_DAY0_VS_DAY1_MONOCYTE_IN_CULTURE_UP
Systematic name | M4458
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes cultured for 0 days versus those cultured for 1 day.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_DAY0_VS_DAY1_MONOCYTE_IN_CULTURE_DN
Systematic name | M4459
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes cultured for 0 days versus those cultured for 1 day.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_DAY0_VS_DAY7_MONOCYTE_IN_CULTURE_UP
Systematic name | M4460
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes cultured for 0 days versus those cultured for 7 days.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_DAY0_VS_DAY7_MONOCYTE_IN_CULTURE_DN
Systematic name | M4461
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes cultured for 0 days versus those cultured for 7 days.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_DAY1_VS_DAY7_MONOCYTE_IN_CULTURE_UP
Systematic name | M4462
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes cultured for 1 day versus those cultured for 7 days.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_DAY1_VS_DAY7_MONOCYTE_IN_CULTURE_DN
Systematic name | M4463
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes cultured for 1 day versus those cultured for 7 days.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NEUTROPHIL_VS_DC_UP
Systematic name | M4464
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of neutrophils versus dendritic cells (DC).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NEUTROPHIL_VS_DC_DN
Systematic name | M4465
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of neutrophils versus dendritic cells (DC).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NEUTROPHIL_VS_MONOCYTE_UP
Systematic name | M4466
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of neuthrophils versus monocytes.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NEUTROPHIL_VS_MONOCYTE_DN
Systematic name | M4467
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of neutrophils versusl monocytes.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_DC_VS_MONOCYTE_UP
Systematic name | M4471
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus monocytes.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_DC_VS_MONOCYTE_DN
Systematic name | M4472
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus monocytes.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_TCELL_VS_NEUTROPHIL_UP
Systematic name | M4473
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus unstimulated neutrophils.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_TCELL_VS_NEUTROPHIL_DN
Systematic name | M4474
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus unstimulated neutrophils.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_TCELL_VS_DC_UP
Systematic name | M4475
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus unstimulated dendritic cells (DC).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_TCELL_VS_DC_DN
Systematic name | M4476
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus unstimulated dendritic cells (DC).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_TCELL_VS_MONOCYTE_UP
Systematic name | M4478
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus monocytes cultured for 0 days.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_TCELL_VS_MONOCYTE_DN
Systematic name | M4480
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] CD8 T cells versus monocytes cultured for 0 days.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_BCELL_VS_NEUTROPHIL_UP
Systematic name | M4481
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus unstimulated neutrophils.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_BCELL_VS_NEUTROPHIL_DN
Systematic name | M4482
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus unstimulated neutrophils.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_BCELL_VS_DC_UP
Systematic name | M4483
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus unstimulated dendritic cells (DC).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_BCELL_VS_DC_DN
Systematic name | M4484
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus unstimulated dendritic cells (DC).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_BCELL_VS_MONOCYTE_UP
Systematic name | M4485
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive B cells versus day 0 monocytes.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_BCELL_VS_MONOCYTE_DN
Systematic name | M4486
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive B cells versus day 0 monocytes.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD8_TCELL_VS_NEUTROPHIL_UP
Systematic name | M4488
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus unstimulated neutrophils.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD8_TCELL_VS_NEUTROPHIL_DN
Systematic name | M4489
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus unstimulated neutrophils.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD8_TCELL_VS_DC_UP
Systematic name | M4490
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus unstimulated dendritic cells (DC).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD8_TCELL_VS_DC_DN
Systematic name | M4492
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus unstimulated dendritic cells (DC).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD8_TCELL_VS_MONOCYTE_UP
Systematic name | M4494
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus day 0 monocytes.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD8_TCELL_VS_MONOCYTE_DN
Systematic name | M4496
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus day 0 monocytes.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_NEUTROPHIL_UP
Systematic name | M4497
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus unstimulated neutrophils.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_NEUTROPHIL_DN
Systematic name | M4498
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus unstimulated neutrophils.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_DC_UP
Systematic name | M4501
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus unstimulatd dendritic cells (DC).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_DC_DN
Systematic name | M4503
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus unstimulatd dendritic cells (DC).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_MONOCYTE_UP
Systematic name | M4504
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus day 0 monocytes.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_MONOCYTE_DN
Systematic name | M4506
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus day 0 monocytes.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_TH1_VS_TH2_12H_ACT_UP
Systematic name | M4507
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of stimulated CD4 [GeneID=920] Th1 cells at 12 h versus stimulated CD4 [GeneID=920] Th2 cells at 12 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_TH1_VS_TH2_12H_ACT_DN
Systematic name | M4509
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of stimulated CD4 [GeneID=920] Th1 cells at 12 h versus stimulated CD4 [GeneID=920] Th2 cells at 12 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_TH1_VS_TH2_48H_ACT_UP
Systematic name | M4510
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of stimulated CD4 [GeneID=920] Th1 cells at 48 h versus stimulated CD4 [GeneID=920] Th2 cells at 48 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_TH1_VS_TH2_48H_ACT_DN
Systematic name | M4512
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of stimulated CD4 [GeneID=920] Th1 cells at 48 h versus stimulated CD4 [GeneID=920] Th2 cells at 48 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IL2_VS_IL15_STIM_NKCELL_UP
Systematic name | M4514
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NK cells stimulated with IL2 [GeneID=3558] at 16 h versus NK cells stimulated with IL15 [GeneID=3600] at 16 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_IL2_VS_IL15_STIM_NKCELL_DN
Systematic name | M4516
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NK cells stimulated with IL2 [GeneID=3558] at 16 h versus NK cells stimulated with IL15 [GeneID=3600] at 16 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_CTRL_VS_LPS_24H_DC_UP
Systematic name | M4518
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated dendritic cells (DC) versus 1 day DC stimulated with LPS (TLR4 agonist).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_CTRL_VS_LPS_24H_DC_DN
Systematic name | M4520
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated dendritic cells (DC) versus 1 day DC stimulated with LPS (TLR4 agonist).
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_12H_ACT_TH1_UP
Systematic name | M4521
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus stimulated CD4 [GeneID=920] Th1 cells at 12 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_12H_ACT_TH1_DN
Systematic name | M4523
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus stimulated CD4 [GeneID=920] Th1 cells at 12 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_48H_ACT_TH1_UP
Systematic name | M4524
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus stimulated CD4 [GeneID=920] Th1 cells at 48 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_48H_ACT_TH1_DN
Systematic name | M4525
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus stimulated CD4 [GeneID=920] Th1 cells at 48 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_12H_ACT_TH2_UP
Systematic name | M4526
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus stimulated CD4 [GeneID=920] Th2 cells at 12 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_12H_ACT_TH2_DN
Systematic name | M4527
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus stimulated CD4 [GeneID=920] Th2 cells at 12 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_48H_ACT_TH2_UP
Systematic name | M4528
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus stimulated CD4 [GeneID=920] Th2 cells at 48 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_NAIVE_CD4_TCELL_VS_48H_ACT_TH2_DN
Systematic name | M4529
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus stimulated CD4 [GeneID=920] Th2 cells at 48 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_UNSTIM_VS_IL2_STIM_NKCELL_UP
Systematic name | M4530
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated NK cells versus those stimulated with IL2 [GeneID=3558] at 16 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_UNSTIM_VS_IL2_STIM_NKCELL_DN
Systematic name | M4531
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated NK cells versus those stimulated with IL2 [GeneID=3558] at 16 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_UNSTIM_VS_IL15_STIM_NKCELL_UP
Systematic name | M4532
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated NK cells versus those stimulated with IL15 [GeneID=3600] at 16 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE22886_UNSTIM_VS_IL15_STIM_NKCELL_DN
Systematic name | M4533
Organism | Homo sapiens
PMID | 15789058
Authors | Abbas AR,Baldwin D,Ma Y,Ouyang W,Gurney A,Martin F,Fong S,van Lookeren Campagne M,Godowski P,Williams PM,Chan AC,Clark HF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated NK cells versus those stimulated with IL2 [GeneID=3600] at 16 h.
Full description | Immune cell-specific expression is one indication of the importance of a gene's role in the immune response. In order to identify such patterns, we set out to broadly profile gene expression in a variety of immune cells.

Standard name | GSE24026_PD1_LIGATION_VS_CTRL_IN_ACT_TCELL_LINE_UP
Systematic name | M4534
Organism | Homo sapiens
PMID | 20890291
Authors | Quigley M,Pereyra F,Nilsson B,Porichis F,Fonseca C,Eichbaum Q,Julg B,Jesneck JL,Brosnahan K,Imam S,Russell K,Toth I,Piechocka-Trocha A,Dolfi D,Angelosanto J,Crawford A,Shin H,Kwon DS,Zupkosky J,Francisco L,Freeman GJ,Wherry EJ,Kaufmann DE,Walker BD,Ebert B,Haining WN.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Jurkat T cells stimulated in the presence of PD-1 versus controls.
Full description | CD8+ T cells in chronic viral infections like HIV develop functional defects such as loss of IL-2 secretion and decreased proliferative potential that are collectively termed exhaustion1. Exhausted T cells express increased levels of multiple inhibitory receptors, such as Programmed Death 1 (PD-1). PD-1 inhibition contributes to impaired virus-specific T cell function in chronic infection because antibody-mediated blockade of its ligand, Programmed Death Ligand 1 (PD-L1) is sufficient to improve T cell function and reduce viral replication in animal models. Reversing PD-1 inhibition is therefore an attractive therapeutic target, but the cellular mechanisms by which PD-1 ligation results in T cell inhibition are not fully understood. PD-1 is thought to limit T cell activation by attenuating T cell receptor (TCR) signaling. It is not known whether PD-1 ligation also acts by upregulating genes in exhausted T cells that impair their function. Here, we analyzed gene-expression profiles from HIV-specific CD8+ T cells in patients with HIV and show that PD-1 coordinately upregulates a program of genes in exhausted CD8+ T cells from humans and mice. This program includes upregulation of basic leucine transcription factor, ATF-like (BATF), a transcription factor in the AP-1 family. Enforced expression of BATF was sufficient to impair T cell proliferation and cytokine secretion, while BATF knockdown reduced PD-1 inhibition. Silencing BATF in CD4+ and CD8+ T cells from chronic viremic patients rescued HIV-specific T cell function. Thus inhibitory receptors can cause T cell exhaustion by upregulating genes – such as BATF – that inhibit T cell function.

Standard name | GSE24026_PD1_LIGATION_VS_CTRL_IN_ACT_TCELL_LINE_DN
Systematic name | M4538
Organism | Homo sapiens
PMID | 20890291
Authors | Quigley M,Pereyra F,Nilsson B,Porichis F,Fonseca C,Eichbaum Q,Julg B,Jesneck JL,Brosnahan K,Imam S,Russell K,Toth I,Piechocka-Trocha A,Dolfi D,Angelosanto J,Crawford A,Shin H,Kwon DS,Zupkosky J,Francisco L,Freeman GJ,Wherry EJ,Kaufmann DE,Walker BD,Ebert B,Haining WN.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Jurkat T cells stimulated in the presence of PD-1 versus controls.
Full description | CD8+ T cells in chronic viral infections like HIV develop functional defects such as loss of IL-2 secretion and decreased proliferative potential that are collectively termed exhaustion1. Exhausted T cells express increased levels of multiple inhibitory receptors, such as Programmed Death 1 (PD-1). PD-1 inhibition contributes to impaired virus-specific T cell function in chronic infection because antibody-mediated blockade of its ligand, Programmed Death Ligand 1 (PD-L1) is sufficient to improve T cell function and reduce viral replication in animal models. Reversing PD-1 inhibition is therefore an attractive therapeutic target, but the cellular mechanisms by which PD-1 ligation results in T cell inhibition are not fully understood. PD-1 is thought to limit T cell activation by attenuating T cell receptor (TCR) signaling. It is not known whether PD-1 ligation also acts by upregulating genes in exhausted T cells that impair their function. Here, we analyzed gene-expression profiles from HIV-specific CD8+ T cells in patients with HIV and show that PD-1 coordinately upregulates a program of genes in exhausted CD8+ T cells from humans and mice. This program includes upregulation of basic leucine transcription factor, ATF-like (BATF), a transcription factor in the AP-1 family. Enforced expression of BATF was sufficient to impair T cell proliferation and cytokine secretion, while BATF knockdown reduced PD-1 inhibition. Silencing BATF in CD4+ and CD8+ T cells from chronic viremic patients rescued HIV-specific T cell function. Thus inhibitory receptors can cause T cell exhaustion by upregulating genes – such as BATF – that inhibit T cell function.

Standard name | GSE24081_CONTROLLER_VS_PROGRESSOR_HIV_SPECIFIC_CD8_TCELL_UP
Systematic name | M4539
Organism | Homo sapiens
PMID | 20890291
Authors | Quigley M,Pereyra F,Nilsson B,Porichis F,Fonseca C,Eichbaum Q,Julg B,Jesneck JL,Brosnahan K,Imam S,Russell K,Toth I,Piechocka-Trocha A,Dolfi D,Angelosanto J,Crawford A,Shin H,Kwon DS,Zupkosky J,Francisco L,Freeman GJ,Wherry EJ,Kaufmann DE,Walker BD,Ebert B,Haining WN.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells with progressing HIV infection versus those with controlled HIV infection.
Full description | CD8+ T cells in chronic viral infections like HIV develop functional defects such as loss of IL-2 secretion and decreased proliferative potential that are collectively termed exhaustion1. Exhausted T cells express increased levels of multiple inhibitory receptors, such as Programmed Death 1 (PD-1). PD-1 inhibition contributes to impaired virus-specific T cell function in chronic infection because antibody-mediated blockade of its ligand, Programmed Death Ligand 1 (PD-L1) is sufficient to improve T cell function and reduce viral replication in animal models. Reversing PD-1 inhibition is therefore an attractive therapeutic target, but the cellular mechanisms by which PD-1 ligation results in T cell inhibition are not fully understood. PD-1 is thought to limit T cell activation by attenuating T cell receptor (TCR) signaling. It is not known whether PD-1 ligation also acts by upregulating genes in exhausted T cells that impair their function. Here, we analyzed gene-expression profiles from HIV-specific CD8+ T cells in patients with HIV and show that PD-1 coordinately upregulates a program of genes in exhausted CD8+ T cells from humans and mice. This program includes upregulation of basic leucine transcription factor, ATF-like (BATF), a transcription factor in the AP-1 family. Enforced expression of BATF was sufficient to impair T cell proliferation and cytokine secretion, while BATF knockdown reduced PD-1 inhibition. Silencing BATF in CD4+ and CD8+ T cells from chronic viremic patients rescued HIV-specific T cell function. Thus inhibitory receptors can cause T cell exhaustion by upregulating genes – such as BATF – that inhibit T cell function.

Standard name | GSE24081_CONTROLLER_VS_PROGRESSOR_HIV_SPECIFIC_CD8_TCELL_DN
Systematic name | M4540
Organism | Homo sapiens
PMID | 20890291
Authors | Quigley M,Pereyra F,Nilsson B,Porichis F,Fonseca C,Eichbaum Q,Julg B,Jesneck JL,Brosnahan K,Imam S,Russell K,Toth I,Piechocka-Trocha A,Dolfi D,Angelosanto J,Crawford A,Shin H,Kwon DS,Zupkosky J,Francisco L,Freeman GJ,Wherry EJ,Kaufmann DE,Walker BD,Ebert B,Haining WN.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells with progressing HIV infection versus those with controlled HIV infection.
Full description | CD8+ T cells in chronic viral infections like HIV develop functional defects such as loss of IL-2 secretion and decreased proliferative potential that are collectively termed exhaustion1. Exhausted T cells express increased levels of multiple inhibitory receptors, such as Programmed Death 1 (PD-1). PD-1 inhibition contributes to impaired virus-specific T cell function in chronic infection because antibody-mediated blockade of its ligand, Programmed Death Ligand 1 (PD-L1) is sufficient to improve T cell function and reduce viral replication in animal models. Reversing PD-1 inhibition is therefore an attractive therapeutic target, but the cellular mechanisms by which PD-1 ligation results in T cell inhibition are not fully understood. PD-1 is thought to limit T cell activation by attenuating T cell receptor (TCR) signaling. It is not known whether PD-1 ligation also acts by upregulating genes in exhausted T cells that impair their function. Here, we analyzed gene-expression profiles from HIV-specific CD8+ T cells in patients with HIV and show that PD-1 coordinately upregulates a program of genes in exhausted CD8+ T cells from humans and mice. This program includes upregulation of basic leucine transcription factor, ATF-like (BATF), a transcription factor in the AP-1 family. Enforced expression of BATF was sufficient to impair T cell proliferation and cytokine secretion, while BATF knockdown reduced PD-1 inhibition. Silencing BATF in CD4+ and CD8+ T cells from chronic viremic patients rescued HIV-specific T cell function. Thus inhibitory receptors can cause T cell exhaustion by upregulating genes – such as BATF – that inhibit T cell function.

Standard name | GSE24102_GRANULOCYSTIC_MDSC_VS_NEUTROPHIL_UP
Systematic name | M4541
Organism | Mus musculus
PMID | 21954284
Authors | Youn JI,Collazo M,Shalova IN,Biswas SK,Gabrilovich DI.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of granulocytic myeloid derived suppressor cells (MDSC) versus neutrophils.
Full description | Myeloid derived suppressor cells (MDSC) playing the immune suppressive roles in tumor bearing host consists of two major subsets of granulocytic and monocytic cells. Granulocytic MDSC (G-MDSC) express CD11b+ Gr-1high Ly6G+ Ly6Clow and produce high level of reactive oxygen species (ROS). Interestingly, neutrophils are well known ROS producing cells during immune defensive process and share same surface markers with G-MDSC. These similar features always brought the fundamental questions what’s the difference between G-MDSC and neutrophils but it’s not yet proven clearly. In this study, we examined the gene expression of G-MDSC and neutrophils using Affymetrix microarray.

Standard name | GSE24102_GRANULOCYSTIC_MDSC_VS_NEUTROPHIL_DN
Systematic name | M4542
Organism | Mus musculus
PMID | 21954284
Authors | Youn JI,Collazo M,Shalova IN,Biswas SK,Gabrilovich DI.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of granulocytic myeloid derived suppressor cells (MDSC) versus neutrophils.
Full description | Myeloid derived suppressor cells (MDSC) playing the immune suppressive roles in tumor bearing host consists of two major subsets of granulocytic and monocytic cells. Granulocytic MDSC (G-MDSC) express CD11b+ Gr-1high Ly6G+ Ly6Clow and produce high level of reactive oxygen species (ROS). Interestingly, neutrophils are well known ROS producing cells during immune defensive process and share same surface markers with G-MDSC. These similar features always brought the fundamental questions what’s the difference between G-MDSC and neutrophils but it’s not yet proven clearly. In this study, we examined the gene expression of G-MDSC and neutrophils using Affymetrix microarray.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN2_THYMOCYTE_UP
Systematic name | M4545
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of thymic progenitors versus DN2 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN2_THYMOCYTE_DN
Systematic name | M4549
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of thymic progenitors versus DN2 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN3_THYMOCYTE_UP
Systematic name | M4553
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of thymic progenitors versus DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN3_THYMOCYTE_DN
Systematic name | M4554
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of thymic progenitors versus DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_DN2_VS_DN3_THYMOCYTE_UP
Systematic name | M4555
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of DN2 thymocytes versus DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_DN2_VS_DN3_THYMOCYTE_DN
Systematic name | M4558
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of DN2 thymocytes versus DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN2_THYMOCYTE_ADULT_UP
Systematic name | M4559
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of adult thymic progenitors versus adult DN2 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN2_THYMOCYTE_ADULT_DN
Systematic name | M4560
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of adult thymic progenitors versus adult DN2 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN3_THYMOCYTE_ADULT_UP
Systematic name | M4561
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of adult thymic progenitors versus adult DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN3_THYMOCYTE_ADULT_DN
Systematic name | M4564
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of adult thymic progenitors versus adult DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_DN2_VS_DN3_THYMOCYTE_ADULT_UP
Systematic name | M4565
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in adult DN2 thymocytes versus adult DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_DN2_VS_DN3_THYMOCYTE_ADULT_DN
Systematic name | M4567
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in adult DN2 thymocytes versus adult DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN2_THYMOCYTE_FETAL_UP
Systematic name | M4568
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of thymic progenitors versus fetal DN2 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN2_THYMOCYTE_FETAL_DN
Systematic name | M4569
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of thymic progenitors versus fetal DN2 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN3_THYMOCYTE_FETAL_UP
Systematic name | M4570
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of thymic progenitors versus fetal DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_EARLY_THYMIC_PROGENITOR_VS_DN3_THYMOCYTE_FETAL_DN
Systematic name | M4571
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of thymic progenitors versus fetal DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_DN2_VS_DN3_THYMOCYTE_FETAL_UP
Systematic name | M4574
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of fetal DN2 thymocytes versus fetal DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_DN2_VS_DN3_THYMOCYTE_FETAL_DN
Systematic name | M4575
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of fetal DN2 thymocytes versus fetal DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_ADULT_VS_FETAL_EARLY_THYMIC_PROGENITOR_UP
Systematic name | M4576
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of adult thymic progenitors versus fetal thymic progenitors.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_ADULT_VS_FETAL_EARLY_THYMIC_PROGENITOR_DN
Systematic name | M4578
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of adult thymic progenitors versus fetal thymic progenitors.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_ADULT_VS_FETAL_DN2_THYMOCYTE_UP
Systematic name | M4579
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of adult DN2 thymocytes versus fetal DN2 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_ADULT_VS_FETAL_DN2_THYMOCYTE_DN
Systematic name | M4583
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of adult DN2 thymocytes versus fetal DN2 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_ADULT_VS_FETAL_DN3_THYMOCYTE_UP
Systematic name | M4584
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of adult DN3 thymocytes versus fetal DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24142_ADULT_VS_FETAL_DN3_THYMOCYTE_DN
Systematic name | M4585
Organism | Mus musculus
PMID | 22581009
Authors | Belyaev NN,Biró J,Athanasakis D,Fernandez-Reyes D,Potocnik AJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of adult DN3 thymocytes versus fetal DN3 thymocytes.
Full description | Development of T-cells provides a unique opportunity to study cell-fate determination due to the accessability and the well defined stages of developmental stages. In order to understand the genetic programs underlying fetal and adult T‑cell fate specification we subjected highly purified fetal and adult T-cell progenitor populations to a genome‑wide transcriptional analysis. The aim was to identify molecular elements that govern T-cell fate specification as a whole but ultimately to isolate elements that were specific for a given population in a specific developmental window.

Standard name | GSE24634_NAIVE_CD4_TCELL_VS_DAY3_IL4_CONV_TREG_UP
Systematic name | M4586
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive T cells at day 0 versus CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 3.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_NAIVE_CD4_TCELL_VS_DAY3_IL4_CONV_TREG_DN
Systematic name | M4587
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive T cells at day 0 versus CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 3.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_NAIVE_CD4_TCELL_VS_DAY5_IL4_CONV_TREG_UP
Systematic name | M4588
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive T cells at day 0 versus CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 5.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_NAIVE_CD4_TCELL_VS_DAY5_IL4_CONV_TREG_DN
Systematic name | M4589
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive T cells at day 0 versus CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 5.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_NAIVE_CD4_TCELL_VS_DAY7_IL4_CONV_TREG_UP
Systematic name | M4590
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive T cells at day 0 versus CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 7.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_NAIVE_CD4_TCELL_VS_DAY7_IL4_CONV_TREG_DN
Systematic name | M4593
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive T cells at day 0 versus CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 7.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_NAIVE_CD4_TCELL_VS_DAY10_IL4_CONV_TREG_UP
Systematic name | M4596
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive T cells at day 0 versus CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 10.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_NAIVE_CD4_TCELL_VS_DAY10_IL4_CONV_TREG_DN
Systematic name | M4597
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive T cells at day 0 versus CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 10.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TREG_VS_TCONV_POST_DAY3_IL4_CONVERSION_UP
Systematic name | M4599
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 3 versus CD25- T cells incubated with IL4 [GeneID=3565] at day 3.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TREG_VS_TCONV_POST_DAY3_IL4_CONVERSION_DN
Systematic name | M4600
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 3 versus CD25- T cells incubated with IL4 [GeneID=3565] at day 3.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TREG_VS_TCONV_POST_DAY5_IL4_CONVERSION_UP
Systematic name | M4601
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD25+ T cells treated with IL4 [GeneID=3565] versus CD25- T cells treated with IL4 [GeneID=3565] at day 5.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TREG_VS_TCONV_POST_DAY5_IL4_CONVERSION_DN
Systematic name | M4603
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD25+ T cells treated with IL4 [GeneID=3565] versus CD25- T cells treated with IL4 [GeneID=3565] at day 5.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TREG_VS_TCONV_POST_DAY7_IL4_CONVERSION_UP
Systematic name | M4604
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 7 versus CD25- T cells treated with IL4 [GeneID=3565] at day 7.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TREG_VS_TCONV_POST_DAY7_IL4_CONVERSION_DN
Systematic name | M4606
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 7 versus CD25- T cells treated with IL4 [GeneID=3565] at day 7.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TREG_VS_TCONV_POST_DAY10_IL4_CONVERSION_UP
Systematic name | M4607
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 10 versus CD25- T cells treated with IL4 [GeneID=3565] at 10 h.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TREG_VS_TCONV_POST_DAY10_IL4_CONVERSION_DN
Systematic name | M4612
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD25+ regulatory T cell (Treg) treated with IL4 [GeneID=3565] at day 10 versus CD25- T cells treated with IL4 [GeneID=3565] at 10 h.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TEFF_VS_TCONV_DAY3_IN_CULTURE_UP
Systematic name | M4613
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD25+ T effector cells treated with IL4 [GeneID=3565] at day 3 versus untreated CD25- T cells at day 3.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TEFF_VS_TCONV_DAY3_IN_CULTURE_DN
Systematic name | M4616
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD25+ T effector cells treated with IL4 [GeneID=3565] at day 3 versus untreated CD25- T cells at day 3.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TEFF_VS_TCONV_DAY5_IN_CULTURE_UP
Systematic name | M4617
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD25+ T effector cells at day 5 versus untreated CD25- T cells at day 5.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TEFF_VS_TCONV_DAY5_IN_CULTURE_DN
Systematic name | M4620
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD25+ T effector cells at day 5 versus untreated CD25- T cells at day 5.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TEFF_VS_TCONV_DAY7_IN_CULTURE_UP
Systematic name | M4622
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD25+ T effector cells at day 7 versus untreated CD25- T cells at day 7.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TEFF_VS_TCONV_DAY7_IN_CULTURE_DN
Systematic name | M4624
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD25+ T effector cells at day 7 versus untreated CD25- T cells at day 7.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TEFF_VS_TCONV_DAY10_IN_CULTURE_UP
Systematic name | M4626
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD25+ T effector cells at day 10 versus untreated CD25- T cells at day 10.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_TEFF_VS_TCONV_DAY10_IN_CULTURE_DN
Systematic name | M4628
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD25+ T effector cells at day 10 versus untreated CD25- T cells at day 10.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_IL4_VS_CTRL_TREATED_NAIVE_CD4_TCELL_DAY3_UP
Systematic name | M4630
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD25- T cells treated with IL4 [GeneID=3565] at day 3 versus untreated CD25- T cells at day 3.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_IL4_VS_CTRL_TREATED_NAIVE_CD4_TCELL_DAY3_DN
Systematic name | M4632
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD25- T cells treated with IL4 [GeneID=3565] at day 3 versus untreated CD25- T cells at day 3.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_IL4_VS_CTRL_TREATED_NAIVE_CD4_TCELL_DAY5_UP
Systematic name | M4633
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD25- T cells treated with IL4 [GeneID=3565] at day 5 versus untreated CD25- T cells at day 5.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_IL4_VS_CTRL_TREATED_NAIVE_CD4_TCELL_DAY5_DN
Systematic name | M4635
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD25- T cells treated with IL4 [GeneID=3565] at day 5 versus untreated CD25- T cells at day 5.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_IL4_VS_CTRL_TREATED_NAIVE_CD4_TCELL_DAY7_UP
Systematic name | M4636
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD25- T cells treated with IL4 [GeneID=3565] at day 7 versus untreated CD25- T cells at day 7.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_IL4_VS_CTRL_TREATED_NAIVE_CD4_TCELL_DAY7_DN
Systematic name | M4638
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD25- T cells treated with IL4 [GeneID=3565] at day 7 versus untreated CD25- T cells at day 7.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_IL4_VS_CTRL_TREATED_NAIVE_CD4_TCELL_DAY10_UP
Systematic name | M4639
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD25- T cells treated with IL4 [GeneID=3565] at day 10 versus untreated CD25- T cells at day 10.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE24634_IL4_VS_CTRL_TREATED_NAIVE_CD4_TCELL_DAY10_DN
Systematic name | M4640
Organism | Homo sapiens
PMID | 21347372
Authors | Prots I,Skapenko A,Lipsky PE,Schulze-Koops H.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD25- T cells treated with IL4 [GeneID=3565] at day 10 versus untreated CD25- T cells at day 10.
Full description | CD25+ regulatory T cells develop in the thymus (nTregs), but may also be generated in the periphery upon stimulation of naive CD4 T cells under appropriate conditions (iTregs). The mechanisms that regulate the generation of peripheral iTregs are largely unknown. We used microarrays to gain insights into the molecular program of extrathymic Treg development.

Standard name | GSE25087_FETAL_VS_ADULT_TREG_UP
Systematic name | M4641
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of fetal regulatory T cell (Treg) versus adult regulatory T cell (Treg).
Full description | We compared differences in fetal and adult T cells by performing whole genome profiling on sort-purified T cells (naïve CD4+ and Treg cells) from human fetal specimens (18-22 gestational weeks) and adult specimens (age 25-40 years old). Fetal and Adult Naïve CD4+ T cells phenotype: CD3+CD4+CD45RA+CCR7+CD27+, Fetal and Adult CD4+CD25+ Treg phenotype: CD3+CD4+CD25bright

Standard name | GSE25087_FETAL_VS_ADULT_TREG_DN
Systematic name | M4643
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of fetal regulatory T cell (Treg) versus adult regulatory T cell (Treg).
Full description | We compared differences in fetal and adult T cells by performing whole genome profiling on sort-purified T cells (naïve CD4+ and Treg cells) from human fetal specimens (18-22 gestational weeks) and adult specimens (age 25-40 years old). Fetal and Adult Naïve CD4+ T cells phenotype: CD3+CD4+CD45RA+CCR7+CD27+, Fetal and Adult CD4+CD25+ Treg phenotype: CD3+CD4+CD25bright

Standard name | GSE25087_FETAL_VS_ADULT_TCONV_UP
Systematic name | M4645
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of fetal conventional T cells versus adult conventional T cells.
Full description | We compared differences in fetal and adult T cells by performing whole genome profiling on sort-purified T cells (naïve CD4+ and Treg cells) from human fetal specimens (18-22 gestational weeks) and adult specimens (age 25-40 years old). Fetal and Adult Naïve CD4+ T cells phenotype: CD3+CD4+CD45RA+CCR7+CD27+, Fetal and Adult CD4+CD25+ Treg phenotype: CD3+CD4+CD25bright

Standard name | GSE25087_FETAL_VS_ADULT_TCONV_DN
Systematic name | M4646
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of fetal conventional T cells versus adult conventional T cells.
Full description | We compared differences in fetal and adult T cells by performing whole genome profiling on sort-purified T cells (naïve CD4+ and Treg cells) from human fetal specimens (18-22 gestational weeks) and adult specimens (age 25-40 years old). Fetal and Adult Naïve CD4+ T cells phenotype: CD3+CD4+CD45RA+CCR7+CD27+, Fetal and Adult CD4+CD25+ Treg phenotype: CD3+CD4+CD25bright

Standard name | GSE25087_TREG_VS_TCONV_FETUS_UP
Systematic name | M4647
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of fetal regulatory T cell (Treg) versus fetal conventional T cells.
Full description | We compared differences in fetal and adult T cells by performing whole genome profiling on sort-purified T cells (naïve CD4+ and Treg cells) from human fetal specimens (18-22 gestational weeks) and adult specimens (age 25-40 years old). Fetal and Adult Naïve CD4+ T cells phenotype: CD3+CD4+CD45RA+CCR7+CD27+, Fetal and Adult CD4+CD25+ Treg phenotype: CD3+CD4+CD25bright

Standard name | GSE25087_TREG_VS_TCONV_FETUS_DN
Systematic name | M4649
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of fetal regulatory T cell (Treg) versus fetal conventional T cells.
Full description | We compared differences in fetal and adult T cells by performing whole genome profiling on sort-purified T cells (naïve CD4+ and Treg cells) from human fetal specimens (18-22 gestational weeks) and adult specimens (age 25-40 years old). Fetal and Adult Naïve CD4+ T cells phenotype: CD3+CD4+CD45RA+CCR7+CD27+, Fetal and Adult CD4+CD25+ Treg phenotype: CD3+CD4+CD25bright

Standard name | GSE25087_TREG_VS_TCONV_ADULT_UP
Systematic name | M4650
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of adult regulatory T cell (Treg) versus adult conventional T cells.
Full description | We compared differences in fetal and adult T cells by performing whole genome profiling on sort-purified T cells (naïve CD4+ and Treg cells) from human fetal specimens (18-22 gestational weeks) and adult specimens (age 25-40 years old). Fetal and Adult Naïve CD4+ T cells phenotype: CD3+CD4+CD45RA+CCR7+CD27+, Fetal and Adult CD4+CD25+ Treg phenotype: CD3+CD4+CD25bright

Standard name | GSE25087_TREG_VS_TCONV_ADULT_DN
Systematic name | M4652
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of adult regulatory T cell (Treg) versus adult conventional T cells.
Full description | We compared differences in fetal and adult T cells by performing whole genome profiling on sort-purified T cells (naïve CD4+ and Treg cells) from human fetal specimens (18-22 gestational weeks) and adult specimens (age 25-40 years old). Fetal and Adult Naïve CD4+ T cells phenotype: CD3+CD4+CD45RA+CCR7+CD27+, Fetal and Adult CD4+CD25+ Treg phenotype: CD3+CD4+CD25bright

Standard name | GSE26495_NAIVE_VS_PD1HIGH_CD8_TCELL_UP
Systematic name | M4654
Organism | Homo sapiens
PMID | 21383243
Authors | Duraiswamy J,Ibegbu CC,Masopust D,Miller JD,Araki K,Doho GH,Tata P,Gupta S,Zilliox MJ,Nakaya HI,Pulendran B,Haining WN,Freeman GJ,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus PD-1 high CD8 T cells.
Full description | T cell dysfunction is an important feature of many chronic viral infections. In particular, it was shown that PD-1 regulates T cell dysfunction during chronic LCMV infection in mice and PD-1 high cells exhibit an intense exhausted gene signature. These findings were extended to human chronic infections such as HIV, HCV and HBV. However, it is not known if PD-1 high cells of healthy humans have the traits of exhausted cells. In this study, we provide a comprehensive description of phenotype, function and gene expression profiles of PD-1 high versus PD-1 low CD8 T cells in the peripheral blood of healthy human adults as following: 1) The percentage of naive and memory CD8 T cells varied widely in the peripheral blood cells of healthy humans and PD-1 was expressed by the memory CD8 T cells. 2) PD-1 high CD8 T cells in healthy humans did not significantly correlated with the PD-1 high exhausted gene signature of HIV specific human CD8 T cells or chronic LCMV specific CD8 T cells from mice. 3) PD-1 expression did not directly affect the ability of CD8 T cells to secrete cytokines in healthy adults. 4) PD-1 was expressed by the effector memory (TEM) compared to ‘terminally differentiated effector’ (TEMRA) CD8 T cells. 5) Finally, an interesting inverse relationship between CD45RA and PD-1 expression was observed.

Standard name | GSE26495_NAIVE_VS_PD1HIGH_CD8_TCELL_DN
Systematic name | M4656
Organism | Homo sapiens
PMID | 21383243
Authors | Duraiswamy J,Ibegbu CC,Masopust D,Miller JD,Araki K,Doho GH,Tata P,Gupta S,Zilliox MJ,Nakaya HI,Pulendran B,Haining WN,Freeman GJ,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus PD-1 high CD8 T cells.
Full description | T cell dysfunction is an important feature of many chronic viral infections. In particular, it was shown that PD-1 regulates T cell dysfunction during chronic LCMV infection in mice and PD-1 high cells exhibit an intense exhausted gene signature. These findings were extended to human chronic infections such as HIV, HCV and HBV. However, it is not known if PD-1 high cells of healthy humans have the traits of exhausted cells. In this study, we provide a comprehensive description of phenotype, function and gene expression profiles of PD-1 high versus PD-1 low CD8 T cells in the peripheral blood of healthy human adults as following: 1) The percentage of naive and memory CD8 T cells varied widely in the peripheral blood cells of healthy humans and PD-1 was expressed by the memory CD8 T cells. 2) PD-1 high CD8 T cells in healthy humans did not significantly correlated with the PD-1 high exhausted gene signature of HIV specific human CD8 T cells or chronic LCMV specific CD8 T cells from mice. 3) PD-1 expression did not directly affect the ability of CD8 T cells to secrete cytokines in healthy adults. 4) PD-1 was expressed by the effector memory (TEM) compared to ‘terminally differentiated effector’ (TEMRA) CD8 T cells. 5) Finally, an interesting inverse relationship between CD45RA and PD-1 expression was observed.

Standard name | GSE26495_NAIVE_VS_PD1LOW_CD8_TCELL_UP
Systematic name | M4658
Organism | Homo sapiens
PMID | 21383243
Authors | Duraiswamy J,Ibegbu CC,Masopust D,Miller JD,Araki K,Doho GH,Tata P,Gupta S,Zilliox MJ,Nakaya HI,Pulendran B,Haining WN,Freeman GJ,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus PD-1 low CD8 T cells.
Full description | T cell dysfunction is an important feature of many chronic viral infections. In particular, it was shown that PD-1 regulates T cell dysfunction during chronic LCMV infection in mice and PD-1 high cells exhibit an intense exhausted gene signature. These findings were extended to human chronic infections such as HIV, HCV and HBV. However, it is not known if PD-1 high cells of healthy humans have the traits of exhausted cells. In this study, we provide a comprehensive description of phenotype, function and gene expression profiles of PD-1 high versus PD-1 low CD8 T cells in the peripheral blood of healthy human adults as following: 1) The percentage of naive and memory CD8 T cells varied widely in the peripheral blood cells of healthy humans and PD-1 was expressed by the memory CD8 T cells. 2) PD-1 high CD8 T cells in healthy humans did not significantly correlated with the PD-1 high exhausted gene signature of HIV specific human CD8 T cells or chronic LCMV specific CD8 T cells from mice. 3) PD-1 expression did not directly affect the ability of CD8 T cells to secrete cytokines in healthy adults. 4) PD-1 was expressed by the effector memory (TEM) compared to ‘terminally differentiated effector’ (TEMRA) CD8 T cells. 5) Finally, an interesting inverse relationship between CD45RA and PD-1 expression was observed.

Standard name | GSE26495_NAIVE_VS_PD1LOW_CD8_TCELL_DN
Systematic name | M4659
Organism | Homo sapiens
PMID | 21383243
Authors | Duraiswamy J,Ibegbu CC,Masopust D,Miller JD,Araki K,Doho GH,Tata P,Gupta S,Zilliox MJ,Nakaya HI,Pulendran B,Haining WN,Freeman GJ,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus PD-1 low CD8 T cells.
Full description | T cell dysfunction is an important feature of many chronic viral infections. In particular, it was shown that PD-1 regulates T cell dysfunction during chronic LCMV infection in mice and PD-1 high cells exhibit an intense exhausted gene signature. These findings were extended to human chronic infections such as HIV, HCV and HBV. However, it is not known if PD-1 high cells of healthy humans have the traits of exhausted cells. In this study, we provide a comprehensive description of phenotype, function and gene expression profiles of PD-1 high versus PD-1 low CD8 T cells in the peripheral blood of healthy human adults as following: 1) The percentage of naive and memory CD8 T cells varied widely in the peripheral blood cells of healthy humans and PD-1 was expressed by the memory CD8 T cells. 2) PD-1 high CD8 T cells in healthy humans did not significantly correlated with the PD-1 high exhausted gene signature of HIV specific human CD8 T cells or chronic LCMV specific CD8 T cells from mice. 3) PD-1 expression did not directly affect the ability of CD8 T cells to secrete cytokines in healthy adults. 4) PD-1 was expressed by the effector memory (TEM) compared to ‘terminally differentiated effector’ (TEMRA) CD8 T cells. 5) Finally, an interesting inverse relationship between CD45RA and PD-1 expression was observed.

Standard name | GSE26495_PD1HIGH_VS_PD1LOW_CD8_TCELL_UP
Systematic name | M4660
Organism | Homo sapiens
PMID | 21383243
Authors | Duraiswamy J,Ibegbu CC,Masopust D,Miller JD,Araki K,Doho GH,Tata P,Gupta S,Zilliox MJ,Nakaya HI,Pulendran B,Haining WN,Freeman GJ,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of PD-1 high CD8 T cells versus PD-1 low CD8 T cells.
Full description | T cell dysfunction is an important feature of many chronic viral infections. In particular, it was shown that PD-1 regulates T cell dysfunction during chronic LCMV infection in mice and PD-1 high cells exhibit an intense exhausted gene signature. These findings were extended to human chronic infections such as HIV, HCV and HBV. However, it is not known if PD-1 high cells of healthy humans have the traits of exhausted cells. In this study, we provide a comprehensive description of phenotype, function and gene expression profiles of PD-1 high versus PD-1 low CD8 T cells in the peripheral blood of healthy human adults as following: 1) The percentage of naive and memory CD8 T cells varied widely in the peripheral blood cells of healthy humans and PD-1 was expressed by the memory CD8 T cells. 2) PD-1 high CD8 T cells in healthy humans did not significantly correlated with the PD-1 high exhausted gene signature of HIV specific human CD8 T cells or chronic LCMV specific CD8 T cells from mice. 3) PD-1 expression did not directly affect the ability of CD8 T cells to secrete cytokines in healthy adults. 4) PD-1 was expressed by the effector memory (TEM) compared to ‘terminally differentiated effector’ (TEMRA) CD8 T cells. 5) Finally, an interesting inverse relationship between CD45RA and PD-1 expression was observed.

Standard name | GSE26495_PD1HIGH_VS_PD1LOW_CD8_TCELL_DN
Systematic name | M4662
Organism | Homo sapiens
PMID | 21383243
Authors | Duraiswamy J,Ibegbu CC,Masopust D,Miller JD,Araki K,Doho GH,Tata P,Gupta S,Zilliox MJ,Nakaya HI,Pulendran B,Haining WN,Freeman GJ,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of PD-1 high CD8 T cells versus PD-1 low CD8 T cells.
Full description | T cell dysfunction is an important feature of many chronic viral infections. In particular, it was shown that PD-1 regulates T cell dysfunction during chronic LCMV infection in mice and PD-1 high cells exhibit an intense exhausted gene signature. These findings were extended to human chronic infections such as HIV, HCV and HBV. However, it is not known if PD-1 high cells of healthy humans have the traits of exhausted cells. In this study, we provide a comprehensive description of phenotype, function and gene expression profiles of PD-1 high versus PD-1 low CD8 T cells in the peripheral blood of healthy human adults as following: 1) The percentage of naive and memory CD8 T cells varied widely in the peripheral blood cells of healthy humans and PD-1 was expressed by the memory CD8 T cells. 2) PD-1 high CD8 T cells in healthy humans did not significantly correlated with the PD-1 high exhausted gene signature of HIV specific human CD8 T cells or chronic LCMV specific CD8 T cells from mice. 3) PD-1 expression did not directly affect the ability of CD8 T cells to secrete cytokines in healthy adults. 4) PD-1 was expressed by the effector memory (TEM) compared to ‘terminally differentiated effector’ (TEMRA) CD8 T cells. 5) Finally, an interesting inverse relationship between CD45RA and PD-1 expression was observed.

Standard name | GSE26669_CTRL_VS_COSTIM_BLOCK_MLR_CD4_TCELL_UP
Systematic name | M4663
Organism | Mus musculus
PMID | 21362570
Authors | Pearl JI,Lee AS,Leveson-Gower DB,Sun N,Ghosh Z,Lan F,Ransohoff J,Negrin RS,Davis MM,Wu JC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells versus CD4 [GeneID=920] T cells treated with leukocyte costimulatory blockade antibodies.
Full description | To elucidate the gene expression “footprint” of antigenically challenged T-cells which had been treated with anti-LFA-1, CTLA4Ig, anti-CD40-ligand antibodies, we performed microarray gene expression analysis comparing the expression profile of costimulatory blockade treated and untreated responder T-cells.

Standard name | GSE26669_CTRL_VS_COSTIM_BLOCK_MLR_CD4_TCELL_DN
Systematic name | M4664
Organism | Mus musculus
PMID | 21362570
Authors | Pearl JI,Lee AS,Leveson-Gower DB,Sun N,Ghosh Z,Lan F,Ransohoff J,Negrin RS,Davis MM,Wu JC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells versus CD4 [GeneID=920] T cells treated with leukocyte costimulatory blockade antibodies.
Full description | To elucidate the gene expression “footprint” of antigenically challenged T-cells which had been treated with anti-LFA-1, CTLA4Ig, anti-CD40-ligand antibodies, we performed microarray gene expression analysis comparing the expression profile of costimulatory blockade treated and untreated responder T-cells.

Standard name | GSE26669_CTRL_VS_COSTIM_BLOCK_MLR_CD8_TCELL_UP
Systematic name | M4666
Organism | Mus musculus
PMID | 21362570
Authors | Pearl JI,Lee AS,Leveson-Gower DB,Sun N,Ghosh Z,Lan F,Ransohoff J,Negrin RS,Davis MM,Wu JC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD8 T cells versus CD8 T cells treated with leukocyte costimulatory blockade antibodies.
Full description | To elucidate the gene expression “footprint” of antigenically challenged T-cells which had been treated with anti-LFA-1, CTLA4Ig, anti-CD40-ligand antibodies, we performed microarray gene expression analysis comparing the expression profile of costimulatory blockade treated and untreated responder T-cells.

Standard name | GSE26669_CTRL_VS_COSTIM_BLOCK_MLR_CD8_TCELL_DN
Systematic name | M4667
Organism | Mus musculus
PMID | 21362570
Authors | Pearl JI,Lee AS,Leveson-Gower DB,Sun N,Ghosh Z,Lan F,Ransohoff J,Negrin RS,Davis MM,Wu JC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD8 T cells versus CD8 T cells treated with leukocyte costimulatory blockade antibodies.
Full description | To elucidate the gene expression “footprint” of antigenically challenged T-cells which had been treated with anti-LFA-1, CTLA4Ig, anti-CD40-ligand antibodies, we performed microarray gene expression analysis comparing the expression profile of costimulatory blockade treated and untreated responder T-cells.

Standard name | GSE26669_CD4_VS_CD8_TCELL_IN_MLR_UP
Systematic name | M4668
Organism | Mus musculus
PMID | 21362570
Authors | Pearl JI,Lee AS,Leveson-Gower DB,Sun N,Ghosh Z,Lan F,Ransohoff J,Negrin RS,Davis MM,Wu JC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells versus the untreated CD8 T cells.
Full description | To elucidate the gene expression “footprint” of antigenically challenged T-cells which had been treated with anti-LFA-1, CTLA4Ig, anti-CD40-ligand antibodies, we performed microarray gene expression analysis comparing the expression profile of costimulatory blockade treated and untreated responder T-cells.

Standard name | GSE26669_CD4_VS_CD8_TCELL_IN_MLR_DN
Systematic name | M4670
Organism | Mus musculus
PMID | 21362570
Authors | Pearl JI,Lee AS,Leveson-Gower DB,Sun N,Ghosh Z,Lan F,Ransohoff J,Negrin RS,Davis MM,Wu JC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells versus the untreated CD8 T cells.
Full description | To elucidate the gene expression “footprint” of antigenically challenged T-cells which had been treated with anti-LFA-1, CTLA4Ig, anti-CD40-ligand antibodies, we performed microarray gene expression analysis comparing the expression profile of costimulatory blockade treated and untreated responder T-cells.

Standard name | GSE26669_CD4_VS_CD8_TCELL_IN_MLR_COSTIM_BLOCK_UP
Systematic name | M4672
Organism | Mus musculus
PMID | 21362570
Authors | Pearl JI,Lee AS,Leveson-Gower DB,Sun N,Ghosh Z,Lan F,Ransohoff J,Negrin RS,Davis MM,Wu JC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells versus CD8 T cells treated with leukocyte costimulatory blockade antibodies.
Full description | To elucidate the gene expression “footprint” of antigenically challenged T-cells which had been treated with anti-LFA-1, CTLA4Ig, anti-CD40-ligand antibodies, we performed microarray gene expression analysis comparing the expression profile of costimulatory blockade treated and untreated responder T-cells.

Standard name | GSE26669_CD4_VS_CD8_TCELL_IN_MLR_COSTIM_BLOCK_DN
Systematic name | M4673
Organism | Mus musculus
PMID | 21362570
Authors | Pearl JI,Lee AS,Leveson-Gower DB,Sun N,Ghosh Z,Lan F,Ransohoff J,Negrin RS,Davis MM,Wu JC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells versus CD8 T cells treated with leukocyte costimulatory blockade antibodies.
Full description | To elucidate the gene expression “footprint” of antigenically challenged T-cells which had been treated with anti-LFA-1, CTLA4Ig, anti-CD40-ligand antibodies, we performed microarray gene expression analysis comparing the expression profile of costimulatory blockade treated and untreated responder T-cells.

Standard name | GSE26928_NAIVE_VS_EFF_MEMORY_CD4_TCELL_UP
Systematic name | M4674
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus CD4 [GeneID=920] effector memory T cells.
Full description |

Standard name | GSE26928_NAIVE_VS_EFF_MEMORY_CD4_TCELL_DN
Systematic name | M4676
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus CD4 [GeneID=920] effector memory T cells.
Full description |

Standard name | GSE26928_NAIVE_VS_CENT_MEMORY_CD4_TCELL_UP
Systematic name | M4677
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus CD4 [GeneID=920] central memory T cells.
Full description |

Standard name | GSE26928_NAIVE_VS_CENT_MEMORY_CD4_TCELL_DN
Systematic name | M4678
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus CD4 [GeneID=920] central memory T cells.
Full description |

Standard name | GSE26928_NAIVE_VS_CXCR5_POS_CD4_TCELL_UP
Systematic name | M4682
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD4 [GeneID=920] T cells versus CD4 [GeneID=920] CXCR5+ [GeneID=643] T cells.
Full description |

Standard name | GSE26928_NAIVE_VS_CXCR5_POS_CD4_TCELL_DN
Systematic name | M4683
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD4 [GeneID=920] T cells versus CD4 [GeneID=920] CXCR5+ [GeneID=643] T cells.
Full description |

Standard name | GSE26928_EFF_MEM_VS_CENTR_MEM_CD4_TCELL_UP
Systematic name | M4684
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] effector memory T cells versus CD4 [GeneID=920] central memory T cells.
Full description |

Standard name | GSE26928_EFF_MEM_VS_CENTR_MEM_CD4_TCELL_DN
Systematic name | M4685
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] effector memory T cells versus CD4 [GeneID=920] central memory T cells.
Full description |

Standard name | GSE26928_EFF_MEMORY_VS_CXCR5_POS_CD4_TCELL_UP
Systematic name | M4686
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] effector memory T cells versus CD4 [GeneID=920] CXCR5+ [GeneID=643] T cells.
Full description |

Standard name | GSE26928_EFF_MEMORY_VS_CXCR5_POS_CD4_TCELL_DN
Systematic name | M4687
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] effector memory T cells versus CD4 [GeneID=920] CXCR5+ [GeneID=643] T cells.
Full description |

Standard name | GSE26928_CENTR_MEMORY_VS_CXCR5_POS_CD4_TCELL_UP
Systematic name | M4688
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] central memory T cells versus CD4 [GeneID=920] CXCR5+ [GeneID=643] T cells.
Full description |

Standard name | GSE26928_CENTR_MEMORY_VS_CXCR5_POS_CD4_TCELL_DN
Systematic name | M4689
Organism | Homo sapiens
PMID | 21471443
Authors | Chevalier N,Jarrossay D,Ho E,Avery DT,Ma CS,Yu D,Sallusto F,Tangye SG,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] central memory T cells versus CD4 [GeneID=920] CXCR5+ [GeneID=643] T cells.
Full description |

Standard name | GSE2706_UNSTIM_VS_2H_R848_DC_UP
Systematic name | M4691
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with R848 for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_2H_R848_DC_DN
Systematic name | M4692
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with R848 for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_8H_R848_DC_UP
Systematic name | M4693
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with R848 for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_8H_R848_DC_DN
Systematic name | M4694
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with R848 for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_2H_LPS_DC_UP
Systematic name | M4695
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with LPS (TLR4 agonist) for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_2H_LPS_DC_DN
Systematic name | M4696
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with LPS (TLR4 agonist) for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_8H_LPS_DC_UP
Systematic name | M4698
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with LPS (TLR4 agonist) for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_8H_LPS_DC_DN
Systematic name | M4701
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with LPS (TLR4 agonist) for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_2H_LPS_AND_R848_DC_UP
Systematic name | M4702
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_2H_LPS_AND_R848_DC_DN
Systematic name | M4703
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_8H_LPS_AND_R848_DC_UP
Systematic name | M4704
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_UNSTIM_VS_8H_LPS_AND_R848_DC_DN
Systematic name | M4705
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of unstimulated dendritic cells (DC) at 0 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_R848_VS_LPS_2H_STIM_DC_UP
Systematic name | M4706
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with R848 at 2 h versus DCs stimulated with LPS (TLR4 agonist) for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_R848_VS_LPS_2H_STIM_DC_DN
Systematic name | M4708
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with R848 at 2 h versus DCs stimulated with LPS (TLR4 agonist) for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_R848_VS_LPS_8H_STIM_DC_UP
Systematic name | M4712
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with R848 at 8 h versus DCs stimulated with LPS (TLR4 agonist) for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_R848_VS_LPS_8H_STIM_DC_DN
Systematic name | M4713
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with R848 at 8 h versus DCs stimulated with LPS (TLR4 agonist) for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_R848_VS_R848_AND_LPS_2H_STIM_DC_UP
Systematic name | M4714
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with R848 at 2 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_R848_VS_R848_AND_LPS_2H_STIM_DC_DN
Systematic name | M4715
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with R848 at 2 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_R848_VS_R848_AND_LPS_8H_STIM_DC_UP
Systematic name | M4719
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with R848 at 8 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_R848_VS_R848_AND_LPS_8H_STIM_DC_DN
Systematic name | M4720
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with R848 at 8 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_LPS_VS_R848_AND_LPS_2H_STIM_DC_UP
Systematic name | M4722
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_LPS_VS_R848_AND_LPS_2H_STIM_DC_DN
Systematic name | M4724
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 2 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_LPS_VS_R848_AND_LPS_8H_STIM_DC_UP
Systematic name | M4727
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 8 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_LPS_VS_R848_AND_LPS_8H_STIM_DC_DN
Systematic name | M4728
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 8 h versus DCs stimulated with LPS (TLR4 agonist) and R848 for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_2H_VS_8H_R848_STIM_DC_UP
Systematic name | M4729
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with R848 at 2 h versus DCs stimulatd with R848 for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_2H_VS_8H_R848_STIM_DC_DN
Systematic name | M4730
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with R848 at 2 h versus DCs stimulatd with R848 for 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_2H_VS_8H_LPS_STIM_DC_UP
Systematic name | M4731
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DCs stimulated with LPS (TLR4 agonist) at 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_2H_VS_8H_LPS_STIM_DC_DN
Systematic name | M4733
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 2 h versus DCs stimulated with LPS (TLR4 agonist) at 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_2H_VS_8H_R848_AND_LPS_STIM_DC_UP
Systematic name | M4736
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with R848 at 2 h versus DCs stimulated with LPS (TLR4 agonist) at 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE2706_2H_VS_8H_R848_AND_LPS_STIM_DC_DN
Systematic name | M4738
Organism | Homo sapiens
PMID | 15995707
Authors | Napolitani G,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with R848 at 2 h versus DCs stimulated with LPS (TLR4 agonist) at 8 h.
Full description | Toll like receptors (TLRs) sense microbial products and initiate adaptive immune responses by activating dendritic cells (DCs). Since pathogens may contain several agonists we asked whether different TLRs may synergize in DC activation. We report that in human and mouse DC TLR3 or TLR4 potently synergize with TLR7, TLR8 or TLR9 in the induction of selected cytokine genes. Upon synergistic stimulation, IL-12, IL-23 and Delta-4 are induced at levels 50-100 fold higher than those induced by optimal concentrations of single agonists, leading to enhanced and sustained TH1 polarizing capacity. Using microarray analysis we show that only 1.5% of the transcripts induced by single TLR agonists are synergistically regulated by combinations of TLR4 and TLR8 agonists. These results identify a combinatorial code by which DCs discriminate pathogens and provide (suggest) a rationale to design adjuvants for TH1 responses. Series_overall_design: 3 untreated, 3 treated with LPS at 2h, 3 treated with LPS at 8h, 3 treated with R848 at 2h, 3 treated with R848 at 8h, 3 treated with LPS + R848 at 2h, 3 treated with LPS + R848 at 8h

Standard name | GSE27786_LSK_VS_LIN_NEG_CELL_UP
Systematic name | M4739
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of LSK versus lineage negative cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_LIN_NEG_CELL_DN
Systematic name | M4742
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of LSK versus lineage negative cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_BCELL_UP
Systematic name | M4743
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of LSK versus B cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_BCELL_DN
Systematic name | M4744
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of LSK versus B cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_CD4_TCELL_UP
Systematic name | M4745
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of LSK versus CD4 [GeneID=920] T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_CD4_TCELL_DN
Systematic name | M4747
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of LSK versus CD4 [GeneID=920] T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_CD8_TCELL_UP
Systematic name | M4749
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulatd in comparison of LSK versus CD8 T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_CD8_TCELL_DN
Systematic name | M4750
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulatd in comparison of LSK versus CD8 T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_NKCELL_UP
Systematic name | M4751
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of LSK versus NK cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_NKCELL_DN
Systematic name | M4753
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of LSK versus NK cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_NKTCELL_UP
Systematic name | M4754
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of LSK versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_NKTCELL_DN
Systematic name | M4756
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of LSK versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_ERYTHROBLAST_UP
Systematic name | M4757
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of LSK versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_ERYTHROBLAST_DN
Systematic name | M4759
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of LSK versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_NEUTROPHIL_UP
Systematic name | M4760
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of LSK versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_NEUTROPHIL_DN
Systematic name | M4761
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of LSK versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_MONO_MAC_UP
Systematic name | M4763
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of LSK versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LSK_VS_MONO_MAC_DN
Systematic name | M4765
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of LSK versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_BCELL_UP
Systematic name | M4766
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lineage negative versus B cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_BCELL_DN
Systematic name | M4768
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lineage negative versus B cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_CD4_TCELL_UP
Systematic name | M4769
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lineage negative versus CD4 [GeneID=920] T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_CD4_TCELL_DN
Systematic name | M4773
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lineage negative versus CD4 [GeneID=920] T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_CD8_TCELL_UP
Systematic name | M4775
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lineage negative versus CD8 T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_CD8_TCELL_DN
Systematic name | M4777
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lineage negative versus CD8 T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_NKCELL_UP
Systematic name | M4783
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lineage negative versus NK cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_NKCELL_DN
Systematic name | M4784
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lineage negative versus NK cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_NKTCELL_UP
Systematic name | M4787
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lineage negative versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_NKTCELL_DN
Systematic name | M4788
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lineage negative versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_ERYTHROBLAST_UP
Systematic name | M4790
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lineage negative versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_ERYTHROBLAST_DN
Systematic name | M4793
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lineage negative versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_NEUTROPHIL_UP
Systematic name | M4794
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lineage negative versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_NEUTROPHIL_DN
Systematic name | M4795
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lineage negative versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_MONO_MAC_UP
Systematic name | M4796
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lineage negative versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_LIN_NEG_VS_MONO_MAC_DN
Systematic name | M4798
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lineage negative versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_CD4_TCELL_UP
Systematic name | M4799
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus CD4 [GeneID=920] T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_CD4_TCELL_DN
Systematic name | M4800
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus CD4 [GeneID=920] T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_CD8_TCELL_UP
Systematic name | M4801
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus CD8 T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_CD8_TCELL_DN
Systematic name | M4802
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus CD8 T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_NKCELL_UP
Systematic name | M4805
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus NK cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_NKCELL_DN
Systematic name | M4806
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus NK cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_NKTCELL_UP
Systematic name | M4808
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_NKTCELL_DN
Systematic name | M4809
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_ERYTHROBLAST_UP
Systematic name | M4810
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_ERYTHROBLAST_DN
Systematic name | M4811
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_NEUTROPHIL_UP
Systematic name | M4813
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_NEUTROPHIL_DN
Systematic name | M4816
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_MONO_MAC_UP
Systematic name | M4817
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_BCELL_VS_MONO_MAC_DN
Systematic name | M4818
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_VS_CD8_TCELL_UP
Systematic name | M4819
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells versus CD8 T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_VS_CD8_TCELL_DN
Systematic name | M4821
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells versus CD8 T cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_TCELL_VS_NKCELL_UP
Systematic name | M4822
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells versus NK cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_TCELL_VS_NKCELL_DN
Systematic name | M4823
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells versus NK cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_TCELL_VS_NKTCELL_UP
Systematic name | M4824
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_TCELL_VS_NKTCELL_DN
Systematic name | M4825
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_TCELL_VS_ERYTHTROBLAST_UP
Systematic name | M4827
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_TCELL_VS_ERYTHTROBLAST_DN
Systematic name | M4828
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_TCELL_VS_NEUTROPHIL_UP
Systematic name | M4830
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_TCELL_VS_NEUTROPHIL_DN
Systematic name | M4832
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_TCELL_VS_MONO_MAC_UP
Systematic name | M4833
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD4_TCELL_VS_MONO_MAC_DN
Systematic name | M4834
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD8_TCELL_VS_NKCELL_UP
Systematic name | M4836
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells versus NK cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD8_TCELL_VS_NKCELL_DN
Systematic name | M4838
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells versus NK cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD8_TCELL_VS_NKTCELL_UP
Systematic name | M4839
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD8_TCELL_VS_NKTCELL_DN
Systematic name | M4840
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD8_TCELL_VS_ERYTHROBLAST_UP
Systematic name | M4841
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD8_TCELL_VS_ERYTHROBLAST_DN
Systematic name | M4845
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD8_TCELL_VS_NEUTROPHIL_UP
Systematic name | M4846
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD8_TCELL_VS_NEUTROPHIL_DN
Systematic name | M4847
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD8_TCELL_VS_MONO_MAC_UP
Systematic name | M4848
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 T cells versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_CD8_TCELL_VS_MONO_MAC_DN
Systematic name | M4849
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 T cells versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKCELL_VS_NKTCELL_UP
Systematic name | M4851
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NK cells versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKCELL_VS_NKTCELL_DN
Systematic name | M4852
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NK cells versus NKT cells.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKCELL_VS_ERYTHROBLAST_UP
Systematic name | M4853
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NK cells versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKCELL_VS_ERYTHROBLAST_DN
Systematic name | M4854
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NK cells versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKCELL_VS_NEUTROPHIL_UP
Systematic name | M4858
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NK cells versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKCELL_VS_NEUTROPHIL_DN
Systematic name | M4859
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NK cells versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKCELL_VS_MONO_MAC_UP
Systematic name | M4860
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NK cells versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKCELL_VS_MONO_MAC_DN
Systematic name | M4863
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NK cells versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKTCELL_VS_ERYTHROBLAST_UP
Systematic name | M4865
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NKT cells versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKTCELL_VS_ERYTHROBLAST_DN
Systematic name | M4867
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NKT cells versus erythroblasts.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKTCELL_VS_NEUTROPHIL_UP
Systematic name | M4868
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NKT cells versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKTCELL_VS_NEUTROPHIL_DN
Systematic name | M4869
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NKT cells versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKTCELL_VS_MONO_MAC_UP
Systematic name | M4870
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NKT cells versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NKTCELL_VS_MONO_MAC_DN
Systematic name | M4871
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NKT cells versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_ERYTHROBLAST_VS_NEUTROPHIL_UP
Systematic name | M4875
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of erythroblasts versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_ERYTHROBLAST_VS_NEUTROPHIL_DN
Systematic name | M4876
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of erythroblasts versus neutrophils.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_ERYTHROBLAST_VS_MONO_MAC_UP
Systematic name | M4877
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of erythroblasts versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_ERYTHROBLAST_VS_MONO_MAC_DN
Systematic name | M4878
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of erythroblasts versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NEUTROPHIL_VS_MONO_MAC_UP
Systematic name | M4880
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of neutrophils versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE27786_NEUTROPHIL_VS_MONO_MAC_DN
Systematic name | M4883
Organism | Mus musculus
PMID | 21540074
Authors | Konuma T,Nakamura S,Miyagi S,Negishi M,Chiba T,Oguro H,Yuan J,Mochizuki-Kashio M,Ichikawa H,Miyoshi H,Vidal M,Iwama A.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of neutrophils versus monocyte macrophages.
Full description | Each fraction of mouse hematopoietic cells was purified by cell sorting from bone marrow of 8-week-old C57BL/6 mice, and its gene expression was analyzed.

Standard name | GSE28237_FOLLICULAR_VS_EARLY_GC_BCELL_UP
Systematic name | M4884
Organism | Mus musculus
PMID | 20518031
Authors | Wilke G,Steinhauser G,Grün J,Berek C
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive follicular B cells versus early germinal center (GC) B cells.
Full description | Upon immunization with a T cell dependent antigen naive follicular B cells (Fo) are activated and a germinal center reaction is induced. Within the next 2 weeks large germinal centers develop where the process of affinity maturation takes place. To analyze the gene expression profile of resting and activated B cells, follicular B cells (Fo), B cells from early (GC1) and late germinal centers (GC2) were isolated and their gene expression profile compared.

Standard name | GSE28237_FOLLICULAR_VS_EARLY_GC_BCELL_DN
Systematic name | M4885
Organism | Mus musculus
PMID | 20518031
Authors | Wilke G,Steinhauser G,Grün J,Berek C
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive follicular B cells versus early germinal center (GC) B cells.
Full description | Upon immunization with a T cell dependent antigen naive follicular B cells (Fo) are activated and a germinal center reaction is induced. Within the next 2 weeks large germinal centers develop where the process of affinity maturation takes place. To analyze the gene expression profile of resting and activated B cells, follicular B cells (Fo), B cells from early (GC1) and late germinal centers (GC2) were isolated and their gene expression profile compared.

Standard name | GSE28237_FOLLICULAR_VS_LATE_GC_BCELL_UP
Systematic name | M4886
Organism | Mus musculus
PMID | 20518031
Authors | Wilke G,Steinhauser G,Grün J,Berek C
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of follicular B cells versus late germinal center (GC) B cells.
Full description | Upon immunization with a T cell dependent antigen naive follicular B cells (Fo) are activated and a germinal center reaction is induced. Within the next 2 weeks large germinal centers develop where the process of affinity maturation takes place. To analyze the gene expression profile of resting and activated B cells, follicular B cells (Fo), B cells from early (GC1) and late germinal centers (GC2) were isolated and their gene expression profile compared.

Standard name | GSE28237_FOLLICULAR_VS_LATE_GC_BCELL_DN
Systematic name | M4889
Organism | Mus musculus
PMID | 20518031
Authors | Wilke G,Steinhauser G,Grün J,Berek C
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of follicular B cells versus late germinal center (GC) B cells.
Full description | Upon immunization with a T cell dependent antigen naive follicular B cells (Fo) are activated and a germinal center reaction is induced. Within the next 2 weeks large germinal centers develop where the process of affinity maturation takes place. To analyze the gene expression profile of resting and activated B cells, follicular B cells (Fo), B cells from early (GC1) and late germinal centers (GC2) were isolated and their gene expression profile compared.

Standard name | GSE28237_EARLY_VS_LATE_GC_BCELL_UP
Systematic name | M4893
Organism | Mus musculus
PMID | 20518031
Authors | Wilke G,Steinhauser G,Grün J,Berek C
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of early germinal center (GC) B cells versus late GC B cells.
Full description | Upon immunization with a T cell dependent antigen naive follicular B cells (Fo) are activated and a germinal center reaction is induced. Within the next 2 weeks large germinal centers develop where the process of affinity maturation takes place. To analyze the gene expression profile of resting and activated B cells, follicular B cells (Fo), B cells from early (GC1) and late germinal centers (GC2) were isolated and their gene expression profile compared.

Standard name | GSE28237_EARLY_VS_LATE_GC_BCELL_DN
Systematic name | M4894
Organism | Mus musculus
PMID | 20518031
Authors | Wilke G,Steinhauser G,Grün J,Berek C
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of early germinal center (GC) B cells versus late GC B cells.
Full description | Upon immunization with a T cell dependent antigen naive follicular B cells (Fo) are activated and a germinal center reaction is induced. Within the next 2 weeks large germinal centers develop where the process of affinity maturation takes place. To analyze the gene expression profile of resting and activated B cells, follicular B cells (Fo), B cells from early (GC1) and late germinal centers (GC2) were isolated and their gene expression profile compared.

Standard name | GSE2826_WT_VS_XID_BCELL_UP
Systematic name | M4895
Organism | Mus musculus
PMID | 15214046
Authors | Lindvall JM,Blomberg KE,Berglöf A,Yang Q,Smith CI,Islam TC
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of primary splenic B cells from wild type mice versus those from Xid mice.
Full description | Bruton's tyrosine kinase (Btk) is important for B lymphocyte development. To identify genes that are differentially expressed in primary B cells lacking functional Btk, splenocytes from X-linked immunodeficiency (Xid), Btk knockout (KO) and immunocompetent CBA mice, were used in microarrays containing more than 12,000 genes and expressed sequence tags (ESTs). We found 4515 transcripts expressed in duplicate experiments in all three strains. Out of these, 38 were differentially expressed genes (21 up-regulated &gt;2 fold and 17 down-regulated &lt;-2 fold) between CBA and Btk defective mice. Ten out of these genes were selected and quantitative Real-Time PCR was conducted for validation and further investigation. Real-Time experiments correlated nicely with the microarray data. No definitive phenotypic difference has previously been reported between Xid and Btk KO mice. We found 7 genes, whose expression differed (&gt;2 fold) between the two strains. Moreover, when the 38 genes, which differed between immunocompetent CBA and Btk defective mice were ranked according to fold-increase, the levels in Btk KO mice were significantly more altered. This suggests that the defect in Btk KO mice is more severe and demonstrates that the mutant Btk protein in Xid mice does not generally function as dominant negative form.

Standard name | GSE2826_WT_VS_XID_BCELL_DN
Systematic name | M4897
Organism | Mus musculus
PMID | 15214046
Authors | Lindvall JM,Blomberg KE,Berglöf A,Yang Q,Smith CI,Islam TC
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of primary splenic B cells from wild type mice versus those from Xid mice.
Full description | Bruton's tyrosine kinase (Btk) is important for B lymphocyte development. To identify genes that are differentially expressed in primary B cells lacking functional Btk, splenocytes from X-linked immunodeficiency (Xid), Btk knockout (KO) and immunocompetent CBA mice, were used in microarrays containing more than 12,000 genes and expressed sequence tags (ESTs). We found 4515 transcripts expressed in duplicate experiments in all three strains. Out of these, 38 were differentially expressed genes (21 up-regulated &gt;2 fold and 17 down-regulated &lt;-2 fold) between CBA and Btk defective mice. Ten out of these genes were selected and quantitative Real-Time PCR was conducted for validation and further investigation. Real-Time experiments correlated nicely with the microarray data. No definitive phenotypic difference has previously been reported between Xid and Btk KO mice. We found 7 genes, whose expression differed (&gt;2 fold) between the two strains. Moreover, when the 38 genes, which differed between immunocompetent CBA and Btk defective mice were ranked according to fold-increase, the levels in Btk KO mice were significantly more altered. This suggests that the defect in Btk KO mice is more severe and demonstrates that the mutant Btk protein in Xid mice does not generally function as dominant negative form.

Standard name | GSE2826_WT_VS_BTK_KO_BCELL_UP
Systematic name | M4898
Organism | Mus musculus
PMID | 15214046
Authors | Lindvall JM,Blomberg KE,Berglöf A,Yang Q,Smith CI,Islam TC
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of primary splenic B cells from wild type mice versus those from BTK [GeneID=695] knockout mice.
Full description | Bruton's tyrosine kinase (Btk) is important for B lymphocyte development. To identify genes that are differentially expressed in primary B cells lacking functional Btk, splenocytes from X-linked immunodeficiency (Xid), Btk knockout (KO) and immunocompetent CBA mice, were used in microarrays containing more than 12,000 genes and expressed sequence tags (ESTs). We found 4515 transcripts expressed in duplicate experiments in all three strains. Out of these, 38 were differentially expressed genes (21 up-regulated &gt;2 fold and 17 down-regulated &lt;-2 fold) between CBA and Btk defective mice. Ten out of these genes were selected and quantitative Real-Time PCR was conducted for validation and further investigation. Real-Time experiments correlated nicely with the microarray data. No definitive phenotypic difference has previously been reported between Xid and Btk KO mice. We found 7 genes, whose expression differed (&gt;2 fold) between the two strains. Moreover, when the 38 genes, which differed between immunocompetent CBA and Btk defective mice were ranked according to fold-increase, the levels in Btk KO mice were significantly more altered. This suggests that the defect in Btk KO mice is more severe and demonstrates that the mutant Btk protein in Xid mice does not generally function as dominant negative form.

Standard name | GSE2826_WT_VS_BTK_KO_BCELL_DN
Systematic name | M4899
Organism | Mus musculus
PMID | 15214046
Authors | Lindvall JM,Blomberg KE,Berglöf A,Yang Q,Smith CI,Islam TC
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of primary splenic B cells from wild type mice versus those from BTK [GeneID=695] knockout mice.
Full description | Bruton's tyrosine kinase (Btk) is important for B lymphocyte development. To identify genes that are differentially expressed in primary B cells lacking functional Btk, splenocytes from X-linked immunodeficiency (Xid), Btk knockout (KO) and immunocompetent CBA mice, were used in microarrays containing more than 12,000 genes and expressed sequence tags (ESTs). We found 4515 transcripts expressed in duplicate experiments in all three strains. Out of these, 38 were differentially expressed genes (21 up-regulated &gt;2 fold and 17 down-regulated &lt;-2 fold) between CBA and Btk defective mice. Ten out of these genes were selected and quantitative Real-Time PCR was conducted for validation and further investigation. Real-Time experiments correlated nicely with the microarray data. No definitive phenotypic difference has previously been reported between Xid and Btk KO mice. We found 7 genes, whose expression differed (&gt;2 fold) between the two strains. Moreover, when the 38 genes, which differed between immunocompetent CBA and Btk defective mice were ranked according to fold-increase, the levels in Btk KO mice were significantly more altered. This suggests that the defect in Btk KO mice is more severe and demonstrates that the mutant Btk protein in Xid mice does not generally function as dominant negative form.

Standard name | GSE2826_XID_VS_BTK_KO_BCELL_UP
Systematic name | M4900
Organism | Mus musculus
PMID | 15214046
Authors | Lindvall JM,Blomberg KE,Berglöf A,Yang Q,Smith CI,Islam TC
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of primary splenic B cells from Xid mice versus those from BTK [GeneID=695] knockout mice.
Full description | Bruton's tyrosine kinase (Btk) is important for B lymphocyte development. To identify genes that are differentially expressed in primary B cells lacking functional Btk, splenocytes from X-linked immunodeficiency (Xid), Btk knockout (KO) and immunocompetent CBA mice, were used in microarrays containing more than 12,000 genes and expressed sequence tags (ESTs). We found 4515 transcripts expressed in duplicate experiments in all three strains. Out of these, 38 were differentially expressed genes (21 up-regulated &gt;2 fold and 17 down-regulated &lt;-2 fold) between CBA and Btk defective mice. Ten out of these genes were selected and quantitative Real-Time PCR was conducted for validation and further investigation. Real-Time experiments correlated nicely with the microarray data. No definitive phenotypic difference has previously been reported between Xid and Btk KO mice. We found 7 genes, whose expression differed (&gt;2 fold) between the two strains. Moreover, when the 38 genes, which differed between immunocompetent CBA and Btk defective mice were ranked according to fold-increase, the levels in Btk KO mice were significantly more altered. This suggests that the defect in Btk KO mice is more severe and demonstrates that the mutant Btk protein in Xid mice does not generally function as dominant negative form.

Standard name | GSE2826_XID_VS_BTK_KO_BCELL_DN
Systematic name | M4901
Organism | Mus musculus
PMID | 15214046
Authors | Lindvall JM,Blomberg KE,Berglöf A,Yang Q,Smith CI,Islam TC
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of primary splenic B cells from Xid mice versus those from BTK [GeneID=695] knockout mice.
Full description | Bruton's tyrosine kinase (Btk) is important for B lymphocyte development. To identify genes that are differentially expressed in primary B cells lacking functional Btk, splenocytes from X-linked immunodeficiency (Xid), Btk knockout (KO) and immunocompetent CBA mice, were used in microarrays containing more than 12,000 genes and expressed sequence tags (ESTs). We found 4515 transcripts expressed in duplicate experiments in all three strains. Out of these, 38 were differentially expressed genes (21 up-regulated &gt;2 fold and 17 down-regulated &lt;-2 fold) between CBA and Btk defective mice. Ten out of these genes were selected and quantitative Real-Time PCR was conducted for validation and further investigation. Real-Time experiments correlated nicely with the microarray data. No definitive phenotypic difference has previously been reported between Xid and Btk KO mice. We found 7 genes, whose expression differed (&gt;2 fold) between the two strains. Moreover, when the 38 genes, which differed between immunocompetent CBA and Btk defective mice were ranked according to fold-increase, the levels in Btk KO mice were significantly more altered. This suggests that the defect in Btk KO mice is more severe and demonstrates that the mutant Btk protein in Xid mice does not generally function as dominant negative form.

Standard name | GSE29614_CTRL_VS_TIV_FLU_VACCINE_PBMC_2007_UP
Systematic name | M4903
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus that after the vaccination
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29614_CTRL_VS_TIV_FLU_VACCINE_PBMC_2007_DN
Systematic name | M4905
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus that after the vaccination
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29614_CTRL_VS_DAY3_TIV_FLU_VACCINE_PBMC_UP
Systematic name | M4906
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus those from day 3 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29614_CTRL_VS_DAY3_TIV_FLU_VACCINE_PBMC_DN
Systematic name | M4907
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus those from day 3 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29614_CTRL_VS_DAY7_TIV_FLU_VACCINE_PBMC_UP
Systematic name | M4908
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus those from day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29614_CTRL_VS_DAY7_TIV_FLU_VACCINE_PBMC_DN
Systematic name | M4912
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus those from day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29614_DAY3_VS_DAY7_TIV_FLU_VACCINE_PBMC_UP
Systematic name | M4914
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee at day 3 post-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29614_DAY3_VS_DAY7_TIV_FLU_VACCINE_PBMC_DN
Systematic name | M4915
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee at day 3 post-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29615_CTRL_VS_DAY3_LAIV_IFLU_VACCINE_PBMC_UP
Systematic name | M4916
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from LAIV influenza vaccinee pre-vaccination versus those at day 3 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29615_CTRL_VS_DAY3_LAIV_IFLU_VACCINE_PBMC_DN
Systematic name | M4917
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from LAIV influenza vaccinee pre-vaccination versus those at day 3 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29615_CTRL_VS_DAY7_LAIV_FLU_VACCINE_PBMC_UP
Systematic name | M4918
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from LAIV influenza vaccine pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29615_CTRL_VS_DAY7_LAIV_FLU_VACCINE_PBMC_DN
Systematic name | M4919
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from LAIV influenza vaccine pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29615_DAY3_VS_DAY7_LAIV_FLU_VACCINE_PBMC_UP
Systematic name | M4921
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from LAIV influenza vaccinee at day 3 post-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29615_DAY3_VS_DAY7_LAIV_FLU_VACCINE_PBMC_DN
Systematic name | M4922
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from LAIV influenza vaccinee at day 3 post-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29615_CTRL_VS_LAIV_FLU_VACCINE_PBMC_UP
Systematic name | M4923
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus those post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29615_CTRL_VS_LAIV_FLU_VACCINE_PBMC_DN
Systematic name | M4924
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus those post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying the innate responses to the trivalent inactivated influenza (TIV) and live attenuated influenza (LAIV) vaccination in humans, and to identify early gene signatures that predict the magnitude of the antibody responses to influenza vaccination.

Standard name | GSE29617_CTRL_VS_TIV_FLU_VACCINE_PBMC_2008_UP
Systematic name | M4926
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee before vaccination versus that after the vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29617_CTRL_VS_TIV_FLU_VACCINE_PBMC_2008_DN
Systematic name | M4927
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee before vaccination versus that after the vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29617_CTRL_VS_DAY3_TIV_FLU_VACCINE_PBMC_2008_UP
Systematic name | M4928
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus those at day 3 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29617_CTRL_VS_DAY3_TIV_FLU_VACCINE_PBMC_2008_DN
Systematic name | M4929
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus those at day 3 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29617_CTRL_VS_DAY7_TIV_FLU_VACCINE_PBMC_2008_UP
Systematic name | M4930
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29617_CTRL_VS_DAY7_TIV_FLU_VACCINE_PBMC_2008_DN
Systematic name | M4931
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29617_DAY3_VS_DAY7_TIV_FLU_VACCINE_PBMC_2008_UP
Systematic name | M4933
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee at day 3 post-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29617_DAY3_VS_DAY7_TIV_FLU_VACCINE_PBMC_2008_DN
Systematic name | M4935
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from TIV influenza vaccinee at day 3 post-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_MONOCYTE_UP
Systematic name | M4936
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus monocytes.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_MONOCYTE_DN
Systematic name | M4938
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus monocytes.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_PDC_UP
Systematic name | M4940
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus plasmacytoid dendritic cells (pDC) .
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_PDC_DN
Systematic name | M4942
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus plasmacytoid dendritic cells (pDC) .
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_MDC_UP
Systematic name | M4943
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus myeloid dendritic cells (mDC).
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_MDC_DN
Systematic name | M4944
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus myeloid dendritic cells (mDC).
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_MONOCYTE_VS_PDC_UP
Systematic name | M4945
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes versus plasmacytoid dendritic cells (pDC).
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_MONOCYTE_VS_PDC_DN
Systematic name | M4946
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes versus plasmacytoid dendritic cells (pDC).
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_MONOCYTE_VS_MDC_UP
Systematic name | M4948
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes versus myeloid dendritic cells (mDC).
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_MONOCYTE_VS_MDC_DN
Systematic name | M4949
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes versus myeloid dendritic cells (mDC).
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PDC_VS_MDC_UP
Systematic name | M4951
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of plasmacytoid dendritic cells (DC) versus myeloid DCs.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PDC_VS_MDC_DN
Systematic name | M4952
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of plasmacytoid dendritic cells (DC) versus myeloid DCs.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_MONOCYTE_DAY7_FLU_VACCINE_UP
Systematic name | M4954
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells from influenza vaccinee at day 7 versus monocytes from influenza vaccinee at day 7.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_MONOCYTE_DAY7_FLU_VACCINE_DN
Systematic name | M4955
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells from influenza vaccinee at day 7 versus monocytes from influenza vaccinee at day 7.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_PDC_DAY7_FLU_VACCINE_UP
Systematic name | M4958
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells from influenza vaccinee at day 7 post-vaccination versus plasmacytoid dendritic cells (pDC) at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_PDC_DAY7_FLU_VACCINE_DN
Systematic name | M4959
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells from influenza vaccinee at day 7 post-vaccination versus plasmacytoid dendritic cells (pDC) at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_MDC_DAY7_FLU_VACCINE_UP
Systematic name | M4961
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells from influenza vaccinee at day 7 post-vaccination versus myeloid dendritic cells (mDC) at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_BCELL_VS_MDC_DAY7_FLU_VACCINE_DN
Systematic name | M4962
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells from influenza vaccinee at day 7 post-vaccination versus myeloid dendritic cells (mDC) at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_MONOCYTE_VS_PDC_DAY7_FLU_VACCINE_UP
Systematic name | M4963
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes from influenza vaccinee at day 7 post-vaccination versus plasmacytoid dendritic cells (mDC) at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_MONOCYTE_VS_PDC_DAY7_FLU_VACCINE_DN
Systematic name | M4964
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes from influenza vaccinee at day 7 post-vaccination versus plasmacytoid dendritic cells (mDC) at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_MONOCYTE_VS_MDC_DAY7_FLU_VACCINE_UP
Systematic name | M4966
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes from influenza vaccinee at day 7 post-vaccination versus myeloid dendritic cells at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_MONOCYTE_VS_MDC_DAY7_FLU_VACCINE_DN
Systematic name | M4968
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes from influenza vaccinee at day 7 post-vaccination versus myeloid dendritic cells at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PDC_VS_MDC_DAY7_FLU_VACCINE_UP
Systematic name | M4970
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of plasmacytoid dendritic cells (DC) from influenza vaccinee at day 7 post-vaccination versus myeloid DCs at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PDC_VS_MDC_DAY7_FLU_VACCINE_DN
Systematic name | M4971
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of plasmacytoid dendritic cells (DC) from influenza vaccinee at day 7 post-vaccination versus myeloid DCs at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_FLU_VACCINE_BCELL_UP
Systematic name | M4972
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells from influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_FLU_VACCINE_BCELL_DN
Systematic name | M4973
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells from influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_FLU_VACCINE_MONOCYTE_UP
Systematic name | M4975
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes from influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_FLU_VACCINE_MONOCYTE_DN
Systematic name | M4977
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes from influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_FLU_VACCINE_PDC_UP
Systematic name | M4978
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of plasmacytoid dendritic cells (pDC) from influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_FLU_VACCINE_PDC_DN
Systematic name | M4979
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of plasmacytoid dendritic cells (pDC) from influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_FLU_VACCINE_MDC_UP
Systematic name | M4980
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of plasmacytoid dendritic cells (DC) from influenza vaccinee at day 0 versus myeloid DCs at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_FLU_VACCINE_MDC_DN
Systematic name | M4981
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of plasmacytoid dendritic cells (DC) from influenza vaccinee at day 0 versus myeloid DCs at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_LAIV_FLU_VACCINE_BCELL_UP
Systematic name | M4982
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells from LAIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_LAIV_FLU_VACCINE_BCELL_DN
Systematic name | M4984
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells from LAIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_TIV_FLU_VACCINE_BCELL_UP
Systematic name | M4985
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells from TIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_TIV_FLU_VACCINE_BCELL_DN
Systematic name | M4990
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells from TIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_LAIV_FLU_VACCINE_MONOCYTE_UP
Systematic name | M4993
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes from LAIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_LAIV_FLU_VACCINE_MONOCYTE_DN
Systematic name | M4994
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes from LAIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_TIV_FLU_VACCINE_MONOCYTE_UP
Systematic name | M4996
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes from TIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_TIV_FLU_VACCINE_MONOCYTE_DN
Systematic name | M4997
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes from TIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_LAIV_FLU_VACCINE_PDC_UP
Systematic name | M4999
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of plasmacytoid dendritic cells (pDC) from influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_LAIV_FLU_VACCINE_PDC_DN
Systematic name | M5001
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of plasmacytoid dendritic cells (pDC) from influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_TIV_FLU_VACCINE_PDC_UP
Systematic name | M5003
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of plasmacytoid dendritic cells (pDC) from TIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_TIV_FLU_VACCINE_PDC_DN
Systematic name | M5005
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of plasmacytoid dendritic cells (pDC) from TIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_LAIV_FLU_VACCINE_MDC_UP
Systematic name | M5007
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of myeloid dendritic cells (mDC) from LAIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_LAIV_FLU_VACCINE_MDC_DN
Systematic name | M5008
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of myeloid dendritic cells (mDC) from LAIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_TIV_FLU_VACCINE_MDC_UP
Systematic name | M5009
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of myeloid dendritic cells (mDC) from TIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_PRE_VS_DAY7_POST_TIV_FLU_VACCINE_MDC_DN
Systematic name | M5010
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of myeloid dendritic cells (mDC) from TIV influenza vaccinee pre-vaccination versus those at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_LAIV_VS_TIV_FLU_VACCINE_DAY7_BCELL_UP
Systematic name | M5011
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells from LAIV influenza vaccinee at day 7 post-vaccination versus those from TIV influenza vaccinee at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_LAIV_VS_TIV_FLU_VACCINE_DAY7_BCELL_DN
Systematic name | M5013
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells from LAIV influenza vaccinee at day 7 post-vaccination versus those from TIV influenza vaccinee at day 7 post-vaccination.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_LAIV_VS_TIV_FLU_VACCINE_DAY7_MONOCYTE_UP
Systematic name | M5015
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes from LAIV influenza vaccinee at day 7 post-vaccination vesus those from TIV influenza vaccinee at day 7.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_LAIV_VS_TIV_FLU_VACCINE_DAY7_MONOCYTE_DN
Systematic name | M5016
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes from LAIV influenza vaccinee at day 7 post-vaccination vesus those from TIV influenza vaccinee at day 7.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_LAIV_VS_TIV_FLU_VACCINE_DAY7_PDC_UP
Systematic name | M5018
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of plasmacytoid dendritic cells from LAIV influenza vaccinee at day 7 post-vaccination vesus those from TIV influenza vaccinee at day 7.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_LAIV_VS_TIV_FLU_VACCINE_DAY7_PDC_DN
Systematic name | M5019
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of plasmacytoid dendritic cells from LAIV influenza vaccinee at day 7 post-vaccination vesus those from TIV influenza vaccinee at day 7.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_LAIV_VS_TIV_FLU_VACCINE_DAY7_MDC_UP
Systematic name | M5020
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of myeloid dendritic cells from LAIV influenza vaccinee at day 7 post-vaccination vesus those from TIV influenza vaccinee at day 7.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE29618_LAIV_VS_TIV_FLU_VACCINE_DAY7_MDC_DN
Systematic name | M5022
Organism | Homo sapiens
PMID | 21743478
Authors | Nakaya HI,Wrammert J,Lee EK,Racioppi L,Marie-Kunze S,Haining WN,Means AR,Kasturi SP,Khan N,Li GM,McCausland M,Kanchan V,Kokko KE,Li S,Elbein R,Mehta AK,Aderem A,Subbarao K,Ahmed R,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of myeloid dendritic cells from LAIV influenza vaccinee at day 7 post-vaccination vesus those from TIV influenza vaccinee at day 7.
Full description | Systems vaccinology has emerged as an interdisciplinary field that combines systems wide measurements and network and predictive modeling applied to vaccinology. Here we used the systems vaccinology approach to study the molecular mechanisms underlying th

Standard name | GSE30083_SP1_VS_SP2_THYMOCYTE_UP
Systematic name | M5023
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of SP1 thymocytes versus SP2 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP1_VS_SP2_THYMOCYTE_DN
Systematic name | M5024
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of SP1 thymocytes versus SP2 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP1_VS_SP3_THYMOCYTE_UP
Systematic name | M5025
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of SP1 thymocytes versus SP3 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP1_VS_SP3_THYMOCYTE_DN
Systematic name | M5026
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of SP1 thymocytes versus SP3 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP1_VS_SP4_THYMOCYTE_UP
Systematic name | M5028
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of SP1 thymocytes versus SP4 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP1_VS_SP4_THYMOCYTE_DN
Systematic name | M5030
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of SP1 thymocytes versus SP4 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP2_VS_SP3_THYMOCYTE_UP
Systematic name | M5031
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of SP2 thymocytes versus SP3 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP2_VS_SP3_THYMOCYTE_DN
Systematic name | M5033
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of SP2 thymocytes versus SP3 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP2_VS_SP4_THYMOCYTE_UP
Systematic name | M5034
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of SP2 thymocytes versus SP4 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP2_VS_SP4_THYMOCYTE_DN
Systematic name | M5035
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of SP2 thymocytes versus SP4 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP3_VS_SP4_THYMOCYTE_UP
Systematic name | M5036
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of SP3 thymocytes versus SP4 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30083_SP3_VS_SP4_THYMOCYTE_DN
Systematic name | M5037
Organism | Mus musculus
PMID | 22022412
Authors | Teng F,Zhou Y,Jin R,Chen Y,Pei X,Liu Y,Dong J,Wang W,Pang X,Qian X,Chen WF,Zhang Y,Ge Q.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of SP3 thymocytes versus SP4 thymocytes.
Full description | After positive selection in the thymus, the newly generated single positive (SP) thymocytes are phenotypically and functionally immature and undergo apoptosis upon antigen stimulation. In the thymic medullary microenvironment, SP cells progressively acquire immunocompetence. Negative selection to remove autoreactive T cells also occur at this stage. We have defined four subsets of CD4 SP, namely, SP1, SP2, SP3, and SP4 that follow a functional maturation program and a sequential emergence during mouse ontogeny.We used microarray to detail the global programm of gene expression during the maturation of murine CD4 single positive thymocytes

Standard name | GSE30962_PRIMARY_VS_SECONDARY_ACUTE_LCMV_INF_CD8_TCELL_UP
Systematic name | M5041
Organism | Mus musculus
PMID | 21856186
Authors | West EE,Youngblood B,Tan WG,Jin HT,Araki K,Alexe G,Konieczny BT,Calpe S,Freeman GJ,Terhorst C,Haining WN,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of splenic primary CD8 effector T cells at day 8 post-acute infection versus splenic secondary CD8 effector T cells at day 8 post-acute infection.
Full description | Understanding the response of memory CD8 T cells to persistent antigen re-stimulation and the role of CD4 T cell help is critical to the design of successful vaccines for chronic diseases. However, studies comparing the protective abilities and qualities of memory and naïve cells have been mostly performed in acute infections, and little is known about their roles during chronic infections. Herein, we show that memory cells dominate over naïve cells and are protective when present in large enough numbers to quickly reduce infection. In contrast, when infection is not rapidly reduced, memory cells are quickly lost, unlike naïve cells. This loss of memory cells is due to (i) an early block in cell proliferation, (ii) selective regulation by the inhibitory receptor 2B4, and (iii) increased reliance on CD4 T cell help. These findings have important implications towards the design of T cell vaccines against chronic infections and tumors.

Standard name | GSE30962_PRIMARY_VS_SECONDARY_ACUTE_LCMV_INF_CD8_TCELL_DN
Systematic name | M5043
Organism | Mus musculus
PMID | 21856186
Authors | West EE,Youngblood B,Tan WG,Jin HT,Araki K,Alexe G,Konieczny BT,Calpe S,Freeman GJ,Terhorst C,Haining WN,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of splenic primary CD8 effector T cells at day 8 post-acute infection versus splenic secondary CD8 effector T cells at day 8 post-acute infection.
Full description | Understanding the response of memory CD8 T cells to persistent antigen re-stimulation and the role of CD4 T cell help is critical to the design of successful vaccines for chronic diseases. However, studies comparing the protective abilities and qualities of memory and naïve cells have been mostly performed in acute infections, and little is known about their roles during chronic infections. Herein, we show that memory cells dominate over naïve cells and are protective when present in large enough numbers to quickly reduce infection. In contrast, when infection is not rapidly reduced, memory cells are quickly lost, unlike naïve cells. This loss of memory cells is due to (i) an early block in cell proliferation, (ii) selective regulation by the inhibitory receptor 2B4, and (iii) increased reliance on CD4 T cell help. These findings have important implications towards the design of T cell vaccines against chronic infections and tumors.

Standard name | GSE30962_PRIMARY_VS_SECONDARY_CHRONIC_LCMV_INF_CD8_TCELL_UP
Systematic name | M5044
Organism | Mus musculus
PMID | 21856186
Authors | West EE,Youngblood B,Tan WG,Jin HT,Araki K,Alexe G,Konieczny BT,Calpe S,Freeman GJ,Terhorst C,Haining WN,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of splenic primary CD8 effector T cells at day 8 post-chronic infection versus splenic secondary CD8 effector T cells at day 8 post-chronic infection.
Full description | Understanding the response of memory CD8 T cells to persistent antigen re-stimulation and the role of CD4 T cell help is critical to the design of successful vaccines for chronic diseases. However, studies comparing the protective abilities and qualities of memory and naïve cells have been mostly performed in acute infections, and little is known about their roles during chronic infections. Herein, we show that memory cells dominate over naïve cells and are protective when present in large enough numbers to quickly reduce infection. In contrast, when infection is not rapidly reduced, memory cells are quickly lost, unlike naïve cells. This loss of memory cells is due to (i) an early block in cell proliferation, (ii) selective regulation by the inhibitory receptor 2B4, and (iii) increased reliance on CD4 T cell help. These findings have important implications towards the design of T cell vaccines against chronic infections and tumors.

Standard name | GSE30962_PRIMARY_VS_SECONDARY_CHRONIC_LCMV_INF_CD8_TCELL_DN
Systematic name | M5045
Organism | Mus musculus
PMID | 21856186
Authors | West EE,Youngblood B,Tan WG,Jin HT,Araki K,Alexe G,Konieczny BT,Calpe S,Freeman GJ,Terhorst C,Haining WN,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of splenic primary CD8 effector T cells at day 8 post-chronic infection versus splenic secondary CD8 effector T cells at day 8 post-chronic infection.
Full description | Understanding the response of memory CD8 T cells to persistent antigen re-stimulation and the role of CD4 T cell help is critical to the design of successful vaccines for chronic diseases. However, studies comparing the protective abilities and qualities of memory and naïve cells have been mostly performed in acute infections, and little is known about their roles during chronic infections. Herein, we show that memory cells dominate over naïve cells and are protective when present in large enough numbers to quickly reduce infection. In contrast, when infection is not rapidly reduced, memory cells are quickly lost, unlike naïve cells. This loss of memory cells is due to (i) an early block in cell proliferation, (ii) selective regulation by the inhibitory receptor 2B4, and (iii) increased reliance on CD4 T cell help. These findings have important implications towards the design of T cell vaccines against chronic infections and tumors.

Standard name | GSE30962_ACUTE_VS_CHRONIC_LCMV_PRIMARY_INF_CD8_TCELL_UP
Systematic name | M5046
Organism | Mus musculus
PMID | 21856186
Authors | West EE,Youngblood B,Tan WG,Jin HT,Araki K,Alexe G,Konieczny BT,Calpe S,Freeman GJ,Terhorst C,Haining WN,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of splenic primary CD8 effector T cells at day 8 post-acute infection versus splenic primary CD8 effector T cells at day 8 post-chronic infection.
Full description | Understanding the response of memory CD8 T cells to persistent antigen re-stimulation and the role of CD4 T cell help is critical to the design of successful vaccines for chronic diseases. However, studies comparing the protective abilities and qualities of memory and naïve cells have been mostly performed in acute infections, and little is known about their roles during chronic infections. Herein, we show that memory cells dominate over naïve cells and are protective when present in large enough numbers to quickly reduce infection. In contrast, when infection is not rapidly reduced, memory cells are quickly lost, unlike naïve cells. This loss of memory cells is due to (i) an early block in cell proliferation, (ii) selective regulation by the inhibitory receptor 2B4, and (iii) increased reliance on CD4 T cell help. These findings have important implications towards the design of T cell vaccines against chronic infections and tumors.

Standard name | GSE30962_ACUTE_VS_CHRONIC_LCMV_PRIMARY_INF_CD8_TCELL_DN
Systematic name | M5048
Organism | Mus musculus
PMID | 21856186
Authors | West EE,Youngblood B,Tan WG,Jin HT,Araki K,Alexe G,Konieczny BT,Calpe S,Freeman GJ,Terhorst C,Haining WN,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of splenic primary CD8 effector T cells at day 8 post-acute infection versus splenic primary CD8 effector T cells at day 8 post-chronic infection.
Full description | Understanding the response of memory CD8 T cells to persistent antigen re-stimulation and the role of CD4 T cell help is critical to the design of successful vaccines for chronic diseases. However, studies comparing the protective abilities and qualities of memory and naïve cells have been mostly performed in acute infections, and little is known about their roles during chronic infections. Herein, we show that memory cells dominate over naïve cells and are protective when present in large enough numbers to quickly reduce infection. In contrast, when infection is not rapidly reduced, memory cells are quickly lost, unlike naïve cells. This loss of memory cells is due to (i) an early block in cell proliferation, (ii) selective regulation by the inhibitory receptor 2B4, and (iii) increased reliance on CD4 T cell help. These findings have important implications towards the design of T cell vaccines against chronic infections and tumors.

Standard name | GSE30962_ACUTE_VS_CHRONIC_LCMV_SECONDARY_INF_CD8_TCELL_UP
Systematic name | M5049
Organism | Mus musculus
PMID | 21856186
Authors | West EE,Youngblood B,Tan WG,Jin HT,Araki K,Alexe G,Konieczny BT,Calpe S,Freeman GJ,Terhorst C,Haining WN,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of splenic secondary CD8 effector T cells at day 8 post-acute infection versus splenic secondary CD8 effector T cells at day 8 post-chronic infection.
Full description | Understanding the response of memory CD8 T cells to persistent antigen re-stimulation and the role of CD4 T cell help is critical to the design of successful vaccines for chronic diseases. However, studies comparing the protective abilities and qualities of memory and naïve cells have been mostly performed in acute infections, and little is known about their roles during chronic infections. Herein, we show that memory cells dominate over naïve cells and are protective when present in large enough numbers to quickly reduce infection. In contrast, when infection is not rapidly reduced, memory cells are quickly lost, unlike naïve cells. This loss of memory cells is due to (i) an early block in cell proliferation, (ii) selective regulation by the inhibitory receptor 2B4, and (iii) increased reliance on CD4 T cell help. These findings have important implications towards the design of T cell vaccines against chronic infections and tumors.

Standard name | GSE30962_ACUTE_VS_CHRONIC_LCMV_SECONDARY_INF_CD8_TCELL_DN
Systematic name | M5052
Organism | Mus musculus
PMID | 21856186
Authors | West EE,Youngblood B,Tan WG,Jin HT,Araki K,Alexe G,Konieczny BT,Calpe S,Freeman GJ,Terhorst C,Haining WN,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of splenic secondary CD8 effector T cells at day 8 post-acute infection versus splenic secondary CD8 effector T cells at day 8 post-chronic infection.
Full description | Understanding the response of memory CD8 T cells to persistent antigen re-stimulation and the role of CD4 T cell help is critical to the design of successful vaccines for chronic diseases. However, studies comparing the protective abilities and qualities of memory and naïve cells have been mostly performed in acute infections, and little is known about their roles during chronic infections. Herein, we show that memory cells dominate over naïve cells and are protective when present in large enough numbers to quickly reduce infection. In contrast, when infection is not rapidly reduced, memory cells are quickly lost, unlike naïve cells. This loss of memory cells is due to (i) an early block in cell proliferation, (ii) selective regulation by the inhibitory receptor 2B4, and (iii) increased reliance on CD4 T cell help. These findings have important implications towards the design of T cell vaccines against chronic infections and tumors.

Standard name | GSE31082_DN_VS_DP_THYMOCYTE_UP
Systematic name | M5054
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4- [GeneID=920] CD8- thymocytes versus CD4+ [GeneID=920] CD8+ thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_DN_VS_DP_THYMOCYTE_DN
Systematic name | M5055
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4- [GeneID=920] CD8- thymocytes versus CD4+ [GeneID=920] CD8+ thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_DN_VS_CD4_SP_THYMOCYTE_UP
Systematic name | M5057
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4- [GeneID=920] CD8- thymocytes versus CD4+ [GeneID=920] CD8- thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_DN_VS_CD4_SP_THYMOCYTE_DN
Systematic name | M5059
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4- [GeneID=920] CD8- thymocytes versus CD4+ [GeneID=920] CD8- thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_DN_VS_CD8_SP_THYMOCYTE_UP
Systematic name | M5061
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4- [GeneID=920] CD8- thymocytes versus CD4- [GeneID=920] CD8+ thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_DN_VS_CD8_SP_THYMOCYTE_DN
Systematic name | M5063
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4- [GeneID=920] CD8- thymocytes versus CD4- [GeneID=920] CD8+ thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_DP_VS_CD4_SP_THYMOCYTE_UP
Systematic name | M5064
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4+ [GeneID=920] CD8+ thymocytes versus CD4+ [GeneID=920] CD8- thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_DP_VS_CD4_SP_THYMOCYTE_DN
Systematic name | M5065
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4+ [GeneID=920] CD8+ thymocytes versus CD4- [GeneID=920] CD8+ thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_DP_VS_CD8_SP_THYMOCYTE_UP
Systematic name | M5066
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4+ [GeneID=920] CD8+ thymocytes versus CD4- [GeneID=920] CD8+ thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_DP_VS_CD8_SP_THYMOCYTE_DN
Systematic name | M5068
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4+ [GeneID=920] CD8+ thymocytes versus CD4- [GeneID=920] CD8+ thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_CD4_VS_CD8_SP_THYMOCYTE_UP
Systematic name | M5069
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4+ [GeneID=920] CD8- thymocytes versus CD4- [GeneID=920] CD8+ thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE31082_CD4_VS_CD8_SP_THYMOCYTE_DN
Systematic name | M5070
Organism | Mus musculus
PMID | 21873191
Authors | Egawa T,Littman DR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4+ [GeneID=920] CD8- thymocytes versus CD4- [GeneID=920] CD8+ thymocytes.
Full description | Mouse thymocytes can be classified into four major subsets based on expression of CD4 and CD8 co-receptors. CD4-CD8- (double negative, DN) cells become CD4+CD8+ (double positive, DP) cells following productive T cell receptor (TCR) beta chain rearrangement. A small proportion of DP cells are selected through interaction of clonal TCRalpha/beta and MHC self peptide complex expressed on thymic stromal cells. DP cell expressing MHC class I-restricted TCR become CD4-CD8+ cells, which will finally differentiate into cytotoxic T cells, while MHC class II restricted selection generates CD4+CD8- helper lineage T cells. We used microarrays to identify genes important for thymocyte differentiation and lineage determination by profiling gene expression in different thymocyte subsets.

Standard name | GSE32423_MEMORY_VS_NAIVE_CD8_TCELL_UP
Systematic name | M5072
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells versus naive CD8 T cells.
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_MEMORY_VS_NAIVE_CD8_TCELL_DN
Systematic name | M5073
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells versus naive CD8 T cells.
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_MEMORY_VS_NAIVE_CD8_TCELL_IL7_UP
Systematic name | M5074
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells treated with IL7 [GeneID=3574] versus naive CD8 T cells treated with IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_MEMORY_VS_NAIVE_CD8_TCELL_IL7_DN
Systematic name | M5078
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells treated with IL7 [GeneID=3574] versus naive CD8 T cells treated with IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_MEMORY_VS_NAIVE_CD8_TCELL_IL7_IL4_UP
Systematic name | M5079
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells treated with IL4 [GeneID=3565] and IL7 [GeneID=3574] versus naive CD8 T cells treated with IL4 [GeneID=3565] and IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_MEMORY_VS_NAIVE_CD8_TCELL_IL7_IL4_DN
Systematic name | M5081
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells treated with IL4 [GeneID=3565] and IL7 [GeneID=3574] versus naive CD8 T cells treated with IL4 [GeneID=3565] and IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_CTRL_VS_IL7_MEMORY_CD8_TCELL_UP
Systematic name | M5083
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells versus those treated with IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_CTRL_VS_IL7_MEMORY_CD8_TCELL_DN
Systematic name | M5084
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells versus those treated with IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_CTRL_VS_IL4_MEMORY_CD8_TCELL_UP
Systematic name | M5085
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells versus those treated with IL4 [GeneID=3565].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_CTRL_VS_IL4_MEMORY_CD8_TCELL_DN
Systematic name | M5086
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells versus those treated with IL4 [GeneID=3565].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_CTRL_VS_IL7_IL4_MEMORY_CD8_TCELL_UP
Systematic name | M5087
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells versus those treated with IL4 [GeneID=3565] and IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_CTRL_VS_IL7_IL4_MEMORY_CD8_TCELL_DN
Systematic name | M5088
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells versus those treated with IL4 [GeneID=3565] and IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_IL7_VS_IL7_IL4_MEMORY_CD8_TCELL_UP
Systematic name | M5089
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells treated with IL7 [GeneID=3574] versus those treated with IL4 [GeneID=3565] and IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_IL7_VS_IL7_IL4_MEMORY_CD8_TCELL_DN
Systematic name | M5092
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells treated with IL7 [GeneID=3574] versus those treated with IL4 [GeneID=3565] and IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_IL7_VS_IL4_MEMORY_CD8_TCELL_UP
Systematic name | M5093
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD8 T cells treated with IL7 [GeneID=3574] versus those treated with IL4 [GeneID=3565].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_IL7_VS_IL4_MEMORY_CD8_TCELL_DN
Systematic name | M5094
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD8 T cells treated with IL7 [GeneID=3574] versus those treated with IL4 [GeneID=3565].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_IL7_VS_IL7_IL4_NAIVE_CD8_TCELL_UP
Systematic name | M5095
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells treated with IL7 [GeneID=3574] versus those treated with IL4 [GeneID=3565] and IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE32423_IL7_VS_IL7_IL4_NAIVE_CD8_TCELL_DN
Systematic name | M5096
Organism | Mus musculus
PMID | 22942430
Authors | Ventre E,Brinza L,Schicklin S,Mafille J,Coupet CA,Marçais A,Djebali S,Jubin V,Walzer T,Marvel J
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells treated with IL7 [GeneID=3574] versus those treated with IL4 [GeneID=3565] and IL7 [GeneID=3574].
Full description | Effects of IL-4 on CD8 T cells functions are largely unknown. IL-4 induces survival and proliferation of CD8 T cells, but several studies suggest that IL-4 could also affect several functions of CD8 T cells such as cytotoxicity. Our team has shown that IL-4 repress the expression of Ccl5 in vitro. To define more precisely the impact of IL-4 on CD8 T cells, we performed a whole genome expression microarray analysis of naive and memory CD8 T cells cultured in presence or absence of IL-4. This approach allowed us to define the IL4-gene-expression signature on CD8 T cells.

Standard name | GSE3337_CTRL_VS_4H_IFNG_IN_CD8POS_DC_UP
Systematic name | M5097
Organism | Mus musculus
PMID | 16339401
Authors | Orabona C,Puccetti P,Vacca C,Bicciato S,Luchini A,Fallarino F,Bianchi R,Velardi E,Perruccio K,Velardi A,Bronte V,Fioretti MC,Grohmann U.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD8+ dendritic cells (DC) at 4 h versus those treated with IFNG [GeneID=3458] at 4 h.
Full description | Although much is known on the transcriptional profiles of dendritic cells (DCs) during maturation, the molecular switches critical for the acquisition of a tolerogenic program by DCs are still obscure. In the present study, we explored the gene expression pattern of CD8+ DCs purified from the mouse spleen and treated with interferon (IFN)-gamma. The cytokine, indeed, potentiates the tolerogenic potential of this DC subset via induction of the immunosuppressive tryptophan catabolism mediated by indoleamine 2,3-dioxygenase (IDO). By comparing the expression of the IFN-gamma-modulated genes in IDO+ versus IDO- murine DCs, we found a consistent and selective association of the IDO-competent phenotype with the down-modulation of the Tyrobp gene, encoding the adapter molecule DAP12. IFN-gamma-mediated down-modulation of this gene involved IFN consensus sequence binding protein (ICSBP), a transcription factor also known as IRF-8. While silencing of Tyrobp conferred IDO functional competence on IDO- DCs, silencing of Icsbp1 in IDO+ cells completely abolished IDO expression and function. In parallel, silencing of TYROBP conferred IDO competence on human IDO- DCs while silencing of IRF8 impaired IDO expression and activity in human IDO+ DCs. Therefore, the same small set of molecular switches controls IDO competence in murine and human DCs.

Standard name | GSE3337_CTRL_VS_4H_IFNG_IN_CD8POS_DC_DN
Systematic name | M5099
Organism | Mus musculus
PMID | 16339401
Authors | Orabona C,Puccetti P,Vacca C,Bicciato S,Luchini A,Fallarino F,Bianchi R,Velardi E,Perruccio K,Velardi A,Bronte V,Fioretti MC,Grohmann U.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD8+ dendritic cells (DC) at 4 h versus those treated with IFNG [GeneID=3458] at 4 h.
Full description | Although much is known on the transcriptional profiles of dendritic cells (DCs) during maturation, the molecular switches critical for the acquisition of a tolerogenic program by DCs are still obscure. In the present study, we explored the gene expression pattern of CD8+ DCs purified from the mouse spleen and treated with interferon (IFN)-gamma. The cytokine, indeed, potentiates the tolerogenic potential of this DC subset via induction of the immunosuppressive tryptophan catabolism mediated by indoleamine 2,3-dioxygenase (IDO). By comparing the expression of the IFN-gamma-modulated genes in IDO+ versus IDO- murine DCs, we found a consistent and selective association of the IDO-competent phenotype with the down-modulation of the Tyrobp gene, encoding the adapter molecule DAP12. IFN-gamma-mediated down-modulation of this gene involved IFN consensus sequence binding protein (ICSBP), a transcription factor also known as IRF-8. While silencing of Tyrobp conferred IDO functional competence on IDO- DCs, silencing of Icsbp1 in IDO+ cells completely abolished IDO expression and function. In parallel, silencing of TYROBP conferred IDO competence on human IDO- DCs while silencing of IRF8 impaired IDO expression and activity in human IDO+ DCs. Therefore, the same small set of molecular switches controls IDO competence in murine and human DCs.

Standard name | GSE3337_CTRL_VS_16H_IFNG_IN_CD8POS_DC_UP
Systematic name | M5100
Organism | Mus musculus
PMID | 16339401
Authors | Orabona C,Puccetti P,Vacca C,Bicciato S,Luchini A,Fallarino F,Bianchi R,Velardi E,Perruccio K,Velardi A,Bronte V,Fioretti MC,Grohmann U.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD8+ dendritic cells (DC) at 16 h versus those treated with IFNG [GeneID=31658] at 16 h.
Full description | Although much is known on the transcriptional profiles of dendritic cells (DCs) during maturation, the molecular switches critical for the acquisition of a tolerogenic program by DCs are still obscure. In the present study, we explored the gene expression pattern of CD8+ DCs purified from the mouse spleen and treated with interferon (IFN)-gamma. The cytokine, indeed, potentiates the tolerogenic potential of this DC subset via induction of the immunosuppressive tryptophan catabolism mediated by indoleamine 2,3-dioxygenase (IDO). By comparing the expression of the IFN-gamma-modulated genes in IDO+ versus IDO- murine DCs, we found a consistent and selective association of the IDO-competent phenotype with the down-modulation of the Tyrobp gene, encoding the adapter molecule DAP12. IFN-gamma-mediated down-modulation of this gene involved IFN consensus sequence binding protein (ICSBP), a transcription factor also known as IRF-8. While silencing of Tyrobp conferred IDO functional competence on IDO- DCs, silencing of Icsbp1 in IDO+ cells completely abolished IDO expression and function. In parallel, silencing of TYROBP conferred IDO competence on human IDO- DCs while silencing of IRF8 impaired IDO expression and activity in human IDO+ DCs. Therefore, the same small set of molecular switches controls IDO competence in murine and human DCs.

Standard name | GSE3337_CTRL_VS_16H_IFNG_IN_CD8POS_DC_DN
Systematic name | M5101
Organism | Mus musculus
PMID | 16339401
Authors | Orabona C,Puccetti P,Vacca C,Bicciato S,Luchini A,Fallarino F,Bianchi R,Velardi E,Perruccio K,Velardi A,Bronte V,Fioretti MC,Grohmann U.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD8+ dendritic cells (DC) at 16 h versus those treated with IFNG [GeneID=31658] at 16 h.
Full description | Although much is known on the transcriptional profiles of dendritic cells (DCs) during maturation, the molecular switches critical for the acquisition of a tolerogenic program by DCs are still obscure. In the present study, we explored the gene expression pattern of CD8+ DCs purified from the mouse spleen and treated with interferon (IFN)-gamma. The cytokine, indeed, potentiates the tolerogenic potential of this DC subset via induction of the immunosuppressive tryptophan catabolism mediated by indoleamine 2,3-dioxygenase (IDO). By comparing the expression of the IFN-gamma-modulated genes in IDO+ versus IDO- murine DCs, we found a consistent and selective association of the IDO-competent phenotype with the down-modulation of the Tyrobp gene, encoding the adapter molecule DAP12. IFN-gamma-mediated down-modulation of this gene involved IFN consensus sequence binding protein (ICSBP), a transcription factor also known as IRF-8. While silencing of Tyrobp conferred IDO functional competence on IDO- DCs, silencing of Icsbp1 in IDO+ cells completely abolished IDO expression and function. In parallel, silencing of TYROBP conferred IDO competence on human IDO- DCs while silencing of IRF8 impaired IDO expression and activity in human IDO+ DCs. Therefore, the same small set of molecular switches controls IDO competence in murine and human DCs.

Standard name | GSE3337_4H_VS_16H_IFNG_IN_CD8POS_DC_UP
Systematic name | M5102
Organism | Mus musculus
PMID | 16339401
Authors | Orabona C,Puccetti P,Vacca C,Bicciato S,Luchini A,Fallarino F,Bianchi R,Velardi E,Perruccio K,Velardi A,Bronte V,Fioretti MC,Grohmann U.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD8+ dendritic cells (DC) at 4 h versus those treated with IFNG [GeneID=3458] at 16 h.
Full description | Although much is known on the transcriptional profiles of dendritic cells (DCs) during maturation, the molecular switches critical for the acquisition of a tolerogenic program by DCs are still obscure. In the present study, we explored the gene expression pattern of CD8+ DCs purified from the mouse spleen and treated with interferon (IFN)-gamma. The cytokine, indeed, potentiates the tolerogenic potential of this DC subset via induction of the immunosuppressive tryptophan catabolism mediated by indoleamine 2,3-dioxygenase (IDO). By comparing the expression of the IFN-gamma-modulated genes in IDO+ versus IDO- murine DCs, we found a consistent and selective association of the IDO-competent phenotype with the down-modulation of the Tyrobp gene, encoding the adapter molecule DAP12. IFN-gamma-mediated down-modulation of this gene involved IFN consensus sequence binding protein (ICSBP), a transcription factor also known as IRF-8. While silencing of Tyrobp conferred IDO functional competence on IDO- DCs, silencing of Icsbp1 in IDO+ cells completely abolished IDO expression and function. In parallel, silencing of TYROBP conferred IDO competence on human IDO- DCs while silencing of IRF8 impaired IDO expression and activity in human IDO+ DCs. Therefore, the same small set of molecular switches controls IDO competence in murine and human DCs.

Standard name | GSE3337_4H_VS_16H_IFNG_IN_CD8POS_DC_DN
Systematic name | M5104
Organism | Mus musculus
PMID | 16339401
Authors | Orabona C,Puccetti P,Vacca C,Bicciato S,Luchini A,Fallarino F,Bianchi R,Velardi E,Perruccio K,Velardi A,Bronte V,Fioretti MC,Grohmann U.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD8+ dendritic cells (DC) at 4 h versus those treated with IFNG [GeneID=3458] at 16 h.
Full description | Although much is known on the transcriptional profiles of dendritic cells (DCs) during maturation, the molecular switches critical for the acquisition of a tolerogenic program by DCs are still obscure. In the present study, we explored the gene expression pattern of CD8+ DCs purified from the mouse spleen and treated with interferon (IFN)-gamma. The cytokine, indeed, potentiates the tolerogenic potential of this DC subset via induction of the immunosuppressive tryptophan catabolism mediated by indoleamine 2,3-dioxygenase (IDO). By comparing the expression of the IFN-gamma-modulated genes in IDO+ versus IDO- murine DCs, we found a consistent and selective association of the IDO-competent phenotype with the down-modulation of the Tyrobp gene, encoding the adapter molecule DAP12. IFN-gamma-mediated down-modulation of this gene involved IFN consensus sequence binding protein (ICSBP), a transcription factor also known as IRF-8. While silencing of Tyrobp conferred IDO functional competence on IDO- DCs, silencing of Icsbp1 in IDO+ cells completely abolished IDO expression and function. In parallel, silencing of TYROBP conferred IDO competence on human IDO- DCs while silencing of IRF8 impaired IDO expression and activity in human IDO+ DCs. Therefore, the same small set of molecular switches controls IDO competence in murine and human DCs.

Standard name | GSE33513_TCF7_KO_VS_HET_EARLY_THYMIC_PROGENITOR_UP
Systematic name | M5105
Organism | Mus musculus
PMID | 22109558
Authors | Germar K,Dose M,Konstantinou T,Zhang J,Wang H,Lobry C,Arnett KL,Blacklow SC,Aifantis I,Aster JC,Gounari F.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TCF7 [GeneID=6932] deficient early thymic progenitors versus the TCF7 [GeneID=6932] sufficient ones.
Full description | Although transcriptional programs associated with T-cell specification and commitment have been described, the functional hierarchy and the roles of key regulators in structuring/ orchestrating these programs remain unclear. Activation of Notch signaling in uncommitted precursors by the thymic stroma initiates the T-cell differentiation program. One regulator first induced in these precursors is the DNA binding protein Tcf-1, a T-cell specific mediator of Wnt signaling. Yet the specific contribution of Tcf-1 to early T-cell development and the signals inducing it in these cells remain unclear. Here we assign functional significance to Tcf-1 as a gatekeeper of T-cell fate. We show that Tcf-1 is directly activated by Notch signals. Tcf-1 is required at the earliest phase of Tcell determination for progression beyond the early thymic progenitor (ETP) stage. The global expression profile of Tcf-1 deficient progenitors indicates that basic processes of DNA metabolism are downregulated in its absence and the blocked T-cell progenitors become abortive and die by apoptosis. Our data thus add an important functional relationship to the roadmap of T-cell development. We used microarrays to detail the global programme of gene expression of mouse ETP thymocyte after Ikaros inactivation with dominant negative of Ik at different stage.

Standard name | GSE33513_TCF7_KO_VS_HET_EARLY_THYMIC_PROGENITOR_DN
Systematic name | M5107
Organism | Mus musculus
PMID | 22109558
Authors | Germar K,Dose M,Konstantinou T,Zhang J,Wang H,Lobry C,Arnett KL,Blacklow SC,Aifantis I,Aster JC,Gounari F.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TCF7 [GeneID=6932] deficient early thymic progenitors versus the TCF7 [GeneID=6932] sufficient ones.
Full description | Although transcriptional programs associated with T-cell specification and commitment have been described, the functional hierarchy and the roles of key regulators in structuring/ orchestrating these programs remain unclear. Activation of Notch signaling in uncommitted precursors by the thymic stroma initiates the T-cell differentiation program. One regulator first induced in these precursors is the DNA binding protein Tcf-1, a T-cell specific mediator of Wnt signaling. Yet the specific contribution of Tcf-1 to early T-cell development and the signals inducing it in these cells remain unclear. Here we assign functional significance to Tcf-1 as a gatekeeper of T-cell fate. We show that Tcf-1 is directly activated by Notch signals. Tcf-1 is required at the earliest phase of Tcell determination for progression beyond the early thymic progenitor (ETP) stage. The global expression profile of Tcf-1 deficient progenitors indicates that basic processes of DNA metabolism are downregulated in its absence and the blocked T-cell progenitors become abortive and die by apoptosis. Our data thus add an important functional relationship to the roadmap of T-cell development. We used microarrays to detail the global programme of gene expression of mouse ETP thymocyte after Ikaros inactivation with dominant negative of Ik at different stage.

Standard name | GSE339_CD4POS_VS_CD8POS_DC_UP
Systematic name | M5108
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] dendritic cells (DC) versus CD8 DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD4POS_VS_CD8POS_DC_DN
Systematic name | M5112
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] dendritic cells (DC) versus CD8 DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD4POS_VS_CD4CD8DN_DC_UP
Systematic name | M5114
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] dendritic cells (DC) versus CD4- [GeneID=920] CD8- DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD4POS_VS_CD4CD8DN_DC_DN
Systematic name | M5116
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] dendritic cells (DC) versus CD4- [GeneID=920] CD8- DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD8POS_VS_CD4CD8DN_DC_UP
Systematic name | M5117
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 dendritic cells (DC) versus CD4- [GeneID=920] CD8- DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD8POS_VS_CD4CD8DN_DC_DN
Systematic name | M5118
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 dendritic cells (DC) versus CD4- [GeneID=920] CD8- DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD4POS_VS_CD8POS_DC_IN_CULTURE_UP
Systematic name | M5119
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] dendritic cells (DC) versus CD8 DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD4POS_VS_CD8POS_DC_IN_CULTURE_DN
Systematic name | M5120
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] dendritic cells (DC) versus CD8 DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD4POS_VS_CD4CD8DN_DC_IN_CULTURE_UP
Systematic name | M5122
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] dendritic cells (DC) versus CD4- [GeneID=920] CD8- DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD4POS_VS_CD4CD8DN_DC_IN_CULTURE_DN
Systematic name | M5124
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] dendritic cells (DC) versus CD4- [GeneID=920] CD8- DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD8POS_VS_CD4CD8DN_DC_IN_CULTURE_UP
Systematic name | M5127
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD8 dendritic cells (DC) versus CD4- [GeneID=920] CD8- DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_CD8POS_VS_CD4CD8DN_DC_IN_CULTURE_DN
Systematic name | M5128
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD8 dendritic cells (DC) versus CD4- [GeneID=920] CD8- DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_EX_VIVO_VS_IN_CULTURE_CD4POS_DC_UP
Systematic name | M5129
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of ex vivo CD4 [GeneID=920] dendritic cells (DC) versus cultured CD4 [GeneID=920] DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_EX_VIVO_VS_IN_CULTURE_CD4POS_DC_DN
Systematic name | M5130
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of ex vivo CD4 [GeneID=920] dendritic cells (DC) versus cultured CD4 [GeneID=920] DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_EX_VIVO_VS_IN_CULTURE_CD8POS_DC_UP
Systematic name | M5131
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of ex vivo CD8 dendritic cells versus cultured CD8 DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_EX_VIVO_VS_IN_CULTURE_CD8POS_DC_DN
Systematic name | M5132
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of ex vivo CD8 dendritic cells versus cultured CD8 DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_EX_VIVO_VS_IN_CULTURE_CD4CD8DN_DC_UP
Systematic name | M5134
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of ex vivo CD4- [GeneID=920] CD8- dendritic cells (DC) versus cultured CD4- [GeneID=920] CD8- DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE339_EX_VIVO_VS_IN_CULTURE_CD4CD8DN_DC_DN
Systematic name | M5135
Organism | Mus musculus
PMID | 12816982
Authors | Edwards AD,Chaussabel D,Tomlinson S,Schulz O,Sher A,Reis e Sousa C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of ex vivo CD4- [GeneID=920] CD8- dendritic cells (DC) versus cultured CD4- [GeneID=920] CD8- DCs.
Full description | The functional relationships and properties of different sub-types of dendritic cells (DC) remain largely undefined. We used a global gene profiling approach to determine gene expression patterns among murine splenic CD11c high DC subsets in an effort to better characterise these cells.

Standard name | GSE34205_HEALTHY_VS_RSV_INF_INFANT_PBMC_UP
Systematic name | M5136
Organism | Homo sapiens
PMID | 22398282
Authors | Ioannidis I,McNally B,Willette M,Peeples ME,Chaussabel D,Durbin JE,Ramilo O,Mejias A,Flaño E
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from infanct with acute RSV infection.
Full description | To study the transcriptional profile of patients with acute RSV or Influenza infection,children of median age 2.4 months (range 1.5-8.6) hospitalized with acute RSV and influenza virus infection were offered study enrollment after microbiologic confirmation of the diagnosis. Blood samples were collected from them within 42-72 hours of hospitalization. We excluded children with suspected or proven polymicrobial infections, with underlying chronic medical conditions (i.e congenital heart disease, renal insufficiency), with immunodeficiency, or those who received systemic steroids or other immunomodulatory therapies. The RSV cohort consisted of 51 patients with median age of 2 months (range 1.5-3.9) and the influenza cohort had 28 patients with median age of 5.5 months (range 1.4-21). Control samples were obtained from healthy children undergoing elective surgical procedures or at outpatient clinic visits. To exclude viral co-infections we performed nasopharyngeal viral cultures of all subjects. We recruited 10 control patients for the RSV cohort with median age of 6.7 months (range 5-10), and 12 control patients for the influenza cohort with median age of18.5 months (range 10.5-26).

Standard name | GSE34205_HEALTHY_VS_RSV_INF_INFANT_PBMC_DN
Systematic name | M5137
Organism | Homo sapiens
PMID | 22398282
Authors | Ioannidis I,McNally B,Willette M,Peeples ME,Chaussabel D,Durbin JE,Ramilo O,Mejias A,Flaño E
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from infanct with acute RSV infection.
Full description | To study the transcriptional profile of patients with acute RSV or Influenza infection,children of median age 2.4 months (range 1.5-8.6) hospitalized with acute RSV and influenza virus infection were offered study enrollment after microbiologic confirmation of the diagnosis. Blood samples were collected from them within 42-72 hours of hospitalization. We excluded children with suspected or proven polymicrobial infections, with underlying chronic medical conditions (i.e congenital heart disease, renal insufficiency), with immunodeficiency, or those who received systemic steroids or other immunomodulatory therapies. The RSV cohort consisted of 51 patients with median age of 2 months (range 1.5-3.9) and the influenza cohort had 28 patients with median age of 5.5 months (range 1.4-21). Control samples were obtained from healthy children undergoing elective surgical procedures or at outpatient clinic visits. To exclude viral co-infections we performed nasopharyngeal viral cultures of all subjects. We recruited 10 control patients for the RSV cohort with median age of 6.7 months (range 5-10), and 12 control patients for the influenza cohort with median age of18.5 months (range 10.5-26).

Standard name | GSE34205_HEALTHY_VS_FLU_INF_INFANT_PBMC_UP
Systematic name | M5138
Organism | Homo sapiens
PMID | 22398282
Authors | Ioannidis I,McNally B,Willette M,Peeples ME,Chaussabel D,Durbin JE,Ramilo O,Mejias A,Flaño E
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from infanct with acute influenza infection.
Full description | To study the transcriptional profile of patients with acute RSV or Influenza infection,children of median age 2.4 months (range 1.5-8.6) hospitalized with acute RSV and influenza virus infection were offered study enrollment after microbiologic confirmation of the diagnosis. Blood samples were collected from them within 42-72 hours of hospitalization. We excluded children with suspected or proven polymicrobial infections, with underlying chronic medical conditions (i.e congenital heart disease, renal insufficiency), with immunodeficiency, or those who received systemic steroids or other immunomodulatory therapies. The RSV cohort consisted of 51 patients with median age of 2 months (range 1.5-3.9) and the influenza cohort had 28 patients with median age of 5.5 months (range 1.4-21). Control samples were obtained from healthy children undergoing elective surgical procedures or at outpatient clinic visits. To exclude viral co-infections we performed nasopharyngeal viral cultures of all subjects. We recruited 10 control patients for the RSV cohort with median age of 6.7 months (range 5-10), and 12 control patients for the influenza cohort with median age of18.5 months (range 10.5-26).

Standard name | GSE34205_HEALTHY_VS_FLU_INF_INFANT_PBMC_DN
Systematic name | M5139
Organism | Homo sapiens
PMID | 22398282
Authors | Ioannidis I,McNally B,Willette M,Peeples ME,Chaussabel D,Durbin JE,Ramilo O,Mejias A,Flaño E
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from infanct with acute influenza infection.
Full description | To study the transcriptional profile of patients with acute RSV or Influenza infection,children of median age 2.4 months (range 1.5-8.6) hospitalized with acute RSV and influenza virus infection were offered study enrollment after microbiologic confirmation of the diagnosis. Blood samples were collected from them within 42-72 hours of hospitalization. We excluded children with suspected or proven polymicrobial infections, with underlying chronic medical conditions (i.e congenital heart disease, renal insufficiency), with immunodeficiency, or those who received systemic steroids or other immunomodulatory therapies. The RSV cohort consisted of 51 patients with median age of 2 months (range 1.5-3.9) and the influenza cohort had 28 patients with median age of 5.5 months (range 1.4-21). Control samples were obtained from healthy children undergoing elective surgical procedures or at outpatient clinic visits. To exclude viral co-infections we performed nasopharyngeal viral cultures of all subjects. We recruited 10 control patients for the RSV cohort with median age of 6.7 months (range 5-10), and 12 control patients for the influenza cohort with median age of18.5 months (range 10.5-26).

Standard name | GSE34205_RSV_VS_FLU_INF_INFANT_PBMC_UP
Systematic name | M5141
Organism | Homo sapiens
PMID | 22398282
Authors | Ioannidis I,McNally B,Willette M,Peeples ME,Chaussabel D,Durbin JE,Ramilo O,Mejias A,Flaño E
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from infancts with acute RSV infection versus PBMCs from infants with acute influenza infection.
Full description | To study the transcriptional profile of patients with acute RSV or Influenza infection,children of median age 2.4 months (range 1.5-8.6) hospitalized with acute RSV and influenza virus infection were offered study enrollment after microbiologic confirmation of the diagnosis. Blood samples were collected from them within 42-72 hours of hospitalization. We excluded children with suspected or proven polymicrobial infections, with underlying chronic medical conditions (i.e congenital heart disease, renal insufficiency), with immunodeficiency, or those who received systemic steroids or other immunomodulatory therapies. The RSV cohort consisted of 51 patients with median age of 2 months (range 1.5-3.9) and the influenza cohort had 28 patients with median age of 5.5 months (range 1.4-21). Control samples were obtained from healthy children undergoing elective surgical procedures or at outpatient clinic visits. To exclude viral co-infections we performed nasopharyngeal viral cultures of all subjects. We recruited 10 control patients for the RSV cohort with median age of 6.7 months (range 5-10), and 12 control patients for the influenza cohort with median age of18.5 months (range 10.5-26).

Standard name | GSE34205_RSV_VS_FLU_INF_INFANT_PBMC_DN
Systematic name | M5142
Organism | Homo sapiens
PMID | 22398282
Authors | Ioannidis I,McNally B,Willette M,Peeples ME,Chaussabel D,Durbin JE,Ramilo O,Mejias A,Flaño E
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from infancts with acute RSV infection versus PBMCs from infants with acute influenza infection.
Full description | To study the transcriptional profile of patients with acute RSV or Influenza infection,children of median age 2.4 months (range 1.5-8.6) hospitalized with acute RSV and influenza virus infection were offered study enrollment after microbiologic confirmation of the diagnosis. Blood samples were collected from them within 42-72 hours of hospitalization. We excluded children with suspected or proven polymicrobial infections, with underlying chronic medical conditions (i.e congenital heart disease, renal insufficiency), with immunodeficiency, or those who received systemic steroids or other immunomodulatory therapies. The RSV cohort consisted of 51 patients with median age of 2 months (range 1.5-3.9) and the influenza cohort had 28 patients with median age of 5.5 months (range 1.4-21). Control samples were obtained from healthy children undergoing elective surgical procedures or at outpatient clinic visits. To exclude viral co-infections we performed nasopharyngeal viral cultures of all subjects. We recruited 10 control patients for the RSV cohort with median age of 6.7 months (range 5-10), and 12 control patients for the influenza cohort with median age of18.5 months (range 10.5-26).

Standard name | GSE360_CTRL_VS_L_DONOVANI_DC_UP
Systematic name | M5143
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated dendritic cells (DC) versus DCs exposed to parasite L. donovani.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_L_DONOVANI_DC_DN
Systematic name | M5144
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated dendritic cells (DC) versus DCs exposed to parasite L. donovani.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_L_MAJOR_DC_UP
Systematic name | M5145
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated dendritic cells (DC) versus DCs exposed to parasite L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_L_MAJOR_DC_DN
Systematic name | M5146
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated dendritic cells (DC) versus DCs exposed to parasite L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_T_GONDII_DC_UP
Systematic name | M5147
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated dendritic cells (DC) versus DCs exposed to parasite Toxoplasma gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_T_GONDII_DC_DN
Systematic name | M5148
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated dendritic cells (DC) versus DCs exposed to parasite Toxoplasma gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_B_MALAYI_HIGH_DOSE_DC_UP
Systematic name | M5150
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus DCs exposed to B. malayi (50 worms/well).
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_B_MALAYI_HIGH_DOSE_DC_DN
Systematic name | M5151
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus DCs exposed to B. malayi (50 worms/well).
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_B_MALAYI_LOW_DOSE_DC_UP
Systematic name | M5152
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus DCs exposed to B. malayi (5 worms/well).
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_B_MALAYI_LOW_DOSE_DC_DN
Systematic name | M5153
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus DCs exposed to B. malayi (5 worms/well).
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_M_TUBERCULOSIS_DC_UP
Systematic name | M5154
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus DCs exposed to M.tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_M_TUBERCULOSIS_DC_DN
Systematic name | M5156
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus DCs exposed to M.tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_L_DONOVANI_MAC_UP
Systematic name | M5157
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus macrophages exposed to L.donovani.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_L_DONOVANI_MAC_DN
Systematic name | M5159
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus macrophages exposed to L.donovani.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_L_MAJOR_MAC_UP
Systematic name | M5160
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus macrophages exposed to L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_L_MAJOR_MAC_DN
Systematic name | M5161
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus macrophages exposed to L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_T_GONDII_MAC_UP
Systematic name | M5162
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus macrophages exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_T_GONDII_MAC_DN
Systematic name | M5163
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus macrophages exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_B_MALAYI_HIGH_DOSE_MAC_UP
Systematic name | M5165
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus macrophages exposed to B. malayi (50 worms/well).
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_B_MALAYI_HIGH_DOSE_MAC_DN
Systematic name | M5167
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus macrophages exposed to B. malayi (50 worms/well).
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_B_MALAYI_LOW_DOSE_MAC_UP
Systematic name | M5168
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus macrophages exposed to B. malayi (5 worms/well).
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_B_MALAYI_LOW_DOSE_MAC_DN
Systematic name | M5169
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus macrophages exposed to B. malayi (5 worms/well).
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_M_TUBERCULOSIS_MAC_UP
Systematic name | M5170
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_CTRL_VS_M_TUBERCULOSIS_MAC_DN
Systematic name | M5171
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_UP
Systematic name | M5172
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus untreated macrophages.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_DN
Systematic name | M5173
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus untreated macrophages.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_L_DONOVANI_UP
Systematic name | M5174
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus macrophages exposed to L. donovani.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_L_DONOVANI_DN
Systematic name | M5176
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus macrophages exposed to L. donovani.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_L_MAJOR_UP
Systematic name | M5181
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells exposed to L. major versus macrophages exposed to L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_L_MAJOR_DN
Systematic name | M5182
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells exposed to L. major versus macrophages exposed to L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_T_GONDII_UP
Systematic name | M5183
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to T. gondii versus macrophages exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_T_GONDII_DN
Systematic name | M5184
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to T. gondii versus macrophages exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_B_MALAYI_HIGH_DOSE_UP
Systematic name | M5185
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to 50 worm/well B. malayi versus macrophages exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_B_MALAYI_HIGH_DOSE_DN
Systematic name | M5186
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to 50 worm/well B. malayi versus macrophages exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_B_MALAYI_LOW_DOSE_UP
Systematic name | M5187
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to 5 worm/well B. malayi versus macrophages exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_B_MALAYI_LOW_DOSE_DN
Systematic name | M5188
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to 5 worm/well B. malayi versus macrophages exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_M_TUBERCULOSIS_UP
Systematic name | M5189
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to M. tuberculosis versus macrophages exposed to L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_DC_VS_MAC_M_TUBERCULOSIS_DN
Systematic name | M5191
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to M. tuberculosis versus macrophages exposed to L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_L_MAJOR_DC_UP
Systematic name | M5192
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus DCs exposed to L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_L_MAJOR_DC_DN
Systematic name | M5194
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus DCs exposed to L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_T_GONDII_DC_UP
Systematic name | M5195
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus DCs exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_T_GONDII_DC_DN
Systematic name | M5196
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus DCs exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_B_MALAYI_HIGH_DOSE_DC_UP
Systematic name | M5197
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus DCs exposed to 50 worm/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_B_MALAYI_HIGH_DOSE_DC_DN
Systematic name | M5201
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus DCs exposed to 50 worm/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_B_MALAYI_LOW_DOSE_DC_UP
Systematic name | M5203
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus DCs exposed to 5 worm/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_B_MALAYI_LOW_DOSE_DC_DN
Systematic name | M5204
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus DCs exposed to 5 worm/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_M_TUBERCULOSIS_DC_UP
Systematic name | M5205
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus DCs exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_M_TUBERCULOSIS_DC_DN
Systematic name | M5206
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to L. donovani versus DCs exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_T_GONDII_DC_UP
Systematic name | M5207
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to L. major versus DCs exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_T_GONDII_DC_DN
Systematic name | M5208
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to L. major versus DCs exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_B_MALAYI_HIGH_DOSE_DC_UP
Systematic name | M5209
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to L. major versus DCs exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_B_MALAYI_HIGH_DOSE_DC_DN
Systematic name | M5210
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to L. major versus DCs exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_B_MALAYI_LOW_DOSE_DC_UP
Systematic name | M5211
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to L. major versus DCs exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_B_MALAYI_LOW_DOSE_DC_DN
Systematic name | M5212
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to L. major versus DCs exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_M_TUBERCULOSIS_DC_UP
Systematic name | M5213
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to L. major versus DCs exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_M_TUBERCULOSIS_DC_DN
Systematic name | M5214
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to L. major versus DCs exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_B_MALAYI_HIGH_DOSE_DC_UP
Systematic name | M5215
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to T. gondii versus DCs exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_B_MALAYI_HIGH_DOSE_DC_DN
Systematic name | M5216
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to T. gondii versus DCs exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_B_MALAYI_LOW_DOSE_DC_UP
Systematic name | M5217
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to T. gondii versus DCs exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_B_MALAYI_LOW_DOSE_DC_DN
Systematic name | M5219
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to T. gondii versus DCs exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_M_TUBERCULOSIS_DC_UP
Systematic name | M5220
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to T. gondii versus DCs exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_M_TUBERCULOSIS_DC_DN
Systematic name | M5221
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to T. gondii versus DCs exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_HIGH_VS_LOW_DOSE_B_MALAYI_DC_UP
Systematic name | M5222
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to 50 worms/well B. malayi versus those exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_HIGH_VS_LOW_DOSE_B_MALAYI_DC_DN
Systematic name | M5225
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to 50 worms/well B. malayi versus those exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_HIGH_DOSE_B_MALAYI_VS_M_TUBERCULOSIS_DC_UP
Systematic name | M5227
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to 50 worms/well B. malayi versus DC exposed to M. tuberculosis
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_HIGH_DOSE_B_MALAYI_VS_M_TUBERCULOSIS_DC_DN
Systematic name | M5228
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to 50 worms/well B. malayi versus DC exposed to M. tuberculosis
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_LOW_DOSE_B_MALAYI_VS_M_TUBERCULOSIS_DC_UP
Systematic name | M5229
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) exposed to 5 worms/well B. malayi versus DC exposed to M. tuberculosis
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_LOW_DOSE_B_MALAYI_VS_M_TUBERCULOSIS_DC_DN
Systematic name | M5230
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) exposed to 5 worms/well B. malayi versus DC exposed to M. tuberculosis
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_L_MAJOR_MAC_UP
Systematic name | M5231
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to L. donovani versus macrophages exposed to L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_L_MAJOR_MAC_DN
Systematic name | M5232
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to L. donovani versus macrophages exposed to L. major.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_T_GONDII_MAC_UP
Systematic name | M5233
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to L. donovani versus macrophages exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_T_GONDII_MAC_DN
Systematic name | M5234
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to L. donovani versus macrophages exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_B_MALAYI_HIGH_DOSE_MAC_UP
Systematic name | M5235
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to L. donovani versus macrophages exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_B_MALAYI_HIGH_DOSE_MAC_DN
Systematic name | M5237
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to L. donovani versus macrophages exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_B_MALAYI_LOW_DOSE_MAC_UP
Systematic name | M5239
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to L. donovani versus macrophages exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_B_MALAYI_LOW_DOSE_MAC_DN
Systematic name | M5240
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to L. donovani versus macrophages exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_M_TUBERCULOSIS_MAC_UP
Systematic name | M5241
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to L. donovani versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_DONOVANI_VS_M_TUBERCULOSIS_MAC_DN
Systematic name | M5242
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to L. donovani versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_T_GONDII_MAC_UP
Systematic name | M5243
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to L. major versus macrophages exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_T_GONDII_MAC_DN
Systematic name | M5246
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to L. major versus macrophages exposed to T. gondii.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_B_MALAYI_HIGH_DOSE_MAC_UP
Systematic name | M5247
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to L. major versus macrophages exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_B_MALAYI_HIGH_DOSE_MAC_DN
Systematic name | M5249
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to L. major versus macrophages exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_B_MALAYI_LOW_DOSE_MAC_UP
Systematic name | M5250
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to L. major versus macrophages exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_B_MALAYI_LOW_DOSE_MAC_DN
Systematic name | M5251
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to L. major versus macrophages exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_M_TUBERCULOSIS_MAC_UP
Systematic name | M5252
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to L. major versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_L_MAJOR_VS_M_TUBERCULOSIS_MAC_DN
Systematic name | M5253
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to L. major versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_B_MALAYI_HIGH_DOSE_MAC_UP
Systematic name | M5254
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to T. gondii versus macrophages exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_B_MALAYI_HIGH_DOSE_MAC_DN
Systematic name | M5255
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to T. gondii versus macrophages exposed to 50 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_B_MALAYI_LOW_DOSE_MAC_UP
Systematic name | M5256
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to T. gondii versus macrophages exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_B_MALAYI_LOW_DOSE_MAC_DN
Systematic name | M5257
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to T. gondii versus macrophages exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_M_TUBERCULOSIS_MAC_UP
Systematic name | M5258
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to T. gondii versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_T_GONDII_VS_M_TUBERCULOSIS_MAC_DN
Systematic name | M5259
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to T. gondii versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_HIGH_VS_LOW_DOSE_B_MALAYI_MAC_UP
Systematic name | M5261
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to 50 worms/well B. malayi versus those exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_HIGH_VS_LOW_DOSE_B_MALAYI_MAC_DN
Systematic name | M5262
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to 50 worms/well B. malayi versus those exposed to 5 worms/well B. malayi.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_HIGH_DOSE_B_MALAYI_VS_M_TUBERCULOSIS_MAC_UP
Systematic name | M5263
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to 50 worms/well B. malayi versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_HIGH_DOSE_B_MALAYI_VS_M_TUBERCULOSIS_MAC_DN
Systematic name | M5264
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to 50 worms/well B. malayi versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_LOW_DOSE_B_MALAYI_VS_M_TUBERCULOSIS_MAC_UP
Systematic name | M5266
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages exposed to 5 worms/well B. malayi versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE360_LOW_DOSE_B_MALAYI_VS_M_TUBERCULOSIS_MAC_DN
Systematic name | M5268
Organism | Homo sapiens
PMID | 12663451
Authors | Chaussabel D,Semnani RT,McDowell MA,Sacks D,Sher A,Nutman TB.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages exposed to 5 worms/well B. malayi versus macrophages exposed to M. tuberculosis.
Full description | Monocyte-derived dendritic cells (DC) and macrophages (MΦ) generated in vitro from the same individual blood donors were exposed to five different pathogens, and gene expression profiles were assessed by microarray analysis. Responses to Mycobacterium tuberculosis and to phylogenetically distinct protozoan (Leishmania major, L. donovani, Toxoplasma gondii) and helminth (Brugia malayi) parasites were examined, each of which produces chronic infections in humans yet vary considerably in the nature of the immune responses they trigger.

Standard name | GSE36392_TYPE_2_MYELOID_VS_EOSINOPHIL_IL25_TREATED_LUNG_UP
Systematic name | M5270
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of type 2 myeloid (T2M) cells treated with IL25 [GeneID=64806] versus eosinophils treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_TYPE_2_MYELOID_VS_EOSINOPHIL_IL25_TREATED_LUNG_DN
Systematic name | M5271
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of type 2 myeloid (T2M) cells treated with IL25 [GeneID=64806] versus eosinophils treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_TYPE_2_MYELOID_VS_MAC_IL25_TREATED_LUNG_UP
Systematic name | M5273
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of type 2 myeloid (T2M) cells treated with IL25 [GeneID=64806] versus macrophages treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_TYPE_2_MYELOID_VS_MAC_IL25_TREATED_LUNG_DN
Systematic name | M5274
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of type 2 myeloid (T2M) cells treated with IL25 [GeneID=64806] versus macrophages treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_TYPE_2_MYELOID_VS_NEUTROPHIL_IL25_TREATED_LUNG_UP
Systematic name | M5276
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of type 2 myeloid (T2M) cells treated with IL25 [GeneID=64806] versus neutrophils treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_TYPE_2_MYELOID_VS_NEUTROPHIL_IL25_TREATED_LUNG_DN
Systematic name | M5277
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of type 2 myeloid (T2M) cells treated with IL25 [GeneID=64806] versus neutrophils treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_EOSINOPHIL_VS_MAC_IL25_TREATED_LUNG_UP
Systematic name | M5280
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils treated with IL25 [GeneID=64806] versus macrophages treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_EOSINOPHIL_VS_MAC_IL25_TREATED_LUNG_DN
Systematic name | M5281
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils treated with IL25 [GeneID=64806] versus macrophages treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_EOSINOPHIL_VS_NEUTROPHIL_IL25_TREATED_LUNG_UP
Systematic name | M5282
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils treated with IL25 [GeneID=64806] versus neutrophils treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_EOSINOPHIL_VS_NEUTROPHIL_IL25_TREATED_LUNG_DN
Systematic name | M5284
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils treated with IL25 [GeneID=64806] versus neutrophils treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_MAC_VS_NEUTROPHIL_IL25_TREATED_LUNG_UP
Systematic name | M5285
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages treated with IL25 [GeneID=64806] versus neutrophils treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36392_MAC_VS_NEUTROPHIL_IL25_TREATED_LUNG_DN
Systematic name | M5286
Organism | Mus musculus
PMID | 22543263
Authors | Petersen BC,Budelsky AL,Baptist AP,Schaller MA,Lukacs NW.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages treated with IL25 [GeneID=64806] versus neutrophils treated with IL25 [GeneID=64806].
Full description | Many symptoms associated with allergic asthma result from the sequelae of type 2 inflammation. Interleukin (IL)-25 promotes type 2 inflammatory responses, and T2M cells represent an IL-4 and IL-13 producing granulocytic IL-25 responsive population. We used microarrays to characterize the gene expression profile of T2M cells, and compared T2M cells to other inflammatory subsets (eosinophils, neutrophils, and macrophages) in the lungs of mice with IL-25-induced pulmonary inflammation.

Standard name | GSE36476_CTRL_VS_TSST_ACT_16H_MEMORY_CD4_TCELL_YOUNG_UP
Systematic name | M5287
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from young donors versus those treated with TSST at 16 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_16H_MEMORY_CD4_TCELL_YOUNG_DN
Systematic name | M5288
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from young donors versus those treated with TSST at 16 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_40H_MEMORY_CD4_TCELL_YOUNG_UP
Systematic name | M5289
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from young donors versus those treated with TSST at 40 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_40H_MEMORY_CD4_TCELL_YOUNG_DN
Systematic name | M5292
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from young donors versus those treated with TSST at 40 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_72H_MEMORY_CD4_TCELL_YOUNG_UP
Systematic name | M5293
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from young donors versus those treated with TSST at 72 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_72H_MEMORY_CD4_TCELL_YOUNG_DN
Systematic name | M5294
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from young donors versus those treated with TSST at 72 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_16H_MEMORY_CD4_TCELL_OLD_UP
Systematic name | M5295
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from old donors versus those treated with TSST at 16 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_16H_MEMORY_CD4_TCELL_OLD_DN
Systematic name | M5296
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from old donors versus those treated with TSST at 16 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_40H_MEMORY_CD4_TCELL_OLD_UP
Systematic name | M5299
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from old donors versus those treated with TSST at 40 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_40H_MEMORY_CD4_TCELL_OLD_DN
Systematic name | M5300
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from old donors versus those treated with TSST at 40 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_72H_MEMORY_CD4_TCELL_OLD_UP
Systematic name | M5302
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from old donors versus those treated with TSST at 72 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_CTRL_VS_TSST_ACT_72H_MEMORY_CD4_TCELL_OLD_DN
Systematic name | M5303
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] memory T cells from old donors versus those treated with TSST at 72 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_YOUNG_VS_OLD_DONOR_MEMORY_CD4_TCELL_UP
Systematic name | M5306
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated memory CD4 [GeneID=920] T cells from young donors versus those from old donors.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_YOUNG_VS_OLD_DONOR_MEMORY_CD4_TCELL_DN
Systematic name | M5307
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated memory CD4 [GeneID=920] T cells from young donors versus those from old donors.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_YOUNG_VS_OLD_DONOR_MEMORY_CD4_TCELL_16H_TSST_ACT_UP
Systematic name | M5313
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD4 [GeneID=920] T cells from young donors treated with TSST at 16 h versus those from old donors treated with TSST at 16 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_YOUNG_VS_OLD_DONOR_MEMORY_CD4_TCELL_16H_TSST_ACT_DN
Systematic name | M5317
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD4 [GeneID=920] T cells from young donors treated with TSST at 16 h versus those from old donors treated with TSST at 16 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_YOUNG_VS_OLD_DONOR_MEMORY_CD4_TCELL_40H_TSST_ACT_UP
Systematic name | M5318
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD4 [GeneID=920] T cells from young donors treated with TSST at 40 h versus those from old donors treated with TSST at 40 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_YOUNG_VS_OLD_DONOR_MEMORY_CD4_TCELL_40H_TSST_ACT_DN
Systematic name | M5322
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD4 [GeneID=920] T cells from young donors treated with TSST at 40 h versus those from old donors treated with TSST at 40 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_YOUNG_VS_OLD_DONOR_MEMORY_CD4_TCELL_72H_TSST_ACT_UP
Systematic name | M5323
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD4 [GeneID=920] T cells from young donors treated with TSST at 72 h versus those from old donors treated with TSST at 72 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE36476_YOUNG_VS_OLD_DONOR_MEMORY_CD4_TCELL_72H_TSST_ACT_DN
Systematic name | M5324
Organism | Homo sapiens
PMID | 22434910
Authors | Yu M,Li G,Lee WW,Yuan M,Cui D,Weyand CM,Goronzy JJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD4 [GeneID=920] T cells from young donors treated with TSST at 72 h versus those from old donors treated with TSST at 72 h.
Full description | With increasing age, the ability of the immune system to protect against recurring infections or to control chronic infections erodes. The objective of the current study was to identify gene expression signatures in elderly CD4 T cell responses

Standard name | GSE37416_CTRL_VS_0H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5326
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 0 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_0H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5327
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 0 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_3H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5328
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 3 h versus PMN treated with F. tularensis vaccine at 3 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_3H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5330
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 3 h versus PMN treated with F. tularensis vaccine at 3 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_6H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5332
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 6 h versus PMN treated with F. tularensis vaccine at 6 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_6H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5333
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 6 h versus PMN treated with F. tularensis vaccine at 6 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_12H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5334
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 12 h versus PMN treated with F. tularensis vaccine at 12 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_12H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5335
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 12 h versus PMN treated with F. tularensis vaccine at 12 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_24H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5337
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 24 h versus PMN treated with F. tularensis vaccine at 24 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_24H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5338
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 24 h versus PMN treated with F. tularensis vaccine at 24 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_48H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5339
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 48 h versus PMN treated with F. tularensis vaccine at 48 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_CTRL_VS_48H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5340
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 48 h versus PMN treated with F. tularensis vaccine at 48 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_0H_VS_3H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5341
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 3 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_0H_VS_3H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5342
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 3 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_0H_VS_6H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5344
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 6 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_0H_VS_6H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5346
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 6 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_0H_VS_12H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5347
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 12 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_0H_VS_12H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5348
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 12 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_0H_VS_24H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5349
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 24 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_0H_VS_24H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5350
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 24 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_0H_VS_48H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5351
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 48 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_0H_VS_48H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5353
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 0 h versus PMN treated with F. tularensis vaccine at 48 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_12H_VS_24H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5357
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 12 h versus PMN treated with F. tularensis vaccine at 24 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_12H_VS_24H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5358
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 12 h versus PMN treated with F. tularensis vaccine at 24 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_12H_VS_48H_F_TULARENSIS_LVS_NEUTROPHIL_UP
Systematic name | M5359
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 12 h versus PMN treated with F. tularensis vaccine at 48 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE37416_12H_VS_48H_F_TULARENSIS_LVS_NEUTROPHIL_DN
Systematic name | M5361
Organism | Homo sapiens
PMID | 22986450
Authors | Schwartz JT,Bandyopadhyay S,Kobayashi SD,McCracken J,Whitney AR,Deleo FR,Allen LA.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control polymorphonuclear leukocytes (PMN) at 12 h versus PMN treated with F. tularensis vaccine at 48 h.
Full description | We demonstrated recently that both constitutive and FAS-triggered apoptosis of human neutrophils are profoundly impaired by Francisella tularensis, but how this is achieved is largely unknown. To test the hypothesis that changes in neutrophil gene expression contribute to this phenotype, we used human oligonucleotide microarrays to identify differentially regulated genes in cells infected with F. tularensis strain LVS compared with uninfected controls. In order to examine the effect of F. tularensis on the neutrophil transcriptome, we performed microarray expression analysis on human neutrophils treated with F. tularensis subsp. holarctica live vaccine strain (LVS).

Standard name | GSE3982_CTRL_VS_PMA_STIM_EOSINOPHIL_UP
Systematic name | M5363
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated eosinophils versus eosinophils treated with PMA [PubChem=4792] at 2 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CTRL_VS_PMA_STIM_EOSINOPHIL_DN
Systematic name | M5364
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated eosinophils versus eosinophils treated with PMA [PubChem=4792] at 2 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CTRL_VS_IGE_STIM_MAST_CELL_UP
Systematic name | M5365
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated mast cells versus mast cells treated with IgE at 2 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CTRL_VS_IGE_STIM_MAST_CELL_DN
Systematic name | M5366
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated mast cells versus mast cells treated with IgE at 2 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CTRL_VS_LPS_4H_MAC_UP
Systematic name | M5367
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages versus macrophages treated with LPS (TLR4 agonist) at 4 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CTRL_VS_LPS_4H_MAC_DN
Systematic name | M5368
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages versus macrophages treated with LPS (TLR4 agonist) at 4 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CTRL_VS_LPS_1H_NEUTROPHIL_UP
Systematic name | M5371
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated neutrophils versus neutrophils treated with LPS (TLR4 agonist) at 1 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CTRL_VS_LPS_1H_NEUTROPHIL_DN
Systematic name | M5373
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated neutrophils versus neutrophils treated with LPS (TLR4 agonist) at 1 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CTRL_VS_LPS_48H_DC_UP
Systematic name | M5375
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated dendritic cells (DC) versus DCs treated with LPS (TLR4 agonist) at 48 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CTRL_VS_LPS_48H_DC_DN
Systematic name | M5377
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated dendritic cells (DC) versus DCs treated with LPS (TLR4 agonist) at 48 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MEMORY_CD4_TCELL_VS_TH1_UP
Systematic name | M5378
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD4 [GeneID=920] T cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MEMORY_CD4_TCELL_VS_TH1_DN
Systematic name | M5379
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD4 [GeneID=920] T cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MEMORY_CD4_TCELL_VS_TH2_UP
Systematic name | M5381
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD4 [GeneID=920] T cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MEMORY_CD4_TCELL_VS_TH2_DN
Systematic name | M5382
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD4 [GeneID=920] T cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MEMORY_CD4_TCELL_VS_BCELL_UP
Systematic name | M5384
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of memory CD4 [GeneID=920] T cells versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MEMORY_CD4_TCELL_VS_BCELL_DN
Systematic name | M5385
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of memory CD4 [GeneID=920] T cells versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_MAC_LPS_STIM_UP
Systematic name | M5387
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulatd with LPS (TLR4 agonist) at 48 h versus macrophages stimulated with LPS (TLR4 agonist) at 4 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_MAC_LPS_STIM_DN
Systematic name | M5390
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulatd with LPS (TLR4 agonist) at 48 h versus macrophages stimulated with LPS (TLR4 agonist) at 4 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_NEUTROPHIL_LPS_STIM_UP
Systematic name | M5391
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 48 h versus neutrophils stimulated with LPS (TLR4 agonist) at 1 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_NEUTROPHIL_LPS_STIM_DN
Systematic name | M5393
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) stimulated with LPS (TLR4 agonist) at 48 h versus neutrophils stimulated with LPS (TLR4 agonist) at 1 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_NEUTROPHIL_LPS_STIM_UP
Systematic name | M5394
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages stimulated with LPS (TLR4 agonist) at 4 h versus neutrophils stimulated with LPS (TLR4 agonist) at 1 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_NEUTROPHIL_LPS_STIM_DN
Systematic name | M5396
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages stimulated with LPS (TLR4 agonist) at 4 h versus neutrophils stimulated with LPS (TLR4 agonist) at 1 h.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_MAST_CELL_UP
Systematic name | M5397
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus mast cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_MAST_CELL_DN
Systematic name | M5398
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus mast cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_DC_UP
Systematic name | M5399
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus dendritic cells (DC).
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_DC_DN
Systematic name | M5400
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus dendritic cells (DC).
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_MAC_UP
Systematic name | M5401
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus macrophages.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_MAC_DN
Systematic name | M5403
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus macrophages.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_NEUTROPHIL_UP
Systematic name | M5404
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus neutrophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_NEUTROPHIL_DN
Systematic name | M5405
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus neutrophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_BCELL_UP
Systematic name | M5406
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_BCELL_DN
Systematic name | M5411
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_BASOPHIL_UP
Systematic name | M5413
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_BASOPHIL_DN
Systematic name | M5414
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_EFF_MEMORY_CD4_TCELL_UP
Systematic name | M5416
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_EFF_MEMORY_CD4_TCELL_DN
Systematic name | M5417
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_CENT_MEMORY_CD4_TCELL_UP
Systematic name | M5418
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_CENT_MEMORY_CD4_TCELL_DN
Systematic name | M5419
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_NKCELL_UP
Systematic name | M5420
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_NKCELL_DN
Systematic name | M5421
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_TH1_UP
Systematic name | M5422
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_TH1_DN
Systematic name | M5423
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_TH2_UP
Systematic name | M5424
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of eosinophils versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EOSINOPHIL_VS_TH2_DN
Systematic name | M5425
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of eosinophils versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_DC_UP
Systematic name | M5426
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mast cells versus dendritic cells (DC).
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_DC_DN
Systematic name | M5427
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mast cells versus dendritic cells (DC).
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_MAC_UP
Systematic name | M5429
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mast cells versus macrophages.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_MAC_DN
Systematic name | M5431
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mast cells versus macrophages.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_NEUTROPHIL_UP
Systematic name | M5432
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mast cells versus neutrophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_NEUTROPHIL_DN
Systematic name | M5433
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mast cells versus neutrophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_BCELL_UP
Systematic name | M5434
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mast cells versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_BCELL_DN
Systematic name | M5437
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mast cells versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_BASOPHIL_UP
Systematic name | M5438
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mast cells versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_BASOPHIL_DN
Systematic name | M5439
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mast cells versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_EFF_MEMORY_CD4_TCELL_UP
Systematic name | M5441
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mast cells versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_EFF_MEMORY_CD4_TCELL_DN
Systematic name | M5445
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mast cells versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_CENT_MEMORY_CD4_TCELL_UP
Systematic name | M5446
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mast cells versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_CENT_MEMORY_CD4_TCELL_DN
Systematic name | M5448
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mast cells versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_NKCELL_UP
Systematic name | M5450
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mast cells versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_NKCELL_DN
Systematic name | M5452
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mast cells versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_TH1_UP
Systematic name | M5453
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mast cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_TH1_DN
Systematic name | M5454
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mast cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_TH2_UP
Systematic name | M5455
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of mast cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAST_CELL_VS_TH2_DN
Systematic name | M5456
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of mast cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_MAC_UP
Systematic name | M5458
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus macrophages.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_MAC_DN
Systematic name | M5460
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus macrophages.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_NEUTROPHIL_UP
Systematic name | M5461
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus neutrophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_NEUTROPHIL_DN
Systematic name | M5462
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus neutrophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_BCELL_UP
Systematic name | M5463
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_BCELL_DN
Systematic name | M5470
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_BASOPHIL_UP
Systematic name | M5472
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_BASOPHIL_DN
Systematic name | M5473
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_EFF_MEMORY_CD4_TCELL_UP
Systematic name | M5474
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_EFF_MEMORY_CD4_TCELL_DN
Systematic name | M5475
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_CENT_MEMORY_CD4_TCELL_UP
Systematic name | M5476
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_CENT_MEMORY_CD4_TCELL_DN
Systematic name | M5477
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_NKCELL_UP
Systematic name | M5478
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_NKCELL_DN
Systematic name | M5480
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_TH1_UP
Systematic name | M5481
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_TH1_DN
Systematic name | M5482
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_TH2_UP
Systematic name | M5484
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of dendritic cells (DC) versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_DC_VS_TH2_DN
Systematic name | M5486
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of dendritic cells (DC) versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_NEUTROPHIL_UP
Systematic name | M5491
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus neutrophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_NEUTROPHIL_DN
Systematic name | M5492
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus neutrophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_BCELL_UP
Systematic name | M5494
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_BCELL_DN
Systematic name | M5495
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_BASOPHIL_UP
Systematic name | M5496
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_BASOPHIL_DN
Systematic name | M5498
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_EFF_MEMORY_CD4_TCELL_UP
Systematic name | M5503
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_EFF_MEMORY_CD4_TCELL_DN
Systematic name | M5504
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_CENT_MEMORY_CD4_TCELL_UP
Systematic name | M5506
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_CENT_MEMORY_CD4_TCELL_DN
Systematic name | M5507
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_NKCELL_UP
Systematic name | M5508
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_NKCELL_DN
Systematic name | M5509
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_TH1_UP
Systematic name | M5510
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_TH1_DN
Systematic name | M5511
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_TH2_UP
Systematic name | M5513
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of macrophages versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_MAC_VS_TH2_DN
Systematic name | M5514
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of macrophages versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_BCELL_UP
Systematic name | M5515
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of neutrophils versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_BCELL_DN
Systematic name | M5521
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of neutrophils versus B cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_BASOPHIL_UP
Systematic name | M5524
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of neutrophils versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_BASOPHIL_DN
Systematic name | M5525
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of neutrophils versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_EFF_MEMORY_CD4_TCELL_UP
Systematic name | M5526
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of neutrophils versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_EFF_MEMORY_CD4_TCELL_DN
Systematic name | M5527
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of neutrophils versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_CENT_MEMORY_CD4_TCELL_UP
Systematic name | M5528
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of neutrophils versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_CENT_MEMORY_CD4_TCELL_DN
Systematic name | M5529
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of neutrophils versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_NKCELL_UP
Systematic name | M5530
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of neutrophils versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_NKCELL_DN
Systematic name | M5531
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of neutrophils versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_TH1_UP
Systematic name | M5532
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of neutrophils versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_TH1_DN
Systematic name | M5533
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of neutrophils versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_TH2_UP
Systematic name | M5534
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of neutrophils versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NEUTROPHIL_VS_TH2_DN
Systematic name | M5535
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of neutrophils versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_BASOPHIL_UP
Systematic name | M5538
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_BASOPHIL_DN
Systematic name | M5540
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus basophils.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_EFF_MEMORY_CD4_TCELL_UP
Systematic name | M5541
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_EFF_MEMORY_CD4_TCELL_DN
Systematic name | M5543
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_CENT_MEMORY_CD4_TCELL_UP
Systematic name | M5544
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_CENT_MEMORY_CD4_TCELL_DN
Systematic name | M5545
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_NKCELL_UP
Systematic name | M5546
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_NKCELL_DN
Systematic name | M5548
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_TH1_UP
Systematic name | M5551
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_TH1_DN
Systematic name | M5553
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_TH2_UP
Systematic name | M5554
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of B cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BCELL_VS_TH2_DN
Systematic name | M5555
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of B cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BASOPHIL_VS_EFF_MEMORY_CD4_TCELL_UP
Systematic name | M5556
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of basophils versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BASOPHIL_VS_EFF_MEMORY_CD4_TCELL_DN
Systematic name | M5557
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of basophils versus effector memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BASOPHIL_VS_CENT_MEMORY_CD4_TCELL_UP
Systematic name | M5559
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of basophils versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BASOPHIL_VS_CENT_MEMORY_CD4_TCELL_DN
Systematic name | M5560
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of basophils versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BASOPHIL_VS_NKCELL_UP
Systematic name | M5561
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of basophils versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BASOPHIL_VS_NKCELL_DN
Systematic name | M5563
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of basophils versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BASOPHIL_VS_TH1_UP
Systematic name | M5564
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of basophils versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BASOPHIL_VS_TH1_DN
Systematic name | M5565
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of basophils versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BASOPHIL_VS_TH2_UP
Systematic name | M5566
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of basophils versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_BASOPHIL_VS_TH2_DN
Systematic name | M5567
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of basophils versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EFF_MEMORY_VS_CENT_MEMORY_CD4_TCELL_UP
Systematic name | M5569
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effective memory CD4 [GeneID=920] T cells versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EFF_MEMORY_VS_CENT_MEMORY_CD4_TCELL_DN
Systematic name | M5571
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effective memory CD4 [GeneID=920] T cells versus central memory CD4 [GeneID=920] T cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EFF_MEMORY_CD4_TCELL_VS_NKCELL_UP
Systematic name | M5573
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effective memory CD4 [GeneID=920] T cells versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EFF_MEMORY_CD4_TCELL_VS_NKCELL_DN
Systematic name | M5575
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effective memory CD4 [GeneID=920] T cells versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EFF_MEMORY_CD4_TCELL_VS_TH1_UP
Systematic name | M5577
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effective memory CD4 [GeneID=920] T cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EFF_MEMORY_CD4_TCELL_VS_TH1_DN
Systematic name | M5579
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effective memory CD4 [GeneID=920] T cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EFF_MEMORY_CD4_TCELL_VS_TH2_UP
Systematic name | M5580
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effective memory CD4 [GeneID=920] T cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_EFF_MEMORY_CD4_TCELL_VS_TH2_DN
Systematic name | M5582
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effective memory CD4 [GeneID=920] T cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CENT_MEMORY_CD4_TCELL_VS_NKCELL_UP
Systematic name | M5584
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of central memory CD4 [GeneID=920] T cells versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CENT_MEMORY_CD4_TCELL_VS_NKCELL_DN
Systematic name | M5585
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of central memory CD4 [GeneID=920] T cells versus NK cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CENT_MEMORY_CD4_TCELL_VS_TH1_UP
Systematic name | M5586
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of central memory CD4 [GeneID=920] T cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CENT_MEMORY_CD4_TCELL_VS_TH1_DN
Systematic name | M5590
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of central memory CD4 [GeneID=920] T cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CENT_MEMORY_CD4_TCELL_VS_TH2_UP
Systematic name | M5591
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of central memory CD4 [GeneID=920] T cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_CENT_MEMORY_CD4_TCELL_VS_TH2_DN
Systematic name | M5592
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of central memory CD4 [GeneID=920] T cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NKCELL_VS_TH1_UP
Systematic name | M5593
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NK cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NKCELL_VS_TH1_DN
Systematic name | M5595
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NK cells versus Th1 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NKCELL_VS_TH2_UP
Systematic name | M5596
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NK cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE3982_NKCELL_VS_TH2_DN
Systematic name | M5598
Organism | Homo sapiens
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NK cells versus Th2 cells.
Full description | In the present study we used Affymetrix oligonucleotide microarrays to produce gene transcription profiles for the major leukocyte types in humans. This comprehensive dataset enabled us to not only establish which genes were expressed in each leukocyte type, but also which genes were expressed in each subset after activation. The used of a comprehensive dataset of gene profiles from all the major human leukocyte subsets enabled a novel and powerful means for identification of genes associated with single leukocyte subsets, or different immune paradigms.

Standard name | GSE39820_CTRL_VS_IL1B_IL6_CD4_TCELL_UP
Systematic name | M5599
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with IL1B [GeneID=3553] and IL6 [GeneID=3569].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_IL1B_IL6_CD4_TCELL_DN
Systematic name | M5600
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with IL1B [GeneID=3553] and IL6 [GeneID=3569].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_IL1B_IL6_IL23A_CD4_TCELL_UP
Systematic name | M5602
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated witl IL1B [GeneID=3553], IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_IL1B_IL6_IL23A_CD4_TCELL_DN
Systematic name | M5603
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with IL1B [GeneID=3553], IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_TGFBETA1_IL6_CD4_TCELL_UP
Systematic name | M5604
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with TGFB1 [GeneID=7040] and IL6 [GeneID=3569].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_TGFBETA1_IL6_CD4_TCELL_DN
Systematic name | M5606
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with TGFB1 [GeneID=7040] and IL6 [GeneID=3569].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_TGFBETA1_IL6_IL23A_CD4_TCELL_UP
Systematic name | M5607
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with TGFB1 [GeneID=7040], IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_TGFBETA1_IL6_IL23A_CD4_TCELL_DN
Systematic name | M5609
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with TGFB1 [GeneID=7040], IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_TGFBETA3_IL6_CD4_TCELL_UP
Systematic name | M5610
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with TGFB3 [GeneID=7043] IL6 [GeneID=3569].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_TGFBETA3_IL6_CD4_TCELL_DN
Systematic name | M5612
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with TGFB3 [GeneID=7043] IL6 [GeneID=3569].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_TGFBETA3_IL6_IL23A_CD4_TCELL_UP
Systematic name | M5613
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with TGFB3 [GeneID=7043], IL6 [GeneID=3569] and IL32A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_CTRL_VS_TGFBETA3_IL6_IL23A_CD4_TCELL_DN
Systematic name | M5614
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells versus those treated with TGFB3 [GeneID=7043], IL6 [GeneID=3569] and IL32A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_IL1B_IL6_VS_IL1B_IL6_IL23A_TREATED_CD4_TCELL_UP
Systematic name | M5615
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated CD4 [GeneID=920] T cells treated with IL1B [GeneID=3553] and IL6 [GeneID=3569] versus those treated with IL1B [GeneID=3553], IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_IL1B_IL6_VS_IL1B_IL6_IL23A_TREATED_CD4_TCELL_DN
Systematic name | M5616
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated CD4 [GeneID=920] T cells treated with IL1B [GeneID=3553] and IL6 [GeneID=3569] versus those treated with IL1B [GeneID=3553], IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_TGFBETA1_IL6_VS_TGFBETA1_IL6_IL23A_TREATED_CD4_TCELL_UP
Systematic name | M5617
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with TGFB1 [GeneID=7040] and IL6 [GeneID=3569] versus those treated with TGFB1 [GeneID=7040], IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_TGFBETA1_IL6_VS_TGFBETA1_IL6_IL23A_TREATED_CD4_TCELL_DN
Systematic name | M5619
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with TGFB1 [GeneID=7040] and IL6 [GeneID=3569] versus those treated with TGFB1 [GeneID=7040], IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_TGFBETA3_IL6_VS_TGFBETA3_IL6_IL23A_TREATED_CD4_TCELL_UP
Systematic name | M5620
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with TGFB3 [GeneID=7043] and IL6 [GeneID=3569] versus those treated with TGF3B [GeneID=7043], IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_TGFBETA3_IL6_VS_TGFBETA3_IL6_IL23A_TREATED_CD4_TCELL_DN
Systematic name | M5621
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with TGFB3 [GeneID=7043] and IL6 [GeneID=3569] versus those treated with TGF3B [GeneID=7043], IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_TGFBETA1_VS_TGFBETA3_IN_IL6_TREATED_CD4_TCELL_UP
Systematic name | M5623
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with TGFB1 [GeneID=7040] versus those treated with TGFB3 [GeneID=7043] and IL6 [GeneID=3569].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_TGFBETA1_VS_TGFBETA3_IN_IL6_TREATED_CD4_TCELL_DN
Systematic name | M5626
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with TGFB1 [GeneID=7040] versus those treated with TGFB3 [GeneID=7043] and IL6 [GeneID=3569].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_TGFBETA1_VS_TGFBETA3_IN_IL6_IL23A_TREATED_CD4_TCELL_UP
Systematic name | M5627
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CD4 [GeneID=920] T cells treated with TGFB1 [GeneID=7040] versus those treated with TGFB3 [GeneID=7043] treated with IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE39820_TGFBETA1_VS_TGFBETA3_IN_IL6_IL23A_TREATED_CD4_TCELL_DN
Systematic name | M5629
Organism | Mus musculus
PMID | 22961052
Authors | Lee Y,Awasthi A,Yosef N,Quintana FJ,Xiao S,Peters A,Wu C,Kleinewietfeld M,Kunder S,Hafler DA,Sobel RA,Regev A,Kuchroo VK.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CD4 [GeneID=920] T cells treated with TGFB1 [GeneID=7040] versus those treated with TGFB3 [GeneID=7043] treated with IL6 [GeneID=3569] and IL23A [GeneID=51561].
Full description | TGF-beta3 produced by developing Th17 cells induces highly pathogenic T cells that are functionally and molecularly distinct from TGF-beta1-induced Th17 cells. The microarray data represent a distinct molecular signature for pathogenic versus non-pathogenic Th17 cells.

Standard name | GSE5463_CTRL_VS_DEXAMETHASONE_TREATED_THYMOCYTE_UP
Systematic name | M5630
Organism | Mus musculus
PMID | 16914556
Authors | Bianchini R,Nocentini G,Krausz LT,Fettucciari K,Coaccioli S,Ronchetti S,Riccardi C.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control thymocytes versus thymocytes treated with dexamethasone [PubChem=5743].
Full description | Glucocorticoids play a role in regulation of T lymphocytes homeostasis and development. In particular, glucocorticoid treatment induces massive apoptosis of CD4+CD8+ double positive (DP) thymocytes. This effect is due to many mechanisms, mainly driven by modulation of gene transcription. To find out which genes are modulated, we analyzed DP thymocytes treated for 3 hours with dexamethasone or medium alone, by global gene expression profiling using the Affymetrix technology (MGU74Av2 GeneChip). The data were analyzed with MAS 5.0 imposing a cut off of 1.7 fold in up regulation and 1.35 fold in down regulation. To further filter results we also used the statistical software, SAM (d 0.88 see figure 1s in supplementary data of the above cited manuscript). Results indicate modulation of 156 genes, also confirmed by either RNAse protection assay or Real Time PCR. For data mining we also used Go Miner to explore the Gene Ontology data bank (see tables 1-3 of the above cited manuscript). The overall results demonstrated that dexamethasone caused the down-regulation of genes promoting survival of DP thymocytes (e.g. Notch1, Socs1 and Id3) or the modulation of genes activating cell death through the ceramide pathway (Ugcg, Sgpp1, Degs1 and Gpr65) or through the mithocondrial machinery. Among the latter, there are Bcl-2 family members (Bim, Bfl-1, Bcl-xL and Bcl-xbeta), genes involved in the control of redox status (thioredoxin reductase, TXNIP and idh2) and genes belonging to Tis11 family which are involved in mRNA stability. Our study suggests that dexamethasone treatment of DP thymocytes modulates several genes belonging to apoptosis-related systems that can contribute to their apoptosis.

Standard name | GSE5463_CTRL_VS_DEXAMETHASONE_TREATED_THYMOCYTE_DN
Systematic name | M5632
Organism | Mus musculus
PMID | 16914556
Authors | Bianchini R,Nocentini G,Krausz LT,Fettucciari K,Coaccioli S,Ronchetti S,Riccardi C.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control thymocytes versus thymocytes treated with dexamethasone [PubChem=5743].
Full description | Glucocorticoids play a role in regulation of T lymphocytes homeostasis and development. In particular, glucocorticoid treatment induces massive apoptosis of CD4+CD8+ double positive (DP) thymocytes. This effect is due to many mechanisms, mainly driven by modulation of gene transcription. To find out which genes are modulated, we analyzed DP thymocytes treated for 3 hours with dexamethasone or medium alone, by global gene expression profiling using the Affymetrix technology (MGU74Av2 GeneChip). The data were analyzed with MAS 5.0 imposing a cut off of 1.7 fold in up regulation and 1.35 fold in down regulation. To further filter results we also used the statistical software, SAM (d 0.88 see figure 1s in supplementary data of the above cited manuscript). Results indicate modulation of 156 genes, also confirmed by either RNAse protection assay or Real Time PCR. For data mining we also used Go Miner to explore the Gene Ontology data bank (see tables 1-3 of the above cited manuscript). The overall results demonstrated that dexamethasone caused the down-regulation of genes promoting survival of DP thymocytes (e.g. Notch1, Socs1 and Id3) or the modulation of genes activating cell death through the ceramide pathway (Ugcg, Sgpp1, Degs1 and Gpr65) or through the mithocondrial machinery. Among the latter, there are Bcl-2 family members (Bim, Bfl-1, Bcl-xL and Bcl-xbeta), genes involved in the control of redox status (thioredoxin reductase, TXNIP and idh2) and genes belonging to Tis11 family which are involved in mRNA stability. Our study suggests that dexamethasone treatment of DP thymocytes modulates several genes belonging to apoptosis-related systems that can contribute to their apoptosis.

Standard name | GSE5960_TH1_VS_ANERGIC_TH1_UP
Systematic name | M5637
Organism | Mus musculus
PMID | 17028589
Authors | Zha Y,Marks R,Ho AW,Peterson AC,Janardhan S,Brown I,Praveen K,Stang S,Stone JC,Gajewski TF.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of anergy induced CD4 [GeneID=920] T cells versus conventional CD4 [GeneID=920] T cells.
Full description | compare gene expression profiles between normal and anergic T cells and identify upregulated genes in anergic T cells

Standard name | GSE5960_TH1_VS_ANERGIC_TH1_DN
Systematic name | M5638
Organism | Mus musculus
PMID | 17028589
Authors | Zha Y,Marks R,Ho AW,Peterson AC,Janardhan S,Brown I,Praveen K,Stang S,Stone JC,Gajewski TF.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of anergy induced CD4 [GeneID=920] T cells versus conventional CD4 [GeneID=920] T cells.
Full description | compare gene expression profiles between normal and anergic T cells and identify upregulated genes in anergic T cells

Standard name | GSE6269_HEALTHY_VS_FLU_INF_PBMC_UP
Systematic name | M5639
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMC from patients with acute influenza infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_HEALTHY_VS_FLU_INF_PBMC_DN
Systematic name | M5640
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMC from patients with acute influenza infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_HEALTHY_VS_E_COLI_INF_PBMC_UP
Systematic name | M5641
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMC from patients with acute E. coli infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_HEALTHY_VS_E_COLI_INF_PBMC_DN
Systematic name | M5642
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMC from patients with acute E. coli infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_FLU_VS_STAPH_AUREUS_INF_PBMC_UP
Systematic name | M5643
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMC from patients with acute S. aureus infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_FLU_VS_STAPH_AUREUS_INF_PBMC_DN
Systematic name | M5644
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMC from patients with acute S. aureus infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_HEALTHY_VS_STAPH_PNEUMO_INF_PBMC_UP
Systematic name | M5648
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMC from patients with acute S. pneumoniae infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_HEALTHY_VS_STAPH_PNEUMO_INF_PBMC_DN
Systematic name | M5649
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMC from patients with acute S. pneumoniae infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_FLU_VS_E_COLI_INF_PBMC_UP
Systematic name | M5653
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute influenza infection versus PBMC from patients with acute E. coli infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_FLU_VS_E_COLI_INF_PBMC_DN
Systematic name | M5654
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute influenza infection versus PBMC from patients with acute E. coli infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_HEALTHY_VS_STAPH_AUREUS_INF_PBMC_UP
Systematic name | M5655
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute influenza infection versus PBMC from patients with acute S. aureus infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_HEALTHY_VS_STAPH_AUREUS_INF_PBMC_DN
Systematic name | M5656
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute influenza infection versus PBMC from patients with acute S. aureus infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_FLU_VS_STREP_PNEUMO_INF_PBMC_UP
Systematic name | M5657
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute influenza infection versus PBMC from patients with acute S. pneumoniae infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_FLU_VS_STREP_PNEUMO_INF_PBMC_DN
Systematic name | M5658
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute influenza infection versus PBMC from patients with acute S. pneumoniae infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_E_COLI_VS_STAPH_AUREUS_INF_PBMC_UP
Systematic name | M5659
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute E. coli infection versus PBMC from patients with acute S. aureus infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_E_COLI_VS_STAPH_AUREUS_INF_PBMC_DN
Systematic name | M5660
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute E. coli infection versus PBMC from patients with acute S. aureus infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_E_COLI_VS_STREP_PNEUMO_INF_PBMC_UP
Systematic name | M5661
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute E. coli infection versus PBMC from patients with acute S. pneumoniae infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_E_COLI_VS_STREP_PNEUMO_INF_PBMC_DN
Systematic name | M5662
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute E. coli infection versus PBMC from patients with acute S. pneumoniae infection.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_STAPH_AUREUS_VS_STREP_PNEUMO_INF_PBMC_UP
Systematic name | M5663
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute infection: S. aureus versus S. pneumoniae.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6269_STAPH_AUREUS_VS_STREP_PNEUMO_INF_PBMC_DN
Systematic name | M5664
Organism | Homo sapiens
PMID | 17105821
Authors | Ramilo O,Allman W,Chung W,Mejias A,Ardura M,Glaser C,Wittkowski KM,Piqueras B,Banchereau J,Palucka AK,Chaussabel D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with acute infection: S. aureus versus S. pneumoniae.
Full description | Each infectious agent represents a unique combination of pathogen-associated molecular patterns that interact with specific pattern-recognition receptors expressed on immune cells. Therefore, we surmised that the blood immune cells of individuals with different infections might bear discriminative transcriptional signatures. Gene expression profiles were obtained for 131 peripheral blood samples from pediatric patients with acute infections caused by influenza A virus, Gram-negative (Escherichia coli) or Gram-positive (Staphylococcus aureus and Streptococcus pneumoniae) bacteria. Thirty-five genes were identified that best discriminate patients with influenza A virus infection from patients with either E coli or S pneumoniae infection. These genes classified with 95% accuracy (35 of 37 samples) an independent set of patients with either influenza A, E coli, or S pneumoniae infection. A different signature discriminated patients with E coli versus S aureus infections with 85% accuracy (34 of 40). Furthermore, distinctive gene expression patterns were observed in patients presenting with respiratory infections of different etiologies. Thus, microarray analyses of patient peripheral blood leukocytes might assist in the differential diagnosis of infectious diseases.

Standard name | GSE6566_STRONG_VS_WEAK_DC_STIMULATED_CD4_TCELL_UP
Systematic name | M5665
Organism | Homo sapiens
PMID | 18081042
Authors | Lozza L,Rivino L,Guarda G,Jarrossay D,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A,Geginat J.
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] cells stimulated with strong dendritic cells (DC) versus CD4 [GeneID=920] T cells stimulated with weak DCs.
Full description | The strength of T cell stimulation determines IL-7 responsiveness, recall potential and lineage commitment of primed human CD4+IL-7Rhi T cells. We analyzed how the strength of antigenic stimulation - as determined by dendritic cell (DC) number, DC maturation state and antigen concentration - controls in human CD4+ T cells IL-7R-alpha expression and responsiveness to IL-7, IL-15 and antigen. We found that T cells primed by different strengths of stimulation expressed IL-7R-alpha in different proportions and preferentially on cells that maintained expression of the central memory marker CCR7. However, while CCR7+IL-7Rhi cells generated at high strength of stimulation proliferated vigorously in response to IL-7 or IL-15, CCR7+IL-7Rhi cells generated at low strength of stimulation responded poorly. High cytokine responsiveness was associated with reduced PTEN expression and enhanced s6-kinase activation, consistent with efficient receptor coupling to downstream signalling pathways. Interestingly, while intermediate-stimulated CCR7+IL-7Rhi cells were non-polarized, self-renewed with IL-7 and expanded with antigen, high-stimulated cells generated Th1 effector cells with cytokines but showed impaired IL-2 production and survival with antigen. Gene expression analysis suggested that high-stimulated cells represented pre-Th1 cells with low recall potential and high metabolic state. Taken together these results demonstrate that IL-7 receptor expression and coupling are instructed in T cells by the strength of stimulation and suggest that memory subsets may derive from CCR7+IL-7Rhi precursors that received different strengths of stimulation.

Standard name | GSE6566_STRONG_VS_WEAK_DC_STIMULATED_CD4_TCELL_DN
Systematic name | M5666
Organism | Homo sapiens
PMID | 18081042
Authors | Lozza L,Rivino L,Guarda G,Jarrossay D,Rinaldi A,Bertoni F,Sallusto F,Lanzavecchia A,Geginat J.
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] cells stimulated with strong dendritic cells (DC) versus CD4 [GeneID=920] T cells stimulated with weak DCs.
Full description | The strength of T cell stimulation determines IL-7 responsiveness, recall potential and lineage commitment of primed human CD4+IL-7Rhi T cells. We analyzed how the strength of antigenic stimulation - as determined by dendritic cell (DC) number, DC maturation state and antigen concentration - controls in human CD4+ T cells IL-7R-alpha expression and responsiveness to IL-7, IL-15 and antigen. We found that T cells primed by different strengths of stimulation expressed IL-7R-alpha in different proportions and preferentially on cells that maintained expression of the central memory marker CCR7. However, while CCR7+IL-7Rhi cells generated at high strength of stimulation proliferated vigorously in response to IL-7 or IL-15, CCR7+IL-7Rhi cells generated at low strength of stimulation responded poorly. High cytokine responsiveness was associated with reduced PTEN expression and enhanced s6-kinase activation, consistent with efficient receptor coupling to downstream signalling pathways. Interestingly, while intermediate-stimulated CCR7+IL-7Rhi cells were non-polarized, self-renewed with IL-7 and expanded with antigen, high-stimulated cells generated Th1 effector cells with cytokines but showed impaired IL-2 production and survival with antigen. Gene expression analysis suggested that high-stimulated cells represented pre-Th1 cells with low recall potential and high metabolic state. Taken together these results demonstrate that IL-7 receptor expression and coupling are instructed in T cells by the strength of stimulation and suggest that memory subsets may derive from CCR7+IL-7Rhi precursors that received different strengths of stimulation.

Standard name | GSE7400_CTRL_VS_CSF3_IN_VIVO_TREATED_PBMC_UP
Systematic name | M5668
Organism | Homo sapiens
PMID | 17761290
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated peripheral blood mononuclear cells (PBMC) versus PBMCs treated with CSF3 [GeneID=1440].
Full description | Granulocyte-colony stimulating factor (G-CSF) is used to boost granulocyte counts in immunocompromised patients, but its effects on the immune system may be counter productive. We tested the hypothesis that G-CSF mobilized peripheral blood stem cell (PBSC) products are immunologically down regulated based on gene microarray analysis. Ten peripheral blood samples from normal donors for allogeneic PBSC transplantation were obtained before and after administration of G-CSF and tested on Affymetrix Human U133 Plus 2.0 GeneChip® microarrays. Significant changes in gene expression after G-CSF mobilization were reported by controlling the false discovery rate at 5%. Immune-related genes were isolated from the data set and categorized according to probe set annotations and a thorough, independent literature search. We found that G-CSF up-regulated inflammatory and neutrophil activation pathway gene expression; however, adaptive immune-related gene expression, such as antigen presentation, co-stimulation, T cell activation and cytolytic effector pathways, were generally down-regulated. Thus, despite significant increases in stem cells, lymphocytes and antigen presenting cells, G-CSF mobilized PBSC allografts exhibit a suppressive adaptive immune-related gene expression profile. Our data provides an explanation for the potentially immunosuppressive effects observed after G-CSF administration.

Standard name | GSE7400_CTRL_VS_CSF3_IN_VIVO_TREATED_PBMC_DN
Systematic name | M5670
Organism | Homo sapiens
PMID | 17761290
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated peripheral blood mononuclear cells (PBMC) versus PBMCs treated with CSF3 [GeneID=1440].
Full description | Granulocyte-colony stimulating factor (G-CSF) is used to boost granulocyte counts in immunocompromised patients, but its effects on the immune system may be counter productive. We tested the hypothesis that G-CSF mobilized peripheral blood stem cell (PBSC) products are immunologically down regulated based on gene microarray analysis. Ten peripheral blood samples from normal donors for allogeneic PBSC transplantation were obtained before and after administration of G-CSF and tested on Affymetrix Human U133 Plus 2.0 GeneChip® microarrays. Significant changes in gene expression after G-CSF mobilization were reported by controlling the false discovery rate at 5%. Immune-related genes were isolated from the data set and categorized according to probe set annotations and a thorough, independent literature search. We found that G-CSF up-regulated inflammatory and neutrophil activation pathway gene expression; however, adaptive immune-related gene expression, such as antigen presentation, co-stimulation, T cell activation and cytolytic effector pathways, were generally down-regulated. Thus, despite significant increases in stem cells, lymphocytes and antigen presenting cells, G-CSF mobilized PBSC allografts exhibit a suppressive adaptive immune-related gene expression profile. Our data provides an explanation for the potentially immunosuppressive effects observed after G-CSF administration.

Standard name | GSE7460_TCONV_VS_TREG_LN_UP
Systematic name | M5673
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TconvLN versus TregLN (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_TCONV_VS_TREG_LN_DN
Systematic name | M5674
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TconvLN versus TregLN (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_TCONV_VS_TREG_THYMUS_UP
Systematic name | M5675
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of TconvThy versus TregThy (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_TCONV_VS_TREG_THYMUS_DN
Systematic name | M5676
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of TconvThy versus TregThy (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_TGFB_TREATED_ACT_CD8_TCELL_UP
Systematic name | M5677
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of ActCD8 versus ActCD8TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_TGFB_TREATED_ACT_CD8_TCELL_DN
Systematic name | M5679
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of ActCD8 versus ActCD8TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_TGFB_TREATED_ACT_TREG_UP
Systematic name | M5680
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of ActTreg versus ActTregTGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_TGFB_TREATED_ACT_TREG_DN
Systematic name | M5682
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of ActTreg versus ActTregTGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CD8_TCELL_VS_TREG_ACT_UP
Systematic name | M5683
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of ActCD8 versus ActTreg (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CD8_TCELL_VS_TREG_ACT_DN
Systematic name | M5684
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of ActCD8 versus ActTreg(see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CD8_TCELL_VS_CD4_TCELL_ACT_UP
Systematic name | M5687
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of ActCD8 versus ActCD4 (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CD8_TCELL_VS_CD4_TCELL_ACT_DN
Systematic name | M5689
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of ActCD8 versus ActCD4 (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_TREG_VS_TCONV_ACT_UP
Systematic name | M5690
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of ActTreg versus ActCD4 (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_TREG_VS_TCONV_ACT_DN
Systematic name | M5691
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of ActTreg versus ActCD4 (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_TREG_VS_TCONV_ACT_WITH_TGFB_UP
Systematic name | M5692
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of ActTregTGF versus ActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_TREG_VS_TCONV_ACT_WITH_TGFB_DN
Systematic name | M5693
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of ActTregTGF versus ActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_TGFB_TREATED_ACT_TCONV_UP
Systematic name | M5694
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of ActCD4 versus ActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_TGFB_TREATED_ACT_TCONV_DN
Systematic name | M5695
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of ActCD4 versus ActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_TGFB_TREATED_ACT_FOXP3_HET_TCONV_UP
Systematic name | M5696
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of WTActCD4 versus WTActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_TGFB_TREATED_ACT_FOXP3_HET_TCONV_DN
Systematic name | M5697
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of WTActCD4 versus WTActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_TGFB_TREATED_ACT_FOXP3_MUT_TCONV_UP
Systematic name | M5698
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of sfActCD4 versus sfActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_TGFB_TREATED_ACT_FOXP3_MUT_TCONV_DN
Systematic name | M5699
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of sfActCD4 versus sfActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_FOXP3_MUT_VS_WT_ACT_TCONV_UP
Systematic name | M5700
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of sfActCD4 versus ActCD4 (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_FOXP3_MUT_VS_WT_ACT_TCONV_DN
Systematic name | M5701
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of sfActCD4 versus ActCD4 (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_FOXP3_MUT_VS_WT_ACT_WITH_TGFB_TCONV_UP
Systematic name | M5703
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of sfActCD4TGF versus ActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_FOXP3_MUT_VS_WT_ACT_WITH_TGFB_TCONV_DN
Systematic name | M5705
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of sfActCD4TGF versus ActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_FOXP3_MUT_VS_HET_ACT_TCONV_UP
Systematic name | M5706
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparsion of sfActCD4 versus WTActCD4 (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_FOXP3_MUT_VS_HET_ACT_TCONV_DN
Systematic name | M5707
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparsion of sfActCD4 versus WTActCD4 (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_WT_VS_FOXP3_HET_ACT_TCONV_UP
Systematic name | M5709
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of ActCD4 versus WTActCD4 (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_WT_VS_FOXP3_HET_ACT_TCONV_DN
Systematic name | M5710
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of ActCD4 versus WTActCD4 (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_WT_VS_FOXP3_HET_ACT_WITH_TGFB_TCONV_UP
Systematic name | M5711
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of ActCD4TGF versus WTActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_WT_VS_FOXP3_HET_ACT_WITH_TGFB_TCONV_DN
Systematic name | M5712
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of ActCD4TGF versus WTActCD4TGF (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_FOXP3_OVEREXPR_TCONV_UP
Systematic name | M5713
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of Ctrlrv versus Foxp3rv (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_FOXP3_OVEREXPR_TCONV_DN
Systematic name | M5715
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of Ctrlrv versus Foxp3rv (see Fig. 1 in the paper for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_FOXP3_OVEREXPR_TCONV_1_UP
Systematic name | M5716
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of CTRLrv versus FOXP3rv (see Fig. 1 for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7460_CTRL_VS_FOXP3_OVEREXPR_TCONV_1_DN
Systematic name | M5719
Organism | Homo sapiens
PMID | 18024188
Authors | Buzzeo MP,Yang J,Casella G,Reddy V.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of CTRLrv versus FOXP3rv (see Fig. 1 for details).
Full description | The transcription factor Foxp3 is usually considered the master regulator for the CD4+CD25+ "Treg" lineage, which plays a key role in controlling immune and autoimmune responses, and is characterized by a unique transcriptional signature. We have performed a meta-analysis of this signature in Treg cells in several conditions to delineate the elements that can be ascribed to T cell activation, TGFbeta signaling, or Foxp3 itself. We find that these influences synergize to activate many of the signature’s components. Foxp3 and TGFbeta signaling have interconnected relationships, as Foxp3 is induced by TGFbeta while enhancing TGFbeta’s positive feedback loop. Much of the Treg signature cannot be ascribed to Foxp3, as it contains gene clusters that are co-regulated, but cannot be transactivated, by Foxp3. This suggests that the Treg lineage is specified at a higher level of regulation, upstream of Foxp3, which does control some of the lineage’s essential immunoregulatory attributes.

Standard name | GSE7764_NKCELL_VS_SPLENOCYTE_UP
Systematic name | M5720
Organism | Mus musculus
PMID | 17540585
Authors | Fehniger TA,Cai SF,Cao X,Bredemeyer AJ,Presti RM,French AR,Ley TJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NK cells versus total splenocytes.
Full description | Murine NK cells were compared at rest and following 24 hours of IL-15 stimulation for their mRNA expression profiles on the Affymetrix MOE430_2 microarray platform. Additional comparators included resting bulk splenocytes.

Standard name | GSE7764_NKCELL_VS_SPLENOCYTE_DN
Systematic name | M5722
Organism | Mus musculus
PMID | 17540585
Authors | Fehniger TA,Cai SF,Cao X,Bredemeyer AJ,Presti RM,French AR,Ley TJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NK cells versus total splenocytes.
Full description | Murine NK cells were compared at rest and following 24 hours of IL-15 stimulation for their mRNA expression profiles on the Affymetrix MOE430_2 microarray platform. Additional comparators included resting bulk splenocytes.

Standard name | GSE7764_IL15_TREATED_VS_CTRL_NK_CELL_24H_UP
Systematic name | M5723
Organism | Mus musculus
PMID | 17540585
Authors | Fehniger TA,Cai SF,Cao X,Bredemeyer AJ,Presti RM,French AR,Ley TJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NK cells treated with IL15 [GeneID=3567] versus untreated NK cells.
Full description | Murine NK cells were compared at rest and following 24 hours of IL-15 stimulation for their mRNA expression profiles on the Affymetrix MOE430_2 microarray platform. Additional comparators included resting bulk splenocytes.

Standard name | GSE7764_IL15_TREATED_VS_CTRL_NK_CELL_24H_DN
Systematic name | M5724
Organism | Mus musculus
PMID | 17540585
Authors | Fehniger TA,Cai SF,Cao X,Bredemeyer AJ,Presti RM,French AR,Ley TJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NK cells treated with IL15 [GeneID=3567] versus untreated NK cells.
Full description | Murine NK cells were compared at rest and following 24 hours of IL-15 stimulation for their mRNA expression profiles on the Affymetrix MOE430_2 microarray platform. Additional comparators included resting bulk splenocytes.

Standard name | GSE7764_IL15_NK_CELL_24H_VS_SPLENOCYTE_UP
Systematic name | M5725
Organism | Mus musculus
PMID | 17540585
Authors | Fehniger TA,Cai SF,Cao X,Bredemeyer AJ,Presti RM,French AR,Ley TJ.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of NK cells treated with IL15 [GeneID=3567] versus total splenocytes.
Full description | Murine NK cells were compared at rest and following 24 hours of IL-15 stimulation for their mRNA expression profiles on the Affymetrix MOE430_2 microarray platform. Additional comparators included resting bulk splenocytes.

Standard name | GSE7764_IL15_NK_CELL_24H_VS_SPLENOCYTE_DN
Systematic name | M5726
Organism | Mus musculus
PMID | 17540585
Authors | Fehniger TA,Cai SF,Cao X,Bredemeyer AJ,Presti RM,French AR,Ley TJ.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of NK cells treated with IL15 [GeneID=3567] versus total splenocytes.
Full description | Murine NK cells were compared at rest and following 24 hours of IL-15 stimulation for their mRNA expression profiles on the Affymetrix MOE430_2 microarray platform. Additional comparators included resting bulk splenocytes.

Standard name | GSE7852_TREG_VS_TCONV_LN_UP
Systematic name | M5727
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lymph node regulatory T cells versus lymph node conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_TREG_VS_TCONV_LN_DN
Systematic name | M5729
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lymph node regulatory T cells versus lymph node conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_TREG_VS_TCONV_THYMUS_UP
Systematic name | M5730
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of thymus regulatory T cells versus thymus conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_TREG_VS_TCONV_THYMUS_DN
Systematic name | M5732
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of thymus regulatory T cells versus thymus conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_TREG_VS_TCONV_FAT_UP
Systematic name | M5733
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of fat tissue regulatory T cells versus fat tissue conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_TREG_VS_TCONV_FAT_DN
Systematic name | M5735
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of fat tissue regulatory T cells versus fat tissue conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_LN_VS_THYMUS_TREG_UP
Systematic name | M5737
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lymph node regulatory T cells versus thymus regulatory T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_LN_VS_THYMUS_TREG_DN
Systematic name | M5738
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lymph node regulatory T cells versus thymus regulatory T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_LN_VS_FAT_TREG_UP
Systematic name | M5739
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lymph node regulatory T cells versus fat tissue regulatory T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_LN_VS_FAT_TREG_DN
Systematic name | M5742
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lymph node regulatory T cells versus fat tissue regulatory T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_THYMUS_VS_FAT_TREG_UP
Systematic name | M5743
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of thymus regulatory T cells versus fat tissue regulatory T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_THYMUS_VS_FAT_TREG_DN
Systematic name | M5744
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of thymus regulatory T cells versus fat tissue regulatory T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_LN_VS_THYMUS_TCONV_UP
Systematic name | M5745
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lymph node conventional T cells versus thymus conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_LN_VS_THYMUS_TCONV_DN
Systematic name | M5746
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lymph node conventional T cells versus thymus conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_LN_VS_FAT_TCONV_UP
Systematic name | M5747
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of lymph node conventional T cells versus fat tissue conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_LN_VS_FAT_TCONV_DN
Systematic name | M5748
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of lymph node conventional T cells versus fat tissue conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_THYMUS_VS_FAT_TCONV_UP
Systematic name | M5749
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of thymus conventional T cells versus fat tissue conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_THYMUS_VS_FAT_TCONV_DN
Systematic name | M5750
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of thymus conventional T cells versus fat tissue conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_TREG_VS_TCONV_UP
Systematic name | M5751
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of regulatory T cells versus conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE7852_TREG_VS_TCONV_DN
Systematic name | M5752
Organism | Mus musculus
PMID | 19633656
Authors | Feuerer M,Herrero L,Cipolletta D,Naaz A,Wong J,Nayer A,Lee J,Goldfine AB,Benoist C,Shoelson S,Mathis D.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of regulatory T cells versus conventional T cells.
Full description | Comparisons of global gene-expression profiles revealed a greater distinction between CD4+ Treg cells and CD4+ conventional (Tconv) T cells residing in abdominal (epidydimal) fat versus in more standard locations such as the spleen, thymus and LN.

Standard name | GSE8384_CTRL_VS_B_ABORTUS_4H_MAC_CELL_LINE_UP
Systematic name | M5753
Organism | Mus musculus
PMID | 12595423
Authors | Eskra L,Mathison A,Splitter G.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of control RAW264.7 cells (macrophages) versus those infected with B. abortus.
Full description | Identification of host responses at the gene transcription level provides a molecular profile of the events that occur following infection. Brucella abortus is a facultative intracellular pathogen of macrophages that induces chronic infection in humans and domestic animals. Using microarray technology, the response of macrophages 4 hours following B. abortus infection was analyzed to identify early intracellular infection events that occur in macrophages. Of the more than 6,000 genes, we identified over 140 genes that were reproducibly differentially transcribed. First, an increase in the transcription of a number of pro-inflammatory cytokines and chemokines, such as TNF-α, IL-1β, IL-1α, and members of the SCY family of proteins, was evident that may constitute a general host recruitment of antibacterial defenses. Alternatively, Brucella may subvert newly arriving macrophages for additional intracellular infection. Second, transcription of receptors and cytokines associated with antigen presentation, e.g., MHC class II and IL-12p40, were not evident at this 4 hour period of infection. Third, Brucella inhibited transcription of various host genes involved in apoptosis, cell cycling, and intracellular vesicular trafficking. Identification of macrophage genes whose transcription was inhibited suggests that Brucella utilizes specific mechanisms to target certain cell pathways. In conclusion, these data suggest that B. abortus can alter macrophage pathways to recruit additional macrophages for future infection while simultaneously inhibiting apoptosis and innate immune mechanisms within the macrophage permitting intracellular survival of the bacterium. These results provide insights into the pathogenic strategies used by Brucella to survive long-term within a hostile environment.

Standard name | GSE8384_CTRL_VS_B_ABORTUS_4H_MAC_CELL_LINE_DN
Systematic name | M5758
Organism | Mus musculus
PMID | 12595423
Authors | Eskra L,Mathison A,Splitter G.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of control RAW264.7 cells (macrophages) versus those infected with B. abortus.
Full description | Identification of host responses at the gene transcription level provides a molecular profile of the events that occur following infection. Brucella abortus is a facultative intracellular pathogen of macrophages that induces chronic infection in humans and domestic animals. Using microarray technology, the response of macrophages 4 hours following B. abortus infection was analyzed to identify early intracellular infection events that occur in macrophages. Of the more than 6,000 genes, we identified over 140 genes that were reproducibly differentially transcribed. First, an increase in the transcription of a number of pro-inflammatory cytokines and chemokines, such as TNF-α, IL-1β, IL-1α, and members of the SCY family of proteins, was evident that may constitute a general host recruitment of antibacterial defenses. Alternatively, Brucella may subvert newly arriving macrophages for additional intracellular infection. Second, transcription of receptors and cytokines associated with antigen presentation, e.g., MHC class II and IL-12p40, were not evident at this 4 hour period of infection. Third, Brucella inhibited transcription of various host genes involved in apoptosis, cell cycling, and intracellular vesicular trafficking. Identification of macrophage genes whose transcription was inhibited suggests that Brucella utilizes specific mechanisms to target certain cell pathways. In conclusion, these data suggest that B. abortus can alter macrophage pathways to recruit additional macrophages for future infection while simultaneously inhibiting apoptosis and innate immune mechanisms within the macrophage permitting intracellular survival of the bacterium. These results provide insights into the pathogenic strategies used by Brucella to survive long-term within a hostile environment.

Standard name | GSE8515_CTRL_VS_IL1_4H_STIM_MAC_UP
Systematic name | M5759
Organism | Homo sapiens
PMID | 18498781
Authors | Jura J,Wegrzyn P,Korostyński M,Guzik K,Oczko-Wojciechowska M,Jarzab M,Kowalska M,Piechota M,Przewłocki R,Koj A
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages versus those treated with IL1.
Full description | Using whole-genome Affymetrix microarrays (HG-U133A), we characterized the transcriptome profile of cultured human macrophages stimulated for 4 h with interleukin 1 (IL-1) or interleukin 6 (IL-6). We found that, in distinction to liver cells, IL-1 is much more potent than IL-6 in modifying macrophage gene expression, although considerable heterogeneity in response of macrophages deriving from individual blood donors was observed. The obtained results permitted to identify a large number of cytokine-responsive genes. coding for proteins of unknown function that are now being studied in our laboratory. They may represent novel targets in the anti-inflammatory therapy.

Standard name | GSE8515_CTRL_VS_IL1_4H_STIM_MAC_DN
Systematic name | M5760
Organism | Homo sapiens
PMID | 18498781
Authors | Jura J,Wegrzyn P,Korostyński M,Guzik K,Oczko-Wojciechowska M,Jarzab M,Kowalska M,Piechota M,Przewłocki R,Koj A
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages versus those treated with IL1.
Full description | Using whole-genome Affymetrix microarrays (HG-U133A), we characterized the transcriptome profile of cultured human macrophages stimulated for 4 h with interleukin 1 (IL-1) or interleukin 6 (IL-6). We found that, in distinction to liver cells, IL-1 is much more potent than IL-6 in modifying macrophage gene expression, although considerable heterogeneity in response of macrophages deriving from individual blood donors was observed. The obtained results permitted to identify a large number of cytokine-responsive genes. coding for proteins of unknown function that are now being studied in our laboratory. They may represent novel targets in the anti-inflammatory therapy.

Standard name | GSE8515_CTRL_VS_IL6_4H_STIM_MAC_UP
Systematic name | M5763
Organism | Homo sapiens
PMID | 18498781
Authors | Jura J,Wegrzyn P,Korostyński M,Guzik K,Oczko-Wojciechowska M,Jarzab M,Kowalska M,Piechota M,Przewłocki R,Koj A
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages versus those treated with IL6 [GeneID=3569].
Full description | Using whole-genome Affymetrix microarrays (HG-U133A), we characterized the transcriptome profile of cultured human macrophages stimulated for 4 h with interleukin 1 (IL-1) or interleukin 6 (IL-6). We found that, in distinction to liver cells, IL-1 is much more potent than IL-6 in modifying macrophage gene expression, although considerable heterogeneity in response of macrophages deriving from individual blood donors was observed. The obtained results permitted to identify a large number of cytokine-responsive genes. coding for proteins of unknown function that are now being studied in our laboratory. They may represent novel targets in the anti-inflammatory therapy.

Standard name | GSE8515_CTRL_VS_IL6_4H_STIM_MAC_DN
Systematic name | M5765
Organism | Homo sapiens
PMID | 18498781
Authors | Jura J,Wegrzyn P,Korostyński M,Guzik K,Oczko-Wojciechowska M,Jarzab M,Kowalska M,Piechota M,Przewłocki R,Koj A
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages versus those treated with IL6 [GeneID=3569].
Full description | Using whole-genome Affymetrix microarrays (HG-U133A), we characterized the transcriptome profile of cultured human macrophages stimulated for 4 h with interleukin 1 (IL-1) or interleukin 6 (IL-6). We found that, in distinction to liver cells, IL-1 is much more potent than IL-6 in modifying macrophage gene expression, although considerable heterogeneity in response of macrophages deriving from individual blood donors was observed. The obtained results permitted to identify a large number of cytokine-responsive genes. coding for proteins of unknown function that are now being studied in our laboratory. They may represent novel targets in the anti-inflammatory therapy.

Standard name | GSE8515_IL1_VS_IL6_4H_STIM_MAC_UP
Systematic name | M5766
Organism | Homo sapiens
PMID | 18498781
Authors | Jura J,Wegrzyn P,Korostyński M,Guzik K,Oczko-Wojciechowska M,Jarzab M,Kowalska M,Piechota M,Przewłocki R,Koj A
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages versus those treated with IL1 and IL6 [GeneID=3569].
Full description | Using whole-genome Affymetrix microarrays (HG-U133A), we characterized the transcriptome profile of cultured human macrophages stimulated for 4 h with interleukin 1 (IL-1) or interleukin 6 (IL-6). We found that, in distinction to liver cells, IL-1 is much more potent than IL-6 in modifying macrophage gene expression, although considerable heterogeneity in response of macrophages deriving from individual blood donors was observed. The obtained results permitted to identify a large number of cytokine-responsive genes. coding for proteins of unknown function that are now being studied in our laboratory. They may represent novel targets in the anti-inflammatory therapy.

Standard name | GSE8515_IL1_VS_IL6_4H_STIM_MAC_DN
Systematic name | M5767
Organism | Homo sapiens
PMID | 18498781
Authors | Jura J,Wegrzyn P,Korostyński M,Guzik K,Oczko-Wojciechowska M,Jarzab M,Kowalska M,Piechota M,Przewłocki R,Koj A
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages versus those treated with IL1 and IL6 [GeneID=3569].
Full description | Using whole-genome Affymetrix microarrays (HG-U133A), we characterized the transcriptome profile of cultured human macrophages stimulated for 4 h with interleukin 1 (IL-1) or interleukin 6 (IL-6). We found that, in distinction to liver cells, IL-1 is much more potent than IL-6 in modifying macrophage gene expression, although considerable heterogeneity in response of macrophages deriving from individual blood donors was observed. The obtained results permitted to identify a large number of cytokine-responsive genes. coding for proteins of unknown function that are now being studied in our laboratory. They may represent novel targets in the anti-inflammatory therapy.

Standard name | GSE8678_IL7R_LOW_VS_HIGH_EFF_CD8_TCELL_UP
Systematic name | M5769
Organism | Mus musculus
PMID | 17723218
Authors | Joshi NS,Cui W,Chandele A,Lee HK,Urso DR,Hagman J,Gapin L,Kaech SM.
Category | C7
Sub-category |
Brief description | Genes up-regulated in IL7R [GeneID=3575] low effector CD8 T cells versus IL7R [GeneID=3575] high effector CD8 T cells.
Full description | At the peak of the CD8 T cell response to acture viral and bacterial infections, expression of the Interleukin-7 Receptor (IL-7R) marks Memory Precursor Effector CD8 T Cells (MPECs) from other Short-Lived Effector CD8 T cells (SLECs), which are IL-7Rlo. This study was designed to determine the gene expression differences between these two subsets of effector CD8 T cells.

Standard name | GSE8678_IL7R_LOW_VS_HIGH_EFF_CD8_TCELL_DN
Systematic name | M5771
Organism | Mus musculus
PMID | 17723218
Authors | Joshi NS,Cui W,Chandele A,Lee HK,Urso DR,Hagman J,Gapin L,Kaech SM.
Category | C7
Sub-category |
Brief description | Genes down-regulated in IL7R [GeneID=3575] low effector CD8 T cells versus IL7R [GeneID=3575] high effector CD8 T cells.
Full description | At the peak of the CD8 T cell response to acture viral and bacterial infections, expression of the Interleukin-7 Receptor (IL-7R) marks Memory Precursor Effector CD8 T Cells (MPECs) from other Short-Lived Effector CD8 T cells (SLECs), which are IL-7Rlo. This study was designed to determine the gene expression differences between these two subsets of effector CD8 T cells.

Standard name | GSE8868_SPLEEN_VS_INTESTINE_CD11B_POS_CD11C_NEG_DC_UP
Systematic name | M5772
Organism | Mus musculus
PMID | 17873879
Authors | Denning TL,Wang YC,Patel SR,Williams IR,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells (DC) from spleen versus those from intestine.
Full description | The intestinal immune system must elicit robust immunity against harmful pathogens but restrain immune responses directed against commensal microbes and dietary antigens. The mechanisms that maintain this dichotomy are poorly understood. Here we describe a population of CD11b+F4/80+CD11c– macrophages in the lamina propria (LP) that express several anti-inflammatory molecules including interleukin 10 (IL-10), but little or no pro-inflammatory cytokines, even upon stimulation with Toll-like receptor (TLR) ligands. These macrophages induced, in a manner dependent on IL-10, retinoic acid and exogenous transforming growth factor-β, differentiation of FoxP3+ regulatory T cells. In contrast, LP CD11b+ dendritic cells elicited IL-17 production. This IL-17 production was suppressed by LP macrophages, indicating that a dynamic interplay between these subsets may influence the balance between immune activation and tolerance. Splenic or small intestine lamina propria CD11b+11c- cells were isolated for RNA extraction and hybridization on Affymetrix microarrays. We sought to determine the unique genetic profile of small intestine lamina propria CD11b+11c- cells.

Standard name | GSE8868_SPLEEN_VS_INTESTINE_CD11B_POS_CD11C_NEG_DC_DN
Systematic name | M5773
Organism | Mus musculus
PMID | 17873879
Authors | Denning TL,Wang YC,Patel SR,Williams IR,Pulendran B.
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells (DC) from spleen versus those from intestine.
Full description | The intestinal immune system must elicit robust immunity against harmful pathogens but restrain immune responses directed against commensal microbes and dietary antigens. The mechanisms that maintain this dichotomy are poorly understood. Here we describe a population of CD11b+F4/80+CD11c– macrophages in the lamina propria (LP) that express several anti-inflammatory molecules including interleukin 10 (IL-10), but little or no pro-inflammatory cytokines, even upon stimulation with Toll-like receptor (TLR) ligands. These macrophages induced, in a manner dependent on IL-10, retinoic acid and exogenous transforming growth factor-β, differentiation of FoxP3+ regulatory T cells. In contrast, LP CD11b+ dendritic cells elicited IL-17 production. This IL-17 production was suppressed by LP macrophages, indicating that a dynamic interplay between these subsets may influence the balance between immune activation and tolerance. Splenic or small intestine lamina propria CD11b+11c- cells were isolated for RNA extraction and hybridization on Affymetrix microarrays. We sought to determine the unique genetic profile of small intestine lamina propria CD11b+11c- cells.

Standard name | GSE9006_HEALTHY_VS_TYPE_1_DIABETES_PBMC_AT_DX_UP
Systematic name | M5774
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from patients with type 1 diabetes at the time of diagnosis.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_HEALTHY_VS_TYPE_1_DIABETES_PBMC_AT_DX_DN
Systematic name | M5776
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from patients with type 1 diabetes at the time of diagnosis.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_HEALTHY_VS_TYPE_1_DIABETES_PBMC_1MONTH_POST_DX_UP
Systematic name | M5777
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from patients with type 1 diabetes at 1 month after the diagnosis.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_HEALTHY_VS_TYPE_1_DIABETES_PBMC_1MONTH_POST_DX_DN
Systematic name | M5778
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from patients with type 1 diabetes at 1 month after the diagnosis.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_HEALTHY_VS_TYPE_1_DIABETES_PBMC_4MONTH_POST_DX_UP
Systematic name | M5779
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from patients with type 1 diabetes at 4 month after the diagnosis.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_HEALTHY_VS_TYPE_1_DIABETES_PBMC_4MONTH_POST_DX_DN
Systematic name | M5780
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from patients with type 1 diabetes at 4 month after the diagnosis.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_HEALTHY_VS_TYPE_2_DIABETES_PBMC_AT_DX_UP
Systematic name | M5781
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from patients with type 2 diabetes at the time of diagnosis.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_HEALTHY_VS_TYPE_2_DIABETES_PBMC_AT_DX_DN
Systematic name | M5782
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from healthy donors versus PBMCs from patients with type 2 diabetes at the time of diagnosis.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_TYPE_1_DIABETES_AT_DX_VS_1MONTH_POST_DX_PBMC_UP
Systematic name | M5783
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with type 1 diabetes at the time of the diagnosis versus those at 1 month later.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_TYPE_1_DIABETES_AT_DX_VS_1MONTH_POST_DX_PBMC_DN
Systematic name | M5786
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with type 1 diabetes at the time of the diagnosis versus those at 1 month later.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_TYPE_1_DIABETES_AT_DX_VS_4MONTH_POST_DX_PBMC_UP
Systematic name | M5787
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with type 1 diabetes at the time of the diagnosis versus those at 4 months later.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_TYPE_1_DIABETES_AT_DX_VS_4MONTH_POST_DX_PBMC_DN
Systematic name | M5788
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with type 1 diabetes at the time of the diagnosis versus those at 4 months later.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_1MONTH_VS_4MONTH_POST_TYPE_1_DIABETES_DX_PBMC_UP
Systematic name | M5790
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with type 1 diabetes at 1 month after the diagnosis versus those at 4 months later.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_1MONTH_VS_4MONTH_POST_TYPE_1_DIABETES_DX_PBMC_DN
Systematic name | M5791
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of peripheral blood mononuclear cells (PBMC) from patients with type 1 diabetes at 1 month after the diagnosis versus those at 4 months later.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_TYPE_1_VS_TYPE_2_DIABETES_PBMC_AT_DX_UP
Systematic name | M5797
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood mononuclear cells (PBMC) from patients with type 1 diabetes at the time of diagnosis versus those with type 2 diabetes at the time of diagnosis.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9006_TYPE_1_VS_TYPE_2_DIABETES_PBMC_AT_DX_DN
Systematic name | M5799
Organism | Homo sapiens
PMID | 17595242
Authors | Kaizer EC,Glaser CL,Chaussabel D,Banchereau J,Pascual V,White PC.
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood mononuclear cells (PBMC) from patients with type 1 diabetes at the time of diagnosis versus those with type 2 diabetes at the time of diagnosis.
Full description | Objective: We hypothesized that type 1 diabetes (T1D) is accompanied by changes in gene expression in peripheral blood mononuclear cells (PBMCs) due to dysregulation of adaptive and innate immunity, counterregulatory responses to immune dysregulation, insulin deficiency and hyperglycemia. Research Design and Methods: Microarray analysis was performed on PBMCs from 43 patients with newly diagnosed T1D, 12 patients with newly diagnosed type 2 diabetes (T2D) and 24 healthy controls. One and four month follow-up samples were obtained from 20 of the T1D patients. Results: Microarray analysis identified 282 genes differing in expression between newlydiagnosed T1D patients and controls at a false discovery rate of 0.05. Changes in expression of interleukin-1β (IL1B), early growth response gene 3 (EGR3), and prostaglandin-endoperoxide synthase 2 (PTGS2) resolved within four months of insulin therapy and were also observed in T2D suggesting that they resulted from hyperglycemia. With use of a knowledge base, 81/282 genes could be placed within a network of interrelated genes with predicted functions including apoptosis and cell proliferation. IL1B and the MYC oncogene were the most highly-connected genes in the network. IL1B was highly overexpressed in both T1D and T2D, whereas MYC was dysregulated only in T1D. Conclusion: T1D and T2D likely share a final common pathway for beta cell dysfunction that includes secretion of interleukin-1β and prostaglandins by immune effector cells, exacerbating existing beta cell dysfunction, and causing further hyperglycemia. The results identify several targets for disease-modifying therapy of diabetes and potential biomarkers for monitoring treatment efficacy.

Standard name | GSE9037_CTRL_VS_LPS_1H_STIM_BMDM_UP
Systematic name | M5800
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages at 4 h versus those treated with LPS (TLR4 agonist) at 1 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_CTRL_VS_LPS_1H_STIM_BMDM_DN
Systematic name | M5801
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages at 4 h versus those treated with LPS (TLR4 agonist) at 1 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_CTRL_VS_LPS_4H_STIM_BMDM_UP
Systematic name | M5803
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages at 4 h versus those treated with LPS (TLR4 agonist) at 4 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_CTRL_VS_LPS_4H_STIM_BMDM_DN
Systematic name | M5806
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages at 4 h versus those treated with LPS (TLR4 agonist) at 4 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_CTRL_VS_LPS_1H_STIM_IRAK4_KO_BMDM_UP
Systematic name | M5807
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages from IRAK4 [GeneID=51135] deficient mice at 4 h versus those treated with LPS (TLR4 agonist) at 1 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_CTRL_VS_LPS_1H_STIM_IRAK4_KO_BMDM_DN
Systematic name | M5808
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages from IRAK4 [GeneID=51135] deficient mice at 4 h versus those treated with LPS (TLR4 agonist) at 1 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_CTRL_VS_LPS_4H_STIM_IRAK4_KO_BMDM_UP
Systematic name | M5809
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated macrophages from IRAK4 [GeneID=51135] deficient mice at 4 h versus those treated with LPS (TLR4 agonist) at 4 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_CTRL_VS_LPS_4H_STIM_IRAK4_KO_BMDM_DN
Systematic name | M5811
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated macrophages from IRAK4 [GeneID=51135] deficient mice at 4 h versus those treated with LPS (TLR4 agonist) at 4 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_WT_VS_IRAK4_KO_BMDM_UP
Systematic name | M5812
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated wild type macrophages at 4 h versus those from IRAK4 [GeneID=51135] deficient mice at 4 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_WT_VS_IRAK4_KO_BMDM_DN
Systematic name | M5814
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated wild type macrophages at 4 h versus those from IRAK4 [GeneID=51135] deficient mice at 4 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_WT_VS_IRAK4_KO_LPS_1H_STIM_BMDM_UP
Systematic name | M5815
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of untreated wild type macrophages at 1 h versus those from IRAK4 [GeneID=51135] deficient mice treated with LPS (TLR4 agonist) at 1 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_WT_VS_IRAK4_KO_LPS_1H_STIM_BMDM_DN
Systematic name | M5816
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of untreated wild type macrophages at 1 h versus those from IRAK4 [GeneID=51135] deficient mice treated with LPS (TLR4 agonist) at 1 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_WT_VS_IRAK4_KO_LPS_4H_STIM_BMDM_UP
Systematic name | M5817
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of wild type macrophage treated with LPS (TLR4 agonist) at 4 h versus those from IRAK4 [GeneID=51135] deficient mice treated with LPS (TLR4 agonist) at 4 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9037_WT_VS_IRAK4_KO_LPS_4H_STIM_BMDM_DN
Systematic name | M5818
Organism | Mus musculus
PMID | 18266302
Authors | Koziczak-Holbro M,Glück A,Tschopp C,Mathison JC,Gram H
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of wild type macrophage treated with LPS (TLR4 agonist) at 4 h versus those from IRAK4 [GeneID=51135] deficient mice treated with LPS (TLR4 agonist) at 4 h.
Full description | IRAK-4 is an essential component of the signal transduction complex downstream of the IL-1- and Toll-like receptors. Though regarded as the first kinase in the signaling cascade, the role of IRAK-4 kinase activity versus its scaffold function is still controversial. In order to investigate the role of IRAK-4 kinase function in vivo, ‘knock-in’ mice were generated by replacing the wild type IRAK-4 gene with a mutant gene encoding kinase deficient IRAK-4 protein (IRAK-4 KD). Analysis of bone marrow macrophages obtained from WT and IRAK-4 KD mice with a number of experimental techniques demonstrated that the IRAK-4 KD cells greatly lack responsiveness to stimulation with the Toll-like receptor 4 (TLR4) agonist LPS. One of the techniques used, microarray analysis, identified IRAK-4 kinase-dependent LPS response genes and revealed that the induction of LPS-responsive mRNAs was largely ablated in IRAK-4 KD cells. In summary, our results suggest that IRAK-4 kinase activity plays a critical role in TLR4-mediated induction of inflammatory responses.

Standard name | GSE9650_NAIVE_VS_EFF_CD8_TCELL_UP
Systematic name | M5819
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus effector CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_NAIVE_VS_EFF_CD8_TCELL_DN
Systematic name | M5820
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus effector CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_NAIVE_VS_EXHAUSTED_CD8_TCELL_UP
Systematic name | M5821
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus exhausted CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_NAIVE_VS_EXHAUSTED_CD8_TCELL_DN
Systematic name | M5828
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus exhausted CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_NAIVE_VS_MEMORY_CD8_TCELL_UP
Systematic name | M5831
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of naive CD8 T cells versus memory CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_NAIVE_VS_MEMORY_CD8_TCELL_DN
Systematic name | M5832
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of naive CD8 T cells versus memory CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_EFFECTOR_VS_EXHAUSTED_CD8_TCELL_UP
Systematic name | M5833
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effector CD8 T cells versus exhausted CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_EFFECTOR_VS_EXHAUSTED_CD8_TCELL_DN
Systematic name | M5834
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effector CD8 T cells versus exhausted CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_EFFECTOR_VS_MEMORY_CD8_TCELL_UP
Systematic name | M5836
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of effector CD8 T cells versus memory CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_EFFECTOR_VS_MEMORY_CD8_TCELL_DN
Systematic name | M5837
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of effector CD8 T cells versus memory CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_EXHAUSTED_VS_MEMORY_CD8_TCELL_UP
Systematic name | M5838
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of exhausted CD8 T cells versus memory CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_EXHAUSTED_VS_MEMORY_CD8_TCELL_DN
Systematic name | M5841
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of exhausted CD8 T cells versus memory CD8 T cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_GP33_VS_GP276_LCMV_SPECIFIC_EXHAUSTED_CD8_TCELL_UP
Systematic name | M5842
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of virus specific (gp33) exhausted CD8 T cells versus the virus specific (gp276) cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9650_GP33_VS_GP276_LCMV_SPECIFIC_EXHAUSTED_CD8_TCELL_DN
Systematic name | M5843
Organism | Mus musculus
PMID | 17950003
Authors | Wherry EJ,Ha SJ,Kaech SM,Haining WN,Sarkar S,Kalia V,Subramaniam S,Blattman JN,Barber DL,Ahmed R.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of virus specific (gp33) exhausted CD8 T cells versus the virus specific (gp276) cells.
Full description | CD8 T cells normally differentiate from resting naïve T cells into function effector and then memory CD8 T cells following acute infections. During chronic viral infections, however, virus-specific CD8 T cells often become exhausted. We used microarrays to examine the gene expression differences between naive, effector, memory and exhausted virus-specific CD8 T cells following lymphocytic choriomeningitis virus infection.

Standard name | GSE9988_ANTI_TREM1_VS_LPS_MONOCYTE_UP
Systematic name | M5844
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] versus monocytes treated with 5000 ng/ml LPS (TLR4 agonist).
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_VS_LPS_MONOCYTE_DN
Systematic name | M5845
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] versus monocytes treated with 5000 ng/ml LPS (TLR4 agonist).
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_VS_LOW_LPS_MONOCYTE_UP
Systematic name | M5846
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] versus monocytes treated with 1 ng/ml LPS (TLR4 agonist).
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_VS_LOW_LPS_MONOCYTE_DN
Systematic name | M5847
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] versus monocytes treated with 1 ng/ml LPS (TLR4 agonist).
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_VS_ANTI_TREM1_AND_LPS_MONOCYTE_UP
Systematic name | M5848
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] versus monocytes treated with anti-TREM1 [GeneID=54210] and 5000 ng/ml LPS (TLR4 agonist).
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_VS_ANTI_TREM1_AND_LPS_MONOCYTE_DN
Systematic name | M5849
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] versus monocytes treated with anti-TREM1 [GeneID=54210] and 5000 ng/ml LPS (TLR4 agonist).
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_VS_CTRL_TREATED_MONOCYTES_UP
Systematic name | M5850
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] versus monocytes treated with control IgG.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_VS_CTRL_TREATED_MONOCYTES_DN
Systematic name | M5851
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] versus monocytes treated with control IgG.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_VS_VEHICLE_TREATED_MONOCYTES_UP
Systematic name | M5852
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] versus untreated monocytes.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_VS_VEHICLE_TREATED_MONOCYTES_DN
Systematic name | M5853
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] versus untreated monocytes.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LPS_VS_LOW_LPS_MONOCYTE_UP
Systematic name | M5854
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with 5000 ng/ml LPS (TLR4 agonist) versus those treated with 1 ng/ml LPS (TLR4 agonist).
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LPS_VS_LOW_LPS_MONOCYTE_DN
Systematic name | M5855
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with 5000 ng/ml LPS (TLR4 agonist) versus those treated with 1 ng/ml LPS (TLR4 agonist).
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LPS_VS_LPS_AND_ANTI_TREM1_MONOCYTE_UP
Systematic name | M5856
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with 5000 ng/ml LPS (TLR4 agonist) versus monocytes treated with anti-TREM1 [GeneID=54210].
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LPS_VS_LPS_AND_ANTI_TREM1_MONOCYTE_DN
Systematic name | M5857
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with 5000 ng/ml LPS (TLR4 agonist) versus monocytes treated with anti-TREM1 [GeneID=54210].
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LPS_VS_CTRL_TREATED_MONOCYTE_UP
Systematic name | M5858
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with 5000 ng/ml LPS (TLR4 agonist) versus monocytes treated with control IgG.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LPS_VS_CTRL_TREATED_MONOCYTE_DN
Systematic name | M5859
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with 5000 ng/ml LPS (TLR4 agonist) versus monocytes treated with control IgG.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LPS_VS_VEHICLE_TREATED_MONOCYTE_UP
Systematic name | M5860
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with 1 ng/ml LPS (TLR4 agonist) versus untreated monocytes.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LPS_VS_VEHICLE_TREATED_MONOCYTE_DN
Systematic name | M5861
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with 1 ng/ml LPS (TLR4 agonist) versus untreated monocytes.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LOW_LPS_VS_ANTI_TREM1_AND_LPS_MONOCYTE_UP
Systematic name | M5862
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with 1 ng/ml LPS (TLR4 agonist) versus monocytes treated with anti-TREM1 [GeneID=54210] and 5000 ng/ml LPS (TLR4 agonist).
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LOW_LPS_VS_ANTI_TREM1_AND_LPS_MONOCYTE_DN
Systematic name | M5865
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with 1 ng/ml LPS (TLR4 agonist) versus monocytes treated with anti-TREM1 [GeneID=54210] and 5000 ng/ml LPS (TLR4 agonist).
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LOW_LPS_VS_CTRL_TREATED_MONOCYTE_UP
Systematic name | M5867
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with 1 ng/ml LPS (TLR4 agonist) versus monocytes treated with control IgG.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LOW_LPS_VS_CTRL_TREATED_MONOCYTE_DN
Systematic name | M5870
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with 1 ng/ml LPS (TLR4 agonist) versus monocytes treated with control IgG.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LOW_LPS_VS_VEHICLE_TREATED_MONOCYTE_UP
Systematic name | M5873
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with 1 ng/ml LPS (TLR4 agonist) versus untreated monocytes.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_LOW_LPS_VS_VEHICLE_TREATED_MONOCYTE_DN
Systematic name | M5874
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with 1 ng/ml LPS (TLR4 agonist) versus untreated monocytes.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_AND_LPS_VS_CTRL_TREATED_MONOCYTES_UP
Systematic name | M5875
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] and 5000 ng/ml LPS (TLR4 agonist) versus monocytes treated with control IgG.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_AND_LPS_VS_CTRL_TREATED_MONOCYTES_DN
Systematic name | M5877
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] and 5000 ng/ml LPS (TLR4 agonist) versus monocytes treated with control IgG.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_AND_LPS_VS_VEHICLE_TREATED_MONOCYTES_UP
Systematic name | M5878
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] and 5000 ng/ml LPS (TLR4 agonist) versus untreated monocytes.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE9988_ANTI_TREM1_AND_LPS_VS_VEHICLE_TREATED_MONOCYTES_DN
Systematic name | M5879
Organism | Homo sapiens
PMID | 18292579
Authors | Dower K,Ellis DK,Saraf K,Jelinsky SA,Lin LL.
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison of monocytes treated with anti-TREM1 [GeneID=54210] and 5000 ng/ml LPS (TLR4 agonist) versus untreated monocytes.
Full description | TREM-1 is an orphan immunoreceptor expressed on monocytes, macrophages, and neutrophils. TREM-1 associates with and signals via the adapter protein DAP12/TYROBP, which contains an immunoreceptor tyrosine-based activation motif (ITAM). TREM-1 activation by receptor cross-linking is pro-inflammatory, and can amplify cellular responses to Toll-like receptor (TLR) ligands such as bacterial lipopolysaccharide (LPS). To investigate the cellular consequences of TREM-1 activation, we have characterized global gene expression changes in human monocytes in response to TREM-1 cross-linking in comparison to and combined with LPS. Both TREM-1 activation and LPS up-regulate chemokines, cytokines, matrix metalloproteases, and PTGS/COX2, consistent with a core inflammatory response. However, other immunomodulatory factors are selectively induced, including SPP1 and CSF1 (i.e., M-CSF) by TREM-1 activation and IL-23 and CSF3 (i.e., G-CSF) by LPS. Additionally, cross-talk between TREM-1 activation and LPS occurs on multiple levels. While synergy in GM-CSF protein production is reflected in commensurate mRNA abundance, comparable synergy in IL-1b protein production is not. TREM-1 activation also attenuates the induction of some LPS target genes, including those that encode IL-12 cytokine family subunits. Whereas positive TREM-1 outputs are abolished by the PI3K inhibitor wortmannin, this attenuation is largely PI3K-independent. These experiments provide a detailed analysis of the cellular consequences of TREM-1 activation, and highlight some of the complexity in signal integration between ITAM- and TLR-mediated signaling.

Standard name | GSE369_SOCS3_KO_VS_WT_LIVER_UP
Systematic name | M5960
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes up-regulated in livers: SOCS3 [GeneID=9021] knockout versus wildtype.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_SOCS3_KO_VS_WT_LIVER_DN
Systematic name | M5963
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes down-regulated in livers: SOCS3 [GeneID=9021] knockout versus wildtype.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_SOCS3_KO_VS_WT_LIVER_POST_IL6_INJECTION_UP
Systematic name | M5964
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes up-regulated in livers injected with IL6 [GeneID=3569]: SOCS3 [GeneID=9021] knockout versus wildtype.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_SOCS3_KO_VS_WT_LIVER_POST_IL6_INJECTION_DN
Systematic name | M5966
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes down-regulated in livers injected with IL6 [GeneID=3569]: SOCS3 [GeneID=9021] knockout versus wildtype.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_IFNG_KO_VS_WT_LIVER_UP
Systematic name | M5970
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes up-regulated in liver: IFNG [GeneID=3458] knockout versus wildtype.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_IFNG_KO_VS_WT_LIVER_DN
Systematic name | M5972
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes down-regulated in liver: IFNG [GeneID=3458] knockout versus wildtype.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_PRE_VS_POST_IL6_INJECTION_IFNG_KO_LIVER_UP
Systematic name | M5973
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes up-regulated in liver from SOC3 [GeneID=9021] knockout: untreated versus IL6 [GeneID=3569] injection.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_PRE_VS_POST_IL6_INJECTION_IFNG_KO_LIVER_DN
Systematic name | M5975
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes down-regulated in liver from SOC3 [GeneID=9021] knockout: untreated versus IL6 [GeneID=3569] injection.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_PRE_VS_POST_IL6_INJECTION_SOCS3_KO_LIVER_UP
Systematic name | M5976
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes up-regulated in liver from SOCS3 [GeneID=9021] knockout: untreated versus IL6 [GeneID=3569] injection.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_PRE_VS_POST_IL6_INJECTION_SOCS3_KO_LIVER_DN
Systematic name | M5977
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes down-regulated in liver from SOCS3 [GeneID=9021] knockout: untreated versus IL6 [GeneID=3569] injection.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_SOCS3_KO_VS_IFNG_KO_LIVER_UP
Systematic name | M5978
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes up-regulated in liver with knockouts of: SOCS3 [GeneID=9021] versus IFNG [GeneID=3458].
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_PRE_VS_POST_IL6_INJECTION_IFNG_WT_LIVER_UP
Systematic name | M5979
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes up-regulated in liver: untreated versus IL6 [GeneID=3569] injection.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_PRE_VS_POST_IL6_INJECTION_IFNG_WT_LIVER_DN
Systematic name | M5980
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes down-regulated in liver: untreated versus IL6 [GeneID=3569] injection.
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE369_SOCS3_KO_VS_IFNG_KO_LIVER_DN
Systematic name | M5983
Organism | Mus musculus
PMID | 12754505
Authors | Croker BA,Krebs DL,Zhang JG,Wormald S,Willson TA,Stanley EG,Robb L,Greenhalgh CJ,Förster I,Clausen BE,Nicola NA,Metcalf D,Hilton DJ,Roberts AW,Alexander WS
Category | C7
Sub-category |
Brief description | Genes down-regulated in liver with knockouts of: SOCS3 [GeneID=9021] versus IFNG [GeneID=3458].
Full description | Changes in mouse liver mRNA profiles following intraperitoneal cytokine injection. Either interferon-gamma-/-, albumin-cre(-) Socs3(w/fl) mice, or albumin-cre(+) Socs3(-/fl) mice were injected with either phosphate-buffered saline, interferon-gamma, or interfeukin-6, and livers taken after 4h.

Standard name | GSE411_WT_VS_SOCS3_KO_MACROPHAGE_IL6_STIM_400MIN_DN
Systematic name | M5984
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages treated by IL6 [GeneID=3569] for 400min: wildtype versus SOCS3 [GeneID=9021].
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_UNSTIM_VS_100MIN_IL6_STIM_MACROPHAGE_UP
Systematic name | M5985
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: untreated versus IL6 [GeneID=3569] for 100min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_UNSTIM_VS_100MIN_IL6_STIM_MACROPHAGE_DN
Systematic name | M5986
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: untreated versus IL6 [GeneID=3569] for 100min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_WT_VS_SOCS3_KO_MACROPHAGE_UP
Systematic name | M5990
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: wildtype versus SOCS3 [GeneID=9021].
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_WT_VS_SOCS3_KO_MACROPHAGE_DN
Systematic name | M5991
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: wildtype versus SOCS3 [GeneID=9021].
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_WT_VS_SOCS3_KO_MACROPHAGE_IL6_STIM_100MIN_UP
Systematic name | M5992
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages treated by IL6 [GeneID=3569] for 100min: wildtype versus SOCS3 [GeneID=9021].
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_WT_VS_SOCS3_KO_MACROPHAGE_IL6_STIM_100MIN_DN
Systematic name | M5993
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages treated by IL6 [GeneID=3569] for 100min: wildtype versus SOCS3 [GeneID=9021].
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_WT_VS_SOCS3_KO_MACROPHAGE_IL6_STIM_400MIN_UP
Systematic name | M5994
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages treated by IL6 [GeneID=3569] for 400min: wildtype versus SOCS3 [GeneID=9021].
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_100MIN_VS_400MIN_IL6_STIM_SOCS3_KO_MACROPHAGE_DN
Systematic name | M5995
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with SOCS3 [GeneID=9021] knockout treated by IL6 [GeneID=3569]: 100min versus 400min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_UNSTIM_VS_400MIN_IL6_STIM_MACROPHAGE_DN
Systematic name | M5996
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: untreated versus IL6 [GeneID=3569] for 400min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_100MIN_VS_400MIN_IL6_STIM_MACROPHAGE_UP
Systematic name | M5997
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages treated by IL6 [GeneID=3569]: 100min versus 400min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_100MIN_VS_400MIN_IL6_STIM_MACROPHAGE_DN
Systematic name | M5998
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages treated by IL6 [GeneID=3569]: 100min versus 400min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_UNSTIM_VS_400MIN_IL6_STIM_MACROPHAGE_UP
Systematic name | M5999
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: untreated versus IL6 [GeneID=3569] for 400min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_UNSTIM_VS_100MIN_IL6_STIM_SOCS3_KO_MACROPHAGE_DN
Systematic name | M6000
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with SOCS3 [GeneID=9021]: untreated versus IL6 [GeneID=3569] for 100min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_UNSTIM_VS_400MIN_IL6_STIM_SOCS3_KO_MACROPHAGE_UP
Systematic name | M6001
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with SOCS3 [GeneID=9021]: untreated versus IL6 [GeneID=3569] for 400min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_UNSTIM_VS_400MIN_IL6_STIM_SOCS3_KO_MACROPHAGE_DN
Systematic name | M6003
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with SOCS3 [GeneID=9021]: untreated versus IL6 [GeneID=3569] for 400min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_UNSTIM_VS_100MIN_IL6_STIM_SOCS3_KO_MACROPHAGE_UP
Systematic name | M6004
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with SOCS3 [GeneID=9021]: untreated versus IL6 [GeneID=3569] for 100min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE411_100MIN_VS_400MIN_IL6_STIM_SOCS3_KO_MACROPHAGE_UP
Systematic name | M6005
Organism | Mus musculus
PMID | 12754506
Authors | Lang R,Pauleau AL,Parganas E,Takahashi Y,Mages J,Ihle JN,Rutschman R,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with SOCS3 [GeneID=9021] knockout treated by IL6 [GeneID=3569]: 100min versus 400min.
Full description | Effects of SOCS3 on the transcriptional response of bone marrow-derived macrophages to IL-6. Fetal liver cells from SOCS3+/+ or SOCS3-/- embryos were used to reconstitute recipient mice. Donor derived bone marrow from these mice was differentiated to macrophages. Macrophages were either unstimulated, or stimulated for 100 or 400 minutes with 10 ng/ml IL-6.

Standard name | GSE557_WT_VS_CIITA_KO_DC_UP
Systematic name | M6006
Organism | Mus musculus
PMID | 12910265
Authors | Wong AW,Brickey WJ,Taxman DJ,Deventer van HW,Reed W,Gao JX,Zheng P,Liu Y,Li P,Blum JS,McKinnon KP,Ting JP
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: wildtype versus CIITA [GeneID=4261] knockout.
Full description | Triplicates preparations of RNA from day 10 DC's. Experiment is described in Wong et al 2003 Nat. Immunol.

Standard name | GSE557_WT_VS_CIITA_KO_DC_DN
Systematic name | M6008
Organism | Mus musculus
PMID | 12910265
Authors | Wong AW,Brickey WJ,Taxman DJ,Deventer van HW,Reed W,Gao JX,Zheng P,Liu Y,Li P,Blum JS,McKinnon KP,Ting JP
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: wildtype versus CIITA [GeneID=4261] knockout.
Full description | Triplicates preparations of RNA from day 10 DC's. Experiment is described in Wong et al 2003 Nat. Immunol.

Standard name | GSE557_WT_VS_I_AB_KO_DC_UP
Systematic name | M6009
Organism | Mus musculus
PMID | 12910265
Authors | Wong AW,Brickey WJ,Taxman DJ,Deventer van HW,Reed W,Gao JX,Zheng P,Liu Y,Li P,Blum JS,McKinnon KP,Ting JP
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: wildtype versus I ab-/- mice.
Full description | Triplicates preparations of RNA from day 10 DC's. Experiment is described in Wong et al 2003 Nat. Immunol.

Standard name | GSE557_WT_VS_I_AB_KO_DC_DN
Systematic name | M6010
Organism | Mus musculus
PMID | 12910265
Authors | Wong AW,Brickey WJ,Taxman DJ,Deventer van HW,Reed W,Gao JX,Zheng P,Liu Y,Li P,Blum JS,McKinnon KP,Ting JP
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: wildtype versus I ab-/- mice.
Full description | Triplicates preparations of RNA from day 10 DC's. Experiment is described in Wong et al 2003 Nat. Immunol.

Standard name | GSE557_CIITA_KO_VS_I_AB_KO_DC_UP
Systematic name | M6012
Organism | Mus musculus
PMID | 12910265
Authors | Wong AW,Brickey WJ,Taxman DJ,Deventer van HW,Reed W,Gao JX,Zheng P,Liu Y,Li P,Blum JS,McKinnon KP,Ting JP
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: CIITA [GeneID=4261] knockout versus I ab-/- mice.
Full description | Triplicates preparations of RNA from day 10 DC's. Experiment is described in Wong et al 2003 Nat. Immunol.

Standard name | GSE557_CIITA_KO_VS_I_AB_KO_DC_DN
Systematic name | M6014
Organism | Mus musculus
PMID | 12910265
Authors | Wong AW,Brickey WJ,Taxman DJ,Deventer van HW,Reed W,Gao JX,Zheng P,Liu Y,Li P,Blum JS,McKinnon KP,Ting JP
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: CIITA [GeneID=4261] knockout versus I ab-/- mice.
Full description | Triplicates preparations of RNA from day 10 DC's. Experiment is described in Wong et al 2003 Nat. Immunol.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL4_TREATED_ACT_CD4_TCELL_2H_DN
Systematic name | M6015
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 and IL4 [GeneID=7040;3565] (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL4_TREATED_ACT_CD4_TCELL_2H_UP
Systematic name | M6016
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 and IL4 [GeneID=7040;3565] (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_ACT_CD4_TCELL_6H_UP
Systematic name | M6017
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_ACT_CD4_TCELL_6H_DN
Systematic name | M6018
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL4_TREATED_ACT_CD4_TCELL_4H_UP
Systematic name | M6019
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 and IL4 [GeneID=7040;3565] (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_ACT_CD4_TCELL_2H_DN
Systematic name | M6020
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL4_TREATED_ACT_CD4_TCELL_6H_DN
Systematic name | M6021
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL4 [GeneID=3565] (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL4_TREATED_ACT_CD4_TCELL_48H_UP
Systematic name | M6022
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL4 [GeneID=3565] (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL4_TREATED_ACT_CD4_TCELL_48H_DN
Systematic name | M6024
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL4 [GeneID=3565] (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_ACT_CD4_TCELL_2H_UP
Systematic name | M6025
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_48H_UP
Systematic name | M6027
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (48h) versus TGFB1 [GeneID=7040] and IL-12 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_48H_DN
Systematic name | M6028
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (48h) versus TGFB1 [GeneID=7040] and IL-12 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_IL4_TREATED_ACT_CD4_TCELL_48H_UP
Systematic name | M6029
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (48h) versus IL4 [GeneID=3565] (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_IL4_TREATED_ACT_CD4_TCELL_48H_DN
Systematic name | M6030
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (48h) versus IL4 [GeneID=3565] (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_ACT_VS_ACT_CD4_TCELL_48H_UP
Systematic name | M6032
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (48h) versus untreated (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_ACT_VS_ACT_CD4_TCELL_48H_DN
Systematic name | M6033
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (48h) versus untreated (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_VS_IL4_TREATED_ACT_CD4_TCELL_48H_UP
Systematic name | M6035
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (48h) versus IL4 [GeneID=3565] (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL4_TREATED_ACT_CD4_TCELL_2H_DN
Systematic name | M6037
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL4 [GeneID=3565] (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL4_TREATED_ACT_CD4_TCELL_6H_UP
Systematic name | M6038
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL4 [GeneID=3565] (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_ACT_VS_ACT_CD4_TCELL_48H_DN
Systematic name | M6039
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (48h) versus untreated (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL4_ACT_VS_ACT_CD4_TCELL_48H_UP
Systematic name | M6040
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL4 [GeneID=3565] (48h) versus untreated (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL4_ACT_VS_ACT_CD4_TCELL_48H_DN
Systematic name | M6042
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL4 [GeneID=3565] (48h) versus untreated (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL12_TREATED_ACT_CD4_TCELL_6H_DN
Systematic name | M6043
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL-12 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL12_TREATED_ACT_CD4_TCELL_48H_UP
Systematic name | M6044
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL-12 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL12_TREATED_ACT_CD4_TCELL_48H_DN
Systematic name | M6045
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL-12 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_2H_UP
Systematic name | M6047
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 [GeneID=7040] and IL-12 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_2H_DN
Systematic name | M6048
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 [GeneID=7040] and IL-12 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_6H_UP
Systematic name | M6049
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 [GeneID=7040] and IL-12 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_6H_DN
Systematic name | M6053
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 [GeneID=7040] and IL-12 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_48H_UP
Systematic name | M6055
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 [GeneID=7040] and IL-12 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_48H_DN
Systematic name | M6056
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 [GeneID=7040] and IL-12 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL4_TREATED_ACT_CD4_TCELL_2H_UP
Systematic name | M6057
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL4 [GeneID=3565] (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_6H_UP
Systematic name | M6059
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (6h) versus TGFB1 [GeneID=7040] and IL-12 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_6H_DN
Systematic name | M6060
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (6h) versus TGFB1 [GeneID=7040] and IL-12 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_IL4_TREATED_ACT_CD4_TCELL_6H_UP
Systematic name | M6061
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (6h) versus IL4 [GeneID=3565] (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_IL4_TREATED_ACT_CD4_TCELL_6H_DN
Systematic name | M6062
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (6h) versus IL4 [GeneID=3565] (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_ACT_VS_ACT_CD4_TCELL_6H_UP
Systematic name | M6063
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (6h) versus untreated (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_ACT_VS_ACT_CD4_TCELL_6H_DN
Systematic name | M6064
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (6h) versus untreated (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_VS_IL4_TREATED_ACT_CD4_TCELL_6H_UP
Systematic name | M6065
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (6h) versus IL4 [GeneID=3565] (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_VS_IL4_TREATED_ACT_CD4_TCELL_6H_DN
Systematic name | M6066
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (6h) versus IL4 [GeneID=3565] (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_ACT_VS_ACT_CD4_TCELL_6H_UP
Systematic name | M6067
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (6h) versus untreated (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_ACT_VS_ACT_CD4_TCELL_6H_DN
Systematic name | M6068
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (6h) versus untreated (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_ACT_CD4_TCELL_48H_UP
Systematic name | M6069
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_ACT_CD4_TCELL_48H_DN
Systematic name | M6073
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL12_TREATED_ACT_CD4_TCELL_2H_UP
Systematic name | M6074
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (2h) versus IL-12 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL12_TREATED_ACT_CD4_TCELL_2H_DN
Systematic name | M6075
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (2h) versus IL-12 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_2H_UP
Systematic name | M6076
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (2h) versus TGFB1 [GeneID=7040] and IL-12 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_2H_DN
Systematic name | M6077
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (2h) versus TGFB1 [GeneID=7040] and IL-12 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL4_TREATED_ACT_CD4_TCELL_2H_UP
Systematic name | M6079
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (2h) versus IL4 [GeneID=3565] (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL4_TREATED_ACT_CD4_TCELL_2H_DN
Systematic name | M6080
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (2h) versus IL4 [GeneID=3565] (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_ACT_VS_ACT_CD4_TCELL_2H_UP
Systematic name | M6081
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (2h) versus untreated (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_ACT_VS_ACT_CD4_TCELL_2H_DN
Systematic name | M6082
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (2h) versus untreated (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_2H_UP
Systematic name | M6083
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (2h) versus TGFB1 [GeneID=7040] and IL-12 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_2H_DN
Systematic name | M6084
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (2h) versus TGFB1 [GeneID=7040] and IL-12 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_IL4_TREATED_ACT_CD4_TCELL_2H_UP
Systematic name | M6085
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (2h) versus IL4 [GeneID=3565] (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_VS_IL4_TREATED_ACT_CD4_TCELL_2H_DN
Systematic name | M6086
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (2h) versus IL4 [GeneID=3565] (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL4_TREATED_ACT_CD4_TCELL_4H_DN
Systematic name | M6087
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 and IL4 [GeneID=7040;3565] (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL4_TREATED_ACT_CD4_TCELL_48H_UP
Systematic name | M6088
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 and IL4 [GeneID=7040;3565] (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_TGFB_AND_IL4_TREATED_ACT_CD4_TCELL_48H_DN
Systematic name | M6089
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by TGFB1 and IL4 [GeneID=7040;3565] (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL12_TREATED_ACT_CD4_TCELL_2H_UP
Systematic name | M6090
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL-12 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL12_TREATED_ACT_CD4_TCELL_2H_DN
Systematic name | M6091
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL-12 (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_UNTREATED_VS_IL12_TREATED_ACT_CD4_TCELL_6H_UP
Systematic name | M6092
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated (0h) versus activated by anti-CD3 and anti-CD28 and then stimulated by IL-12 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL4_ACT_VS_ACT_CD4_TCELL_2H_UP
Systematic name | M6094
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL4 [GeneID=3565] (2h) versus untreated (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL4_ACT_VS_ACT_CD4_TCELL_2H_DN
Systematic name | M6095
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL4 [GeneID=3565] (2h) versus untreated (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL12_TREATED_ACT_CD4_TCELL_6H_UP
Systematic name | M6096
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (6h) versus IL-12 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL12_TREATED_ACT_CD4_TCELL_6H_DN
Systematic name | M6098
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (6h) versus IL-12 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_6H_UP
Systematic name | M6099
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (6h) versus TGFB1 [GeneID=7050] and IL-12 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_6H_DN
Systematic name | M6102
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (6h) versus TGFB1 [GeneID=7050] and IL-12 (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL4_TREATED_ACT_CD4_TCELL_6H_UP
Systematic name | M6103
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (6h) versus IL4 [GeneID=3565] (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL4_TREATED_ACT_CD4_TCELL_6H_DN
Systematic name | M6104
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (6h) versus IL4 [GeneID=3565] (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_ACT_VS_ACT_CD4_TCELL_6H_UP
Systematic name | M6106
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (6h) versus untreated (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_ACT_VS_ACT_CD4_TCELL_6H_DN
Systematic name | M6107
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (6h) versus untreated (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL12_TREATED_ACT_CD4_TCELL_48H_DN
Systematic name | M6108
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (48h) versus IL-12 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_48H_UP
Systematic name | M6109
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (48h) versus TGFB1 [GeneID-7040] and IL-12 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_TGFB_AND_IL12_TREATED_ACT_CD4_TCELL_48H_DN
Systematic name | M6111
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (48h) versus TGFB1 [GeneID-7040] and IL-12 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL4_TREATED_ACT_CD4_TCELL_48H_UP
Systematic name | M6112
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (48h) versus IL4 [GeneID=3565] (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL4_TREATED_ACT_CD4_TCELL_48H_DN
Systematic name | M6114
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (48h) versus IL4 [GeneID=3565] (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_ACT_VS_ACT_CD4_TCELL_48H_UP
Systematic name | M6115
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (48h) versus untreated (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_ACT_VS_ACT_CD4_TCELL_48H_DN
Systematic name | M6118
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (48h) versus untreated (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL4_ACT_VS_ACT_CD4_TCELL_6H_DN
Systematic name | M6119
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL4 [GeneID=3565] (6h) versus untreated (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_TGFB_AND_IL4_VS_IL12_TREATED_ACT_CD4_TCELL_48H_UP
Systematic name | M6120
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 and IL4 [GeneID=7040;3565] (48h) versus IL-12 (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_VS_IL4_TREATED_ACT_CD4_TCELL_2H_UP
Systematic name | M6123
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (2h) versus IL4 [GeneID=3565] (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL4_ACT_VS_ACT_CD4_TCELL_6H_UP
Systematic name | M6124
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL4 [GeneID=3565] (6h) versus untreated (6h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_ACT_VS_ACT_CD4_TCELL_2H_UP
Systematic name | M6125
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (2h) versus untreated (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_ACT_VS_ACT_CD4_TCELL_2H_DN
Systematic name | M6126
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (2h) versus untreated (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_ACT_VS_ACT_CD4_TCELL_2H_DN
Systematic name | M6127
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (2h) versus untreated (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_VS_IL4_TREATED_ACT_CD4_TCELL_2H_DN
Systematic name | M6128
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (2h) versus IL4 [GeneID=3565] (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_VS_IL4_TREATED_ACT_CD4_TCELL_48H_DN
Systematic name | M6129
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (48h) versus IL4 [GeneID=3565] (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_ACT_VS_ACT_CD4_TCELL_2H_UP
Systematic name | M6130
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: IL-12 (2h) versus untreated (2h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE2770_IL12_AND_TGFB_ACT_VS_ACT_CD4_TCELL_48H_UP
Systematic name | M6131
Organism | Homo sapiens
PMID | 14607935
Authors | Lund R,Aittokallio T,Nevalainen O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells activated by anti-CD3 and anti-CD28: TGFB1 [GeneID=7040] and IL-12 (48h) versus untreated (48h).
Full description | Th1 and Th2 cells arise from a common precursor cell in response to triggering through the TCR and cytokine receptors for IL-12 or IL-4. This leads to activation of complex signaling pathways, which are not known in detail. Disturbances in the balance between type 1 and type 2 responses can lead to certain immune-mediated diseases. Thus, it is important to understand how Th1 and Th2 cells are generated. To clarify the mechanisms as to how IL-12 and IL-4 induce Th1 and Th2 differentiation and how TGF-beta can inhibit this process, we have used oligonucleotide arrays to examine the early polarization of Th1 and Th2 cells in the presence and absence of TGF-beta after 0, 2, 6 and 48 hours of polarization.

Standard name | GSE3400_UNTREATED_VS_IFNB_TREATED_MEF_UP
Systematic name | M6133
Organism | Mus musculus
PMID | 15131130
Authors | Pfeffer LM,Kim JG,Pfeffer SR,Carrigan DJ,Baker DP,Wei L,Homayouni R
Category | C7
Sub-category |
Brief description | Genes up-regulated in mouse embryonic fibroblasts (MEF): untreated versus interferon beta.
Full description | A number of IFN-induced proteins are believed to be responsible for the antiviral state induced by IFNs. Our microarray analysis of IFN-regulated genes in MEFs from wild-type mice identified 124 probe sets that were differentially regulated upon IFN treatment. This group consisted of many known ISGs such as Ifit1, Gbp2, mx1, Isg15, Stat1, nmi, mx2, If204, Adar, Irf1, and protein kinase R.

Standard name | GSE3400_UNTREATED_VS_IFNB_TREATED_MEF_DN
Systematic name | M6134
Organism | Mus musculus
PMID | 15131130
Authors | Pfeffer LM,Kim JG,Pfeffer SR,Carrigan DJ,Baker DP,Wei L,Homayouni R
Category | C7
Sub-category |
Brief description | Genes down-regulated in mouse embryonic fibroblasts (MEF): untreated versus interferon beta.
Full description | A number of IFN-induced proteins are believed to be responsible for the antiviral state induced by IFNs. Our microarray analysis of IFN-regulated genes in MEFs from wild-type mice identified 124 probe sets that were differentially regulated upon IFN treatment. This group consisted of many known ISGs such as Ifit1, Gbp2, mx1, Isg15, Stat1, nmi, mx2, If204, Adar, Irf1, and protein kinase R.

Standard name | GSE1112_HY_CD8AB_VS_HY_CD8AA_THYMOCYTE_RTOC_CULTURE_DN
Systematic name | M6138
Organism | Mus musculus
PMID | 15133507
Authors | Yamagata T,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 alphabeta HY thymocyte RTOC culture versus CD8 alphaalpha HY thymocyte RTOC culture.
Full description | Four independent chip hybridization with RNAs from four independent RTOC cultures.

Standard name | GSE1112_OT1_VS_HY_CD8AB_THYMOCYTE_RTOC_CULTURE_UP
Systematic name | M6140
Organism | Mus musculus
PMID | 15133507
Authors | Yamagata T,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 alphabeta OT1 thymocyte RTOC culture versus CD8 alphabeta HY thymocyte RTOC culture.
Full description | Four independent chip hybridization with RNAs from four independent RTOC cultures.

Standard name | GSE1112_OT1_CD8AB_VS_HY_CD8AA_THYMOCYTE_RTOC_CULTURE_UP
Systematic name | M6141
Organism | Mus musculus
PMID | 15133507
Authors | Yamagata T,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 alphabeta OT1 thymocyte RTOC culture versus CD8 alphaalpha HY thymocyte RTOC culture.
Full description | Four independent chip hybridization with RNAs from four independent RTOC cultures.

Standard name | GSE1112_OT1_CD8AB_VS_HY_CD8AA_THYMOCYTE_RTOC_CULTURE_DN
Systematic name | M6142
Organism | Mus musculus
PMID | 15133507
Authors | Yamagata T,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 alphabeta OT1 thymocyte RTOC culture versus CD8 alphaalpha HY thymocyte RTOC culture.
Full description | Four independent chip hybridization with RNAs from four independent RTOC cultures.

Standard name | GSE1112_HY_CD8AB_VS_HY_CD8AA_THYMOCYTE_RTOC_CULTURE_UP
Systematic name | M6143
Organism | Mus musculus
PMID | 15133507
Authors | Yamagata T,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 alphabeta HY thymocyte RTOC culture versus CD8 alphaalpha HY thymocyte RTOC culture.
Full description | Four independent chip hybridization with RNAs from four independent RTOC cultures.

Standard name | GSE1112_OT1_VS_HY_CD8AB_THYMOCYTE_RTOC_CULTURE_DN
Systematic name | M6146
Organism | Mus musculus
PMID | 15133507
Authors | Yamagata T,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 alphabeta OT1 thymocyte RTOC culture versus CD8 alphabeta HY thymocyte RTOC culture.
Full description | Four independent chip hybridization with RNAs from four independent RTOC cultures.

Standard name | GSE1740_MCSF_VS_MCSF_AND_IFNG_DAY2_DERIVED_MACROPHAGE_WITH_IFNA_STIM_DN
Systematic name | M6147
Organism | Homo sapiens
PMID | 15467722
Authors | Tassiulas I,Hu X,Ho H,Kashyap Y,Paik P,Hu Y,Lowell CA,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived macrophages: no priming, stimulated by interferon alpha versus primed by IFNG [GeneID=3458] and then stimulated by interferon alpha.
Full description | Type I IFN-inducible gene expression in human blood monocytes primed with Type II IFN.

Standard name | GSE1740_UNSTIM_VS_IFNA_STIMULATED_MCSF_DERIVED_MACROPHAGE_UP
Systematic name | M6148
Organism | Homo sapiens
PMID | 15467722
Authors | Tassiulas I,Hu X,Ho H,Kashyap Y,Paik P,Hu Y,Lowell CA,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived macrophages: untreated versus stimulated by interferon alpha.
Full description | Type I IFN-inducible gene expression in human blood monocytes primed with Type II IFN.

Standard name | GSE1740_UNSTIM_VS_IFNA_STIMULATED_MCSF_DERIVED_MACROPHAGE_DN
Systematic name | M6150
Organism | Homo sapiens
PMID | 15467722
Authors | Tassiulas I,Hu X,Ho H,Kashyap Y,Paik P,Hu Y,Lowell CA,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived macrophages: untreated versus stimulated by interferon alpha.
Full description | Type I IFN-inducible gene expression in human blood monocytes primed with Type II IFN.

Standard name | GSE1740_UNSTIM_VS_IFNA_STIMULATED_MCSF_IFNG_DERIVED_MACROPHAGE_DN
Systematic name | M6152
Organism | Homo sapiens
PMID | 15467722
Authors | Tassiulas I,Hu X,Ho H,Kashyap Y,Paik P,Hu Y,Lowell CA,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived macrophages primed by IFNG [GeneID=3458]: untreated versus interferon alpha.
Full description | Type I IFN-inducible gene expression in human blood monocytes primed with Type II IFN.

Standard name | GSE1740_MCSF_VS_MCSF_AND_IFNG_DAY2_DERIVED_MACROPHAGE_UP
Systematic name | M6156
Organism | Homo sapiens
PMID | 15467722
Authors | Tassiulas I,Hu X,Ho H,Kashyap Y,Paik P,Hu Y,Lowell CA,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived macrophages: no priming versus primed by IFNG [GeneID=3458].
Full description | Type I IFN-inducible gene expression in human blood monocytes primed with Type II IFN.

Standard name | GSE1740_MCSF_VS_MCSF_AND_IFNG_DAY2_DERIVED_MACROPHAGE_DN
Systematic name | M6157
Organism | Homo sapiens
PMID | 15467722
Authors | Tassiulas I,Hu X,Ho H,Kashyap Y,Paik P,Hu Y,Lowell CA,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived macrophages: no priming versus primed by IFNG [GeneID=3458].
Full description | Type I IFN-inducible gene expression in human blood monocytes primed with Type II IFN.

Standard name | GSE1740_MCSF_VS_MCSF_AND_IFNG_DAY2_DERIVED_MACROPHAGE_WITH_IFNA_STIM_UP
Systematic name | M6158
Organism | Homo sapiens
PMID | 15467722
Authors | Tassiulas I,Hu X,Ho H,Kashyap Y,Paik P,Hu Y,Lowell CA,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived macrophages: no priming, stimulated by interferon alpha versus primed by IFNG [GeneID=3458] and then stimulated by interferon alpha.
Full description | Type I IFN-inducible gene expression in human blood monocytes primed with Type II IFN.

Standard name | GSE1740_UNSTIM_VS_IFNA_STIMULATED_MCSF_IFNG_DERIVED_MACROPHAGE_UP
Systematic name | M6159
Organism | Homo sapiens
PMID | 15467722
Authors | Tassiulas I,Hu X,Ho H,Kashyap Y,Paik P,Hu Y,Lowell CA,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived macrophages primed by IFNG [GeneID=3458]: untreated versus interferon alpha.
Full description | Type I IFN-inducible gene expression in human blood monocytes primed with Type II IFN.

Standard name | GSE1791_CTRL_VS_NEUROMEDINU_IN_T_CELL_LINE_3H_DN
Systematic name | M6160
Organism | Mus musculus
PMID | 15585845
Authors | Johnson EN,Appelbaum ER,Carpenter DC,Cox RF,Disa J,Foley JJ,Ghosh SK,Naselsky DP,Pullen MA,Sarau HM,Scheff SR,Steplewski KM,Zaks-Zilberman M,Aiyar N
Category | C7
Sub-category |
Brief description | Genes down-regulated in D10.G4.1 T cell line (3h): control versus treated with NMU [GeneID=10874].
Full description | Effects of Neuromedin-U on gene expression in mouse D10.G4.1 T-cells natively expressing the GPCR Axor13

Standard name | GSE1791_CTRL_VS_NEUROMEDINU_IN_T_CELL_LINE_0.8H_DN
Systematic name | M6163
Organism | Mus musculus
PMID | 15585845
Authors | Johnson EN,Appelbaum ER,Carpenter DC,Cox RF,Disa J,Foley JJ,Ghosh SK,Naselsky DP,Pullen MA,Sarau HM,Scheff SR,Steplewski KM,Zaks-Zilberman M,Aiyar N
Category | C7
Sub-category |
Brief description | Genes down-regulated in D10.G4.1 T cell line (0.8h): control versus treated with NMU [GeneID=10874].
Full description | Effects of Neuromedin-U on gene expression in mouse D10.G4.1 T-cells natively expressing the GPCR Axor13

Standard name | GSE1791_CTRL_VS_NEUROMEDINU_IN_T_CELL_LINE_0.8H_UP
Systematic name | M6165
Organism | Mus musculus
PMID | 15585845
Authors | Johnson EN,Appelbaum ER,Carpenter DC,Cox RF,Disa J,Foley JJ,Ghosh SK,Naselsky DP,Pullen MA,Sarau HM,Scheff SR,Steplewski KM,Zaks-Zilberman M,Aiyar N
Category | C7
Sub-category |
Brief description | Genes up-regulated in D10.G4.1 T cell line (0.8h): control versus treated with NMU [GeneID=10874].
Full description | Effects of Neuromedin-U on gene expression in mouse D10.G4.1 T-cells natively expressing the GPCR Axor13

Standard name | GSE1791_CTRL_VS_NEUROMEDINU_IN_T_CELL_LINE_6H_UP
Systematic name | M6166
Organism | Mus musculus
PMID | 15585845
Authors | Johnson EN,Appelbaum ER,Carpenter DC,Cox RF,Disa J,Foley JJ,Ghosh SK,Naselsky DP,Pullen MA,Sarau HM,Scheff SR,Steplewski KM,Zaks-Zilberman M,Aiyar N
Category | C7
Sub-category |
Brief description | Genes up-regulated in D10.G4.1 T cell line (6h): control versus treated with NMU [GeneID=10874].
Full description | Effects of Neuromedin-U on gene expression in mouse D10.G4.1 T-cells natively expressing the GPCR Axor13

Standard name | GSE1791_CTRL_VS_NEUROMEDINU_IN_T_CELL_LINE_3H_UP
Systematic name | M6167
Organism | Mus musculus
PMID | 15585845
Authors | Johnson EN,Appelbaum ER,Carpenter DC,Cox RF,Disa J,Foley JJ,Ghosh SK,Naselsky DP,Pullen MA,Sarau HM,Scheff SR,Steplewski KM,Zaks-Zilberman M,Aiyar N
Category | C7
Sub-category |
Brief description | Genes up-regulated in D10.G4.1 T cell line (3h): control versus treated with NMU [GeneID=10874].
Full description | Effects of Neuromedin-U on gene expression in mouse D10.G4.1 T-cells natively expressing the GPCR Axor13

Standard name | GSE1791_CTRL_VS_NEUROMEDINU_IN_T_CELL_LINE_12H_UP
Systematic name | M6168
Organism | Mus musculus
PMID | 15585845
Authors | Johnson EN,Appelbaum ER,Carpenter DC,Cox RF,Disa J,Foley JJ,Ghosh SK,Naselsky DP,Pullen MA,Sarau HM,Scheff SR,Steplewski KM,Zaks-Zilberman M,Aiyar N
Category | C7
Sub-category |
Brief description | Genes up-regulated in D10.G4.1 T cell line (12h): control versus treated with NMU [GeneID=10874].
Full description | Effects of Neuromedin-U on gene expression in mouse D10.G4.1 T-cells natively expressing the GPCR Axor13

Standard name | GSE1791_CTRL_VS_NEUROMEDINU_IN_T_CELL_LINE_12H_DN
Systematic name | M6169
Organism | Mus musculus
PMID | 15585845
Authors | Johnson EN,Appelbaum ER,Carpenter DC,Cox RF,Disa J,Foley JJ,Ghosh SK,Naselsky DP,Pullen MA,Sarau HM,Scheff SR,Steplewski KM,Zaks-Zilberman M,Aiyar N
Category | C7
Sub-category |
Brief description | Genes down-regulated in D10.G4.1 T cell line (12h): control versus treated with NMU [GeneID=10874].
Full description | Effects of Neuromedin-U on gene expression in mouse D10.G4.1 T-cells natively expressing the GPCR Axor13

Standard name | GSE1791_CTRL_VS_NEUROMEDINU_IN_T_CELL_LINE_6H_DN
Systematic name | M6172
Organism | Mus musculus
PMID | 15585845
Authors | Johnson EN,Appelbaum ER,Carpenter DC,Cox RF,Disa J,Foley JJ,Ghosh SK,Naselsky DP,Pullen MA,Sarau HM,Scheff SR,Steplewski KM,Zaks-Zilberman M,Aiyar N
Category | C7
Sub-category |
Brief description | Genes down-regulated in D10.G4.1 T cell line (6h): control versus treated with NMU [GeneID=10874].
Full description | Effects of Neuromedin-U on gene expression in mouse D10.G4.1 T-cells natively expressing the GPCR Axor13

Standard name | GSE2128_CTRL_VS_MIMETOPE_NEGATIVE_SELECTION_DP_THYMOCYTE_NOD_DN
Systematic name | M6174
Organism | Mus musculus
PMID | 15780994
Authors | Zucchelli S,Holler P,Yamagata T,Roy M,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in NOD CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with no peptide 0h versus NOD CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with mimetope negative sel 16h.
Full description | Fetal thymic organ culture (FTOC) DC2.5 CD4+CD8+ thymocytes from B6g7 or NOD background. 0 or 16 hour after addition of the BDC mimitope

Standard name | GSE2128_C57BL6_VS_NOD_CD4CD8_DP_THYMOCYTE_UP
Systematic name | M6178
Organism | Mus musculus
PMID | 15780994
Authors | Zucchelli S,Holler P,Yamagata T,Roy M,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes from: B6 versus NOD mice.
Full description | Fetal thymic organ culture (FTOC) DC2.5 CD4+CD8+ thymocytes from B6g7 or NOD background. 0 or 16 hour after addition of the BDC mimitope

Standard name | GSE2128_CTRL_VS_MIMETOPE_NEGATIVE_SELECTION_DP_THYMOCYTE_C57BL6_UP
Systematic name | M6180
Organism | Mus musculus
PMID | 15780994
Authors | Zucchelli S,Holler P,Yamagata T,Roy M,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in C57BL6 CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with no peptide 0h versus C57BL6 CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with mimetope negative sel 16h.
Full description | Fetal thymic organ culture (FTOC) DC2.5 CD4+CD8+ thymocytes from B6g7 or NOD background. 0 or 16 hour after addition of the BDC mimitope

Standard name | GSE2128_C57BL6_VS_NOD_THYMOCYTE_MIMETOPE_NEGATIVE_SELECTION_DN
Systematic name | M6182
Organism | Mus musculus
PMID | 15780994
Authors | Zucchelli S,Holler P,Yamagata T,Roy M,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in C57BL6 CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with mimetope negative sel 16h versus NOD CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with mimetope negative sel 16h.
Full description | Fetal thymic organ culture (FTOC) DC2.5 CD4+CD8+ thymocytes from B6g7 or NOD background. 0 or 16 hour after addition of the BDC mimitope

Standard name | GSE2128_C57BL6_VS_NOD_THYMOCYTE_UP
Systematic name | M6183
Organism | Mus musculus
PMID | 15780994
Authors | Zucchelli S,Holler P,Yamagata T,Roy M,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in C57BL6 CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with no peptide 0h versus NOD CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with no peptide 0h.
Full description | Fetal thymic organ culture (FTOC) DC2.5 CD4+CD8+ thymocytes from B6g7 or NOD background. 0 or 16 hour after addition of the BDC mimitope

Standard name | GSE2128_C57BL6_VS_NOD_CD4CD8_DP_THYMOCYTE_DN
Systematic name | M6184
Organism | Mus musculus
PMID | 15780994
Authors | Zucchelli S,Holler P,Yamagata T,Roy M,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes from: B6 versus NOD mice.
Full description | Fetal thymic organ culture (FTOC) DC2.5 CD4+CD8+ thymocytes from B6g7 or NOD background. 0 or 16 hour after addition of the BDC mimitope

Standard name | GSE2128_CTRL_VS_MIMETOPE_NEGATIVE_SELECTION_DP_THYMOCYTE_C57BL6_DN
Systematic name | M6185
Organism | Mus musculus
PMID | 15780994
Authors | Zucchelli S,Holler P,Yamagata T,Roy M,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in C57BL6 CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with no peptide 0h versus C57BL6 CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with mimetope negative sel 16h.
Full description | Fetal thymic organ culture (FTOC) DC2.5 CD4+CD8+ thymocytes from B6g7 or NOD background. 0 or 16 hour after addition of the BDC mimitope

Standard name | GSE2128_CTRL_VS_MIMETOPE_NEGATIVE_SELECTION_DP_THYMOCYTE_NOD_UP
Systematic name | M6186
Organism | Mus musculus
PMID | 15780994
Authors | Zucchelli S,Holler P,Yamagata T,Roy M,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in NOD CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with no peptide 0h versus NOD CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with mimetope negative sel 16h.
Full description | Fetal thymic organ culture (FTOC) DC2.5 CD4+CD8+ thymocytes from B6g7 or NOD background. 0 or 16 hour after addition of the BDC mimitope

Standard name | GSE2128_C57BL6_VS_NOD_THYMOCYTE_DN
Systematic name | M6187
Organism | Mus musculus
PMID | 15780994
Authors | Zucchelli S,Holler P,Yamagata T,Roy M,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in C57BL6 CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with no peptide 0h versus NOD CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with no peptide 0h.
Full description | Fetal thymic organ culture (FTOC) DC2.5 CD4+CD8+ thymocytes from B6g7 or NOD background. 0 or 16 hour after addition of the BDC mimitope

Standard name | GSE2128_C57BL6_VS_NOD_THYMOCYTE_MIMETOPE_NEGATIVE_SELECTION_UP
Systematic name | M6188
Organism | Mus musculus
PMID | 15780994
Authors | Zucchelli S,Holler P,Yamagata T,Roy M,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in C57BL6 CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with mimetope negative sel 16h versus NOD CD4 CD8 double positive thymocyte transgenic for the BDC2.5 TCR incubated with mimetope negative sel 16h.
Full description | Fetal thymic organ culture (FTOC) DC2.5 CD4+CD8+ thymocytes from B6g7 or NOD background. 0 or 16 hour after addition of the BDC mimitope

Standard name | GSE2124_CTRL_VS_LYMPHOTOXIN_BETA_TREATED_MLN_DN
Systematic name | M6190
Organism | Mus musculus
PMID | 15843551
Authors | Huber C,Thielen C,Seeger H,Schwarz P,Montrasio F,Wilson MR,Heinen E,Fu YX,Miele G,Aguzzi A
Category | C7
Sub-category |
Brief description | Genes down-regulated in mesenteric lymph nodes: control versus 1 day after injection with soluble form of LTB [GeneID=4050].
Full description | treatment of mesenteric lymph nodes with soluble lymphotoxin-beta receptor for 0,1,2,3,27 and 35 days

Standard name | GSE2124_CTRL_VS_LYMPHOTOXIN_BETA_TREATED_MLN_UP
Systematic name | M6191
Organism | Mus musculus
PMID | 15843551
Authors | Huber C,Thielen C,Seeger H,Schwarz P,Montrasio F,Wilson MR,Heinen E,Fu YX,Miele G,Aguzzi A
Category | C7
Sub-category |
Brief description | Genes up-regulated in mesenteric lymph nodes: control versus 1 day after injection with soluble form of LTB [GeneID=4050].
Full description | treatment of mesenteric lymph nodes with soluble lymphotoxin-beta receptor for 0,1,2,3,27 and 35 days

Standard name | GSE2405_S_AUREUS_VS_UNTREATED_NEUTROPHIL_UP
Systematic name | M6192
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (9h): S. aureus infection versus control.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_24H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_DN
Systematic name | M6193
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (24h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_HEAT_KILLED_VS_LIVE_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_9H_UP
Systematic name | M6194
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (9h) infection by A. phagocytophilum: heat killed versus live bacteria.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_HEAT_KILLED_VS_LIVE_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_9H_DN
Systematic name | M6196
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (9h) infection by A. phagocytophilum: heat killed versus live bacteria.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_12H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_UP
Systematic name | M6197
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (12h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_HEAT_KILLED_LYSATE_VS_LIVE_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_9H_UP
Systematic name | M6198
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (9h): treated by heat killed HC60 cell (promyelocytic leukemia) lysate versus A. phagocytophilum infection.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_HEAT_KILLED_LYSATE_VS_LIVE_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_9H_DN
Systematic name | M6199
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (9h): treated by heat killed HC60 cell (promyelocytic leukemia) lysate versus A. phagocytophilum infection.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_HEAT_KILLED_LYSATE_VS_LIVE_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_24H_UP
Systematic name | M6200
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (24h): treated by heat killed HC60 cell (promyelocytic leukemia) lysate versus A. phagocytophilum infection.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_HEAT_KILLED_LYSATE_VS_LIVE_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_24H_DN
Systematic name | M6201
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (24h): treated by heat killed HC60 cell (promyelocytic leukemia) lysate versus A. phagocytophilum infection.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_9H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_DN
Systematic name | M6202
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (9h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_12H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_DN
Systematic name | M6203
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (12h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_24H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_UP
Systematic name | M6204
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (24h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_S_AUREUS_VS_UNTREATED_NEUTROPHIL_DN
Systematic name | M6205
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (9h): S. aureus infection versus control.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_S_AUREUS_VS_A_PHAGOCYTOPHILUM_NEUTROPHIL_UP
Systematic name | M6207
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes 9h after infection by: S. aureus versus A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_S_AUREUS_VS_A_PHAGOCYTOPHILUM_NEUTROPHIL_DN
Systematic name | M6208
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes 9h after infection by: S. aureus versus A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_1.5H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_UP
Systematic name | M6209
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (1.5h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_1.5H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_DN
Systematic name | M6211
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (1.5h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_3H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_UP
Systematic name | M6212
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (3h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_3H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_DN
Systematic name | M6213
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (3h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_6H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_UP
Systematic name | M6214
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (6h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_6H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_DN
Systematic name | M6215
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (6h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_0H_VS_9H_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_UP
Systematic name | M6217
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (9h): control versus infection by A. phagocytophilum.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_HEAT_KILLED_VS_LIVE_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_24H_UP
Systematic name | M6218
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polymorphonuclear leukocytes (24h) infection by A. phagocytophilum: heat killed versus live bacteria.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE2405_HEAT_KILLED_VS_LIVE_A_PHAGOCYTOPHILUM_STIM_NEUTROPHIL_24H_DN
Systematic name | M6219
Organism | Homo sapiens
PMID | 15879137
Authors | Borjesson DL,Kobayashi SD,Whitney AR,Voyich JM,Argue CM,Deleo FR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polymorphonuclear leukocytes (24h) infection by A. phagocytophilum: heat killed versus live bacteria.
Full description | Polymorphonuclear leukocytes (PMNs) were obtained from healthy individuals in accordance with protocols approved by the Institutional Review Board for Human Subjects at the University of Minnesota and the National Institute of Allergy and Infectious Diseases. PMNs (107) were combined on ice with live S. aureus (108) or with live or heat-killed A. phagocytophilum (bacteria isolated from 5x106 infected HL60 cells for a ratio of 1 infected HL60 cell: 2 PMNs, ~ 5-20 A. phagocytophilum: PMN) in wells of a 12-well tissue culture plate (pre-coated with 20% autologous normal human serum). Unstimulated control assays received either buffer (for S. aureus comparisons) or clarified HL60 lysate (for A. phagocytophilum comparisons). Plates were centrifuged at 350 x g for 8 min at 4oC to synchronize phagocytosis and incubated at 37 deg. C in a CO2 incubator for the indicated times. At the indicated times, tissue culture medium was aspirated from the plate and PMNs were lysed directly with RLT buffer (Qiagen, Valencia, CA). Purification of PMN RNA and subsequent preparation of labeled cRNA target was performed as described in Methods. Labeling of samples, hybridization of cRNA with HU133A oligonucleotide arrays (Affymetrix, Santa Clara, CA), and scanning were performed according to standard Affymetrix protocols ( http://www.affymetrix.com/pdf/expression_manual.pdf ). Experiments were performed in triplicate, using PMNs from three healthy individuals for each treatment.

Standard name | GSE1566_WT_VS_EZH2_KO_LN_TCELL_UP
Systematic name | M6221
Organism | Mus musculus
PMID | 15882624
Authors | Su IH,Dobenecker MW,Dickinson E,Oser M,Basavaraj A,Marqueron R,Viale A,Reinberg D,Wülfing C,Tarakhovsky A
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymph node T cells: wildtype versus EZH2 [GeneID=2146] knockout.
Full description | Lymph node T cells isolated from Ezh2fl/fl or Ezh2 deficient mice

Standard name | GSE1566_WT_VS_EZH2_KO_LN_TCELL_DN
Systematic name | M6224
Organism | Mus musculus
PMID | 15882624
Authors | Su IH,Dobenecker MW,Dickinson E,Oser M,Basavaraj A,Marqueron R,Viale A,Reinberg D,Wülfing C,Tarakhovsky A
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymph node T cells: wildtype versus EZH2 [GeneID=2146] knockout.
Full description | Lymph node T cells isolated from Ezh2fl/fl or Ezh2 deficient mice

Standard name | GSE22601_DOUBLE_NEGATIVE_VS_DOUBLE_POSITIVE_THYMOCYTE_UP
Systematic name | M6226
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymocytes: double negative versus double positive.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_POSITIVE_VS_CD4_SINGLE_POSITIVE_THYMOCYTE_UP
Systematic name | M6227
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymocytes: double positive versus CD4 [GeneID=920] single positive.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_NEGATIVE_VS_IMMATURE_CD4_SP_THYMOCYTE_DN
Systematic name | M6228
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in double negative thymocyte versus immature CD4 [GeneID=920] single positive cells.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_NEGATIVE_VS_CD8_SINGLE_POSITIVE_THYMOCYTE_DN
Systematic name | M6230
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymocytes: double negative versus CD8 single positive.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_IMMATURE_CD4_SINGLE_POSITIVE_VS_DOUBLE_POSITIVE_THYMOCYTE_UP
Systematic name | M6232
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in immature CD4 [GeneID=920] single positive cells versus double positive thymocytes.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_NEGATIVE_VS_IMMATURE_CD4_SP_THYMOCYTE_UP
Systematic name | M6234
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in double negative thymocyte versus immature CD4 [GeneID=920] single positive cells.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_NEGATIVE_VS_CD8_SINGLE_POSITIVE_THYMOCYTE_UP
Systematic name | M6235
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymocytes: double negative versus CD8 single positive.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_IMMATURE_CD4_SINGLE_POSITIVE_VS_CD4_SINGLE_POSITIVE_THYMOCYTE_DN
Systematic name | M6237
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] single positive cells: immature versus thymocytes.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_IMMATURE_CD4_SINGLE_POSITIVE_VS_CD8_SINGLE_POSITIVE_THYMOCYTE_UP
Systematic name | M6238
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in single positive cells: immature CD4 [GeneID=920] versus CD8 thymocytes.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_IMMATURE_CD4_SINGLE_POSITIVE_VS_CD8_SINGLE_POSITIVE_THYMOCYTE_DN
Systematic name | M6240
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in single positive cells: immature CD4 [GeneID=920] versus CD8 thymocytes.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_NEGATIVE_VS_CD4_SINGLE_POSITIVE_THYMOCYTE_UP
Systematic name | M6242
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymocytes: double negative versus CD4 [GeneID=920] single positive.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_NEGATIVE_VS_CD4_SINGLE_POSITIVE_THYMOCYTE_DN
Systematic name | M6243
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymocytes: double negative versus CD4 [GeneID=920] single positive.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_CD4_SINGLE_POSITIVE_VS_CD8_SINGLE_POSITIVE_THYMOCYTE_UP
Systematic name | M6245
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in single positive thymocytes: CD4 [GeneID=920] versus CD8.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_NEGATIVE_VS_DOUBLE_POSITIVE_THYMOCYTE_DN
Systematic name | M6246
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymocytes: double negative versus double positive.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_IMMATURE_CD4_SINGLE_POSITIVE_VS_DOUBLE_POSITIVE_THYMOCYTE_DN
Systematic name | M6247
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in immature CD4 [GeneID=920] single positive cells versus double positive thymocytes.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_IMMATURE_CD4_SINGLE_POSITIVE_VS_CD4_SINGLE_POSITIVE_THYMOCYTE_UP
Systematic name | M6248
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] single positive cells: immature versus thymocytes.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_POSITIVE_VS_CD8_SINGLE_POSITIVE_THYMOCYTE_DN
Systematic name | M6249
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymocytes: double positive versus CD8 single positive.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_CD4_SINGLE_POSITIVE_VS_CD8_SINGLE_POSITIVE_THYMOCYTE_DN
Systematic name | M6251
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in single positive thymocytes: CD4 [GeneID=920] versus CD8.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_POSITIVE_VS_CD4_SINGLE_POSITIVE_THYMOCYTE_DN
Systematic name | M6252
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymocytes: double positive versus CD4 [GeneID=920] single positive.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE22601_DOUBLE_POSITIVE_VS_CD8_SINGLE_POSITIVE_THYMOCYTE_UP
Systematic name | M6253
Organism | Homo sapiens
PMID | 15928199
Authors | Dik WA,Pike-Overzet K,Weerkamp F,Ridder de D,Haas de EF,Baert MR,Spek der van P,Koster EE,Reinders MJ,Dongen van JJ,Langerak AW,Staal FJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymocytes: double positive versus CD8 single positive.
Full description | T cells develop from progenitors that migrate from the bone marrow into the thymus. Thymocytes are subdivided roughly as being double negative (DN), double positive (DP), or single positive (SP), based on the expression of the CD4 and CD8 coreceptors. The DN stage is heterogeneous and can be subdivided into four distinct subsets in mice based on the expression of CD44 and CD25. In human, three distinct DN stages can be recognized: a CD34+CD38−CD1a− stage that represents the most immature thymic subset and the consecutive CD34+CD38+CD1a− and CD34+CD38+CD1a+ stages. Human DN thymocytes mature via an immature single positive (ISP CD4+) and a DP stage into CD4+ or CD8+ SP T cells that express functional T cell receptors (TCR) and that exit the thymus. In this study, gene expression was measured in each of these nine stages.

Standard name | GSE8835_CD4_VS_CD8_TCELL_UP
Systematic name | M6254
Organism | Homo sapiens
PMID | 15965501
Authors | Görgün G,Holderried TA,Zahrieh D,Neuberg D,Gribben JG
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: CD4 [GeneID=920] versus CD8.
Full description | To examine the impact of tumors on the immune system, we compared global gene expression profiles of peripheral blood T cells from previously untreated patients with B cell chronic lymphocytic leukemia (CLL) with those from age-matched healthy donors. Although the cells analyzed were not part of the malignant clone, analysis revealed differentially expressed genes, mainly involved in cell differentiation in CD4 cells and defects in cytoskeleton formation, vesicle trafficking, and cytotoxicity in CD8 cells of the CLL patients. In coculture experiments using CLL cells and T cells from healthy allogeneic donors, similar defects developed in both CD4 and CD8 cells. These changes were induced only with direct contact and were not cytokine mediated. Identification of the specific pathways perturbed in the T cells of cancer-bearing patients will allow us to assess steps to repair these defects, which will likely be required to enhance antitumor immunity. Gene expression profiling was performed to determine whether CLL cells induce changes in T cells in patients with CLL.

Standard name | GSE8835_CD4_VS_CD8_TCELL_DN
Systematic name | M6255
Organism | Homo sapiens
PMID | 15965501
Authors | Görgün G,Holderried TA,Zahrieh D,Neuberg D,Gribben JG
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: CD4 [GeneID=920] versus CD8.
Full description | To examine the impact of tumors on the immune system, we compared global gene expression profiles of peripheral blood T cells from previously untreated patients with B cell chronic lymphocytic leukemia (CLL) with those from age-matched healthy donors. Although the cells analyzed were not part of the malignant clone, analysis revealed differentially expressed genes, mainly involved in cell differentiation in CD4 cells and defects in cytoskeleton formation, vesicle trafficking, and cytotoxicity in CD8 cells of the CLL patients. In coculture experiments using CLL cells and T cells from healthy allogeneic donors, similar defects developed in both CD4 and CD8 cells. These changes were induced only with direct contact and were not cytokine mediated. Identification of the specific pathways perturbed in the T cells of cancer-bearing patients will allow us to assess steps to repair these defects, which will likely be required to enhance antitumor immunity. Gene expression profiling was performed to determine whether CLL cells induce changes in T cells in patients with CLL.

Standard name | GSE8835_CD4_VS_CD8_TCELL_CLL_PATIENT_UP
Systematic name | M6256
Organism | Homo sapiens
PMID | 15965501
Authors | Görgün G,Holderried TA,Zahrieh D,Neuberg D,Gribben JG
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells from CLL (chronic lymphocytic leukemia) patients: CD4 [GeneID=920] versus CD8.
Full description | To examine the impact of tumors on the immune system, we compared global gene expression profiles of peripheral blood T cells from previously untreated patients with B cell chronic lymphocytic leukemia (CLL) with those from age-matched healthy donors. Although the cells analyzed were not part of the malignant clone, analysis revealed differentially expressed genes, mainly involved in cell differentiation in CD4 cells and defects in cytoskeleton formation, vesicle trafficking, and cytotoxicity in CD8 cells of the CLL patients. In coculture experiments using CLL cells and T cells from healthy allogeneic donors, similar defects developed in both CD4 and CD8 cells. These changes were induced only with direct contact and were not cytokine mediated. Identification of the specific pathways perturbed in the T cells of cancer-bearing patients will allow us to assess steps to repair these defects, which will likely be required to enhance antitumor immunity. Gene expression profiling was performed to determine whether CLL cells induce changes in T cells in patients with CLL.

Standard name | GSE8835_CD4_VS_CD8_TCELL_CLL_PATIENT_DN
Systematic name | M6258
Organism | Homo sapiens
PMID | 15965501
Authors | Görgün G,Holderried TA,Zahrieh D,Neuberg D,Gribben JG
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells from CLL (chronic lymphocytic leukemia) patients: CD4 [GeneID=920] versus CD8.
Full description | To examine the impact of tumors on the immune system, we compared global gene expression profiles of peripheral blood T cells from previously untreated patients with B cell chronic lymphocytic leukemia (CLL) with those from age-matched healthy donors. Although the cells analyzed were not part of the malignant clone, analysis revealed differentially expressed genes, mainly involved in cell differentiation in CD4 cells and defects in cytoskeleton formation, vesicle trafficking, and cytotoxicity in CD8 cells of the CLL patients. In coculture experiments using CLL cells and T cells from healthy allogeneic donors, similar defects developed in both CD4 and CD8 cells. These changes were induced only with direct contact and were not cytokine mediated. Identification of the specific pathways perturbed in the T cells of cancer-bearing patients will allow us to assess steps to repair these defects, which will likely be required to enhance antitumor immunity. Gene expression profiling was performed to determine whether CLL cells induce changes in T cells in patients with CLL.

Standard name | GSE8835_HEALTHY_VS_CLL_CD4_TCELL_UP
Systematic name | M6260
Organism | Homo sapiens
PMID | 15965501
Authors | Görgün G,Holderried TA,Zahrieh D,Neuberg D,Gribben JG
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: healthy versus CLL (chronic lymphocytic leukemia)l.
Full description | To examine the impact of tumors on the immune system, we compared global gene expression profiles of peripheral blood T cells from previously untreated patients with B cell chronic lymphocytic leukemia (CLL) with those from age-matched healthy donors. Although the cells analyzed were not part of the malignant clone, analysis revealed differentially expressed genes, mainly involved in cell differentiation in CD4 cells and defects in cytoskeleton formation, vesicle trafficking, and cytotoxicity in CD8 cells of the CLL patients. In coculture experiments using CLL cells and T cells from healthy allogeneic donors, similar defects developed in both CD4 and CD8 cells. These changes were induced only with direct contact and were not cytokine mediated. Identification of the specific pathways perturbed in the T cells of cancer-bearing patients will allow us to assess steps to repair these defects, which will likely be required to enhance antitumor immunity. Gene expression profiling was performed to determine whether CLL cells induce changes in T cells in patients with CLL.

Standard name | GSE8835_HEALTHY_VS_CLL_CD4_TCELL_DN
Systematic name | M6261
Organism | Homo sapiens
PMID | 15965501
Authors | Görgün G,Holderried TA,Zahrieh D,Neuberg D,Gribben JG
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: healthy versus CLL (chronic lymphocytic leukemia)l.
Full description | To examine the impact of tumors on the immune system, we compared global gene expression profiles of peripheral blood T cells from previously untreated patients with B cell chronic lymphocytic leukemia (CLL) with those from age-matched healthy donors. Although the cells analyzed were not part of the malignant clone, analysis revealed differentially expressed genes, mainly involved in cell differentiation in CD4 cells and defects in cytoskeleton formation, vesicle trafficking, and cytotoxicity in CD8 cells of the CLL patients. In coculture experiments using CLL cells and T cells from healthy allogeneic donors, similar defects developed in both CD4 and CD8 cells. These changes were induced only with direct contact and were not cytokine mediated. Identification of the specific pathways perturbed in the T cells of cancer-bearing patients will allow us to assess steps to repair these defects, which will likely be required to enhance antitumor immunity. Gene expression profiling was performed to determine whether CLL cells induce changes in T cells in patients with CLL.

Standard name | GSE8835_HEALTHY_VS_CLL_CD8_TCELL_UP
Systematic name | M6262
Organism | Homo sapiens
PMID | 15965501
Authors | Görgün G,Holderried TA,Zahrieh D,Neuberg D,Gribben JG
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: healthy versus CLL (chronic lymphocytic leukemia).
Full description | To examine the impact of tumors on the immune system, we compared global gene expression profiles of peripheral blood T cells from previously untreated patients with B cell chronic lymphocytic leukemia (CLL) with those from age-matched healthy donors. Although the cells analyzed were not part of the malignant clone, analysis revealed differentially expressed genes, mainly involved in cell differentiation in CD4 cells and defects in cytoskeleton formation, vesicle trafficking, and cytotoxicity in CD8 cells of the CLL patients. In coculture experiments using CLL cells and T cells from healthy allogeneic donors, similar defects developed in both CD4 and CD8 cells. These changes were induced only with direct contact and were not cytokine mediated. Identification of the specific pathways perturbed in the T cells of cancer-bearing patients will allow us to assess steps to repair these defects, which will likely be required to enhance antitumor immunity. Gene expression profiling was performed to determine whether CLL cells induce changes in T cells in patients with CLL.

Standard name | GSE8835_HEALTHY_VS_CLL_CD8_TCELL_DN
Systematic name | M6263
Organism | Homo sapiens
PMID | 15965501
Authors | Görgün G,Holderried TA,Zahrieh D,Neuberg D,Gribben JG
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: healthy versus CLL (chronic lymphocytic leukemia).
Full description | To examine the impact of tumors on the immune system, we compared global gene expression profiles of peripheral blood T cells from previously untreated patients with B cell chronic lymphocytic leukemia (CLL) with those from age-matched healthy donors. Although the cells analyzed were not part of the malignant clone, analysis revealed differentially expressed genes, mainly involved in cell differentiation in CD4 cells and defects in cytoskeleton formation, vesicle trafficking, and cytotoxicity in CD8 cells of the CLL patients. In coculture experiments using CLL cells and T cells from healthy allogeneic donors, similar defects developed in both CD4 and CD8 cells. These changes were induced only with direct contact and were not cytokine mediated. Identification of the specific pathways perturbed in the T cells of cancer-bearing patients will allow us to assess steps to repair these defects, which will likely be required to enhance antitumor immunity. Gene expression profiling was performed to determine whether CLL cells induce changes in T cells in patients with CLL.

Standard name | GSE2585_CTEC_VS_THYMIC_MACROPHAGE_DN
Systematic name | M6264
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes down-regulated in cortical thymic epithelial cells (cTEC) versus thymic macrophages.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_CTEC_VS_MTEC_THYMUS_UP
Systematic name | M6265
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic epithelial cells: cortical (cTEC) versus medullary (mTEC).
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_AIRE_KO_VS_WT_CD80_HIGH_MTEC_UP
Systematic name | M6266
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes up-regulated in medullary thymic epithelial cells (mTEC) with CD80 [GeneID=941] high: AIRE [GeneID=326] knockout versus wildtype.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_CTEC_VS_THYMIC_MACROPHAGE_UP
Systematic name | M6268
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes up-regulated in cortical thymic epithelial cells (cTEC) versus thymic macrophages.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_CD80_HIGH_VS_LOW_AIRE_KO_MTEC_UP
Systematic name | M6269
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes up-regulated in medullary thymic epithelial cells (mTEC) with AIRE [GeneID=326] knockout: CD80 [GeneID=941] high versus low.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_AIRE_KO_VS_WT_CD80_LOW_MTEC_DN
Systematic name | M6270
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes down-regulated in medullary thymic epithelial cells (mTEC) with CD80 [GeneID=941] low: AIRE [GeneID=326] knockout versus wildtype.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_CTEC_VS_THYMIC_DC_UP
Systematic name | M6271
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes up-regulated in cortical thymic epithelial cells (cTEC) versus thymic dendritic cells.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_CTEC_VS_THYMIC_DC_DN
Systematic name | M6272
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes down-regulated in cortical thymic epithelial cells (cTEC) versus thymic dendritic cells.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_AIRE_KO_VS_WT_CD80_HIGH_MTEC_DN
Systematic name | M6273
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes down-regulated in medullary thymic epithelial cells (mTEC) with CD80 [GeneID=941] high: AIRE [GeneID=326] knockout versus wildtype.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_CTEC_VS_MTEC_THYMUS_DN
Systematic name | M6274
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic epithelial cells: cortical (cTEC) versus medullary (mTEC).
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_CD80_HIGH_VS_LOW_AIRE_KO_MTEC_DN
Systematic name | M6275
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes down-regulated in medullary thymic epithelial cells (mTEC) with AIRE [GeneID=326] knockout: CD80 [GeneID=941] high versus low.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_CD80_HIGH_VS_LOW_MTEC_UP
Systematic name | M6276
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes up-regulated in medullary thymic epithelial cells (mTEC): CD80 [GeneID=941] high versus low.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_THYMIC_DC_VS_THYMIC_MACROPHAGE_DN
Systematic name | M6277
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic: dendritic cells versus macrophages.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_AIRE_KO_VS_WT_CD80_LOW_MTEC_UP
Systematic name | M6278
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes up-regulated in medullary thymic epithelial cells (mTEC) with CD80 [GeneID=941] low: AIRE [GeneID=326] knockout versus wildtype.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_THYMIC_MACROPHAGE_VS_MTEC_UP
Systematic name | M6279
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic macrophages versus medullary thymic epithelial cells (mTEC).
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_THYMIC_MACROPHAGE_VS_MTEC_DN
Systematic name | M6280
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic macrophages versus medullary thymic epithelial cells (mTEC).
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_CD80_HIGH_VS_LOW_MTEC_DN
Systematic name | M6282
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes down-regulated in medullary thymic epithelial cells (mTEC): CD80 [GeneID=941] high versus low.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_THYMIC_DC_VS_MTEC_DN
Systematic name | M6283
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic dendritic cells versus medullary thymic epithelial cells (mTEC).
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_THYMIC_DC_VS_THYMIC_MACROPHAGE_UP
Systematic name | M6284
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic: dendritic cells versus macrophages.
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE2585_THYMIC_DC_VS_MTEC_UP
Systematic name | M6289
Organism | Mus musculus
PMID | 15983066
Authors | Derbinski J,Gäbler J,Brors B,Tierling S,Jonnakuty S,Hergenhahn M,Peltonen L,Walter J,Kyewski B
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic dendritic cells versus medullary thymic epithelial cells (mTEC).
Full description | Gene expression in different thymic stromal cells and subsets thereof was analyzed in 6-12 week old wild type (C57BL/6) and Aire knock-out (mixed background) mice. Thymic stromal cells were purified by sequential enzymatic digestion (collagenase, collagenase/dispase and trypsin) followed by gradient centrifugation and FACS sorting. Sort criteria were as follows: dendritic cells (CD11c+, F4/80 -), macrophages (F4/80+, CD11c-), cTECs (CD45–/lo, CDR1/Ly51+, Ep-CAM+) and mTECs (CD45–/lo, CDR1/Ly51–, Ep-CAM+). mTECs of wild-type and Aire knock-out mice were further subdivided according to CD80 expression levels. For microarray analysis total RNA from thymic stromal cell samples of two independent experiments was pre-amplified and biotinylated by two rounds of cDNA synthesis and in vitro transcription. Fluorescence readings were evaluated by using Microarray Suite 5.0 software.

Standard name | GSE1925_CTRL_VS_3H_IFNG_STIM_MACROPHAGE_DN
Systematic name | M6290
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: untreated versus stimulated by IFNG [GeneID=3458] for 3h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_3H_VS_24H_IFNG_STIM_MACROPHAGE_DN
Systematic name | M6291
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages stimulated by IFNG [GeneID=3458]: 3h versus 24h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_3H_VS_24H_IFNG_STIM_MACROPHAGE_UP
Systematic name | M6292
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages stimulated by IFNG [GeneID=3458]: 3h versus 24h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_24H_IFNG_STIM_MACROPHAGE_UP
Systematic name | M6293
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: untreated versus stimulated by IFNG [GeneID=3458] for 24h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_24H_IFNG_STIM_MACROPHAGE_DN
Systematic name | M6294
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: untreated versus stimulated by IFNG [GeneID=3458] for 24h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_3H_IFNG_STIM_IFNG_PRIMED_MACROPHAGE_UP
Systematic name | M6295
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages primed by IFNG [GeneID=3458]: untreated versus stimulated by IFNG [GeneID=3458] for 3h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_IFNG_PRIMED_MACROPHAGE_3H_IFNG_STIM_UP
Systematic name | M6296
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages stimulated by IFNG [GeneID=3458] for 3h: control versus primed by IFNG [GeneID=3458].
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_IFNG_PRIMED_MACROPHAGE_3H_IFNG_STIM_DN
Systematic name | M6297
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages stimulated by IFNG [GeneID=3458] for 3h: control versus primed by IFNG [GeneID=3458].
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_24H_IFNG_STIM_IFNG_PRIMED_MACROPHAGE_DN
Systematic name | M6299
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages primed by IFNG [GeneID=3458]: untreated versus stimulated by IFNG [GeneID=3458] for 24h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_3H_VS_24H_IFNG_STIM_IFNG_PRIMED_MACROPHAGE_UP
Systematic name | M6300
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages primed and then stimulated by IFNG [GeneID=3458]: 3h versus 24h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_3H_VS_24H_IFNG_STIM_IFNG_PRIMED_MACROPHAGE_DN
Systematic name | M6301
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages primed and then stimulated by IFNG [GeneID=3458]: 3h versus 24h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_3H_IFNG_STIM_MACROPHAGE_UP
Systematic name | M6305
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: untreated versus stimulated by IFNG [GeneID=3458] for 3h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_IFNG_PRIMED_MACROPHAGE_UP
Systematic name | M6306
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in control macrophages: untreated versus primed by IFNG [GeneID=3458].
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_IFNG_PRIMED_MACROPHAGE_24H_IFNG_STIM_UP
Systematic name | M6307
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages stimulated by IFNG [GeneID=3458] for 24h: control versus primed by IFNG [GeneID=3458].
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_IFNG_PRIMED_MACROPHAGE_24H_IFNG_STIM_DN
Systematic name | M6309
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages stimulated by IFNG [GeneID=3458] for 24h: control versus primed by IFNG [GeneID=3458].
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_3H_IFNG_STIM_IFNG_PRIMED_MACROPHAGE_DN
Systematic name | M6310
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages primed by IFNG [GeneID=3458]: untreated versus stimulated by IFNG [GeneID=3458] for 3h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_IFNG_PRIMED_MACROPHAGE_DN
Systematic name | M6313
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in control macrophages: untreated versus primed by IFNG [GeneID=3458].
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE1925_CTRL_VS_24H_IFNG_STIM_IFNG_PRIMED_MACROPHAGE_UP
Systematic name | M6314
Organism | Homo sapiens
PMID | 16148108
Authors | Hu X,Park-Min KH,Ho HH,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages primed by IFNG [GeneID=3458]: untreated versus stimulated by IFNG [GeneID=3458] for 24h.
Full description | IFN-gamma transcriptional responses in control and IFN-gamma primed primary human macrophages

Standard name | GSE2935_UV_INACTIVATED_VS_LIVE_SENDAI_VIRUS_INF_MACROPHAGE_UP
Systematic name | M6316
Organism | Mus musculus
PMID | 16208318
Authors | Tyner JW,Uchida O,Kajiwara N,Kim EY,Patel AC,O'Sullivan MP,Walter MJ,Schwendener RA,Cook DN,Danoff TM,Holtzman MJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: control versus Sendai virus infection.
Full description | Thus, mouse macrophage cultures were established from PBMCs isolated from wild-type control mice and were inoculated with SeV (Sendai virus) or UV-SeV (UV-inactivated SeV). These microarrays were performed in concert with assays of CCL5 and CCR5 expression, viral replication, and cellular apoptosis. Initial experiments indicated that wild-type mouse macrophages inoculated with SeV exhibit induction of CCL5 mRNA to the highest level of any known mouse gene product, while mRNA levels for CCL5 receptors (CCR5 as well as CCR3 and CCR1) or alternative ligands for these receptors (CCL3 and CCL4) were relatively unchanged by viral infection.

Standard name | GSE2935_UV_INACTIVATED_VS_LIVE_SENDAI_VIRUS_INF_MACROPHAGE_DN
Systematic name | M6317
Organism | Mus musculus
PMID | 16208318
Authors | Tyner JW,Uchida O,Kajiwara N,Kim EY,Patel AC,O'Sullivan MP,Walter MJ,Schwendener RA,Cook DN,Danoff TM,Holtzman MJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: control versus Sendai virus infection.
Full description | Thus, mouse macrophage cultures were established from PBMCs isolated from wild-type control mice and were inoculated with SeV (Sendai virus) or UV-SeV (UV-inactivated SeV). These microarrays were performed in concert with assays of CCL5 and CCR5 expression, viral replication, and cellular apoptosis. Initial experiments indicated that wild-type mouse macrophages inoculated with SeV exhibit induction of CCL5 mRNA to the highest level of any known mouse gene product, while mRNA levels for CCL5 receptors (CCR5 as well as CCR3 and CCR1) or alternative ligands for these receptors (CCL3 and CCL4) were relatively unchanged by viral infection.

Standard name | GSE3565_CTRL_VS_LPS_INJECTED_DUSP1_KO_SPLENOCYTES_DN
Systematic name | M6321
Organism | Mus musculus
PMID | 16380512
Authors | Hammer M,Mages J,Dietrich H,Servatius A,Howells N,Cato AC,Lang R
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen from DUSP1 [GeneID=1843] knockout: control versus LPS.
Full description | Activation of the Mitogen activated protein kinase (MAPK) cascade following Toll-like receptor (TLR) stimulation enables innate immune cells to rapidly activate cytokine gene expression. A balanced response to signals of infectious danger requires that cellular activation is transient. Here, we identify the MAPK phosphatase Dual specificity phosphatase-1 (DUSP1) as an essential endogenous regulator of the inflammatory response to LPS. DUSP1-deficient (DUSP1-/-) bone marrow derived macrophages showed selectively prolonged activation of p38 MAPK and increased cytokine production. Intraperitoneal challenge of DUSP1-/- mice with LPS caused increased lethality and overshooting production of IL-6 and TNF-alpha. Transcriptional profiling revealed that DUSP1 controls a significant fraction of LPS-induced genes, that includes IL-6 and IL-10 as well as the chemokines CCL3, CCL4 and CXCL2. In contrast, the expression of the important mediators of endotoxin lethality, IFN-gamma and IL-12, was not significantly altered by the absence of DUSP1. These data together demonstrate a specific regulatory role of DUSP1 in controlling a subset of LPS-induced genes that determines the outcome of endotoxin shock.

Standard name | GSE3565_CTRL_VS_LPS_INJECTED_DUSP1_KO_SPLENOCYTES_UP
Systematic name | M6323
Organism | Mus musculus
PMID | 16380512
Authors | Hammer M,Mages J,Dietrich H,Servatius A,Howells N,Cato AC,Lang R
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen from DUSP1 [GeneID=1843] knockout: control versus LPS.
Full description | Activation of the Mitogen activated protein kinase (MAPK) cascade following Toll-like receptor (TLR) stimulation enables innate immune cells to rapidly activate cytokine gene expression. A balanced response to signals of infectious danger requires that cellular activation is transient. Here, we identify the MAPK phosphatase Dual specificity phosphatase-1 (DUSP1) as an essential endogenous regulator of the inflammatory response to LPS. DUSP1-deficient (DUSP1-/-) bone marrow derived macrophages showed selectively prolonged activation of p38 MAPK and increased cytokine production. Intraperitoneal challenge of DUSP1-/- mice with LPS caused increased lethality and overshooting production of IL-6 and TNF-alpha. Transcriptional profiling revealed that DUSP1 controls a significant fraction of LPS-induced genes, that includes IL-6 and IL-10 as well as the chemokines CCL3, CCL4 and CXCL2. In contrast, the expression of the important mediators of endotoxin lethality, IFN-gamma and IL-12, was not significantly altered by the absence of DUSP1. These data together demonstrate a specific regulatory role of DUSP1 in controlling a subset of LPS-induced genes that determines the outcome of endotoxin shock.

Standard name | GSE3565_DUSP1_VS_WT_SPLENOCYTES_DN
Systematic name | M6324
Organism | Mus musculus
PMID | 16380512
Authors | Hammer M,Mages J,Dietrich H,Servatius A,Howells N,Cato AC,Lang R
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated spleen: DUSP1 [GeneID=1843] knockout versus wildtype.
Full description | Activation of the Mitogen activated protein kinase (MAPK) cascade following Toll-like receptor (TLR) stimulation enables innate immune cells to rapidly activate cytokine gene expression. A balanced response to signals of infectious danger requires that cellular activation is transient. Here, we identify the MAPK phosphatase Dual specificity phosphatase-1 (DUSP1) as an essential endogenous regulator of the inflammatory response to LPS. DUSP1-deficient (DUSP1-/-) bone marrow derived macrophages showed selectively prolonged activation of p38 MAPK and increased cytokine production. Intraperitoneal challenge of DUSP1-/- mice with LPS caused increased lethality and overshooting production of IL-6 and TNF-alpha. Transcriptional profiling revealed that DUSP1 controls a significant fraction of LPS-induced genes, that includes IL-6 and IL-10 as well as the chemokines CCL3, CCL4 and CXCL2. In contrast, the expression of the important mediators of endotoxin lethality, IFN-gamma and IL-12, was not significantly altered by the absence of DUSP1. These data together demonstrate a specific regulatory role of DUSP1 in controlling a subset of LPS-induced genes that determines the outcome of endotoxin shock.

Standard name | GSE3565_CTRL_VS_LPS_INJECTED_SPLENOCYTES_UP
Systematic name | M6326
Organism | Mus musculus
PMID | 16380512
Authors | Hammer M,Mages J,Dietrich H,Servatius A,Howells N,Cato AC,Lang R
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen from wildtype mice: control versus LPS.
Full description | Activation of the Mitogen activated protein kinase (MAPK) cascade following Toll-like receptor (TLR) stimulation enables innate immune cells to rapidly activate cytokine gene expression. A balanced response to signals of infectious danger requires that cellular activation is transient. Here, we identify the MAPK phosphatase Dual specificity phosphatase-1 (DUSP1) as an essential endogenous regulator of the inflammatory response to LPS. DUSP1-deficient (DUSP1-/-) bone marrow derived macrophages showed selectively prolonged activation of p38 MAPK and increased cytokine production. Intraperitoneal challenge of DUSP1-/- mice with LPS caused increased lethality and overshooting production of IL-6 and TNF-alpha. Transcriptional profiling revealed that DUSP1 controls a significant fraction of LPS-induced genes, that includes IL-6 and IL-10 as well as the chemokines CCL3, CCL4 and CXCL2. In contrast, the expression of the important mediators of endotoxin lethality, IFN-gamma and IL-12, was not significantly altered by the absence of DUSP1. These data together demonstrate a specific regulatory role of DUSP1 in controlling a subset of LPS-induced genes that determines the outcome of endotoxin shock.

Standard name | GSE3565_CTRL_VS_LPS_INJECTED_SPLENOCYTES_DN
Systematic name | M6328
Organism | Mus musculus
PMID | 16380512
Authors | Hammer M,Mages J,Dietrich H,Servatius A,Howells N,Cato AC,Lang R
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen from wildtype mice: control versus LPS.
Full description | Activation of the Mitogen activated protein kinase (MAPK) cascade following Toll-like receptor (TLR) stimulation enables innate immune cells to rapidly activate cytokine gene expression. A balanced response to signals of infectious danger requires that cellular activation is transient. Here, we identify the MAPK phosphatase Dual specificity phosphatase-1 (DUSP1) as an essential endogenous regulator of the inflammatory response to LPS. DUSP1-deficient (DUSP1-/-) bone marrow derived macrophages showed selectively prolonged activation of p38 MAPK and increased cytokine production. Intraperitoneal challenge of DUSP1-/- mice with LPS caused increased lethality and overshooting production of IL-6 and TNF-alpha. Transcriptional profiling revealed that DUSP1 controls a significant fraction of LPS-induced genes, that includes IL-6 and IL-10 as well as the chemokines CCL3, CCL4 and CXCL2. In contrast, the expression of the important mediators of endotoxin lethality, IFN-gamma and IL-12, was not significantly altered by the absence of DUSP1. These data together demonstrate a specific regulatory role of DUSP1 in controlling a subset of LPS-induced genes that determines the outcome of endotoxin shock.

Standard name | GSE3565_DUSP1_VS_WT_SPLENOCYTES_UP
Systematic name | M6329
Organism | Mus musculus
PMID | 16380512
Authors | Hammer M,Mages J,Dietrich H,Servatius A,Howells N,Cato AC,Lang R
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated spleen: DUSP1 [GeneID=1843] knockout versus wildtype.
Full description | Activation of the Mitogen activated protein kinase (MAPK) cascade following Toll-like receptor (TLR) stimulation enables innate immune cells to rapidly activate cytokine gene expression. A balanced response to signals of infectious danger requires that cellular activation is transient. Here, we identify the MAPK phosphatase Dual specificity phosphatase-1 (DUSP1) as an essential endogenous regulator of the inflammatory response to LPS. DUSP1-deficient (DUSP1-/-) bone marrow derived macrophages showed selectively prolonged activation of p38 MAPK and increased cytokine production. Intraperitoneal challenge of DUSP1-/- mice with LPS caused increased lethality and overshooting production of IL-6 and TNF-alpha. Transcriptional profiling revealed that DUSP1 controls a significant fraction of LPS-induced genes, that includes IL-6 and IL-10 as well as the chemokines CCL3, CCL4 and CXCL2. In contrast, the expression of the important mediators of endotoxin lethality, IFN-gamma and IL-12, was not significantly altered by the absence of DUSP1. These data together demonstrate a specific regulatory role of DUSP1 in controlling a subset of LPS-induced genes that determines the outcome of endotoxin shock.

Standard name | GSE3565_DUSP1_VS_WT_SPLENOCYTES_POST_LPS_INJECTION_UP
Systematic name | M6332
Organism | Mus musculus
PMID | 16380512
Authors | Hammer M,Mages J,Dietrich H,Servatius A,Howells N,Cato AC,Lang R
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen from mice injected with LPS: DUSP1 [GeneID=1843] knockout versus wildtype.
Full description | Activation of the Mitogen activated protein kinase (MAPK) cascade following Toll-like receptor (TLR) stimulation enables innate immune cells to rapidly activate cytokine gene expression. A balanced response to signals of infectious danger requires that cellular activation is transient. Here, we identify the MAPK phosphatase Dual specificity phosphatase-1 (DUSP1) as an essential endogenous regulator of the inflammatory response to LPS. DUSP1-deficient (DUSP1-/-) bone marrow derived macrophages showed selectively prolonged activation of p38 MAPK and increased cytokine production. Intraperitoneal challenge of DUSP1-/- mice with LPS caused increased lethality and overshooting production of IL-6 and TNF-alpha. Transcriptional profiling revealed that DUSP1 controls a significant fraction of LPS-induced genes, that includes IL-6 and IL-10 as well as the chemokines CCL3, CCL4 and CXCL2. In contrast, the expression of the important mediators of endotoxin lethality, IFN-gamma and IL-12, was not significantly altered by the absence of DUSP1. These data together demonstrate a specific regulatory role of DUSP1 in controlling a subset of LPS-induced genes that determines the outcome of endotoxin shock.

Standard name | GSE3565_DUSP1_VS_WT_SPLENOCYTES_POST_LPS_INJECTION_DN
Systematic name | M6333
Organism | Mus musculus
PMID | 16380512
Authors | Hammer M,Mages J,Dietrich H,Servatius A,Howells N,Cato AC,Lang R
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen from mice injected with LPS: DUSP1 [GeneID=1843] knockout versus wildtype.
Full description | Activation of the Mitogen activated protein kinase (MAPK) cascade following Toll-like receptor (TLR) stimulation enables innate immune cells to rapidly activate cytokine gene expression. A balanced response to signals of infectious danger requires that cellular activation is transient. Here, we identify the MAPK phosphatase Dual specificity phosphatase-1 (DUSP1) as an essential endogenous regulator of the inflammatory response to LPS. DUSP1-deficient (DUSP1-/-) bone marrow derived macrophages showed selectively prolonged activation of p38 MAPK and increased cytokine production. Intraperitoneal challenge of DUSP1-/- mice with LPS caused increased lethality and overshooting production of IL-6 and TNF-alpha. Transcriptional profiling revealed that DUSP1 controls a significant fraction of LPS-induced genes, that includes IL-6 and IL-10 as well as the chemokines CCL3, CCL4 and CXCL2. In contrast, the expression of the important mediators of endotoxin lethality, IFN-gamma and IL-12, was not significantly altered by the absence of DUSP1. These data together demonstrate a specific regulatory role of DUSP1 in controlling a subset of LPS-induced genes that determines the outcome of endotoxin shock.

Standard name | GSE3720_UNSTIM_VS_LPS_STIM_VD2_GAMMADELTA_TCELL_UP
Systematic name | M6337
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Vd2 gamma delta T cells: untreated versus LPS.
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_UNSTIM_VS_LPS_STIM_VD2_GAMMADELTA_TCELL_DN
Systematic name | M6338
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Vd2 gamma delta T cells: untreated versus LPS.
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_UNSTIM_VS_PMA_STIM_VD2_GAMMADELTA_TCELL_UP
Systematic name | M6340
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Vd2 gamma delta T cells: untreated versus phorbol myristate acetate and ionomycin [PubChem=4792;3733].
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_UNSTIM_VS_LPS_STIM_VD1_GAMMADELTA_TCELL_DN
Systematic name | M6341
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Vd1 gamma delta T cells: untreated versus LPS.
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_UNSTIM_VS_PMA_STIM_VD1_GAMMADELTA_TCELL_UP
Systematic name | M6343
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Vd1 gamma delta T cells: untreated versus phorbol myristate acetate and ionomycin [PubChem=4792;3733].
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_UNSTIM_VS_PMA_STIM_VD1_GAMMADELTA_TCELL_DN
Systematic name | M6344
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Vd1 gamma delta T cells: untreated versus phorbol myristate acetate and ionomycin [PubChem=4792;3733].
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_LPS_VS_PMA_STIM_VD1_GAMMADELTA_TCELL_DN
Systematic name | M6345
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Vd1 gamma delta T cells: LPS versus phorbol myristate acetate and ionomycin [PubChem=4792;3733].
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_LPS_VS_PMA_STIM_VD2_GAMMADELTA_TCELL_UP
Systematic name | M6346
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Vd2 gamma delta T cells: LPS versus phorbol myristate acetate and ionomycin [PubChem=4792;3733].
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_LPS_VS_PMA_STIM_VD2_GAMMADELTA_TCELL_DN
Systematic name | M6347
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Vd2 gamma delta T cells: LPS versus phorbol myristate acetate and ionomycin [PubChem=4792;3733].
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_LPS_VS_PMA_STIM_VD1_GAMMADELTA_TCELL_UP
Systematic name | M6348
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Vd1 gamma delta T cells: LPS versus phorbol myristate acetate and ionomycin [PubChem=4792;3733].
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_UNSTIM_VS_PMA_STIM_VD2_GAMMADELTA_TCELL_DN
Systematic name | M6351
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Vd2 gamma delta T cells: untreated versus phorbol myristate acetate and ionomycin [PubChem=4792;3733].
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_VD1_VS_VD2_GAMMADELTA_TCELL_WITH_LPS_STIM_UP
Systematic name | M6352
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in gamma delta T cells stimulated by LPS: Vd1 versus Vd2.
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_VD1_VS_VD2_GAMMADELTA_TCELL_WITH_LPS_STIM_DN
Systematic name | M6354
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in gamma delta T cells stimulated by LPS: Vd1 versus Vd2.
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_VD1_VS_VD2_GAMMADELTA_TCELL_WITH_PMA_STIM_UP
Systematic name | M6356
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in gamma delta T cells stimulated by phorbol myristate acetate and ionomycin [PubChem=4792;3733]: Vd1 versus Vd2.
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_UNSTIM_VS_LPS_STIM_VD1_GAMMADELTA_TCELL_UP
Systematic name | M6357
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Vd1 gamma delta T cells: untreated versus LPS.
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_VD1_VS_VD2_GAMMADELTA_TCELL_DN
Systematic name | M6358
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in gamma delta T cells: Vd1 versus Vd2.
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_VD1_VS_VD2_GAMMADELTA_TCELL_WITH_PMA_STIM_DN
Systematic name | M6360
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in gamma delta T cells stimulated by phorbol myristate acetate and ionomycin [PubChem=4792;3733]: Vd1 versus Vd2.
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3720_VD1_VS_VD2_GAMMADELTA_TCELL_UP
Systematic name | M6361
Organism | Homo sapiens
PMID | 16423401
Authors | Kress E,Hedges JF,Jutila MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in gamma delta T cells: Vd1 versus Vd2.
Full description | The two major human gd T cell subsets, Vd1 and Vd2, display differences in tissue tropism and agonist responses, but we have little insight into global differences that may exist at the gene expression level. This is due to the small numbers of these cells that can be obtained from healthy donors, which limit comprehensive, comparative gene expression analyses. We established a culture method that expands Vd1 and Vd2 cells from the same PBL preparation to levels sufficient for sorting and microarray analysis. Although the subsets were expanded identically (anti-TCR mAb, plus IL-15), 392 and 614 genes were identified, which were differentially expressed in the two subsets, from two donors, respectively. Approximately 4,500 genes changed in both subsets following PMA/ionomycin treatment; about 50% of these genes were subset-specific. Both subsets responded to a crude LPS preparation, but only 6% of the responsive genes were the same. The differentially expressed genes were consistent with Vd2 cells being more inflammatory and Vd1 cells having more of a regulatory phenotype. Both subsets expressed transcripts encoding an array of innate and NK cell receptors, supporting the relationship of gd T cells to the innate immune system. Our results show that circulating Vd1 and Vd2 subsets in humans have considerable, inherent differences in gene expression following treatment with non-TCR agonists, supporting unique functional roles for these cells in vivo.

Standard name | GSE3691_IFN_PRODUCING_KILLER_DC_VS_CONVENTIONAL_DC_SPLEEN_UP
Systematic name | M6363
Organism | Mus musculus
PMID | 16444266
Authors | Chan CW,Crafton E,Fan HN,Flook J,Yoshimura K,Skarica M,Brockstedt D,Dubensky TW,Stins MF,Lanier LL,Pardoll DM,Housseau F
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendiritic cells from speen: interferon producing killer cells versus conventional.
Full description | To characterize differences between BALB/c splenic CD11cintB220+Gr1+ PDCs (plasmacytoid dendritic cells), CD11cintB220+CD49b+ IKDCs (interferon producing killer-dendritic cells), and CD11chighB220- cDCs (conventional dendritic cells), we performed gene expression profile analysis using Affymetrix chips. We FACS-sorted BALB/c spleen DC subpopulations. Comparison of differentially expressed genes between IKDCs and cDCs vividly revealed selective expression of multiple NK-related genes in IKDCs . These included granzymes A, B, K and M, perforin, Fas ligand, and NK receptors such as NKG2A, NKG2D, Ly49 family genes, NKR-P1, NKG7, NKp46 and Mafa (KLRG1). No NK-related genes were highly expressed in the PDCs.

Standard name | GSE3691_IFN_PRODUCING_KILLER_DC_VS_PLASMACYTOID_DC_SPLEEN_DN
Systematic name | M6365
Organism | Mus musculus
PMID | 16444266
Authors | Chan CW,Crafton E,Fan HN,Flook J,Yoshimura K,Skarica M,Brockstedt D,Dubensky TW,Stins MF,Lanier LL,Pardoll DM,Housseau F
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendiritic cells from speen: interferon producing killer cells versus plasmacytoid.
Full description | To characterize differences between BALB/c splenic CD11cintB220+Gr1+ PDCs (plasmacytoid dendritic cells), CD11cintB220+CD49b+ IKDCs (interferon producing killer-dendritic cells), and CD11chighB220- cDCs (conventional dendritic cells), we performed gene expression profile analysis using Affymetrix chips. We FACS-sorted BALB/c spleen DC subpopulations. Comparison of differentially expressed genes between IKDCs and cDCs vividly revealed selective expression of multiple NK-related genes in IKDCs . These included granzymes A, B, K and M, perforin, Fas ligand, and NK receptors such as NKG2A, NKG2D, Ly49 family genes, NKR-P1, NKG7, NKp46 and Mafa (KLRG1). No NK-related genes were highly expressed in the PDCs.

Standard name | GSE3691_IFN_PRODUCING_KILLER_DC_VS_CONVENTIONAL_DC_SPLEEN_DN
Systematic name | M6366
Organism | Mus musculus
PMID | 16444266
Authors | Chan CW,Crafton E,Fan HN,Flook J,Yoshimura K,Skarica M,Brockstedt D,Dubensky TW,Stins MF,Lanier LL,Pardoll DM,Housseau F
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendiritic cells from speen: interferon producing killer cells versus conventional.
Full description | To characterize differences between BALB/c splenic CD11cintB220+Gr1+ PDCs (plasmacytoid dendritic cells), CD11cintB220+CD49b+ IKDCs (interferon producing killer-dendritic cells), and CD11chighB220- cDCs (conventional dendritic cells), we performed gene expression profile analysis using Affymetrix chips. We FACS-sorted BALB/c spleen DC subpopulations. Comparison of differentially expressed genes between IKDCs and cDCs vividly revealed selective expression of multiple NK-related genes in IKDCs . These included granzymes A, B, K and M, perforin, Fas ligand, and NK receptors such as NKG2A, NKG2D, Ly49 family genes, NKR-P1, NKG7, NKp46 and Mafa (KLRG1). No NK-related genes were highly expressed in the PDCs.

Standard name | GSE3691_IFN_PRODUCING_KILLER_DC_VS_PLASMACYTOID_DC_SPLEEN_UP
Systematic name | M6367
Organism | Mus musculus
PMID | 16444266
Authors | Chan CW,Crafton E,Fan HN,Flook J,Yoshimura K,Skarica M,Brockstedt D,Dubensky TW,Stins MF,Lanier LL,Pardoll DM,Housseau F
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendiritic cells from speen: interferon producing killer cells versus plasmacytoid.
Full description | To characterize differences between BALB/c splenic CD11cintB220+Gr1+ PDCs (plasmacytoid dendritic cells), CD11cintB220+CD49b+ IKDCs (interferon producing killer-dendritic cells), and CD11chighB220- cDCs (conventional dendritic cells), we performed gene expression profile analysis using Affymetrix chips. We FACS-sorted BALB/c spleen DC subpopulations. Comparison of differentially expressed genes between IKDCs and cDCs vividly revealed selective expression of multiple NK-related genes in IKDCs . These included granzymes A, B, K and M, perforin, Fas ligand, and NK receptors such as NKG2A, NKG2D, Ly49 family genes, NKR-P1, NKG7, NKp46 and Mafa (KLRG1). No NK-related genes were highly expressed in the PDCs.

Standard name | GSE3691_CONVENTIONAL_VS_PLASMACYTOID_DC_SPLEEN_DN
Systematic name | M6368
Organism | Mus musculus
PMID | 16444266
Authors | Chan CW,Crafton E,Fan HN,Flook J,Yoshimura K,Skarica M,Brockstedt D,Dubensky TW,Stins MF,Lanier LL,Pardoll DM,Housseau F
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendiritic cells from speen: conventional versus plasmacytoid.
Full description | To characterize differences between BALB/c splenic CD11cintB220+Gr1+ PDCs (plasmacytoid dendritic cells), CD11cintB220+CD49b+ IKDCs (interferon producing killer-dendritic cells), and CD11chighB220- cDCs (conventional dendritic cells), we performed gene expression profile analysis using Affymetrix chips. We FACS-sorted BALB/c spleen DC subpopulations. Comparison of differentially expressed genes between IKDCs and cDCs vividly revealed selective expression of multiple NK-related genes in IKDCs . These included granzymes A, B, K and M, perforin, Fas ligand, and NK receptors such as NKG2A, NKG2D, Ly49 family genes, NKR-P1, NKG7, NKp46 and Mafa (KLRG1). No NK-related genes were highly expressed in the PDCs.

Standard name | GSE3691_CONVENTIONAL_VS_PLASMACYTOID_DC_SPLEEN_UP
Systematic name | M6369
Organism | Mus musculus
PMID | 16444266
Authors | Chan CW,Crafton E,Fan HN,Flook J,Yoshimura K,Skarica M,Brockstedt D,Dubensky TW,Stins MF,Lanier LL,Pardoll DM,Housseau F
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendiritic cells from speen: conventional versus plasmacytoid.
Full description | To characterize differences between BALB/c splenic CD11cintB220+Gr1+ PDCs (plasmacytoid dendritic cells), CD11cintB220+CD49b+ IKDCs (interferon producing killer-dendritic cells), and CD11chighB220- cDCs (conventional dendritic cells), we performed gene expression profile analysis using Affymetrix chips. We FACS-sorted BALB/c spleen DC subpopulations. Comparison of differentially expressed genes between IKDCs and cDCs vividly revealed selective expression of multiple NK-related genes in IKDCs . These included granzymes A, B, K and M, perforin, Fas ligand, and NK receptors such as NKG2A, NKG2D, Ly49 family genes, NKR-P1, NKG7, NKp46 and Mafa (KLRG1). No NK-related genes were highly expressed in the PDCs.

Standard name | GSE3994_WT_VS_PAC1_KO_ACTIVATED_MAST_CELL_UP
Systematic name | M6371
Organism | Mus musculus
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived mast cells: wildtype versus ADCYAP1R1 [GeneID=117] knockout.
Full description | Bone marrow-derived mast cells were differentiated over 4-6 weeks using bone marrow from Pac-1+/+ and Pac1-/- littermate mice. Cell purity was 99% c-kit and Fc epsilon receptor positive as assessed by flow cytometry. Cells were stimulated by Fc epsilon receptor crosslinking using IgE-DNP/HSA for sensitization for 18 hours and DNP-HSA antigen for crosslinking for 2 hours. Gene transcript abundance was determined and scaled to 150 using alogorithms in MicroArray Analysis Suite Software 5.0 (Affymetrix).

Standard name | GSE3994_WT_VS_PAC1_KO_ACTIVATED_MAST_CELL_DN
Systematic name | M6372
Organism | Mus musculus
PMID | 16474395
Authors | Jeffrey KL,Brummer T,Rolph MS,Liu SM,Callejas NA,Grumont RJ,Gillieron C,Mackay F,Grey S,Camps M,Rommel C,Gerondakis SD,Mackay CR
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived mast cells: wildtype versus ADCYAP1R1 [GeneID=117] knockout.
Full description | Bone marrow-derived mast cells were differentiated over 4-6 weeks using bone marrow from Pac-1+/+ and Pac1-/- littermate mice. Cell purity was 99% c-kit and Fc epsilon receptor positive as assessed by flow cytometry. Cells were stimulated by Fc epsilon receptor crosslinking using IgE-DNP/HSA for sensitization for 18 hours and DNP-HSA antigen for crosslinking for 2 hours. Gene transcript abundance was determined and scaled to 150 using alogorithms in MicroArray Analysis Suite Software 5.0 (Affymetrix).

Standard name | GSE4142_NAIVE_BCELL_VS_PLASMA_CELL_DN
Systematic name | M6374
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve B lymphocytes versus plasma cells.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_NAIVE_VS_GC_BCELL_UP
Systematic name | M6375
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: naïve versus germinal center.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_NAIVE_VS_GC_BCELL_DN
Systematic name | M6377
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: naïve versus germinal center.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_NAIVE_BCELL_VS_PLASMA_CELL_UP
Systematic name | M6381
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve B lymphocytes versus plasma cells.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_PLASMA_CELL_VS_GC_BCELL_DN
Systematic name | M6385
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasma cells versus germinal center B lymphocytes.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_NAIVE_VS_MEMORY_BCELL_UP
Systematic name | M6388
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: naïve versus memory.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_NAIVE_VS_MEMORY_BCELL_DN
Systematic name | M6389
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: naïve versus memory.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_PLASMA_CELL_VS_GC_BCELL_UP
Systematic name | M6390
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasma cells versus germinal center B lymphocytes.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_GC_BCELL_VS_MEMORY_BCELL_DN
Systematic name | M6393
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: germinal center versus memory.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_PLASMA_CELL_VS_MEMORY_BCELL_UP
Systematic name | M6395
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasma cells versus memory B lymphocytes.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_PLASMA_CELL_VS_MEMORY_BCELL_DN
Systematic name | M6396
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasma cells versus memory B lymphocytes.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE4142_GC_BCELL_VS_MEMORY_BCELL_UP
Systematic name | M6397
Organism | Mus musculus
PMID | 16492737
Authors | Luckey CJ,Bhattacharya D,Goldrath AW,Weissman IL,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: germinal center versus memory.
Full description | In order to better understand the factors that regulate B cell differentiation upon exposure to antigen, we compares global gene expression profiles from naive B cells with antigen-specific plasma, germinal center, and memory B cells after immunization with the T-dependent antigen, NP-CGG. The memory B cell-enriched transcripts were then compared with memory T cell-enriched and hematopoietic stem cell-enriched transcripts in order to generate a transcriptional profile of self-renewal within the hematopoietic system.

Standard name | GSE8921_UNSTIM_0H_VS_TLR1_2_STIM_MONOCYTE_3H_UP
Systematic name | M6398
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes: untreated versus M. tuberculosis 19 kDa lipopeptide (3h).
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_0H_VS_TLR1_2_STIM_MONOCYTE_3H_DN
Systematic name | M6399
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes: untreated versus M. tuberculosis 19 kDa lipopeptide (3h).
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_0H_VS_TLR1_2_STIM_MONOCYTE_6H_UP
Systematic name | M6403
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes: untreated versus M. tuberculosis 19 kDa lipopeptide (6h).
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_0H_VS_TLR1_2_STIM_MONOCYTE_6H_DN
Systematic name | M6404
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes: untreated versus M. tuberculosis 19 kDa lipopeptide (6h).
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_0H_VS_TLR1_2_STIM_MONOCYTE_12H_UP
Systematic name | M6406
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes: untreated versus M. tuberculosis 19 kDa lipopeptide (12h).
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_0H_VS_TLR1_2_STIM_MONOCYTE_12H_DN
Systematic name | M6408
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes: untreated versus M. tuberculosis 19 kDa lipopeptide (12h).
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_0H_VS_TLR1_2_STIM_MONOCYTE_24H_UP
Systematic name | M6410
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes: untreated versus M. tuberculosis 19 kDa lipopeptide (24h).
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_0H_VS_TLR1_2_STIM_MONOCYTE_24H_DN
Systematic name | M6411
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes: untreated versus M. tuberculosis 19 kDa lipopeptide (24h).
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_VS_TLR1_2_STIM_MONOCYTE_3H_UP
Systematic name | M6412
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (3h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_VS_TLR1_2_STIM_MONOCYTE_3H_DN
Systematic name | M6414
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (3h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_VS_TLR1_2_STIM_MONOCYTE_6H_UP
Systematic name | M6415
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (6h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_VS_TLR1_2_STIM_MONOCYTE_6H_DN
Systematic name | M6417
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (6h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_VS_TLR1_2_STIM_MONOCYTE_12H_UP
Systematic name | M6418
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (12h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_VS_TLR1_2_STIM_MONOCYTE_12H_DN
Systematic name | M6419
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (12h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_VS_TLR1_2_STIM_MONOCYTE_24H_UP
Systematic name | M6420
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (24h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_UNSTIM_VS_TLR1_2_STIM_MONOCYTE_24H_DN
Systematic name | M6421
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (24h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_3H_VS_24H_TLR1_2_STIM_MONOCYTE_UP
Systematic name | M6424
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes in response to M. tuberculosis 19 kDa lipopeptide: 3h versus 24h.
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE8921_3H_VS_24H_TLR1_2_STIM_MONOCYTE_DN
Systematic name | M6425
Organism | Homo sapiens
PMID | 16497887
Authors | Liu PT,Stenger S,Li H,Wenzel L,Tan BH,Krutzik SR,Ochoa MT,Schauber J,Wu K,Meinken C,Kamen DL,Wagner M,Bals R,Steinmeyer A,Zügel U,Gallo RL,Eisenberg D,Hewison M,Hollis BW,Adams JS,Bloom BR,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes in response to M. tuberculosis 19 kDa lipopeptide: 3h versus 24h.
Full description | In innate immune responses, activation of Toll-like receptors (TLRs) triggers direct antimicrobial activity against intracellular bacteria, which in murine, but not human, monocytes and macrophages is mediated principally by nitric oxide. We report here that TLR activation of human macrophages up-regulated expression of the vitamin D receptor and the vitamin D-1-hydroxylase genes, leading to induction of the antimicrobial peptide cathelicidin and killing of intracellular Mycobacterium tuberculosis. We also observed that sera from African-American individuals, known to have increased susceptibility to tuberculosis, had low 25-hydroxyvitamin D and were inefficient in supporting cathelicidin messenger RNA induction. These data support a link between TLRs and vitamin D-mediated innate immunity and suggest that differences in ability of human populations to produce vitamin D may contribute to susceptibility to microbial infection.

Standard name | GSE3039_CD4_TCELL_VS_NKT_CELL_UP
Systematic name | M6426
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells versus NKT cells.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_NKT_CELL_VS_ALPHABETA_CD8_TCELL_UP
Systematic name | M6429
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in NKT cell versus CD8A CD8B [GeneID=925;926] T cells.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_NKT_CELL_VS_ALPHABETA_CD8_TCELL_DN
Systematic name | M6430
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in NKT cell versus CD8A CD8B [GeneID=925;926] T cells.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_CD4_TCELL_VS_NKT_CELL_DN
Systematic name | M6431
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells versus NKT cells.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_NKT_CELL_VS_B1_BCELL_UP
Systematic name | M6432
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in NKT cells versus B1 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_NKT_CELL_VS_B1_BCELL_DN
Systematic name | M6433
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in NKT cells versus B1 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_NKT_CELL_VS_B2_BCELL_UP
Systematic name | M6435
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in NKT cells versus B2 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_NKT_CELL_VS_B2_BCELL_DN
Systematic name | M6436
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in NKT cells versus B2 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_ALPHAALPHA_CD8_TCELL_VS_B2_BCELL_UP
Systematic name | M6437
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A [GeneID=925] T cells versus B2 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_ALPHAALPHA_CD8_TCELL_VS_B2_BCELL_DN
Systematic name | M6439
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A [GeneID=925] T cells versus B2 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_ALPHAALPHA_CD8_TCELL_VS_B1_BCELL_UP
Systematic name | M6440
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A [GeneID=925] T cells versus B1 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_ALPHAALPHA_CD8_TCELL_VS_B1_BCELL_DN
Systematic name | M6442
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A [GeneID=925] T cells versus B1 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_ALPHABETA_CD8_TCELL_VS_B2_BCELL_UP
Systematic name | M6443
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A CD8B [GeneID=925;926] versus B2 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_ALPHABETA_CD8_TCELL_VS_B2_BCELL_DN
Systematic name | M6445
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A CD8B [GeneID=925;926] versus B2 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_ALPHABETA_CD8_TCELL_VS_B1_BCELL_UP
Systematic name | M6447
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A CD8B [GeneID=925;926] versus B1 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_ALPHABETA_CD8_TCELL_VS_B1_BCELL_DN
Systematic name | M6449
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A CD8B [GeneID=925;926] versus B1 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_B2_VS_B1_BCELL_UP
Systematic name | M6450
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: B2 versus B1.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_B2_VS_B1_BCELL_DN
Systematic name | M6453
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: B2 versus B1.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_CD4_TCELL_VS_ALPHAALPHA_CD8_TCELL_UP
Systematic name | M6456
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: CD4 [GeneID=920] versus CD8A [GeneID=925].
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_CD4_TCELL_VS_ALPHAALPHA_CD8_TCELL_DN
Systematic name | M6457
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: CD4 [GeneID=920] versus CD8A [GeneID=925].
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_CD4_TCELL_VS_ALPHABETA_CD8_TCELL_UP
Systematic name | M6459
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: CD4 [GeneID=920] versus CD8A CD8B [GeneID=925;926].
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_CD4_TCELL_VS_ALPHABETA_CD8_TCELL_DN
Systematic name | M6461
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: CD4 [GeneID=920] versus CD8A CD8B [GeneID=925;926].
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_CD4_TCELL_VS_B2_BCELL_UP
Systematic name | M6462
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells versus B2 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_CD4_TCELL_VS_B2_BCELL_DN
Systematic name | M6464
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells versus B2 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_CD4_TCELL_VS_B1_BCELL_UP
Systematic name | M6466
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells versus B1 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_CD4_TCELL_VS_B1_BCELL_DN
Systematic name | M6468
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells versus B1 B lymphocytes.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_NKT_CELL_VS_ALPHAALPHA_CD8_TCELL_UP
Systematic name | M6473
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in NKT cells versus CD8A [GeneID=925] T cells.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_NKT_CELL_VS_ALPHAALPHA_CD8_TCELL_DN
Systematic name | M6474
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in NKT cells versus CD8A [GeneID=925] T cells.
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_ALPHAALPHA_VS_ALPHABETA_CD8_TCELL_DN
Systematic name | M6475
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: CD8A [GeneID=925] versus CD8A CD8B [GeneID=925;926].
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE3039_ALPHAALPHA_VS_ALPHABETA_CD8_TCELL_UP
Systematic name | M6476
Organism | Mus musculus
PMID | 16623764
Authors | Yamagata T,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: CD8A [GeneID=925] versus CD8A CD8B [GeneID=925;926].
Full description | Three innate (B1-B, NKT, CD8aaT cells) and adaptive (B2-B, CD4T, CD8abT cells) cell-types were sorted by FACS. Three biological replicates for NKT, CD4T, CD8aaT, CD8abT cells and two biological replicates for B1 and B2 cells were generated and the expression profiles were determined using Affymetrix Mu74Av2 chip. Comparisons between the sample groups allow the identification of genes differentially expressed between the innate and adaptive cell-types.

Standard name | GSE4748_CTRL_VS_CYANOBACTERIUM_LPSLIKE_STIM_DC_3H_UP
Systematic name | M6477
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: untreated versus LPS like antigen from O. planktothrix (3h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_CTRL_VS_CYANOBACTERIUM_LPSLIKE_STIM_DC_3H_DN
Systematic name | M6478
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: untreated versus LPS like antigen from O. planktothrix (3h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_CTRL_VS_LPS_STIM_DC_3H_UP
Systematic name | M6480
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: untreated versus LPS (3h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_CTRL_VS_LPS_STIM_DC_3H_DN
Systematic name | M6481
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: untreated versus LPS (3h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_CTRL_VS_LPS_AND_CYANOBACTERIUM_LPSLIKE_STIM_DC_3H_UP
Systematic name | M6484
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: untreated versus LPS and LPS like antigen from O. planktothrix (3h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_CTRL_VS_LPS_AND_CYANOBACTERIUM_LPSLIKE_STIM_DC_3H_DN
Systematic name | M6485
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: untreated versus LPS and LPS like antigen from O. planktothrix (3h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_CTRL_VS_CYANOBACTERIUM_LPSLIKE_STIM_DC_1H_UP
Systematic name | M6486
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: untreated versus LPS like antigen from O. planktothrix (1h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_CTRL_VS_CYANOBACTERIUM_LPSLIKE_STIM_DC_1H_DN
Systematic name | M6488
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: untreated versus LPS like antigen from O. planktothrix (1h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_CYANOBACTERIUM_LPSLIKE_VS_LPS_AND_CYANOBACTERIUM_LPSLIKE_STIM_DC_3H_UP
Systematic name | M6491
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: LPS like antigen from O. planktothrix (3h) versus LPS and LPS like antigen from O. planktothrix (3h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_CYANOBACTERIUM_LPSLIKE_VS_LPS_AND_CYANOBACTERIUM_LPSLIKE_STIM_DC_3H_DN
Systematic name | M6492
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: LPS like antigen from O. planktothrix (3h) versus LPS and LPS like antigen from O. planktothrix (3h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_LPS_VS_LPS_AND_CYANOBACTERIUM_LPSLIKE_STIM_DC_3H_UP
Systematic name | M6493
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: LPS (3h) versus LPS and LPS like antigen from O. planktothrix (3h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4748_LPS_VS_LPS_AND_CYANOBACTERIUM_LPSLIKE_STIM_DC_3H_DN
Systematic name | M6494
Organism | Homo sapiens
PMID | 16717116
Authors | Macagno A,Molteni M,Rinaldi A,Bertoni F,Lanzavecchia A,Rossetti C,Sallusto F
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: LPS (3h) versus LPS and LPS like antigen from O. planktothrix (3h).
Full description | A cyanobacterial LPS antagonist prevents endotoxin shock and blocks sustained TLR4 stimulation required for cytokine expression. We report the identification and biologic characterization of an LPS-like molecule extracted from the cyanobacterium Oscillatoria Planktothrix FP1 (CyP).

Standard name | GSE4984_UNTREATED_VS_GALECTIN1_TREATED_DC_UP
Systematic name | M6495
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: control versus treated with LGALS1 [GeneID=3956].
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_UNTREATED_VS_GALECTIN1_TREATED_DC_DN
Systematic name | M6496
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: control versus treated with LGALS1 [GeneID=3956].
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_UNTREATED_VS_LPS_TREATED_DC_UP
Systematic name | M6498
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: control versus LPS.
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_UNTREATED_VS_LPS_TREATED_DC_DN
Systematic name | M6499
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: control versus LPS.
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_UNTREATED_VS_VEHICLE_CTRL_TREATED_DC_UP
Systematic name | M6500
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: untreated versus vehicle.
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_UNTREATED_VS_VEHICLE_CTRL_TREATED_DC_DN
Systematic name | M6501
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: untreated versus vehicle.
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_GALECTIN1_VS_LPS_STIM_DC_UP
Systematic name | M6502
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: LGALS1 [GeneID=3956] versus LPS.
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_GALECTIN1_VS_LPS_STIM_DC_DN
Systematic name | M6504
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: LGALS1 [GeneID=3956] versus LPS.
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_GALECTIN1_VS_VEHICLE_CTRL_TREATED_DC_UP
Systematic name | M6505
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: LGALS1 [GeneID=3956] versus vehicle.
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_GALECTIN1_VS_VEHICLE_CTRL_TREATED_DC_DN
Systematic name | M6507
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: LGALS1 [GeneID=3956] versus vehicle.
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_LPS_VS_VEHICLE_CTRL_TREATED_DC_UP
Systematic name | M6508
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: LPS versus vehicle.
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE4984_LPS_VS_VEHICLE_CTRL_TREATED_DC_DN
Systematic name | M6511
Organism | Homo sapiens
PMID | 16785517
Authors | Fulcher JA,Hashimi ST,Levroney EL,Pang M,Gurney KB,Baum LG,Lee B
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: LPS versus vehicle.
Full description | Human monocyte derived dendritic cells matured via galectin-1 or LPS.

Standard name | GSE5542_UNTREATED_VS_IFNG_TREATED_EPITHELIAL_CELLS_6H_UP
Systematic name | M6512
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (6h): untreated versus IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNG_TREATED_EPITHELIAL_CELLS_6H_DN
Systematic name | M6513
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (6h): untreated versus IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNA_TREATED_EPITHELIAL_CELLS_6H_UP
Systematic name | M6514
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (6h): untreated versus interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNA_TREATED_EPITHELIAL_CELLS_6H_DN
Systematic name | M6516
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (6h): untreated versus interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_6H_UP
Systematic name | M6518
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (6h): untreated versus interferon alpha and IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_6H_DN
Systematic name | M6519
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (6h): untreated versus interferon alpha and IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNG_TREATED_EPITHELIAL_CELLS_24H_UP
Systematic name | M6522
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (24h): untreated versus IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNG_TREATED_EPITHELIAL_CELLS_24H_DN
Systematic name | M6523
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (24h): untreated versus IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNA_TREATED_EPITHELIAL_CELLS_24H_UP
Systematic name | M6524
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (24h): untreated versus interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNA_TREATED_EPITHELIAL_CELLS_24H_DN
Systematic name | M6525
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (24h): untreated versus interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_24H_UP
Systematic name | M6527
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (24h): untreated versus interferon alpha and IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_UNTREATED_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_24H_DN
Systematic name | M6529
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (24h): untreated versus interferon alpha and IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNG_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_6H_UP
Systematic name | M6531
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (6h): IFNG [GeneID=3458] versus IFNG [GeneID=3458] and interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNG_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_6H_DN
Systematic name | M6533
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (6h): IFNG [GeneID=3458] versus IFNG [GeneID=3458] and interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNG_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_24H_UP
Systematic name | M6535
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (24h): IFNG [GeneID=3458] versus IFNG [GeneID=3458] and interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNG_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_24H_DN
Systematic name | M6536
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (24h): IFNG [GeneID=3458] versus IFNG [GeneID=3458] and interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNA_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_6H_UP
Systematic name | M6537
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (6h): interferon alpha versus interferon alpha and IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNA_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_6H_DN
Systematic name | M6538
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (6h): interferon alpha versus interferon alpha and IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNA_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_24H_UP
Systematic name | M6539
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (24h): interferon alpha versus interferon alpha and IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNA_VS_IFNA_AND_IFNG_TREATED_EPITHELIAL_CELLS_24H_DN
Systematic name | M6540
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (24h): interferon alpha versus interferon alpha and IFNG [GeneID=3458].
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNG_VS_IFNA_TREATED_EPITHELIAL_CELLS_6H_UP
Systematic name | M6542
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (6h): IFNG [GeneID=3458] versus interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNG_VS_IFNA_TREATED_EPITHELIAL_CELLS_6H_DN
Systematic name | M6543
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (6h): IFNG [GeneID=3458] versus interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNG_VS_IFNA_TREATED_EPITHELIAL_CELLS_24H_UP
Systematic name | M6544
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes up-regulated in epithelial cells (24h): IFNG [GeneID=3458] versus interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE5542_IFNG_VS_IFNA_TREATED_EPITHELIAL_CELLS_24H_DN
Systematic name | M6546
Organism | Homo sapiens
PMID | 16800785
Authors | Sanda C,Weitzel P,Tsukahara T,Schaley J,Edenberg HJ,Stephens MA,McClintick JN,Blatt LM,Li L,Brodsky L,Taylor MW
Category | C7
Sub-category |
Brief description | Genes down-regulated in epithelial cells (24h): IFNG [GeneID=3458] versus interferon alpha.
Full description | Type I and type II interferons (IFNs) bind to different cell surface receptors but activate overlapping signal transduction pathways. We examined the effects of a type I IFN (IFN-acon1) and a type II iFN (IFN-g1b) on gene experession in A549 cells and demonstrate that there is a common set of genes modulated by both IFNs as well as a set of gene specifically regulated by each, reflecting the activation of different signaling pathways. In particualr, IFN-g induced many more genes of the signaling pathways, apoptosis, and cytokine interactions than did IFN-a. Even with genes induced by both IFNs there were distinctive quantitativive differences in expression. IFN-g1b plays a major role in the induction and regulation of the complement pathway. Previous work has shown a synergistic antivral and antiproliferative effect of type I and type II IFNs in cell culture and in the treament of tumors in mice. We demonstrate that a majority of genes showed and additive effect of IFN-acon1 and IFN-g1b, but a subset of gene is synergistically induced; these incluce ISG10, MX2, OAS2, and other genes known to be involved in the antiviral response, TRAIL (TNFSF10) and caspases involved in apoptosis and chemokine genes RANTES, CXCL10, and CXCL11. Greater than additive transcription of some of these genes in the presence of both IFNs was confirmed by real-time kinetic RT-PCR. Elevated induction of many of these genes may be sufficient to explain the synergistic antiviral and antitumor effects of this combination of IFNS in vivo.

Standard name | GSE4811_CLASSSICALY_ACTIVATED_VS_TYPE_2_ACTIVATED_MACROPHAGE_UP
Systematic name | M6547
Organism | Mus musculus
PMID | 16905575
Authors | Edwards JP,Zhang X,Frauwirth KA,Mosser DM
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated macrophages: classically (M1) versus alternative (M2).
Full description | The purpose of this study is to identify novel markers for the type II activated macrophage, which is generated by classical stimulation in the presence if IgG immune complexes. These cells gererally produce high levels of IL-10 and low levels of IL-12, in comparison to classically activated macrophages. We wish to identify gene expression which is enriched in Type II activated macrophages in comparison to classically activated macrophages.

Standard name | GSE4811_CLASSSICALY_ACTIVATED_VS_TYPE_2_ACTIVATED_MACROPHAGE_DN
Systematic name | M6548
Organism | Mus musculus
PMID | 16905575
Authors | Edwards JP,Zhang X,Frauwirth KA,Mosser DM
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated macrophages: classically (M1) versus alternative (M2).
Full description | The purpose of this study is to identify novel markers for the type II activated macrophage, which is generated by classical stimulation in the presence if IgG immune complexes. These cells gererally produce high levels of IL-10 and low levels of IL-12, in comparison to classically activated macrophages. We wish to identify gene expression which is enriched in Type II activated macrophages in comparison to classically activated macrophages.

Standard name | GSE5142_CTRL_VS_HTERT_TRANSDUCED_CD8_TCELL_EARLY_PASSAGE_CLONE_UP
Systematic name | M6549
Organism | Homo sapiens
PMID | 16951325
Authors | Menzel O,Migliaccio M,Goldstein DR,Dahoun S,Delorenzi M,Rufer N
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: control versus over-expressing TERT [GeneID=7015].
Full description | Using CD8+ T lymphocyte clones over-expressing telomerase weinvestigated the molecular mechanisms that regulate T cell proliferation. Transduction and subcloning procedures were performed on CD8 + naive T-cell clones isolated from two different healthy individuals aged between 30 to 35 years (HD1 and HD2). T-cell cloneswere transduced to express hTERT/GFP or GFP alone. HD2 was profiled on U133Plus 2.0 and submitted as a separate GEO series.

Standard name | GSE5142_CTRL_VS_HTERT_TRANSDUCED_CD8_TCELL_EARLY_PASSAGE_CLONE_DN
Systematic name | M6550
Organism | Homo sapiens
PMID | 16951325
Authors | Menzel O,Migliaccio M,Goldstein DR,Dahoun S,Delorenzi M,Rufer N
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: control versus over-expressing TERT [GeneID=7015].
Full description | Using CD8+ T lymphocyte clones over-expressing telomerase weinvestigated the molecular mechanisms that regulate T cell proliferation. Transduction and subcloning procedures were performed on CD8 + naive T-cell clones isolated from two different healthy individuals aged between 30 to 35 years (HD1 and HD2). T-cell cloneswere transduced to express hTERT/GFP or GFP alone. HD2 was profiled on U133Plus 2.0 and submitted as a separate GEO series.

Standard name | GSE5142_HTERT_TRANSDUCED_VS_CTRL_CD8_TCELL_LATE_PASSAGE_CLONE_UP
Systematic name | M6551
Organism | Homo sapiens
PMID | 16951325
Authors | Menzel O,Migliaccio M,Goldstein DR,Dahoun S,Delorenzi M,Rufer N
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: early passage clone over-expressing TERT [GeneID=7015] versus late passage control.
Full description | Using CD8+ T lymphocyte clones over-expressing telomerase weinvestigated the molecular mechanisms that regulate T cell proliferation. Transduction and subcloning procedures were performed on CD8 + naive T-cell clones isolated from two different healthy individuals aged between 30 to 35 years (HD1 and HD2). T-cell cloneswere transduced to express hTERT/GFP or GFP alone. HD2 was profiled on U133Plus 2.0 and submitted as a separate GEO series.

Standard name | GSE5142_HTERT_TRANSDUCED_VS_CTRL_CD8_TCELL_LATE_PASSAGE_CLONE_DN
Systematic name | M6552
Organism | Homo sapiens
PMID | 16951325
Authors | Menzel O,Migliaccio M,Goldstein DR,Dahoun S,Delorenzi M,Rufer N
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: early passage clone over-expressing TERT [GeneID=7015] versus late passage control.
Full description | Using CD8+ T lymphocyte clones over-expressing telomerase weinvestigated the molecular mechanisms that regulate T cell proliferation. Transduction and subcloning procedures were performed on CD8 + naive T-cell clones isolated from two different healthy individuals aged between 30 to 35 years (HD1 and HD2). T-cell cloneswere transduced to express hTERT/GFP or GFP alone. HD2 was profiled on U133Plus 2.0 and submitted as a separate GEO series.

Standard name | GSE5679_CTRL_VS_PPARG_LIGAND_ROSIGLITAZONE_TREATED_DC_UP
Systematic name | M6553
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: untreated versus rosiglitazone [PubChem=77999].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_CTRL_VS_PPARG_LIGAND_ROSIGLITAZONE_TREATED_DC_DN
Systematic name | M6554
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: untreated versus rosiglitazone [PubChem=77999].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_CTRL_VS_RARA_AGONIST_AM580_TREATED_DC_UP
Systematic name | M6555
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: untreated versus AM580 [PubChem=2126].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_CTRL_VS_RARA_AGONIST_AM580_TREATED_DC_DN
Systematic name | M6556
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: untreated versus AM580 [PubChem=2126].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_CTRL_VS_PPARG_LIGAND_ROSIGLITAZONE_AND_RARA_AGONIST_AM580_TREATED_DC_UP
Systematic name | M6558
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: untreated versus rosiglitazone and AM580 [PubChem=77999;2126].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_CTRL_VS_PPARG_LIGAND_ROSIGLITAZONE_AND_RARA_AGONIST_AM580_TREATED_DC_DN
Systematic name | M6560
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: untreated versus rosiglitazone and AM580 [PubChem=77999;2126].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_PPARG_LIGAND_ROSIGLITAZONE_VS_RARA_AGONIST_AM580_TREATED_DC_UP
Systematic name | M6561
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: rosiglitazone [PubChem=77999] versus AM580 [PubChem=2126].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_PPARG_LIGAND_ROSIGLITAZONE_VS_RARA_AGONIST_AM580_TREATED_DC_DN
Systematic name | M6563
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: rosiglitazone [PubChem=77999] versus AM580 [PubChem=2126].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_PPARG_LIGAND_ROSIGLITAZONE_VS_ROSIGLITAZONE_AND_RARA_AGONIST_AM580_TREATED_DC_UP
Systematic name | M6565
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: rosiglitazone [PubChem=77999] versus rosiglitazone and AM580 [PubChem=77999;2126].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_PPARG_LIGAND_ROSIGLITAZONE_VS_ROSIGLITAZONE_AND_RARA_AGONIST_AM580_TREATED_DC_DN
Systematic name | M6567
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: rosiglitazone [PubChem=77999] versus rosiglitazone and AM580 [PubChem=77999;2126].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_RARA_AGONIST_AM580_VS_AM580_AND_ROSIGLITAZONE_TREATED_DC_UP
Systematic name | M6569
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: AM580 [PubChem=2126] versus rosiglitazone and AM580 [PubChem=77999;2126].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE5679_RARA_AGONIST_AM580_VS_AM580_AND_ROSIGLITAZONE_TREATED_DC_DN
Systematic name | M6570
Organism | Homo sapiens
PMID | 16982809
Authors | Szatmari I,Pap A,Rühl R,Ma JX,Illarionov PA,Besra GS,Rajnavolgyi E,Dezso B,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: AM580 [PubChem=2126] versus rosiglitazone and AM580 [PubChem=77999;2126].
Full description | Our data indicated that activation of the PPARg nuclear receptor induces a retinoid response in human dendritic cells. In order to assess the contribution of retinoid signaling to the PPARg response we decided to use a combination of pharmacological activators and inhibitors of these pathways. Cells were treated with the synthetic PPARg ligand rosiglitazone (RSG), or with RSG along with the RARa antagonist (AGN193109) to block RARa mediated gene expression, or the RARa specific agonists (AM580) alone. This design allows one to determine if retinoid signaling is a downstream event of PPARg activation and what portion of PPARg regulated genes are regulated via induced retinoid signaling.

Standard name | GSE4535_BM_DERIVED_DC_VS_FOLLICULAR_DC_UP
Systematic name | M6573
Organism | Mus musculus
PMID | 17015706
Authors | Nishikawa Y,Hikida M,Magari M,Kanayama N,Mori M,Kitamura H,Kurosaki T,Ohmori H
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: bone marrow-derived versus follicular.
Full description | expression profiles of FDC and BMDC are compared

Standard name | GSE4535_BM_DERIVED_DC_VS_FOLLICULAR_DC_DN
Systematic name | M6574
Organism | Mus musculus
PMID | 17015706
Authors | Nishikawa Y,Hikida M,Magari M,Kanayama N,Mori M,Kitamura H,Kurosaki T,Ohmori H
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: bone marrow-derived versus follicular.
Full description | expression profiles of FDC and BMDC are compared

Standard name | GSE5455_HEALTHY_VS_TUMOR_BEARING_MOUSE_SPLEEN_MONOCYTE_UP
Systematic name | M6575
Organism | Mus musculus
PMID | 17016559
Authors | Gallina G,Dolcetti L,Serafini P,Santo De C,Marigo I,Colombo MP,Basso G,Brombacher F,Borrello I,Zanovello P,Bicciato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in ITGAM+ [GeneID=3684] cells from spleen: healthy versus tumor bearing mice.
Full description | Active suppression of tumor-specific T lymphocytes can limit the immune-surveillance and immunotherapy efficacy. While tumor-recruited CD11b+ myeloid cells are known mediators of tumor-associated immune dysfunction, the true nature of these suppressive cells and the fine biochemical pathways governing their immunosuppressive activity remain elusive. Here we describe a population of circulating CD11b+/IL-4Rα+, inflammatory-type monocytes that is elicited by growing tumors and activated by IFN-γ released from T lymphocytes. CD11b+/IL-4Rα+ cells produce IL-13 and IFN-γ and integrate the downstream signals of these cytokines to trigger the molecular pathways suppressing antigen-activated CD8+ T lymphocytes. Analogous immunosuppressive circuits are active in CD11b+ cells present within the tumor microenvironment. These suppressor cells challenge the current idea that tumor-conditioned immunosuppressive monocytes/macrophages are alternatively activated. Moreover, our data show how the inflammatory response elicited by tumors has detrimental effects on the adaptive immune system and suggest novel approaches for the treatment of tumorinduced immune dysfunctions.

Standard name | GSE5455_HEALTHY_VS_TUMOR_BEARING_MOUSE_SPLEEN_MONOCYTE_DN
Systematic name | M6576
Organism | Mus musculus
PMID | 17016559
Authors | Gallina G,Dolcetti L,Serafini P,Santo De C,Marigo I,Colombo MP,Basso G,Brombacher F,Borrello I,Zanovello P,Bicciato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in ITGAM+ [GeneID=3684] cells from spleen: healthy versus tumor bearing mice.
Full description | Active suppression of tumor-specific T lymphocytes can limit the immune-surveillance and immunotherapy efficacy. While tumor-recruited CD11b+ myeloid cells are known mediators of tumor-associated immune dysfunction, the true nature of these suppressive cells and the fine biochemical pathways governing their immunosuppressive activity remain elusive. Here we describe a population of circulating CD11b+/IL-4Rα+, inflammatory-type monocytes that is elicited by growing tumors and activated by IFN-γ released from T lymphocytes. CD11b+/IL-4Rα+ cells produce IL-13 and IFN-γ and integrate the downstream signals of these cytokines to trigger the molecular pathways suppressing antigen-activated CD8+ T lymphocytes. Analogous immunosuppressive circuits are active in CD11b+ cells present within the tumor microenvironment. These suppressor cells challenge the current idea that tumor-conditioned immunosuppressive monocytes/macrophages are alternatively activated. Moreover, our data show how the inflammatory response elicited by tumors has detrimental effects on the adaptive immune system and suggest novel approaches for the treatment of tumorinduced immune dysfunctions.

Standard name | GSE5455_HEALTHY_VS_TUMOR_BEARING_MOUSE_SPLEEN_MONOCYTE_24H_INCUBATION_UP
Systematic name | M6577
Organism | Mus musculus
PMID | 17016559
Authors | Gallina G,Dolcetti L,Serafini P,Santo De C,Marigo I,Colombo MP,Basso G,Brombacher F,Borrello I,Zanovello P,Bicciato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in ITGAM+ [GeneID=3684] cells (incubated for 24h in complete medium) from spleen: healthy versus tumor bearing mice.
Full description | Active suppression of tumor-specific T lymphocytes can limit the immune-surveillance and immunotherapy efficacy. While tumor-recruited CD11b+ myeloid cells are known mediators of tumor-associated immune dysfunction, the true nature of these suppressive cells and the fine biochemical pathways governing their immunosuppressive activity remain elusive. Here we describe a population of circulating CD11b+/IL-4Rα+, inflammatory-type monocytes that is elicited by growing tumors and activated by IFN-γ released from T lymphocytes. CD11b+/IL-4Rα+ cells produce IL-13 and IFN-γ and integrate the downstream signals of these cytokines to trigger the molecular pathways suppressing antigen-activated CD8+ T lymphocytes. Analogous immunosuppressive circuits are active in CD11b+ cells present within the tumor microenvironment. These suppressor cells challenge the current idea that tumor-conditioned immunosuppressive monocytes/macrophages are alternatively activated. Moreover, our data show how the inflammatory response elicited by tumors has detrimental effects on the adaptive immune system and suggest novel approaches for the treatment of tumorinduced immune dysfunctions.

Standard name | GSE5455_HEALTHY_VS_TUMOR_BEARING_MOUSE_SPLEEN_MONOCYTE_24H_INCUBATION_DN
Systematic name | M6578
Organism | Mus musculus
PMID | 17016559
Authors | Gallina G,Dolcetti L,Serafini P,Santo De C,Marigo I,Colombo MP,Basso G,Brombacher F,Borrello I,Zanovello P,Bicciato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in ITGAM+ [GeneID=3684] cells (incubated for 24h in complete medium) from spleen: healthy versus tumor bearing mice.
Full description | Active suppression of tumor-specific T lymphocytes can limit the immune-surveillance and immunotherapy efficacy. While tumor-recruited CD11b+ myeloid cells are known mediators of tumor-associated immune dysfunction, the true nature of these suppressive cells and the fine biochemical pathways governing their immunosuppressive activity remain elusive. Here we describe a population of circulating CD11b+/IL-4Rα+, inflammatory-type monocytes that is elicited by growing tumors and activated by IFN-γ released from T lymphocytes. CD11b+/IL-4Rα+ cells produce IL-13 and IFN-γ and integrate the downstream signals of these cytokines to trigger the molecular pathways suppressing antigen-activated CD8+ T lymphocytes. Analogous immunosuppressive circuits are active in CD11b+ cells present within the tumor microenvironment. These suppressor cells challenge the current idea that tumor-conditioned immunosuppressive monocytes/macrophages are alternatively activated. Moreover, our data show how the inflammatory response elicited by tumors has detrimental effects on the adaptive immune system and suggest novel approaches for the treatment of tumorinduced immune dysfunctions.

Standard name | GSE5455_EX_VIVO_VS_POST_24H_INCUBATION_MONOCYTES_FROM_TUMOR_BEARING_MOUSE_UP
Systematic name | M6579
Organism | Mus musculus
PMID | 17016559
Authors | Gallina G,Dolcetti L,Serafini P,Santo De C,Marigo I,Colombo MP,Basso G,Brombacher F,Borrello I,Zanovello P,Bicciato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in ITGAM+ [GeneID=3684] cells from spleens of tumor bearing mice: processed immediately versus those incubated for 24h in complete medium.
Full description | Active suppression of tumor-specific T lymphocytes can limit the immune-surveillance and immunotherapy efficacy. While tumor-recruited CD11b+ myeloid cells are known mediators of tumor-associated immune dysfunction, the true nature of these suppressive cells and the fine biochemical pathways governing their immunosuppressive activity remain elusive. Here we describe a population of circulating CD11b+/IL-4Rα+, inflammatory-type monocytes that is elicited by growing tumors and activated by IFN-γ released from T lymphocytes. CD11b+/IL-4Rα+ cells produce IL-13 and IFN-γ and integrate the downstream signals of these cytokines to trigger the molecular pathways suppressing antigen-activated CD8+ T lymphocytes. Analogous immunosuppressive circuits are active in CD11b+ cells present within the tumor microenvironment. These suppressor cells challenge the current idea that tumor-conditioned immunosuppressive monocytes/macrophages are alternatively activated. Moreover, our data show how the inflammatory response elicited by tumors has detrimental effects on the adaptive immune system and suggest novel approaches for the treatment of tumorinduced immune dysfunctions.

Standard name | GSE5455_EX_VIVO_VS_POST_24H_INCUBATION_MONOCYTES_FROM_TUMOR_BEARING_MOUSE_DN
Systematic name | M6580
Organism | Mus musculus
PMID | 17016559
Authors | Gallina G,Dolcetti L,Serafini P,Santo De C,Marigo I,Colombo MP,Basso G,Brombacher F,Borrello I,Zanovello P,Bicciato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in ITGAM+ [GeneID=3684] cells from spleens of tumor bearing mice: processed immediately versus those incubated for 24h in complete medium.
Full description | Active suppression of tumor-specific T lymphocytes can limit the immune-surveillance and immunotherapy efficacy. While tumor-recruited CD11b+ myeloid cells are known mediators of tumor-associated immune dysfunction, the true nature of these suppressive cells and the fine biochemical pathways governing their immunosuppressive activity remain elusive. Here we describe a population of circulating CD11b+/IL-4Rα+, inflammatory-type monocytes that is elicited by growing tumors and activated by IFN-γ released from T lymphocytes. CD11b+/IL-4Rα+ cells produce IL-13 and IFN-γ and integrate the downstream signals of these cytokines to trigger the molecular pathways suppressing antigen-activated CD8+ T lymphocytes. Analogous immunosuppressive circuits are active in CD11b+ cells present within the tumor microenvironment. These suppressor cells challenge the current idea that tumor-conditioned immunosuppressive monocytes/macrophages are alternatively activated. Moreover, our data show how the inflammatory response elicited by tumors has detrimental effects on the adaptive immune system and suggest novel approaches for the treatment of tumorinduced immune dysfunctions.

Standard name | GSE5099_UNSTIM_VS_MCSF_TREATED_MONOCYTE_DAY3_UP
Systematic name | M6581
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes: untreated versus CSF1 [GeneID=1435].
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_UNSTIM_VS_MCSF_TREATED_MONOCYTE_DAY3_DN
Systematic name | M6583
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes: untreated versus CSF1 [GeneID=1435] knockout at day 3.
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_UNSTIM_VS_MCSF_TREATED_MONOCYTE_DAY7_UP
Systematic name | M6584
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes up-regulated in unstimulated monocytes versus macrophages incubated with CSF1 [GeneID=435] at day 7.
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_UNSTIM_VS_MCSF_TREATED_MONOCYTE_DAY7_DN
Systematic name | M6585
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes down-regulated in unstimulated monocytes versus macrophages incubated with CSF1 [GeneID=435] at day 7.
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_MONOCYTE_VS_CLASSICAL_M1_MACROPHAGE_UP
Systematic name | M6586
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes versus classically activated (M1) macrophages.
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_MONOCYTE_VS_CLASSICAL_M1_MACROPHAGE_DN
Systematic name | M6587
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes versus classically activated (M1) macrophages.
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_MONOCYTE_VS_ALTERNATIVE_M2_MACROPHAGE_UP
Systematic name | M6588
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes versus alternatively activated (M2) macrophages.
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_MONOCYTE_VS_ALTERNATIVE_M2_MACROPHAGE_DN
Systematic name | M6589
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes versus alternatively activated (M2) macrophages.
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_DAY3_VS_DAY7_MCSF_TREATED_MACROPHAGE_UP
Systematic name | M6592
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes up-regulated upon CSF1 [GeneID=1435] treatment: monocytes (3 days) versus macrophages (7 days).
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_DAY3_VS_DAY7_MCSF_TREATED_MACROPHAGE_DN
Systematic name | M6593
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes down-regulated upon CSF1 [GeneID=1435] treatment: monocytes (3 days) versus macrophages (7 days).
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_CLASSICAL_M1_VS_ALTERNATIVE_M2_MACROPHAGE_UP
Systematic name | M6595
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: classical (M1) versus alternative (M2).
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5099_CLASSICAL_M1_VS_ALTERNATIVE_M2_MACROPHAGE_DN
Systematic name | M6596
Organism | Homo sapiens
PMID | 17082649
Authors | Martinez FO,Gordon S,Locati M,Mantovani A
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: classical (M1) versus alternative (M2).
Full description | Monocytes mature tom acrophages in the presence of the lineage determining cytokine M-CSF. They can be further polarized into M1 or M2 macrophages with distinct functional properties. We used microarrays to detail the global programme of gene expression underlying macrophage maturation and polarization and identified distinct classes of up-regulated genes during this process.

Standard name | GSE5589_UNSTIM_VS_45MIN_LPS_STIM_MACROPHAGE_UP
Systematic name | M6597
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: untreated (0 min) versus LPS (45 min).
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_UNSTIM_VS_45MIN_LPS_STIM_MACROPHAGE_DN
Systematic name | M6599
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: untreated (0 min) versus LPS (45 min).
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_UNSTIM_VS_180MIN_LPS_STIM_MACROPHAGE_UP
Systematic name | M6600
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: untreated (0 min) versus LPS (180 min).
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_UNSTIM_VS_180MIN_LPS_STIM_MACROPHAGE_DN
Systematic name | M6601
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: untreated (0 min) versus LPS (180 min).
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_UNSTIM_VS_45MIN_LPS_AND_IL10_STIM_MACROPHAGE_UP
Systematic name | M6602
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: untreated (0 min) versus IL10 [GeneID=3586] and LPS (45 min).
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_UNSTIM_VS_45MIN_LPS_AND_IL10_STIM_MACROPHAGE_DN
Systematic name | M6603
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: untreated (0 min) versus IL10 [GeneID=3586] and LPS (45 min).
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_UNSTIM_VS_180MIN_LPS_AND_IL10_STIM_MACROPHAGE_UP
Systematic name | M6604
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: untreated (0 min) versus IL10 [GeneID=3586] and LPS (180 min).
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_UNSTIM_VS_180MIN_LPS_AND_IL10_STIM_MACROPHAGE_DN
Systematic name | M6605
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: untreated (0 min) versus IL10 [GeneID=3586] and LPS (180 min).
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_UNSTIM_VS_45MIN_LPS_AND_IL6_STIM_MACROPHAGE_UP
Systematic name | M6606
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: untreated (0 min) versus IL6 [GeneID=3569] and LPS (45 min).
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_UNSTIM_VS_45MIN_LPS_AND_IL6_STIM_MACROPHAGE_DN
Systematic name | M6607
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: untreated (0 min) versus IL6 [GeneID=3569] and LPS (45 min).
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6609
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophage (45 min): LPS versus IL10 [GeneID=3586] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6610
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophage (45 min): LPS versus IL10 [GeneID=3586] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL6_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6611
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophage (45 min): LPS versus IL6 [GeneID=3569] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL6_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6612
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophage (45 min): LPS versus IL6 [GeneID=3569] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_AND_IL10_VS_LPS_AND_IL6_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6613
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages (45 min): IL10 [GeneID=3486] and LPS versus IL6 [GeneID=3469] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_AND_IL10_VS_LPS_AND_IL6_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6614
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages (45 min): IL10 [GeneID=3486] and LPS versus IL6 [GeneID=3469] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_MACROPHAGE_180MIN_UP
Systematic name | M6615
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophage (180 min): LPS versus IL10 [GeneID=3586] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_MACROPHAGE_180MIN_DN
Systematic name | M6617
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophage (180 min): LPS versus IL10 [GeneID=3586] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_IL6_KO_MACROPHAGE_45MIN_UP
Systematic name | M6618
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with IL6 [GeneID=3569] knockout and 45 min of stimulation by: LPS versus IL10 [GeneID=3586] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_IL6_KO_MACROPHAGE_45MIN_DN
Systematic name | M6619
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with IL6 [GeneID=3569] knockout and 45 min of stimulation by: LPS versus IL10 [GeneID=3586] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL6_STIM_IL6_KO_MACROPHAGE_45MIN_UP
Systematic name | M6620
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with IL6 [GeneID=3569] knockout and 45 min of stimulation by: LPS versus IL6 [GeneID=3569] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL6_STIM_IL6_KO_MACROPHAGE_45MIN_DN
Systematic name | M6621
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with IL6 [GeneID=3569] knockout and 45 min of stimulation by: LPS versus IL6 [GeneID=3569] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_IL6_KO_MACROPHAGE_180MIN_UP
Systematic name | M6623
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with IL6 [GeneID=3569] knockout and 180 min of stimulation by: LPS versus IL10 [GeneID=3586] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_IL6_KO_MACROPHAGE_180MIN_DN
Systematic name | M6624
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with IL6 [GeneID=3569] knockout and 180 min of stimulation by: LPS versus IL10 [GeneID=3586] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_AND_IL10_VS_LPS_AND_IL6_STIM_IL6_KO_MACROPHAGE_45MIN_UP
Systematic name | M6625
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with IL6 [GeneID=3469] knockout and 45 min of stimulation by AIL10 [GeneID=3486] and LPS versus IL6 [GeneID=3469] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_AND_IL10_VS_LPS_AND_IL6_STIM_IL6_KO_MACROPHAGE_45MIN_DN
Systematic name | M6626
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with IL6 [GeneID=3469] knockout and 45 min of stimulation by AIL10 [GeneID=3486] and LPS versus IL6 [GeneID=3469] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_45MIN_UP
Systematic name | M6629
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with IL10 [GeneID=3486] knockout and 45 min of stimulation by: LPS versus LPS and IL10 [GeneID=3486].
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_45MIN_DN
Systematic name | M6630
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with IL10 [GeneID=3486] knockout and 45 min of stimulation by: LPS versus LPS and IL10 [GeneID=3486].
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL6_STIM_IL10_KO_MACROPHAGE_45MIN_UP
Systematic name | M6631
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with IL10 [GeneID=3486] knockout and 45 min stimulation by: LPS versus IL6 [GeneID=3469] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL6_STIM_IL10_KO_MACROPHAGE_45MIN_DN
Systematic name | M6632
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with IL10 [GeneID=3486] knockout and 45 min stimulation by: LPS versus IL6 [GeneID=3469] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_180MIN_UP
Systematic name | M6633
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with IL10 [GeneID=3486] and 180 min stimulation of: LPS versus IL10 [GeneID=3486] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_180MIN_DN
Systematic name | M6634
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with IL10 [GeneID=3486] and 180 min stimulation of: LPS versus IL10 [GeneID=3486] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_AND_IL10_VS_LPS_AND_IL6_STIM_IL10_KO_MACROPHAGE_45MIN_UP
Systematic name | M6635
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with IL10 [GeneID=3486] knockout and 45 min of stimulation by: LPS versus IL6 [GeneID=3469] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_LPS_AND_IL10_VS_LPS_AND_IL6_STIM_IL10_KO_MACROPHAGE_45MIN_DN
Systematic name | M6636
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with IL10 [GeneID=3486] knockout and 45 min of stimulation by: LPS versus IL6 [GeneID=3469] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL6_KO_LPS_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6638
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 45 min stimulation by LPS: wildtype versus IL6 [GeneID=3469] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL6_KO_LPS_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6639
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 45 min stimulation by LPS: wildtype versus IL6 [GeneID=3469] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL6_KO_LPS_AND_IL10_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6640
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophagesat 45 min stimulation of IL10 [GeneID=3486] and LPS: wildtype versus IL6 [GeneID=3469] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL6_KO_LPS_AND_IL10_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6644
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophagesat 45 min stimulation of IL10 [GeneID=3486] and LPS: wildtype versus IL6 [GeneID=3469] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL6_KO_LPS_AND_IL6_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6645
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 45 min of stimulation by IL6 [GeneID=3469] and LPS: wildtype versus IL6 [GeneID=3469] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL6_KO_LPS_AND_IL6_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6646
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 45 min of stimulation by IL6 [GeneID=3469] and LPS: wildtype versus IL6 [GeneID=3469] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL10_KO_LPS_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6647
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 45 min of stimulation by LPS: wildtype versus IL10 [GeneID=3486].
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL10_KO_LPS_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6648
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 45 min of stimulation by LPS: wildtype versus IL10 [GeneID=3486].
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL10_KO_LPS_AND_IL10_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6649
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 45 min of stimulation by IL10 [GeneID=3486] and LPS: wildtype versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL10_KO_LPS_AND_IL10_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6650
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 45 min of stimulation by IL10 [GeneID=3486] and LPS: wildtype versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL10_KO_LPS_AND_IL6_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6651
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 45 min of stimulation by IL6 [GeneID=3469] and LPS: wildtype versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL10_KO_LPS_AND_IL6_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6652
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 45 min of stimulation by IL6 [GeneID=3469] and LPS: wildtype versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_IL6_KO_VS_IL10_KO_LPS_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6653
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 45 min of stimulation by LPS: IL6 [GeneID=3469] knockout versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_IL6_KO_VS_IL10_KO_LPS_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6654
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 45 min of stimulation by LPS: IL6 [GeneID=3469] knockout versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_IL6_KO_VS_IL10_KO_LPS_AND_IL10_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6655
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 45 min of stimulation by IL10 [GeneID=3486] and LPS: IL6 [GeneID=3469] knockout versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_IL6_KO_VS_IL10_KO_LPS_AND_IL10_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6660
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 45 min of stimulation by IL10 [GeneID=3486] and LPS: IL6 [GeneID=3469] knockout versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_IL6_KO_VS_IL10_KO_LPS_AND_IL6_STIM_MACROPHAGE_45MIN_UP
Systematic name | M6661
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages (45 min): IL6 [GeneID=3469] knockout stimulated by IL6 [GeneID=3469] and LPS versus IL10 [GeneID=3486] knockout stimulated by and IL6 [GeneID=3469] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_IL6_KO_VS_IL10_KO_LPS_AND_IL6_STIM_MACROPHAGE_45MIN_DN
Systematic name | M6662
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages (45 min): IL6 [GeneID=3469] knockout stimulated by IL6 [GeneID=3469] and LPS versus IL10 [GeneID=3486] knockout stimulated by and IL6 [GeneID=3469] and LPS.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_IL6_KO_VS_IL10_KO_LPS_STIM_MACROPHAGE_180MIN_UP
Systematic name | M6664
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophagesat 180 min stimulation by LPS: IL6 [GeneID=3469] knockout versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_IL6_KO_VS_IL10_KO_LPS_STIM_MACROPHAGE_180MIN_DN
Systematic name | M6667
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophagesat 180 min stimulation by LPS: IL6 [GeneID=3469] knockout versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_IL6_KO_VS_IL10_KO_LPS_AND_IL10_STIM_MACROPHAGE_180MIN_UP
Systematic name | M6668
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophagesat 180 min of stimulation by IL10 [GeneID=3486] and LPS: IL6 [GeneID=3469] knockout versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_IL6_KO_VS_IL10_KO_LPS_AND_IL10_STIM_MACROPHAGE_180MIN_DN
Systematic name | M6671
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophagesat 180 min of stimulation by IL10 [GeneID=3486] and LPS: IL6 [GeneID=3469] knockout versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL10_KO_LPS_STIM_MACROPHAGE_180MIN_UP
Systematic name | M6673
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 180 min of stimulation by LPS: wildtype versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL10_KO_LPS_STIM_MACROPHAGE_180MIN_DN
Systematic name | M6675
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 180 min of stimulation by LPS: wildtype versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL10_KO_LPS_AND_IL10_STIM_MACROPHAGE_180MIN_UP
Systematic name | M6676
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 180 min of stimulation with IL10 [GeneID=3486] and LPS: wildtype versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL10_KO_LPS_AND_IL10_STIM_MACROPHAGE_180MIN_DN
Systematic name | M6677
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 180 min of stimulation with IL10 [GeneID=3486] and LPS: wildtype versus IL10 [GeneID=3486] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL6_KO_LPS_STIM_MACROPHAGE_180MIN_UP
Systematic name | M6678
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 180 min of stimulation byLPS: wildtype versus IL6 [GeneID=3469] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL6_KO_LPS_STIM_MACROPHAGE_180MIN_DN
Systematic name | M6680
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 180 min of stimulation byLPS: wildtype versus IL6 [GeneID=3469] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL6_KO_LPS_AND_IL10_STIM_MACROPHAGE_180MIN_UP
Systematic name | M6681
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages at 180 min of stimulation with IL10 [GeneID=3486] and LPS: wildtype versus IL6 [GeneID=3469] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE5589_WT_VS_IL6_KO_LPS_AND_IL10_STIM_MACROPHAGE_180MIN_DN
Systematic name | M6683
Organism | Mus musculus
PMID | 17114459
Authors | Kasmi El KC,Holst J,Coffre M,Mielke L,Pauw de A,Lhocine N,Smith AM,Rutschman R,Kaushal D,Shen Y,Suda T,Donnelly RP,Myers MG,Alexander W,Vignali DA,Watowich SS,Ernst M,Hilton DJ,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages at 180 min of stimulation with IL10 [GeneID=3486] and LPS: wildtype versus IL6 [GeneID=3469] knockout.
Full description | IL-10 or IL-6 stimulation of control 129xC57BL/6 murine bone marrow derived macrophages in the presence of LPS. We used microarrays to detail the global programme of gene expression changes in response to IL-6 or IL-10 stimulation in the presence of lipopolysaccharide. BMDMs were isolated from control, IL-6-/-, and IL-10-/- mice on a 129XBL/6 mixed background mice and differentiated in the presence of CSF-1 for 6-7 days. Cells were scraped and plated in 6 well plates at 2x10e6/well. Cells were washed with complete DMEM and rested for 1-2 hr before stimulation with combinations of IL-10 (10 ng/ml), IL-6 (2 ng/ml) or LPS (100 ng/ml) for 45 min or 180 mins. Complete biological replicates were performed.

Standard name | GSE3920_UNTREATED_VS_IFNA_TREATED_ENDOTHELIAL_CELL_UP
Systematic name | M6684
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes up-regulated in ndothelial cells: untreated versus interferon alpha.
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_UNTREATED_VS_IFNA_TREATED_ENDOTHELIAL_CELL_DN
Systematic name | M6685
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes down-regulated in ndothelial cells: untreated versus interferon alpha.
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_UNTREATED_VS_IFNB_TREATED_ENDOTHELIAL_CELL_UP
Systematic name | M6686
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes up-regulated in endothelial cells: untreated versus interferon beta.
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_UNTREATED_VS_IFNA_TREATED_FIBROBLAST_DN
Systematic name | M6687
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes down-regulated fibroblasts: untreated versus interferon alpha.
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_UNTREATED_VS_IFNG_TREATED_FIBROBLAST_UP
Systematic name | M6688
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes up-regulated in fibroblasts: untreated versus IFNG [GeneID=3458].
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_UNTREATED_VS_IFNG_TREATED_FIBROBLAST_DN
Systematic name | M6689
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes down-regulated in fibroblasts: untreated versus IFNG [GeneID=3458].
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_IFNA_VS_IFNG_TREATED_FIBROBLAST_UP
Systematic name | M6690
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes up-regulated in fibroblasts: interferon alpha versus IFNG [GeneID=3458].
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_IFNA_VS_IFNG_TREATED_FIBROBLAST_DN
Systematic name | M6691
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes down-regulated in fibroblasts: interferon alpha versus IFNG [GeneID=3458].
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_UNTREATED_VS_IFNB_TREATED_ENDOTHELIAL_CELL_DN
Systematic name | M6694
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes down-regulated in endothelial cells: untreated versus interferon beta.
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_UNTREATED_VS_IFNG_TREATED_ENDOTHELIAL_CELL_UP
Systematic name | M6695
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes up-regulated in endothelial cells: untreated versus IFNG [GeneID=3458].
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_UNTREATED_VS_IFNG_TREATED_ENDOTHELIAL_CELL_DN
Systematic name | M6696
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes down-regulated in endothelial cells: untreated versus IFNG [GeneID=3458].
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_IFNA_VS_IFNG_TREATED_ENDOTHELIAL_CELL_UP
Systematic name | M6697
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes up-regulated in endothelial cells: interferon alpha versus IFNG [GeneID=3458].
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_IFNA_VS_IFNG_TREATED_ENDOTHELIAL_CELL_DN
Systematic name | M6699
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes down-regulated in endothelial cells: interferon alpha versus IFNG [GeneID=3458].
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_IFNA_VS_IFNB_TREATED_ENDOTHELIAL_CELL_UP
Systematic name | M6700
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes up-regulated in endothelial cells: interferon alpha versus interferon beta.
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_IFNA_VS_IFNB_TREATED_ENDOTHELIAL_CELL_DN
Systematic name | M6701
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes down-regulated in endothelial cells: interferon alpha versus interferon beta.
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_IFNB_VS_IFNG_TREATED_ENDOTHELIAL_CELL_UP
Systematic name | M6702
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes up-regulated in endothelial cells: interferon beta versus IFNG [GeneID=3458].
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_IFNB_VS_IFNG_TREATED_ENDOTHELIAL_CELL_DN
Systematic name | M6703
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes down-regulated in endothelial cells: interferon beta versus IFNG [GeneID=3458].
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE3920_UNTREATED_VS_IFNA_TREATED_FIBROBLAST_UP
Systematic name | M6704
Organism | Homo sapiens
PMID | 17202376
Authors | Indraccolo S,Pfeffer U,Minuzzo S,Esposito G,Roni V,Mandruzzato S,Ferrari N,Anfosso L,Dell'Eva R,Noonan DM,Chieco-Bianchi L,Albini A,Amadori A
Category | C7
Sub-category |
Brief description | Genes up-regulated fibroblasts: untreated versus interferon alpha.
Full description | IFNs are highly pleiotropic cytokines also endowed with marked anti-angiogenic activity. In this study, the mRNA expression profiles of endothelial cells (EC) exposed in vitro to IFN-alpha, IFN-beta, or IFN-gamma were determined. We found that in HUVEC as well as in other EC types 175 genes were upregulated (>2-fold increase) by IFNs, including genes involved in the host response to RNA viruses, inflammation, and apoptosis. Interestingly, 41 genes showed a >5-fold higher induction by IFN-alpha in EC compared to human fibroblasts; among them, the gene encoding the angiostatic chemokine CXCL11 was selectively induced by IFN-alpha in EC along with other genes associated with angiogenesis regulation, including CXCL10, TRAIL, and guanylate binding protein 1 (GBP-1). These transcriptional changes were confirmed and extended by quantitative PCR analysis and ELISA; whereas IFN-alpha and IFN-beta exerted virtually identical effects on transcriptome modulation, a differential gene regulation by type I and type II IFN emerged, especially as far as quantitative aspects were concerned. In vivo, IFN-alpha-producing tumors over-expressed murine CXCL10-11, GBP-1 and TRAIL, with evidence of CXCL11 production by tumor-associated EC. Overall, these findings improve our understanding of the anti-angiogenic effects of IFNs by showing that these cytokines trigger an anti-angiogenic transcriptional program in EC. Moreover, we suggest that quantitative differences in the magnitude of the transcriptional activation of IFNresponsive genes could form the basis for cell-specific transcriptional signatures.

Standard name | GSE6092_CTRL_VS_BORRELIA_BIRGDOFERI_INF_ENDOTHELIAL_CELL_UP
Systematic name | M6707
Organism | Homo sapiens
PMID | 17202382
Authors | Dame TM,Orenzoff BL,Palmer LE,Furie MB
Category | C7
Sub-category |
Brief description | Genes up-regulated in endothelial cells: untreated versus exposed to E. burgdoferi.
Full description | Borrelia burgdorferi, the agent of Lyme disease, promotes pro-inflammatory changes in endothelium that lead to the recruitment of leukocytes. The host immune response to infection results in increased levels of IFN-gamma in the serum and lesions of Lyme disease patients that correlate with greater severity of disease. Therefore, the effect of IFN-gamma on the gene expression profile of primary human endothelial cells exposed to B. burgdorferi was determined. B. burgdorferi and IFN-gamma synergistically augmented the expression of 34 genes, seven of which encode chemokines. Six of these (CCL7, CCL8, CX3CL1, CXCL9, CXCL10, and CXCL11) attract T lymphocytes, and one (CXCL2) is specific for neutrophils. Synergistic production of the attractants for T cells was confirmed at the protein level. IL-1beta, TNF-alpha, and LPS also cooperated with IFN-gamma to induce synergistic production of CXCL10 by endothelium, indicating that IFN-gamma potentiates inflammation in concert with a variety of mediators. An in vitro model of the blood vessel wall revealed that an increased number of human T lymphocytes traversed endothelium exposed to B. burgdorferi and IFN-gamma, as compared to unstimulated endothelial monolayers. In contrast, addition of IFN-gamma diminished the migration of neutrophils across B. burgdorferi-activated endothelium. IFN-gamma thus alters gene expression by endothelium exposed to B. burgdorferi in a manner that promotes recruitment of T cells and suppresses that of neutrophils. This modulation may facilitate the development of chronic inflammatory lesions in Lyme disease.

Standard name | GSE6092_CTRL_VS_BORRELIA_BIRGDOFERI_INF_ENDOTHELIAL_CELL_DN
Systematic name | M6708
Organism | Homo sapiens
PMID | 17202382
Authors | Dame TM,Orenzoff BL,Palmer LE,Furie MB
Category | C7
Sub-category |
Brief description | Genes down-regulated in endothelial cells: untreated versus exposed to E. burgdoferi.
Full description | Borrelia burgdorferi, the agent of Lyme disease, promotes pro-inflammatory changes in endothelium that lead to the recruitment of leukocytes. The host immune response to infection results in increased levels of IFN-gamma in the serum and lesions of Lyme disease patients that correlate with greater severity of disease. Therefore, the effect of IFN-gamma on the gene expression profile of primary human endothelial cells exposed to B. burgdorferi was determined. B. burgdorferi and IFN-gamma synergistically augmented the expression of 34 genes, seven of which encode chemokines. Six of these (CCL7, CCL8, CX3CL1, CXCL9, CXCL10, and CXCL11) attract T lymphocytes, and one (CXCL2) is specific for neutrophils. Synergistic production of the attractants for T cells was confirmed at the protein level. IL-1beta, TNF-alpha, and LPS also cooperated with IFN-gamma to induce synergistic production of CXCL10 by endothelium, indicating that IFN-gamma potentiates inflammation in concert with a variety of mediators. An in vitro model of the blood vessel wall revealed that an increased number of human T lymphocytes traversed endothelium exposed to B. burgdorferi and IFN-gamma, as compared to unstimulated endothelial monolayers. In contrast, addition of IFN-gamma diminished the migration of neutrophils across B. burgdorferi-activated endothelium. IFN-gamma thus alters gene expression by endothelium exposed to B. burgdorferi in a manner that promotes recruitment of T cells and suppresses that of neutrophils. This modulation may facilitate the development of chronic inflammatory lesions in Lyme disease.

Standard name | GSE6092_UNSTIM_VS_IFNG_STIM_ENDOTHELIAL_CELL_UP
Systematic name | M6710
Organism | Homo sapiens
PMID | 17202382
Authors | Dame TM,Orenzoff BL,Palmer LE,Furie MB
Category | C7
Sub-category |
Brief description | Genes up-regulated in endothelial cells: untreated versus IFNG [GeneID=3458].
Full description | Borrelia burgdorferi, the agent of Lyme disease, promotes pro-inflammatory changes in endothelium that lead to the recruitment of leukocytes. The host immune response to infection results in increased levels of IFN-gamma in the serum and lesions of Lyme disease patients that correlate with greater severity of disease. Therefore, the effect of IFN-gamma on the gene expression profile of primary human endothelial cells exposed to B. burgdorferi was determined. B. burgdorferi and IFN-gamma synergistically augmented the expression of 34 genes, seven of which encode chemokines. Six of these (CCL7, CCL8, CX3CL1, CXCL9, CXCL10, and CXCL11) attract T lymphocytes, and one (CXCL2) is specific for neutrophils. Synergistic production of the attractants for T cells was confirmed at the protein level. IL-1beta, TNF-alpha, and LPS also cooperated with IFN-gamma to induce synergistic production of CXCL10 by endothelium, indicating that IFN-gamma potentiates inflammation in concert with a variety of mediators. An in vitro model of the blood vessel wall revealed that an increased number of human T lymphocytes traversed endothelium exposed to B. burgdorferi and IFN-gamma, as compared to unstimulated endothelial monolayers. In contrast, addition of IFN-gamma diminished the migration of neutrophils across B. burgdorferi-activated endothelium. IFN-gamma thus alters gene expression by endothelium exposed to B. burgdorferi in a manner that promotes recruitment of T cells and suppresses that of neutrophils. This modulation may facilitate the development of chronic inflammatory lesions in Lyme disease.

Standard name | GSE6092_UNSTIM_VS_IFNG_STIM_ENDOTHELIAL_CELL_DN
Systematic name | M6711
Organism | Homo sapiens
PMID | 17202382
Authors | Dame TM,Orenzoff BL,Palmer LE,Furie MB
Category | C7
Sub-category |
Brief description | Genes down-regulated in endothelial cells: untreated versus IFNG [GeneID=3458].
Full description | Borrelia burgdorferi, the agent of Lyme disease, promotes pro-inflammatory changes in endothelium that lead to the recruitment of leukocytes. The host immune response to infection results in increased levels of IFN-gamma in the serum and lesions of Lyme disease patients that correlate with greater severity of disease. Therefore, the effect of IFN-gamma on the gene expression profile of primary human endothelial cells exposed to B. burgdorferi was determined. B. burgdorferi and IFN-gamma synergistically augmented the expression of 34 genes, seven of which encode chemokines. Six of these (CCL7, CCL8, CX3CL1, CXCL9, CXCL10, and CXCL11) attract T lymphocytes, and one (CXCL2) is specific for neutrophils. Synergistic production of the attractants for T cells was confirmed at the protein level. IL-1beta, TNF-alpha, and LPS also cooperated with IFN-gamma to induce synergistic production of CXCL10 by endothelium, indicating that IFN-gamma potentiates inflammation in concert with a variety of mediators. An in vitro model of the blood vessel wall revealed that an increased number of human T lymphocytes traversed endothelium exposed to B. burgdorferi and IFN-gamma, as compared to unstimulated endothelial monolayers. In contrast, addition of IFN-gamma diminished the migration of neutrophils across B. burgdorferi-activated endothelium. IFN-gamma thus alters gene expression by endothelium exposed to B. burgdorferi in a manner that promotes recruitment of T cells and suppresses that of neutrophils. This modulation may facilitate the development of chronic inflammatory lesions in Lyme disease.

Standard name | GSE6092_UNSTIM_VS_IFNG_STIM_AND_B_BURGDORFERI_INF_ENDOTHELIAL_CELL_UP
Systematic name | M6713
Organism | Homo sapiens
PMID | 17202382
Authors | Dame TM,Orenzoff BL,Palmer LE,Furie MB
Category | C7
Sub-category |
Brief description | Genes up-regulated in endothelial cells: untreated versus IFNG [GeneID=3459] and B. burgdoferi.
Full description | Borrelia burgdorferi, the agent of Lyme disease, promotes pro-inflammatory changes in endothelium that lead to the recruitment of leukocytes. The host immune response to infection results in increased levels of IFN-gamma in the serum and lesions of Lyme disease patients that correlate with greater severity of disease. Therefore, the effect of IFN-gamma on the gene expression profile of primary human endothelial cells exposed to B. burgdorferi was determined. B. burgdorferi and IFN-gamma synergistically augmented the expression of 34 genes, seven of which encode chemokines. Six of these (CCL7, CCL8, CX3CL1, CXCL9, CXCL10, and CXCL11) attract T lymphocytes, and one (CXCL2) is specific for neutrophils. Synergistic production of the attractants for T cells was confirmed at the protein level. IL-1beta, TNF-alpha, and LPS also cooperated with IFN-gamma to induce synergistic production of CXCL10 by endothelium, indicating that IFN-gamma potentiates inflammation in concert with a variety of mediators. An in vitro model of the blood vessel wall revealed that an increased number of human T lymphocytes traversed endothelium exposed to B. burgdorferi and IFN-gamma, as compared to unstimulated endothelial monolayers. In contrast, addition of IFN-gamma diminished the migration of neutrophils across B. burgdorferi-activated endothelium. IFN-gamma thus alters gene expression by endothelium exposed to B. burgdorferi in a manner that promotes recruitment of T cells and suppresses that of neutrophils. This modulation may facilitate the development of chronic inflammatory lesions in Lyme disease.

Standard name | GSE6092_UNSTIM_VS_IFNG_STIM_AND_B_BURGDORFERI_INF_ENDOTHELIAL_CELL_DN
Systematic name | M6715
Organism | Homo sapiens
PMID | 17202382
Authors | Dame TM,Orenzoff BL,Palmer LE,Furie MB
Category | C7
Sub-category |
Brief description | Genes down-regulated in endothelial cells: untreated versus IFNG [GeneID=3459] and B. burgdoferi.
Full description | Borrelia burgdorferi, the agent of Lyme disease, promotes pro-inflammatory changes in endothelium that lead to the recruitment of leukocytes. The host immune response to infection results in increased levels of IFN-gamma in the serum and lesions of Lyme disease patients that correlate with greater severity of disease. Therefore, the effect of IFN-gamma on the gene expression profile of primary human endothelial cells exposed to B. burgdorferi was determined. B. burgdorferi and IFN-gamma synergistically augmented the expression of 34 genes, seven of which encode chemokines. Six of these (CCL7, CCL8, CX3CL1, CXCL9, CXCL10, and CXCL11) attract T lymphocytes, and one (CXCL2) is specific for neutrophils. Synergistic production of the attractants for T cells was confirmed at the protein level. IL-1beta, TNF-alpha, and LPS also cooperated with IFN-gamma to induce synergistic production of CXCL10 by endothelium, indicating that IFN-gamma potentiates inflammation in concert with a variety of mediators. An in vitro model of the blood vessel wall revealed that an increased number of human T lymphocytes traversed endothelium exposed to B. burgdorferi and IFN-gamma, as compared to unstimulated endothelial monolayers. In contrast, addition of IFN-gamma diminished the migration of neutrophils across B. burgdorferi-activated endothelium. IFN-gamma thus alters gene expression by endothelium exposed to B. burgdorferi in a manner that promotes recruitment of T cells and suppresses that of neutrophils. This modulation may facilitate the development of chronic inflammatory lesions in Lyme disease.

Standard name | GSE6092_B_BURGDOFERI_VS_B_BURGDORFERI_AND_IFNG_STIM_ENDOTHELIAL_CELL_UP
Systematic name | M6716
Organism | Homo sapiens
PMID | 17202382
Authors | Dame TM,Orenzoff BL,Palmer LE,Furie MB
Category | C7
Sub-category |
Brief description | Genes up-regulated in endothelial cells: B. burgdoferi versus IFNG [GeneID=3459] and B. burgdoferi .
Full description | Borrelia burgdorferi, the agent of Lyme disease, promotes pro-inflammatory changes in endothelium that lead to the recruitment of leukocytes. The host immune response to infection results in increased levels of IFN-gamma in the serum and lesions of Lyme disease patients that correlate with greater severity of disease. Therefore, the effect of IFN-gamma on the gene expression profile of primary human endothelial cells exposed to B. burgdorferi was determined. B. burgdorferi and IFN-gamma synergistically augmented the expression of 34 genes, seven of which encode chemokines. Six of these (CCL7, CCL8, CX3CL1, CXCL9, CXCL10, and CXCL11) attract T lymphocytes, and one (CXCL2) is specific for neutrophils. Synergistic production of the attractants for T cells was confirmed at the protein level. IL-1beta, TNF-alpha, and LPS also cooperated with IFN-gamma to induce synergistic production of CXCL10 by endothelium, indicating that IFN-gamma potentiates inflammation in concert with a variety of mediators. An in vitro model of the blood vessel wall revealed that an increased number of human T lymphocytes traversed endothelium exposed to B. burgdorferi and IFN-gamma, as compared to unstimulated endothelial monolayers. In contrast, addition of IFN-gamma diminished the migration of neutrophils across B. burgdorferi-activated endothelium. IFN-gamma thus alters gene expression by endothelium exposed to B. burgdorferi in a manner that promotes recruitment of T cells and suppresses that of neutrophils. This modulation may facilitate the development of chronic inflammatory lesions in Lyme disease.

Standard name | GSE6092_B_BURGDOFERI_VS_B_BURGDORFERI_AND_IFNG_STIM_ENDOTHELIAL_CELL_DN
Systematic name | M6717
Organism | Homo sapiens
PMID | 17202382
Authors | Dame TM,Orenzoff BL,Palmer LE,Furie MB
Category | C7
Sub-category |
Brief description | Genes down-regulated in endothelial cells: B. burgdoferi versus IFNG [GeneID=3459] and B. burgdoferi .
Full description | Borrelia burgdorferi, the agent of Lyme disease, promotes pro-inflammatory changes in endothelium that lead to the recruitment of leukocytes. The host immune response to infection results in increased levels of IFN-gamma in the serum and lesions of Lyme disease patients that correlate with greater severity of disease. Therefore, the effect of IFN-gamma on the gene expression profile of primary human endothelial cells exposed to B. burgdorferi was determined. B. burgdorferi and IFN-gamma synergistically augmented the expression of 34 genes, seven of which encode chemokines. Six of these (CCL7, CCL8, CX3CL1, CXCL9, CXCL10, and CXCL11) attract T lymphocytes, and one (CXCL2) is specific for neutrophils. Synergistic production of the attractants for T cells was confirmed at the protein level. IL-1beta, TNF-alpha, and LPS also cooperated with IFN-gamma to induce synergistic production of CXCL10 by endothelium, indicating that IFN-gamma potentiates inflammation in concert with a variety of mediators. An in vitro model of the blood vessel wall revealed that an increased number of human T lymphocytes traversed endothelium exposed to B. burgdorferi and IFN-gamma, as compared to unstimulated endothelial monolayers. In contrast, addition of IFN-gamma diminished the migration of neutrophils across B. burgdorferi-activated endothelium. IFN-gamma thus alters gene expression by endothelium exposed to B. burgdorferi in a manner that promotes recruitment of T cells and suppresses that of neutrophils. This modulation may facilitate the development of chronic inflammatory lesions in Lyme disease.

Standard name | GSE6092_IFNG_VS_IFNG_AND_B_BURGDORFERI_INF_ENDOTHELIAL_CELL_UP
Systematic name | M6718
Organism | Homo sapiens
PMID | 17202382
Authors | Dame TM,Orenzoff BL,Palmer LE,Furie MB
Category | C7
Sub-category |
Brief description | Genes up-regulated in endothelial cells: IFNG [GeneID=3459] versus IFNG [GeneID=3459] and B. burgdoferi.
Full description | Borrelia burgdorferi, the agent of Lyme disease, promotes pro-inflammatory changes in endothelium that lead to the recruitment of leukocytes. The host immune response to infection results in increased levels of IFN-gamma in the serum and lesions of Lyme disease patients that correlate with greater severity of disease. Therefore, the effect of IFN-gamma on the gene expression profile of primary human endothelial cells exposed to B. burgdorferi was determined. B. burgdorferi and IFN-gamma synergistically augmented the expression of 34 genes, seven of which encode chemokines. Six of these (CCL7, CCL8, CX3CL1, CXCL9, CXCL10, and CXCL11) attract T lymphocytes, and one (CXCL2) is specific for neutrophils. Synergistic production of the attractants for T cells was confirmed at the protein level. IL-1beta, TNF-alpha, and LPS also cooperated with IFN-gamma to induce synergistic production of CXCL10 by endothelium, indicating that IFN-gamma potentiates inflammation in concert with a variety of mediators. An in vitro model of the blood vessel wall revealed that an increased number of human T lymphocytes traversed endothelium exposed to B. burgdorferi and IFN-gamma, as compared to unstimulated endothelial monolayers. In contrast, addition of IFN-gamma diminished the migration of neutrophils across B. burgdorferi-activated endothelium. IFN-gamma thus alters gene expression by endothelium exposed to B. burgdorferi in a manner that promotes recruitment of T cells and suppresses that of neutrophils. This modulation may facilitate the development of chronic inflammatory lesions in Lyme disease.

Standard name | GSE6092_IFNG_VS_IFNG_AND_B_BURGDORFERI_INF_ENDOTHELIAL_CELL_DN
Systematic name | M6720
Organism | Homo sapiens
PMID | 17202382
Authors | Dame TM,Orenzoff BL,Palmer LE,Furie MB
Category | C7
Sub-category |
Brief description | Genes down-regulated in endothelial cells: IFNG [GeneID=3459] versus IFNG [GeneID=3459] and B. burgdoferi.
Full description | Borrelia burgdorferi, the agent of Lyme disease, promotes pro-inflammatory changes in endothelium that lead to the recruitment of leukocytes. The host immune response to infection results in increased levels of IFN-gamma in the serum and lesions of Lyme disease patients that correlate with greater severity of disease. Therefore, the effect of IFN-gamma on the gene expression profile of primary human endothelial cells exposed to B. burgdorferi was determined. B. burgdorferi and IFN-gamma synergistically augmented the expression of 34 genes, seven of which encode chemokines. Six of these (CCL7, CCL8, CX3CL1, CXCL9, CXCL10, and CXCL11) attract T lymphocytes, and one (CXCL2) is specific for neutrophils. Synergistic production of the attractants for T cells was confirmed at the protein level. IL-1beta, TNF-alpha, and LPS also cooperated with IFN-gamma to induce synergistic production of CXCL10 by endothelium, indicating that IFN-gamma potentiates inflammation in concert with a variety of mediators. An in vitro model of the blood vessel wall revealed that an increased number of human T lymphocytes traversed endothelium exposed to B. burgdorferi and IFN-gamma, as compared to unstimulated endothelial monolayers. In contrast, addition of IFN-gamma diminished the migration of neutrophils across B. burgdorferi-activated endothelium. IFN-gamma thus alters gene expression by endothelium exposed to B. burgdorferi in a manner that promotes recruitment of T cells and suppresses that of neutrophils. This modulation may facilitate the development of chronic inflammatory lesions in Lyme disease.

Standard name | GSE6259_FLT3L_INDUCED_VS_WT_SPLENIC_DC_33D1_POS_UP
Systematic name | M6721
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in 33D1+ spleen dendritic cells: Flt3L Melanom injected mice versus healthy controls.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_VS_WT_SPLENIC_DC_33D1_POS_DN
Systematic name | M6722
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in 33D1+ spleen dendritic cells: Flt3L Melanom injected mice versus healthy controls.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_33D1_POS_VS_DEC205_POS_FLT3L_INDUCED_SPLENIC_DC_UP
Systematic name | M6723
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen dendritic cells from Flt3L Melanom injected mice: 33D1+ versus DEC205+ subpopulations.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_33D1_POS_VS_DEC205_POS_FLT3L_INDUCED_SPLENIC_DC_DN
Systematic name | M6728
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen dendritic cells from Flt3L Melanom injected mice: 33D1+ versus DEC205+ subpopulations.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_33D1_POS_VS_DEC205_POS_SPLENIC_DC_UP
Systematic name | M6730
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen dendritic cells from healthy mice: 33D1+ versus DEC205+ subpopulations.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_33D1_POS_VS_DEC205_POS_SPLENIC_DC_DN
Systematic name | M6731
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen dendritic cells from healthy mice: 33D1+ versus DEC205+ subpopulations.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_BCELL_VS_CD4_TCELL_UP
Systematic name | M6732
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_BCELL_VS_CD4_TCELL_DN
Systematic name | M6733
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_BCELL_VS_CD8_TCELL_UP
Systematic name | M6735
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes versus CD8 T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_BCELL_VS_CD8_TCELL_DN
Systematic name | M6736
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes versus CD8 T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_CD4_TCELL_VS_CD8_TCELL_UP
Systematic name | M6738
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: CD4 [GeneID=920] versus CD8.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_CD4_TCELL_VS_CD8_TCELL_DN
Systematic name | M6739
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: CD4 [GeneID=920] versus CD8.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_33D1_POS_DC_VS_BCELL_UP
Systematic name | M6741
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in cells from Flt3L Melanom injected mice: 33D1+ versus B lymphocytes.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_33D1_POS_DC_VS_BCELL_DN
Systematic name | M6745
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in cells from Flt3L Melanom injected mice: 33D1+ versus B lymphocytes.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_33D1_POS_DC_VS_CD4_TCELL_UP
Systematic name | M6746
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in cells from Flt3L Melanom injected mice: 33D1+ versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_33D1_POS_DC_VS_CD4_TCELL_DN
Systematic name | M6747
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in cells from Flt3L Melanom injected mice: 33D1+ versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_33D1_POS_DC_VS_CD8_TCELL_UP
Systematic name | M6748
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in cells from Flt3L Melanom injected mice: 33D1+ versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_33D1_POS_DC_VS_CD8_TCELL_DN
Systematic name | M6749
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in cells from Flt3L Melanom injected mice: 33D1+ versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_33D1_POS_DC_VS_BCELL_UP
Systematic name | M6751
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenic dendritic cells versus 33D1+ B lymphocytes.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_33D1_POS_DC_VS_BCELL_DN
Systematic name | M6755
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenic dendritic cells versus 33D1+ B lymphocytes.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_33D1_POS_DC_VS_CD4_TCELL_UP
Systematic name | M6756
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenic CD 33D1+ dendritic cells versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_33D1_POS_DC_VS_CD4_TCELL_DN
Systematic name | M6757
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenic CD 33D1+ dendritic cells versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_33D1_POS_DC_VS_CD8_TCELL_UP
Systematic name | M6758
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenic 33D1+ dendritic cells versus CD8 T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_33D1_POS_DC_VS_CD8_TCELL_DN
Systematic name | M6759
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenic 33D1+ dendritic cells versus CD8 T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_DEC205_POS_DC_VS_BCELL_UP
Systematic name | M6760
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in cells from Flt3L Melanom injected mice: splenic DEC205+ dendritic cells versus B lymphocytes.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_DEC205_POS_DC_VS_BCELL_DN
Systematic name | M6762
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in cells from Flt3L Melanom injected mice: splenic DEC205+ dendritic cells versus B lymphocytes.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_DEC205_POS_DC_VS_CD4_TCELL_UP
Systematic name | M6763
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in cells from Flt3L Melanom injected mice: splenic DEC205+ dendritic cells versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_DEC205_POS_DC_VS_CD4_TCELL_DN
Systematic name | M6764
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in cells from Flt3L Melanom injected mice: splenic DEC205+ dendritic cells versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_DEC205_POS_DC_VS_CD8_TCELL_UP
Systematic name | M6765
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in cells from Flt3L Melanom injected mice: splenic DEC205+ dendritic cells versus CD8 T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_FLT3L_INDUCED_DEC205_POS_DC_VS_CD8_TCELL_DN
Systematic name | M6769
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in cells from Flt3L Melanom injected mice: splenic DEC205+ dendritic cells versus CD8 T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_DEC205_POS_DC_VS_BCELL_UP
Systematic name | M6770
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenic dendritic cells: DEC205+ versus B lymphocytes.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_DEC205_POS_DC_VS_BCELL_DN
Systematic name | M6772
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenic dendritic cells: DEC205+ versus B lymphocytes.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_DEC205_POS_DC_VS_CD4_TCELL_UP
Systematic name | M6773
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenic DEC205+ dendritic cells versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_DEC205_POS_DC_VS_CD4_TCELL_DN
Systematic name | M6774
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenic DEC205+ dendritic cells versus CD4 [GeneID=920] T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_DEC205_POS_DC_VS_CD8_TCELL_UP
Systematic name | M6775
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenic DEC205+ dendritic cells versus CD8 T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6259_DEC205_POS_DC_VS_CD8_TCELL_DN
Systematic name | M6776
Organism | Mus musculus
PMID | 17204652
Authors | Dudziak D,Kamphorst AO,Heidkamp GF,Buchholz VR,Trumpfheller C,Yamazaki S,Cheong C,Liu K,Lee HW,Park CG,Steinman RM,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenic DEC205+ dendritic cells versus CD8 T cells.
Full description | Dendritic cells (DCs) process and present self and foreign antigens to induce tolerance or immunity. In vitro models suggest that induction of immunity is controlled by regulating the presentation of antigen, but little is known about how DCs control antigen presentation in vivo. To examine antigen processing and presentation in vivo we specifically targeted antigens to the two major subsets of DCs using chimeric monoclonal antibodies. Unlike CD8+ DCs that express the cell surface protein CD205, CD8- DCs, which are positive for the 33D1 antigen, are specialized for presentation on MHC class II. This difference in antigen processing is intrinsic to the DC subsets and associated with increased expression of proteins associated with MHC processing.

Standard name | GSE6681_DELETED_FOXP3_VS_WT_TREG_UP
Systematic name | M6777
Organism | Mus musculus
PMID | 17220892
Authors | Williams LM,Rudensky AY
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: FOX3P [GeneID=50943] knockout versus wildtype.
Full description | Analysis of Foxp3 ablated peripheral regulatory T cells. Regulatory T cells require the expression of the transcription factor Foxp3 for thymic development. It is not known whether continuous expression of Foxp3 is required for the maintained function of mature regulatory T cells in the periphery. Results indicate changes to the regulatory T cell developmental program in the absence of Foxp3.

Standard name | GSE6681_DELETED_FOXP3_VS_WT_TREG_DN
Systematic name | M6779
Organism | Mus musculus
PMID | 17220892
Authors | Williams LM,Rudensky AY
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: FOX3P [GeneID=50943] knockout versus wildtype.
Full description | Analysis of Foxp3 ablated peripheral regulatory T cells. Regulatory T cells require the expression of the transcription factor Foxp3 for thymic development. It is not known whether continuous expression of Foxp3 is required for the maintained function of mature regulatory T cells in the periphery. Results indicate changes to the regulatory T cell developmental program in the absence of Foxp3.

Standard name | GSE3203_WT_VS_IFNAR1_KO_INFLUENZA_INFECTED_LN_BCELL_UP
Systematic name | M6780
Organism | Mus musculus
PMID | 17237394
Authors | Chang WL,Coro ES,Rau FC,Xiao Y,Erle DJ,Baumgarth N
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymph node B lymphocytes with influenza infection: wildtype versus IFNAR1 [GeneID=2454] knockout.
Full description | Influenza virus infection-induced gene expression changes of regional B cells are mediated at least in part through type I Interferon: Our objective is to determine whether the influenza virus-infection induced gene expression changes in regional lymph node B cells are facilitated at least in part through type I interferon. Our specific aim is to compare the gene expression profile of highly FACS-purified B cells in the regional lymph nodes of wildtype and IFNR-/- mice prior to and 48h following infection with influenza virus infection and to contrast this expression profile with that of FACS-purified wildtype B cells activated in vitro with IFN-beta +/- anti-CD86 for 12h.

Standard name | GSE3203_INFLUENZA_INF_VS_IFNB_TREATED_LN_BCELL_DN
Systematic name | M6781
Organism | Mus musculus
PMID | 17237394
Authors | Chang WL,Coro ES,Rau FC,Xiao Y,Erle DJ,Baumgarth N
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymph node B lymphocytes: influenza infected versus interferon beta stimulation.
Full description | Influenza virus infection-induced gene expression changes of regional B cells are mediated at least in part through type I Interferon: Our objective is to determine whether the influenza virus-infection induced gene expression changes in regional lymph node B cells are facilitated at least in part through type I interferon. Our specific aim is to compare the gene expression profile of highly FACS-purified B cells in the regional lymph nodes of wildtype and IFNR-/- mice prior to and 48h following infection with influenza virus infection and to contrast this expression profile with that of FACS-purified wildtype B cells activated in vitro with IFN-beta +/- anti-CD86 for 12h.

Standard name | GSE3203_HEALTHY_VS_INFLUENZA_INFECTED_LN_BCELL_UP
Systematic name | M6785
Organism | Mus musculus
PMID | 17237394
Authors | Chang WL,Coro ES,Rau FC,Xiao Y,Erle DJ,Baumgarth N
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymph node B lymphocytes: influenza infection versus un-infected.
Full description | Influenza virus infection-induced gene expression changes of regional B cells are mediated at least in part through type I Interferon: Our objective is to determine whether the influenza virus-infection induced gene expression changes in regional lymph node B cells are facilitated at least in part through type I interferon. Our specific aim is to compare the gene expression profile of highly FACS-purified B cells in the regional lymph nodes of wildtype and IFNR-/- mice prior to and 48h following infection with influenza virus infection and to contrast this expression profile with that of FACS-purified wildtype B cells activated in vitro with IFN-beta +/- anti-CD86 for 12h.

Standard name | GSE3203_UNTREATED_VS_IFNB_TREATED_LN_BCELL_DN
Systematic name | M6789
Organism | Mus musculus
PMID | 17237394
Authors | Chang WL,Coro ES,Rau FC,Xiao Y,Erle DJ,Baumgarth N
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymph node B lymphocytes: untreated versus interferon beta.
Full description | Influenza virus infection-induced gene expression changes of regional B cells are mediated at least in part through type I Interferon: Our objective is to determine whether the influenza virus-infection induced gene expression changes in regional lymph node B cells are facilitated at least in part through type I interferon. Our specific aim is to compare the gene expression profile of highly FACS-purified B cells in the regional lymph nodes of wildtype and IFNR-/- mice prior to and 48h following infection with influenza virus infection and to contrast this expression profile with that of FACS-purified wildtype B cells activated in vitro with IFN-beta +/- anti-CD86 for 12h.

Standard name | GSE3203_INFLUENZA_INF_VS_IFNB_TREATED_LN_BCELL_UP
Systematic name | M6790
Organism | Mus musculus
PMID | 17237394
Authors | Chang WL,Coro ES,Rau FC,Xiao Y,Erle DJ,Baumgarth N
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymph node B lymphocytes: influenza infected versus interferon beta stimulation.
Full description | Influenza virus infection-induced gene expression changes of regional B cells are mediated at least in part through type I Interferon: Our objective is to determine whether the influenza virus-infection induced gene expression changes in regional lymph node B cells are facilitated at least in part through type I interferon. Our specific aim is to compare the gene expression profile of highly FACS-purified B cells in the regional lymph nodes of wildtype and IFNR-/- mice prior to and 48h following infection with influenza virus infection and to contrast this expression profile with that of FACS-purified wildtype B cells activated in vitro with IFN-beta +/- anti-CD86 for 12h.

Standard name | GSE3203_HEALTHY_VS_INFLUENZA_INFECTED_LN_BCELL_DN
Systematic name | M6791
Organism | Mus musculus
PMID | 17237394
Authors | Chang WL,Coro ES,Rau FC,Xiao Y,Erle DJ,Baumgarth N
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymph node B lymphocytes: influenza infection versus un-infected.
Full description | Influenza virus infection-induced gene expression changes of regional B cells are mediated at least in part through type I Interferon: Our objective is to determine whether the influenza virus-infection induced gene expression changes in regional lymph node B cells are facilitated at least in part through type I interferon. Our specific aim is to compare the gene expression profile of highly FACS-purified B cells in the regional lymph nodes of wildtype and IFNR-/- mice prior to and 48h following infection with influenza virus infection and to contrast this expression profile with that of FACS-purified wildtype B cells activated in vitro with IFN-beta +/- anti-CD86 for 12h.

Standard name | GSE3203_UNTREATED_VS_IFNB_TREATED_LN_BCELL_UP
Systematic name | M6795
Organism | Mus musculus
PMID | 17237394
Authors | Chang WL,Coro ES,Rau FC,Xiao Y,Erle DJ,Baumgarth N
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymph node B lymphocytes: untreated versus interferon beta.
Full description | Influenza virus infection-induced gene expression changes of regional B cells are mediated at least in part through type I Interferon: Our objective is to determine whether the influenza virus-infection induced gene expression changes in regional lymph node B cells are facilitated at least in part through type I interferon. Our specific aim is to compare the gene expression profile of highly FACS-purified B cells in the regional lymph nodes of wildtype and IFNR-/- mice prior to and 48h following infection with influenza virus infection and to contrast this expression profile with that of FACS-purified wildtype B cells activated in vitro with IFN-beta +/- anti-CD86 for 12h.

Standard name | GSE3203_WT_VS_IFNAR1_KO_INFLUENZA_INFECTED_LN_BCELL_DN
Systematic name | M6798
Organism | Mus musculus
PMID | 17237394
Authors | Chang WL,Coro ES,Rau FC,Xiao Y,Erle DJ,Baumgarth N
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymph node B lymphocytes with influenza infection: wildtype versus IFNAR1 [GeneID=2454] knockout.
Full description | Influenza virus infection-induced gene expression changes of regional B cells are mediated at least in part through type I Interferon: Our objective is to determine whether the influenza virus-infection induced gene expression changes in regional lymph node B cells are facilitated at least in part through type I interferon. Our specific aim is to compare the gene expression profile of highly FACS-purified B cells in the regional lymph nodes of wildtype and IFNR-/- mice prior to and 48h following infection with influenza virus infection and to contrast this expression profile with that of FACS-purified wildtype B cells activated in vitro with IFN-beta +/- anti-CD86 for 12h.

Standard name | GSE6875_TCONV_VS_TREG_UP
Systematic name | M6799
Organism | Mus musculus
PMID | 17273171
Authors | Lin W,Haribhai D,Relland LM,Truong N,Carlson MR,Williams CB,Chatila TA
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv versus T reg.
Full description | To analyze gene expression in in regulatory T cell precursors that develop in the absence of a functional Foxp3 protein as compared to that of normal regulatory T cells

Standard name | GSE6875_TCONV_VS_TREG_DN
Systematic name | M6800
Organism | Mus musculus
PMID | 17273171
Authors | Lin W,Haribhai D,Relland LM,Truong N,Carlson MR,Williams CB,Chatila TA
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv versus T reg.
Full description | To analyze gene expression in in regulatory T cell precursors that develop in the absence of a functional Foxp3 protein as compared to that of normal regulatory T cells

Standard name | GSE6875_TCONV_VS_FOXP3_KO_TREG_UP
Systematic name | M6801
Organism | Mus musculus
PMID | 17273171
Authors | Lin W,Haribhai D,Relland LM,Truong N,Carlson MR,Williams CB,Chatila TA
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv versus T reg FOXP3 [GeneID=50943] knockout.
Full description | To analyze gene expression in in regulatory T cell precursors that develop in the absence of a functional Foxp3 protein as compared to that of normal regulatory T cells

Standard name | GSE6875_TCONV_VS_FOXP3_KO_TREG_DN
Systematic name | M6802
Organism | Mus musculus
PMID | 17273171
Authors | Lin W,Haribhai D,Relland LM,Truong N,Carlson MR,Williams CB,Chatila TA
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv versus T reg FOXP3 [GeneID=50943] knockout.
Full description | To analyze gene expression in in regulatory T cell precursors that develop in the absence of a functional Foxp3 protein as compared to that of normal regulatory T cells

Standard name | GSE6875_WT_VS_FOXP3_KO_TREG_UP
Systematic name | M6803
Organism | Mus musculus
PMID | 17273171
Authors | Lin W,Haribhai D,Relland LM,Truong N,Carlson MR,Williams CB,Chatila TA
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: wildtype versus FOXP3 [GeneID=50943] knockout.
Full description | To analyze gene expression in in regulatory T cell precursors that develop in the absence of a functional Foxp3 protein as compared to that of normal regulatory T cells

Standard name | GSE6875_WT_VS_FOXP3_KO_TREG_DN
Systematic name | M6804
Organism | Mus musculus
PMID | 17273171
Authors | Lin W,Haribhai D,Relland LM,Truong N,Carlson MR,Williams CB,Chatila TA
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: wildtype versus FOXP3 [GeneID=50943] knockout.
Full description | To analyze gene expression in in regulatory T cell precursors that develop in the absence of a functional Foxp3 protein as compared to that of normal regulatory T cells

Standard name | GSE7218_UNSTIM_VS_ANTIGEN_STIM_THROUGH_IGM_BCELL_UP
Systematic name | M6805
Organism | Mus musculus
PMID | 17420266
Authors | Horikawa K,Martin SW,Pogue SL,Silver K,Peng K,Takatsu K,Goodnow CC
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes expressing IgM - BCR [GeneID=613]: untreated versus anti-HEL.
Full description | IgG cytoplasmic tail interferes with the induction of antigen-response genes

Standard name | GSE7218_UNSTIM_VS_ANTIGEN_STIM_THROUGH_IGM_BCELL_DN
Systematic name | M6806
Organism | Mus musculus
PMID | 17420266
Authors | Horikawa K,Martin SW,Pogue SL,Silver K,Peng K,Takatsu K,Goodnow CC
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes expressing IgM - BCR [GeneID=613]: untreated versus anti-HEL.
Full description | IgG cytoplasmic tail interferes with the induction of antigen-response genes

Standard name | GSE7218_IGM_VS_IGG_SIGNAL_THGOUGH_ANTIGEN_BCELL_UP
Systematic name | M6807
Organism | Mus musculus
PMID | 17420266
Authors | Horikawa K,Martin SW,Pogue SL,Silver K,Peng K,Takatsu K,Goodnow CC
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes treated by anti-HEL and expressing BCR [GeneID=613] fusions with: IgM versus IgMG.
Full description | IgG cytoplasmic tail interferes with the induction of antigen-response genes

Standard name | GSE7218_IGM_VS_IGG_SIGNAL_THGOUGH_ANTIGEN_BCELL_DN
Systematic name | M6808
Organism | Mus musculus
PMID | 17420266
Authors | Horikawa K,Martin SW,Pogue SL,Silver K,Peng K,Takatsu K,Goodnow CC
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes treated by anti-HEL and expressing BCR [GeneID=613] fusions with: IgM versus IgMG.
Full description | IgG cytoplasmic tail interferes with the induction of antigen-response genes

Standard name | GSE7218_UNSTIM_VS_ANTIGEN_STIM_THROUGH_IGG_BCELL_UP
Systematic name | M6809
Organism | Mus musculus
PMID | 17420266
Authors | Horikawa K,Martin SW,Pogue SL,Silver K,Peng K,Takatsu K,Goodnow CC
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: expressing IgM BCR [GeneID=613] fusion and untreated versus expressing IgMG BCR [GeneID=613] fusion and treated by anti-HEL.
Full description | IgG cytoplasmic tail interferes with the induction of antigen-response genes

Standard name | GSE7218_UNSTIM_VS_ANTIGEN_STIM_THROUGH_IGG_BCELL_DN
Systematic name | M6810
Organism | Mus musculus
PMID | 17420266
Authors | Horikawa K,Martin SW,Pogue SL,Silver K,Peng K,Takatsu K,Goodnow CC
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: expressing IgM BCR [GeneID=613] fusion and untreated versus expressing IgMG BCR [GeneID=613] fusion and treated by anti-HEL.
Full description | IgG cytoplasmic tail interferes with the induction of antigen-response genes

Standard name | GSE6090_UNSTIM_VS_DC_SIGN_STIM_DC_UP
Systematic name | M6811
Organism | Homo sapiens
PMID | 17496896
Authors | Hodges A,Sharrocks K,Edelmann M,Baban D,Moris A,Schwartz O,Drakesmith H,Davies K,Kessler B,McMichael A,Simmons A
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: control versus stimulated with anti-CD209 [GeneID=30835] antibody.
Full description | DC-SIGN is a C-type lectin expressed by dendritic cells (DCs) that binds HIV-1, sequestering it within multivesicular bodies to facilitate transmission to CD4+ T cells. Here we characterize the molecular basis of signalling through DC-SIGN by large-scale gene expression profiling and phosphoproteome analysis. Solitary DC-SIGN activation leads to a phenotypically disparate transcriptional program from Toll-like receptor (TLR) triggering with downregulation of MHC II, CD86, and interferon response genes and with induction of the TLR negative regulator ATF3. Phosphoproteome analysis reveals DC-SIGN signals through the leukemia-associated Rho guanine nucleotide exchange factor (LARG) to induce Rho activity. This LARG activation also occurs on DC HIV exposure and is required for effective HIV viral synapse formation. Taken together HIV mediated DC-SIGN signalling provides a mechanism by which HIV evades the immune response yet induces viral spread.

Standard name | GSE6090_UNSTIM_VS_DC_SIGN_STIM_DC_DN
Systematic name | M6812
Organism | Homo sapiens
PMID | 17496896
Authors | Hodges A,Sharrocks K,Edelmann M,Baban D,Moris A,Schwartz O,Drakesmith H,Davies K,Kessler B,McMichael A,Simmons A
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: control versus stimulated with anti-CD209 [GeneID=30835] antibody.
Full description | DC-SIGN is a C-type lectin expressed by dendritic cells (DCs) that binds HIV-1, sequestering it within multivesicular bodies to facilitate transmission to CD4+ T cells. Here we characterize the molecular basis of signalling through DC-SIGN by large-scale gene expression profiling and phosphoproteome analysis. Solitary DC-SIGN activation leads to a phenotypically disparate transcriptional program from Toll-like receptor (TLR) triggering with downregulation of MHC II, CD86, and interferon response genes and with induction of the TLR negative regulator ATF3. Phosphoproteome analysis reveals DC-SIGN signals through the leukemia-associated Rho guanine nucleotide exchange factor (LARG) to induce Rho activity. This LARG activation also occurs on DC HIV exposure and is required for effective HIV viral synapse formation. Taken together HIV mediated DC-SIGN signalling provides a mechanism by which HIV evades the immune response yet induces viral spread.

Standard name | GSE7509_UNSTIM_VS_IFNA_STIM_IMMATURE_DC_UP
Systematic name | M6814
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes up-regulated in immature dendritic cells: untreated versus interferon alpha.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_UNSTIM_VS_IFNA_STIM_IMMATURE_DC_DN
Systematic name | M6816
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes down-regulated in immature dendritic cells: untreated versus interferon alpha.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_UNSTIM_VS_FCGRIIB_STIM_DC_UP
Systematic name | M6817
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: untreated versus anti-FcgRIIB.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_UNSTIM_VS_FCGRIIB_STIM_DC_DN
Systematic name | M6818
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: untreated versus anti-FcgRIIB.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_UNSTIM_VS_TNFA_IL1B_IL6_PGE_STIM_DC_UP
Systematic name | M6819
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: untreated versus inflammatory cytokine cocktail.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_UNSTIM_VS_TNFA_IL1B_IL6_PGE_STIM_DC_DN
Systematic name | M6820
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: untreated versus inflammatory cytokine cocktail.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_FCGRIIB_VS_TNFA_IL1B_IL6_PGE_STIM_DC_UP
Systematic name | M6823
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: anti-FcgRIIB versus inflammatory cytokine cocktail.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_FCGRIIB_VS_TNFA_IL1B_IL6_PGE_STIM_DC_DN
Systematic name | M6824
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: anti-FcgRIIB versus inflammatory cytokine cocktail.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_UNSTIM_VS_FCGRIIB_STIM_MONOCYTE_UP
Systematic name | M6825
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes: untreated versus anti- FcgRIIB.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_UNSTIM_VS_FCGRIIB_STIM_MONOCYTE_DN
Systematic name | M6826
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes: untreated versus anti- FcgRIIB.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_DC_VS_MONOCYTE_UP
Systematic name | M6827
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells versus monocytes.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_DC_VS_MONOCYTE_DN
Systematic name | M6829
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells versus monocytes.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_DC_VS_MONOCYTE_WITH_FCGRIIB_STIM_UP
Systematic name | M6832
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes up-regulated in response to anti-FcgRIIB: dendritic cells versus monocytes.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7509_DC_VS_MONOCYTE_WITH_FCGRIIB_STIM_DN
Systematic name | M6835
Organism | Homo sapiens
PMID | 17502666
Authors | Dhodapkar KM,Banerjee D,Connolly J,Kukreja A,Matayeva E,Veri MC,Ravetch JV,Steinman RM,Dhodapkar MV
Category | C7
Sub-category |
Brief description | Genes down-regulated in response to anti-FcgRIIB: dendritic cells versus monocytes.
Full description | The ability of dendritic cells (DCs) to activate immunity is linked to their maturation status. In prior studies we have shown that selective antibody-mediated blockade of inhibitory FcgRIIB receptor on human DCs in the presence of activating immunoglobulin (Ig) ligands leads to DC maturation and enhanced immunity to antibody-coated tumor cells. Here we show that Fcg receptor (FcgR) mediated activation of human monocytes and monocyte-derived DCs is associated with a distinct gene expression pattern, including several inflammation associated chemokines as well as type 1 interferon (IFN) response genes including the activation of signal transducer and activator of transcription 1 (STAT1).

Standard name | GSE7548_NAIVE_VS_DAY7_PCC_IMMUNIZATION_CD4_TCELL_UP
Systematic name | M6836
Organism | Mus musculus
PMID | 17529982
Authors | Fazilleau N,Eisenbraun MD,Malherbe L,Ebright JN,Pogue-Caley RR,McHeyzer-Williams LJ,McHeyzer-Williams MG
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells from lymph nodes: naïve versus day 7 after immunization.
Full description | Mice were immunized with PCC (pigeon cytochrome c).

Standard name | GSE7548_NAIVE_VS_DAY7_PCC_IMMUNIZATION_CD4_TCELL_DN
Systematic name | M6837
Organism | Mus musculus
PMID | 17529982
Authors | Fazilleau N,Eisenbraun MD,Malherbe L,Ebright JN,Pogue-Caley RR,McHeyzer-Williams LJ,McHeyzer-Williams MG
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells from lymph nodes: naïve versus day 7 after immunization.
Full description | Mice were immunized with PCC (pigeon cytochrome c).

Standard name | GSE7548_NAIVE_VS_DAY28_PCC_IMMUNIZATION_CD4_TCELL_UP
Systematic name | M6839
Organism | Mus musculus
PMID | 17529982
Authors | Fazilleau N,Eisenbraun MD,Malherbe L,Ebright JN,Pogue-Caley RR,McHeyzer-Williams LJ,McHeyzer-Williams MG
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells from lymph nodes: naïve versus day 28 after immunization.
Full description | Mice were immunized with PCC (pigeon cytochrome c).

Standard name | GSE7548_NAIVE_VS_DAY28_PCC_IMMUNIZATION_CD4_TCELL_DN
Systematic name | M6841
Organism | Mus musculus
PMID | 17529982
Authors | Fazilleau N,Eisenbraun MD,Malherbe L,Ebright JN,Pogue-Caley RR,McHeyzer-Williams LJ,McHeyzer-Williams MG
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells from lymph nodes: naïve versus day 28 after immunization.
Full description | Mice were immunized with PCC (pigeon cytochrome c).

Standard name | GSE7548_DAY7_VS_DAY28_PCC_IMMUNIZATION_CD4_TCELL_UP
Systematic name | M6842
Organism | Mus musculus
PMID | 17529982
Authors | Fazilleau N,Eisenbraun MD,Malherbe L,Ebright JN,Pogue-Caley RR,McHeyzer-Williams LJ,McHeyzer-Williams MG
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells from lymph nodes: naïve versus day 28 after immunization.
Full description | Mice were immunized with PCC (pigeon cytochrome c).

Standard name | GSE7548_DAY7_VS_DAY28_PCC_IMMUNIZATION_CD4_TCELL_DN
Systematic name | M6843
Organism | Mus musculus
PMID | 17529982
Authors | Fazilleau N,Eisenbraun MD,Malherbe L,Ebright JN,Pogue-Caley RR,McHeyzer-Williams LJ,McHeyzer-Williams MG
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells from lymph nodes: naïve versus day 28 after immunization.
Full description | Mice were immunized with PCC (pigeon cytochrome c).

Standard name | GSE7348_UNSTIM_VS_LPS_STIM_MACROPHAGE_UP
Systematic name | M6844
Organism | Mus musculus
PMID | 17538624
Authors | Foster SL,Hargreaves DC,Medzhitov R
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: untreated versus LPS.
Full description | The inflammatory response initiated by microbial products signaling through Toll-like receptors (TLRs) of the innate immune system is essential for host defense against infection. Because inflammation can be harmful to host tissues, the innate response is highly regulated. Negative regulation of TLR4, the receptor for bacterial lipopolysaccharide (LPS), results in LPS tolerance, defined as hyporesponsiveness to repeated stimulation with LPS. LPS tolerance is thought to protect the host from excessive inflammation by turning off TLR4 signal, which then shuts down TLR-induced genes. However, TLR signaling induces hundreds of genes with very different functions. We reasoned that genes with different functions should have different requirements for regulation. Specifically, genes encoding proinflammatory mediators should be transiently inactivated to limit tissue damage, while genes encoding antimicrobial effectors, which directly target pathogens, should remain inducible in tolerant cells to protect the host from infection. Using an in vitro system of LPS tolerance in macrophages, here we show that TLR-induced genes may indeed be divided into two distinct categories based on their functions and regulatory requirements. Further, we show these distinct groups are regulated by gene-specific, and not signal-specific mechanisms.

Standard name | GSE7348_UNSTIM_VS_LPS_STIM_MACROPHAGE_DN
Systematic name | M6846
Organism | Mus musculus
PMID | 17538624
Authors | Foster SL,Hargreaves DC,Medzhitov R
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: untreated versus LPS.
Full description | The inflammatory response initiated by microbial products signaling through Toll-like receptors (TLRs) of the innate immune system is essential for host defense against infection. Because inflammation can be harmful to host tissues, the innate response is highly regulated. Negative regulation of TLR4, the receptor for bacterial lipopolysaccharide (LPS), results in LPS tolerance, defined as hyporesponsiveness to repeated stimulation with LPS. LPS tolerance is thought to protect the host from excessive inflammation by turning off TLR4 signal, which then shuts down TLR-induced genes. However, TLR signaling induces hundreds of genes with very different functions. We reasoned that genes with different functions should have different requirements for regulation. Specifically, genes encoding proinflammatory mediators should be transiently inactivated to limit tissue damage, while genes encoding antimicrobial effectors, which directly target pathogens, should remain inducible in tolerant cells to protect the host from infection. Using an in vitro system of LPS tolerance in macrophages, here we show that TLR-induced genes may indeed be divided into two distinct categories based on their functions and regulatory requirements. Further, we show these distinct groups are regulated by gene-specific, and not signal-specific mechanisms.

Standard name | GSE7348_UNSTIM_VS_TOLERIZED_AND_LPS_STIM_MACROPHAGE_UP
Systematic name | M6847
Organism | Mus musculus
PMID | 17538624
Authors | Foster SL,Hargreaves DC,Medzhitov R
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: naïve untreated versus tolerant stimulated by LPS.
Full description | The inflammatory response initiated by microbial products signaling through Toll-like receptors (TLRs) of the innate immune system is essential for host defense against infection. Because inflammation can be harmful to host tissues, the innate response is highly regulated. Negative regulation of TLR4, the receptor for bacterial lipopolysaccharide (LPS), results in LPS tolerance, defined as hyporesponsiveness to repeated stimulation with LPS. LPS tolerance is thought to protect the host from excessive inflammation by turning off TLR4 signal, which then shuts down TLR-induced genes. However, TLR signaling induces hundreds of genes with very different functions. We reasoned that genes with different functions should have different requirements for regulation. Specifically, genes encoding proinflammatory mediators should be transiently inactivated to limit tissue damage, while genes encoding antimicrobial effectors, which directly target pathogens, should remain inducible in tolerant cells to protect the host from infection. Using an in vitro system of LPS tolerance in macrophages, here we show that TLR-induced genes may indeed be divided into two distinct categories based on their functions and regulatory requirements. Further, we show these distinct groups are regulated by gene-specific, and not signal-specific mechanisms.

Standard name | GSE7348_UNSTIM_VS_TOLERIZED_AND_LPS_STIM_MACROPHAGE_DN
Systematic name | M6848
Organism | Mus musculus
PMID | 17538624
Authors | Foster SL,Hargreaves DC,Medzhitov R
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: naïve untreated versus tolerant stimulated by LPS.
Full description | The inflammatory response initiated by microbial products signaling through Toll-like receptors (TLRs) of the innate immune system is essential for host defense against infection. Because inflammation can be harmful to host tissues, the innate response is highly regulated. Negative regulation of TLR4, the receptor for bacterial lipopolysaccharide (LPS), results in LPS tolerance, defined as hyporesponsiveness to repeated stimulation with LPS. LPS tolerance is thought to protect the host from excessive inflammation by turning off TLR4 signal, which then shuts down TLR-induced genes. However, TLR signaling induces hundreds of genes with very different functions. We reasoned that genes with different functions should have different requirements for regulation. Specifically, genes encoding proinflammatory mediators should be transiently inactivated to limit tissue damage, while genes encoding antimicrobial effectors, which directly target pathogens, should remain inducible in tolerant cells to protect the host from infection. Using an in vitro system of LPS tolerance in macrophages, here we show that TLR-induced genes may indeed be divided into two distinct categories based on their functions and regulatory requirements. Further, we show these distinct groups are regulated by gene-specific, and not signal-specific mechanisms.

Standard name | GSE7348_LPS_VS_TOLERIZED_AND_LPS_STIM_MACROPHAGE_UP
Systematic name | M6849
Organism | Mus musculus
PMID | 17538624
Authors | Foster SL,Hargreaves DC,Medzhitov R
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages in response to LPS: naïve versus tolerant.
Full description | The inflammatory response initiated by microbial products signaling through Toll-like receptors (TLRs) of the innate immune system is essential for host defense against infection. Because inflammation can be harmful to host tissues, the innate response is highly regulated. Negative regulation of TLR4, the receptor for bacterial lipopolysaccharide (LPS), results in LPS tolerance, defined as hyporesponsiveness to repeated stimulation with LPS. LPS tolerance is thought to protect the host from excessive inflammation by turning off TLR4 signal, which then shuts down TLR-induced genes. However, TLR signaling induces hundreds of genes with very different functions. We reasoned that genes with different functions should have different requirements for regulation. Specifically, genes encoding proinflammatory mediators should be transiently inactivated to limit tissue damage, while genes encoding antimicrobial effectors, which directly target pathogens, should remain inducible in tolerant cells to protect the host from infection. Using an in vitro system of LPS tolerance in macrophages, here we show that TLR-induced genes may indeed be divided into two distinct categories based on their functions and regulatory requirements. Further, we show these distinct groups are regulated by gene-specific, and not signal-specific mechanisms.

Standard name | GSE7348_LPS_VS_TOLERIZED_AND_LPS_STIM_MACROPHAGE_DN
Systematic name | M6850
Organism | Mus musculus
PMID | 17538624
Authors | Foster SL,Hargreaves DC,Medzhitov R
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages in response to LPS: naïve versus tolerant.
Full description | The inflammatory response initiated by microbial products signaling through Toll-like receptors (TLRs) of the innate immune system is essential for host defense against infection. Because inflammation can be harmful to host tissues, the innate response is highly regulated. Negative regulation of TLR4, the receptor for bacterial lipopolysaccharide (LPS), results in LPS tolerance, defined as hyporesponsiveness to repeated stimulation with LPS. LPS tolerance is thought to protect the host from excessive inflammation by turning off TLR4 signal, which then shuts down TLR-induced genes. However, TLR signaling induces hundreds of genes with very different functions. We reasoned that genes with different functions should have different requirements for regulation. Specifically, genes encoding proinflammatory mediators should be transiently inactivated to limit tissue damage, while genes encoding antimicrobial effectors, which directly target pathogens, should remain inducible in tolerant cells to protect the host from infection. Using an in vitro system of LPS tolerance in macrophages, here we show that TLR-induced genes may indeed be divided into two distinct categories based on their functions and regulatory requirements. Further, we show these distinct groups are regulated by gene-specific, and not signal-specific mechanisms.

Standard name | GSE7768_OVA_ALONE_VS_OVA_WITH_LPS_IMMUNIZED_MOUSE_WHOLE_SPLEEN_6H_UP
Systematic name | M6851
Organism | Mus musculus
PMID | 17569868
Authors | Mata-Haro V,Cekic C,Martin M,Chilton PM,Casella CR,Mitchell TC
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleens from mice immunized with ova peptides alone versus those immunized with LPS as adjuvant.
Full description | An unresolved issue in immunology is the extent to which inflammatory effects are needed for robust T cell responses. In this study, mice were immunized by iv injection using either high toxicity lipopolysaccharide (LPS) or low toxicity monophosphoryl lipid A (MPL) as adjuvant. Six hours after iv immunization, whole spleens were harvested and gene expression was measured in unfractionated splenic populations of cells. The analysis indicated that the low toxicity adjuvanticity of MPL was associated with TLR4-mediated signaling that was biased to the TRIF branch of TLR4, while LPS generated balanced MyD88 and TRIF-associated outcomes.

Standard name | GSE7768_OVA_ALONE_VS_OVA_WITH_LPS_IMMUNIZED_MOUSE_WHOLE_SPLEEN_6H_DN
Systematic name | M6852
Organism | Mus musculus
PMID | 17569868
Authors | Mata-Haro V,Cekic C,Martin M,Chilton PM,Casella CR,Mitchell TC
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleens from mice immunized with ova peptides alone versus those immunized with LPS as adjuvant.
Full description | An unresolved issue in immunology is the extent to which inflammatory effects are needed for robust T cell responses. In this study, mice were immunized by iv injection using either high toxicity lipopolysaccharide (LPS) or low toxicity monophosphoryl lipid A (MPL) as adjuvant. Six hours after iv immunization, whole spleens were harvested and gene expression was measured in unfractionated splenic populations of cells. The analysis indicated that the low toxicity adjuvanticity of MPL was associated with TLR4-mediated signaling that was biased to the TRIF branch of TLR4, while LPS generated balanced MyD88 and TRIF-associated outcomes.

Standard name | GSE7768_OVA_WITH_LPS_VS_OVA_WITH_MPL_IMMUNIZED_MOUSE_WHOLE_SPLEEN_6H_UP
Systematic name | M6853
Organism | Mus musculus
PMID | 17569868
Authors | Mata-Haro V,Cekic C,Martin M,Chilton PM,Casella CR,Mitchell TC
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleens: LPS versus monophosphoryl lipid A.
Full description | An unresolved issue in immunology is the extent to which inflammatory effects are needed for robust T cell responses. In this study, mice were immunized by iv injection using either high toxicity lipopolysaccharide (LPS) or low toxicity monophosphoryl lipid A (MPL) as adjuvant. Six hours after iv immunization, whole spleens were harvested and gene expression was measured in unfractionated splenic populations of cells. The analysis indicated that the low toxicity adjuvanticity of MPL was associated with TLR4-mediated signaling that was biased to the TRIF branch of TLR4, while LPS generated balanced MyD88 and TRIF-associated outcomes.

Standard name | GSE7768_OVA_WITH_LPS_VS_OVA_WITH_MPL_IMMUNIZED_MOUSE_WHOLE_SPLEEN_6H_DN
Systematic name | M6855
Organism | Mus musculus
PMID | 17569868
Authors | Mata-Haro V,Cekic C,Martin M,Chilton PM,Casella CR,Mitchell TC
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleens: LPS versus monophosphoryl lipid A.
Full description | An unresolved issue in immunology is the extent to which inflammatory effects are needed for robust T cell responses. In this study, mice were immunized by iv injection using either high toxicity lipopolysaccharide (LPS) or low toxicity monophosphoryl lipid A (MPL) as adjuvant. Six hours after iv immunization, whole spleens were harvested and gene expression was measured in unfractionated splenic populations of cells. The analysis indicated that the low toxicity adjuvanticity of MPL was associated with TLR4-mediated signaling that was biased to the TRIF branch of TLR4, while LPS generated balanced MyD88 and TRIF-associated outcomes.

Standard name | GSE7768_OVA_ALONE_VS_OVA_WITH_MPL_IMMUNIZED_MOUSE_WHOLE_SPLEEN_6H_UP
Systematic name | M6857
Organism | Mus musculus
PMID | 17569868
Authors | Mata-Haro V,Cekic C,Martin M,Chilton PM,Casella CR,Mitchell TC
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleens from mice immunized with ova peptides alone versus those immunized with monophosphoryl lipid A as adjuvant.
Full description | An unresolved issue in immunology is the extent to which inflammatory effects are needed for robust T cell responses. In this study, mice were immunized by iv injection using either high toxicity lipopolysaccharide (LPS) or low toxicity monophosphoryl lipid A (MPL) as adjuvant. Six hours after iv immunization, whole spleens were harvested and gene expression was measured in unfractionated splenic populations of cells. The analysis indicated that the low toxicity adjuvanticity of MPL was associated with TLR4-mediated signaling that was biased to the TRIF branch of TLR4, while LPS generated balanced MyD88 and TRIF-associated outcomes.

Standard name | GSE7768_OVA_ALONE_VS_OVA_WITH_MPL_IMMUNIZED_MOUSE_WHOLE_SPLEEN_6H_DN
Systematic name | M6859
Organism | Mus musculus
PMID | 17569868
Authors | Mata-Haro V,Cekic C,Martin M,Chilton PM,Casella CR,Mitchell TC
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleens from mice immunized with ova peptides alone versus those immunized with monophosphoryl lipid A as adjuvant.
Full description | An unresolved issue in immunology is the extent to which inflammatory effects are needed for robust T cell responses. In this study, mice were immunized by iv injection using either high toxicity lipopolysaccharide (LPS) or low toxicity monophosphoryl lipid A (MPL) as adjuvant. Six hours after iv immunization, whole spleens were harvested and gene expression was measured in unfractionated splenic populations of cells. The analysis indicated that the low toxicity adjuvanticity of MPL was associated with TLR4-mediated signaling that was biased to the TRIF branch of TLR4, while LPS generated balanced MyD88 and TRIF-associated outcomes.

Standard name | GSE4590_PRE_BCELL_VS_SMALL_PRE_BCELL_UP
Systematic name | M6860
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes up-regulated during B lymphocyte differentiation: pre-B I versus small pre-B II.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_PRE_BCELL_VS_SMALL_PRE_BCELL_DN
Systematic name | M6861
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes down-regulated during B lymphocyte differentiation: pre-B I versus small pre-B II.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_PRE_BCELL_VS_LARGE_PRE_BCELL_UP
Systematic name | M6863
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes up-regulated during B lymphocyte differentiation: pre-B I versus large pre-B II.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_PRE_BCELL_VS_LARGE_PRE_BCELL_DN
Systematic name | M6865
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes down-regulated during B lymphocyte differentiation: pre-B I versus large pre-B II.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_PRE_BCELL_VS_VPREB_POS_LARGE_PRE_BCELL_UP
Systematic name | M6867
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes up-regulated during B lymphocyte differentiation: pre-B I versus VPREB1+ [GeneID=7441] large pre-B II.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_PRE_BCELL_VS_VPREB_POS_LARGE_PRE_BCELL_DN
Systematic name | M6871
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes down-regulated during B lymphocyte differentiation: pre-B I versus VPREB1+ [GeneID=7441] large pre-B II.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_SMALL_VS_LARGE_PRE_BCELL_UP
Systematic name | M6872
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes up-regulated during B lymphocyte differentiation: small pre-B II versus large pre-B II.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_SMALL_VS_LARGE_PRE_BCELL_DN
Systematic name | M6873
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes down-regulated during B lymphocyte differentiation: small pre-B II versus large pre-B II.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_SMALL_VS_VPREB_POS_LARGE_PRE_BCELL_UP
Systematic name | M6874
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes up-regulated during B lymphocyte differentiation: small pre-B II versus VPREB1+ [GeneID=7441] large pre-B II.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_SMALL_VS_VPREB_POS_LARGE_PRE_BCELL_DN
Systematic name | M6876
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes down-regulated during B lymphocyte differentiation: small pre-B II versus VPREB1+ [GeneID=7441] large pre-B II.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_LARGE_PRE_BCELL_VS_VPREB_POS_LARGE_PRE_BCELL_UP
Systematic name | M6877
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes up-regulated during B lymphocyte differentiation: large pre-B II versus VPREB1+ [GeneID=7441] pre-B Il.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE4590_LARGE_PRE_BCELL_VS_VPREB_POS_LARGE_PRE_BCELL_DN
Systematic name | M6878
Organism | Homo sapiens
PMID | 17890238
Authors | Hoffmann R,Lottaz C,Kühne T,Rolink A,Melchers F
Category | C7
Sub-category |
Brief description | Genes down-regulated during B lymphocyte differentiation: large pre-B II versus VPREB1+ [GeneID=7441] pre-B Il.
Full description | Cells from four develppmental stages were purified by FACS from human bone marrow samples

Standard name | GSE9601_UNTREATED_VS_NFKB_INHIBITOR_TREATED_HCMV_INF_MONOCYTE_UP
Systematic name | M6880
Organism | Homo sapiens
PMID | 18003728
Authors | Chan G,Bivins-Smith ER,Smith MS,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes after HCMV infection: untreated versus BAY 11-7082 [PubChem=5353431].
Full description | Human cytomegalovirus induces a pro-inflammatory monocyte following infection and we have evidence that NF-κB and phosphatidylinositol 3-kinase [PI(3)K] are key mediators in this early activation. To begin to address how these signalling pathways are responsible for the rapid activation of infected monocytes, we examined the role these pathways played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes, including inflammatory genes, were regulated in a NF-κB- and/or PI(3)K-dependent manner, identifying these pathways as key cellular control points in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE9601_UNTREATED_VS_NFKB_INHIBITOR_TREATED_HCMV_INF_MONOCYTE_DN
Systematic name | M6881
Organism | Homo sapiens
PMID | 18003728
Authors | Chan G,Bivins-Smith ER,Smith MS,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes after HCMV infection: untreated versus BAY 11-7082 [PubChem=5353431].
Full description | Human cytomegalovirus induces a pro-inflammatory monocyte following infection and we have evidence that NF-κB and phosphatidylinositol 3-kinase [PI(3)K] are key mediators in this early activation. To begin to address how these signalling pathways are responsible for the rapid activation of infected monocytes, we examined the role these pathways played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes, including inflammatory genes, were regulated in a NF-κB- and/or PI(3)K-dependent manner, identifying these pathways as key cellular control points in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE9601_UNTREATED_VS_PI3K_INHIBITOR_TREATED_HCMV_INF_MONOCYTE_UP
Systematic name | M6882
Organism | Homo sapiens
PMID | 18003728
Authors | Chan G,Bivins-Smith ER,Smith MS,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes after HCMV infection: untreated versus Ly294002 [PubChem=3973].
Full description | Human cytomegalovirus induces a pro-inflammatory monocyte following infection and we have evidence that NF-κB and phosphatidylinositol 3-kinase [PI(3)K] are key mediators in this early activation. To begin to address how these signalling pathways are responsible for the rapid activation of infected monocytes, we examined the role these pathways played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes, including inflammatory genes, were regulated in a NF-κB- and/or PI(3)K-dependent manner, identifying these pathways as key cellular control points in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE9601_UNTREATED_VS_PI3K_INHIBITOR_TREATED_HCMV_INF_MONOCYTE_DN
Systematic name | M6883
Organism | Homo sapiens
PMID | 18003728
Authors | Chan G,Bivins-Smith ER,Smith MS,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes after HCMV infection: untreated versus Ly294002 [PubChem=3973].
Full description | Human cytomegalovirus induces a pro-inflammatory monocyte following infection and we have evidence that NF-κB and phosphatidylinositol 3-kinase [PI(3)K] are key mediators in this early activation. To begin to address how these signalling pathways are responsible for the rapid activation of infected monocytes, we examined the role these pathways played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes, including inflammatory genes, were regulated in a NF-κB- and/or PI(3)K-dependent manner, identifying these pathways as key cellular control points in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE9601_NFKB_INHIBITOR_VS_PI3K_INHIBITOR_TREATED_HCMV_INF_MONOCYTE_UP
Systematic name | M6884
Organism | Homo sapiens
PMID | 18003728
Authors | Chan G,Bivins-Smith ER,Smith MS,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes after HCMV infection: BAY 11-7082 [PubChem=5353431] versus Ly294002 [PubChem=3973].
Full description | Human cytomegalovirus induces a pro-inflammatory monocyte following infection and we have evidence that NF-κB and phosphatidylinositol 3-kinase [PI(3)K] are key mediators in this early activation. To begin to address how these signalling pathways are responsible for the rapid activation of infected monocytes, we examined the role these pathways played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes, including inflammatory genes, were regulated in a NF-κB- and/or PI(3)K-dependent manner, identifying these pathways as key cellular control points in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE9601_NFKB_INHIBITOR_VS_PI3K_INHIBITOR_TREATED_HCMV_INF_MONOCYTE_DN
Systematic name | M6887
Organism | Homo sapiens
PMID | 18003728
Authors | Chan G,Bivins-Smith ER,Smith MS,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes after HCMV infection: BAY 11-7082 [PubChem=5353431] versus Ly294002 [PubChem=3973].
Full description | Human cytomegalovirus induces a pro-inflammatory monocyte following infection and we have evidence that NF-κB and phosphatidylinositol 3-kinase [PI(3)K] are key mediators in this early activation. To begin to address how these signalling pathways are responsible for the rapid activation of infected monocytes, we examined the role these pathways played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes, including inflammatory genes, were regulated in a NF-κB- and/or PI(3)K-dependent manner, identifying these pathways as key cellular control points in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE9316_IL6_KO_VS_IFNG_KO_INVIVO_EXPANDED_CD4_TCELL_UP
Systematic name | M6888
Organism | Mus musculus
PMID | 18025126
Authors | Hirota K,Yoshitomi H,Hashimoto M,Maeda S,Teradaira S,Sugimoto N,Yamaguchi T,Nomura T,Ito H,Nakamura T,Sakaguchi N,Sakaguchi S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells with in vivo expansion: IL6 [GeneID=3569] versus IFNG [GeneID=3458].
Full description | Th17 cells are enriched by sorting FR4-CD4+ T cells from SKG mice. A large number of Th17 cells also develop spontaneously when CD4+ T cells from IFN-g-deficient (IFN-g-/-) BALB/c mice are transferred to T cell-deficient RAG2-deficient (RAG2-/-) mice and subjected to homeostatic proliferation, whereas they fail to develop in similar transfer of IL-6-deficient (IL-6-/-) CD4+ T cells to IL-6-/- RAG2-/- mice. To explore the functional molecules specifically expressed by Th17 cells, we conducted Gene Microarray analysis between 10-month-old SKG FR4-CD4+ cells and age-matched BALB/c FR4-CD4+ cells, and between IFN-g-/- CD4+ cells transferred to RAG2-/- mice and IL-6-/- CD4+ T cells transferred to IL-6-/- RAG2-/- mice. The analysis revealed that 1,556 and 115 genes were up-regulated in 10-month-old SKG FR4-CD4+ and IFN-g-/- CD4+ T cells after homeostatic proliferation, respectively, with 29 genes shared by the two groups of genes. The 29 genes included those encoding cytokines, chemokines, and their receptors, such as IL-1 receptor type1 (IL-1R1), IL-17, IL-22, IL-21, CCR6, and CCL20.

Standard name | GSE9316_IL6_KO_VS_IFNG_KO_INVIVO_EXPANDED_CD4_TCELL_DN
Systematic name | M6892
Organism | Mus musculus
PMID | 18025126
Authors | Hirota K,Yoshitomi H,Hashimoto M,Maeda S,Teradaira S,Sugimoto N,Yamaguchi T,Nomura T,Ito H,Nakamura T,Sakaguchi N,Sakaguchi S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells with in vivo expansion: IL6 [GeneID=3569] versus IFNG [GeneID=3458].
Full description | Th17 cells are enriched by sorting FR4-CD4+ T cells from SKG mice. A large number of Th17 cells also develop spontaneously when CD4+ T cells from IFN-g-deficient (IFN-g-/-) BALB/c mice are transferred to T cell-deficient RAG2-deficient (RAG2-/-) mice and subjected to homeostatic proliferation, whereas they fail to develop in similar transfer of IL-6-deficient (IL-6-/-) CD4+ T cells to IL-6-/- RAG2-/- mice. To explore the functional molecules specifically expressed by Th17 cells, we conducted Gene Microarray analysis between 10-month-old SKG FR4-CD4+ cells and age-matched BALB/c FR4-CD4+ cells, and between IFN-g-/- CD4+ cells transferred to RAG2-/- mice and IL-6-/- CD4+ T cells transferred to IL-6-/- RAG2-/- mice. The analysis revealed that 1,556 and 115 genes were up-regulated in 10-month-old SKG FR4-CD4+ and IFN-g-/- CD4+ T cells after homeostatic proliferation, respectively, with 29 genes shared by the two groups of genes. The 29 genes included those encoding cytokines, chemokines, and their receptors, such as IL-1 receptor type1 (IL-1R1), IL-17, IL-22, IL-21, CCR6, and CCL20.

Standard name | GSE9316_CD4_TCELL_BALBC_VS_TH17_ENRI_CD4_TCELL_SKG_PMA_IONO_STIM_FR4NEG_UP
Systematic name | M6893
Organism | Mus musculus
PMID | 18025126
Authors | Hirota K,Yoshitomi H,Hashimoto M,Maeda S,Teradaira S,Sugimoto N,Yamaguchi T,Nomura T,Ito H,Nakamura T,Sakaguchi N,Sakaguchi S
Category | C7
Sub-category |
Brief description | Genes up-regulated in FOLR4- CD4 [GeneID=390243;920] T cells treated by phorbol myristate acetate and ionomycin [PubChem=4792;3733] from: BALB/c versus SKG mice.
Full description | Th17 cells are enriched by sorting FR4-CD4+ T cells from SKG mice. A large number of Th17 cells also develop spontaneously when CD4+ T cells from IFN-g-deficient (IFN-g-/-) BALB/c mice are transferred to T cell-deficient RAG2-deficient (RAG2-/-) mice and subjected to homeostatic proliferation, whereas they fail to develop in similar transfer of IL-6-deficient (IL-6-/-) CD4+ T cells to IL-6-/- RAG2-/- mice. To explore the functional molecules specifically expressed by Th17 cells, we conducted Gene Microarray analysis between 10-month-old SKG FR4-CD4+ cells and age-matched BALB/c FR4-CD4+ cells, and between IFN-g-/- CD4+ cells transferred to RAG2-/- mice and IL-6-/- CD4+ T cells transferred to IL-6-/- RAG2-/- mice. The analysis revealed that 1,556 and 115 genes were up-regulated in 10-month-old SKG FR4-CD4+ and IFN-g-/- CD4+ T cells after homeostatic proliferation, respectively, with 29 genes shared by the two groups of genes. The 29 genes included those encoding cytokines, chemokines, and their receptors, such as IL-1 receptor type1 (IL-1R1), IL-17, IL-22, IL-21, CCR6, and CCL20.

Standard name | GSE9316_CD4_TCELL_BALBC_VS_TH17_ENRI_CD4_TCELL_SKG_PMA_IONO_STIM_FR4NEG_DN
Systematic name | M6894
Organism | Mus musculus
PMID | 18025126
Authors | Hirota K,Yoshitomi H,Hashimoto M,Maeda S,Teradaira S,Sugimoto N,Yamaguchi T,Nomura T,Ito H,Nakamura T,Sakaguchi N,Sakaguchi S
Category | C7
Sub-category |
Brief description | Genes down-regulated in FOLR4- CD4 [GeneID=390243;920] T cells treated by phorbol myristate acetate and ionomycin [PubChem=4792;3733] from: BALB/c versus SKG mice.
Full description | Th17 cells are enriched by sorting FR4-CD4+ T cells from SKG mice. A large number of Th17 cells also develop spontaneously when CD4+ T cells from IFN-g-deficient (IFN-g-/-) BALB/c mice are transferred to T cell-deficient RAG2-deficient (RAG2-/-) mice and subjected to homeostatic proliferation, whereas they fail to develop in similar transfer of IL-6-deficient (IL-6-/-) CD4+ T cells to IL-6-/- RAG2-/- mice. To explore the functional molecules specifically expressed by Th17 cells, we conducted Gene Microarray analysis between 10-month-old SKG FR4-CD4+ cells and age-matched BALB/c FR4-CD4+ cells, and between IFN-g-/- CD4+ cells transferred to RAG2-/- mice and IL-6-/- CD4+ T cells transferred to IL-6-/- RAG2-/- mice. The analysis revealed that 1,556 and 115 genes were up-regulated in 10-month-old SKG FR4-CD4+ and IFN-g-/- CD4+ T cells after homeostatic proliferation, respectively, with 29 genes shared by the two groups of genes. The 29 genes included those encoding cytokines, chemokines, and their receptors, such as IL-1 receptor type1 (IL-1R1), IL-17, IL-22, IL-21, CCR6, and CCL20.

Standard name | GSE9509_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_10MIN_UP
Systematic name | M6895
Organism | Mus musculus
PMID | 18025162
Authors | Kasmi El KC,Smith AM,Williams L,Neale G,Panopoulos AD,Panopolous A,Watowich SS,Häcker H,Foxwell BM,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with IL10 [GeneID=3586] knockout in response to 10 min treatment by: LPS versus LPS and IL10 [GeneID=3586].
Full description | IL-10 regulates anti-inflammatory signaling via the activation of STAT3, which in turn controls the induction of a gene expression program whose products execute inhibitory effects on pro-inflammatory mediator production. Here we show that IL-10 induces the expression of an ETS family transcriptional repressor, ETV3 and a helicase family co-repressor, SBNO2 (Strawberry notch homolog 2) in mouse and human macrophages. IL-10-mediated induction of ETV3 and SBNO2 expression was dependent upon both STAT3, and co-stimulus through the TLR pathway. We also observed that ETV3 expression was strongly induced by the STAT3 pathway induced by IL-10 but not STAT3 signaling activated by IL-6, which cannot activate the anti-inflammatory signaling pathway. ETV3 and SBNO2 specifically repressed NF-kB-mediated transcription and can physically interact. Collectively our data suggest that ETV3 and SBNO2 are components of the pathways that contribute to the downstream anti-inflammatory effects of IL-10. We compared expression profiles of macrophages isolated from IL-10 -/- mice. Macrophages were treated with either LPS or LPS plus IL-10. Treatment times were 10, 20 and 30 minutes.

Standard name | GSE9509_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_10MIN_DN
Systematic name | M6896
Organism | Mus musculus
PMID | 18025162
Authors | Kasmi El KC,Smith AM,Williams L,Neale G,Panopoulos AD,Panopolous A,Watowich SS,Häcker H,Foxwell BM,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with IL10 [GeneID=3586] knockout in response to 10 min treatment by: LPS versus LPS and IL10 [GeneID=3586].
Full description | IL-10 regulates anti-inflammatory signaling via the activation of STAT3, which in turn controls the induction of a gene expression program whose products execute inhibitory effects on pro-inflammatory mediator production. Here we show that IL-10 induces the expression of an ETS family transcriptional repressor, ETV3 and a helicase family co-repressor, SBNO2 (Strawberry notch homolog 2) in mouse and human macrophages. IL-10-mediated induction of ETV3 and SBNO2 expression was dependent upon both STAT3, and co-stimulus through the TLR pathway. We also observed that ETV3 expression was strongly induced by the STAT3 pathway induced by IL-10 but not STAT3 signaling activated by IL-6, which cannot activate the anti-inflammatory signaling pathway. ETV3 and SBNO2 specifically repressed NF-kB-mediated transcription and can physically interact. Collectively our data suggest that ETV3 and SBNO2 are components of the pathways that contribute to the downstream anti-inflammatory effects of IL-10. We compared expression profiles of macrophages isolated from IL-10 -/- mice. Macrophages were treated with either LPS or LPS plus IL-10. Treatment times were 10, 20 and 30 minutes.

Standard name | GSE9509_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_20MIN_UP
Systematic name | M6899
Organism | Mus musculus
PMID | 18025162
Authors | Kasmi El KC,Smith AM,Williams L,Neale G,Panopoulos AD,Panopolous A,Watowich SS,Häcker H,Foxwell BM,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with IL10 [GeneID=3586] knockout in response to 20 min treatment by: LPS versus LPS and IL10 [GeneID=3586].
Full description | IL-10 regulates anti-inflammatory signaling via the activation of STAT3, which in turn controls the induction of a gene expression program whose products execute inhibitory effects on pro-inflammatory mediator production. Here we show that IL-10 induces the expression of an ETS family transcriptional repressor, ETV3 and a helicase family co-repressor, SBNO2 (Strawberry notch homolog 2) in mouse and human macrophages. IL-10-mediated induction of ETV3 and SBNO2 expression was dependent upon both STAT3, and co-stimulus through the TLR pathway. We also observed that ETV3 expression was strongly induced by the STAT3 pathway induced by IL-10 but not STAT3 signaling activated by IL-6, which cannot activate the anti-inflammatory signaling pathway. ETV3 and SBNO2 specifically repressed NF-kB-mediated transcription and can physically interact. Collectively our data suggest that ETV3 and SBNO2 are components of the pathways that contribute to the downstream anti-inflammatory effects of IL-10. We compared expression profiles of macrophages isolated from IL-10 -/- mice. Macrophages were treated with either LPS or LPS plus IL-10. Treatment times were 10, 20 and 30 minutes.

Standard name | GSE9509_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_20MIN_DN
Systematic name | M6901
Organism | Mus musculus
PMID | 18025162
Authors | Kasmi El KC,Smith AM,Williams L,Neale G,Panopoulos AD,Panopolous A,Watowich SS,Häcker H,Foxwell BM,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with IL10 [GeneID=3586] knockout in response to 20 min treatment by: LPS versus LPS and IL10 [GeneID=3586].
Full description | IL-10 regulates anti-inflammatory signaling via the activation of STAT3, which in turn controls the induction of a gene expression program whose products execute inhibitory effects on pro-inflammatory mediator production. Here we show that IL-10 induces the expression of an ETS family transcriptional repressor, ETV3 and a helicase family co-repressor, SBNO2 (Strawberry notch homolog 2) in mouse and human macrophages. IL-10-mediated induction of ETV3 and SBNO2 expression was dependent upon both STAT3, and co-stimulus through the TLR pathway. We also observed that ETV3 expression was strongly induced by the STAT3 pathway induced by IL-10 but not STAT3 signaling activated by IL-6, which cannot activate the anti-inflammatory signaling pathway. ETV3 and SBNO2 specifically repressed NF-kB-mediated transcription and can physically interact. Collectively our data suggest that ETV3 and SBNO2 are components of the pathways that contribute to the downstream anti-inflammatory effects of IL-10. We compared expression profiles of macrophages isolated from IL-10 -/- mice. Macrophages were treated with either LPS or LPS plus IL-10. Treatment times were 10, 20 and 30 minutes.

Standard name | GSE9509_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_30MIN_UP
Systematic name | M6902
Organism | Mus musculus
PMID | 18025162
Authors | Kasmi El KC,Smith AM,Williams L,Neale G,Panopoulos AD,Panopolous A,Watowich SS,Häcker H,Foxwell BM,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with IL10 [GeneID=3586] knockout in response to 30 min treatment by: LPS versus LPS and IL10 [GeneID=3586].
Full description | IL-10 regulates anti-inflammatory signaling via the activation of STAT3, which in turn controls the induction of a gene expression program whose products execute inhibitory effects on pro-inflammatory mediator production. Here we show that IL-10 induces the expression of an ETS family transcriptional repressor, ETV3 and a helicase family co-repressor, SBNO2 (Strawberry notch homolog 2) in mouse and human macrophages. IL-10-mediated induction of ETV3 and SBNO2 expression was dependent upon both STAT3, and co-stimulus through the TLR pathway. We also observed that ETV3 expression was strongly induced by the STAT3 pathway induced by IL-10 but not STAT3 signaling activated by IL-6, which cannot activate the anti-inflammatory signaling pathway. ETV3 and SBNO2 specifically repressed NF-kB-mediated transcription and can physically interact. Collectively our data suggest that ETV3 and SBNO2 are components of the pathways that contribute to the downstream anti-inflammatory effects of IL-10. We compared expression profiles of macrophages isolated from IL-10 -/- mice. Macrophages were treated with either LPS or LPS plus IL-10. Treatment times were 10, 20 and 30 minutes.

Standard name | GSE9509_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_30MIN_DN
Systematic name | M6903
Organism | Mus musculus
PMID | 18025162
Authors | Kasmi El KC,Smith AM,Williams L,Neale G,Panopoulos AD,Panopolous A,Watowich SS,Häcker H,Foxwell BM,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with IL10 [GeneID=3586] knockout in response to 30 min treatment by: LPS versus LPS and IL10 [GeneID=3586].
Full description | IL-10 regulates anti-inflammatory signaling via the activation of STAT3, which in turn controls the induction of a gene expression program whose products execute inhibitory effects on pro-inflammatory mediator production. Here we show that IL-10 induces the expression of an ETS family transcriptional repressor, ETV3 and a helicase family co-repressor, SBNO2 (Strawberry notch homolog 2) in mouse and human macrophages. IL-10-mediated induction of ETV3 and SBNO2 expression was dependent upon both STAT3, and co-stimulus through the TLR pathway. We also observed that ETV3 expression was strongly induced by the STAT3 pathway induced by IL-10 but not STAT3 signaling activated by IL-6, which cannot activate the anti-inflammatory signaling pathway. ETV3 and SBNO2 specifically repressed NF-kB-mediated transcription and can physically interact. Collectively our data suggest that ETV3 and SBNO2 are components of the pathways that contribute to the downstream anti-inflammatory effects of IL-10. We compared expression profiles of macrophages isolated from IL-10 -/- mice. Macrophages were treated with either LPS or LPS plus IL-10. Treatment times were 10, 20 and 30 minutes.

Standard name | GSE9509_10MIN_VS_30MIN_LPS_STIM_IL10_KO_MACROPHAGE_UP
Systematic name | M6904
Organism | Mus musculus
PMID | 18025162
Authors | Kasmi El KC,Smith AM,Williams L,Neale G,Panopoulos AD,Panopolous A,Watowich SS,Häcker H,Foxwell BM,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with IL10 [GeneID=3586] knockout treated by LPS: 10 min versus 30 min.
Full description | IL-10 regulates anti-inflammatory signaling via the activation of STAT3, which in turn controls the induction of a gene expression program whose products execute inhibitory effects on pro-inflammatory mediator production. Here we show that IL-10 induces the expression of an ETS family transcriptional repressor, ETV3 and a helicase family co-repressor, SBNO2 (Strawberry notch homolog 2) in mouse and human macrophages. IL-10-mediated induction of ETV3 and SBNO2 expression was dependent upon both STAT3, and co-stimulus through the TLR pathway. We also observed that ETV3 expression was strongly induced by the STAT3 pathway induced by IL-10 but not STAT3 signaling activated by IL-6, which cannot activate the anti-inflammatory signaling pathway. ETV3 and SBNO2 specifically repressed NF-kB-mediated transcription and can physically interact. Collectively our data suggest that ETV3 and SBNO2 are components of the pathways that contribute to the downstream anti-inflammatory effects of IL-10. We compared expression profiles of macrophages isolated from IL-10 -/- mice. Macrophages were treated with either LPS or LPS plus IL-10. Treatment times were 10, 20 and 30 minutes.

Standard name | GSE9509_10MIN_VS_30MIN_LPS_STIM_IL10_KO_MACROPHAGE_DN
Systematic name | M6908
Organism | Mus musculus
PMID | 18025162
Authors | Kasmi El KC,Smith AM,Williams L,Neale G,Panopoulos AD,Panopolous A,Watowich SS,Häcker H,Foxwell BM,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with IL10 [GeneID=3586] knockout treated by LPS: 10 min versus 30 min.
Full description | IL-10 regulates anti-inflammatory signaling via the activation of STAT3, which in turn controls the induction of a gene expression program whose products execute inhibitory effects on pro-inflammatory mediator production. Here we show that IL-10 induces the expression of an ETS family transcriptional repressor, ETV3 and a helicase family co-repressor, SBNO2 (Strawberry notch homolog 2) in mouse and human macrophages. IL-10-mediated induction of ETV3 and SBNO2 expression was dependent upon both STAT3, and co-stimulus through the TLR pathway. We also observed that ETV3 expression was strongly induced by the STAT3 pathway induced by IL-10 but not STAT3 signaling activated by IL-6, which cannot activate the anti-inflammatory signaling pathway. ETV3 and SBNO2 specifically repressed NF-kB-mediated transcription and can physically interact. Collectively our data suggest that ETV3 and SBNO2 are components of the pathways that contribute to the downstream anti-inflammatory effects of IL-10. We compared expression profiles of macrophages isolated from IL-10 -/- mice. Macrophages were treated with either LPS or LPS plus IL-10. Treatment times were 10, 20 and 30 minutes.

Standard name | GSE9509_10MIN_VS_30MIN_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_UP
Systematic name | M6909
Organism | Mus musculus
PMID | 18025162
Authors | Kasmi El KC,Smith AM,Williams L,Neale G,Panopoulos AD,Panopolous A,Watowich SS,Häcker H,Foxwell BM,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with IL10 [GeneID=3586] knockout treated by LPS and IL10 [GeneID=3586]: 10 min versus 30 min.
Full description | IL-10 regulates anti-inflammatory signaling via the activation of STAT3, which in turn controls the induction of a gene expression program whose products execute inhibitory effects on pro-inflammatory mediator production. Here we show that IL-10 induces the expression of an ETS family transcriptional repressor, ETV3 and a helicase family co-repressor, SBNO2 (Strawberry notch homolog 2) in mouse and human macrophages. IL-10-mediated induction of ETV3 and SBNO2 expression was dependent upon both STAT3, and co-stimulus through the TLR pathway. We also observed that ETV3 expression was strongly induced by the STAT3 pathway induced by IL-10 but not STAT3 signaling activated by IL-6, which cannot activate the anti-inflammatory signaling pathway. ETV3 and SBNO2 specifically repressed NF-kB-mediated transcription and can physically interact. Collectively our data suggest that ETV3 and SBNO2 are components of the pathways that contribute to the downstream anti-inflammatory effects of IL-10. We compared expression profiles of macrophages isolated from IL-10 -/- mice. Macrophages were treated with either LPS or LPS plus IL-10. Treatment times were 10, 20 and 30 minutes.

Standard name | GSE9509_10MIN_VS_30MIN_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_DN
Systematic name | M6911
Organism | Mus musculus
PMID | 18025162
Authors | Kasmi El KC,Smith AM,Williams L,Neale G,Panopoulos AD,Panopolous A,Watowich SS,Häcker H,Foxwell BM,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with IL10 [GeneID=3586] knockout treated by LPS and IL10 [GeneID=3586]: 10 min versus 30 min.
Full description | IL-10 regulates anti-inflammatory signaling via the activation of STAT3, which in turn controls the induction of a gene expression program whose products execute inhibitory effects on pro-inflammatory mediator production. Here we show that IL-10 induces the expression of an ETS family transcriptional repressor, ETV3 and a helicase family co-repressor, SBNO2 (Strawberry notch homolog 2) in mouse and human macrophages. IL-10-mediated induction of ETV3 and SBNO2 expression was dependent upon both STAT3, and co-stimulus through the TLR pathway. We also observed that ETV3 expression was strongly induced by the STAT3 pathway induced by IL-10 but not STAT3 signaling activated by IL-6, which cannot activate the anti-inflammatory signaling pathway. ETV3 and SBNO2 specifically repressed NF-kB-mediated transcription and can physically interact. Collectively our data suggest that ETV3 and SBNO2 are components of the pathways that contribute to the downstream anti-inflammatory effects of IL-10. We compared expression profiles of macrophages isolated from IL-10 -/- mice. Macrophages were treated with either LPS or LPS plus IL-10. Treatment times were 10, 20 and 30 minutes.

Standard name | GSE6674_UNSTIM_VS_ANTI_IGM_STIM_BCELL_UP
Systematic name | M6915
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: control versus anti IgM.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_UNSTIM_VS_ANTI_IGM_STIM_BCELL_DN
Systematic name | M6916
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: control versus anti IgM.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_UNSTIM_VS_CPG_STIM_BCELL_UP
Systematic name | M6918
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: control versus CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_UNSTIM_VS_CPG_STIM_BCELL_DN
Systematic name | M6919
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: control versus CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_UNSTIM_VS_PL2_3_STIM_BCELL_UP
Systematic name | M6922
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: control versus PL2-3 (Chromatin IC).
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_UNSTIM_VS_PL2_3_STIM_BCELL_DN
Systematic name | M6923
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: control versus PL2-3 (Chromatin IC).
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_UNSTIM_VS_ANTI_IGM_AND_CPG_STIM_BCELL_UP
Systematic name | M6925
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: control versus anti IgM and CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_UNSTIM_VS_ANTI_IGM_AND_CPG_STIM_BCELL_DN
Systematic name | M6926
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: control versus anti IgM and cell anti IgM and CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_ANTI_IGM_VS_CPG_STIM_BCELL_UP
Systematic name | M6927
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: anti IgM versus CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_ANTI_IGM_VS_CPG_STIM_BCELL_DN
Systematic name | M6928
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: anti IgM versus CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_ANTI_IGM_VS_PL2_3_STIM_BCELL_UP
Systematic name | M6930
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: anti IgM versus PL2-3 (Chromatin IC).
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_ANTI_IGM_VS_PL2_3_STIM_BCELL_DN
Systematic name | M6932
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: anti IgM versus PL2-3 (Chromatin IC).
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_ANTI_IGM_VS_ANTI_IGM_AND_CPG_STIM_BCELL_UP
Systematic name | M6934
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: anti IgM versus anti IgM and CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_ANTI_IGM_VS_ANTI_IGM_AND_CPG_STIM_BCELL_DN
Systematic name | M6935
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: anti IgM versus anti IgM and CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_CPG_VS_PL2_3_STIM_BCELL_UP
Systematic name | M6936
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: CpG oligodeoxynucleotide 1826 versus PL2-3 (Chromatin IC).
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_CPG_VS_PL2_3_STIM_BCELL_DN
Systematic name | M6938
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: CpG oligodeoxynucleotide 1826 versus PL2-3 (Chromatin IC).
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_CPG_VS_CPG_AND_ANTI_IGM_STIM_BCELL_UP
Systematic name | M6940
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: CpG oligodeoxynucleotide 1826 versus anti IgM and CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_CPG_VS_CPG_AND_ANTI_IGM_STIM_BCELL_DN
Systematic name | M6941
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: CpG oligodeoxynucleotide 1826 versus anti IgM and CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_PL2_3_VS_ANTI_IGM_AND_CPG_STIM_BCELL_UP
Systematic name | M6942
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: PL2-3 (Chromatin IC) versus anti IgM and CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE6674_PL2_3_VS_ANTI_IGM_AND_CPG_STIM_BCELL_DN
Systematic name | M6943
Organism | Mus musculus
PMID | 18025183
Authors | Busconi L,Bauer JW,Tumang JR,Laws A,Perkins-Mesires K,Tabor AS,Lau C,Corley RB,Rothstein TL,Lund FE,Behrens TW,Marshak-Rothstein A
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: PL2-3 (Chromatin IC) versus anti IgM and CpG oligodeoxynucleotide 1826.
Full description | We have previously shown that rheumatoid factors (RF) produced by Fas-deficient autoimmune-prone mice typically bind autologous IgG2a with remarkably low affinity. Nevertheless, B cells representative of this RF population proliferate vigorously in response IgG2a/chromatin immune complexes through a mechanism dependent on the sequential engagement of the BCR and Toll-like receptor 9 (TLR9). To more precisely address the role of both receptors in this response, we analyzed the signaling pathways activated in AM14 B cells stimulated with these complexes. We found that the BCR not only serves to direct the chromatin complex to an internal compartment where it can engage TLR9 but also transmits a suboptimal signal that in combination with the signals emanating from TLR9 leads to NF-kappa-B activation and proliferation. Importantly, engagement of both receptors leads to the upregulation of a group of gene products, not induced by the BCR or TLR9 alone, that include IL-2. These data indicate that autoreactive B cells, stimulated by a combination of BCR and TLR9 ligands, acquire functional properties that may contribute to the activation of additional cells involved in the autoimmune disease process.

Standard name | GSE7831_UNSTIM_VS_CPG_STIM_PDC_1H_UP
Systematic name | M6944
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoit dendritic cells (1h): untreated versus CpG oligodeoxynucleotide 1826.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_UNSTIM_VS_CPG_STIM_PDC_1H_DN
Systematic name | M6945
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoit dendritic cells (1h): untreated versus CpG oligodeoxynucleotide 1826.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_UNSTIM_VS_INFLUENZA_STIM_PDC_1H_UP
Systematic name | M6947
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells (1h): untreated versus influenza virus infection.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_UNSTIM_VS_INFLUENZA_STIM_PDC_1H_DN
Systematic name | M6949
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells (1h): untreated versus influenza virus infection.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_CPG_VS_INFLUENZA_STIM_PDC_1H_UP
Systematic name | M6950
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells (1h): CpG oligodeoxynucleotide 1826 versus influenza virus infection.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_CPG_VS_INFLUENZA_STIM_PDC_1H_DN
Systematic name | M6952
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells (1h): CpG oligodeoxynucleotide 1826 versus influenza virus infection.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_UNSTIM_VS_CPG_STIM_PDC_4H_UP
Systematic name | M6953
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoit dendritic cells (4h): untreated versus CpG oligodeoxynucleotide 1826.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_UNSTIM_VS_CPG_STIM_PDC_4H_DN
Systematic name | M6954
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoit dendritic cells (4h): untreated versus CpG oligodeoxynucleotide 1826.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_UNSTIM_VS_INFLUENZA_STIM_PDC_4H_UP
Systematic name | M6955
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells (4h): untreated versus influenza virus infection.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_UNSTIM_VS_INFLUENZA_STIM_PDC_4H_DN
Systematic name | M6956
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells (4h): untreated versus influenza virus infection.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_CPG_VS_INFLUENZA_STIM_PDC_4H_UP
Systematic name | M6958
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells (4h): CpG oligodeoxynucleotide 1826 versus influenza virus infection.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_CPG_VS_INFLUENZA_STIM_PDC_4H_DN
Systematic name | M6959
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells (4h): CpG oligodeoxynucleotide 1826 versus influenza virus infection.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_1H_VS_4H_CPG_STIM_PDC_UP
Systematic name | M6960
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells in response to CpG oligodeoxynucleotide 1826: 1h versus 4h.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_1H_VS_4H_CPG_STIM_PDC_DN
Systematic name | M6961
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells in response to CpG oligodeoxynucleotide 1826: 1h versus 4h.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_1H_VS_4H_INFLUENZA_STIM_PDC_UP
Systematic name | M6963
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells in response to influenza virus infection: 1h versus 4h.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE7831_1H_VS_4H_INFLUENZA_STIM_PDC_DN
Systematic name | M6964
Organism | Mus musculus
PMID | 18029397
Authors | Iparraguirre A,Tobias JW,Hensley SE,Masek KS,Cavanagh LL,Rendl M,Hunter CA,Ertl HC,Andrian von UH,Weninger W
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells in response to influenza virus infection: 1h versus 4h.
Full description | CpG 1826 binds to Toll-like receptor (TLR)9, whereas influenza virus PR8 activates pDC via TLR7. Differential stimulation of pDCs is expected to result in unique activation mechanism(s) leading to a different phenotypically and functionally matured pDC We used microarrays to detail the global programme of gene expression underlying the maturation process of pDC activated with CpG 1826 and influenza virus PR8. We identified a distinct expression profile of upregulated immunomediators.

Standard name | GSE9239_CTRL_VS_TNF_INHIBITOR_TREATED_DC_UP
Systematic name | M6965
Organism | Homo sapiens
PMID | 18039949
Authors | Zaba LC,Cardinale I,Gilleaudeau P,Sullivan-Whalen M,Suárez-Fariñas M,Fariñas Suárez M,Fuentes-Duculan J,Novitskaya I,Khatcherian A,Bluth MJ,Lowes MA,Krueger JG
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: control versus TNF [GeneID=7124] inhibitor etanercept.
Full description | The process for making monocyte derived DCs (moDCs) has been previously described (46). All analysis was performed on “day 5” immature DCs. Etanercept 10mg/mL was added to experimental wells on days 0, 2, and 4. We chose this concentration of etanercept as it approximates the plasma concentration of drug when given 50mg BIW.

Standard name | GSE9239_CTRL_VS_TNF_INHIBITOR_TREATED_DC_DN
Systematic name | M6966
Organism | Homo sapiens
PMID | 18039949
Authors | Zaba LC,Cardinale I,Gilleaudeau P,Sullivan-Whalen M,Suárez-Fariñas M,Fariñas Suárez M,Fuentes-Duculan J,Novitskaya I,Khatcherian A,Bluth MJ,Lowes MA,Krueger JG
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: control versus TNF [GeneID=7124] inhibitor etanercept.
Full description | The process for making monocyte derived DCs (moDCs) has been previously described (46). All analysis was performed on “day 5” immature DCs. Etanercept 10mg/mL was added to experimental wells on days 0, 2, and 4. We chose this concentration of etanercept as it approximates the plasma concentration of drug when given 50mg BIW.

Standard name | GSE8621_UNSTIM_VS_LPS_STIM_MACROPHAGE_UP
Systematic name | M6970
Organism | Mus musculus
PMID | 18086374
Authors | Mages J,Dietrich H,Lang R
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve macrophages: untreated versus LPS.
Full description | Among the multiple mechanisms that control the intensity and duration of macrophage activation, the development of a state of refractoriness to a second stimulation in cells treated with LPS has long been recognized. Release of inhibitory cytokines and alterations in intracellular signaling pathways may be involved in the development of LPS tolerance. Although a number of molecules have been implicated, a detailed picture of the molecular changes in LPS tolerance is still missing. We have used a genome-wide gene expression analysis approach to (i) define which fraction of LPS target genes are subject to tolerance induction and (ii) identify genes that are expressed at high levels in tolerant macrophages. Our data show that in LPS tolerant macrophages the vast majority of LPS-induced gene expression is abrogated. The extent of tolerance induction varies for individual genes, and a small subset appears to be excepted. Compared to other negative control mechanisms of macrophages, e.g. IL-10-induced deactivation, LPS-tolerance inhibits a much wider range of transcriptional targets. Some previously described negative regulators of TLR-signaling (e.g. IRAK-M) were confirmed as expressed at higher levels in LPS-tolerant macrophages. In addition, we discuss other potential players in LPS tolerance identified in this group of genes.

Standard name | GSE8621_UNSTIM_VS_LPS_STIM_MACROPHAGE_DN
Systematic name | M6971
Organism | Mus musculus
PMID | 18086374
Authors | Mages J,Dietrich H,Lang R
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve macrophages: untreated versus LPS.
Full description | Among the multiple mechanisms that control the intensity and duration of macrophage activation, the development of a state of refractoriness to a second stimulation in cells treated with LPS has long been recognized. Release of inhibitory cytokines and alterations in intracellular signaling pathways may be involved in the development of LPS tolerance. Although a number of molecules have been implicated, a detailed picture of the molecular changes in LPS tolerance is still missing. We have used a genome-wide gene expression analysis approach to (i) define which fraction of LPS target genes are subject to tolerance induction and (ii) identify genes that are expressed at high levels in tolerant macrophages. Our data show that in LPS tolerant macrophages the vast majority of LPS-induced gene expression is abrogated. The extent of tolerance induction varies for individual genes, and a small subset appears to be excepted. Compared to other negative control mechanisms of macrophages, e.g. IL-10-induced deactivation, LPS-tolerance inhibits a much wider range of transcriptional targets. Some previously described negative regulators of TLR-signaling (e.g. IRAK-M) were confirmed as expressed at higher levels in LPS-tolerant macrophages. In addition, we discuss other potential players in LPS tolerance identified in this group of genes.

Standard name | GSE8621_LPS_PRIMED_UNSTIM_VS_LPS_PRIMED_AND_LPS_STIM_MACROPHAGE_UP
Systematic name | M6973
Organism | Mus musculus
PMID | 18086374
Authors | Mages J,Dietrich H,Lang R
Category | C7
Sub-category |
Brief description | Genes up-regulated in tolerant microphages: untreated versus LPS.
Full description | Among the multiple mechanisms that control the intensity and duration of macrophage activation, the development of a state of refractoriness to a second stimulation in cells treated with LPS has long been recognized. Release of inhibitory cytokines and alterations in intracellular signaling pathways may be involved in the development of LPS tolerance. Although a number of molecules have been implicated, a detailed picture of the molecular changes in LPS tolerance is still missing. We have used a genome-wide gene expression analysis approach to (i) define which fraction of LPS target genes are subject to tolerance induction and (ii) identify genes that are expressed at high levels in tolerant macrophages. Our data show that in LPS tolerant macrophages the vast majority of LPS-induced gene expression is abrogated. The extent of tolerance induction varies for individual genes, and a small subset appears to be excepted. Compared to other negative control mechanisms of macrophages, e.g. IL-10-induced deactivation, LPS-tolerance inhibits a much wider range of transcriptional targets. Some previously described negative regulators of TLR-signaling (e.g. IRAK-M) were confirmed as expressed at higher levels in LPS-tolerant macrophages. In addition, we discuss other potential players in LPS tolerance identified in this group of genes.

Standard name | GSE8621_LPS_PRIMED_UNSTIM_VS_LPS_PRIMED_AND_LPS_STIM_MACROPHAGE_DN
Systematic name | M6975
Organism | Mus musculus
PMID | 18086374
Authors | Mages J,Dietrich H,Lang R
Category | C7
Sub-category |
Brief description | Genes down-regulated in tolerant microphages: untreated versus LPS.
Full description | Among the multiple mechanisms that control the intensity and duration of macrophage activation, the development of a state of refractoriness to a second stimulation in cells treated with LPS has long been recognized. Release of inhibitory cytokines and alterations in intracellular signaling pathways may be involved in the development of LPS tolerance. Although a number of molecules have been implicated, a detailed picture of the molecular changes in LPS tolerance is still missing. We have used a genome-wide gene expression analysis approach to (i) define which fraction of LPS target genes are subject to tolerance induction and (ii) identify genes that are expressed at high levels in tolerant macrophages. Our data show that in LPS tolerant macrophages the vast majority of LPS-induced gene expression is abrogated. The extent of tolerance induction varies for individual genes, and a small subset appears to be excepted. Compared to other negative control mechanisms of macrophages, e.g. IL-10-induced deactivation, LPS-tolerance inhibits a much wider range of transcriptional targets. Some previously described negative regulators of TLR-signaling (e.g. IRAK-M) were confirmed as expressed at higher levels in LPS-tolerant macrophages. In addition, we discuss other potential players in LPS tolerance identified in this group of genes.

Standard name | GSE8621_UNSTIM_VS_LPS_PRIMED_UNSTIM_MACROPHAGE_UP
Systematic name | M6978
Organism | Mus musculus
PMID | 18086374
Authors | Mages J,Dietrich H,Lang R
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated macrophages: naïve versus tolerant.
Full description | Among the multiple mechanisms that control the intensity and duration of macrophage activation, the development of a state of refractoriness to a second stimulation in cells treated with LPS has long been recognized. Release of inhibitory cytokines and alterations in intracellular signaling pathways may be involved in the development of LPS tolerance. Although a number of molecules have been implicated, a detailed picture of the molecular changes in LPS tolerance is still missing. We have used a genome-wide gene expression analysis approach to (i) define which fraction of LPS target genes are subject to tolerance induction and (ii) identify genes that are expressed at high levels in tolerant macrophages. Our data show that in LPS tolerant macrophages the vast majority of LPS-induced gene expression is abrogated. The extent of tolerance induction varies for individual genes, and a small subset appears to be excepted. Compared to other negative control mechanisms of macrophages, e.g. IL-10-induced deactivation, LPS-tolerance inhibits a much wider range of transcriptional targets. Some previously described negative regulators of TLR-signaling (e.g. IRAK-M) were confirmed as expressed at higher levels in LPS-tolerant macrophages. In addition, we discuss other potential players in LPS tolerance identified in this group of genes.

Standard name | GSE8621_UNSTIM_VS_LPS_PRIMED_UNSTIM_MACROPHAGE_DN
Systematic name | M6980
Organism | Mus musculus
PMID | 18086374
Authors | Mages J,Dietrich H,Lang R
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated macrophages: naïve versus tolerant.
Full description | Among the multiple mechanisms that control the intensity and duration of macrophage activation, the development of a state of refractoriness to a second stimulation in cells treated with LPS has long been recognized. Release of inhibitory cytokines and alterations in intracellular signaling pathways may be involved in the development of LPS tolerance. Although a number of molecules have been implicated, a detailed picture of the molecular changes in LPS tolerance is still missing. We have used a genome-wide gene expression analysis approach to (i) define which fraction of LPS target genes are subject to tolerance induction and (ii) identify genes that are expressed at high levels in tolerant macrophages. Our data show that in LPS tolerant macrophages the vast majority of LPS-induced gene expression is abrogated. The extent of tolerance induction varies for individual genes, and a small subset appears to be excepted. Compared to other negative control mechanisms of macrophages, e.g. IL-10-induced deactivation, LPS-tolerance inhibits a much wider range of transcriptional targets. Some previously described negative regulators of TLR-signaling (e.g. IRAK-M) were confirmed as expressed at higher levels in LPS-tolerant macrophages. In addition, we discuss other potential players in LPS tolerance identified in this group of genes.

Standard name | GSE8621_LPS_STIM_VS_LPS_PRIMED_AND_LPS_STIM_MACROPHAGE_UP
Systematic name | M6982
Organism | Mus musculus
PMID | 18086374
Authors | Mages J,Dietrich H,Lang R
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages in response to LPS: naïve versus tolerant.
Full description | Among the multiple mechanisms that control the intensity and duration of macrophage activation, the development of a state of refractoriness to a second stimulation in cells treated with LPS has long been recognized. Release of inhibitory cytokines and alterations in intracellular signaling pathways may be involved in the development of LPS tolerance. Although a number of molecules have been implicated, a detailed picture of the molecular changes in LPS tolerance is still missing. We have used a genome-wide gene expression analysis approach to (i) define which fraction of LPS target genes are subject to tolerance induction and (ii) identify genes that are expressed at high levels in tolerant macrophages. Our data show that in LPS tolerant macrophages the vast majority of LPS-induced gene expression is abrogated. The extent of tolerance induction varies for individual genes, and a small subset appears to be excepted. Compared to other negative control mechanisms of macrophages, e.g. IL-10-induced deactivation, LPS-tolerance inhibits a much wider range of transcriptional targets. Some previously described negative regulators of TLR-signaling (e.g. IRAK-M) were confirmed as expressed at higher levels in LPS-tolerant macrophages. In addition, we discuss other potential players in LPS tolerance identified in this group of genes.

Standard name | GSE8621_LPS_STIM_VS_LPS_PRIMED_AND_LPS_STIM_MACROPHAGE_DN
Systematic name | M6983
Organism | Mus musculus
PMID | 18086374
Authors | Mages J,Dietrich H,Lang R
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages in response to LPS: naïve versus tolerant.
Full description | Among the multiple mechanisms that control the intensity and duration of macrophage activation, the development of a state of refractoriness to a second stimulation in cells treated with LPS has long been recognized. Release of inhibitory cytokines and alterations in intracellular signaling pathways may be involved in the development of LPS tolerance. Although a number of molecules have been implicated, a detailed picture of the molecular changes in LPS tolerance is still missing. We have used a genome-wide gene expression analysis approach to (i) define which fraction of LPS target genes are subject to tolerance induction and (ii) identify genes that are expressed at high levels in tolerant macrophages. Our data show that in LPS tolerant macrophages the vast majority of LPS-induced gene expression is abrogated. The extent of tolerance induction varies for individual genes, and a small subset appears to be excepted. Compared to other negative control mechanisms of macrophages, e.g. IL-10-induced deactivation, LPS-tolerance inhibits a much wider range of transcriptional targets. Some previously described negative regulators of TLR-signaling (e.g. IRAK-M) were confirmed as expressed at higher levels in LPS-tolerant macrophages. In addition, we discuss other potential players in LPS tolerance identified in this group of genes.

Standard name | GSE8621_UNSTIM_VS_LPS_PRIMED_AND_LPS_STIM_MACROPHAGE_UP
Systematic name | M6986
Organism | Mus musculus
PMID | 18086374
Authors | Mages J,Dietrich H,Lang R
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve untreated macrophages versus tolerant macrophages stimulated by LPS.
Full description | Among the multiple mechanisms that control the intensity and duration of macrophage activation, the development of a state of refractoriness to a second stimulation in cells treated with LPS has long been recognized. Release of inhibitory cytokines and alterations in intracellular signaling pathways may be involved in the development of LPS tolerance. Although a number of molecules have been implicated, a detailed picture of the molecular changes in LPS tolerance is still missing. We have used a genome-wide gene expression analysis approach to (i) define which fraction of LPS target genes are subject to tolerance induction and (ii) identify genes that are expressed at high levels in tolerant macrophages. Our data show that in LPS tolerant macrophages the vast majority of LPS-induced gene expression is abrogated. The extent of tolerance induction varies for individual genes, and a small subset appears to be excepted. Compared to other negative control mechanisms of macrophages, e.g. IL-10-induced deactivation, LPS-tolerance inhibits a much wider range of transcriptional targets. Some previously described negative regulators of TLR-signaling (e.g. IRAK-M) were confirmed as expressed at higher levels in LPS-tolerant macrophages. In addition, we discuss other potential players in LPS tolerance identified in this group of genes.

Standard name | GSE8621_UNSTIM_VS_LPS_PRIMED_AND_LPS_STIM_MACROPHAGE_DN
Systematic name | M6987
Organism | Mus musculus
PMID | 18086374
Authors | Mages J,Dietrich H,Lang R
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve untreated macrophages versus tolerant macrophages stimulated by LPS.
Full description | Among the multiple mechanisms that control the intensity and duration of macrophage activation, the development of a state of refractoriness to a second stimulation in cells treated with LPS has long been recognized. Release of inhibitory cytokines and alterations in intracellular signaling pathways may be involved in the development of LPS tolerance. Although a number of molecules have been implicated, a detailed picture of the molecular changes in LPS tolerance is still missing. We have used a genome-wide gene expression analysis approach to (i) define which fraction of LPS target genes are subject to tolerance induction and (ii) identify genes that are expressed at high levels in tolerant macrophages. Our data show that in LPS tolerant macrophages the vast majority of LPS-induced gene expression is abrogated. The extent of tolerance induction varies for individual genes, and a small subset appears to be excepted. Compared to other negative control mechanisms of macrophages, e.g. IL-10-induced deactivation, LPS-tolerance inhibits a much wider range of transcriptional targets. Some previously described negative regulators of TLR-signaling (e.g. IRAK-M) were confirmed as expressed at higher levels in LPS-tolerant macrophages. In addition, we discuss other potential players in LPS tolerance identified in this group of genes.

Standard name | GSE9878_CTRL_VS_EBF_TRANSDUCED_PAX5_KO_PRO_BCELL_UP
Systematic name | M6988
Organism | Mus musculus
PMID | 18176567
Authors | Pongubala JM,Northrup DL,Lancki DW,Medina KL,Treiber T,Bertolino E,Thomas M,Grosschedl R,Allman D,Singh H
Category | C7
Sub-category |
Brief description | Genes up-regulated in pro-B cells with PAX5 [GeneID=5079] knockout: control versus over-expressing EBF1 [GeneID=1879].
Full description | We have determined that sustained expression of EBF suppresses alternate lineage genes independently of Pax5.

Standard name | GSE9878_CTRL_VS_EBF_TRANSDUCED_PAX5_KO_PRO_BCELL_DN
Systematic name | M6989
Organism | Mus musculus
PMID | 18176567
Authors | Pongubala JM,Northrup DL,Lancki DW,Medina KL,Treiber T,Bertolino E,Thomas M,Grosschedl R,Allman D,Singh H
Category | C7
Sub-category |
Brief description | Genes down-regulated in pro-B cells with PAX5 [GeneID=5079] knockout: control versus over-expressing EBF1 [GeneID=1879].
Full description | We have determined that sustained expression of EBF suppresses alternate lineage genes independently of Pax5.

Standard name | GSE5503_LIVER_DC_VS_MLN_DC_ACTIVATED_ALLOGENIC_TCELL_UP
Systematic name | M6990
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes up-regulated in allogeneic T cells after stimulation with dendritic cells from: liver versus mesenteric lymph nodes (mLN).
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_LIVER_DC_VS_MLN_DC_ACTIVATED_ALLOGENIC_TCELL_DN
Systematic name | M6991
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes down-regulated in allogeneic T cells after stimulation with dendritic cells from: liver versus mesenteric lymph nodes (mLN).
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_LIVER_DC_VS_PLN_DC_ACTIVATED_ALLOGENIC_TCELL_UP
Systematic name | M6992
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes up-regulated in allogeneic T cells after stimulation with dendritic cells from: liver versus peripheral lymph nodes (pLN).
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_LIVER_DC_VS_PLN_DC_ACTIVATED_ALLOGENIC_TCELL_DN
Systematic name | M6993
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes down-regulated in allogeneic T cells after stimulation with dendritic cells from: liver versus peripheral lymph nodes (pLN).
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_LIVER_DC_VS_SPLEEN_DC_ACTIVATED_ALLOGENIC_TCELL_UP
Systematic name | M6996
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes up-regulated in allogeneic T cells after stimulation with dendritic cells from: liver versus spleen.
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_LIVER_DC_VS_SPLEEN_DC_ACTIVATED_ALLOGENIC_TCELL_DN
Systematic name | M6997
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes down-regulated in allogeneic T cells after stimulation with dendritic cells from: liver versus spleen.
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_MLN_DC_VS_PLN_DC_ACTIVATED_ALLOGENIC_TCELL_UP
Systematic name | M7000
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes up-regulated in allogeneic T cells after stimulation with dendritic cells from lymph nodes: mesenteric (mLN) versus peripheral (pLN).
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_MLN_DC_VS_PLN_DC_ACTIVATED_ALLOGENIC_TCELL_DN
Systematic name | M291
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes down-regulated in allogeneic T cells after stimulation with dendritic cells from lymph nodes: mesenteric (mLN) versus peripheral (pLN).
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_MLN_DC_VS_SPLEEN_DC_ACTIVATED_ALLOGENIC_TCELL_UP
Systematic name | M293
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes up-regulated in allogeneic T cells after stimulation with dendritic cells from: mesenteric lymph nodes (mLN) versus spleen.
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_MLN_DC_VS_SPLEEN_DC_ACTIVATED_ALLOGENIC_TCELL_DN
Systematic name | M294
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes down-regulated in allogeneic T cells after stimulation with dendritic cells from: mesenteric lymph nodes (mLN) versus spleen.
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_PLN_DC_VS_SPLEEN_DC_ACTIVATED_ALLOGENIC_TCELL_UP
Systematic name | M296
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes up-regulated in allogeneic T cells after stimulation with dendritic cells from: peripheral lymph nodes (mLN) versus spleen.
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE5503_PLN_DC_VS_SPLEEN_DC_ACTIVATED_ALLOGENIC_TCELL_DN
Systematic name | M297
Organism | Mus musculus
PMID | 18178870
Authors | Kim TD,Terwey TH,Zakrzewski JL,Suh D,Kochman AA,Chen ME,King CG,Borsotti C,Grubin J,Smith OM,Heller G,Liu C,Murphy GF,Alpdogan O,Brink den van MR
Category | C7
Sub-category |
Brief description | Genes down-regulated in allogeneic T cells after stimulation with dendritic cells from: peripheral lymph nodes (mLN) versus spleen.
Full description | Transcriptional response of murine allogeneic T cells (B10.BR) after stimulation with different organ-derived (spleen, liver, peripheral and mesenteric lymph nodes) dendritic cells (C57BL/6) in vitro

Standard name | GSE10240_CTRL_VS_IL17_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_DN
Systematic name | M298
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes down-regulated in primary bronchial epithelial cells: control versus stimulated with IL17A [GeneID=3605].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_IL22_VS_IL17_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_UP
Systematic name | M299
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes up-regulated in primary bronchial epithelial cells stimulated with: IL22 [GeneID=50616] versus IL17A [GeneID=3605].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_CTRL_VS_IL17_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_UP
Systematic name | M300
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes up-regulated in primary bronchial epithelial cells: control versus stimulated with IL17A [GeneID=3605].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_CTRL_VS_IL22_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_DN
Systematic name | M301
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes down-regulated in primary bronchial epithelial cells: control versus stimulated with IL22 [GeneID=50616].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_CTRL_VS_IL22_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_UP
Systematic name | M302
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes up-regulated in primary bronchial epithelial cells: control versus stimulated with IL22 [GeneID=50616].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_CTRL_VS_IL17_AND_IL22_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_UP
Systematic name | M303
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes up-regulated in primary bronchial epithelial cells: control versus stimulated with IL17A and IL22 [GeneID=3605;50616].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_CTRL_VS_IL17_AND_IL22_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_DN
Systematic name | M304
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes down-regulated in primary bronchial epithelial cells: control versus stimulated with IL17A and IL22 [GeneID=3605;50616].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_IL22_VS_IL22_AND_IL17_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_UP
Systematic name | M306
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes up-regulated in primary bronchial epithelial cells stimulated with: IL22 [GeneID=50616] versus IL17A and IL22 [GeneID=3605;50616].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_IL22_VS_IL22_AND_IL17_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_DN
Systematic name | M309
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes down-regulated in primary bronchial epithelial cells stimulated with: IL22 [GeneID=50616] versus IL17A and IL22 [GeneID=3605;50616].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_IL22_VS_IL17_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_DN
Systematic name | M310
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes down-regulated in primary bronchial epithelial cells stimulated with: IL22 [GeneID=50616] versus IL17A [GeneID=3605].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_IL17_VS_IL17_AND_IL22_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_DN
Systematic name | M312
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes down-regulated in primary bronchial epithelial cells stimulated with: IL17A [GeneID=50616] versus IL17A and IL22 [GeneID=3605;50616].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10240_IL17_VS_IL17_AND_IL22_STIM_PRIMARY_BRONCHIAL_EPITHELIAL_CELLS_UP
Systematic name | M313
Organism | Homo sapiens
PMID | 18264110
Authors | Aujla SJ,Chan YR,Zheng M,Fei M,Askew DJ,Pociask DA,Reinhart TA,McAllister F,Edeal J,Gaus K,Husain S,Kreindler JL,Dubin PJ,Pilewski JM,Myerburg MM,Mason CA,Iwakura Y,Kolls JK
Category | C7
Sub-category |
Brief description | Genes up-regulated in primary bronchial epithelial cells stimulated with: IL17A [GeneID=50616] versus IL17A and IL22 [GeneID=3605;50616].
Full description | Primary HBE cells were stimulated with IL-22 and IL-17, and gene expression was studied using an Affymetrix platform microarray, in order to investigate which genes may be upregulated or downregulated in response to these cytokines. Of particular interest was the host defense genes such as antimicrobial peptides, which have been shown to be upregulated by IL-22 and IL-17 in skin keratinocytes.

Standard name | GSE10273_LOW_IL7_VS_HIGH_IL7_AND_IRF4_IN_IRF4_8_NULL_PRE_BCELL_UP
Systematic name | M315
Organism | Mus musculus
PMID | 18280186
Authors | Johnson K,Hashimshony T,Sawai CM,Pongubala JM,Skok JA,Aifantis I,Singh H
Category | C7
Sub-category |
Brief description | Genes up-regulated in IRF4 and IRF8 [GeneID=3662;3394] null pre-B cells treated with 0.25 ng/ml IL7 [GeneID=3574] versus the cells treated with 5 ng/ml IL7 [GeneID=3574] and transduced with IRF4 [GeneID=3662].
Full description | Productive rearrangement of the immunoglobulin heavy chain locus triggers a major developmental checkpoint that promotes limited clonal expansion of pre-B cells, culminating in cell cycle arrest and rearrangement of the kappa (κ) or lambda (λ) light-chain loci. B lineage cells lacking the related transcription factors IRF-4 and IRF-8 undergo a developmental arrest at the cycling pre-B cell stage and are blocked for light-chain recombination. Using Irf-4,8-/- pre-B cells we demonstrate that two pathways converge to synergistically drive light-chain rearrangement, a process that is not simply activated by cell cycle exit. One pathway is directly dependent on IRF-4, whose expression is elevated by pre-BCR signaling. IRF-4 targets the κ 3′ and λ enhancers to increase locus accessibility and positions a kappa allele away from pericentromeric heterochromatin. The other pathway is triggered by attenuation of IL-7 signaling and results in activation of the κ intronic enhancer via binding of the transcription factor, E2A. Intriguingly, IRF-4 regulates the expression of CXCR4 and promotes the migration of pre-B cells in response to the chemokine CXCL12. We propose that IRF-4 coordinates the two pathways regulating light-chain recombination by positioning pre-B cells away from IL-7 expressing stromal cells. We used microarrys to identify the changes in gene expression under different levels of the cytokine IL-7 and after rescue of genetic defect.

Standard name | GSE10273_HIGH_VS_LOW_IL7_TREATED_IRF4_8_NULL_PRE_BCELL_DN
Systematic name | M316
Organism | Mus musculus
PMID | 18280186
Authors | Johnson K,Hashimshony T,Sawai CM,Pongubala JM,Skok JA,Aifantis I,Singh H
Category | C7
Sub-category |
Brief description | Genes down-regulated in IRF4 and IRF8 [GeneID=3662;3394] null pre-B cells treated with IL7 [GeneID=3574]: 5 ng/ml versus 0.25ng/ml.
Full description | Productive rearrangement of the immunoglobulin heavy chain locus triggers a major developmental checkpoint that promotes limited clonal expansion of pre-B cells, culminating in cell cycle arrest and rearrangement of the kappa (κ) or lambda (λ) light-chain loci. B lineage cells lacking the related transcription factors IRF-4 and IRF-8 undergo a developmental arrest at the cycling pre-B cell stage and are blocked for light-chain recombination. Using Irf-4,8-/- pre-B cells we demonstrate that two pathways converge to synergistically drive light-chain rearrangement, a process that is not simply activated by cell cycle exit. One pathway is directly dependent on IRF-4, whose expression is elevated by pre-BCR signaling. IRF-4 targets the κ 3′ and λ enhancers to increase locus accessibility and positions a kappa allele away from pericentromeric heterochromatin. The other pathway is triggered by attenuation of IL-7 signaling and results in activation of the κ intronic enhancer via binding of the transcription factor, E2A. Intriguingly, IRF-4 regulates the expression of CXCR4 and promotes the migration of pre-B cells in response to the chemokine CXCL12. We propose that IRF-4 coordinates the two pathways regulating light-chain recombination by positioning pre-B cells away from IL-7 expressing stromal cells. We used microarrys to identify the changes in gene expression under different levels of the cytokine IL-7 and after rescue of genetic defect.

Standard name | GSE10273_HIGH_IL7_VS_HIGH_IL7_AND_IRF4_IN_IRF4_8_NULL_PRE_BCELL_DN
Systematic name | M317
Organism | Mus musculus
PMID | 18280186
Authors | Johnson K,Hashimshony T,Sawai CM,Pongubala JM,Skok JA,Aifantis I,Singh H
Category | C7
Sub-category |
Brief description | Genes down-regulated in IRF4 and IRF8 [GeneID=3662;3394] null pre-B cell treated with 5ng/ml IL7 [GeneID=3574] versus those transduced with IRF4 [GeneID=3662].
Full description | Productive rearrangement of the immunoglobulin heavy chain locus triggers a major developmental checkpoint that promotes limited clonal expansion of pre-B cells, culminating in cell cycle arrest and rearrangement of the kappa (κ) or lambda (λ) light-chain loci. B lineage cells lacking the related transcription factors IRF-4 and IRF-8 undergo a developmental arrest at the cycling pre-B cell stage and are blocked for light-chain recombination. Using Irf-4,8-/- pre-B cells we demonstrate that two pathways converge to synergistically drive light-chain rearrangement, a process that is not simply activated by cell cycle exit. One pathway is directly dependent on IRF-4, whose expression is elevated by pre-BCR signaling. IRF-4 targets the κ 3′ and λ enhancers to increase locus accessibility and positions a kappa allele away from pericentromeric heterochromatin. The other pathway is triggered by attenuation of IL-7 signaling and results in activation of the κ intronic enhancer via binding of the transcription factor, E2A. Intriguingly, IRF-4 regulates the expression of CXCR4 and promotes the migration of pre-B cells in response to the chemokine CXCL12. We propose that IRF-4 coordinates the two pathways regulating light-chain recombination by positioning pre-B cells away from IL-7 expressing stromal cells. We used microarrys to identify the changes in gene expression under different levels of the cytokine IL-7 and after rescue of genetic defect.

Standard name | GSE10273_HIGH_VS_LOW_IL7_TREATED_IRF4_8_NULL_PRE_BCELL_UP
Systematic name | M318
Organism | Mus musculus
PMID | 18280186
Authors | Johnson K,Hashimshony T,Sawai CM,Pongubala JM,Skok JA,Aifantis I,Singh H
Category | C7
Sub-category |
Brief description | Genes up-regulated in IRF4 and IRF8 [GeneID=3662;3394] null pre-B cells treated with IL7 [GeneID=3574]: 5 ng/ml versus 0.25ng/ml.
Full description | Productive rearrangement of the immunoglobulin heavy chain locus triggers a major developmental checkpoint that promotes limited clonal expansion of pre-B cells, culminating in cell cycle arrest and rearrangement of the kappa (κ) or lambda (λ) light-chain loci. B lineage cells lacking the related transcription factors IRF-4 and IRF-8 undergo a developmental arrest at the cycling pre-B cell stage and are blocked for light-chain recombination. Using Irf-4,8-/- pre-B cells we demonstrate that two pathways converge to synergistically drive light-chain rearrangement, a process that is not simply activated by cell cycle exit. One pathway is directly dependent on IRF-4, whose expression is elevated by pre-BCR signaling. IRF-4 targets the κ 3′ and λ enhancers to increase locus accessibility and positions a kappa allele away from pericentromeric heterochromatin. The other pathway is triggered by attenuation of IL-7 signaling and results in activation of the κ intronic enhancer via binding of the transcription factor, E2A. Intriguingly, IRF-4 regulates the expression of CXCR4 and promotes the migration of pre-B cells in response to the chemokine CXCL12. We propose that IRF-4 coordinates the two pathways regulating light-chain recombination by positioning pre-B cells away from IL-7 expressing stromal cells. We used microarrys to identify the changes in gene expression under different levels of the cytokine IL-7 and after rescue of genetic defect.

Standard name | GSE10273_HIGH_IL7_VS_HIGH_IL7_AND_IRF4_IN_IRF4_8_NULL_PRE_BCELL_UP
Systematic name | M320
Organism | Mus musculus
PMID | 18280186
Authors | Johnson K,Hashimshony T,Sawai CM,Pongubala JM,Skok JA,Aifantis I,Singh H
Category | C7
Sub-category |
Brief description | Genes up-regulated in IRF4 and IRF8 [GeneID=3662;3394] null pre-B cell treated with 5ng/ml IL7 [GeneID=3574] versus those transduced with IRF4 [GeneID=3662].
Full description | Productive rearrangement of the immunoglobulin heavy chain locus triggers a major developmental checkpoint that promotes limited clonal expansion of pre-B cells, culminating in cell cycle arrest and rearrangement of the kappa (κ) or lambda (λ) light-chain loci. B lineage cells lacking the related transcription factors IRF-4 and IRF-8 undergo a developmental arrest at the cycling pre-B cell stage and are blocked for light-chain recombination. Using Irf-4,8-/- pre-B cells we demonstrate that two pathways converge to synergistically drive light-chain rearrangement, a process that is not simply activated by cell cycle exit. One pathway is directly dependent on IRF-4, whose expression is elevated by pre-BCR signaling. IRF-4 targets the κ 3′ and λ enhancers to increase locus accessibility and positions a kappa allele away from pericentromeric heterochromatin. The other pathway is triggered by attenuation of IL-7 signaling and results in activation of the κ intronic enhancer via binding of the transcription factor, E2A. Intriguingly, IRF-4 regulates the expression of CXCR4 and promotes the migration of pre-B cells in response to the chemokine CXCL12. We propose that IRF-4 coordinates the two pathways regulating light-chain recombination by positioning pre-B cells away from IL-7 expressing stromal cells. We used microarrys to identify the changes in gene expression under different levels of the cytokine IL-7 and after rescue of genetic defect.

Standard name | GSE10273_LOW_IL7_VS_HIGH_IL7_AND_IRF4_IN_IRF4_8_NULL_PRE_BCELL_DN
Systematic name | M322
Organism | Mus musculus
PMID | 18280186
Authors | Johnson K,Hashimshony T,Sawai CM,Pongubala JM,Skok JA,Aifantis I,Singh H
Category | C7
Sub-category |
Brief description | Genes down-regulated in IRF4 and IRF8 [GeneID=3662;3394] null pre-B cells treated with 0.25 ng/ml IL7 [GeneID=3574] versus the cells treated with 5 ng/ml IL7 [GeneID=3574] and transduced with IRF4 [GeneID=3662].
Full description | Productive rearrangement of the immunoglobulin heavy chain locus triggers a major developmental checkpoint that promotes limited clonal expansion of pre-B cells, culminating in cell cycle arrest and rearrangement of the kappa (κ) or lambda (λ) light-chain loci. B lineage cells lacking the related transcription factors IRF-4 and IRF-8 undergo a developmental arrest at the cycling pre-B cell stage and are blocked for light-chain recombination. Using Irf-4,8-/- pre-B cells we demonstrate that two pathways converge to synergistically drive light-chain rearrangement, a process that is not simply activated by cell cycle exit. One pathway is directly dependent on IRF-4, whose expression is elevated by pre-BCR signaling. IRF-4 targets the κ 3′ and λ enhancers to increase locus accessibility and positions a kappa allele away from pericentromeric heterochromatin. The other pathway is triggered by attenuation of IL-7 signaling and results in activation of the κ intronic enhancer via binding of the transcription factor, E2A. Intriguingly, IRF-4 regulates the expression of CXCR4 and promotes the migration of pre-B cells in response to the chemokine CXCL12. We propose that IRF-4 coordinates the two pathways regulating light-chain recombination by positioning pre-B cells away from IL-7 expressing stromal cells. We used microarrys to identify the changes in gene expression under different levels of the cytokine IL-7 and after rescue of genetic defect.

Standard name | GSE8685_IL2_STARVED_VS_IL2_ACT_IL2_STARVED_CD4_TCELL_UP
Systematic name | M324
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Sez-2 cells (T cell lymphoma): untreated versus IL2 [GeneID=3558].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL2_STARVED_VS_IL2_ACT_IL2_STARVED_CD4_TCELL_DN
Systematic name | M325
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Sez-2 cells (T cell lymphoma): untreated versus IL2 [GeneID=3558].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL2_STARVED_VS_IL15_ACT_IL2_STARVED_CD4_TCELL_UP
Systematic name | M326
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Sez-2 cells (T cell lymphoma): untreated versus IL5 [GeneID=3567].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL2_STARVED_VS_IL15_ACT_IL2_STARVED_CD4_TCELL_DN
Systematic name | M327
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Sez-2 cells (T cell lymphoma): untreated versus IL5 [GeneID=3567].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL2_STARVED_VS_IL21_ACT_IL2_STARVED_CD4_TCELL_UP
Systematic name | M328
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Sez-2 cells (T cell lymphoma): untreated versus IL21 [GeneID=59067].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL2_STARVED_VS_IL21_ACT_IL2_STARVED_CD4_TCELL_DN
Systematic name | M330
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Sez-2 cells (T cell lymphoma): untreated versus IL21 [GeneID=59067].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL2_ACT_IL2_STARVED_VS_IL15_ACT_IL2_STARVED_CD4_TCELL_UP
Systematic name | M331
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Sez-2 cells (T cell lymphoma): untreated versus IL15 [GeneID=3600].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL2_ACT_IL2_STARVED_VS_IL15_ACT_IL2_STARVED_CD4_TCELL_DN
Systematic name | M332
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Sez-2 cells (T cell lymphoma): untreated versus IL15 [GeneID=3600].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL2_ACT_IL2_STARVED_VS_IL21_ACT_IL2_STARVED_CD4_TCELL_UP
Systematic name | M333
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Sez-2 cells (T cell lymphoma): IL2 [GeneID=3558] versus IL21 [GeneID=59067].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL2_ACT_IL2_STARVED_VS_IL21_ACT_IL2_STARVED_CD4_TCELL_DN
Systematic name | M335
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Sez-2 cells (T cell lymphoma): IL2 [GeneID=3558] versus IL21 [GeneID=59067].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL15_ACT_IL2_STARVED_VS_IL21_ACT_IL2_STARVED_CD4_TCELL_UP
Systematic name | M337
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in Sez-2 cells (T cell lymphoma): IL15 [GeneID=3600] versus IL21 [GeneID=3600].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE8685_IL15_ACT_IL2_STARVED_VS_IL21_ACT_IL2_STARVED_CD4_TCELL_DN
Systematic name | M338
Organism | Homo sapiens
PMID | 18281483
Authors | Marzec M,Halasa K,Kasprzycka M,Wysocka M,Liu X,Tobias JW,Baldwin D,Zhang Q,Odum N,Rook AH,Wasik MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in Sez-2 cells (T cell lymphoma): IL15 [GeneID=3600] versus IL21 [GeneID=3600].
Full description | In this study we compared the effects of IL-2, IL-15, and IL-21 on the gene expression, activation of cell signaling pathways, and functional properties of cells derived from the CD4+ cutaneous T-cell lymphoma (CTCL). Whereas both IL-2 and IL-15 that signal through receptors that share the common gamma chain and the beta chain modulated the expression of >1,000 genes, IL-21 that signals via the receptor also containing gamma chain up-regulated <40 genes. All three cytokines induced tyrosine phosphorylation of Jak1 and Jak3. However, only IL-2 and IL-15 strongly activated STAT5, PI3K/Akt, and MEK/ERK signaling pathways. In contrast, IL-21 selectively activated STAT3. Whereas all three cytokines protected CTCL cells from apoptosis, only IL-2 and IL-15 promoted their proliferation. The effects of the cytokine stimulation were Jak3- and Jak1-kinase dependent. These findings document the vastly different impact of IL-2 and IL-15 vs. IL-21 on malignant CD4+ T cells. They also suggest two novel therapeutic approaches to CTCL and, possibly, other CD4+ T cell lymphomas: inhibition of the Jak1/Jak3 kinase complex and, given the known strong immunostimulatory properties of IL-21 on CD8+ T, NK, and B cells, application of this cytokine to boost an immune response against malignant CD4+ T cells.

Standard name | GSE7596_AKT_TRANSD_VS_CTRL_CD4_TCONV_WITH_TGFB_UP
Systematic name | M339
Organism | Mus musculus
PMID | 18283119
Authors | Haxhinasto S,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv in response to TGF-beta: expressing constantly active form of AKT1 [GeneID=207] versus control.
Full description | The CD4+Foxp3+ regulatory T cells play an essential role in maintaining tolerance via their suppressive function on conventional T cells. The intracellular signaling pathways that regulate Foxp3 expression are largely unknown. In this study we describe a novel inhibitory role for AKT in regulating de novo induction of Foxp3 both in vivo and in vitro. A constitutively active allele of AKT significantly diminished TGF-â induced Foxp3 induction via a rapamycin-sensitive pathway, establishing a role for the AKT-mTOR axis in Treg cells. Moreover, the observed impairment in Foxp3 induction was paralleled by a selective downmodulation of the imparted Treg transcriptional signature highlighting the importance of the balance of intracellular signals in Treg differentiation . Our results provide a basis for further elucidation of molecular mechanisms that regulate Foxp3 induction and identify AKT as an important negative regulator of this process.

Standard name | GSE7596_AKT_TRANSD_VS_CTRL_CD4_TCONV_WITH_TGFB_DN
Systematic name | M340
Organism | Mus musculus
PMID | 18283119
Authors | Haxhinasto S,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv in response to TGF-beta: expressing constantly active form of AKT1 [GeneID=207] versus control.
Full description | The CD4+Foxp3+ regulatory T cells play an essential role in maintaining tolerance via their suppressive function on conventional T cells. The intracellular signaling pathways that regulate Foxp3 expression are largely unknown. In this study we describe a novel inhibitory role for AKT in regulating de novo induction of Foxp3 both in vivo and in vitro. A constitutively active allele of AKT significantly diminished TGF-â induced Foxp3 induction via a rapamycin-sensitive pathway, establishing a role for the AKT-mTOR axis in Treg cells. Moreover, the observed impairment in Foxp3 induction was paralleled by a selective downmodulation of the imparted Treg transcriptional signature highlighting the importance of the balance of intracellular signals in Treg differentiation . Our results provide a basis for further elucidation of molecular mechanisms that regulate Foxp3 induction and identify AKT as an important negative regulator of this process.

Standard name | GSE10211_UV_INACT_SENDAI_VS_LIVE_SENDAI_VIRUS_TRACHEAL_EPITHELIAL_CELLS_DN
Systematic name | M341
Organism | Mus musculus
PMID | 18292557
Authors | Shornick LP,Wells AG,Zhang Y,Patel AC,Huang G,Takami K,Sosa M,Shukla NA,Agapov E,Holtzman MJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in tracheal epithelial cells infected with UV inactivated versus intact Sendai virus.
Full description | Oligonucleotide microarrays were used to establish a profile for gene expression in wild-type airway epithelial cells after paramyxoviral infection. Analysis was performed on mRNA isolated from SeV-infected primary-culture mouse tracheal epithelial cells that were maintained under physiologic conditions (air-liquid interface).

Standard name | GSE10211_UV_INACT_SENDAI_VS_LIVE_SENDAI_VIRUS_TRACHEAL_EPITHELIAL_CELLS_UP
Systematic name | M343
Organism | Mus musculus
PMID | 18292557
Authors | Shornick LP,Wells AG,Zhang Y,Patel AC,Huang G,Takami K,Sosa M,Shukla NA,Agapov E,Holtzman MJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in tracheal epithelial cells infected with UV inactivated versus intact Sendai virus.
Full description | Oligonucleotide microarrays were used to establish a profile for gene expression in wild-type airway epithelial cells after paramyxoviral infection. Analysis was performed on mRNA isolated from SeV-infected primary-culture mouse tracheal epithelial cells that were maintained under physiologic conditions (air-liquid interface).

Standard name | GSE10147_IL3_VS_IL3_AND_HIVP17_STIM_PDC_UP
Systematic name | M344
Organism | Homo sapiens
PMID | 18310327
Authors | Fiorentini S,Riboldi E,Facchetti F,Avolio M,Fabbri M,Tosti G,Becker PD,Guzman CA,Sozzani S,Caruso A
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells: IL3 [GeneID=3562] versus IL3 [GeneID=3562] and the HIV matrix protein p17.
Full description | We used microarrays to detail the global program of gene expression underlying the effect of p17 on human plasmacytoid dendritic cells and was compared to CpG profile.

Standard name | GSE10147_IL3_VS_IL3_AND_HIVP17_STIM_PDC_DN
Systematic name | M345
Organism | Homo sapiens
PMID | 18310327
Authors | Fiorentini S,Riboldi E,Facchetti F,Avolio M,Fabbri M,Tosti G,Becker PD,Guzman CA,Sozzani S,Caruso A
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells: IL3 [GeneID=3562] versus IL3 [GeneID=3562] and the HIV matrix protein p17.
Full description | We used microarrays to detail the global program of gene expression underlying the effect of p17 on human plasmacytoid dendritic cells and was compared to CpG profile.

Standard name | GSE10147_IL3_VS_IL3_AND_CPG_STIM_PDC_UP
Systematic name | M348
Organism | Homo sapiens
PMID | 18310327
Authors | Fiorentini S,Riboldi E,Facchetti F,Avolio M,Fabbri M,Tosti G,Becker PD,Guzman CA,Sozzani S,Caruso A
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells: IL3 [GeneID=3562] versus IL3 [GeneID=3562] and CpG.
Full description | We used microarrays to detail the global program of gene expression underlying the effect of p17 on human plasmacytoid dendritic cells and was compared to CpG profile.

Standard name | GSE10147_IL3_AND_HIVP17_VS_IL3_AND_CPG_STIM_PDC_DN
Systematic name | M350
Organism | Homo sapiens
PMID | 18310327
Authors | Fiorentini S,Riboldi E,Facchetti F,Avolio M,Fabbri M,Tosti G,Becker PD,Guzman CA,Sozzani S,Caruso A
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells treated with IL3 [GeneID=3562]: HIV matrix protein p17 versus CpG.
Full description | We used microarrays to detail the global program of gene expression underlying the effect of p17 on human plasmacytoid dendritic cells and was compared to CpG profile.

Standard name | GSE10147_IL3_AND_HIVP17_VS_IL3_AND_CPG_STIM_PDC_UP
Systematic name | M351
Organism | Homo sapiens
PMID | 18310327
Authors | Fiorentini S,Riboldi E,Facchetti F,Avolio M,Fabbri M,Tosti G,Becker PD,Guzman CA,Sozzani S,Caruso A
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells treated with IL3 [GeneID=3562]: HIV matrix protein p17 versus CpG.
Full description | We used microarrays to detail the global program of gene expression underlying the effect of p17 on human plasmacytoid dendritic cells and was compared to CpG profile.

Standard name | GSE10147_IL3_VS_IL3_AND_CPG_STIM_PDC_DN
Systematic name | M353
Organism | Homo sapiens
PMID | 18310327
Authors | Fiorentini S,Riboldi E,Facchetti F,Avolio M,Fabbri M,Tosti G,Becker PD,Guzman CA,Sozzani S,Caruso A
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells: IL3 [GeneID=3562] versus IL3 [GeneID=3562] and CpG.
Full description | We used microarrays to detail the global program of gene expression underlying the effect of p17 on human plasmacytoid dendritic cells and was compared to CpG profile.

Standard name | GSE10422_WT_VS_BAFF_TRANSGENIC_LN_BCELL_DN
Systematic name | M354
Organism | Mus musculus
PMID | 18313334
Authors | Gardam S,Sierro F,Basten A,Mackay F,Brink R
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype B cells versus BAFF-transgenic (over-express TNFSF13B [GeneID=10673]) B cells from lymph node.
Full description | Tumor necrosis factor-associated factors 2 and 3 (TRAF2 and TRAF3) were shown to function in a co-operative and non-redundant manner to suppress nuclear factor-κB2 (NF-κB2) activation, gene expression and survival in mature B cells. In the absence of this suppressive activity, B cells developed independently of the obligatory B cell survival factor, BAFF (B cell activating factor of the tumor necrosis factor family). This constitutive, lineage-specific suppression of B cell survival by TRAF2 and TRAF3 determines the requirement for BAFF to sustain B cell development in vivo. We wished to investigate the effect on gene expression in B cells which lacked the negative regulators TRAF2 and TRAF3, and hence had hyperactive NF-kB2 signalling. As Baff-tg mice display a similar phenotype, and have a genetic modification which acts in the same pathway, yet further up, than TRAF2 and TRAF3, we wished to compare and contrast Baff-tg B cells with TRAF2 and TRAF3 deficient B cells. This analysis should identify genes that are important in B cell survival.

Standard name | GSE10422_WT_VS_BAFF_TRANSGENIC_LN_BCELL_UP
Systematic name | M357
Organism | Mus musculus
PMID | 18313334
Authors | Gardam S,Sierro F,Basten A,Mackay F,Brink R
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype B cells versus BAFF-transgenic (over-express TNFSF13B [GeneID=10673]) B cells from lymph node.
Full description | Tumor necrosis factor-associated factors 2 and 3 (TRAF2 and TRAF3) were shown to function in a co-operative and non-redundant manner to suppress nuclear factor-κB2 (NF-κB2) activation, gene expression and survival in mature B cells. In the absence of this suppressive activity, B cells developed independently of the obligatory B cell survival factor, BAFF (B cell activating factor of the tumor necrosis factor family). This constitutive, lineage-specific suppression of B cell survival by TRAF2 and TRAF3 determines the requirement for BAFF to sustain B cell development in vivo. We wished to investigate the effect on gene expression in B cells which lacked the negative regulators TRAF2 and TRAF3, and hence had hyperactive NF-kB2 signalling. As Baff-tg mice display a similar phenotype, and have a genetic modification which acts in the same pathway, yet further up, than TRAF2 and TRAF3, we wished to compare and contrast Baff-tg B cells with TRAF2 and TRAF3 deficient B cells. This analysis should identify genes that are important in B cell survival.

Standard name | GSE10500_ARTHRITIC_SYNOVIAL_FLUID_VS_HEALTHY_MACROPHAGE_UP
Systematic name | M358
Organism | Homo sapiens
PMID | 18345002
Authors | Yarilina A,Park-Min KH,Antoniv T,Hu X,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages from patients with synovial fluid rheumatoid arthritis versus monocyte-derived macrophages from healthy persons.
Full description | Macrophages from RA synovial fluids were compared to primary human blood-derived macrophages.

Standard name | GSE10500_ARTHRITIC_SYNOVIAL_FLUID_VS_HEALTHY_MACROPHAGE_DN
Systematic name | M359
Organism | Homo sapiens
PMID | 18345002
Authors | Yarilina A,Park-Min KH,Antoniv T,Hu X,Ivashkiv LB
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages from patients with synovial fluid rheumatoid arthritis versus monocyte-derived macrophages from healthy persons.
Full description | Macrophages from RA synovial fluids were compared to primary human blood-derived macrophages.

Standard name | GSE7568_CTRL_VS_3H_TGFB_TREATED_MACROPHAGES_WITH_IL4_AND_DEXAMETHASONE_UP
Systematic name | M360
Organism | Homo sapiens
PMID | 18453574
Authors | Gratchev A,Kzhyshkowska J,Kannookadan S,Ochsenreiter M,Popova A,Yu X,Mamidi S,Stonehouse-Usselmann E,Muller-Molinet I,Gooi L,Goerdt S
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages differentiated in the presence of IL4 [GeneID=3565] and dexamethasone [PubChem=5743] for 5 days versus those subsequently treated with TGFB1 [GeneID=7040] for 3h.
Full description | The goal of the study was to identify the effects of TGF-beta on primary human macrophages maturated under different conditions.

Standard name | GSE7568_CTRL_VS_3H_TGFB_TREATED_MACROPHAGES_WITH_IL4_AND_DEXAMETHASONE_DN
Systematic name | M361
Organism | Homo sapiens
PMID | 18453574
Authors | Gratchev A,Kzhyshkowska J,Kannookadan S,Ochsenreiter M,Popova A,Yu X,Mamidi S,Stonehouse-Usselmann E,Muller-Molinet I,Gooi L,Goerdt S
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages differentiated in the presence of IL4 [GeneID=3565] and dexamethasone [PubChem=5743] for 5 days versus those subsequently treated with TGFB1 [GeneID=7040] for 3h.
Full description | The goal of the study was to identify the effects of TGF-beta on primary human macrophages maturated under different conditions.

Standard name | GSE7568_CTRL_VS_24H_TGFB_TREATED_MACROPHAGES_WITH_IL4_AND_DEXAMETHASONE_UP
Systematic name | M363
Organism | Homo sapiens
PMID | 18453574
Authors | Gratchev A,Kzhyshkowska J,Kannookadan S,Ochsenreiter M,Popova A,Yu X,Mamidi S,Stonehouse-Usselmann E,Muller-Molinet I,Gooi L,Goerdt S
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages differentiated in the presence of IL4 [GeneID=3565] and dexamethasone [PubChem=5743] for 5 days versus those subsequently treated with TGFB1 [GeneID=7040] for 24h.
Full description | The goal of the study was to identify the effects of TGF-beta on primary human macrophages maturated under different conditions.

Standard name | GSE7568_CTRL_VS_24H_TGFB_TREATED_MACROPHAGES_WITH_IL4_AND_DEXAMETHASONE_DN
Systematic name | M364
Organism | Homo sapiens
PMID | 18453574
Authors | Gratchev A,Kzhyshkowska J,Kannookadan S,Ochsenreiter M,Popova A,Yu X,Mamidi S,Stonehouse-Usselmann E,Muller-Molinet I,Gooi L,Goerdt S
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages differentiated in the presence of IL4 [GeneID=3565] and dexamethasone [PubChem=5743] for 5 days versus those subsequently treated with TGFB1 [GeneID=7040] for 24h.
Full description | The goal of the study was to identify the effects of TGF-beta on primary human macrophages maturated under different conditions.

Standard name | GSE7568_IL4_VS_IL4_AND_TGFB_TREATED_MACROPHAGE_24H_UP
Systematic name | M365
Organism | Homo sapiens
PMID | 18453574
Authors | Gratchev A,Kzhyshkowska J,Kannookadan S,Ochsenreiter M,Popova A,Yu X,Mamidi S,Stonehouse-Usselmann E,Muller-Molinet I,Gooi L,Goerdt S
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages differentiated in the presence of IL4 [GeneID=3565] for 5 days versus those subsequently treated with TGFB1 [GeneID=7040] for 24h.
Full description | The goal of the study was to identify the effects of TGF-beta on primary human macrophages maturated under different conditions.

Standard name | GSE7568_IL4_VS_IL4_AND_TGFB_TREATED_MACROPHAGE_24H_DN
Systematic name | M367
Organism | Homo sapiens
PMID | 18453574
Authors | Gratchev A,Kzhyshkowska J,Kannookadan S,Ochsenreiter M,Popova A,Yu X,Mamidi S,Stonehouse-Usselmann E,Muller-Molinet I,Gooi L,Goerdt S
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages differentiated in the presence of IL4 [GeneID=3565] for 5 days versus those subsequently treated with TGFB1 [GeneID=7040] for 24h.
Full description | The goal of the study was to identify the effects of TGF-beta on primary human macrophages maturated under different conditions.

Standard name | GSE7568_IL4_VS_IL4_AND_DEXAMETHASONE_TREATED_MACROPHAGE_UP
Systematic name | M368
Organism | Homo sapiens
PMID | 18453574
Authors | Gratchev A,Kzhyshkowska J,Kannookadan S,Ochsenreiter M,Popova A,Yu X,Mamidi S,Stonehouse-Usselmann E,Muller-Molinet I,Gooi L,Goerdt S
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages differentiated for 5 days in the presence of: IL4 [GeneID=3565] versus IL4 [GeneID=3565] and dexamethasone [PubChem=5743].
Full description | The goal of the study was to identify the effects of TGF-beta on primary human macrophages maturated under different conditions.

Standard name | GSE7568_IL4_VS_IL4_AND_DEXAMETHASONE_TREATED_MACROPHAGE_DN
Systematic name | M369
Organism | Homo sapiens
PMID | 18453574
Authors | Gratchev A,Kzhyshkowska J,Kannookadan S,Ochsenreiter M,Popova A,Yu X,Mamidi S,Stonehouse-Usselmann E,Muller-Molinet I,Gooi L,Goerdt S
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages differentiated for 5 days in the presence of: IL4 [GeneID=3565] versus IL4 [GeneID=3565] and dexamethasone [PubChem=5743].
Full description | The goal of the study was to identify the effects of TGF-beta on primary human macrophages maturated under different conditions.

Standard name | GSE7568_IL4_TGFB_DEXAMETHASONE_VS_IL4_TGFB_TREATED_MACROPHAGE_UP
Systematic name | M370
Organism | Homo sapiens
PMID | 18453574
Authors | Gratchev A,Kzhyshkowska J,Kannookadan S,Ochsenreiter M,Popova A,Yu X,Mamidi S,Stonehouse-Usselmann E,Muller-Molinet I,Gooi L,Goerdt S
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: 5 days with IL4 [GeneID=3565] and dexamethasone [PubChem=5743] followed by TGFB1 [GeneID=7040] for 24h versus 5 days with IL4 [GeneID=3565] followed by TGFB1 [GeneID=7040] for 24h.
Full description | The goal of the study was to identify the effects of TGF-beta on primary human macrophages maturated under different conditions.

Standard name | GSE7568_IL4_TGFB_DEXAMETHASONE_VS_IL4_TGFB_TREATED_MACROPHAGE_DN
Systematic name | M371
Organism | Homo sapiens
PMID | 18453574
Authors | Gratchev A,Kzhyshkowska J,Kannookadan S,Ochsenreiter M,Popova A,Yu X,Mamidi S,Stonehouse-Usselmann E,Muller-Molinet I,Gooi L,Goerdt S
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: 5 days with IL4 [GeneID=3565] and dexamethasone [PubChem=5743] followed by TGFB1 [GeneID=7040] for 24h versus 5 days with IL4 [GeneID=3565] followed by TGFB1 [GeneID=7040] for 24h.
Full description | The goal of the study was to identify the effects of TGF-beta on primary human macrophages maturated under different conditions.

Standard name | GSE11386_NAIVE_VS_MEMORY_BCELL_DN
Systematic name | M372
Organism | Mus musculus
PMID | 18566367
Authors | Tomayko MM,Anderson SM,Brayton CE,Sadanand S,Steinel NC,Behrens TW,Shlomchik MJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: naïve versus memory.
Full description | Memory B cells play essential roles in the maintenance of long-term immunity and may be important in the pathogenesis of autoimmune disease, but how these cells are distinguished from their naïve precursors is poorly understood. To address this, it would be important to understand how gene expression differs between memory and naive B cells in order to elucidate memory-specific functions. Using model systems that help overcome the lack of murine memory-specific markers and the low frequency of antigen-specific memory and naïve cells, we undertook a global comparison of gene expression between memory B cells and their naive precursors. 1st generation screen: These data represent our first generation comparison of gene expression between murine naïve and memory splenic B cells. Naïve NP-binding splenic B cells were FACS purified from unimmunized mVh186.2 transgenic Balb/c mice. Memory B cells were generated by immunizing mVh186.2 transgenic Balb/c mice with 2 doses of NP-CGG in alum delivered i.p. 6 weeks apart. After a minimum of 12-weeks rest, NP-binding splenic B cells were isolated by FACS. Total RNA was extracted, cRNA synthesized and labeled and hybridized to Affymetrix mouse 430 2.0 chips. 2nd generation screen: These data represent our second generation comparison of gene expression between murine naïve and memory splenic B cells. Naïve NP-binding AA4.1neg splenic B cells were FACS purified from unimmunized mVh186.2 transgenic Jk KO Balb/c mice. Memory B cells were generated from these naive precursors after adoptive transfer into recipients that mount poor endogenous NP-responses. 12-weeks post i.p. immunization with NP-CGG in alum, NP-specific splenic memory B cells were isolated by FACS. Total RNA was extracted, cRNA synthesized and labeled and hybridized to Affymetrix mouse 430 2.0 chips. Memory/Naïve comparison data linked below as Supplementary files.

Standard name | GSE11386_NAIVE_VS_MEMORY_BCELL_UP
Systematic name | M374
Organism | Mus musculus
PMID | 18566367
Authors | Tomayko MM,Anderson SM,Brayton CE,Sadanand S,Steinel NC,Behrens TW,Shlomchik MJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: naïve versus memory.
Full description | Memory B cells play essential roles in the maintenance of long-term immunity and may be important in the pathogenesis of autoimmune disease, but how these cells are distinguished from their naïve precursors is poorly understood. To address this, it would be important to understand how gene expression differs between memory and naive B cells in order to elucidate memory-specific functions. Using model systems that help overcome the lack of murine memory-specific markers and the low frequency of antigen-specific memory and naïve cells, we undertook a global comparison of gene expression between memory B cells and their naive precursors. 1st generation screen: These data represent our first generation comparison of gene expression between murine naïve and memory splenic B cells. Naïve NP-binding splenic B cells were FACS purified from unimmunized mVh186.2 transgenic Balb/c mice. Memory B cells were generated by immunizing mVh186.2 transgenic Balb/c mice with 2 doses of NP-CGG in alum delivered i.p. 6 weeks apart. After a minimum of 12-weeks rest, NP-binding splenic B cells were isolated by FACS. Total RNA was extracted, cRNA synthesized and labeled and hybridized to Affymetrix mouse 430 2.0 chips. 2nd generation screen: These data represent our second generation comparison of gene expression between murine naïve and memory splenic B cells. Naïve NP-binding AA4.1neg splenic B cells were FACS purified from unimmunized mVh186.2 transgenic Jk KO Balb/c mice. Memory B cells were generated from these naive precursors after adoptive transfer into recipients that mount poor endogenous NP-responses. 12-weeks post i.p. immunization with NP-CGG in alum, NP-specific splenic memory B cells were isolated by FACS. Total RNA was extracted, cRNA synthesized and labeled and hybridized to Affymetrix mouse 430 2.0 chips. Memory/Naïve comparison data linked below as Supplementary files.

Standard name | GSE7219_WT_VS_NIK_NFKB2_KO_DC_UP
Systematic name | M377
Organism | Mus musculus
PMID | 18566401
Authors | Lind EF,Ahonen CL,Wasiuk A,Kosaka Y,Becher B,Bennett KA,Noelle RJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: wildtype versus NFKB2 [GeneID=4791].
Full description | This study aims at identifying genes that are NIK/NF-kappaB2 responsive in murine dendritic cells matured in vivo.

Standard name | GSE7219_WT_VS_NIK_NFKB2_KO_DC_DN
Systematic name | M379
Organism | Mus musculus
PMID | 18566401
Authors | Lind EF,Ahonen CL,Wasiuk A,Kosaka Y,Becher B,Bennett KA,Noelle RJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: wildtype versus NFKB2 [GeneID=4791].
Full description | This study aims at identifying genes that are NIK/NF-kappaB2 responsive in murine dendritic cells matured in vivo.

Standard name | GSE7219_UNSTIM_VS_LPS_AND_ANTI_CD40_STIM_DC_UP
Systematic name | M380
Organism | Mus musculus
PMID | 18566401
Authors | Lind EF,Ahonen CL,Wasiuk A,Kosaka Y,Becher B,Bennett KA,Noelle RJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendric cells: untreated versus LPS and anti-CD40.
Full description | This study aims at identifying genes that are NIK/NF-kappaB2 responsive in murine dendritic cells matured in vivo.

Standard name | GSE7219_UNSTIM_VS_LPS_AND_ANTI_CD40_STIM_DC_DN
Systematic name | M381
Organism | Mus musculus
PMID | 18566401
Authors | Lind EF,Ahonen CL,Wasiuk A,Kosaka Y,Becher B,Bennett KA,Noelle RJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendric cells: untreated versus LPS and anti-CD40.
Full description | This study aims at identifying genes that are NIK/NF-kappaB2 responsive in murine dendritic cells matured in vivo.

Standard name | GSE7219_UNSTIM_VS_LPS_AND_ANTI_CD40_STIM_NIK_NFKB2_KO_DC_UP
Systematic name | M383
Organism | Mus musculus
PMID | 18566401
Authors | Lind EF,Ahonen CL,Wasiuk A,Kosaka Y,Becher B,Bennett KA,Noelle RJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cell NIK NFkB2-KO versus dendritic cell NIK NFkB2-KO LPS and anti-CD40 stimulated.
Full description | This study aims at identifying genes that are NIK/NF-kappaB2 responsive in murine dendritic cells matured in vivo.

Standard name | GSE7219_UNSTIM_VS_LPS_AND_ANTI_CD40_STIM_NIK_NFKB2_KO_DC_DN
Systematic name | M384
Organism | Mus musculus
PMID | 18566401
Authors | Lind EF,Ahonen CL,Wasiuk A,Kosaka Y,Becher B,Bennett KA,Noelle RJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cell NIK NFkB2-KO versus dendritic cell NIK NFkB2-KO LPS and anti-CD40 stimulated.
Full description | This study aims at identifying genes that are NIK/NF-kappaB2 responsive in murine dendritic cells matured in vivo.

Standard name | GSE7219_WT_VS_NIK_NFKB2_KO_LPS_AND_ANTI_CD40_STIM_DC_UP
Systematic name | M385
Organism | Mus musculus
PMID | 18566401
Authors | Lind EF,Ahonen CL,Wasiuk A,Kosaka Y,Becher B,Bennett KA,Noelle RJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cell wildtype LPS and anti-CD40 stimulated versus dendritic cell NIK NFkB2-KO LPS and anti-CD40 stimulated.
Full description | This study aims at identifying genes that are NIK/NF-kappaB2 responsive in murine dendritic cells matured in vivo.

Standard name | GSE7219_WT_VS_NIK_NFKB2_KO_LPS_AND_ANTI_CD40_STIM_DC_DN
Systematic name | M386
Organism | Mus musculus
PMID | 18566401
Authors | Lind EF,Ahonen CL,Wasiuk A,Kosaka Y,Becher B,Bennett KA,Noelle RJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cell wildtype LPS and anti-CD40 stimulated versus dendritic cell NIK NFkB2-KO LPS and anti-CD40 stimulated.
Full description | This study aims at identifying genes that are NIK/NF-kappaB2 responsive in murine dendritic cells matured in vivo.

Standard name | GSE12003_MIR223_KO_VS_WT_BM_PROGENITOR_4D_CULTURE_UP
Systematic name | M387
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes up-regulated in 4 day cultures of bone marrow progenitors: wildtype versus MIR223 [GeneID=407008] knockout.
Full description | This array analysis is to study developmental time course of the regulation of target messages’ expression during culture of murine neutrophils versus miR-223 null neutrophils. Culture media was SILAC-IMDM for MS analysis.

Standard name | GSE11973_MIR223_KOVS_WT_BONE_MARROW_NEUTROPHIL_UP
Systematic name | M388
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes up-regulated in neutrophils from MIR223 [GeneID=407008] bone marrow versus the wildtype cells.
Full description | This array analysis is to study the regulation of target messages’ expression in in vitro cultured murine neutrophils versus miR-223 null neutrophils. Culture media was SILAC-IMDM for MS analysis.

Standard name | GSE12003_MIR223_KO_VS_WT_BM_PROGENITOR_4D_CULTURE_DN
Systematic name | M390
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes down-regulated in 4 day cultures of bone marrow progenitors: wildtype versus MIR223 [GeneID=407008] knockout.
Full description | This array analysis is to study developmental time course of the regulation of target messages’ expression during culture of murine neutrophils versus miR-223 null neutrophils. Culture media was SILAC-IMDM for MS analysis.

Standard name | GSE12001_MIR223_KO_VS_WT_NEUTROPHIL_DN
Systematic name | M391
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes down-regulated in neutrophils: MIR223 [GeneID=407008] knockout versus wildtype.
Full description | This array analysis is to study the regulation of target messages’ expression in murine neutrophils versus miR-223 null neutrophils.

Standard name | GSE12003_MIR223_KO_VS_WT_BM_PROGENITOR_8D_CULTURE_DN
Systematic name | M392
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes down-regulated in 8 day cultures of bone marrow progenitors: wildtype versus MIR223 [GeneID=407008] knockout.
Full description | This array analysis is to study developmental time course of the regulation of target messages’ expression during culture of murine neutrophils versus miR-223 null neutrophils. Culture media was SILAC-IMDM for MS analysis.

Standard name | GSE11973_MIR223_KOVS_WT_BONE_MARROW_NEUTROPHIL_DN
Systematic name | M394
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes down-regulated in neutrophils from MIR223 [GeneID=407008] bone marrow versus the wildtype cells.
Full description | This array analysis is to study the regulation of target messages’ expression in in vitro cultured murine neutrophils versus miR-223 null neutrophils. Culture media was SILAC-IMDM for MS analysis.

Standard name | GSE12003_MIR223_KO_VS_WT_BM_PROGENITOR_8D_CULTURE_UP
Systematic name | M395
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes up-regulated in 8 day cultures of bone marrow progenitors: wildtype versus MIR223 [GeneID=407008] knockout.
Full description | This array analysis is to study developmental time course of the regulation of target messages’ expression during culture of murine neutrophils versus miR-223 null neutrophils. Culture media was SILAC-IMDM for MS analysis.

Standard name | GSE12001_MIR223_KO_VS_WT_NEUTROPHIL_UP
Systematic name | M396
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes up-regulated in neutrophils: MIR223 [GeneID=407008] knockout versus wildtype.
Full description | This array analysis is to study the regulation of target messages’ expression in murine neutrophils versus miR-223 null neutrophils.

Standard name | GSE12003_4D_VS_8D_CULTURE_BM_PROGENITOR_UP
Systematic name | M397
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes up-regulated in of bone marrow progenitors: 4- versus 8-day cultures.
Full description | This array analysis is to study developmental time course of the regulation of target messages’ expression during culture of murine neutrophils versus miR-223 null neutrophils. Culture media was SILAC-IMDM for MS analysis.

Standard name | GSE12003_4D_VS_8D_CULTURE_MIR223_KO_BM_PROGENITOR_DN
Systematic name | M403
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes down-regulated in of bone marrow progenitors with MIR223 [GeneID=407008] knockout: 4- versus 8-day cultures.
Full description | This array analysis is to study developmental time course of the regulation of target messages’ expression during culture of murine neutrophils versus miR-223 null neutrophils. Culture media was SILAC-IMDM for MS analysis.

Standard name | GSE12003_4D_VS_8D_CULTURE_MIR223_KO_BM_PROGENITOR_UP
Systematic name | M405
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes up-regulated in of bone marrow progenitors with MIR223 [GeneID=407008] knockout: 4- versus 8-day cultures.
Full description | This array analysis is to study developmental time course of the regulation of target messages’ expression during culture of murine neutrophils versus miR-223 null neutrophils. Culture media was SILAC-IMDM for MS analysis.

Standard name | GSE12003_4D_VS_8D_CULTURE_BM_PROGENITOR_DN
Systematic name | M406
Organism | Mus musculus
PMID | 18668037
Authors | Baek D,Villén J,Shin C,Camargo FD,Gygi SP,Bartel DP
Category | C7
Sub-category |
Brief description | Genes down-regulated in of bone marrow progenitors: 4- versus 8-day cultures.
Full description | This array analysis is to study developmental time course of the regulation of target messages’ expression during culture of murine neutrophils versus miR-223 null neutrophils. Culture media was SILAC-IMDM for MS analysis.

Standard name | GSE11884_WT_VS_FURIN_KO_NAIVE_CD4_TCELL_UP
Systematic name | M407
Organism | Mus musculus
PMID | 18701887
Authors | Pesu M,Watford WT,Wei L,Xu L,Fuss I,Strober W,Andersson J,Shevach EM,Quezado M,Bouladoux N,Roebroek A,Belkaid Y,Creemers J,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve wildtype CD4 [GeneID=920] T cells versus those from T cell specific FURIN [GeneID=5045] knockout mice.
Full description | Furin is a proprotein convertase induced in activated T cells, reported to processes the anti-inflammatory cytokine TGFb-1. Herein, we show that conditional deletion of furin in T cells allowed for normal T cell development but impaired the function of regulatory T cells and effector cells, which produced less TGFb-1. Furin-deficient Treg cells, were less protective in a T cell transfer colitis model and failed to induce Foxp3 in normal T cells. Furin-deficient effector cells were inherently overly active and were resistant to suppressive activity of wild-type Tregs. Thus, our results indicate that furin is indispensable in maintaining peripheral tolerance, which is due, at least in part, to its nonredundant, essential function in regulating TGFb-1 production. Targeting furin has emerged as a strategy in malignant and infectious disease. The current work suggests that inhibiting furin might activate immune responses, but may result in a breakdown in peripheral tolerance.

Standard name | GSE11884_WT_VS_FURIN_KO_NAIVE_CD4_TCELL_DN
Systematic name | M410
Organism | Mus musculus
PMID | 18701887
Authors | Pesu M,Watford WT,Wei L,Xu L,Fuss I,Strober W,Andersson J,Shevach EM,Quezado M,Bouladoux N,Roebroek A,Belkaid Y,Creemers J,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve wildtype CD4 [GeneID=920] T cells versus those from T cell specific FURIN [GeneID=5045] knockout mice.
Full description | Furin is a proprotein convertase induced in activated T cells, reported to processes the anti-inflammatory cytokine TGFb-1. Herein, we show that conditional deletion of furin in T cells allowed for normal T cell development but impaired the function of regulatory T cells and effector cells, which produced less TGFb-1. Furin-deficient Treg cells, were less protective in a T cell transfer colitis model and failed to induce Foxp3 in normal T cells. Furin-deficient effector cells were inherently overly active and were resistant to suppressive activity of wild-type Tregs. Thus, our results indicate that furin is indispensable in maintaining peripheral tolerance, which is due, at least in part, to its nonredundant, essential function in regulating TGFb-1 production. Targeting furin has emerged as a strategy in malignant and infectious disease. The current work suggests that inhibiting furin might activate immune responses, but may result in a breakdown in peripheral tolerance.

Standard name | GSE11818_WT_VS_DICER_KO_TREG_DN
Systematic name | M411
Organism | Mus musculus
PMID | 18725525
Authors | Zhou X,Jeker LT,Fife BT,Zhu S,Anderson MS,McManus MT,Bluestone JA
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: wildtype versus DICER1 [GeneID=23405] knockout.
Full description | A new Treg-specific, FoxP3-GFP-hCre BAC transgenic was crossed to a conditional Dicer knock-out mouse strain to analyze the role of microRNAs (miRNA) in the development and function of regulatory T cells (Tregs). Although thymic Tregs developed normally in this setting, the cells showed evidence of altered differentiation and dysfunction in the periphery. Dicer-deficient Treg lineage cells failed to remain stable as a subset of cells down-regulated the Treg-specific transcription factor, FoxP3, while the majority expressed altered levels of multiple genes and proteins (including Neuropilin 1, GITR and CTLA-4) associated with the Treg fingerprint. In fact, a significant percentage of the Treg lineage cells took on a Th memory phenotype including increased levels of CD127, IL-4, and interferon-g. Importantly, Dicer-deficient Tregs lost suppression activity in vivo; the mice rapidly developed fatal systemic autoimmune disease resembling the FoxP3 knockout phenotype. These results support a central role for miRNAs in maintaining the stability of differentiated Treg function in vivo and homeostasis of the adaptive immune system.

Standard name | GSE11818_WT_VS_DICER_KO_TREG_UP
Systematic name | M412
Organism | Mus musculus
PMID | 18725525
Authors | Zhou X,Jeker LT,Fife BT,Zhu S,Anderson MS,McManus MT,Bluestone JA
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: wildtype versus DICER1 [GeneID=23405] knockout.
Full description | A new Treg-specific, FoxP3-GFP-hCre BAC transgenic was crossed to a conditional Dicer knock-out mouse strain to analyze the role of microRNAs (miRNA) in the development and function of regulatory T cells (Tregs). Although thymic Tregs developed normally in this setting, the cells showed evidence of altered differentiation and dysfunction in the periphery. Dicer-deficient Treg lineage cells failed to remain stable as a subset of cells down-regulated the Treg-specific transcription factor, FoxP3, while the majority expressed altered levels of multiple genes and proteins (including Neuropilin 1, GITR and CTLA-4) associated with the Treg fingerprint. In fact, a significant percentage of the Treg lineage cells took on a Th memory phenotype including increased levels of CD127, IL-4, and interferon-g. Importantly, Dicer-deficient Tregs lost suppression activity in vivo; the mice rapidly developed fatal systemic autoimmune disease resembling the FoxP3 knockout phenotype. These results support a central role for miRNAs in maintaining the stability of differentiated Treg function in vivo and homeostasis of the adaptive immune system.

Standard name | GSE9946_IMMATURE_VS_MATURE_STIMULATORY_DC_UP
Systematic name | M415
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: immature versus mature stimulatory.
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_IMMATURE_VS_MATURE_STIMULATORY_DC_DN
Systematic name | M417
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: immature versus mature stimulatory.
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_IMMATURE_VS_LISTERIA_INF_MATURE_DC_UP
Systematic name | M418
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: immature versus mature inhibitory infected with L. monocytogenes.
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_IMMATURE_VS_LISTERIA_INF_MATURE_DC_DN
Systematic name | M420
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: immature versus mature inhibitory infected with L. monocytogenes.
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_IMMATURE_VS_PROSTAGLANDINE2_TREATED_MATURE_DC_UP
Systematic name | M421
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: immature versus mature inhibitory treated by prostaglandin E2 [PubChem=5280360].
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_IMMATURE_VS_PROSTAGLANDINE2_TREATED_MATURE_DC_DN
Systematic name | M422
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: immature versus mature inhibitory treated by prostaglandin E2 [PubChem=5280360].
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_MATURE_STIMULATORY_VS_LISTERIA_INF_MATURE_DC_UP
Systematic name | M423
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes up-regulated in mature dendritic cells: stimulatory versus inhibitory infected with L. monocytogenes.
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_MATURE_STIMULATORY_VS_LISTERIA_INF_MATURE_DC_DN
Systematic name | M425
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes down-regulated in mature dendritic cells: stimulatory versus inhibitory infected with L. monocytogenes.
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_MATURE_STIMULATORY_VS_PROSTAGLANDINE2_TREATED_MATURE_DC_UP
Systematic name | M428
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes up-regulated in mature dendritic cells: stimulatory versus inhibitory treated by prostaglandin E2 [PubChem=5280360].
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_MATURE_STIMULATORY_VS_PROSTAGLANDINE2_TREATED_MATURE_DC_DN
Systematic name | M429
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes down-regulated in mature dendritic cells: stimulatory versus inhibitory treated by prostaglandin E2 [PubChem=5280360].
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_LISTERIA_INF_MATURE_VS_PROSTAGLANDINE2_TREATED_MATURE_DC_UP
Systematic name | M430
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes up-regulated in mature inhibitory dendritic cells: L. monocytogenes infection versus prostaglandin E2 [PubChem=5280360].
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE9946_LISTERIA_INF_MATURE_VS_PROSTAGLANDINE2_TREATED_MATURE_DC_DN
Systematic name | M431
Organism | Homo sapiens
PMID | 18802101
Authors | Popov A,Driesen J,Abdullah Z,Wickenhauser C,Beyer M,Debey-Pascher S,Saric T,Kummer S,Takikawa O,Domann E,Chakraborty T,Krönke M,Utermöhlen O,Schultze JL
Category | C7
Sub-category |
Brief description | Genes down-regulated in mature inhibitory dendritic cells: L. monocytogenes infection versus prostaglandin E2 [PubChem=5280360].
Full description | Myeloid dendritic cells (DC) and macrophages play an important role in pathogen sensing and antimicrobial defense. Recently we demonstrated that infection of human DC with intracellular bacterium Listeria monocytogenes (L.monocytogenes) leads to the induction of the immunoinhibitory enzyme indoleamine 2,3-dioxygenase (Popov et al., J Clin Invest, 2006), while in the previous studies L.monocytogenes infection was associated with a rather stimulatory DC phenotype. To clarify this discrepancy we performed comparative microarray analysis of immature mo-DC (immDC), mature stimulatory mo-DC (matDC) and mature inhibitory DC either stimulated with prostaglandin E2 (PGE2-DC) or infected with L.monocytogenes (infDC). Studying infection of human myeloid DC with Listeria monocytogenes, we found out, that infected DC are modified by the pathogen to express multiple inhibitory molecules, including indoleamine 2,3-dioxygenase (IDO), cyclooxygenase-2, interleukin 10 and CD25, which acts on DC as IL-2 scavenger. All these inhibitory molecules, expressed on regulatory DC (DCreg), are strictly TNF-dependent and are in concert suppressing T-cell responses. Moreover, only DCreg can efficiently control the number of intracellular listeria, mostly by IDO-mediated mechanisms and by other factors, remaining to be identified. Analyzing publicly acessible data of transcriptional changes in DC and macrophages, infected by various pathogens and parasites (GEO, GSE360), we noticed that infection of these cells with Mycobacterium tuberculosis causes transcriptional response, comparable with the one caused by listeria in human DC. In fact, granuloma in tuberculosis and listeriosis in vivo are enriched for myeloid DC and macrophages characterized by regulatory phenotype. In summary, regulatory myeloid DC and macrophages may play a dual role during life-threatening granulomatous infections, such as tuberculosis: on one hand, regulatory myeloid cells promote pathogen containment by efficiently killing intracellular bacteria, on the other hand these cells inhibit granuloma-associated T cells and thereby might be involved in the retention of TNF-controlled granuloma integrity protecting the host from granuloma break-down and pathogen dissemination.

Standard name | GSE12484_HEALTHY_VS_PERIDONTITIS_NEUTROPHILS_DN
Systematic name | M432
Organism | Homo sapiens
PMID | 18832737
Authors | Wright HJ,Matthews JB,Chapple IL,Ling-Mountford N,Cooper PR
Category | C7
Sub-category |
Brief description | Genes down-regulated in neutrophils isolated from: healthy versus patients with peridontitis.
Full description | Peripheral blood neutrophils from periodontitis patients exhibit a hyper-reactive and hyper-active phenotype (collectively termed hyper-responsivity) in terms of production of reactive oxygen species (ROS) however the molecular basis for this observation is yet to be determined. Our objectives were to identify genes differentially expressed in hyper-responsive peripheral blood neutrophils from chronic periodontitis patients relative to periodontally healthy controls and use this data to identify potential contributory pathways to the hyper-responsive neutrophil phenotype.

Standard name | GSE12484_HEALTHY_VS_PERIDONTITIS_NEUTROPHILS_UP
Systematic name | M433
Organism | Homo sapiens
PMID | 18832737
Authors | Wright HJ,Matthews JB,Chapple IL,Ling-Mountford N,Cooper PR
Category | C7
Sub-category |
Brief description | Genes up-regulated in neutrophils isolated from: healthy versus patients with peridontitis.
Full description | Peripheral blood neutrophils from periodontitis patients exhibit a hyper-reactive and hyper-active phenotype (collectively termed hyper-responsivity) in terms of production of reactive oxygen species (ROS) however the molecular basis for this observation is yet to be determined. Our objectives were to identify genes differentially expressed in hyper-responsive peripheral blood neutrophils from chronic periodontitis patients relative to periodontally healthy controls and use this data to identify potential contributory pathways to the hyper-responsive neutrophil phenotype.

Standard name | GSE12707_AT16L1_HYPOMORPH_VS_WT_THYMUS_DN
Systematic name | M434
Organism | Mus musculus
PMID | 18849966
Authors | Cadwell K,Liu JY,Brown SL,Miyoshi H,Loh J,Lennerz JK,Kishi C,Kc W,Carrero JA,Hunt S,Stone CD,Brunt EM,Xavier RJ,Sleckman BP,Li E,Mizushima N,Stappenbeck TS,Virgin HW
Category | C7
Sub-category |
Brief description | Genes down-regulated in tymocytes: mutant (hypomorph) ATG16L1 [GeneID=55054] versus wildtype.
Full description | The aim of this study is to survey global gene expression of total thymocytes from wild-type mice and Atg16l1 mutant (hypomorph) mice.

Standard name | GSE12707_AT16L1_HYPOMORPH_VS_WT_THYMUS_UP
Systematic name | M436
Organism | Mus musculus
PMID | 18849966
Authors | Cadwell K,Liu JY,Brown SL,Miyoshi H,Loh J,Lennerz JK,Kishi C,Kc W,Carrero JA,Hunt S,Stone CD,Brunt EM,Xavier RJ,Sleckman BP,Li E,Mizushima N,Stappenbeck TS,Virgin HW
Category | C7
Sub-category |
Brief description | Genes up-regulated in tymocytes: mutant (hypomorph) ATG16L1 [GeneID=55054] versus wildtype.
Full description | The aim of this study is to survey global gene expression of total thymocytes from wild-type mice and Atg16l1 mutant (hypomorph) mice.

Standard name | GSE12505_WT_VS_E2_2_HET_PDC_UP
Systematic name | M437
Organism | Mus musculus
PMID | 18854153
Authors | Cisse B,Caton ML,Lehner M,Maeda T,Scheu S,Locksley R,Holmberg D,Zweier C,Hollander den NS,Kant SG,Holter W,Rauch A,Zhuang Y,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells: wildtype versus TCF4 [GeneID=6925] heterozygous knockout.
Full description | Analysis of expression profiles of pDCs from wild type and heterozygous E2-2 mice. Results show the control by E2-2 of the expression of pDC-enriched genes.

Standard name | GSE12507_PDC_CELL_LINE_VS_IMMATUE_T_CELL_LINE_UP
Systematic name | M438
Organism | Homo sapiens
PMID | 18854153
Authors | Cisse B,Caton ML,Lehner M,Maeda T,Scheu S,Locksley R,Holmberg D,Zweier C,Hollander den NS,Kant SG,Holter W,Rauch A,Zhuang Y,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in CAL1 cells (plasmacytoid dendritic cells) versus MOLT4 (immature T cells).
Full description | Analysis of expression profiles of human pDC cell line (CAL1) compared to an immature T cell line (MOLT4)

Standard name | GSE12505_WT_VS_E2_2_HET_PDC_DN
Systematic name | M439
Organism | Mus musculus
PMID | 18854153
Authors | Cisse B,Caton ML,Lehner M,Maeda T,Scheu S,Locksley R,Holmberg D,Zweier C,Hollander den NS,Kant SG,Holter W,Rauch A,Zhuang Y,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells: wildtype versus TCF4 [GeneID=6925] heterozygous knockout.
Full description | Analysis of expression profiles of pDCs from wild type and heterozygous E2-2 mice. Results show the control by E2-2 of the expression of pDC-enriched genes.

Standard name | GSE12507_PDC_CELL_LINE_VS_IMMATUE_T_CELL_LINE_DN
Systematic name | M440
Organism | Homo sapiens
PMID | 18854153
Authors | Cisse B,Caton ML,Lehner M,Maeda T,Scheu S,Locksley R,Holmberg D,Zweier C,Hollander den NS,Kant SG,Holter W,Rauch A,Zhuang Y,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in CAL1 cells (plasmacytoid dendritic cells) versus MOLT4 (immature T cells).
Full description | Analysis of expression profiles of human pDC cell line (CAL1) compared to an immature T cell line (MOLT4)

Standard name | GSE12839_CTRL_VS_IL12_TREATED_PBMC_DN
Systematic name | M441
Organism | Homo sapiens
PMID | 19001140
Authors | Watford WT,Hissong BD,Durant LR,Yamane H,Muul LM,Kanno Y,Tato CM,Ramos HL,Berger AE,Mielke L,Pesu M,Solomon B,Frucht DM,Paul WE,Sher A,Jankovic D,Tsichlis PN,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood monocytes (PBMC): control versus IL-12 stimulation.
Full description | The cytokine interleukin-12 (IL-12) is known to play a central role in adaptive and innate immunity. We employed microarray analysis of IL-12 induced gene expression to provide further insights into its effects on immune response.

Standard name | GSE12839_CTRL_VS_IL12_TREATED_PBMC_UP
Systematic name | M442
Organism | Homo sapiens
PMID | 19001140
Authors | Watford WT,Hissong BD,Durant LR,Yamane H,Muul LM,Kanno Y,Tato CM,Ramos HL,Berger AE,Mielke L,Pesu M,Solomon B,Frucht DM,Paul WE,Sher A,Jankovic D,Tsichlis PN,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood monocytes (PBMC): control versus IL-12 stimulation.
Full description | The cytokine interleukin-12 (IL-12) is known to play a central role in adaptive and innate immunity. We employed microarray analysis of IL-12 induced gene expression to provide further insights into its effects on immune response.

Standard name | GSE12963_UNINF_VS_ENV_AND_NEF_AND_VPR_DEFICIENT_HIV1_INF_CD4_TCELL_UP
Systematic name | M447
Organism | Homo sapiens
PMID | 19050264
Authors | Dabrowska A,Kim N,Aldovini A
Category | C7
Sub-category |
Brief description | Genes up-regulated in control CD4 [GeneID=920] T cells versus those infected with HIV-1 viruses lacking Env, Vpr and Nef.
Full description | The high mutation rate of HIV is linked to the generation of viruses expressing proteins with altered function whose impact on disease progression is unknown. We investigated the effects of HIV-1 viruses lacking Env, Vpr and Nef on CD4+ T cell gene expression using high-density DNA microarray analysis and functional assays.

Standard name | GSE12963_UNINF_VS_ENV_AND_NEF_AND_VPR_DEFICIENT_HIV1_INF_CD4_TCELL_DN
Systematic name | M448
Organism | Homo sapiens
PMID | 19050264
Authors | Dabrowska A,Kim N,Aldovini A
Category | C7
Sub-category |
Brief description | Genes down-regulated in control CD4 [GeneID=920] T cells versus those infected with HIV-1 viruses lacking Env, Vpr and Nef.
Full description | The high mutation rate of HIV is linked to the generation of viruses expressing proteins with altered function whose impact on disease progression is unknown. We investigated the effects of HIV-1 viruses lacking Env, Vpr and Nef on CD4+ T cell gene expression using high-density DNA microarray analysis and functional assays.

Standard name | GSE12963_UNINF_VS_ENV_AND_NEF_DEFICIENT_HIV1_INF_CD4_TCELL_UP
Systematic name | M449
Organism | Homo sapiens
PMID | 19050264
Authors | Dabrowska A,Kim N,Aldovini A
Category | C7
Sub-category |
Brief description | Genes up-regulated in control CD4 [GeneID=920] T cells versus those infected with HIV-1 viruses lacking Env and Nef.
Full description | The high mutation rate of HIV is linked to the generation of viruses expressing proteins with altered function whose impact on disease progression is unknown. We investigated the effects of HIV-1 viruses lacking Env, Vpr and Nef on CD4+ T cell gene expression using high-density DNA microarray analysis and functional assays.

Standard name | GSE12963_UNINF_VS_ENV_AND_NEF_DEFICIENT_HIV1_INF_CD4_TCELL_DN
Systematic name | M452
Organism | Homo sapiens
PMID | 19050264
Authors | Dabrowska A,Kim N,Aldovini A
Category | C7
Sub-category |
Brief description | Genes down-regulated in control CD4 [GeneID=920] T cell versus those infected with HIV-1 viruses lacking Env and Nef.
Full description | The high mutation rate of HIV is linked to the generation of viruses expressing proteins with altered function whose impact on disease progression is unknown. We investigated the effects of HIV-1 viruses lacking Env, Vpr and Nef on CD4+ T cell gene expression using high-density DNA microarray analysis and functional assays.

Standard name | GSE12963_ENV_NEF_VS_ENV_NEF_AND_VPR_DEFICIENT_HIV1_INF_CD4_TCELL_UP
Systematic name | M455
Organism | Homo sapiens
PMID | 19050264
Authors | Dabrowska A,Kim N,Aldovini A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells infected with Env/Nef deficient HIV-1 viruses versus those infected with HIV-1 viruses lacking Env, Nef and Vpr.
Full description | The high mutation rate of HIV is linked to the generation of viruses expressing proteins with altered function whose impact on disease progression is unknown. We investigated the effects of HIV-1 viruses lacking Env, Vpr and Nef on CD4+ T cell gene expression using high-density DNA microarray analysis and functional assays.

Standard name | GSE12963_ENV_NEF_VS_ENV_NEF_AND_VPR_DEFICIENT_HIV1_INF_CD4_TCELL_DN
Systematic name | M458
Organism | Homo sapiens
PMID | 19050264
Authors | Dabrowska A,Kim N,Aldovini A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells infected with Env/Nef deficient HIV-1 viruses versus those infected with HIV-1 viruses lacking Env, Nef and Vpr.
Full description | The high mutation rate of HIV is linked to the generation of viruses expressing proteins with altered function whose impact on disease progression is unknown. We investigated the effects of HIV-1 viruses lacking Env, Vpr and Nef on CD4+ T cell gene expression using high-density DNA microarray analysis and functional assays.

Standard name | GSE11367_CTRL_VS_IL17_TREATED_SMOOTH_MUSCLE_CELL_UP
Systematic name | M460
Organism | Homo sapiens
PMID | 19075290
Authors | Rao DA,Eid RE,Qin L,Yi T,Kirkiles-Smith NC,Tellides G,Pober JS
Category | C7
Sub-category |
Brief description | Genes up-regulated in vascular smooth muscle cells: control versus treated with IL17A [GeneID=3605].
Full description | Investigate the effect of recombinant human IL-17A on vascular smooth muscle cells cultured from human aortas.

Standard name | GSE11367_CTRL_VS_IL17_TREATED_SMOOTH_MUSCLE_CELL_DN
Systematic name | M461
Organism | Homo sapiens
PMID | 19075290
Authors | Rao DA,Eid RE,Qin L,Yi T,Kirkiles-Smith NC,Tellides G,Pober JS
Category | C7
Sub-category |
Brief description | Genes down-regulated in vascular smooth muscle cells: control versus treated with IL17A [GeneID=3605].
Full description | Investigate the effect of recombinant human IL-17A on vascular smooth muscle cells cultured from human aortas.

Standard name | GSE7459_UNTREATED_VS_IL6_TREATED_ACT_CD4_TCELL_UP
Systematic name | M462
Organism | Mus musculus
PMID | 19139170
Authors | Dienz O,Eaton SM,Bond JP,Neveu W,Moquin D,Noubade R,Briso EM,Charland C,Leonard WJ,Ciliberto G,Teuscher C,Haynes L,Rincon M
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: control versus IL6 [GeneID=3569].
Full description | IL-6, a proinflammtory cytokine produced by antigen presenting cells and non-hematopoietic cells in response to external stimuli, acts as an important bridge between the innate and adaptive immune responses. IL-6 together with IL-4 can promote Th2 polarization, while in combination with TGFbeta mediates Th17 differentiation. We examined early changes in gene expression in mouse CD4+ T cells induced by IL-6.

Standard name | GSE7459_UNTREATED_VS_IL6_TREATED_ACT_CD4_TCELL_DN
Systematic name | M463
Organism | Mus musculus
PMID | 19139170
Authors | Dienz O,Eaton SM,Bond JP,Neveu W,Moquin D,Noubade R,Briso EM,Charland C,Leonard WJ,Ciliberto G,Teuscher C,Haynes L,Rincon M
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: control versus IL6 [GeneID=3569].
Full description | IL-6, a proinflammtory cytokine produced by antigen presenting cells and non-hematopoietic cells in response to external stimuli, acts as an important bridge between the innate and adaptive immune responses. IL-6 together with IL-4 can promote Th2 polarization, while in combination with TGFbeta mediates Th17 differentiation. We examined early changes in gene expression in mouse CD4+ T cells induced by IL-6.

Standard name | GSE13173_UNTREATED_VS_IL12_TREATED_ACT_CD8_TCELL_UP
Systematic name | M464
Organism | Mus musculus
PMID | 19155481
Authors | Markiewicz MA,Wise EL,Buchwald ZS,Cheney EE,Hansen TH,Suri A,Cemerski S,Allen PM,Shaw AS
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenocytes from OT-1 TCR transgenic mice: control versus IL-12 treatment.
Full description | The goal was to determine how IL-12 affects gene expression by murine CTL.

Standard name | GSE13173_UNTREATED_VS_IL12_TREATED_ACT_CD8_TCELL_DN
Systematic name | M465
Organism | Mus musculus
PMID | 19155481
Authors | Markiewicz MA,Wise EL,Buchwald ZS,Cheney EE,Hansen TH,Suri A,Cemerski S,Allen PM,Shaw AS
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenocytes from OT-1 TCR transgenic mice: control versus IL-12 treatment.
Full description | The goal was to determine how IL-12 affects gene expression by murine CTL.

Standard name | GSE14413_UNSTIM_VS_IFNB_STIM_NIH3T3_CELLS_UP
Systematic name | M466
Organism | Mus musculus
PMID | 19158679
Authors | Bürckstümmer T,Baumann C,Blüml S,Dixit E,Dürnberger G,Jahn H,Planyavsky M,Bilban M,Colinge J,Bennett KL,Superti-Furga G
Category | C7
Sub-category |
Brief description | Genes up-regulated in NIH3T3 cells (fibroblast): control versus stimulated with IFN-b.
Full description | Cytoplasmic DNA triggers the activation of the innate immune system. While downstream signaling components have been characterized, the DNA sensing components remain largely elusive. We performed a systematic proteomics screen for proteins that associate with DNA, traversed to a screen for IFN-β-induced transcripts. We identified DSIRE (DNA sensor for the IL-1β response, previously called AIM2) as a candidate cytoplasmic sensor. DSIRE showed a marked selectivity for double-stranded DNA. DSIRE can recruit the inflammasome adaptor ASC and gets redistributed to ASC speckles upon coexpression of ASC. RNAi-mediated reduction of DSIRE expression led to an impairment in IL-1β maturation. Reconstitution of unresponsive cells with DSIRE, ASC, caspase 1 and IL-1β showed that DSIRE is sufficient for inflammasome activation. Overall, our data strongly suggest that DSIRE is a cytoplasmic DNA sensor for the inflammasome.

Standard name | GSE14413_UNSTIM_VS_IFNB_STIM_RAW264_CELLS_UP
Systematic name | M469
Organism | Mus musculus
PMID | 19158679
Authors | Bürckstümmer T,Baumann C,Blüml S,Dixit E,Dürnberger G,Jahn H,Planyavsky M,Bilban M,Colinge J,Bennett KL,Superti-Furga G
Category | C7
Sub-category |
Brief description | Genes up-regulated in RAW264.7 cells (macrophage): control versus stimulated with IFN-b.
Full description | Cytoplasmic DNA triggers the activation of the innate immune system. While downstream signaling components have been characterized, the DNA sensing components remain largely elusive. We performed a systematic proteomics screen for proteins that associate with DNA, traversed to a screen for IFN-β-induced transcripts. We identified DSIRE (DNA sensor for the IL-1β response, previously called AIM2) as a candidate cytoplasmic sensor. DSIRE showed a marked selectivity for double-stranded DNA. DSIRE can recruit the inflammasome adaptor ASC and gets redistributed to ASC speckles upon coexpression of ASC. RNAi-mediated reduction of DSIRE expression led to an impairment in IL-1β maturation. Reconstitution of unresponsive cells with DSIRE, ASC, caspase 1 and IL-1β showed that DSIRE is sufficient for inflammasome activation. Overall, our data strongly suggest that DSIRE is a cytoplasmic DNA sensor for the inflammasome.

Standard name | GSE14413_UNSTIM_VS_IFNB_STIM_RAW264_CELLS_DN
Systematic name | M470
Organism | Mus musculus
PMID | 19158679
Authors | Bürckstümmer T,Baumann C,Blüml S,Dixit E,Dürnberger G,Jahn H,Planyavsky M,Bilban M,Colinge J,Bennett KL,Superti-Furga G
Category | C7
Sub-category |
Brief description | Genes down-regulated in RAW264.7 cells (macrophage): control versus stimulated with IFN-b.
Full description | Cytoplasmic DNA triggers the activation of the innate immune system. While downstream signaling components have been characterized, the DNA sensing components remain largely elusive. We performed a systematic proteomics screen for proteins that associate with DNA, traversed to a screen for IFN-β-induced transcripts. We identified DSIRE (DNA sensor for the IL-1β response, previously called AIM2) as a candidate cytoplasmic sensor. DSIRE showed a marked selectivity for double-stranded DNA. DSIRE can recruit the inflammasome adaptor ASC and gets redistributed to ASC speckles upon coexpression of ASC. RNAi-mediated reduction of DSIRE expression led to an impairment in IL-1β maturation. Reconstitution of unresponsive cells with DSIRE, ASC, caspase 1 and IL-1β showed that DSIRE is sufficient for inflammasome activation. Overall, our data strongly suggest that DSIRE is a cytoplasmic DNA sensor for the inflammasome.

Standard name | GSE14413_UNSTIM_VS_IFNB_STIM_NIH3T3_CELLS_DN
Systematic name | M471
Organism | Mus musculus
PMID | 19158679
Authors | Bürckstümmer T,Baumann C,Blüml S,Dixit E,Dürnberger G,Jahn H,Planyavsky M,Bilban M,Colinge J,Bennett KL,Superti-Furga G
Category | C7
Sub-category |
Brief description | Genes down-regulated in NIH3T3 cells (fibroblast): control versus stimulated with IFN-b.
Full description | Cytoplasmic DNA triggers the activation of the innate immune system. While downstream signaling components have been characterized, the DNA sensing components remain largely elusive. We performed a systematic proteomics screen for proteins that associate with DNA, traversed to a screen for IFN-β-induced transcripts. We identified DSIRE (DNA sensor for the IL-1β response, previously called AIM2) as a candidate cytoplasmic sensor. DSIRE showed a marked selectivity for double-stranded DNA. DSIRE can recruit the inflammasome adaptor ASC and gets redistributed to ASC speckles upon coexpression of ASC. RNAi-mediated reduction of DSIRE expression led to an impairment in IL-1β maturation. Reconstitution of unresponsive cells with DSIRE, ASC, caspase 1 and IL-1β showed that DSIRE is sufficient for inflammasome activation. Overall, our data strongly suggest that DSIRE is a cytoplasmic DNA sensor for the inflammasome.

Standard name | GSE14413_UNSTIM_VS_IFNB_STIM_L929_CELLS_DN
Systematic name | M472
Organism | Mus musculus
PMID | 19158679
Authors | Bürckstümmer T,Baumann C,Blüml S,Dixit E,Dürnberger G,Jahn H,Planyavsky M,Bilban M,Colinge J,Bennett KL,Superti-Furga G
Category | C7
Sub-category |
Brief description | Genes down-regulated in L929 cells (fibroblast): control versus stimulated with IFN-b.
Full description | Cytoplasmic DNA triggers the activation of the innate immune system. While downstream signaling components have been characterized, the DNA sensing components remain largely elusive. We performed a systematic proteomics screen for proteins that associate with DNA, traversed to a screen for IFN-β-induced transcripts. We identified DSIRE (DNA sensor for the IL-1β response, previously called AIM2) as a candidate cytoplasmic sensor. DSIRE showed a marked selectivity for double-stranded DNA. DSIRE can recruit the inflammasome adaptor ASC and gets redistributed to ASC speckles upon coexpression of ASC. RNAi-mediated reduction of DSIRE expression led to an impairment in IL-1β maturation. Reconstitution of unresponsive cells with DSIRE, ASC, caspase 1 and IL-1β showed that DSIRE is sufficient for inflammasome activation. Overall, our data strongly suggest that DSIRE is a cytoplasmic DNA sensor for the inflammasome.

Standard name | GSE14413_UNSTIM_VS_IFNB_STIM_L929_CELLS_UP
Systematic name | M473
Organism | Mus musculus
PMID | 19158679
Authors | Bürckstümmer T,Baumann C,Blüml S,Dixit E,Dürnberger G,Jahn H,Planyavsky M,Bilban M,Colinge J,Bennett KL,Superti-Furga G
Category | C7
Sub-category |
Brief description | Genes up-regulated in L929 cells (fibroblast): control versus stimulated with IFN-b.
Full description | Cytoplasmic DNA triggers the activation of the innate immune system. While downstream signaling components have been characterized, the DNA sensing components remain largely elusive. We performed a systematic proteomics screen for proteins that associate with DNA, traversed to a screen for IFN-β-induced transcripts. We identified DSIRE (DNA sensor for the IL-1β response, previously called AIM2) as a candidate cytoplasmic sensor. DSIRE showed a marked selectivity for double-stranded DNA. DSIRE can recruit the inflammasome adaptor ASC and gets redistributed to ASC speckles upon coexpression of ASC. RNAi-mediated reduction of DSIRE expression led to an impairment in IL-1β maturation. Reconstitution of unresponsive cells with DSIRE, ASC, caspase 1 and IL-1β showed that DSIRE is sufficient for inflammasome activation. Overall, our data strongly suggest that DSIRE is a cytoplasmic DNA sensor for the inflammasome.

Standard name | GSE13887_ACT_CD4_VS_NO_TREATED_CD4_TCELL_DN
Systematic name | M474
Organism | Homo sapiens
PMID | 19201859
Authors | Fernandez DR,Telarico T,Bonilla E,Li Q,Banerjee S,Middleton FA,Phillips PE,Crow MK,Oess S,Muller-Esterl W,Perl A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells from healthy donors: activated by anti-CD3 and anti-CD28 versus nitric oxide [PubChem=145068] treatment.
Full description | CD3-positive T cells were negatively isolated from 10 SLE patients and 9 healthy controls without SLE. All of the SLE samples and control samples were compared with one another to identify baseline differences in expression due to the disease. Next, T cell preparations from 4 of the control subjects were stimulated with either Nitric Oxide (NOC-18) 600 uM for 24hr or stimulated through CD3/CD28 for 24hr to determine which genes were responsive to these signaling mechanisms. Here, we show that activity of the mammalian target of rapamycin (mTOR), which is a sensor of the mitochondrial transmembrane potential, is increased in SLE T cells. Activation of mTOR was inducible by NO, a key trigger of MHP which in turn enhanced the expression of HRES-1/Rab4, a small GTPase that regulates recycling of surface receptors through early endosomes. Expression of HRES-1/Rab4 was increased in SLE T cells and, in accordance with its dominant impact on the endocytic recycling of CD4, it was inversely correlated with diminished CD4 expression. HRES-1/Rab4 over-expression was also inversely correlated with diminished TCRζ protein levels. Combined with follow up studies, these results suggest that activation of mTOR causes the loss of TCRζ in lupus T cells through HRES-1/Rab4-dependent lysosomal degradation.

Standard name | GSE13887_HEALTHY_VS_LUPUS_RESTING_CD4_TCELL_DN
Systematic name | M475
Organism | Homo sapiens
PMID | 19201859
Authors | Fernandez DR,Telarico T,Bonilla E,Li Q,Banerjee S,Middleton FA,Phillips PE,Crow MK,Oess S,Muller-Esterl W,Perl A
Category | C7
Sub-category |
Brief description | Genes down-regulated in resting CD4 [GeneID=920] T cells: healthy versus systemic lupus erythrematosus (SLE).
Full description | CD3-positive T cells were negatively isolated from 10 SLE patients and 9 healthy controls without SLE. All of the SLE samples and control samples were compared with one another to identify baseline differences in expression due to the disease. Next, T cell preparations from 4 of the control subjects were stimulated with either Nitric Oxide (NOC-18) 600 uM for 24hr or stimulated through CD3/CD28 for 24hr to determine which genes were responsive to these signaling mechanisms. Here, we show that activity of the mammalian target of rapamycin (mTOR), which is a sensor of the mitochondrial transmembrane potential, is increased in SLE T cells. Activation of mTOR was inducible by NO, a key trigger of MHP which in turn enhanced the expression of HRES-1/Rab4, a small GTPase that regulates recycling of surface receptors through early endosomes. Expression of HRES-1/Rab4 was increased in SLE T cells and, in accordance with its dominant impact on the endocytic recycling of CD4, it was inversely correlated with diminished CD4 expression. HRES-1/Rab4 over-expression was also inversely correlated with diminished TCRζ protein levels. Combined with follow up studies, these results suggest that activation of mTOR causes the loss of TCRζ in lupus T cells through HRES-1/Rab4-dependent lysosomal degradation.

Standard name | GSE13887_RESTING_VS_ACT_CD4_TCELL_UP
Systematic name | M478
Organism | Homo sapiens
PMID | 19201859
Authors | Fernandez DR,Telarico T,Bonilla E,Li Q,Banerjee S,Middleton FA,Phillips PE,Crow MK,Oess S,Muller-Esterl W,Perl A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells from healthy donors: resting versus activated by anti-CD3 and anti-CD28.
Full description | CD3-positive T cells were negatively isolated from 10 SLE patients and 9 healthy controls without SLE. All of the SLE samples and control samples were compared with one another to identify baseline differences in expression due to the disease. Next, T cell preparations from 4 of the control subjects were stimulated with either Nitric Oxide (NOC-18) 600 uM for 24hr or stimulated through CD3/CD28 for 24hr to determine which genes were responsive to these signaling mechanisms. Here, we show that activity of the mammalian target of rapamycin (mTOR), which is a sensor of the mitochondrial transmembrane potential, is increased in SLE T cells. Activation of mTOR was inducible by NO, a key trigger of MHP which in turn enhanced the expression of HRES-1/Rab4, a small GTPase that regulates recycling of surface receptors through early endosomes. Expression of HRES-1/Rab4 was increased in SLE T cells and, in accordance with its dominant impact on the endocytic recycling of CD4, it was inversely correlated with diminished CD4 expression. HRES-1/Rab4 over-expression was also inversely correlated with diminished TCRζ protein levels. Combined with follow up studies, these results suggest that activation of mTOR causes the loss of TCRζ in lupus T cells through HRES-1/Rab4-dependent lysosomal degradation.

Standard name | GSE13887_RESTING_VS_NO_TREATED_CD4_TCELL_DN
Systematic name | M479
Organism | Homo sapiens
PMID | 19201859
Authors | Fernandez DR,Telarico T,Bonilla E,Li Q,Banerjee S,Middleton FA,Phillips PE,Crow MK,Oess S,Muller-Esterl W,Perl A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells from healthy donors: resting versus nitric oxide [PubChem=145068].
Full description | CD3-positive T cells were negatively isolated from 10 SLE patients and 9 healthy controls without SLE. All of the SLE samples and control samples were compared with one another to identify baseline differences in expression due to the disease. Next, T cell preparations from 4 of the control subjects were stimulated with either Nitric Oxide (NOC-18) 600 uM for 24hr or stimulated through CD3/CD28 for 24hr to determine which genes were responsive to these signaling mechanisms. Here, we show that activity of the mammalian target of rapamycin (mTOR), which is a sensor of the mitochondrial transmembrane potential, is increased in SLE T cells. Activation of mTOR was inducible by NO, a key trigger of MHP which in turn enhanced the expression of HRES-1/Rab4, a small GTPase that regulates recycling of surface receptors through early endosomes. Expression of HRES-1/Rab4 was increased in SLE T cells and, in accordance with its dominant impact on the endocytic recycling of CD4, it was inversely correlated with diminished CD4 expression. HRES-1/Rab4 over-expression was also inversely correlated with diminished TCRζ protein levels. Combined with follow up studies, these results suggest that activation of mTOR causes the loss of TCRζ in lupus T cells through HRES-1/Rab4-dependent lysosomal degradation.

Standard name | GSE13887_ACT_CD4_VS_NO_TREATED_CD4_TCELL_UP
Systematic name | M481
Organism | Homo sapiens
PMID | 19201859
Authors | Fernandez DR,Telarico T,Bonilla E,Li Q,Banerjee S,Middleton FA,Phillips PE,Crow MK,Oess S,Muller-Esterl W,Perl A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells from healthy donors: activated by anti-CD3 and anti-CD28 versus nitric oxide [PubChem=145068] treatment.
Full description | CD3-positive T cells were negatively isolated from 10 SLE patients and 9 healthy controls without SLE. All of the SLE samples and control samples were compared with one another to identify baseline differences in expression due to the disease. Next, T cell preparations from 4 of the control subjects were stimulated with either Nitric Oxide (NOC-18) 600 uM for 24hr or stimulated through CD3/CD28 for 24hr to determine which genes were responsive to these signaling mechanisms. Here, we show that activity of the mammalian target of rapamycin (mTOR), which is a sensor of the mitochondrial transmembrane potential, is increased in SLE T cells. Activation of mTOR was inducible by NO, a key trigger of MHP which in turn enhanced the expression of HRES-1/Rab4, a small GTPase that regulates recycling of surface receptors through early endosomes. Expression of HRES-1/Rab4 was increased in SLE T cells and, in accordance with its dominant impact on the endocytic recycling of CD4, it was inversely correlated with diminished CD4 expression. HRES-1/Rab4 over-expression was also inversely correlated with diminished TCRζ protein levels. Combined with follow up studies, these results suggest that activation of mTOR causes the loss of TCRζ in lupus T cells through HRES-1/Rab4-dependent lysosomal degradation.

Standard name | GSE13887_RESTING_VS_ACT_CD4_TCELL_DN
Systematic name | M484
Organism | Homo sapiens
PMID | 19201859
Authors | Fernandez DR,Telarico T,Bonilla E,Li Q,Banerjee S,Middleton FA,Phillips PE,Crow MK,Oess S,Muller-Esterl W,Perl A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells from healthy donors: resting versus activated by anti-CD3 and anti-CD28.
Full description | CD3-positive T cells were negatively isolated from 10 SLE patients and 9 healthy controls without SLE. All of the SLE samples and control samples were compared with one another to identify baseline differences in expression due to the disease. Next, T cell preparations from 4 of the control subjects were stimulated with either Nitric Oxide (NOC-18) 600 uM for 24hr or stimulated through CD3/CD28 for 24hr to determine which genes were responsive to these signaling mechanisms. Here, we show that activity of the mammalian target of rapamycin (mTOR), which is a sensor of the mitochondrial transmembrane potential, is increased in SLE T cells. Activation of mTOR was inducible by NO, a key trigger of MHP which in turn enhanced the expression of HRES-1/Rab4, a small GTPase that regulates recycling of surface receptors through early endosomes. Expression of HRES-1/Rab4 was increased in SLE T cells and, in accordance with its dominant impact on the endocytic recycling of CD4, it was inversely correlated with diminished CD4 expression. HRES-1/Rab4 over-expression was also inversely correlated with diminished TCRζ protein levels. Combined with follow up studies, these results suggest that activation of mTOR causes the loss of TCRζ in lupus T cells through HRES-1/Rab4-dependent lysosomal degradation.

Standard name | GSE13887_RESTING_VS_NO_TREATED_CD4_TCELL_UP
Systematic name | M485
Organism | Homo sapiens
PMID | 19201859
Authors | Fernandez DR,Telarico T,Bonilla E,Li Q,Banerjee S,Middleton FA,Phillips PE,Crow MK,Oess S,Muller-Esterl W,Perl A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells from healthy donors: resting versus nitric oxide [PubChem=145068].
Full description | CD3-positive T cells were negatively isolated from 10 SLE patients and 9 healthy controls without SLE. All of the SLE samples and control samples were compared with one another to identify baseline differences in expression due to the disease. Next, T cell preparations from 4 of the control subjects were stimulated with either Nitric Oxide (NOC-18) 600 uM for 24hr or stimulated through CD3/CD28 for 24hr to determine which genes were responsive to these signaling mechanisms. Here, we show that activity of the mammalian target of rapamycin (mTOR), which is a sensor of the mitochondrial transmembrane potential, is increased in SLE T cells. Activation of mTOR was inducible by NO, a key trigger of MHP which in turn enhanced the expression of HRES-1/Rab4, a small GTPase that regulates recycling of surface receptors through early endosomes. Expression of HRES-1/Rab4 was increased in SLE T cells and, in accordance with its dominant impact on the endocytic recycling of CD4, it was inversely correlated with diminished CD4 expression. HRES-1/Rab4 over-expression was also inversely correlated with diminished TCRζ protein levels. Combined with follow up studies, these results suggest that activation of mTOR causes the loss of TCRζ in lupus T cells through HRES-1/Rab4-dependent lysosomal degradation.

Standard name | GSE13887_HEALTHY_VS_LUPUS_RESTING_CD4_TCELL_UP
Systematic name | M1889
Organism | Homo sapiens
PMID | 19201859
Authors | Fernandez DR,Telarico T,Bonilla E,Li Q,Banerjee S,Middleton FA,Phillips PE,Crow MK,Oess S,Muller-Esterl W,Perl A
Category | C7
Sub-category |
Brief description | Genes up-regulated in resting CD4 [GeneID=920] T cells: healthy versus systemic lupus erythrematosus (SLE).
Full description | CD3-positive T cells were negatively isolated from 10 SLE patients and 9 healthy controls without SLE. All of the SLE samples and control samples were compared with one another to identify baseline differences in expression due to the disease. Next, T cell preparations from 4 of the control subjects were stimulated with either Nitric Oxide (NOC-18) 600 uM for 24hr or stimulated through CD3/CD28 for 24hr to determine which genes were responsive to these signaling mechanisms. Here, we show that activity of the mammalian target of rapamycin (mTOR), which is a sensor of the mitochondrial transmembrane potential, is increased in SLE T cells. Activation of mTOR was inducible by NO, a key trigger of MHP which in turn enhanced the expression of HRES-1/Rab4, a small GTPase that regulates recycling of surface receptors through early endosomes. Expression of HRES-1/Rab4 was increased in SLE T cells and, in accordance with its dominant impact on the endocytic recycling of CD4, it was inversely correlated with diminished CD4 expression. HRES-1/Rab4 over-expression was also inversely correlated with diminished TCRζ protein levels. Combined with follow up studies, these results suggest that activation of mTOR causes the loss of TCRζ in lupus T cells through HRES-1/Rab4-dependent lysosomal degradation.

Standard name | GSE13762_CTRL_VS_125_VITAMIND_DAY5_DC_DN
Systematic name | M1891
Organism | Homo sapiens
PMID | 19201860
Authors | Széles L,Keresztes G,Töröcsik D,Balajthy Z,Krenács L,Póliska S,Steinmeyer A,Zuegel U,Pruenster M,Rot A,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells (5 days): control versus 25-hydroxyvitamin D3 [PubChem=1593].
Full description | We have carried out global gene expression analysis to clarify the interrelationship between 1,25-dihydroxyvitamin D3 and differentiation-driven gene expression patterns in developing human monocyte-derived dendritic cells. Monocytes were treated with 10 nM 1,25-dihydroxyvitamin D3 or vehicle 14 hours after plating for 12 hours or 5 days. Monocytes, differentiating dendritic cells (+/-1,25-dihydroxyvitamin D3 for 12 hours) and immature dendritic cells (+/-1,25-dihydroxyvitamin D3 for 5 days) were harvested. This design allows one to identify genes regulated by differentiation and/or 1,25-dihydroxyvitamin D3 in human monocyte-derived dendritic cells.

Standard name | GSE13762_CTRL_VS_125_VITAMIND_DAY12_DC_UP
Systematic name | M1892
Organism | Homo sapiens
PMID | 19201860
Authors | Széles L,Keresztes G,Töröcsik D,Balajthy Z,Krenács L,Póliska S,Steinmeyer A,Zuegel U,Pruenster M,Rot A,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells (12 days): control versus 25-hydroxyvitamin D3 [PubChem=1593].
Full description | We have carried out global gene expression analysis to clarify the interrelationship between 1,25-dihydroxyvitamin D3 and differentiation-driven gene expression patterns in developing human monocyte-derived dendritic cells. Monocytes were treated with 10 nM 1,25-dihydroxyvitamin D3 or vehicle 14 hours after plating for 12 hours or 5 days. Monocytes, differentiating dendritic cells (+/-1,25-dihydroxyvitamin D3 for 12 hours) and immature dendritic cells (+/-1,25-dihydroxyvitamin D3 for 5 days) were harvested. This design allows one to identify genes regulated by differentiation and/or 1,25-dihydroxyvitamin D3 in human monocyte-derived dendritic cells.

Standard name | GSE13762_CTRL_VS_125_VITAMIND_DAY5_DC_UP
Systematic name | M1894
Organism | Homo sapiens
PMID | 19201860
Authors | Széles L,Keresztes G,Töröcsik D,Balajthy Z,Krenács L,Póliska S,Steinmeyer A,Zuegel U,Pruenster M,Rot A,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells (5 days): control versus 25-hydroxyvitamin D3 [PubChem=1593].
Full description | We have carried out global gene expression analysis to clarify the interrelationship between 1,25-dihydroxyvitamin D3 and differentiation-driven gene expression patterns in developing human monocyte-derived dendritic cells. Monocytes were treated with 10 nM 1,25-dihydroxyvitamin D3 or vehicle 14 hours after plating for 12 hours or 5 days. Monocytes, differentiating dendritic cells (+/-1,25-dihydroxyvitamin D3 for 12 hours) and immature dendritic cells (+/-1,25-dihydroxyvitamin D3 for 5 days) were harvested. This design allows one to identify genes regulated by differentiation and/or 1,25-dihydroxyvitamin D3 in human monocyte-derived dendritic cells.

Standard name | GSE13762_CTRL_VS_125_VITAMIND_DAY12_DC_DN
Systematic name | M1896
Organism | Homo sapiens
PMID | 19201860
Authors | Széles L,Keresztes G,Töröcsik D,Balajthy Z,Krenács L,Póliska S,Steinmeyer A,Zuegel U,Pruenster M,Rot A,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells (12 days): control versus 25-hydroxyvitamin D3 [PubChem=1593].
Full description | We have carried out global gene expression analysis to clarify the interrelationship between 1,25-dihydroxyvitamin D3 and differentiation-driven gene expression patterns in developing human monocyte-derived dendritic cells. Monocytes were treated with 10 nM 1,25-dihydroxyvitamin D3 or vehicle 14 hours after plating for 12 hours or 5 days. Monocytes, differentiating dendritic cells (+/-1,25-dihydroxyvitamin D3 for 12 hours) and immature dendritic cells (+/-1,25-dihydroxyvitamin D3 for 5 days) were harvested. This design allows one to identify genes regulated by differentiation and/or 1,25-dihydroxyvitamin D3 in human monocyte-derived dendritic cells.

Standard name | GSE13522_WT_VS_IFNG_KO_SKIN_DN
Systematic name | M1898
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin from: wildtype (BALB/c) versus IFNG [GeneID=3458] knockout.
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_Y_STRAIN_INF_SKIN_BALBC_MOUSE_UP
Systematic name | M2906
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin from BALB/c mice after injection of: control versus Trypanosoma cruzi (strain Y).
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_BRAZIL_STRAIN_INF_SKIN_UP
Systematic name | M2908
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin from BALB/c mice after injection of: control versus Trypanosoma cruzi (strain Brazil).
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_Y_STRAIN_INF_SKIN_IFNG_KO_DN
Systematic name | M2910
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin from INFG [GeneID=3458] knockout mice after injection of: control versus Trypanosoma cruzi (strain Y).
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_WT_VS_IFNG_KO_SKING_T_CRUZI_Y_STRAIN_INF_UP
Systematic name | M2911
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin after injection of Trypanosoma cruzi (strain Y): wildtype (BALB/c) versus INFG [GeneID=3458] knockout.
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_G_STRAIN_INF_SKIN_DN
Systematic name | M2912
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin from BALB/c mice after injection of: control versus Trypanosoma cruzi (strain G).
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_WT_VS_IFNG_KO_SKIN_UP
Systematic name | M2913
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin from: wildtype (BALB/c) versus IFNG [GeneID=3458] knockout.
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_Y_STRAIN_INF_SKIN_IFNG_KO_UP
Systematic name | M2914
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin from INFG [GeneID=3458] knockout mice after injection of: control versus Trypanosoma cruzi (strain Y).
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_WT_VS_IFNG_KO_SKING_T_CRUZI_Y_STRAIN_INF_DN
Systematic name | M2915
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin after injection of Trypanosoma cruzi (strain Y): wildtype (BALB/c) versus INFG [GeneID=3458] knockout.
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_Y_STRAIN_INF_SKIN_129_MOUSE_UP
Systematic name | M2916
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin from 129S1 mice after injection of: control versus Trypanosoma cruzi (strain Y).
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_Y_STRAIN_INF_SKIN_129_MOUSE_DN
Systematic name | M2917
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin from 129S1 mice after injection of: control versus Trypanosoma cruzi (strain Y).
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_WT_VS_IFNAR_KO_SKING_T_CRUZI_Y_STRAIN_INF_DN
Systematic name | M2918
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin after injection of Trypanosoma cruzi (strain Y): wildtype (BALB/c) versus IFNAR1 [GeneID=3454] knockout.
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_BRAZIL_STRAIN_INF_SKIN_DN
Systematic name | M2921
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin from BALB/c mice after injection of: control versus Trypanosoma cruzi (strain Brazil).
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_G_STRAIN_INF_SKIN_UP
Systematic name | M2922
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin from BALB/c mice after injection of: control versus Trypanosoma cruzi (strain G).
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_WT_VS_IFNAR_KO_SKIN_DN
Systematic name | M2925
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin: wildtype (BALB/c) versus IFNAR1 [GeneID=3454] knockout.
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_Y_STRAIN_INF_SKIN_BALBC_MOUSE_DN
Systematic name | M2928
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin from BALB/c mice after injection of: control versus Trypanosoma cruzi (strain Y).
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_Y_STRAIN_INF_SKIN_IFNAR_KO_UP
Systematic name | M2929
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin after injection of Trypanosoma cruzi (strain Y): wildtype (129S1) versus IFNAR1 [GeneID=3454] knockout.
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_CTRL_VS_T_CRUZI_Y_STRAIN_INF_SKIN_IFNAR_KO_DN
Systematic name | M2930
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin after injection of Trypanosoma cruzi (strain Y): wildtype (129S1) versus IFNAR1 [GeneID=3454] knockout.
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_WT_VS_IFNAR_KO_SKIN_UP
Systematic name | M2932
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin: wildtype (BALB/c) versus IFNAR1 [GeneID=3454] knockout.
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE13522_WT_VS_IFNAR_KO_SKING_T_CRUZI_Y_STRAIN_INF_UP
Systematic name | M2933
Organism | Mus musculus
PMID | 19201883
Authors | Chessler AD,Unnikrishnan M,Bei AK,Daily JP,Burleigh BA
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin after injection of Trypanosoma cruzi (strain Y): wildtype (BALB/c) versus IFNAR1 [GeneID=3454] knockout.
Full description | To investigate the early host response triggered by three different strains of Trypanosoma cruzi at a local infection site, changes in host gene expression were monitored in a murine intradermal infection model using Affymetrix oligonucleotide arrays. Robust induction of IFN-stimulated genes (ISGs) was observed in excised skin 24 hours post-infection where the level of ISG induction was parasite strain-dependent with the least virulent strain triggering a muted IFN response. Infection of mice immunodepleted of IFNγ-producing cells or infection of IFNγ-deficient mice had minimal impact on the IFN response generated in T. cruzi infected mice. In contrast, infection of mice lacking the type I IFN receptor demonstrated that type I IFNs are largely responsible for the IFN response generated at the site of infection. These data highlight type I IFNs as important components of the innate immune response to T. cruzi the site of inoculation and their role in shaping the early transcriptional response to this pathogen. We used microarrays to detail the local host transcriptional response to intradermal T. cruzi infection in WT mice and mice depleted of NK cells, or deficient in IFN-gamma or type I IFN responses. Additionally we compared the local host-transcriptional response generated to infection with 3 different strains of Trypanosoma cruzi (Y, Brazil, and G).

Standard name | GSE14699_NAIVE_VS_ACT_CD8_TCELL_UP
Systematic name | M2934
Organism | Mus musculus
PMID | 19204323
Authors | Parish IA,Rao S,Smyth GK,Juelich T,Denyer GS,Davey GM,Strasser A,Heath WR
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus activated.
Full description | Peripheral tolerance induction is critical for the maintenance of self-tolerance and can be mediated by immunoregulatory T cells or by direct induction of T cell anergy or deletion. While the molecular processes underlying anergy have been extensively studied, little is known about the molecular basis for peripheral T cell deletion. Here, we determined the gene expression signature of peripheral CD8+ T cells undergoing deletional tolerance, relative to those undergoing immunogenic priming or lymphopenia-induced proliferation. From these data, we report the first detailed molecular signature of cells undergoing deletion. Consistent with defective cytolysis, these cells exhibited deficiencies in granzyme up-regulation. Furthermore, they showed antigen-driven Bcl-2 down-regulation and early up-regulation of the pro-apoptotic protein Bim, consistent with the requirement of this BH3-only protein for peripheral T cell deletion. Bim up-regulation was paralleled by defective IL-7Ra chain re-expression, suggesting that Bim-dependent death may be triggered by loss of IL-7/IL-7R signaling. Finally, we observed parallels in molecular signatures between deletion and anergy suggesting that these tolerance pathways may not be as molecularly distinct as previously surmised.

Standard name | GSE14699_NAIVE_VS_DELETIONAL_TOLERANCE_CD8_TCELL_DN
Systematic name | M2936
Organism | Mus musculus
PMID | 19204323
Authors | Parish IA,Rao S,Smyth GK,Juelich T,Denyer GS,Davey GM,Strasser A,Heath WR
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus undergoing deletional tolerance.
Full description | Peripheral tolerance induction is critical for the maintenance of self-tolerance and can be mediated by immunoregulatory T cells or by direct induction of T cell anergy or deletion. While the molecular processes underlying anergy have been extensively studied, little is known about the molecular basis for peripheral T cell deletion. Here, we determined the gene expression signature of peripheral CD8+ T cells undergoing deletional tolerance, relative to those undergoing immunogenic priming or lymphopenia-induced proliferation. From these data, we report the first detailed molecular signature of cells undergoing deletion. Consistent with defective cytolysis, these cells exhibited deficiencies in granzyme up-regulation. Furthermore, they showed antigen-driven Bcl-2 down-regulation and early up-regulation of the pro-apoptotic protein Bim, consistent with the requirement of this BH3-only protein for peripheral T cell deletion. Bim up-regulation was paralleled by defective IL-7Ra chain re-expression, suggesting that Bim-dependent death may be triggered by loss of IL-7/IL-7R signaling. Finally, we observed parallels in molecular signatures between deletion and anergy suggesting that these tolerance pathways may not be as molecularly distinct as previously surmised.

Standard name | GSE14699_NAIVE_VS_DELETIONAL_TOLERANCE_CD8_TCELL_UP
Systematic name | M2938
Organism | Mus musculus
PMID | 19204323
Authors | Parish IA,Rao S,Smyth GK,Juelich T,Denyer GS,Davey GM,Strasser A,Heath WR
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus undergoing deletional tolerance.
Full description | Peripheral tolerance induction is critical for the maintenance of self-tolerance and can be mediated by immunoregulatory T cells or by direct induction of T cell anergy or deletion. While the molecular processes underlying anergy have been extensively studied, little is known about the molecular basis for peripheral T cell deletion. Here, we determined the gene expression signature of peripheral CD8+ T cells undergoing deletional tolerance, relative to those undergoing immunogenic priming or lymphopenia-induced proliferation. From these data, we report the first detailed molecular signature of cells undergoing deletion. Consistent with defective cytolysis, these cells exhibited deficiencies in granzyme up-regulation. Furthermore, they showed antigen-driven Bcl-2 down-regulation and early up-regulation of the pro-apoptotic protein Bim, consistent with the requirement of this BH3-only protein for peripheral T cell deletion. Bim up-regulation was paralleled by defective IL-7Ra chain re-expression, suggesting that Bim-dependent death may be triggered by loss of IL-7/IL-7R signaling. Finally, we observed parallels in molecular signatures between deletion and anergy suggesting that these tolerance pathways may not be as molecularly distinct as previously surmised.

Standard name | GSE14699_DELETIONAL_TOLERANCE_VS_ACTIVATED_CD8_TCELL_DN
Systematic name | M2939
Organism | Mus musculus
PMID | 19204323
Authors | Parish IA,Rao S,Smyth GK,Juelich T,Denyer GS,Davey GM,Strasser A,Heath WR
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: undergoing deletional tolerance versus activated.
Full description | Peripheral tolerance induction is critical for the maintenance of self-tolerance and can be mediated by immunoregulatory T cells or by direct induction of T cell anergy or deletion. While the molecular processes underlying anergy have been extensively studied, little is known about the molecular basis for peripheral T cell deletion. Here, we determined the gene expression signature of peripheral CD8+ T cells undergoing deletional tolerance, relative to those undergoing immunogenic priming or lymphopenia-induced proliferation. From these data, we report the first detailed molecular signature of cells undergoing deletion. Consistent with defective cytolysis, these cells exhibited deficiencies in granzyme up-regulation. Furthermore, they showed antigen-driven Bcl-2 down-regulation and early up-regulation of the pro-apoptotic protein Bim, consistent with the requirement of this BH3-only protein for peripheral T cell deletion. Bim up-regulation was paralleled by defective IL-7Ra chain re-expression, suggesting that Bim-dependent death may be triggered by loss of IL-7/IL-7R signaling. Finally, we observed parallels in molecular signatures between deletion and anergy suggesting that these tolerance pathways may not be as molecularly distinct as previously surmised.

Standard name | GSE14699_NAIVE_VS_ACT_CD8_TCELL_DN
Systematic name | M2940
Organism | Mus musculus
PMID | 19204323
Authors | Parish IA,Rao S,Smyth GK,Juelich T,Denyer GS,Davey GM,Strasser A,Heath WR
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus activated.
Full description | Peripheral tolerance induction is critical for the maintenance of self-tolerance and can be mediated by immunoregulatory T cells or by direct induction of T cell anergy or deletion. While the molecular processes underlying anergy have been extensively studied, little is known about the molecular basis for peripheral T cell deletion. Here, we determined the gene expression signature of peripheral CD8+ T cells undergoing deletional tolerance, relative to those undergoing immunogenic priming or lymphopenia-induced proliferation. From these data, we report the first detailed molecular signature of cells undergoing deletion. Consistent with defective cytolysis, these cells exhibited deficiencies in granzyme up-regulation. Furthermore, they showed antigen-driven Bcl-2 down-regulation and early up-regulation of the pro-apoptotic protein Bim, consistent with the requirement of this BH3-only protein for peripheral T cell deletion. Bim up-regulation was paralleled by defective IL-7Ra chain re-expression, suggesting that Bim-dependent death may be triggered by loss of IL-7/IL-7R signaling. Finally, we observed parallels in molecular signatures between deletion and anergy suggesting that these tolerance pathways may not be as molecularly distinct as previously surmised.

Standard name | GSE14699_DELETIONAL_TOLERANCE_VS_ACTIVATED_CD8_TCELL_UP
Systematic name | M2941
Organism | Mus musculus
PMID | 19204323
Authors | Parish IA,Rao S,Smyth GK,Juelich T,Denyer GS,Davey GM,Strasser A,Heath WR
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: undergoing deletional tolerance versus activated.
Full description | Peripheral tolerance induction is critical for the maintenance of self-tolerance and can be mediated by immunoregulatory T cells or by direct induction of T cell anergy or deletion. While the molecular processes underlying anergy have been extensively studied, little is known about the molecular basis for peripheral T cell deletion. Here, we determined the gene expression signature of peripheral CD8+ T cells undergoing deletional tolerance, relative to those undergoing immunogenic priming or lymphopenia-induced proliferation. From these data, we report the first detailed molecular signature of cells undergoing deletion. Consistent with defective cytolysis, these cells exhibited deficiencies in granzyme up-regulation. Furthermore, they showed antigen-driven Bcl-2 down-regulation and early up-regulation of the pro-apoptotic protein Bim, consistent with the requirement of this BH3-only protein for peripheral T cell deletion. Bim up-regulation was paralleled by defective IL-7Ra chain re-expression, suggesting that Bim-dependent death may be triggered by loss of IL-7/IL-7R signaling. Finally, we observed parallels in molecular signatures between deletion and anergy suggesting that these tolerance pathways may not be as molecularly distinct as previously surmised.

Standard name | GSE13946_CTRL_VS_DSS_COLITIS_GD_TCELL_FROM_COLON_DN
Systematic name | M2942
Organism | Mus musculus
PMID | 19234201
Authors | Ismail AS,Behrendt CL,Hooper LV
Category | C7
Sub-category |
Brief description | Genes down-regulated in gamma delta intraepithelial lymphocytes from colon: control versus colitis induced by dextran sulfate sodium (DSS).
Full description | gamma delta intraepithelial lymphocytes were isolated from the colons of DSS-treated and untreated mice. Total RNAs were isolated and compared by Affymetrix DNA microarray.

Standard name | GSE13946_CTRL_VS_DSS_COLITIS_GD_TCELL_FROM_COLON_UP
Systematic name | M2943
Organism | Mus musculus
PMID | 19234201
Authors | Ismail AS,Behrendt CL,Hooper LV
Category | C7
Sub-category |
Brief description | Genes up-regulated in gamma delta intraepithelial lymphocytes from colon: control versus colitis induced by dextran sulfate sodium (DSS).
Full description | gamma delta intraepithelial lymphocytes were isolated from the colons of DSS-treated and untreated mice. Total RNAs were isolated and compared by Affymetrix DNA microarray.

Standard name | GSE14415_ACT_TCONV_VS_ACT_NATURAL_TREG_UP
Systematic name | M2945
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated T lymphocytes: T conv versus natural T reg.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_INDUCED_TREG_VS_FOXP3_KO_INDUCED_TREG_DN
Systematic name | M2946
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in induced T reg: wildtype versus non-functional FOXP3 [GeneID=50943].
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_FOXP3_KO_NATURAL_TREG_VS_TCONV_UP
Systematic name | M2947
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in natural T reg with non-functional FOXP3 [GeneID=50943] versus T conv.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_ACT_TCONV_VS_ACT_NATURAL_TREG_DN
Systematic name | M2950
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated T lymphocytes: T conv versus natural T reg.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_INDUCED_TREG_VS_FOXP3_KO_INDUCED_TREG_UP
Systematic name | M2951
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in induced T reg: wildtype versus non-functional FOXP3 [GeneID=50943].
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_INDUCED_TREG_VS_FAILED_INDUCED_TREG_DN
Systematic name | M2952
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: induced versus failed induced.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_FOXP3_KO_NATURAL_TREG_VS_TCONV_DN
Systematic name | M2953
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in natural T reg with non-functional FOXP3 [GeneID=50943] versus T conv.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_INDUCED_TREG_VS_FOXP3_KO_INDUCED_TREG_IL2_CULTURE_UP
Systematic name | M2954
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in induced T reg cultured with IL2 [GeneID=3558]: wildtype versus non-functional FOXP3 [GeneID=50943].
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_INDUCED_TREG_VS_FAILED_INDUCED_TREG_UP
Systematic name | M2955
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: induced versus failed induced.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_INDUCED_TREG_VS_FOXP3_KO_INDUCED_TREG_IL2_CULTURE_DN
Systematic name | M2956
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in induced T reg cultured with IL2 [GeneID=3558]: wildtype versus non-functional FOXP3 [GeneID=50943].
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_INDUCED_TREG_VS_TCONV_UP
Systematic name | M2959
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in induced T reg versus T conv.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_INDUCED_TREG_VS_TCONV_DN
Systematic name | M2960
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in induced T reg versus T conv.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_NATURAL_TREG_VS_TCONV_DN
Systematic name | M2961
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in natural T reg versus T conv.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_ACT_VS_CTRL_NATURAL_TREG_DN
Systematic name | M2962
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in natural T reg: activated versus naïve.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_TCONV_VS_FOXP3_KO_INDUCED_TREG_UP
Systematic name | M2963
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv versus induced T reg with non-functional FOXP3 [GeneID=50943].
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_NATURAL_TREG_VS_FOXP3_KO_NATURAL_TREG_UP
Systematic name | M2964
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in natural T reg: wildtype versus non-functional FOXP3 [GeneID=50943].
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_TCONV_VS_FOXP3_KO_INDUCED_TREG_DN
Systematic name | M2965
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv versus induced T reg with non-functional FOXP3 [GeneID=50943].
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_INDUCED_VS_NATURAL_TREG_UP
Systematic name | M2968
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: induced versus natural.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_INDUCED_VS_NATURAL_TREG_DN
Systematic name | M2969
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: induced versus natural.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_NATURAL_TREG_VS_FOXP3_KO_NATURAL_TREG_DN
Systematic name | M2972
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in natural T reg: wildtype versus non-functional FOXP3 [GeneID=50943].
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_ACT_VS_CTRL_NATURAL_TREG_UP
Systematic name | M2975
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in natural T reg: activated versus naïve.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14415_NATURAL_TREG_VS_TCONV_UP
Systematic name | M2976
Organism | Mus musculus
PMID | 19265124
Authors | Haribhai D,Lin W,Edwards B,Ziegelbauer J,Salzman NH,Carlson MR,Li SH,Simpson PM,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in natural T reg versus T conv.
Full description | The gene expression profile of peripheral Foxp3+ natural regulatory T cells isolated from Foxp3/EGFP bicistronic mice was compared to that of in vitro-induced regulatory T cells and to CD4+ conventional (Foxp3-) T cells. The role of the regulatory T cell transcription factor Foxp3 in shaping the transcriptosomes of natural and induced regulatory T cells was analyzed using mice expressing a mutant FOXP3-EGFP fusion protein (Foxp3deltaEGFP). We used gene expression microarrays to examine the transcriptional programs of natural and induced regulatory T cells and the function of Foxp3 in organizing the transcriptosomes of the respective cell type

Standard name | GSE14386_UNTREATED_VS_IFNA_TREATED_ACT_PBMC_MS_PATIENT_UP
Systematic name | M2977
Organism | Homo sapiens
PMID | 19265172
Authors | Zhang X,Jin J,Tang Y,Speer D,Sujkowska D,Markovic-Plese S
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood mononclear cells (PBMC) from multiple sclerosis (MS) patient: untreated versus IFNB1 [GeneID=3456].
Full description | IFNβ, an effective therapy against relapsing-remitting (RR) multiple sclerosis (MS) is naturally secreted during the innate immune response against viral pathogens. The objective of this study was to characterize the immunomodulatory mechanisms of IFNβ targeting innate immune response and their effects on DC-mediated regulation of T-cell differentiation. We found that IFNβ−1a in-vitro treatment of human monocyte-derived dendritic cells (DCs) induced the expression of TLR7 and the members of its downstream signaling pathway, including myeloid differentiation factor 88 (MyD88), IL-1R-associated kinase (IRAK)4, and TNF receptor-associated factor (TRAF)6, while it inhibited the expression of IL-1R. Using siRNA TLR7 gene silencing, we confirmed that IFNβ-1a-induced changes in MyD88, IRAK4 and IL-1R expression were dependent on TLR7. TLR7 expression was also necessary for the IFNβ-1a-induced inhibition of IL-1β and IL-23, and the induction of IL-27 secretion by DCs. Supernatant (SN) transfer experiments confirmed that IFNβ-1a-induced changes in DCs’ cytokine secretion inhibit Th17 cell differentiation as evidenced by the inhibition of retinoic acid-related orphan nuclear hormone receptor C (RORC) and IL-17A gene expression and IL-17A secretion. Our study has identified a novel therapeutic mechanism of IFNβ−1a, that selectively targets the autoimmune response in MS.

Standard name | GSE14386_UNTREATED_VS_IFNA_TREATED_ACT_PBMC_MS_PATIENT_DN
Systematic name | M2979
Organism | Homo sapiens
PMID | 19265172
Authors | Zhang X,Jin J,Tang Y,Speer D,Sujkowska D,Markovic-Plese S
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood mononclear cells (PBMC) from multiple sclerosis (MS) patient: untreated versus IFNB1 [GeneID=3456].
Full description | IFNβ, an effective therapy against relapsing-remitting (RR) multiple sclerosis (MS) is naturally secreted during the innate immune response against viral pathogens. The objective of this study was to characterize the immunomodulatory mechanisms of IFNβ targeting innate immune response and their effects on DC-mediated regulation of T-cell differentiation. We found that IFNβ−1a in-vitro treatment of human monocyte-derived dendritic cells (DCs) induced the expression of TLR7 and the members of its downstream signaling pathway, including myeloid differentiation factor 88 (MyD88), IL-1R-associated kinase (IRAK)4, and TNF receptor-associated factor (TRAF)6, while it inhibited the expression of IL-1R. Using siRNA TLR7 gene silencing, we confirmed that IFNβ-1a-induced changes in MyD88, IRAK4 and IL-1R expression were dependent on TLR7. TLR7 expression was also necessary for the IFNβ-1a-induced inhibition of IL-1β and IL-23, and the induction of IL-27 secretion by DCs. Supernatant (SN) transfer experiments confirmed that IFNβ-1a-induced changes in DCs’ cytokine secretion inhibit Th17 cell differentiation as evidenced by the inhibition of retinoic acid-related orphan nuclear hormone receptor C (RORC) and IL-17A gene expression and IL-17A secretion. Our study has identified a novel therapeutic mechanism of IFNβ−1a, that selectively targets the autoimmune response in MS.

Standard name | GSE13547_CTRL_VS_ANTI_IGM_STIM_BCELL_12H_DN
Systematic name | M2980
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: control versus stimulated by anti-IgM for 12h.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_2H_VS_12_H_ANTI_IGM_STIM_BCELL_UP
Systematic name | M2981
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes stimulated by anti-IgM: 2h versus 12h.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_2H_VS_12_H_ANTI_IGM_STIM_BCELL_DN
Systematic name | M2982
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes stimulated by anti-IgM: 2h versus 12h.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_WT_VS_ZFX_KO_BCELL_ANTI_IGM_STIM_12H_DN
Systematic name | M2983
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes stimulated by anti-IgM for 12h: wildtype versus ZFX [GeneID=7543] knockout.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_CTRL_VS_ANTI_IGM_STIM_BCELL_12H_UP
Systematic name | M2984
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: control versus stimulated by anti-IgM for 12h.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_WT_VS_ZFX_KO_BCELL_ANTI_IGM_STIM_2H_DN
Systematic name | M2988
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes stimulated by anti-IgM for 2h: wildtype versus ZFX [GeneID=7543] knockout.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_WT_VS_ZFX_KO_BCELL_ANTI_IGM_STIM_12H_UP
Systematic name | M2989
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes stimulated by anti-IgM for 12h: wildtype versus ZFX [GeneID=7543] knockout.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_CTRL_VS_ANTI_IGM_STIM_ZFX_KO_BCELL_2H_DN
Systematic name | M2990
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes with ZFX [GeneID=7543] knockout: control versus stimulated by anti-IgM for 2h.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_CTRL_VS_ANTI_IGM_STIM_BCELL_2H_DN
Systematic name | M2991
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: control versus stimulated by anti-IgM.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_CTRL_VS_ANTI_IGM_STIM_BCELL_2H_UP
Systematic name | M2993
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: control versus stimulated by anti-IgM for 2h.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_WT_VS_ZFX_KO_BCELL_ANTI_IGM_STIM_2H_UP
Systematic name | M2994
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes stimulated by anti-IgM for 2h: wildtype versus ZFX [GeneID=7543] knockout.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_2H_VS_12_H_ANTI_IGM_STIM_ZFX_KO_BCELL_UP
Systematic name | M2995
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes stimulated by anti-IgM: ZFX [GeneID=7543] knockout (2h) versus wildtype (12h).
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_2H_VS_12_H_ANTI_IGM_STIM_ZFX_KO_BCELL_DN
Systematic name | M2996
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes stimulated by anti-IgM: ZFX [GeneID=7543] knockout (2h) versus wildtype (12h).
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_WT_VS_ZFX_KO_BCELL_UP
Systematic name | M2997
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: wildtype versus ZFX [GeneID=7543].
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_CTRL_VS_ANTI_IGM_STIM_ZFX_KO_BCELL_2H_UP
Systematic name | M3000
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes with ZFX [GeneID=7543] knockout: control versus stimulated by anti-IgM for 2h.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_CTRL_VS_ANTI_IGM_STIM_ZFX_KO_BCELL_12H_UP
Systematic name | M7001
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: ZFX [GeneID=7543] knockout versus wildtype cells stimulated by anti-IgM for 12h.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_CTRL_VS_ANTI_IGM_STIM_ZFX_KO_BCELL_12H_DN
Systematic name | M7002
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: ZFX [GeneID=7543] knockout versus wildtype cells stimulated by anti-IgM for 12h.
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE13547_WT_VS_ZFX_KO_BCELL_DN
Systematic name | M7003
Organism | Mus musculus
PMID | 19329779
Authors | Arenzana TL,Smith-Raska MR,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: wildtype versus ZFX [GeneID=7543].
Full description | The development, homeostasis and function of B lymphocytes involve multiple rounds of B cell receptor (BCR)-controlled proliferation and prolonged maintenance. We analyzed the role of transcription factor Zfx, a recently identified regulator of stem cell maintenance, in B cell development and homeostasis. Conditional Zfx deletion in the bone marrow blocked B cell development at the pre-BCR selection checkpoint. Zfx deficiency in peripheral B cells caused impaired generation of the B-1 cell lineage, accelerated B cell turnover, depletion of mature recirculating cells, and delayed T-dependent antibody responses. Zfx-deficient B cells showed normal proximal BCR signaling, but impaired BCR-induced proliferation and survival. This was accompanied by aberrantly enhanced and prolonged integrated stress response, and delayed induction of Cyclin D2 and Bcl-xL proteins. Thus, Zfx restrains the stress response and couples antigen receptor signaling to B cell expansion and maintenance during development and peripheral homeostasis.

Standard name | GSE15330_HSC_VS_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_UP
Systematic name | M7005
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus megakaryo-erythrocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_LYMPHOID_PRIMED_MULTIPOTENT_PROGENITOR_DN
Systematic name | M7006
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus lymphoid primed multipotent progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_DN
Systematic name | M7007
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus megakaryo-erythrocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_MEGAKARYOCYTE_ERYTHROID_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_UP
Systematic name | M7008
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in megakaryo-erythrocyte progenitors versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_LYMPHOID_MULTIPOTENT_VS_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_IKAROS_KO_UP
Systematic name | M7009
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in IKZF1 [GeneID=10320] knockout: lymphoid-primed multipotent progenitors versus megakaryo-erythrocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_LYMPHOID_MULTIPOTENT_VS_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_IKAROS_KO_DN
Systematic name | M7010
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in IKZF1 [GeneID=10320] knockout: lymphoid-primed multipotent progenitors versus megakaryo-erythrocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_LYMPHOID_MULTIPOTENT_VS_PRO_BCELL_UP
Systematic name | M7011
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphoid-primed multipotent progenitors versus pro-B lymphocytes.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_LYMPHOID_MULTIPOTENT_VS_PRO_BCELL_DN
Systematic name | M7016
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphoid-primed multipotent progenitors versus pro-B lymphocytes.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_IKAROS_KO_DN
Systematic name | M7017
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in IKZF1 [GeneID=10320] knockout: hematopoietic stem cells versus megakaryo-erythrocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_LYMPHOID_PRIMED_MULTIPOTENT_PROGENITOR_UP
Systematic name | M7018
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus lymphoid primed multipotent progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_LYMPHOID_MULTIPOTENT_VS_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_DN
Systematic name | M7019
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphoid-primed multipotent progenitors versus megakaryo-erythrocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_IKAROS_KO_UP
Systematic name | M7020
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in IKZF1 [GeneID=10320] knockout: hematopoietic stem cells versus megakaryo-erythrocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_LYMPHOID_MULTIPOTENT_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_UP
Systematic name | M7021
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphoid-primed multipotent progenitors versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_IKAROS_KO_UP
Systematic name | M7022
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in IKZF1 [GeneID=10320] knockout: hematopoietic stem cells versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_IKAROS_KO_DN
Systematic name | M7025
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in IKZF1 [GeneID=10320] knockout: hematopoietic stem cells versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_MEGAKARYOCYTE_ERYTHROID_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_DN
Systematic name | M7026
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in megakaryo-erythrocyte progenitors versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_WT_VS_IKAROS_KO_GRANULOCYTE_MONOCYTE_PROGENITOR_UP
Systematic name | M7027
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in granulo-monocyte progenitors: wildtype versus IKZF1 [GeneID=10320] knockout.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_WT_VS_IKAROS_KO_GRANULOCYTE_MONOCYTE_PROGENITOR_DN
Systematic name | M7028
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in granulo-monocyte progenitors: wildtype versus IKZF1 [GeneID=10320] knockout.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_LYMPHOID_MULTIPOTENT_VS_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_UP
Systematic name | M7031
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphoid-primed multipotent progenitors versus megakaryo-erythrocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_MEGAKARYOCYTE_ERYTHROID_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_IKAROS_KO_DN
Systematic name | M7033
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in IKZF1 [GeneID=10320] knockout: megakaryo-erythrocyte progenitors versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_LYMPHOID_PRIMED_MULTIPOTENT_PROGENITOR_IKAROS_KO_DN
Systematic name | M7035
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in IKZF1 [GeneID=10320] knockout: hematopoietic stem cells versus lymphoid-primed multipotent progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_WT_VS_IKAROS_KO_HSC_DN
Systematic name | M7036
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells: wildtype versus IKZF1 [GeneID=10320] knockout.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_WT_VS_IKAROS_KO_LYMPHOID_MULTIPOTENT_PROGENITOR_UP
Systematic name | M7037
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphoid-primed multipotent progenitors: wildtype versus IKZF1 [GeneID=10320] knockout.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_WT_VS_IKAROS_KO_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_UP
Systematic name | M7039
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in megakaryo-erythrocyte progenitors: wildtype versus IKZF1 [GeneID=10320] knockout.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_WT_VS_IKAROS_KO_HSC_UP
Systematic name | M7040
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells: wildtype versus IKZF1 [GeneID=10320] knockout.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_GRANULOCYTE_MONOCYTE_PROGENITOR_VS_PRO_BCELL_UP
Systematic name | M7041
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in granulo-monocyte progenitors versus pro-B lymphocytes.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_GRANULOCYTE_MONOCYTE_PROGENITOR_VS_PRO_BCELL_DN
Systematic name | M7042
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in granulo-monocyte progenitors versus pro-B lymphocytes.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_MEGAKARYOCYTE_ERYTHROID_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_IKAROS_KO_UP
Systematic name | M7043
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in IKZF1 [GeneID=10320] knockout: megakaryo-erythrocyte progenitors versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_WT_VS_IKAROS_KO_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_DN
Systematic name | M7044
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in megakaryo-erythrocyte progenitors: wildtype versus IKZF1 [GeneID=10320] knockout.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_VS_PRO_BCELL_DN
Systematic name | M7045
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in megakaryo-erythrocyte progenitors versus pro-B lymphocytes.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_LYMPHOID_MULTIPOTENT_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_IKAROS_KO_UP
Systematic name | M7046
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in IKZF1 [GeneID=10320] knockout: lymphoid-primed multipotent progenitors versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_LYMPHOID_MULTIPOTENT_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_IKAROS_KO_DN
Systematic name | M7049
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in IKZF1 [GeneID=10320] knockout: lymphoid-primed multipotent progenitors versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_LYMPHOID_PRIMED_MULTIPOTENT_PROGENITOR_IKAROS_KO_UP
Systematic name | M7050
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in IKZF1 [GeneID=10320] knockout: hematopoietic stem cells versus lymphoid-primed multipotent progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_MEGAKARYOCYTE_ERYTHROID_PROGENITOR_VS_PRO_BCELL_UP
Systematic name | M7053
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in megakaryo-erythrocyte progenitors versus pro-B lymphocytes.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_DN
Systematic name | M7055
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_PRO_BCELL_UP
Systematic name | M7056
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus pro-B lymphocytes.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_WT_VS_IKAROS_KO_LYMPHOID_MULTIPOTENT_PROGENITOR_DN
Systematic name | M7058
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphoid-primed multipotent progenitors: wildtype versus IKZF1 [GeneID=10320] knockout.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_LYMPHOID_MULTIPOTENT_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_DN
Systematic name | M7059
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphoid-primed multipotent progenitors versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_UP
Systematic name | M7060
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus granulo-monocyte progenitors.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE15330_HSC_VS_PRO_BCELL_DN
Systematic name | M7063
Organism | Mus musculus
PMID | 19345118
Authors | Ng SY,Yoshida T,Zhang J,Georgopoulos K
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus pro-B lymphocytes.
Full description | Regulation of lineage potential and transcriptional priming by Ikaros. New insight is provided into a bivalent regulation of lineage priming in the HSC and its lympho-myeloid restricted progeny the LMPP by the lymphoid lineage-determining factor Ikaros Whereas Ikaros is responsible for the activation of a cascade of lymphoid expression programs and for the establishment of lymphoid potential from the HSC to the LMPP it is also responsible for the repression of stem cell and erythroid genetic programs that are incompatible with further lineage restrictions emanating from the LMPP

Standard name | GSE12198_LOW_IL2_STIM_NK_CELL_VS_HIGH_IL2_STIM_NK_CELL_UP
Systematic name | M7064
Organism | Homo sapiens
PMID | 19383914
Authors | Fujisaki H,Kakuda H,Shimasaki N,Imai C,Ma J,Lockey T,Eldridge P,Leung WH,Campana D
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells: low dose versus high dose of IL2 [GeneID=3558].
Full description | Transcriptional profiling of NKAES-derived NK cells after 7 days of culture compared to primary human NK cells and NK cells stimulated by low or high dose IL2 after 7 days of culture.

Standard name | GSE12198_NK_VS_NK_ACT_EXPANSION_SYSTEM_DERIVED_NK_CELL_DN
Systematic name | M7065
Organism | Homo sapiens
PMID | 19383914
Authors | Fujisaki H,Kakuda H,Shimasaki N,Imai C,Ma J,Lockey T,Eldridge P,Leung WH,Campana D
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells: primary versus activated and expanded.
Full description | Transcriptional profiling of NKAES-derived NK cells after 7 days of culture compared to primary human NK cells and NK cells stimulated by low or high dose IL2 after 7 days of culture.

Standard name | GSE12198_LOW_IL2_STIM_NK_CELL_VS_HIGH_IL2_STIM_NK_CELL_DN
Systematic name | M7066
Organism | Homo sapiens
PMID | 19383914
Authors | Fujisaki H,Kakuda H,Shimasaki N,Imai C,Ma J,Lockey T,Eldridge P,Leung WH,Campana D
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells: low dose versus high dose of IL2 [GeneID=3558].
Full description | Transcriptional profiling of NKAES-derived NK cells after 7 days of culture compared to primary human NK cells and NK cells stimulated by low or high dose IL2 after 7 days of culture.

Standard name | GSE12198_CTRL_VS_HIGH_IL2_STIM_NK_CELL_UP
Systematic name | M7067
Organism | Homo sapiens
PMID | 19383914
Authors | Fujisaki H,Kakuda H,Shimasaki N,Imai C,Ma J,Lockey T,Eldridge P,Leung WH,Campana D
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells: primary versus stimulated by high dose of IL2 [GeneID=3558].
Full description | Transcriptional profiling of NKAES-derived NK cells after 7 days of culture compared to primary human NK cells and NK cells stimulated by low or high dose IL2 after 7 days of culture.

Standard name | GSE12198_CTRL_VS_HIGH_IL2_STIM_NK_CELL_DN
Systematic name | M7070
Organism | Homo sapiens
PMID | 19383914
Authors | Fujisaki H,Kakuda H,Shimasaki N,Imai C,Ma J,Lockey T,Eldridge P,Leung WH,Campana D
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells: primary versus stimulated by high dose of IL2 [GeneID=3558].
Full description | Transcriptional profiling of NKAES-derived NK cells after 7 days of culture compared to primary human NK cells and NK cells stimulated by low or high dose IL2 after 7 days of culture.

Standard name | GSE12198_NK_VS_NK_ACT_EXPANSION_SYSTEM_DERIVED_NK_CELL_UP
Systematic name | M7072
Organism | Homo sapiens
PMID | 19383914
Authors | Fujisaki H,Kakuda H,Shimasaki N,Imai C,Ma J,Lockey T,Eldridge P,Leung WH,Campana D
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells: primary versus activated and expanded.
Full description | Transcriptional profiling of NKAES-derived NK cells after 7 days of culture compared to primary human NK cells and NK cells stimulated by low or high dose IL2 after 7 days of culture.

Standard name | GSE12198_CTRL_VS_LOW_IL2_STIM_NK_CELL_UP
Systematic name | M7073
Organism | Homo sapiens
PMID | 19383914
Authors | Fujisaki H,Kakuda H,Shimasaki N,Imai C,Ma J,Lockey T,Eldridge P,Leung WH,Campana D
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells: primary versus stimulated by low dose of IL2 [GeneID=3558].
Full description | Transcriptional profiling of NKAES-derived NK cells after 7 days of culture compared to primary human NK cells and NK cells stimulated by low or high dose IL2 after 7 days of culture.

Standard name | GSE12198_CTRL_VS_LOW_IL2_STIM_NK_CELL_DN
Systematic name | M7074
Organism | Homo sapiens
PMID | 19383914
Authors | Fujisaki H,Kakuda H,Shimasaki N,Imai C,Ma J,Lockey T,Eldridge P,Leung WH,Campana D
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells: primary versus stimulated by low dose of IL2 [GeneID=3558].
Full description | Transcriptional profiling of NKAES-derived NK cells after 7 days of culture compared to primary human NK cells and NK cells stimulated by low or high dose IL2 after 7 days of culture.

Standard name | GSE14908_RESTING_VS_HDM_STIM_CD4_TCELL_ATOPIC_PATIENT_DN
Systematic name | M7075
Organism | Homo sapiens
PMID | 19414752
Authors | Bosco A,McKenna KL,Firth MJ,Sly PD,Holt PG
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells from atopic patients: resting versus stimulated with allergen (house dust mite).
Full description | The aim of this study was to employ a systems-level analysis to elucidate gene expression networks operating in the CD4 T-cell responses which underpin human atopic disease.

Standard name | GSE14908_RESTING_VS_HDM_STIM_CD4_TCELL_ATOPIC_PATIENT_UP
Systematic name | M7077
Organism | Homo sapiens
PMID | 19414752
Authors | Bosco A,McKenna KL,Firth MJ,Sly PD,Holt PG
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells from atopic patients: resting versus stimulated with allergen (house dust mite).
Full description | The aim of this study was to employ a systems-level analysis to elucidate gene expression networks operating in the CD4 T-cell responses which underpin human atopic disease.

Standard name | GSE14908_RESTING_VS_HDM_STIM_CD4_TCELL_NONATOPIC_PATIENT_DN
Systematic name | M7080
Organism | Homo sapiens
PMID | 19414752
Authors | Bosco A,McKenna KL,Firth MJ,Sly PD,Holt PG
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells from non-atopic donors: resting versus stimulated with allergen (house dust mite).
Full description | The aim of this study was to employ a systems-level analysis to elucidate gene expression networks operating in the CD4 T-cell responses which underpin human atopic disease.

Standard name | GSE14908_ATOPIC_VS_NONATOPIC_PATIENT_RESTING_CD4_TCELL_DN
Systematic name | M7083
Organism | Homo sapiens
PMID | 19414752
Authors | Bosco A,McKenna KL,Firth MJ,Sly PD,Holt PG
Category | C7
Sub-category |
Brief description | Genes down-regulated in resting CD4 [GeneID=920] T cells: atopy versus healthy.
Full description | The aim of this study was to employ a systems-level analysis to elucidate gene expression networks operating in the CD4 T-cell responses which underpin human atopic disease.

Standard name | GSE14908_RESTING_VS_HDM_STIM_CD4_TCELL_NONATOPIC_PATIENT_UP
Systematic name | M7086
Organism | Homo sapiens
PMID | 19414752
Authors | Bosco A,McKenna KL,Firth MJ,Sly PD,Holt PG
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells from non-atopic donors: resting versus stimulated with allergen (house dust mite).
Full description | The aim of this study was to employ a systems-level analysis to elucidate gene expression networks operating in the CD4 T-cell responses which underpin human atopic disease.

Standard name | GSE14908_ATOPIC_VS_NONATOPIC_PATIENT_HDM_STIM_CD4_TCELL_UP
Systematic name | M7091
Organism | Homo sapiens
PMID | 19414752
Authors | Bosco A,McKenna KL,Firth MJ,Sly PD,Holt PG
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells stimulated with allergen (house dust mite): atopy versus healthy.
Full description | The aim of this study was to employ a systems-level analysis to elucidate gene expression networks operating in the CD4 T-cell responses which underpin human atopic disease.

Standard name | GSE14908_ATOPIC_VS_NONATOPIC_PATIENT_RESTING_CD4_TCELL_UP
Systematic name | M7092
Organism | Homo sapiens
PMID | 19414752
Authors | Bosco A,McKenna KL,Firth MJ,Sly PD,Holt PG
Category | C7
Sub-category |
Brief description | Genes up-regulated in resting CD4 [GeneID=920] T cells: atopy versus healthy.
Full description | The aim of this study was to employ a systems-level analysis to elucidate gene expression networks operating in the CD4 T-cell responses which underpin human atopic disease.

Standard name | GSE14908_ATOPIC_VS_NONATOPIC_PATIENT_HDM_STIM_CD4_TCELL_DN
Systematic name | M7097
Organism | Homo sapiens
PMID | 19414752
Authors | Bosco A,McKenna KL,Firth MJ,Sly PD,Holt PG
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells stimulated with allergen (house dust mite): atopy versus healthy.
Full description | The aim of this study was to employ a systems-level analysis to elucidate gene expression networks operating in the CD4 T-cell responses which underpin human atopic disease.

Standard name | GSE15139_GMCSF_TREATED_VS_UNTREATED_NEUTROPHILS_DN
Systematic name | M7099
Organism | Homo sapiens
PMID | 19414807
Authors | Daryadel A,Yousefi S,Troi D,Schmid I,Schmidt-Mende J,Mordasini C,Dahinden CA,Ziemiecki A,Simon HU
Category | C7
Sub-category |
Brief description | Genes down-regulated in neutrophils treated with CSF2 [GeneID=1437] versus control.
Full description | The objective of this study was to compare the transcriptional repertoire of mature human neutrophils before and after GM-CSF treatment by using oligonucleotide microarrays. Leukotriene B4 (LTB4) is an important pro-inflammatory lipid mediator generated by neutrophils upon activation. Granulocyte/macrophage colony-stimulating factor (GM-CSF) stimulation is known to enhance agonist-mediated LTB4 production of neutrophils within minutes, a process called “priming”. Here, we demonstrate that GM-CSF also limits the production of LTB4 by neutrophils via a transcriptional mechanism at later time points. We identified hematopoietic specific Ras homologous (RhoH)/translocation three four (TTF), which was induced following GM-CSF stimulation in neutrophils, as a key regulator in this process. Neutrophils derived from RhoH/TTF-deficient (Rhoh-/-) mice demonstrated increased LTB4 production upon activation compared with normal mouse neutrophils. Moreover, neutrophils from cystic fibrosis patients expressed enhanced levels of RhoH/TTF and generated less LTB4 upon activation compared with normal human neutrophils. Taken together, these data suggest that RhoH/TTF represents an inducible feedback inhibitor in neutrophils that is involved in the limitation of innate immune responses.

Standard name | GSE15139_GMCSF_TREATED_VS_UNTREATED_NEUTROPHILS_UP
Systematic name | M7100
Organism | Homo sapiens
PMID | 19414807
Authors | Daryadel A,Yousefi S,Troi D,Schmid I,Schmidt-Mende J,Mordasini C,Dahinden CA,Ziemiecki A,Simon HU
Category | C7
Sub-category |
Brief description | Genes up-regulated in neutrophils treated with CSF2 [GeneID=1437] versus control.
Full description | The objective of this study was to compare the transcriptional repertoire of mature human neutrophils before and after GM-CSF treatment by using oligonucleotide microarrays. Leukotriene B4 (LTB4) is an important pro-inflammatory lipid mediator generated by neutrophils upon activation. Granulocyte/macrophage colony-stimulating factor (GM-CSF) stimulation is known to enhance agonist-mediated LTB4 production of neutrophils within minutes, a process called “priming”. Here, we demonstrate that GM-CSF also limits the production of LTB4 by neutrophils via a transcriptional mechanism at later time points. We identified hematopoietic specific Ras homologous (RhoH)/translocation three four (TTF), which was induced following GM-CSF stimulation in neutrophils, as a key regulator in this process. Neutrophils derived from RhoH/TTF-deficient (Rhoh-/-) mice demonstrated increased LTB4 production upon activation compared with normal mouse neutrophils. Moreover, neutrophils from cystic fibrosis patients expressed enhanced levels of RhoH/TTF and generated less LTB4 upon activation compared with normal human neutrophils. Taken together, these data suggest that RhoH/TTF represents an inducible feedback inhibitor in neutrophils that is involved in the limitation of innate immune responses.

Standard name | GSE15271_CXCR4_POS_VS_NEG_GC_BCELL_DN
Systematic name | M7101
Organism | Homo sapiens
PMID | 19494283
Authors | Caron G,Gallou Le S,Lamy T,Tarte K,Fest T
Category | C7
Sub-category |
Brief description | Genes down-regulated in centroblasts versus centrocytes.
Full description | Functional discrimination between normal centroblast and centrocyte obtained from human inflamed tonsils after cell sorting. We used microarrays to detail the segregation between these two B cell subsets

Standard name | GSE15271_CXCR4_POS_VS_NEG_GC_BCELL_UP
Systematic name | M7103
Organism | Homo sapiens
PMID | 19494283
Authors | Caron G,Gallou Le S,Lamy T,Tarte K,Fest T
Category | C7
Sub-category |
Brief description | Genes up-regulated in centroblasts versus centrocytes.
Full description | Functional discrimination between normal centroblast and centrocyte obtained from human inflamed tonsils after cell sorting. We used microarrays to detail the segregation between these two B cell subsets

Standard name | GSE15624_3H_VS_6H_HALOFUGINONE_TREATED_CD4_TCELL_UP
Systematic name | M7105
Organism | Mus musculus
PMID | 19498172
Authors | Sundrud MS,Koralov SB,Feuerer M,Calado DP,Kozhaya AE,Rhule-Smith A,Lefebvre RE,Unutmaz D,Mazitschek R,Waldner H,Whitman M,Keller T,Rao A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with halofuginone [PubChem=400772]: 3h versus 6h.
Full description | T cell differentiation to the Th17 effector subset requires stimulation through the T cell and co-stimulatory receptors, together with cytokine stimulation by TGFb and IL-6. The small molecule halofuginone (HF) inhibits Th17 cell development and induces a pattern of stress-regulated gene expression that mimics amino acid starvation. We used global transcript profiling to ask how halofuginone modulates gene expression induced during T cell activaiton and Th17 differentiation

Standard name | GSE15624_CTRL_VS_6H_HALOFUGINONE_TREATED_CD4_TCELL_DN
Systematic name | M7106
Organism | Mus musculus
PMID | 19498172
Authors | Sundrud MS,Koralov SB,Feuerer M,Calado DP,Kozhaya AE,Rhule-Smith A,Lefebvre RE,Unutmaz D,Mazitschek R,Waldner H,Whitman M,Keller T,Rao A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: control versus treated with halofuginone [PubChem=400772] for 6h.
Full description | T cell differentiation to the Th17 effector subset requires stimulation through the T cell and co-stimulatory receptors, together with cytokine stimulation by TGFb and IL-6. The small molecule halofuginone (HF) inhibits Th17 cell development and induces a pattern of stress-regulated gene expression that mimics amino acid starvation. We used global transcript profiling to ask how halofuginone modulates gene expression induced during T cell activaiton and Th17 differentiation

Standard name | GSE15624_3H_VS_6H_HALOFUGINONE_TREATED_CD4_TCELL_DN
Systematic name | M7109
Organism | Mus musculus
PMID | 19498172
Authors | Sundrud MS,Koralov SB,Feuerer M,Calado DP,Kozhaya AE,Rhule-Smith A,Lefebvre RE,Unutmaz D,Mazitschek R,Waldner H,Whitman M,Keller T,Rao A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with halofuginone [PubChem=400772]: 3h versus 6h.
Full description | T cell differentiation to the Th17 effector subset requires stimulation through the T cell and co-stimulatory receptors, together with cytokine stimulation by TGFb and IL-6. The small molecule halofuginone (HF) inhibits Th17 cell development and induces a pattern of stress-regulated gene expression that mimics amino acid starvation. We used global transcript profiling to ask how halofuginone modulates gene expression induced during T cell activaiton and Th17 differentiation

Standard name | GSE15624_CTRL_VS_6H_HALOFUGINONE_TREATED_CD4_TCELL_UP
Systematic name | M7111
Organism | Mus musculus
PMID | 19498172
Authors | Sundrud MS,Koralov SB,Feuerer M,Calado DP,Kozhaya AE,Rhule-Smith A,Lefebvre RE,Unutmaz D,Mazitschek R,Waldner H,Whitman M,Keller T,Rao A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: control versus treated with halofuginone [PubChem=400772] for 6h.
Full description | T cell differentiation to the Th17 effector subset requires stimulation through the T cell and co-stimulatory receptors, together with cytokine stimulation by TGFb and IL-6. The small molecule halofuginone (HF) inhibits Th17 cell development and induces a pattern of stress-regulated gene expression that mimics amino acid starvation. We used global transcript profiling to ask how halofuginone modulates gene expression induced during T cell activaiton and Th17 differentiation

Standard name | GSE15624_CTRL_VS_3H_HALOFUGINONE_TREATED_CD4_TCELL_DN
Systematic name | M7115
Organism | Mus musculus
PMID | 19498172
Authors | Sundrud MS,Koralov SB,Feuerer M,Calado DP,Kozhaya AE,Rhule-Smith A,Lefebvre RE,Unutmaz D,Mazitschek R,Waldner H,Whitman M,Keller T,Rao A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: control versus treated with halofuginone [PubChem=400772] for 3h.
Full description | T cell differentiation to the Th17 effector subset requires stimulation through the T cell and co-stimulatory receptors, together with cytokine stimulation by TGFb and IL-6. The small molecule halofuginone (HF) inhibits Th17 cell development and induces a pattern of stress-regulated gene expression that mimics amino acid starvation. We used global transcript profiling to ask how halofuginone modulates gene expression induced during T cell activaiton and Th17 differentiation

Standard name | GSE15624_CTRL_VS_3H_HALOFUGINONE_TREATED_CD4_TCELL_UP
Systematic name | M7116
Organism | Mus musculus
PMID | 19498172
Authors | Sundrud MS,Koralov SB,Feuerer M,Calado DP,Kozhaya AE,Rhule-Smith A,Lefebvre RE,Unutmaz D,Mazitschek R,Waldner H,Whitman M,Keller T,Rao A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: control versus treated with halofuginone [PubChem=400772] for 3h.
Full description | T cell differentiation to the Th17 effector subset requires stimulation through the T cell and co-stimulatory receptors, together with cytokine stimulation by TGFb and IL-6. The small molecule halofuginone (HF) inhibits Th17 cell development and induces a pattern of stress-regulated gene expression that mimics amino acid starvation. We used global transcript profiling to ask how halofuginone modulates gene expression induced during T cell activaiton and Th17 differentiation

Standard name | GSE9960_HEALTHY_VS_GRAM_NEG_SEPSIS_PBMC_UP
Systematic name | M7118
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood monocytes (PMBC): healthy versus Gram negative sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_HEALTHY_VS_GRAM_NEG_SEPSIS_PBMC_DN
Systematic name | M7119
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood monocytes (PMBC): healthy versus Gram negative sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_HEALTHY_VS_GRAM_POS_SEPSIS_PBMC_UP
Systematic name | M7120
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood monocytes (PMBC):healthy versus Gram positive sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_HEALTHY_VS_GRAM_POS_SEPSIS_PBMC_DN
Systematic name | M7121
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood monocytes (PMBC):healthy versus Gram positive sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_HEALTHY_VS_GRAM_NEG_AND_POS_SEPSIS_PBMC_UP
Systematic name | M7123
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood monocytes (PMBC): healthy versus mixed infection sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_HEALTHY_VS_GRAM_NEG_AND_POS_SEPSIS_PBMC_DN
Systematic name | M7124
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood monocytes (PMBC): healthy versus mixed infection sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_HEALTHY_VS_SEPSIS_PBMC_UP
Systematic name | M7125
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood monocytes (PMBC): healthy versus sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_HEALTHY_VS_SEPSIS_PBMC_DN
Systematic name | M7127
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood monocytes (PMBC): healthy versus sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_GRAM_NEG_VS_GRAM_POS_SEPSIS_PBMC_UP
Systematic name | M7128
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood monocytes (PMBC): Gram negative sepsis versus Gram positive sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_GRAM_NEG_VS_GRAM_POS_SEPSIS_PBMC_DN
Systematic name | M7129
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood monocytes (PMBC): Gram negative sepsis versus Gram positive sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_GRAM_NEG_VS_GRAM_NEG_AND_POS_SEPSIS_PBMC_UP
Systematic name | M7130
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood monocytes (PMBC): Gram negative sepsis versus mixed infection sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_GRAM_NEG_VS_GRAM_NEG_AND_POS_SEPSIS_PBMC_DN
Systematic name | M7131
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood monocytes (PMBC): Gram negative sepsis versus mixed infection sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_GRAM_POS_VS_GRAM_NEG_AND_POS_SEPSIS_PBMC_UP
Systematic name | M7132
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood monocytes (PMBC): Gram positive sepsis versus mixed infection sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE9960_GRAM_POS_VS_GRAM_NEG_AND_POS_SEPSIS_PBMC_DN
Systematic name | M7133
Organism | Homo sapiens
PMID | 19535937
Authors | Payen D,Lukaszewicz AC
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood monocytes (PMBC): Gram positive sepsis versus mixed infection sepsis.
Full description | To identify signature genes that help distinguish (1) sepsis from non-infectious causes of systemic inflammatory response syndrome, (2) between Gram-positive and Gram-negative sepsis.

Standard name | GSE12392_CD8A_POS_VS_NEG_SPLEEN_IFNB_KO_DC_DN
Systematic name | M7134
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenic dendritic cells from IFNB1 [GeneID=3456] knockout mice: CD8A+ [GeneID=925] versus CD8A- [GeneID=925] populations.
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_CD8A_POS_VS_NEG_SPLEEN_DC_UP
Systematic name | M7135
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype splenic dendritic cells: CD8A+ [GeneID=925] versus CD8A- [GeneID=925].
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_IFNAR_KO_VS_IFNB_KO_CD8_NEG_SPLEEN_DC_DN
Systematic name | M7136
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A- [GeneID=925] splenic dendritic cells: IFNAR1 [GeneID=3454] knockout versus IFNB1 [GeneID=3456] knockout.
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_CD8A_POS_VS_NEG_SPLEEN_IFNB_KO_DC_UP
Systematic name | M7138
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenic dendritic cells from IFNB1 [GeneID=3456] knockout mice: CD8A+ [GeneID=925] versus CD8A- [GeneID=925] populations.
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_WT_VS_IFNAR_KO_CD8A_NEG_SPLEEN_DC_DN
Systematic name | M7139
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A- [GeneID=925] splenic dendritic cells: wildtype versus IFNAR1 [GeneID=3454] knockout mice.
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_IFNAR_KO_VS_IFNB_KO_CD8_NEG_SPLEEN_DC_UP
Systematic name | M7142
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A- [GeneID=925] splenic dendritic cells: IFNAR1 [GeneID=3454] knockout versus IFNB1 [GeneID=3456] knockout.
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_CD8A_POS_VS_NEG_SPLEEN_DC_DN
Systematic name | M7143
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype splenic dendritic cells: CD8A+ [GeneID=925] versus CD8A- [GeneID=925].
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_WT_VS_IFNB_KO_CD8A_POS_SPLEEN_DC_DN
Systematic name | M7144
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A+ [GeneID=925] splenic dendritic cells: wildtype versus IFNB1 [GeneID=3456] knockout mice.
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_WT_VS_IFNAR_KO_CD8A_NEG_SPLEEN_DC_UP
Systematic name | M7147
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A- [GeneID=925] splenic dendritic cells: wildtype versus IFNAR1 [GeneID=3454] knockout mice.
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_WT_VS_IFNB_KO_CD8A_NEG_SPLEEN_DC_UP
Systematic name | M7148
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A- [GeneID=925] splenic dendritic cells: wildtype versus IFNB1 [GeneID=3456] knockout mice.
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_WT_VS_IFNB_KO_CD8A_NEG_SPLEEN_DC_DN
Systematic name | M7150
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A- [GeneID=925] splenic dendritic cells: wildtype versus IFNB1 [GeneID=3456] knockout mice.
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE12392_WT_VS_IFNB_KO_CD8A_POS_SPLEEN_DC_UP
Systematic name | M7152
Organism | Mus musculus
PMID | 19581626
Authors | Zietara N,Łyszkiewicz M,Gekara N,Puchałka J,Santos Dos VA,Hunt CR,Pandita TK,Lienenklaus S,Weiss S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A+ [GeneID=925] splenic dendritic cells: wildtype versus IFNB1 [GeneID=3456] knockout mice.
Full description | Type I Interferons encompasses a large family of closely related cytokines comprising of at least 13 IFN-α isotypes and single IFN-β. Both IFN-α and IFN-β exert their activity through a common receptor IFNAR. Type I Interferons have broad regulatory effects and various subtypes of dendritic cells are influenced by this cytokines. In our study we asked question whether the low, constitutive levels of type I Interferons produced under steady state conditions are important for proper function of splenic conventional dendritic cells.

Standard name | GSE16697_CD4_TCELL_VS_TFH_CD4_TCELL_UP
Systematic name | M7153
Organism | Mus musculus
PMID | 19608860
Authors | Johnston RJ,Poholek AC,DiToro D,Yusuf I,Eto D,Barnett B,Dent AL,Craft J,Crotty S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells versus follicular helper CD4 [GeneID=920] T cells.
Full description | Analysis of in vivo antigen-specific (LCMV-specific, SMARTA TCR transgenic) follicular helper CD4 T cells (CXCR5high),versus non-follicular helper CD4 T cells (CXCR5low), eight days after viral infection. A paper including data analysis of these experiments has been accepted for publication (Robert J. Johnston et al. Bcl6 and Blimp-1 are reciprocal and antagonistic regulators of follicular helper CD4 T cell differentiation).

Standard name | GSE16697_CD4_TCELL_VS_TFH_CD4_TCELL_DN
Systematic name | M7155
Organism | Mus musculus
PMID | 19608860
Authors | Johnston RJ,Poholek AC,DiToro D,Yusuf I,Eto D,Barnett B,Dent AL,Craft J,Crotty S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells versus follicular helper CD4 [GeneID=920] T cells.
Full description | Analysis of in vivo antigen-specific (LCMV-specific, SMARTA TCR transgenic) follicular helper CD4 T cells (CXCR5high),versus non-follicular helper CD4 T cells (CXCR5low), eight days after viral infection. A paper including data analysis of these experiments has been accepted for publication (Robert J. Johnston et al. Bcl6 and Blimp-1 are reciprocal and antagonistic regulators of follicular helper CD4 T cell differentiation).

Standard name | GSE15735_CTRL_VS_HDAC_INHIBITOR_TREATED_CD4_TCELL_2H_UP
Systematic name | M7156
Organism | Homo sapiens
PMID | 19698979
Authors | Wang Z,Zang C,Cui K,Schones DE,Barski A,Peng W,Zhao K
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: control versus treated with HDAC inhibitors for 2h.
Full description | Histone acetyltransferases (HATs) and deacetylases (HDACs) function antagonistically to control histone acetylation. As acetylation is a histone mark for active transcription, HATs have been associated with active and HDACs with inactive genes. We describe here genome-wide mapping of HATs and HDACs binding on chromatin and ﬁnd that both are found at active genes with acetylated histones. Our data provide evidence that HATs and HDACs are both targeted to transcribed regions of active genes by phosphorylated RNA Pol II. Furthermore, the majority of HDACs in the human genome function to reset chromatin by removing acetylation at active genes. Inactive genes that are primed by MLL-mediated histone H3K4 methylation are subject to a dynamic cycle of acetylation and deacetylation by transient HAT/HDAC binding, preventing Pol II from binding to these genes but poising them for future activation. Silent genes without any H3K4 methylation signal show no evidence of being bound by HDACs.

Standard name | GSE15735_CTRL_VS_HDAC_INHIBITOR_TREATED_CD4_TCELL_12H_DN
Systematic name | M7157
Organism | Homo sapiens
PMID | 19698979
Authors | Wang Z,Zang C,Cui K,Schones DE,Barski A,Peng W,Zhao K
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: control versus treated with HDAC inhibitors for 12h.
Full description | Histone acetyltransferases (HATs) and deacetylases (HDACs) function antagonistically to control histone acetylation. As acetylation is a histone mark for active transcription, HATs have been associated with active and HDACs with inactive genes. We describe here genome-wide mapping of HATs and HDACs binding on chromatin and ﬁnd that both are found at active genes with acetylated histones. Our data provide evidence that HATs and HDACs are both targeted to transcribed regions of active genes by phosphorylated RNA Pol II. Furthermore, the majority of HDACs in the human genome function to reset chromatin by removing acetylation at active genes. Inactive genes that are primed by MLL-mediated histone H3K4 methylation are subject to a dynamic cycle of acetylation and deacetylation by transient HAT/HDAC binding, preventing Pol II from binding to these genes but poising them for future activation. Silent genes without any H3K4 methylation signal show no evidence of being bound by HDACs.

Standard name | GSE15735_2H_VS_12H_HDAC_INHIBITOR_TREATED_CD4_TCELL_UP
Systematic name | M7159
Organism | Homo sapiens
PMID | 19698979
Authors | Wang Z,Zang C,Cui K,Schones DE,Barski A,Peng W,Zhao K
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with HDAC inhibitors: 2h versus 12h.
Full description | Histone acetyltransferases (HATs) and deacetylases (HDACs) function antagonistically to control histone acetylation. As acetylation is a histone mark for active transcription, HATs have been associated with active and HDACs with inactive genes. We describe here genome-wide mapping of HATs and HDACs binding on chromatin and ﬁnd that both are found at active genes with acetylated histones. Our data provide evidence that HATs and HDACs are both targeted to transcribed regions of active genes by phosphorylated RNA Pol II. Furthermore, the majority of HDACs in the human genome function to reset chromatin by removing acetylation at active genes. Inactive genes that are primed by MLL-mediated histone H3K4 methylation are subject to a dynamic cycle of acetylation and deacetylation by transient HAT/HDAC binding, preventing Pol II from binding to these genes but poising them for future activation. Silent genes without any H3K4 methylation signal show no evidence of being bound by HDACs.

Standard name | GSE15735_CTRL_VS_HDAC_INHIBITOR_TREATED_CD4_TCELL_2H_DN
Systematic name | M7161
Organism | Homo sapiens
PMID | 19698979
Authors | Wang Z,Zang C,Cui K,Schones DE,Barski A,Peng W,Zhao K
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: control versus treated with HDAC inhibitors for 2h.
Full description | Histone acetyltransferases (HATs) and deacetylases (HDACs) function antagonistically to control histone acetylation. As acetylation is a histone mark for active transcription, HATs have been associated with active and HDACs with inactive genes. We describe here genome-wide mapping of HATs and HDACs binding on chromatin and ﬁnd that both are found at active genes with acetylated histones. Our data provide evidence that HATs and HDACs are both targeted to transcribed regions of active genes by phosphorylated RNA Pol II. Furthermore, the majority of HDACs in the human genome function to reset chromatin by removing acetylation at active genes. Inactive genes that are primed by MLL-mediated histone H3K4 methylation are subject to a dynamic cycle of acetylation and deacetylation by transient HAT/HDAC binding, preventing Pol II from binding to these genes but poising them for future activation. Silent genes without any H3K4 methylation signal show no evidence of being bound by HDACs.

Standard name | GSE15735_2H_VS_12H_HDAC_INHIBITOR_TREATED_CD4_TCELL_DN
Systematic name | M7162
Organism | Homo sapiens
PMID | 19698979
Authors | Wang Z,Zang C,Cui K,Schones DE,Barski A,Peng W,Zhao K
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with HDAC inhibitors: 2h versus 12h.
Full description | Histone acetyltransferases (HATs) and deacetylases (HDACs) function antagonistically to control histone acetylation. As acetylation is a histone mark for active transcription, HATs have been associated with active and HDACs with inactive genes. We describe here genome-wide mapping of HATs and HDACs binding on chromatin and ﬁnd that both are found at active genes with acetylated histones. Our data provide evidence that HATs and HDACs are both targeted to transcribed regions of active genes by phosphorylated RNA Pol II. Furthermore, the majority of HDACs in the human genome function to reset chromatin by removing acetylation at active genes. Inactive genes that are primed by MLL-mediated histone H3K4 methylation are subject to a dynamic cycle of acetylation and deacetylation by transient HAT/HDAC binding, preventing Pol II from binding to these genes but poising them for future activation. Silent genes without any H3K4 methylation signal show no evidence of being bound by HDACs.

Standard name | GSE15735_CTRL_VS_HDAC_INHIBITOR_TREATED_CD4_TCELL_12H_UP
Systematic name | M7163
Organism | Homo sapiens
PMID | 19698979
Authors | Wang Z,Zang C,Cui K,Schones DE,Barski A,Peng W,Zhao K
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: control versus treated with HDAC inhibitors for 12h.
Full description | Histone acetyltransferases (HATs) and deacetylases (HDACs) function antagonistically to control histone acetylation. As acetylation is a histone mark for active transcription, HATs have been associated with active and HDACs with inactive genes. We describe here genome-wide mapping of HATs and HDACs binding on chromatin and ﬁnd that both are found at active genes with acetylated histones. Our data provide evidence that HATs and HDACs are both targeted to transcribed regions of active genes by phosphorylated RNA Pol II. Furthermore, the majority of HDACs in the human genome function to reset chromatin by removing acetylation at active genes. Inactive genes that are primed by MLL-mediated histone H3K4 methylation are subject to a dynamic cycle of acetylation and deacetylation by transient HAT/HDAC binding, preventing Pol II from binding to these genes but poising them for future activation. Silent genes without any H3K4 methylation signal show no evidence of being bound by HDACs.

Standard name | GSE17812_WT_VS_THPOK_KO_MEMORY_CD8_TCELL_DN
Systematic name | M7164
Organism | Mus musculus
PMID | 19734230
Authors | Setoguchi R,Taniuchi I,Bevan MJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in memory CD8 T cells: wildtype wt versus ZBTB7B [GeneID=51043] knockout.
Full description | We noticed that ThPOK repression is readily abrogated upon in vitro TCR stimulation of peripheral CD8 T cells. This observation prompted us to investigate a role of ThPOK in the CD8 T cell response to an acute viral infection. We observed that clonal expansion is significantly less in both primary and secondary CD8 T cell responses in the absence of functional ThPOK. To approach this mechanism, we carried out a microarray analysis for comparison of gene expression between ThPOKhd/hd and ThPOKwt/wt P14 memory T cells.

Standard name | GSE17812_WT_VS_THPOK_KO_MEMORY_CD8_TCELL_UP
Systematic name | M7166
Organism | Mus musculus
PMID | 19734230
Authors | Setoguchi R,Taniuchi I,Bevan MJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in memory CD8 T cells: wildtype wt versus ZBTB7B [GeneID=51043] knockout.
Full description | We noticed that ThPOK repression is readily abrogated upon in vitro TCR stimulation of peripheral CD8 T cells. This observation prompted us to investigate a role of ThPOK in the CD8 T cell response to an acute viral infection. We observed that clonal expansion is significantly less in both primary and secondary CD8 T cell responses in the absence of functional ThPOK. To approach this mechanism, we carried out a microarray analysis for comparison of gene expression between ThPOKhd/hd and ThPOKwt/wt P14 memory T cells.

Standard name | GSE17186_CD21LOW_VS_CD21HIGH_TRANSITIONAL_BCELL_UP
Systematic name | M7168
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in transitional B lymphocytes: CR2 [GeneID=1380] low versus CR2 [GeneID=1380] high.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_MEMORY_VS_NAIVE_BCELL_UP
Systematic name | M7170
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: memory versus naïve.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_MEMORY_VS_NAIVE_BCELL_DN
Systematic name | M7171
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: memory versus naïve.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_NAIVE_VS_CD21HIGH_TRANSITIONAL_BCELL_CORD_BLOOD_UP
Systematic name | M7172
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes from cord blood: naïve versus transitional CR2 [GeneID=1380] high.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_CD21LOW_VS_CD21HIGH_TRANSITIONAL_BCELL_DN
Systematic name | M7174
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in transitional B lymphocytes: CR2 [GeneID=1380] low versus CR2 [GeneID=1380] high.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_NAIVE_VS_CD21LOW_TRANSITIONAL_BCELL_CORD_BLOOD_UP
Systematic name | M7175
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes from cord blood: naïve versus transitional CR2 [GeneID=1380].
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_NAIVE_VS_CD21LOW_TRANSITIONAL_BCELL_CORD_BLOOD_DN
Systematic name | M7177
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes from cord blood: naïve versus transitional CR2 [GeneID=1380].
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_BLOOD_VS_CORD_BLOOD_NAIVE_BCELL_DN
Systematic name | M7178
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve B lymphocytes versus those from cord blood.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_MEMORY_VS_CD21LOW_TRANSITIONAL_BCELL_UP
Systematic name | M7180
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: memory versus transitional CR2 [GeneID=1380] low.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_MEMORY_VS_CD21LOW_TRANSITIONAL_BCELL_DN
Systematic name | M7183
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: memory versus transitional CR2 [GeneID=1380] low.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_BLOOD_VS_CORD_BLOOD_CD21HIGH_TRANSITIONAL_BCELL_UP
Systematic name | M7185
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in transitional CR2 [GeneID=1380] high B lymphocytes versus those from cord blood.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_BLOOD_VS_CORD_BLOOD_CD21HIGH_TRANSITIONAL_BCELL_DN
Systematic name | M7186
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in transitional CR2 [GeneID=1380] high B lymphocytes versus those from cord blood.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_NAIVE_VS_CD21HIGH_TRANSITIONAL_BCELL_DN
Systematic name | M7187
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: naïve versus transitional CR2 [GeneID=1380] high.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_NAIVE_VS_CD21HIGH_TRANSITIONAL_BCELL_CORD_BLOOD_DN
Systematic name | M7190
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes from cord blood: naïve versus transitional CR2 [GeneID=1380] high.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_CD21LOW_VS_CD21HIGH_TRANSITIONAL_BCELL_CORD_BLOOD_UP
Systematic name | M7192
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in transitional B lymphocytes from cord blood: CR2 [GeneID=1380] low versus CR2 [GeneID=1380] high.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_CD21LOW_VS_CD21HIGH_TRANSITIONAL_BCELL_CORD_BLOOD_DN
Systematic name | M7193
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in transitional B lymphocytes from cord blood: CR2 [GeneID=1380] low versus CR2 [GeneID=1380] high.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_BLOOD_VS_CORD_BLOOD_NAIVE_BCELL_UP
Systematic name | M7194
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve B lymphocytes versus those from cord blood.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_BLOOD_VS_CORD_BLOOD_CD21LOW_TRANSITIONAL_BCELL_UP
Systematic name | M7195
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in transitional CR2 [GeneID=1380] low B lymphocytes versus those from cord blood.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_BLOOD_VS_CORD_BLOOD_CD21LOW_TRANSITIONAL_BCELL_DN
Systematic name | M7196
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in transitional CR2 [GeneID=1380] low B lymphocytes versus those from cord blood.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_NAIVE_VS_CD21LOW_TRANSITIONAL_BCELL_DN
Systematic name | M7197
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: naïve versus transitional CR2 [GeneID=1380] low.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_NAIVE_VS_CD21HIGH_TRANSITIONAL_BCELL_UP
Systematic name | M7198
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: naïve versus transitional CR2 [GeneID=1380] high.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_MEMORY_VS_CD21HIGH_TRANSITIONAL_BCELL_UP
Systematic name | M7200
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: memory versus transitional CR2 [GeneID=1380] high.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_MEMORY_VS_CD21HIGH_TRANSITIONAL_BCELL_DN
Systematic name | M7205
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: memory versus transitional CR2 [GeneID=1380] high.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE17186_NAIVE_VS_CD21LOW_TRANSITIONAL_BCELL_UP
Systematic name | M7206
Organism | Homo sapiens
PMID | 19965666
Authors | Suryani S,Fulcher DA,Santner-Nanan B,Nanan R,Wong M,Shaw PJ,Gibson J,Williams A,Tangye SG
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: naïve versus transitional CR2 [GeneID=1380] low.
Full description | Goals/objectives: to identify various gene expression in B cell subsets derived from human PBMC and cord blood

Standard name | GSE18203_CTRL_VS_INTRATUMORAL_CPG_INJ_MC38_TUMOR_UP
Systematic name | M7207
Organism | Mus musculus
PMID | 19996209
Authors | Westwood JA,Haynes NM,Sharkey J,McLaughlin N,Pegram HJ,Schwendener RA,Smyth MJ,Darcy PK,Kershaw MH
Category | C7
Sub-category |
Brief description | Genes up-regulated in tumors established by injecting MC38 cells (colon cancer): control versus CpG oligodeoxynucleotide 1826.
Full description | To determine the effect on gene expression of intratumoral injection of the Toll-like receptor agonist CpG1826. MC38 colon cancer cells were injected subcutaneously into C57BL/6 mice and allowed to establish until ~40 mm2.

Standard name | GSE18203_CTRL_VS_INTRATUMORAL_CPG_INJ_MC38_TUMOR_DN
Systematic name | M7208
Organism | Mus musculus
PMID | 19996209
Authors | Westwood JA,Haynes NM,Sharkey J,McLaughlin N,Pegram HJ,Schwendener RA,Smyth MJ,Darcy PK,Kershaw MH
Category | C7
Sub-category |
Brief description | Genes down-regulated in tumors established by injecting MC38 cells (colon cancer): control versus CpG oligodeoxynucleotide 1826.
Full description | To determine the effect on gene expression of intratumoral injection of the Toll-like receptor agonist CpG1826. MC38 colon cancer cells were injected subcutaneously into C57BL/6 mice and allowed to establish until ~40 mm2.

Standard name | GSE16266_CTRL_VS_HEATSHOCK_AND_LPS_STIM_MEF_DN
Systematic name | M7209
Organism | Mus musculus
PMID | 20018623
Authors | Takii R,Inouye S,Fujimoto M,Nakamura T,Shinkawa T,Prakasam R,Tan K,Hayashida N,Ichikawa H,Hai T,Nakai A
Category | C7
Sub-category |
Brief description | Genes down-regulated inmouse embryonic fibroblasts (MEF): control versus LPS and heat shock.
Full description | To clarify inflammatory genes whose expression is suppressed at high temperatures, we performed comprehensive analysis of gene expression by using a DNA microarray. Two independent primary cultures of mouse embryo fibroblasts (MEF1 and MEF2) were treated with LPS for 4 hours, or treated with LPS for 4 hours after the pretreatment with heat shock at 42˚C for 1 hour, and we identified 100 genes that undergo more than a 3-fold increase with LPS treatment. Remarkably, 86 genes (86%) underwent less than a 2-fold increase after combined treatments with heat shock and LPS in MEF1 and MEF2 cells.

Standard name | GSE16266_LPS_VS_HEATSHOCK_AND_LPS_STIM_MEF_UP
Systematic name | M7210
Organism | Mus musculus
PMID | 20018623
Authors | Takii R,Inouye S,Fujimoto M,Nakamura T,Shinkawa T,Prakasam R,Tan K,Hayashida N,Ichikawa H,Hai T,Nakai A
Category | C7
Sub-category |
Brief description | Genes up-regulated in mouse embryonic fibroblasts (MEF): LPS versus LPS and heat shock.
Full description | To clarify inflammatory genes whose expression is suppressed at high temperatures, we performed comprehensive analysis of gene expression by using a DNA microarray. Two independent primary cultures of mouse embryo fibroblasts (MEF1 and MEF2) were treated with LPS for 4 hours, or treated with LPS for 4 hours after the pretreatment with heat shock at 42˚C for 1 hour, and we identified 100 genes that undergo more than a 3-fold increase with LPS treatment. Remarkably, 86 genes (86%) underwent less than a 2-fold increase after combined treatments with heat shock and LPS in MEF1 and MEF2 cells.

Standard name | GSE16266_CTRL_VS_HEATSHOCK_AND_LPS_STIM_MEF_UP
Systematic name | M7211
Organism | Mus musculus
PMID | 20018623
Authors | Takii R,Inouye S,Fujimoto M,Nakamura T,Shinkawa T,Prakasam R,Tan K,Hayashida N,Ichikawa H,Hai T,Nakai A
Category | C7
Sub-category |
Brief description | Genes up-regulated inmouse embryonic fibroblasts (MEF): control versus LPS and heat shock.
Full description | To clarify inflammatory genes whose expression is suppressed at high temperatures, we performed comprehensive analysis of gene expression by using a DNA microarray. Two independent primary cultures of mouse embryo fibroblasts (MEF1 and MEF2) were treated with LPS for 4 hours, or treated with LPS for 4 hours after the pretreatment with heat shock at 42˚C for 1 hour, and we identified 100 genes that undergo more than a 3-fold increase with LPS treatment. Remarkably, 86 genes (86%) underwent less than a 2-fold increase after combined treatments with heat shock and LPS in MEF1 and MEF2 cells.

Standard name | GSE16266_CTRL_VS_LPS_STIM_MEF_DN
Systematic name | M7212
Organism | Mus musculus
PMID | 20018623
Authors | Takii R,Inouye S,Fujimoto M,Nakamura T,Shinkawa T,Prakasam R,Tan K,Hayashida N,Ichikawa H,Hai T,Nakai A
Category | C7
Sub-category |
Brief description | Genes down-regulated in mouse embryonic fibroblasts (MEF): control versus LPS.
Full description | To clarify inflammatory genes whose expression is suppressed at high temperatures, we performed comprehensive analysis of gene expression by using a DNA microarray. Two independent primary cultures of mouse embryo fibroblasts (MEF1 and MEF2) were treated with LPS for 4 hours, or treated with LPS for 4 hours after the pretreatment with heat shock at 42˚C for 1 hour, and we identified 100 genes that undergo more than a 3-fold increase with LPS treatment. Remarkably, 86 genes (86%) underwent less than a 2-fold increase after combined treatments with heat shock and LPS in MEF1 and MEF2 cells.

Standard name | GSE16266_LPS_VS_HEATSHOCK_AND_LPS_STIM_MEF_DN
Systematic name | M7217
Organism | Mus musculus
PMID | 20018623
Authors | Takii R,Inouye S,Fujimoto M,Nakamura T,Shinkawa T,Prakasam R,Tan K,Hayashida N,Ichikawa H,Hai T,Nakai A
Category | C7
Sub-category |
Brief description | Genes down-regulated in mouse embryonic fibroblasts (MEF): LPS versus LPS and heat shock.
Full description | To clarify inflammatory genes whose expression is suppressed at high temperatures, we performed comprehensive analysis of gene expression by using a DNA microarray. Two independent primary cultures of mouse embryo fibroblasts (MEF1 and MEF2) were treated with LPS for 4 hours, or treated with LPS for 4 hours after the pretreatment with heat shock at 42˚C for 1 hour, and we identified 100 genes that undergo more than a 3-fold increase with LPS treatment. Remarkably, 86 genes (86%) underwent less than a 2-fold increase after combined treatments with heat shock and LPS in MEF1 and MEF2 cells.

Standard name | GSE16266_CTRL_VS_LPS_STIM_MEF_UP
Systematic name | M7219
Organism | Mus musculus
PMID | 20018623
Authors | Takii R,Inouye S,Fujimoto M,Nakamura T,Shinkawa T,Prakasam R,Tan K,Hayashida N,Ichikawa H,Hai T,Nakai A
Category | C7
Sub-category |
Brief description | Genes up-regulated in mouse embryonic fibroblasts (MEF): control versus LPS.
Full description | To clarify inflammatory genes whose expression is suppressed at high temperatures, we performed comprehensive analysis of gene expression by using a DNA microarray. Two independent primary cultures of mouse embryo fibroblasts (MEF1 and MEF2) were treated with LPS for 4 hours, or treated with LPS for 4 hours after the pretreatment with heat shock at 42˚C for 1 hour, and we identified 100 genes that undergo more than a 3-fold increase with LPS treatment. Remarkably, 86 genes (86%) underwent less than a 2-fold increase after combined treatments with heat shock and LPS in MEF1 and MEF2 cells.

Standard name | GSE19198_CTRL_VS_IL21_TREATED_TCELL_6H_UP
Systematic name | M7221
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: control (0h) versus IL21 [GeneID=59067] treatment for 6h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_CTRL_VS_IL21_TREATED_TCELL_1H_DN
Systematic name | M7222
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: control (0h) versus IL21 [GeneID=59067] treatment for 1h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_1H_VS_6H_IL21_TREATED_TCELL_UP
Systematic name | M7224
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells treated with IL21 [GeneID=59067]: 1h versus 6h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_CTRL_VS_IL21_TREATED_TCELL_1H_UP
Systematic name | M7226
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: control (0h) versus IL21 [GeneID=59067] treatment for 1h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_6H_VS_24H_IL21_TREATED_TCELL_UP
Systematic name | M7227
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells treated with IL21 [GeneID=59067]: 6h versus 24h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_6H_VS_24H_IL21_TREATED_TCELL_DN
Systematic name | M7228
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells treated with IL21 [GeneID=59067]: 6h versus 24h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_CTRL_VS_IL21_TREATED_TCELL_6H_DN
Systematic name | M7229
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: control (0h) versus IL21 [GeneID=59067] treatment for 6h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_1H_VS_24H_IL21_TREATED_TCELL_DN
Systematic name | M7230
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells treated with IL21 [GeneID=59067]: 1h versus 24h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_CTRL_VS_IL21_TREATED_TCELL_24H_DN
Systematic name | M7231
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: control (0h) versus IL21 [GeneID=59067] for 24h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_1H_VS_6H_IL21_TREATED_TCELL_DN
Systematic name | M7232
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells treated with IL21 [GeneID=59067]: 1h versus 6h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_CTRL_VS_IL21_TREATED_TCELL_24H_UP
Systematic name | M7233
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: control (0h) versus IL21 [GeneID=59067] for 24h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE19198_1H_VS_24H_IL21_TREATED_TCELL_UP
Systematic name | M7234
Organism | Mus musculus
PMID | 20064451
Authors | Kwon H,Thierry-Mieg D,Thierry-Mieg J,Kim HP,Oh J,Tunyaplin C,Carotta S,Donovan CE,Goldman ML,Tailor P,Ozato K,Levy DE,Nutt SL,Calame K,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells treated with IL21 [GeneID=59067]: 1h versus 24h.
Full description | Interleukin-21 (IL-21) is a pleiotropic cytokine that induces expression of transcription factor BLIMP1 (encoded by Prdm1), which regulates plasma cell differentiation and T cell homeostasis. We identified an IL-21 response element downstream of Prdm1 that binds the transcription factors STAT3 and IRF4, which are required for optimal Prdm1 expression. Genome-wide ChIP-Seq mapping of STAT3- and IRF4-binding sites showed that most regions with IL-21-induced STAT3 binding also bound IRF4 in vivo, and furthermore, revealed that the noncanonical TTCnnnTAA GAS motif critical in Prdm1 was broadly used for STAT3 binding. Comparing genome-wide expression array data to binding sites revealed that most IL-21-regulated genes were associated with combined STAT3-IRF4 sites rather than pure STAT3 sites. Correspondingly, ChIP-Seq analysis of Irf4_/_ T cells showed greatly diminished STAT3 binding after IL-21 treatment, and Irf4_/_ mice showed impaired IL- 21-induced Tfh cell differentiation in vivo. These results reveal broad cooperative gene regulation by STAT3 and IRF4.

Standard name | GSE18281_SUBCAPSULAR_VS_PERIMEDULLARY_CORTICAL_REGION_OF_THYMUS_UP
Systematic name | M7235
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymus cortical regions: subcapsular versus perimedullary.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_SUBCAPSULAR_VS_CENTRAL_CORTICAL_REGION_OF_THYMUS_DN
Systematic name | M7237
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymus cortical regions: subcapsular versus central cortical.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_CORTICAL_THYMOCYTE_VS_WHOLE_CORTEX_THYMUS_UP
Systematic name | M7238
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes up-regulated in cortical thymocytes versus thymus whole cortex.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_CORTICAL_THYMOCYTE_VS_WHOLE_CORTEX_THYMUS_DN
Systematic name | M7240
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes down-regulated in cortical thymocytes versus thymus whole cortex.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_PERIMEDULLARY_CORTICAL_REGION_VS_WHOLE_MEDULLA_THYMUS_DN
Systematic name | M7241
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymus perimedullary cortical region versus the whole medulla.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_CORTEX_VS_MEDULLA_THYMUS_UP
Systematic name | M7242
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymus: whole cortex versus whole medulla.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_CORTEX_VS_MEDULLA_THYMUS_DN
Systematic name | M7243
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymus: whole cortex versus whole medulla.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_SUBCAPSULAR_VS_CENTRAL_CORTICAL_REGION_OF_THYMUS_UP
Systematic name | M7244
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymus cortical regions: subcapsular versus central cortical.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_MEDULLARY_THYMOCYTE_VS_WHOLE_MEDULLA_THYMUS_UP
Systematic name | M7247
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes up-regulated in medullary thymocytes versus thymus whole medulla.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_MEDULLARY_THYMOCYTE_VS_WHOLE_MEDULLA_THYMUS_DN
Systematic name | M7249
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes down-regulated in medullary thymocytes versus thymus whole medulla.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_SUBCAPSULAR_CORTICAL_REGION_VS_WHOLE_CORTEX_THYMUS_UP
Systematic name | M7251
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymus subcapsular cortical region versus the whole cortex.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_CORTICAL_VS_MEDULLARY_THYMOCYTE_UP
Systematic name | M7252
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymocytes: cortical versus medullary sources.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_SUBCAPSULAR_CORTICAL_REGION_VS_WHOLE_MEDULLA_THYMUS_UP
Systematic name | M7254
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymus subcapsular cortical region versus the whole medulla.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_SUBCAPSULAR_CORTICAL_REGION_VS_WHOLE_MEDULLA_THYMUS_DN
Systematic name | M7255
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymus subcapsular cortical region versus the whole medulla.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_PERIMEDULLARY_CORTICAL_REGION_VS_WHOLE_CORTEX_THYMUS_UP
Systematic name | M7256
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymus perimedullary cortical region versus the whole cortex.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_CORTICAL_VS_MEDULLARY_THYMOCYTE_DN
Systematic name | M7258
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymocytes: cortical versus medullary sources.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_PERIMEDULLARY_CORTICAL_REGION_VS_WHOLE_MEDULLA_THYMUS_UP
Systematic name | M7259
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymus perimedullary cortical region versus the whole medulla.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_SUBCAPSULAR_VS_PERIMEDULLARY_CORTICAL_REGION_OF_THYMUS_DN
Systematic name | M7260
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymus cortical regions: subcapsular versus perimedullary.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_SUBCAPSULAR_CORTICAL_REGION_VS_WHOLE_CORTEX_THYMUS_DN
Systematic name | M7261
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymus subcapsular cortical region versus the whole cortex.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE18281_PERIMEDULLARY_CORTICAL_REGION_VS_WHOLE_CORTEX_THYMUS_DN
Systematic name | M7263
Organism | Mus musculus
PMID | 20064453
Authors | Griffith AV,Fallahi M,Nakase H,Gosink M,Young B,Petrie HT
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymus perimedullary cortical region versus the whole cortex.
Full description | Interaction of hematopoietic progenitors with the thymic stromal microenvironment induces them to proliferate, adopt the T cell fate, and asymmetrically diverge into multiple T lineages. Progenitors at various developmental stages are stratified among different regions of the thymus, implying that the corresponding microenvironments differ from one another, and provide unique sets of signals to progenitors migrating between them. The nature of these differences remains undefined. Here we use novel physical and computational approaches to characterize these stromal subregions, distinguishing gene expression in microdissected tissues from that of their lymphoid constituents. Using this approach, we comprehensively map gene expression in functionally distinct stromal microenvironments, and identify clusters of genes that define each region. Quite unexpectedly, we find that the central cortex lacks distinctive features of its own, and instead appears to function by sequestering unique microenvironments found at the cortical extremities, and modulating the relative proximity of progenitors moving between them.

Standard name | GSE19374_UNINF_VS_LISTERIA_INFECTED_MACROPHAGE_UP
Systematic name | M7264
Organism | Mus musculus
PMID | 20123961
Authors | Rayamajhi M,Humann J,Penheiter K,Andreasen K,Lenz LL
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: control versus Listeria infected.
Full description | Macrophages phagocytose bacteria. Certain pathogenic bacteria access and replicate within the cytosol of infected macrophages and induce changes in macrophage gene expression by triggering of innate immune receptors and/or the effects of bacterial virulence factors. We used microarray analysis to identify changes in macrophage gene expression following infection with Listeria monocytogenes.

Standard name | GSE19374_UNINF_VS_LISTERIA_INFECTED_MACROPHAGE_DN
Systematic name | M7265
Organism | Mus musculus
PMID | 20123961
Authors | Rayamajhi M,Humann J,Penheiter K,Andreasen K,Lenz LL
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: control versus Listeria infected.
Full description | Macrophages phagocytose bacteria. Certain pathogenic bacteria access and replicate within the cytosol of infected macrophages and induce changes in macrophage gene expression by triggering of innate immune receptors and/or the effects of bacterial virulence factors. We used microarray analysis to identify changes in macrophage gene expression following infection with Listeria monocytogenes.

Standard name | GSE19923_E2A_KO_VS_HEB_AND_E2A_KO_DP_THYMOCYTE_DN
Systematic name | M7266
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes: TCF3 [GeneID=6929] knockout versus TCF12 [GeneID=6938] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_WT_VS_E2A_KO_DP_THYMOCYTE_DN
Systematic name | M7267
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes: wildtype versus TCF3 [GeneID=6929] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_WT_VS_E2A_KO_DP_THYMOCYTE_UP
Systematic name | M7268
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes: wildtype versus TCF3 [GeneID=6929] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_WT_VS_HEB_AND_E2A_KO_DP_THYMOCYTE_DN
Systematic name | M7269
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes: wildtype versus TCF3 and TCF12 [GeneID=6929;6938] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_HEB_KO_VS_HEB_AND_E2A_KO_DP_THYMOCYTE_UP
Systematic name | M7270
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes: TCF12 [GeneID=6939] knockout versus TCF3 and TCF12 [GeneID=6929;6938] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_HEB_KO_VS_HEB_AND_E2A_KO_DP_THYMOCYTE_DN
Systematic name | M7271
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes: TCF12 [GeneID=6939] knockout versus TCF3 and TCF12 [GeneID=6929;6938] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_WT_VS_HEB_AND_E2A_KO_DP_THYMOCYTE_UP
Systematic name | M7273
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes: wildtype versus TCF3 and TCF12 [GeneID=6929;6938] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_E2A_KO_VS_HEB_AND_E2A_KO_DP_THYMOCYTE_UP
Systematic name | M7274
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes: TCF3 [GeneID=6929] knockout versus TCF12 [GeneID=6938] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_E2A_KO_VS_E2A_AND_HEB_KO_DP_THYMOCYTE_UP
Systematic name | M7275
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positve thymocyte: TCF3 [GeneID=6929] knockout versus TCF3 and TCF12 [GeneID=6929;6938] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_E2A_KO_VS_E2A_AND_HEB_KO_DP_THYMOCYTE_DN
Systematic name | M7276
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positve thymocyte: TCF3 [GeneID=6929] knockout versus TCF3 and TCF12 [GeneID=6929;6938] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_WT_VS_HEB_KO_DP_THYMOCYTE_DN
Systematic name | M7278
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes: wildtype versus TCF12 [GeneID=6938] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19923_WT_VS_HEB_KO_DP_THYMOCYTE_UP
Systematic name | M7279
Organism | Mus musculus
PMID | 20154672
Authors | D'Cruz LM,Knell J,Fujimoto JK,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes: wildtype versus TCF12 [GeneID=6938] knockout.
Full description | We wanted to test the role of mammalian E proteins E2A and HEB in the development of T cells. Using a conditional deletion system in which these proteins are deleted at the DP stage of T cell development, we compared DP thymocytes deficient for E2A, HEB or both to wild-type thymocytes

Standard name | GSE19772_CTRL_VS_HCMV_INF_MONOCYTES_AND_PI3K_INHIBITION_DN
Systematic name | M7280
Organism | Homo sapiens
PMID | 20173022
Authors | Chan G,Nogalski MT,Bentz GL,Smith MS,Parmater A,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes pre-treated with Ly294002 [PubChem=3973]: control versus HCMV infection.
Full description | Human cytomegalovirus (HCMV) induces pro-inflammatory monocytes following infection and we have evidence that phosphatidylinositol 3-kinase [PI(3)K] is a key mediator in this activation. To begin to address how this signalling pathway is responsible for the functional changes in infected monocytes, we examined the role this pathway played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes were regulated in a PI(3)K-dependent manner, identifying this pathway as a key cellular control point in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE19772_CTRL_VS_HCMV_INF_MONOCYTES_UP
Systematic name | M7282
Organism | Homo sapiens
PMID | 20173022
Authors | Chan G,Nogalski MT,Bentz GL,Smith MS,Parmater A,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes: control versus HCMV infection.
Full description | Human cytomegalovirus (HCMV) induces pro-inflammatory monocytes following infection and we have evidence that phosphatidylinositol 3-kinase [PI(3)K] is a key mediator in this activation. To begin to address how this signalling pathway is responsible for the functional changes in infected monocytes, we examined the role this pathway played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes were regulated in a PI(3)K-dependent manner, identifying this pathway as a key cellular control point in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE19772_HCMV_INFL_VS_HCMV_INF_MONOCYTES_AND_PI3K_INHIBITION_UP
Systematic name | M7283
Organism | Homo sapiens
PMID | 20173022
Authors | Chan G,Nogalski MT,Bentz GL,Smith MS,Parmater A,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes after HCMV infection: untreated versus pre-treated with Ly294002 [PubChem=3973].
Full description | Human cytomegalovirus (HCMV) induces pro-inflammatory monocytes following infection and we have evidence that phosphatidylinositol 3-kinase [PI(3)K] is a key mediator in this activation. To begin to address how this signalling pathway is responsible for the functional changes in infected monocytes, we examined the role this pathway played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes were regulated in a PI(3)K-dependent manner, identifying this pathway as a key cellular control point in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE19772_HCMV_INFL_VS_HCMV_INF_MONOCYTES_AND_PI3K_INHIBITION_DN
Systematic name | M7286
Organism | Homo sapiens
PMID | 20173022
Authors | Chan G,Nogalski MT,Bentz GL,Smith MS,Parmater A,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes after HCMV infection: untreated versus pre-treated with Ly294002 [PubChem=3973].
Full description | Human cytomegalovirus (HCMV) induces pro-inflammatory monocytes following infection and we have evidence that phosphatidylinositol 3-kinase [PI(3)K] is a key mediator in this activation. To begin to address how this signalling pathway is responsible for the functional changes in infected monocytes, we examined the role this pathway played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes were regulated in a PI(3)K-dependent manner, identifying this pathway as a key cellular control point in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE19772_CTRL_VS_HCMV_INF_MONOCYTES_DN
Systematic name | M7287
Organism | Homo sapiens
PMID | 20173022
Authors | Chan G,Nogalski MT,Bentz GL,Smith MS,Parmater A,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes: control versus HCMV infection.
Full description | Human cytomegalovirus (HCMV) induces pro-inflammatory monocytes following infection and we have evidence that phosphatidylinositol 3-kinase [PI(3)K] is a key mediator in this activation. To begin to address how this signalling pathway is responsible for the functional changes in infected monocytes, we examined the role this pathway played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes were regulated in a PI(3)K-dependent manner, identifying this pathway as a key cellular control point in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE19772_CTRL_VS_HCMV_INF_MONOCYTES_AND_PI3K_INHIBITION_UP
Systematic name | M7288
Organism | Homo sapiens
PMID | 20173022
Authors | Chan G,Nogalski MT,Bentz GL,Smith MS,Parmater A,Yurochko AD
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes pre-treated with Ly294002 [PubChem=3973]: control versus HCMV infection.
Full description | Human cytomegalovirus (HCMV) induces pro-inflammatory monocytes following infection and we have evidence that phosphatidylinositol 3-kinase [PI(3)K] is a key mediator in this activation. To begin to address how this signalling pathway is responsible for the functional changes in infected monocytes, we examined the role this pathway played in the transcriptome of infected monocytes. Global transcriptional profiling using cDNA microarrays revealed a significant number of genes were regulated in a PI(3)K-dependent manner, identifying this pathway as a key cellular control point in the conversion of monocytes to an activated pro-inflammatory state following HCMV infection.

Standard name | GSE18893_TCONV_VS_TREG_24H_CULTURE_DN
Systematic name | M7289
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphocytes treated with medium for 24h: T conv versus T reg cells.
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_TCONV_VS_TREG_24H_CULTURE_UP
Systematic name | M7290
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphocytes treated with medium for 24h: T conv versus T reg cells.
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_TCONV_VS_TREG_24H_TNF_STIM_DN
Systematic name | M7291
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphocytes treated with TNF [GeneID=7124] for 24h: T conv versus T reg cells.
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_TCONV_VS_TREG_2H_CULTURE_DN
Systematic name | M7293
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphocytes treated with medium for 2h: T conv versus T reg cells.
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_CTRL_VS_TNF_TREATED_TREG_2H_UP
Systematic name | M7294
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg cells (2h): medium versus TNF [GeneID=7124].
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_CTRL_VS_TNF_TREATED_TCONV_2H_UP
Systematic name | M7295
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv cells (2h): medium versus TNF [GeneID=7124].
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_CTRL_VS_TNF_TREATED_TREG_24H_DN
Systematic name | M7296
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg cells: 2h versus 24h medium treatment.
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_TCONV_VS_TREG_2H_TNF_STIM_UP
Systematic name | M7297
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphocytes treated with TNF [GeneID=7124] for 2h: T conv versus T reg cells.
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_CTRL_VS_TNF_TREATED_TREG_24H_UP
Systematic name | M7299
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg cells: 2h versus 24h medium treatment.
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_TCONV_VS_TREG_2H_CULTURE_UP
Systematic name | M7301
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphocytes treated with medium for 2h: T conv versus T reg cells.
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_CTRL_VS_TNF_TREATED_TCONV_2H_DN
Systematic name | M7302
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv cells (2h): medium versus TNF [GeneID=7124].
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_CTRL_VS_TNF_TREATED_TREG_2H_DN
Systematic name | M7303
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg cells (2h): medium versus TNF [GeneID=7124].
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_CTRL_VS_TNF_TREATED_TCONV_24H_UP
Systematic name | M7304
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv cells (24h): medium versus TNF [GeneID=7124].
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_CTRL_VS_TNF_TREATED_TCONV_24H_DN
Systematic name | M7305
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv cells (24h): medium versus TNF [GeneID=7124].
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_TCONV_VS_TREG_2H_TNF_STIM_DN
Systematic name | M7306
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphocytes treated with TNF [GeneID=7124] for 2h: T conv versus T reg cells.
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE18893_TCONV_VS_TREG_24H_TNF_STIM_UP
Systematic name | M7308
Organism | Homo sapiens
PMID | 20181891
Authors | Nagar M,Jacob-Hirsch J,Vernitsky H,Berkun Y,Ben-Horin S,Amariglio N,Bank I,Kloog Y,Rechavi G,Goldstein I
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphocytes treated with TNF [GeneID=7124] for 24h: T conv versus T reg cells.
Full description | Here we show that tumor necrosis factor (TNF) induced in human T-regulatory cells (Treg), as compared to conventional T cells (Tcon), a transcription program highly enriched for typical NF-κB target genes, such as: the cytokines LTA and TNF; the TNF-receptor super family members FAS, 4-1BB and OX-40; various anti-apoptotic genes; and other important immune-response genes. As an initial approach to examine the cellular program induced by TNF in Tregs versus Tcon cells, we employed microarray gene expression analysis at 2 and 24 hrs following TNF treatment.

Standard name | GSE19888_CTRL_VS_A3R_INHIBITOR_TREATED_MAST_CELL_DN
Systematic name | M7310
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: untreated versus incubated with the peptide ALL1.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_CTRL_VS_A3R_INHIBITOR_TREATED_MAST_CELL_UP
Systematic name | M7311
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: untreated versus incubated with the peptide ALL1.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_PRETREAT_AND_ACT_BY_A3R_VS_A3R_INH_AND_TCELL_MEMBRANES_ACT_MAST_CELL_UP
Systematic name | M7313
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells incubated with the peptide ALL1 followed by treatment with: Cl-IB-MECA [PubChem=3035850] versus T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_ACT_VS_A3R_ACT_WITH_A3R_INH_PRETREATMENT_IN_MAST_CELL_UP
Systematic name | M7316
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: Cl-IB-MECA [PubChem=3035850] versus incubated with the ALL1 peptide followed by treatment with Cl-IB-MECA [PubChem=3035850].
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_ACT_VS_TCELL_MEMBRANES_ACT_IN_MAST_CELL_DN
Systematic name | M7317
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: Cl-IB-MECA [PubChem=3035850] versus T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_ACT_VS_TCELL_MEMBRANES_ACT_AND_A3R_INH_PRETREAT_IN_MAST_CELL_UP
Systematic name | M7318
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: Cl-IB-MECA [PubChem=3035850] versus incubated with the peptide ALL1 followed by stimulation with T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_ACT_VS_TCELL_MEMBRANES_ACT_AND_A3R_INH_PRETREAT_IN_MAST_CELL_DN
Systematic name | M7319
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: Cl-IB-MECA [PubChem=3035850] versus incubated with the peptide ALL1 followed by stimulation with T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_PRETREAT_AND_ACT_BY_A3R_VS_TCELL_MEMBRANES_ACT_MAST_CELL_UP
Systematic name | M7320
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: incubated with the peptide ALL1 and then treated with Cl-IB-MECA [PubChem=3035850] versus stimulation by T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_PRETREAT_AND_ACT_BY_A3R_VS_TCELL_MEMBRANES_ACT_MAST_CELL_DN
Systematic name | M7321
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: incubated with the peptide ALL1 and then treated with Cl-IB-MECA [PubChem=3035850] versus stimulation by T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_VS_ACT_WITH_INHIBITOR_PRETREATMENT_IN_MAST_CELL_UP
Systematic name | M7322
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells incubated the peptide ALL1 versus those followed by treatment with Cl-IB-MECA [PubChem=3035850].
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_VS_ACT_WITH_INHIBITOR_PRETREATMENT_IN_MAST_CELL_DN
Systematic name | M7323
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells incubated the peptide ALL1 versus those followed by treatment with Cl-IB-MECA [PubChem=3035850].
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_VS_TCELL_MEMBRANES_ACT_MAST_CELL_UP
Systematic name | M7324
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: incubated with the peptide ALL1 versus stimulated with T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_CTRL_VS_A3R_ACTIVATION_MAST_CELL_UP
Systematic name | M7325
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: untreated versus Cl-IB-MECA [PubChem=3035850].
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_CTRL_VS_A3R_ACTIVATION_MAST_CELL_DN
Systematic name | M7326
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: untreated versus Cl-IB-MECA [PubChem=3035850].
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_CTRL_VS_A3R_ACT_TREATED_MAST_CELL_PRETREATED_WITH_A3R_INH_UP
Systematic name | M7329
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: untreated versus incubated with the peptide ALL1 followed by treatment with Cl-IB-MECA [PubChem=3035850].
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_ACT_VS_A3R_ACT_WITH_A3R_INH_PRETREATMENT_IN_MAST_CELL_DN
Systematic name | M7332
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: Cl-IB-MECA [PubChem=3035850] versus incubated with the ALL1 peptide followed by treatment with Cl-IB-MECA [PubChem=3035850].
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_ACT_VS_TCELL_MEMBRANES_ACT_IN_MAST_CELL_UP
Systematic name | M7333
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: Cl-IB-MECA [PubChem=3035850] versus T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_CTRL_VS_T_CELL_MEMBRANES_ACT_MAST_CELL_DN
Systematic name | M7334
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: untreated versus stimulated with T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_CTRL_VS_TCELL_MEMBRANES_ACT_MAST_CELL_PRETREAT_A3R_INH_UP
Systematic name | M7335
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: untreated versus incubated with the peptide ALL1 followed by stimulation with T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_CTRL_VS_TCELL_MEMBRANES_ACT_MAST_CELL_PRETREAT_A3R_INH_DN
Systematic name | M7336
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: untreated versus incubated with the peptide ALL1 followed by stimulation with T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_VS_ACT_IN_MAST_CELL_UP
Systematic name | M7340
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells incubated with: the peptide ALL1 versus Cl-IB-MECA [PubChem=3035850].
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_VS_ACT_IN_MAST_CELL_DN
Systematic name | M7341
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells incubated with: the peptide ALL1 versus Cl-IB-MECA [PubChem=3035850].
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_VS_INH_PRETREAT_AND_ACT_WITH_TCELL_MEMBRANES_MAST_CELL_UP
Systematic name | M7342
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells incubated with the peptide ALL1 versus those then stimulated by T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_VS_INH_PRETREAT_AND_ACT_WITH_TCELL_MEMBRANES_MAST_CELL_DN
Systematic name | M7345
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells incubated with the peptide ALL1 versus those then stimulated by T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_NO_PRETREAT_VS_ADENOSINE_A3R_INHIBITOR_PRETREATED_MAST_CELL_TCELL_MEMBRANES_ACT_DN
Systematic name | M7347
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: stimulated with T cell membranes versus incubated with the peptide ALL1 and then stimulated with T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_VS_TCELL_MEMBRANES_ACT_MAST_CELL_DN
Systematic name | M7350
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: incubated with the peptide ALL1 versus stimulated with T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_CTRL_VS_A3R_ACT_TREATED_MAST_CELL_PRETREATED_WITH_A3R_INH_DN
Systematic name | M7351
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells: untreated versus incubated with the peptide ALL1 followed by treatment with Cl-IB-MECA [PubChem=3035850].
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_CTRL_VS_T_CELL_MEMBRANES_ACT_MAST_CELL_UP
Systematic name | M7352
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: untreated versus stimulated with T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_ADENOSINE_A3R_INH_PRETREAT_AND_ACT_BY_A3R_VS_A3R_INH_AND_TCELL_MEMBRANES_ACT_MAST_CELL_DN
Systematic name | M7353
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes down-regulated in HMC-1 (mast leukemia) cells incubated with the peptide ALL1 followed by treatment with: Cl-IB-MECA [PubChem=3035850] versus T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE19888_NO_PRETREAT_VS_ADENOSINE_A3R_INHIBITOR_PRETREATED_MAST_CELL_TCELL_MEMBRANES_ACT_UP
Systematic name | M7354
Organism | Homo sapiens
PMID | 20190146
Authors | Baram D,Dekel O,Mekori YA,Sagi-Eisenberg R
Category | C7
Sub-category |
Brief description | Genes up-regulated in HMC-1 (mast leukemia) cells: stimulated with T cell membranes versus incubated with the peptide ALL1 and then stimulated with T cell membranes.
Full description | We demonstrate that the G protein Gi3 is the cellular target of the adenosine A3 receptor (A3R). By using a cell permeable peptide comprising the C-terminal end of Gαi3 fused to an importation sequence (ALL1) as a selective inhibitor of Gi3 signaling, we show that by coupling to Gi3, the A3R stimulates multiple signaling pathways in human mast cells, leading to upregulation of cytokines, chemokines and growth factors.Following contact with activated T cell membranes, endogenous adenosine binds to and activates the A3R, resulting in Gi3-mediated signaling. Specifically, the majority of ERK1/2 signaling initiated by contact with activated T cell membranes, is mediated by Gi3, giving rise to ALL1-inhibitable cellular responses. These results unveil the physiological GPCR that couples to Gi3 and establish the important role played by this G-protein in inflammatory conditions that involve adenosine-activated mast cells. We used microarrays to detail the effect of ALL1 on gene expression of HMC-1 cells activated directly by the A3 receptor, or by contact with activated T cell membranes.

Standard name | GSE25890_CTRL_VS_IL33_IL7_TREATED_NUOCYTES_DN
Systematic name | M7356
Organism | Mus musculus
PMID | 20200518
Authors | Neill DR,Wong SH,Bellosi A,Flynn RJ,Daly M,Langford TK,Bucks C,Kane CM,Fallon PG,Pannell R,Jolin HE,McKenzie AN
Category | C7
Sub-category |
Brief description | Genes down-regulated in nuocytes: control versus treated with IL7 and IL33 [GeneID=3574;90865].
Full description | Nuocytes are a recently described cell that responds to both IL-25 and IL-33 and produce high levels of IL-13 and IL-5

Standard name | GSE25890_CTRL_VS_IL33_IL7_TREATED_NUOCYTES_UP
Systematic name | M7358
Organism | Mus musculus
PMID | 20200518
Authors | Neill DR,Wong SH,Bellosi A,Flynn RJ,Daly M,Langford TK,Bucks C,Kane CM,Fallon PG,Pannell R,Jolin HE,McKenzie AN
Category | C7
Sub-category |
Brief description | Genes up-regulated in nuocytes: control versus treated with IL7 and IL33 [GeneID=3574;90865].
Full description | Nuocytes are a recently described cell that responds to both IL-25 and IL-33 and produce high levels of IL-13 and IL-5

Standard name | GSE20198_UNTREATED_VS_IL12_TREATED_ACT_CD4_TCELL_DN
Systematic name | M7361
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in the activated CD4 [GeneID=920] T cells (48h): control versus IL-12.
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_UNTREATED_VS_IL12_TREATED_ACT_CD4_TCELL_UP
Systematic name | M7365
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in the activated CD4 [GeneID=920] T cells (48h): control versus IL-12.
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_UNTREATED_VS_IFNA_TREATED_ACT_CD4_TCELL_UP
Systematic name | M7366
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in the activated CD4 [GeneID=920] T cells (48h): control versus interferon alpha.
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_IL12_VS_IFNA_TREATED_ACT_CD4_TCELL_UP
Systematic name | M7367
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in the activated CD4 [GeneID=920] T cells (48h): IL-12 versus interferon alpha.
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_IL12_IL18_VS_IFNA_TREATED_ACT_CD4_TCELL_DN
Systematic name | M7369
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in the activated CD4 [GeneID=920] T cells (48h): IL-12 and IL18 [GeneID=3606] versus interferon alpha.
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_IL12_IL18_VS_IFNA_TREATED_ACT_CD4_TCELL_UP
Systematic name | M7370
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in the activated CD4 [GeneID=920] T cells (48h): IL-12 and IL18 [GeneID=3606] versus interferon alpha.
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_IL12_VS_IL12_IL18_TREATED_ACT_CD4_TCELL_DN
Systematic name | M7372
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in the activated CD4 [GeneID=920] T cells (48h): IL-12 versus IL-12 and IL18 [GeneID=3606].
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_UNTREATED_VS_IL12_IL18_TREATED_ACT_CD4_TCELL_DN
Systematic name | M7373
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in the activated CD4 [GeneID=920] T cells (48h): control versus IL-12 and IL18 [GeneID=3606].
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_IL12_VS_IFNA_TREATED_ACT_CD4_TCELL_DN
Systematic name | M7374
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in the activated CD4 [GeneID=920] T cells (48h): IL-12 versus interferon alpha.
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_UNTREATED_VS_IFNA_TREATED_ACT_CD4_TCELL_DN
Systematic name | M7376
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes down-regulated in the activated CD4 [GeneID=920] T cells (48h): control versus interferon alpha.
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_UNTREATED_VS_IL12_IL18_TREATED_ACT_CD4_TCELL_UP
Systematic name | M7379
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in the activated CD4 [GeneID=920] T cells (48h): control versus IL-12 and IL18 [GeneID=3606].
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20198_IL12_VS_IL12_IL18_TREATED_ACT_CD4_TCELL_UP
Systematic name | M7380
Organism | Homo sapiens
PMID | 20304822
Authors | Filén S,Ylikoski E,Tripathi S,West A,Björkman M,Nyström J,Ahlfors H,Coffey E,Rao KV,Rasool O,Lahesmaa R
Category | C7
Sub-category |
Brief description | Genes up-regulated in the activated CD4 [GeneID=920] T cells (48h): IL-12 versus IL-12 and IL18 [GeneID=3606].
Full description | The aim of this study was to identify genes regulated by IL-12, IL-18 and IFN-alpha during early differentiation of human Th1 cells

Standard name | GSE20484_MCSG_VS_CXCL4_MONOCYTE_DERIVED_MACROPHAGE_DN
Systematic name | M7382
Organism | Homo sapiens
PMID | 20335529
Authors | Gleissner CA,Shaked I,Little KM,Ley K
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte derived macrophages: CSF1 [GeneID=1435] versus PF4 [GeneID=5196].
Full description | Human blood monocytes were differentiated over six days with either 100 ng/ml M-CSF or 1 umol/l CXCL4 In atherosclerotic arteries, blood monocytes differentiate to macrophages in the presence of growth factors like macrophage colony-stimulation factor (MCSF) and chemokines like platelet factor 4 (CXCL4). To compare the gene expression signature of CXCL4-induced macrophages with MCSF-induced macrophages or macrophages polarized with IFN-γ/LPS (M1) or IL-4 (M2), we cultured primary human peripheral blood monocytes for six days. mRNA expression was measured by Affymetrix gene chips and differences were analyzed by Local Pooled Error test, Profile of Complex Functionality and Gene Set Enrichment Analysis. 375 genes were differentially expressed between MCSF- and CXCL4-induced macrophages, 206 of them overexpressed in CXCL4 macrophages coding for genes implicated in the inflammatory/immune response, antigen processing/presentation, and lipid metabolism. CXCL4-induced macrophages overexpressed some M1 and M2 genes and the corresponding cytokines at the protein level, however, their transcriptome clustered with neither M1 nor M2 transcriptomes. They almost completely lost the ability to phagocytose zymosan beads. Genes linked to atherosclerosis were not consistently up- or downregulated. Scavenger receptors showed lower and cholesterol efflux transporters higher expression in CXCL4- than MCSF-induced macrophages, resulting in lower LDL content. We conclude that CXCL4 induces a unique macrophage transcriptome distinct from known macrophage types, defining a new macrophage differentiation that we propose to call M4.

Standard name | GSE20484_MCSG_VS_CXCL4_MONOCYTE_DERIVED_MACROPHAGE_UP
Systematic name | M7384
Organism | Homo sapiens
PMID | 20335529
Authors | Gleissner CA,Shaked I,Little KM,Ley K
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte derived macrophages: CSF1 [GeneID=1435] versus PF4 [GeneID=5196].
Full description | Human blood monocytes were differentiated over six days with either 100 ng/ml M-CSF or 1 umol/l CXCL4 In atherosclerotic arteries, blood monocytes differentiate to macrophages in the presence of growth factors like macrophage colony-stimulation factor (MCSF) and chemokines like platelet factor 4 (CXCL4). To compare the gene expression signature of CXCL4-induced macrophages with MCSF-induced macrophages or macrophages polarized with IFN-γ/LPS (M1) or IL-4 (M2), we cultured primary human peripheral blood monocytes for six days. mRNA expression was measured by Affymetrix gene chips and differences were analyzed by Local Pooled Error test, Profile of Complex Functionality and Gene Set Enrichment Analysis. 375 genes were differentially expressed between MCSF- and CXCL4-induced macrophages, 206 of them overexpressed in CXCL4 macrophages coding for genes implicated in the inflammatory/immune response, antigen processing/presentation, and lipid metabolism. CXCL4-induced macrophages overexpressed some M1 and M2 genes and the corresponding cytokines at the protein level, however, their transcriptome clustered with neither M1 nor M2 transcriptomes. They almost completely lost the ability to phagocytose zymosan beads. Genes linked to atherosclerosis were not consistently up- or downregulated. Scavenger receptors showed lower and cholesterol efflux transporters higher expression in CXCL4- than MCSF-induced macrophages, resulting in lower LDL content. We conclude that CXCL4 induces a unique macrophage transcriptome distinct from known macrophage types, defining a new macrophage differentiation that we propose to call M4.

Standard name | GSE17322_CD103_POS_VS_CD11B_HIGH_LUNG_DC_UP
Systematic name | M7389
Organism | Mus musculus
PMID | 20351058
Authors | Edelson BT,KC W,Juang R,Kohyama M,Benoit LA,Klekotka PA,Moon C,Albring JC,Ise W,Michael DG,Bhattacharya D,Stappenbeck TS,Holtzman MJ,Sung SS,Murphy TL,Hildner K,Murphy KM
Category | C7
Sub-category |
Brief description | Genes up-regulated in lung dendritic cells: CD103+ [GeneID=3682] versus CD11b [GeneID=3684] high.
Full description | Mouse lung CD11c+ dendritic cells are composed of 2 major DC subsets, the CD103+CD11b-low/intermediate DC (CD103+ DC) and the CD11b-highCD103- DC (CD11b-high DC). These 2 subsets are functionally distinct. Comparison of their functions showed CD103+ DC Microarray analysis was performed to compare the gene expression profiles of the 2 lung DC subsets in naïve mice.

Standard name | GSE17322_CD103_POS_VS_CD11B_HIGH_LUNG_DC_DN
Systematic name | M7390
Organism | Mus musculus
PMID | 20351058
Authors | Edelson BT,KC W,Juang R,Kohyama M,Benoit LA,Klekotka PA,Moon C,Albring JC,Ise W,Michael DG,Bhattacharya D,Stappenbeck TS,Holtzman MJ,Sung SS,Murphy TL,Hildner K,Murphy KM
Category | C7
Sub-category |
Brief description | Genes down-regulated in lungh dendritic cell : CD103+ [GeneID=3682] versus CD11b [GeneID=3684] high.
Full description | Mouse lung CD11c+ dendritic cells are composed of 2 major DC subsets, the CD103+CD11b-low/intermediate DC (CD103+ DC) and the CD11b-highCD103- DC (CD11b-high DC). These 2 subsets are functionally distinct. Comparison of their functions showed CD103+ DC Microarray analysis was performed to compare the gene expression profiles of the 2 lung DC subsets in naïve mice.

Standard name | GSE21678_WT_VS_FOXO1_FOXO3_KO_TREG_DN
Systematic name | M7394
Organism | Mus musculus
PMID | 20467422
Authors | Ouyang W,Beckett O,Ma Q,Paik JH,DePinho RA,Li MO
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg cells: wildtype versus FOXO1 and FOXO3 [GeneID=2308;2309].
Full description | Identification of Foxos target genes in Treg cells. Foxo1and Foxo3 are transcription factors of Foxo family. CD4+Foxp3+ Treg cells isolated from wild-type and Foxo1/3-deficient mice were analyzed by global gene expression profiling. Results indicate Foxos regulate expression of a subset of Treg cell signature genes and genes in control of T cell homeostasis, signaling and metabolism.

Standard name | GSE21678_WT_VS_FOXO1_FOXO3_KO_TREG_UP
Systematic name | M7395
Organism | Mus musculus
PMID | 20467422
Authors | Ouyang W,Beckett O,Ma Q,Paik JH,DePinho RA,Li MO
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg cells: wildtype versus FOXO1 and FOXO3 [GeneID=2308;2309].
Full description | Identification of Foxos target genes in Treg cells. Foxo1and Foxo3 are transcription factors of Foxo family. CD4+Foxp3+ Treg cells isolated from wild-type and Foxo1/3-deficient mice were analyzed by global gene expression profiling. Results indicate Foxos regulate expression of a subset of Treg cell signature genes and genes in control of T cell homeostasis, signaling and metabolism.

Standard name | GSE16450_IMMATURE_VS_MATURE_NEURON_CELL_LINE_UP
Systematic name | M7397
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in the neuron cell line: immature versus mature.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16450_IMMATURE_VS_MATURE_NEURON_CELL_LINE_DN
Systematic name | M7401
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in the neuron cell line: immature versus mature.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16450_CTRL_VS_IFNA_12H_STIM_IMMATURE_NEURON_CELL_LINE_UP
Systematic name | M7403
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in immature neuron cell line: control versus interferon alpha (12h).
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16450_CTRL_VS_IFNA_12H_STIM_IMMATURE_NEURON_CELL_LINE_DN
Systematic name | M7406
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in immature neuron cell line: control versus interferon alpha (12h).
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16451_IMMATURE_VS_MATURE_NEURON_CELL_LINE_WEST_EQUINE_ENC_VIRUS_DN
Systematic name | M7408
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in neuron cell line infected with western equine encephalitis virus: immature versus mature cells.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to infection with western equine encephalitis virus (WEEV).

Standard name | GSE16450_CTRL_VS_IFNA_6H_STIM_IMMATURE_NEURON_CELL_LINE_DN
Systematic name | M7410
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in immature neuron cell line: control versus interferon alpha (6h).
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16450_CTRL_VS_IFNA_12H_STIM_MATURE_NEURON_CELL_LINE_UP
Systematic name | M7411
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in mature neuron cell line: control versus interferon alpha (12h).
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16450_CTRL_VS_IFNA_12H_STIM_MATURE_NEURON_CELL_LINE_DN
Systematic name | M7412
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in mature neuron cell line: control versus interferon alpha (12h).
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16451_IMMATURE_VS_MATURE_NEURON_CELL_LINE_WEST_EQUINE_ENC_VIRUS_UP
Systematic name | M7413
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in neuron cell line infected with western equine encephalitis virus: immature versus mature cells.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to infection with western equine encephalitis virus (WEEV).

Standard name | GSE16450_IMMATURE_VS_MATURE_NEURON_CELL_LINE_6H_IFNA_STIM_UP
Systematic name | M7414
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in neuron cell line treated with interferon alpha for 6h: immature versus mature.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16450_IMMATURE_VS_MATURE_NEURON_CELL_LINE_6H_IFNA_STIM_DN
Systematic name | M7415
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in neuron cell line treated with interferon alpha for 6h: immature versus mature.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16450_CTRL_VS_IFNA_6H_STIM_IMMATURE_NEURON_CELL_LINE_UP
Systematic name | M7417
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in immature neuron cell line: control versus interferon alpha (6h).
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16450_IMMATURE_VS_MATURE_NEURON_CELL_LINE_12H_IFNA_STIM_DN
Systematic name | M7418
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in neuron cell line treated with interferon alpha for 12h: immature versus mature.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16450_CTRL_VS_IFNA_6H_STIM_MATURE_NEURON_CELL_LINE_UP
Systematic name | M7420
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in mature neuron cell line: control versus interferon alpha (6h).
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16450_CTRL_VS_IFNA_6H_STIM_MATURE_NEURON_CELL_LINE_DN
Systematic name | M7423
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in mature neuron cell line: control versus interferon alpha (6h).
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE16451_CTRL_VS_WEST_EQUINE_ENC_VIRUS_MATURE_NEURON_CELL_LINE_UP
Systematic name | M7424
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in the mature neuron cell line: control versus infected with western equine encephalitis virus.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to infection with western equine encephalitis virus (WEEV).

Standard name | GSE16451_CTRL_VS_WEST_EQUINE_ENC_VIRUS_MATURE_NEURON_CELL_LINE_DN
Systematic name | M7426
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in the mature neuron cell line: control versus infected with western equine encephalitis virus.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to infection with western equine encephalitis virus (WEEV).

Standard name | GSE16451_CTRL_VS_WEST_EQUINE_ENC_VIRUS_IMMATURE_NEURON_CELL_LINE_UP
Systematic name | M7427
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in the immature neuron cell line: control versus infected with western equine encephalitis viruss.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to infection with western equine encephalitis virus (WEEV).

Standard name | GSE16451_CTRL_VS_WEST_EQUINE_ENC_VIRUS_IMMATURE_NEURON_CELL_LINE_DN
Systematic name | M7428
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in the immature neuron cell line: control versus infected with western equine encephalitis viruss.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to infection with western equine encephalitis virus (WEEV).

Standard name | GSE16450_IMMATURE_VS_MATURE_NEURON_CELL_LINE_12H_IFNA_STIM_UP
Systematic name | M7430
Organism | Homo sapiens
PMID | 20483728
Authors | Peltier DC,Simms A,Farmer JR,Miller DJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in neuron cell line treated with interferon alpha for 12h: immature versus mature.
Full description | Human neuronal differentiation alters responsiveness to innate immune stimuli and virus infections. We used microarrays to examine the transcriptional responses of the human BE(2)-C neuroblastoma cell line to retinoic acid-induced differentiation and type I IFN stimulation.

Standard name | GSE21670_UNTREATED_VS_TGFB_IL6_TREATED_STAT3_KO_CD4_TCELL_UP
Systematic name | M7431
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: medium versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_TGFB_VS_IL6_TREATED_STAT3_KO_CD4_TCELL_DN
Systematic name | M7432
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: TGF beta versus IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_TGFB_VS_TGFB_AND_IL6_TREATED_CD4_TCELL_UP
Systematic name | M7433
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: TGF beta versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_TGFB_VS_TGFB_AND_IL6_TREATED_CD4_TCELL_DN
Systematic name | M7436
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: TGF beta versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_TGFB_VS_IL6_TREATED_CD4_TCELL_UP
Systematic name | M7437
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: TGF beta versus IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_TGFB_VS_IL6_TREATED_CD4_TCELL_DN
Systematic name | M7440
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: TGF beta versus IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_IL6_TREATED_CD4_TCELL_DN
Systematic name | M7441
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: medium versus IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_STAT3_KO_VS_WT_CD4_TCELL_TGFB_TREATED_UP
Systematic name | M7442
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with TGF beta: STAT3 [GeneID=6774] knockout versus wildtype.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_STAT3_KO_VS_WT_CD4_TCELL_TGFB_TREATED_DN
Systematic name | M7443
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with TGF beta: STAT3 [GeneID=6774] knockout versus wildtype.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_TGFB_IL6_TREATED_STAT3_KO_CD4_TCELL_DN
Systematic name | M7444
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: medium versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_TGFB_VS_TGFB_AND_IL6_TREATED_STAT3_KO_CD4_TCELL_UP
Systematic name | M7446
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: TGF beta versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_TGFB_VS_TGFB_AND_IL6_TREATED_STAT3_KO_CD4_TCELL_DN
Systematic name | M7447
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: TGF beta versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_TGFB_VS_IL6_TREATED_STAT3_KO_CD4_TCELL_UP
Systematic name | M7448
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: TGF beta versus IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_IL6_VS_TGFB_AND_IL6_TREATED_STAT3_KO_CD4_TCELL_UP
Systematic name | M7449
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: IL6 [GeneID=3569] versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_IL6_VS_TGFB_AND_IL6_TREATED_STAT3_KO_CD4_TCELL_DN
Systematic name | M7451
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: IL6 [GeneID=3569] versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_STAT3_KO_VS_WT_CD4_TCELL_TGFB_IL6_TREATED_UP
Systematic name | M7452
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with TGF beta and IL6 [GeneID=3569]: STAT3 [GeneID=6774] knockout versus wildtype.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_STAT3_KO_VS_WT_CD4_TCELL_TGFB_IL6_TREATED_DN
Systematic name | M7453
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with TGF beta and IL6 [GeneID=3569]: STAT3 [GeneID=6774] knockout versus wildtype.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_STAT3_KO_VS_WT_CD4_TCELL_DN
Systematic name | M7454
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: STAT3 [GeneID=6774] knockout versus wildtype.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_IL6_TREATED_STAT3_KO_CD4_TCELL_UP
Systematic name | M7457
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: medium versus IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_IL6_TREATED_STAT3_KO_CD4_TCELL_DN
Systematic name | M7458
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: medium versus IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_IL6_TREATED_CD4_TCELL_UP
Systematic name | M7459
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: medium versus IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_TGFB_IL6_TREATED_CD4_TCELL_DN
Systematic name | M7460
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: medium versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_TGFB_TREATED_STAT3_KO_CD4_TCELL_DN
Systematic name | M7463
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: medium versus TGF beta.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_IL6_VS_TGFB_AND_IL6_TREATED_CD4_TCELL_UP
Systematic name | M7464
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: IL6 [GeneID=3569] versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_TGFB_IL6_TREATED_CD4_TCELL_UP
Systematic name | M7467
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: medium versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_STAT3_KO_VS_WT_CD4_TCELL_UP
Systematic name | M7468
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: STAT3 [GeneID=6774] knockout versus wildtype.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_STAT3_KO_VS_WT_CD4_TCELL_IL6_TREATED_DN
Systematic name | M7469
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with IL6 [GeneID=3569]: STAT3 [GeneID=6774] knockout versus wildtype.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_TGFB_TREATED_CD4_TCELL_UP
Systematic name | M7471
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: medium versus TGF beta.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_TGFB_TREATED_CD4_TCELL_DN
Systematic name | M7472
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: medium versus TGF beta.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_IL6_VS_TGFB_AND_IL6_TREATED_CD4_TCELL_DN
Systematic name | M7473
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: IL6 [GeneID=3569] versus TGF beta and IL6 [GeneID=3569].
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_UNTREATED_VS_TGFB_TREATED_STAT3_KO_CD4_TCELL_UP
Systematic name | M7474
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells with STAT3 [GeneID=6774] knockout: medium versus TGF beta.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE21670_STAT3_KO_VS_WT_CD4_TCELL_IL6_TREATED_UP
Systematic name | M7475
Organism | Mus musculus
PMID | 20493732
Authors | Durant L,Watford WT,Ramos HL,Laurence A,Vahedi G,Wei L,Takahashi H,Sun HW,Kanno Y,Powrie F,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with IL6 [GeneID=3569]: STAT3 [GeneID=6774] knockout versus wildtype.
Full description | STAT3, an essential transcription factor with pleiotropic functions, plays critical roles in the pathogenesis of autoimmunity. Despite recent data linking STAT3 with inflammatory bowel disease, exactly how it contributes to chronic intestinal inflammation is not known. Using a T cell transfer model of colitis we found that STAT3 expression in T cells was essential for the induction of both colitis and systemic inflammation. STAT3 was critical in modulating the balance of T helper 17 (Th17) and regulatory T (Treg) cells, as well as in promoting CD4+ T cell proliferation. We used chromatin immunoprecipitation and massive parallel sequencing (ChIP-Seq) to define the genome-wide targets of STAT3 in CD4+ T cells. We found that STAT3 bound to multiple genes involved in Th17 cell differentiation, cell activation, proliferation and survival, regulating both expression and epigenetic modifications. Thus, STAT3 orchestrates multiple critical aspects of T cell function in inflammation and homeostasis.

Standard name | GSE22229_UNTREATED_VS_IMMUNOSUPP_THERAPY_RENAL_TRANSPLANT_PATIENT_PBMC_UP
Systematic name | M7478
Organism | Homo sapiens
PMID | 20501946
Authors | Newell KA,Asare A,Kirk AD,Gisler TD,Bourcier K,Suthanthiran M,Burlingham WJ,Marks WH,Sanz I,Lechler RI,Hernandez-Fuentes MP,Turka LA,Seyfert-Margolis VL,LastName M
Category | C7
Sub-category |
Brief description | Genes up-regulated in periperal blood monocytes (PBMC) from kidney transplant recipients: tolerant versus immunosuppressive therapy.
Full description | In this study, investigators recruited the largest reported cohort of tolerant kidney transplant recipients who maintained their graft after ceasing to take their immunosuppression drug, and compared this cohort to subjects with stable allograft function while on immunosuppression and healthy non transplated, controls. Using gene expression studies, they identified genetic markers that are strong candidates for predicting kidney transplant candidates who may benefit from minimization or withdrawl of immunosuppression. Microarrays were used to detect expressed gene profiles of whole-blood total RNA from subjects in the tolerant, standard immunotherapy and healthy control participants

Standard name | GSE22229_RENAL_TRANSPLANT_IMMUNOSUPP_THERAPY_VS_HEALTHY_PBMC_DN
Systematic name | M7479
Organism | Homo sapiens
PMID | 20501946
Authors | Newell KA,Asare A,Kirk AD,Gisler TD,Bourcier K,Suthanthiran M,Burlingham WJ,Marks WH,Sanz I,Lechler RI,Hernandez-Fuentes MP,Turka LA,Seyfert-Margolis VL,LastName M
Category | C7
Sub-category |
Brief description | Genes down-regulated in periperal blood monocytes (PBMC): kidney transplant recipients receiving immunosuppression therapy versus healthy controls.
Full description | In this study, investigators recruited the largest reported cohort of tolerant kidney transplant recipients who maintained their graft after ceasing to take their immunosuppression drug, and compared this cohort to subjects with stable allograft function while on immunosuppression and healthy non transplated, controls. Using gene expression studies, they identified genetic markers that are strong candidates for predicting kidney transplant candidates who may benefit from minimization or withdrawl of immunosuppression. Microarrays were used to detect expressed gene profiles of whole-blood total RNA from subjects in the tolerant, standard immunotherapy and healthy control participants

Standard name | GSE22229_RENAL_TRANSPLANT_VS_HEALTHY_PBMC_DN
Systematic name | M7480
Organism | Homo sapiens
PMID | 20501946
Authors | Newell KA,Asare A,Kirk AD,Gisler TD,Bourcier K,Suthanthiran M,Burlingham WJ,Marks WH,Sanz I,Lechler RI,Hernandez-Fuentes MP,Turka LA,Seyfert-Margolis VL,LastName M
Category | C7
Sub-category |
Brief description | Genes down-regulated in periperal blood monocytes (PBMC): tolerant kidney transplants versus healthy controls.
Full description | In this study, investigators recruited the largest reported cohort of tolerant kidney transplant recipients who maintained their graft after ceasing to take their immunosuppression drug, and compared this cohort to subjects with stable allograft function while on immunosuppression and healthy non transplated, controls. Using gene expression studies, they identified genetic markers that are strong candidates for predicting kidney transplant candidates who may benefit from minimization or withdrawl of immunosuppression. Microarrays were used to detect expressed gene profiles of whole-blood total RNA from subjects in the tolerant, standard immunotherapy and healthy control participants

Standard name | GSE22229_RENAL_TRANSPLANT_IMMUNOSUPP_THERAPY_VS_HEALTHY_PBMC_UP
Systematic name | M7483
Organism | Homo sapiens
PMID | 20501946
Authors | Newell KA,Asare A,Kirk AD,Gisler TD,Bourcier K,Suthanthiran M,Burlingham WJ,Marks WH,Sanz I,Lechler RI,Hernandez-Fuentes MP,Turka LA,Seyfert-Margolis VL,LastName M
Category | C7
Sub-category |
Brief description | Genes up-regulated in periperal blood monocytes (PBMC): kidney transplant recipients receiving immunosuppression therapy versus healthy controls.
Full description | In this study, investigators recruited the largest reported cohort of tolerant kidney transplant recipients who maintained their graft after ceasing to take their immunosuppression drug, and compared this cohort to subjects with stable allograft function while on immunosuppression and healthy non transplated, controls. Using gene expression studies, they identified genetic markers that are strong candidates for predicting kidney transplant candidates who may benefit from minimization or withdrawl of immunosuppression. Microarrays were used to detect expressed gene profiles of whole-blood total RNA from subjects in the tolerant, standard immunotherapy and healthy control participants

Standard name | GSE22229_UNTREATED_VS_IMMUNOSUPP_THERAPY_RENAL_TRANSPLANT_PATIENT_PBMC_DN
Systematic name | M7485
Organism | Homo sapiens
PMID | 20501946
Authors | Newell KA,Asare A,Kirk AD,Gisler TD,Bourcier K,Suthanthiran M,Burlingham WJ,Marks WH,Sanz I,Lechler RI,Hernandez-Fuentes MP,Turka LA,Seyfert-Margolis VL,LastName M
Category | C7
Sub-category |
Brief description | Genes down-regulated in periperal blood monocytes (PBMC) from kidney transplant recipients: tolerant versus immunosuppressive therapy.
Full description | In this study, investigators recruited the largest reported cohort of tolerant kidney transplant recipients who maintained their graft after ceasing to take their immunosuppression drug, and compared this cohort to subjects with stable allograft function while on immunosuppression and healthy non transplated, controls. Using gene expression studies, they identified genetic markers that are strong candidates for predicting kidney transplant candidates who may benefit from minimization or withdrawl of immunosuppression. Microarrays were used to detect expressed gene profiles of whole-blood total RNA from subjects in the tolerant, standard immunotherapy and healthy control participants

Standard name | GSE22229_RENAL_TRANSPLANT_VS_HEALTHY_PBMC_UP
Systematic name | M7486
Organism | Homo sapiens
PMID | 20501946
Authors | Newell KA,Asare A,Kirk AD,Gisler TD,Bourcier K,Suthanthiran M,Burlingham WJ,Marks WH,Sanz I,Lechler RI,Hernandez-Fuentes MP,Turka LA,Seyfert-Margolis VL,LastName M
Category | C7
Sub-category |
Brief description | Genes up-regulated in periperal blood monocytes (PBMC): tolerant kidney transplants versus healthy controls.
Full description | In this study, investigators recruited the largest reported cohort of tolerant kidney transplant recipients who maintained their graft after ceasing to take their immunosuppression drug, and compared this cohort to subjects with stable allograft function while on immunosuppression and healthy non transplated, controls. Using gene expression studies, they identified genetic markers that are strong candidates for predicting kidney transplant candidates who may benefit from minimization or withdrawl of immunosuppression. Microarrays were used to detect expressed gene profiles of whole-blood total RNA from subjects in the tolerant, standard immunotherapy and healthy control participants

Standard name | GSE21774_CD56_BRIGHT_VS_DIM_CD62L_POSITIVE_NK_CELL_UP
Systematic name | M7489
Organism | Homo sapiens
PMID | 20505160
Authors | Juelke K,Killig M,Luetke-Eversloh M,Parente E,Gruen J,Morandi B,Ferlazzo G,Thiel A,Schmitt-Knosalla I,Romagnani C
Category | C7
Sub-category |
Brief description | Genes up-regulated in NCAM+ [GeneID=4684] NK cells: SELL bright [GeneID=6402] versus SELL dim [GeneID=6402].
Full description | Human Natural Killer (NK) cells comprise two main subsets, CD56bright and CD56dim cells, that differ in function, phenotype and tissue localization. To further dissect the heterogeneity of CD56dim cells, we have performed transcriptome analysis and functional ex vivo characterization of human NK cell subsets according to the expression of markers related to differentiation, migration or competence. Here, we show for the first time that the ability to respond to cytokines or to activating receptors is mutually exclusive in almost all NK cells with the exception of CD56dim CD62L+ cells. Indeed, only these cells combine the ability to produce interferon (IFN)-gamma after cytokines and proliferate in vivo during viral infection with the capacity to kill and produce cytokines upon engagement of activating receptors. Therefore, CD56dim CD62L+ cells represent a unique subset of polyfunctional NK cells. Ex vivo analysis of their function, phenotype, telomere length, frequencies during ageing as well as transfer experiments of NK cell subsets into immunodeficient mice suggest that CD56dim CD62L+ cells represent an intermediate stage of NK cell maturation, which after restimulation can accomplish multiple tasks and further develop into terminally differentiated effectors.

Standard name | GSE21774_CD62L_POS_CD56_BRIGHT_VS_CD62L_NEG_CD56_DIM_NK_CELL_UP
Systematic name | M7490
Organism | Homo sapiens
PMID | 20505160
Authors | Juelke K,Killig M,Luetke-Eversloh M,Parente E,Gruen J,Morandi B,Ferlazzo G,Thiel A,Schmitt-Knosalla I,Romagnani C
Category | C7
Sub-category |
Brief description | Genes up-regulated in NCAM1+ SELL bright [GeneID=4684;6402] versus NCAM1- SELL dim [GeneID=4684;6402].
Full description | Human Natural Killer (NK) cells comprise two main subsets, CD56bright and CD56dim cells, that differ in function, phenotype and tissue localization. To further dissect the heterogeneity of CD56dim cells, we have performed transcriptome analysis and functional ex vivo characterization of human NK cell subsets according to the expression of markers related to differentiation, migration or competence. Here, we show for the first time that the ability to respond to cytokines or to activating receptors is mutually exclusive in almost all NK cells with the exception of CD56dim CD62L+ cells. Indeed, only these cells combine the ability to produce interferon (IFN)-gamma after cytokines and proliferate in vivo during viral infection with the capacity to kill and produce cytokines upon engagement of activating receptors. Therefore, CD56dim CD62L+ cells represent a unique subset of polyfunctional NK cells. Ex vivo analysis of their function, phenotype, telomere length, frequencies during ageing as well as transfer experiments of NK cell subsets into immunodeficient mice suggest that CD56dim CD62L+ cells represent an intermediate stage of NK cell maturation, which after restimulation can accomplish multiple tasks and further develop into terminally differentiated effectors.

Standard name | GSE21774_CD62L_POS_CD56_DIM_VS_CD62L_NEG_CD56_DIM_NK_CELL_UP
Systematic name | M7491
Organism | Homo sapiens
PMID | 20505160
Authors | Juelke K,Killig M,Luetke-Eversloh M,Parente E,Gruen J,Morandi B,Ferlazzo G,Thiel A,Schmitt-Knosalla I,Romagnani C
Category | C7
Sub-category |
Brief description | Genes up-regulated in SELL dim [GeneID=6402] NK cells: NCAM1+ [GeneID=4684] versus NCAM1- [GeneID=4684].
Full description | Human Natural Killer (NK) cells comprise two main subsets, CD56bright and CD56dim cells, that differ in function, phenotype and tissue localization. To further dissect the heterogeneity of CD56dim cells, we have performed transcriptome analysis and functional ex vivo characterization of human NK cell subsets according to the expression of markers related to differentiation, migration or competence. Here, we show for the first time that the ability to respond to cytokines or to activating receptors is mutually exclusive in almost all NK cells with the exception of CD56dim CD62L+ cells. Indeed, only these cells combine the ability to produce interferon (IFN)-gamma after cytokines and proliferate in vivo during viral infection with the capacity to kill and produce cytokines upon engagement of activating receptors. Therefore, CD56dim CD62L+ cells represent a unique subset of polyfunctional NK cells. Ex vivo analysis of their function, phenotype, telomere length, frequencies during ageing as well as transfer experiments of NK cell subsets into immunodeficient mice suggest that CD56dim CD62L+ cells represent an intermediate stage of NK cell maturation, which after restimulation can accomplish multiple tasks and further develop into terminally differentiated effectors.

Standard name | GSE21774_CD56_BRIGHT_VS_DIM_CD62L_POSITIVE_NK_CELL_DN
Systematic name | M7492
Organism | Homo sapiens
PMID | 20505160
Authors | Juelke K,Killig M,Luetke-Eversloh M,Parente E,Gruen J,Morandi B,Ferlazzo G,Thiel A,Schmitt-Knosalla I,Romagnani C
Category | C7
Sub-category |
Brief description | Genes down-regulated in NCAM+ [GeneID=4684] NK cells: SELL bright [GeneID=6402] versus SELL dim [GeneID=6402].
Full description | Human Natural Killer (NK) cells comprise two main subsets, CD56bright and CD56dim cells, that differ in function, phenotype and tissue localization. To further dissect the heterogeneity of CD56dim cells, we have performed transcriptome analysis and functional ex vivo characterization of human NK cell subsets according to the expression of markers related to differentiation, migration or competence. Here, we show for the first time that the ability to respond to cytokines or to activating receptors is mutually exclusive in almost all NK cells with the exception of CD56dim CD62L+ cells. Indeed, only these cells combine the ability to produce interferon (IFN)-gamma after cytokines and proliferate in vivo during viral infection with the capacity to kill and produce cytokines upon engagement of activating receptors. Therefore, CD56dim CD62L+ cells represent a unique subset of polyfunctional NK cells. Ex vivo analysis of their function, phenotype, telomere length, frequencies during ageing as well as transfer experiments of NK cell subsets into immunodeficient mice suggest that CD56dim CD62L+ cells represent an intermediate stage of NK cell maturation, which after restimulation can accomplish multiple tasks and further develop into terminally differentiated effectors.

Standard name | GSE21774_CD62L_POS_CD56_BRIGHT_VS_CD62L_NEG_CD56_DIM_NK_CELL_DN
Systematic name | M7495
Organism | Homo sapiens
PMID | 20505160
Authors | Juelke K,Killig M,Luetke-Eversloh M,Parente E,Gruen J,Morandi B,Ferlazzo G,Thiel A,Schmitt-Knosalla I,Romagnani C
Category | C7
Sub-category |
Brief description | Genes down-regulated in NCAM1+ SELL bright [GeneID=4684;6402] versus NCAM1- SELL dim [GeneID=4684;6402].
Full description | Human Natural Killer (NK) cells comprise two main subsets, CD56bright and CD56dim cells, that differ in function, phenotype and tissue localization. To further dissect the heterogeneity of CD56dim cells, we have performed transcriptome analysis and functional ex vivo characterization of human NK cell subsets according to the expression of markers related to differentiation, migration or competence. Here, we show for the first time that the ability to respond to cytokines or to activating receptors is mutually exclusive in almost all NK cells with the exception of CD56dim CD62L+ cells. Indeed, only these cells combine the ability to produce interferon (IFN)-gamma after cytokines and proliferate in vivo during viral infection with the capacity to kill and produce cytokines upon engagement of activating receptors. Therefore, CD56dim CD62L+ cells represent a unique subset of polyfunctional NK cells. Ex vivo analysis of their function, phenotype, telomere length, frequencies during ageing as well as transfer experiments of NK cell subsets into immunodeficient mice suggest that CD56dim CD62L+ cells represent an intermediate stage of NK cell maturation, which after restimulation can accomplish multiple tasks and further develop into terminally differentiated effectors.

Standard name | GSE21774_CD62L_POS_CD56_DIM_VS_CD62L_NEG_CD56_DIM_NK_CELL_DN
Systematic name | M7496
Organism | Homo sapiens
PMID | 20505160
Authors | Juelke K,Killig M,Luetke-Eversloh M,Parente E,Gruen J,Morandi B,Ferlazzo G,Thiel A,Schmitt-Knosalla I,Romagnani C
Category | C7
Sub-category |
Brief description | Genes down-regulated in SELL dim [GeneID=6402] NK cells: NCAM1+ [GeneID=4684] versus NCAM1- [GeneID=4684].
Full description | Human Natural Killer (NK) cells comprise two main subsets, CD56bright and CD56dim cells, that differ in function, phenotype and tissue localization. To further dissect the heterogeneity of CD56dim cells, we have performed transcriptome analysis and functional ex vivo characterization of human NK cell subsets according to the expression of markers related to differentiation, migration or competence. Here, we show for the first time that the ability to respond to cytokines or to activating receptors is mutually exclusive in almost all NK cells with the exception of CD56dim CD62L+ cells. Indeed, only these cells combine the ability to produce interferon (IFN)-gamma after cytokines and proliferate in vivo during viral infection with the capacity to kill and produce cytokines upon engagement of activating receptors. Therefore, CD56dim CD62L+ cells represent a unique subset of polyfunctional NK cells. Ex vivo analysis of their function, phenotype, telomere length, frequencies during ageing as well as transfer experiments of NK cell subsets into immunodeficient mice suggest that CD56dim CD62L+ cells represent an intermediate stage of NK cell maturation, which after restimulation can accomplish multiple tasks and further develop into terminally differentiated effectors.

Standard name | GSE21379_WT_VS_SAP_KO_TFH_CD4_TCELL_DN
Systematic name | M7498
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] follicular helper T cells (Tfh) with SH2D1A [GeneID=4068] knockout versus wildtype Tfh cells.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21379_WT_VS_SAP_KO_CD4_TCELL_UP
Systematic name | M7499
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] non-follicular helper T cells: wildtype versus SH2D1A [GeneID=4068] knockout.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21379_TFH_VS_NON_TFH_CD4_TCELL_UP
Systematic name | M7500
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] follicular helper T cells (Tfh) versus non-Tfh.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21379_WT_VS_SAP_KO_TFH_CD4_TCELL_UP
Systematic name | M7501
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] follicular helper T cells (Tfh) with SH2D1A [GeneID=4068] knockout versus wildtype Tfh cells.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21380_NON_TFH_VS_TFH_CD4_TCELL_DN
Systematic name | M7502
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: non-Tfh versus Tfh (T follicular helper).
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21380_NON_TFH_VS_GERMINAL_CENTER_TFH_CD4_TCELL_UP
Systematic name | M7503
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: non-Tfh versus Tfh (T follicular helper) from germinal center.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21380_NON_TFH_VS_GERMINAL_CENTER_TFH_CD4_TCELL_DN
Systematic name | M7505
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: non-Tfh versus Tfh (T follicular helper) from germinal center.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21380_TFH_VS_GERMINAL_CENTER_TFH_CD4_TCELL_UP
Systematic name | M7506
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] Tfh (T follicular helper) cells: Tfh versus Tfh from germinal center.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21379_TFH_VS_NON_TFH_CD4_TCELL_DN
Systematic name | M7508
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] follicular helper T cells (Tfh) versus non-Tfh.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21380_TFH_VS_GERMINAL_CENTER_TFH_CD4_TCELL_DN
Systematic name | M7509
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] Tfh (T follicular helper) cells: Tfh versus Tfh from germinal center.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21379_TFH_VS_NON_TFH_SAP_KO_CD4_TCELL_DN
Systematic name | M7510
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] follicular helper T cells (Tfh) with SH2D1A [GeneID=4068] knockout versus non-Tfh cells with SH2D1A [GeneID=4068] knockout.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21379_WT_VS_SAP_KO_CD4_TCELL_DN
Systematic name | M7511
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] non-follicular helper T cells: wildtype versus SH2D1A [GeneID=4068] knockout.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21380_NON_TFH_VS_TFH_CD4_TCELL_UP
Systematic name | M7515
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: non-Tfh versus Tfh (T follicular helper).
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21379_TFH_VS_NON_TFH_SAP_KO_CD4_TCELL_UP
Systematic name | M7516
Organism | Mus musculus
PMID | 20525889
Authors | Yusuf I,Kageyama R,Monticelli L,Johnston RJ,Ditoro D,Hansen K,Barnett B,Crotty S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] follicular helper T cells (Tfh) with SH2D1A [GeneID=4068] knockout versus non-Tfh cells with SH2D1A [GeneID=4068] knockout.
Full description | CD4 T cell help is critical for both the generation and maintenance of germinal centers, and T follicular helper (TFH) cells are the CD4 T cell subset required for this process. SAP (SH2D1A) expression in CD4 T cells is essential for germinal center development. However, SAP-deficient mice have only a moderate defect in TFH differentiation as defined by common TFH surface markers. CXCR5+ TFH cells are found within the germinal center as well as along the boundary regions of T/B cell zones. Here we show that germinal center associated T cells (GC TFH) can be identified by their co-expression of CXCR5 and the GL7 epitope, allowing for phenotypic and functional analysis of TFH and GC TFH populations. Here we show GC TFH are a functionally discrete subset of further polarized TFH cells, with enhanced B cell help capacity and a specialized ability to produce IL-4 in a TH2-independent manner. Strikingly, SAP-deficient mice have an absence of the GC TFH subset and SAP- TFH are defective in IL-4 and IL-21 production. We further demonstrate that SLAM (Slamf1, CD150), a surface receptor that utilizes SAP signaling, is specifically required for IL-4 production by GC TFH. GC TFH cells require IL-4 and IL-21 production for optimal help to B cells. These data illustrate complexities of SAP-dependent SLAM family receptor signaling, revealing a prominent role for SLAM receptor ligation in IL-4 production by germinal center CD4 T cells but not in TFH and GC TFH differentiation.

Standard name | GSE21546_WT_VS_SAP1A_KO_AND_ELK1_KO_DP_THYMOCYTES_DN
Systematic name | M7518
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated double positive thymocytes: wildtype versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_SAP1A_KO_ANTI_CD3_STIM_DP_THYMOCYTES_UP
Systematic name | M7519
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes stimulated by anti-CD3: wildtype versus ELK4 [GeneID=2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_ELK1_KO_DP_THYMOCYTES_UP
Systematic name | M7520
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated double positive thymocytes: wildtype versus ELK1 [GeneID=2002] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_SAP1A_KO_AND_ELK1_KO_ANTI_CD3_STIM_DP_THYMOCYTES_DN
Systematic name | M7522
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes stimulated by anti-CD3: wildtype versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_SAP1A_KO_VS_SAP1A_KO_AND_ELK1_KO_DP_THYMOCYTES_UP
Systematic name | M7523
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated double positive thymocytes: ELK4 [GeneID=2005] knockout versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_SAP1A_KO_VS_SAP1A_KO_AND_ELK1_KO_DP_THYMOCYTES_DN
Systematic name | M7524
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated double positive thymocytes: ELK4 [GeneID=2005] knockout versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_SAP1A_KO_VS_SAP1A_KO_AND_ELK1_KO_ANTI_CD3_STIM_DP_THYMOCYTES_UP
Systematic name | M7525
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes stimulated by anti-CD3: ELK4 [GeneID=2005] knockout versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_SAP1A_KO_VS_SAP1A_KO_AND_ELK1_KO_ANTI_CD3_STIM_DP_THYMOCYTES_DN
Systematic name | M7526
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes stimulated by anti-CD3: ELK4 [GeneID=2005] knockout versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_ELK1_KO_DP_THYMOCYTES_DN
Systematic name | M7527
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated double positive thymocytes: wildtype versus ELK1 [GeneID=2002] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_SAP1A_KO_AND_ELK1_KO_DP_THYMOCYTES_UP
Systematic name | M7529
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated double positive thymocytes: wildtype versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_ELK1_KO_VS_SAP1A_KO_AND_ELK1_KO_ANTI_CD3_STIM_DP_THYMOCYTES_UP
Systematic name | M7530
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in stimulated by anti-CD3 double positive thymocytes: ELK1 [GeneID=2002] knockout versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_ELK1_KO_VS_SAP1A_KO_AND_ELK1_KO_ANTI_CD3_STIM_DP_THYMOCYTES_DN
Systematic name | M7531
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in stimulated by anti-CD3 double positive thymocytes: ELK1 [GeneID=2002] knockout versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_SAP1A_KO_ANTI_CD3_STIM_DP_THYMOCYTES_DN
Systematic name | M7532
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes stimulated by anti-CD3: wildtype versus ELK4 [GeneID=2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_ELK1_KO_ANTI_CD3_STIM_DP_THYMOCYTES_UP
Systematic name | M7535
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes stimulated by anti-CD3: wildtype versus ELK1 [GeneID=2002] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_UNSTIM_VS_ANTI_CD3_STIM_SAP1A_KO_DP_THYMOCYTES_DN
Systematic name | M7536
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes with ELK4 [GeneID=2005] knockout: untreated versus stimulated by anti-CD3.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_UNSTIM_VS_ANTI_CD3_STIM_ELK1_KO_DP_THYMOCYTES_UP
Systematic name | M7537
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes with ELK1 [GeneID=2002] knockout: untreated versus stimulated by anti-CD3.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_UNSTIM_VS_ANTI_CD3_STIM_ELK1_KO_DP_THYMOCYTES_DN
Systematic name | M7538
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes with ELK1 [GeneID=2002] knockout: untreated versus stimulated by anti-CD3.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_UNSTIM_VS_ANTI_CD3_STIM_SAP1A_KO_AND_ELK1_KO_DP_THYMOCYTES_UP
Systematic name | M7539
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes with ELK1 and ELK4 [GeneID=2002;2005] knockout: untreated versus stimulated by anti-CD3.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_UNSTIM_VS_ANTI_CD3_STIM_SAP1A_KO_AND_ELK1_KO_DP_THYMOCYTES_DN
Systematic name | M7541
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes with ELK1 and ELK4 [GeneID=2002;2005] knockout: untreated versus stimulated by anti-CD3.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_SAP1A_KO_DP_THYMOCYTES_UP
Systematic name | M7543
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated double positive thymocytes: wildtype versus ELK4 [GeneID=2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_SAP1A_KO_DP_THYMOCYTES_DN
Systematic name | M7544
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated double positive thymocytes: wildtype versus ELK4 [GeneID=2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_ELK1_KO_VS_SAP1A_KO_AND_ELK1_KO_DP_THYMOCYTES_UP
Systematic name | M7545
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated double positive thymocytes: ELK1 [GeneID=2002] knockout versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_ELK1_KO_VS_SAP1A_KO_AND_ELK1_KO_DP_THYMOCYTES_DN
Systematic name | M7546
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated double positive thymocytes: ELK1 [GeneID=2002] knockout versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_UNSTIM_VS_ANTI_CD3_STIM_DP_THYMOCYTES_UP
Systematic name | M7548
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes: untreated versus stimulated by anti-CD3.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_UNSTIM_VS_ANTI_CD3_STIM_DP_THYMOCYTES_DN
Systematic name | M7549
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes: untreated versus stimulated by anti-CD3.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_UNSTIM_VS_ANTI_CD3_STIM_SAP1A_KO_DP_THYMOCYTES_UP
Systematic name | M7550
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes with ELK4 [GeneID=2005] knockout: untreated versus stimulated by anti-CD3.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_ELK1_KO_ANTI_CD3_STIM_DP_THYMOCYTES_DN
Systematic name | M7551
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes stimulated by anti-CD3: wildtype versus ELK1 [GeneID=2002] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21546_WT_VS_SAP1A_KO_AND_ELK1_KO_ANTI_CD3_STIM_DP_THYMOCYTES_UP
Systematic name | M7553
Organism | Mus musculus
PMID | 20554967
Authors | Costello P,Nicolas R,Willoughby J,Wasylyk B,Nordheim A,Treisman R
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes stimulated by anti-CD3: wildtype versus ELK1 and ELK4 [GeneID=2002;2005] knockout.
Full description | Removal of the transcription factor SAP1a member of the Ternary Complex Factor (TCF) group of transcription factors which in conjunction with Serum Response Factor (SRF) has been shown to have a profound effect on positive selection in the thymus. When another TCF Elk1 is knocked out in mice there is no effect on positive selection unless it is on a Sap1a KO background where the phenotype is very severe. We have stimulated isolated double positive T cells (DPs) with anti-CD3 to mimic positive selection and compared basal and stimulated transcription across the four genotypes to discover the downstream targets of Sap1a involved in positive selection.

Standard name | GSE21927_UNTREATED_VS_GMCSF_IL6_TREATED_BONE_MARROW_UP
Systematic name | M7554
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b BoneMarrow from BALBc mouse versus CD11b BoneMarrow from BALBc mouse incubated with GMCSF and IL-6.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_HEALTHY_VS_TUMOROUS_BALBC_MOUSE_MONOCYTE_DN
Systematic name | M7555
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b+ cells from spleen of BALB/c mice: healthy versus bearing C26GM colon carcinoma.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_VS_C26GM_TUMOR_MONOCYTE_BALBC_UP
Systematic name | M7556
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b+ cells from BALB/c mice bearing C26GM colon carcinoma: spleen of BALB/c mice: spleen versus tumor infiltrating monocytes.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_HEALTHY_VS_TUMOROUS_BALBC_MOUSE_MONOCYTE_UP
Systematic name | M7558
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b+ cells from spleen of BALB/c mice: healthy versus bearing C26GM colon carcinoma.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_VS_4T1_TUMOR_MONOCYTE_BALBC_DN
Systematic name | M7560
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b+ cells from BALB/c mice bearing 4T1 mammary carcinoma: spleen of BALB/c mice: spleen versus tumor infiltrating monocytes.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_VS_BONE_MARROW_MONOCYTE_BALBC_UP
Systematic name | M7562
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b+ cells from BALB/c mice: spleen versus bone marrow.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_C26GM_VS_4T1_TUMOR_MONOCYTE_BALBC_UP
Systematic name | M7563
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b+ cells from BALB/c mice bearing: C26GM colon carcinoma versus 4T1 mammary carcinoma.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_MONOCYTE_VS_GMCSF_GCSF_BONE_MARROW_UP
Systematic name | M7564
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b Spleen from BALBc mouse versus CD11b BoneMarrow from BALBc mouse incubated with GMCSF and GCSF.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_MONOCYTE_VS_GMCSF_GCSF_BONE_MARROW_DN
Systematic name | M7565
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b Spleen from BALBc mouse versus CD11b BoneMarrow from BALBc mouse incubated with GMCSF and GCSF.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_UNTREATED_VS_GMCSF_IL6_TREATED_BONE_MARROW_DN
Systematic name | M7567
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b BoneMarrow from BALBc mouse versus CD11b BoneMarrow from BALBc mouse incubated with GMCSF and IL-6.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_VS_BONE_MARROW_MONOCYTE_BALBC_DN
Systematic name | M7568
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b+ cells from BALB/c mice: spleen versus bone marrow.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_BALBC_VS_C57BL6_MONOCYTE_SPLEEN_UP
Systematic name | M7569
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen CD11b cells: BALBc versus C57BL6 mouse strains.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_BALBC_VS_C57BL6_MONOCYTE_SPLEEN_DN
Systematic name | M7570
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen CD11b cells: BALBc versus C57BL6 mouse strains.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_UNTREATED_VS_GMCSF_GCSF_TREATED_BONE_MARROW_DN
Systematic name | M7571
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b BoneMarrow from BALBc mouse versus CD11b BoneMarrow from BALBc mouse incubated with GMCSF and GCSF.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_GMCSF_IL6_VS_GMCSF_GCSF_TREATED_BONE_MARROW_UP
Systematic name | M7572
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b BoneMarrow from BALBc mouse incubated with GMCSF and IL-6 versus CD11b BoneMarrow from BALBc mouse incubated with GMCSF and GCSF.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_VS_C26GM_TUMOR_MONOCYTE_BALBC_DN
Systematic name | M7573
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b+ cells from BALB/c mice bearing C26GM colon carcinoma: spleen of BALB/c mice: spleen versus tumor infiltrating monocytes.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_VS_4T1_TUMOR_MONOCYTE_BALBC_UP
Systematic name | M7574
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b+ cells from BALB/c mice bearing 4T1 mammary carcinoma: spleen of BALB/c mice: spleen versus tumor infiltrating monocytes.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_BALBC_VS_C57BL6_MONOCYTE_TUMOR_DN
Systematic name | M7575
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b Tumor from BALBc mouse versus CD11b Tumor from C57BL6 mouse.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_VS_TUMOR_MONOCYTE_BALBC_UP
Systematic name | M7579
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b Spleen from BALBc mouse versus CD11b Tumor from BALBc mouse.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_VS_TUMOR_MONOCYTE_BALBC_DN
Systematic name | M7580
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b Spleen from BALBc mouse versus CD11b Tumor from BALBc mouse.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_VS_TUMOR_MONOCYTE_C57BL6_UP
Systematic name | M7582
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b Spleen from C57BL6 mouse versus CD11b Tumor from C57BL6 mouse.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_VS_TUMOR_MONOCYTE_C57BL6_DN
Systematic name | M7583
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b Spleen from C57BL6 mouse versus CD11b Tumor from C57BL6 mouse.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_EL4_VS_MCA203_TUMOR_MONOCYTES_UP
Systematic name | M7584
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b EL4 Tumor from C57BL6 mouse versus CD11b MCA203 Tumor from C57BL6 mouse.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_EL4_VS_MCA203_TUMOR_MONOCYTES_DN
Systematic name | M7586
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b EL4 Tumor from C57BL6 mouse versus CD11b MCA203 Tumor from C57BL6 mouse.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLENIC_VS_TUMOR_MONOCYTES_FROM_C26GM_TUMOROUS_MICE_BALBC_UP
Systematic name | M7587
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b+ cells from BALB/c mice bearing C26GM colon carcinoma: spleen versus tumor.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_UNTREATED_VS_GMCSF_GCSF_TREATED_BONE_MARROW_UP
Systematic name | M7588
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b BoneMarrow from BALBc mouse versus CD11b BoneMarrow from BALBc mouse incubated with GMCSF and GCSF.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLENIC_C26GM_TUMOROUS_VS_4T1_TUMOR_MONOCYTES_UP
Systematic name | M7589
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b+ cells from spleen of BALB/c mice bearing C26GM colon carcinoma versus CD11b+ cells from tumors of BALB/c mice bearing 4T1 mammary carcinoma.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLENIC_C26GM_TUMOROUS_VS_4T1_TUMOR_MONOCYTES_DN
Systematic name | M7590
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b+ cells from spleen of BALB/c mice bearing C26GM colon carcinoma versus CD11b+ cells from tumors of BALB/c mice bearing 4T1 mammary carcinoma.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLENIC_C26GM_TUMOROUS_VS_BONE_MARROW_MONOCYTES_UP
Systematic name | M7592
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b+ cells from spleen of BALB/c mice bearing C26GM colon carcinoma versus CD11b+ cells from bone marrow of healthy BALB/c mice.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLENIC_C26GM_TUMOROUS_VS_BONE_MARROW_MONOCYTES_DN
Systematic name | M7593
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b+ cells from spleen of BALB/c mice bearing C26GM colon carcinoma versus CD11b+ cells from bone marrow of healthy BALB/c mice.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_C57BL6_VS_4T1_TUMOR_BALBC_MONOCYTES_UP
Systematic name | M7594
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b+ cells from spleen of healthy C57BL6 mice versus CD11b+ cells from tumor infiltrating monocytes of BALB/c mice bearing 4T1 mammary carcinoma.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_C57BL6_VS_4T1_TUMOR_BALBC_MONOCYTES_DN
Systematic name | M7595
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b+ cells from spleen of healthy C57BL6 mice versus CD11b+ cells from tumor infiltrating monocytes of BALB/c mice bearing 4T1 mammary carcinoma.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_C57BL6_VS_EL4_TUMOR_BALBC_MONOCYTES_UP
Systematic name | M7596
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b+ from spleen of healthy C57BL6 versus CD11b+ cells from tumors of C57BL6 mice bearing EL4 lymphoma.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLEEN_C57BL6_VS_EL4_TUMOR_BALBC_MONOCYTES_DN
Systematic name | M7599
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b+ from spleen of healthy C57BL6 versus CD11b+ cells from tumors of C57BL6 mice bearing EL4 lymphoma.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_SPLENIC_VS_TUMOR_MONOCYTES_FROM_C26GM_TUMOROUS_MICE_BALBC_DN
Systematic name | M7605
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b+ cells from BALB/c mice bearing C26GM colon carcinoma: spleen versus tumor.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_BALBC_VS_C57BL6_MONOCYTE_TUMOR_UP
Systematic name | M7606
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11b Tumor from BALBc mouse versus CD11b Tumor from C57BL6 mouse.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_C26GM_VS_4T1_TUMOR_MONOCYTE_BALBC_DN
Systematic name | M7607
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b+ cells from BALB/c mice bearing: C26GM colon carcinoma versus 4T1 mammary carcinoma.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21927_GMCSF_IL6_VS_GMCSF_GCSF_TREATED_BONE_MARROW_DN
Systematic name | M7609
Organism | Mus musculus
PMID | 20605485
Authors | Marigo I,Bosio E,Solito S,Mesa C,Fernandez A,Dolcetti L,Ugel S,Sonda N,Bicciato S,Falisi E,Calabrese F,Basso G,Zanovello P,Cozzi E,Mandruzzato S,Bronte V
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11b BoneMarrow from BALBc mouse incubated with GMCSF and IL-6 versus CD11b BoneMarrow from BALBc mouse incubated with GMCSF and GCSF.
Full description | Tumor growth is associated with a profound alteration of myelopoiesis, leading to recruitment of immunosuppressive cells known as myeloid-derived suppressor cells (MDSCs). Analyzing the cytokines affecting myelo-monocytic differentiation produced by various experimental tumors, we found that GM-CSF, G-CSF, and IL-6 allowed a rapid generation of MDSCs from precursors present in mouse and human bone marrow (BM). BM-MDSCs induced by GM-CSF+IL-6 possessed the highest tolerogenic activity, as revealed by the ability to impair the priming of IFN- -producing CD8+ T cells upon in vivo adoptive transfer. Moreover, adoptive transfer of syngeneic, GM-CSF+IL-6-conditioned MDSCs to diabetic mice transplanted with allogeneic pancreatic islets resulted in long term acceptance of the allograft and correction of the diabetic status. Cytokines inducing MDSCs acted on a common molecular pathway. Immunoregulatory activity of both tumor-induced and BM-derived MDSCs was entirely dependent on C/EBP transcription factor, a key component of the emergency myelopoiesis triggered by stress and inflammation. Adoptive transfer of tumor antigen-specific CD8+ T lymphocytes resulted in therapy of established tumors only in mice lacking C/EBP in myeloid compartment. These data unveil another link between inflammation and cancer and identify a novel molecular target to control tumor-induced immune suppression. We used gene expression analysis to identify those factors, secreted by tumor-infiltrating MDSC, which could drive emathopoiesis. Moreover we compare gene expression profile of tumor-induced MDSC, obtained from either the spleen and the tumor infiltrate of tumor bearing mice, and in vitro bone marrow-derived MDSC.

Standard name | GSE21360_PRIMARY_VS_QUATERNARY_MEMORY_CD8_TCELL_DN
Systematic name | M7610
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes down-regulated in memory CD8 T cells: 1' versus 4'.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_SECONDARY_VS_TERTIARY_MEMORY_CD8_TCELL_UP
Systematic name | M7611
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes up-regulated in memory CD8 T cells: 2' versus 3'.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_NAIVE_VS_TERTIARY_MEMORY_CD8_TCELL_DN
Systematic name | M7612
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus 3' memory.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_NAIVE_VS_QUATERNARY_MEMORY_CD8_TCELL_UP
Systematic name | M7613
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes up-regulated inCD8 T cells: naïve versus 4' memory.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_NAIVE_VS_TERTIARY_MEMORY_CD8_TCELL_UP
Systematic name | M7616
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus 3' memory.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_NAIVE_VS_QUATERNARY_MEMORY_CD8_TCELL_DN
Systematic name | M7618
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes down-regulated inCD8 T cells: naïve versus 4' memory.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_PRIMARY_VS_SECONDARY_MEMORY_CD8_TCELL_UP
Systematic name | M7619
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes up-regulated in 1'Memory CD8T versus 2'Memory CD8T.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_PRIMARY_VS_SECONDARY_MEMORY_CD8_TCELL_DN
Systematic name | M7620
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes down-regulated in 1'Memory CD8T versus 2'Memory CD8T.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_SECONDARY_VS_TERTIARY_MEMORY_CD8_TCELL_DN
Systematic name | M7621
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes down-regulated in memory CD8 T cells: 2' versus 3'.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_SECONDARY_VS_QUATERNARY_MEMORY_CD8_TCELL_UP
Systematic name | M7624
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes up-regulated in memory CD8 T cells: 2' versus 4'.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_PRIMARY_VS_QUATERNARY_MEMORY_CD8_TCELL_UP
Systematic name | M7625
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes up-regulated in memory CD8 T cells: 1' versus 4'.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_NAIVE_VS_PRIMARY_MEMORY_CD8_TCELL_UP
Systematic name | M7626
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus 1' memory.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_NAIVE_VS_PRIMARY_MEMORY_CD8_TCELL_DN
Systematic name | M7627
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus 1' memory.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_NAIVE_VS_SECONDARY_MEMORY_CD8_TCELL_UP
Systematic name | M7631
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus 2' memory.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_NAIVE_VS_SECONDARY_MEMORY_CD8_TCELL_DN
Systematic name | M7632
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus 2' memory.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_SECONDARY_VS_QUATERNARY_MEMORY_CD8_TCELL_DN
Systematic name | M7633
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes down-regulated in memory CD8 T cells: 2' versus 4'.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_TERTIARY_VS_QUATERNARY_MEMORY_CD8_TCELL_UP
Systematic name | M7635
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes up-regulated in memory CD8 T cells: 3' versus 4'.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_TERTIARY_VS_QUATERNARY_MEMORY_CD8_TCELL_DN
Systematic name | M7637
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes down-regulated in memory CD8 T cells: 3' versus 4'.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_PRIMARY_VS_TERTIARY_MEMORY_CD8_TCELL_UP
Systematic name | M7640
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes up-regulated in memory CD8 T cells: 1' versus 3'.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE21360_PRIMARY_VS_TERTIARY_MEMORY_CD8_TCELL_DN
Systematic name | M7642
Organism | Mus musculus
PMID | 20619696
Authors | Wirth TC,Xue HH,Rai D,Sabel JT,Bair T,Harty JT,Badovinac VP
Category | C7
Sub-category |
Brief description | Genes down-regulated in memory CD8 T cells: 1' versus 3'.
Full description | The transcriptome of naive OT-I T cells was compared to memory CD8 T cells after 1, 2, 3, or 4 infection with ovalbumin expressing Listeria monocytogenes (LM-OVA).

Standard name | GSE22140_GERMFREE_VS_SPF_MOUSE_CD4_TCELL_DN
Systematic name | M7644
Organism | Mus musculus
PMID | 20620945
Authors | Wu HJ,Ivanov II,Darce J,Hattori K,Shima T,Umesaki Y,Littman DR,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in healthy CD4 [GeneID=920] T cells: germ free versus specific pathogen free.
Full description | A general defect of GF K/BxN T cell proliferation response toward antigen motivated us to look for the impairment in GF K/BxN T cells that might leads to the low Ab production and reduced disease phenotype seen in GF K/BxN mice. To find the difference between GF and SPF K/BxN T cells in a broad and non-biased fashion, we performed gene-expression profiling of these cells using microarrays.

Standard name | GSE22140_GERMFREE_VS_SPF_ARTHRITIC_MOUSE_CD4_TCELL_DN
Systematic name | M7645
Organism | Mus musculus
PMID | 20620945
Authors | Wu HJ,Ivanov II,Darce J,Hattori K,Shima T,Umesaki Y,Littman DR,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in arthritic (KRN model) CD4 [GeneID=920] T cells: germ free versus specific pathogen free conditions.
Full description | A general defect of GF K/BxN T cell proliferation response toward antigen motivated us to look for the impairment in GF K/BxN T cells that might leads to the low Ab production and reduced disease phenotype seen in GF K/BxN mice. To find the difference between GF and SPF K/BxN T cells in a broad and non-biased fashion, we performed gene-expression profiling of these cells using microarrays.

Standard name | GSE22140_HEALTHY_VS_ARTHRITIC_GERMFREE_MOUSE_CD4_TCELL_DN
Systematic name | M7646
Organism | Mus musculus
PMID | 20620945
Authors | Wu HJ,Ivanov II,Darce J,Hattori K,Shima T,Umesaki Y,Littman DR,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells under germ free conditions: healthy versus arthritis (KRN model).
Full description | A general defect of GF K/BxN T cell proliferation response toward antigen motivated us to look for the impairment in GF K/BxN T cells that might leads to the low Ab production and reduced disease phenotype seen in GF K/BxN mice. To find the difference between GF and SPF K/BxN T cells in a broad and non-biased fashion, we performed gene-expression profiling of these cells using microarrays.

Standard name | GSE22140_HEALTHY_VS_ARTHRITIC_GERMFREE_MOUSE_CD4_TCELL_UP
Systematic name | M7648
Organism | Mus musculus
PMID | 20620945
Authors | Wu HJ,Ivanov II,Darce J,Hattori K,Shima T,Umesaki Y,Littman DR,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells under germ free conditions: healthy versus arthritis (KRN model).
Full description | A general defect of GF K/BxN T cell proliferation response toward antigen motivated us to look for the impairment in GF K/BxN T cells that might leads to the low Ab production and reduced disease phenotype seen in GF K/BxN mice. To find the difference between GF and SPF K/BxN T cells in a broad and non-biased fashion, we performed gene-expression profiling of these cells using microarrays.

Standard name | GSE22140_GERMFREE_VS_SPF_ARTHRITIC_MOUSE_CD4_TCELL_UP
Systematic name | M7649
Organism | Mus musculus
PMID | 20620945
Authors | Wu HJ,Ivanov II,Darce J,Hattori K,Shima T,Umesaki Y,Littman DR,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in arthritic (KRN model) CD4 [GeneID=920] T cells: germ free versus specific pathogen free conditions.
Full description | A general defect of GF K/BxN T cell proliferation response toward antigen motivated us to look for the impairment in GF K/BxN T cells that might leads to the low Ab production and reduced disease phenotype seen in GF K/BxN mice. To find the difference between GF and SPF K/BxN T cells in a broad and non-biased fashion, we performed gene-expression profiling of these cells using microarrays.

Standard name | GSE22140_HEALTHY_VS_ARTHRITIC_MOUSE_CD4_TCELL_UP
Systematic name | M7650
Organism | Mus musculus
PMID | 20620945
Authors | Wu HJ,Ivanov II,Darce J,Hattori K,Shima T,Umesaki Y,Littman DR,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells under specific pathogen free conditions: healthy versus arthritis (KRN model).
Full description | A general defect of GF K/BxN T cell proliferation response toward antigen motivated us to look for the impairment in GF K/BxN T cells that might leads to the low Ab production and reduced disease phenotype seen in GF K/BxN mice. To find the difference between GF and SPF K/BxN T cells in a broad and non-biased fashion, we performed gene-expression profiling of these cells using microarrays.

Standard name | GSE22140_HEALTHY_VS_ARTHRITIC_MOUSE_CD4_TCELL_DN
Systematic name | M7651
Organism | Mus musculus
PMID | 20620945
Authors | Wu HJ,Ivanov II,Darce J,Hattori K,Shima T,Umesaki Y,Littman DR,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells under specific pathogen free conditions: healthy versus arthritis (KRN model).
Full description | A general defect of GF K/BxN T cell proliferation response toward antigen motivated us to look for the impairment in GF K/BxN T cells that might leads to the low Ab production and reduced disease phenotype seen in GF K/BxN mice. To find the difference between GF and SPF K/BxN T cells in a broad and non-biased fashion, we performed gene-expression profiling of these cells using microarrays.

Standard name | GSE22140_GERMFREE_VS_SPF_MOUSE_CD4_TCELL_UP
Systematic name | M7652
Organism | Mus musculus
PMID | 20620945
Authors | Wu HJ,Ivanov II,Darce J,Hattori K,Shima T,Umesaki Y,Littman DR,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in healthy CD4 [GeneID=920] T cells: germ free versus specific pathogen free.
Full description | A general defect of GF K/BxN T cell proliferation response toward antigen motivated us to look for the impairment in GF K/BxN T cells that might leads to the low Ab production and reduced disease phenotype seen in GF K/BxN mice. To find the difference between GF and SPF K/BxN T cells in a broad and non-biased fashion, we performed gene-expression profiling of these cells using microarrays.

Standard name | GSE22196_HEALTHY_VS_OBESE_MOUSE_SKIN_GAMMADELTA_TCELL_DN
Systematic name | M7653
Organism | Mus musculus
PMID | 20625397
Authors | Taylor KR,Mills RE,Costanzo AE,Jameson JM
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin gamma delta T cells: healthy versus obesity.
Full description | Epithelial cells provide an initial line of defense against damage and pathogens in barrier tissues such as the skin; however this balance is disrupted in obesity and metabolic disease. Skin gamma delta T cells recognize epithelial damage and release cytokines and growth factors that facilitate wound repair. To determine the impact of obesity and metabolic disease on skin gamma delta T cells, we isolated skin gamma delta T cells from 10-week old C57BLKS/J lean db/+ and obese db/db animals for further study. Due to a deficiency in the leptin receptor (db), homozygous db/db animals do not process satiety signals, continually eat and develop severe obesity and metabolic disease. Skin gamma delta T cells isolated from these animals were compared for changes in mRNA expression using microarray. We have determined that obesity and metabolic disease negatively impacts homeostasis and functionality of skin gamma delta T cells, rendering host defense mechanisms vulnerable to injury and infection.

Standard name | GSE22196_HEALTHY_VS_OBESE_MOUSE_SKIN_GAMMADELTA_TCELL_UP
Systematic name | M7655
Organism | Mus musculus
PMID | 20625397
Authors | Taylor KR,Mills RE,Costanzo AE,Jameson JM
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin gamma delta T cells: healthy versus obesity.
Full description | Epithelial cells provide an initial line of defense against damage and pathogens in barrier tissues such as the skin; however this balance is disrupted in obesity and metabolic disease. Skin gamma delta T cells recognize epithelial damage and release cytokines and growth factors that facilitate wound repair. To determine the impact of obesity and metabolic disease on skin gamma delta T cells, we isolated skin gamma delta T cells from 10-week old C57BLKS/J lean db/+ and obese db/db animals for further study. Due to a deficiency in the leptin receptor (db), homozygous db/db animals do not process satiety signals, continually eat and develop severe obesity and metabolic disease. Skin gamma delta T cells isolated from these animals were compared for changes in mRNA expression using microarray. We have determined that obesity and metabolic disease negatively impacts homeostasis and functionality of skin gamma delta T cells, rendering host defense mechanisms vulnerable to injury and infection.

Standard name | GSE19401_NAIVE_VS_IMMUNIZED_MOUSE_PLN_FOLLICULAR_DC_UP
Systematic name | M7656
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes up-regulated in ex vivo follicular dendritic cells from peripheral lymph nodes: naïve versus immunized mice.
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_NAIVE_VS_IMMUNIZED_MOUSE_PLN_FOLLICULAR_DC_DN
Systematic name | M7658
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes down-regulated in ex vivo follicular dendritic cells from peripheral lymph nodes: naïve versus immunized mice.
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_UNSTIM_VS_RETINOIC_ACID_AND_PAM2CSK4_STIM_FOLLICULAR_DC_DN
Systematic name | M7659
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes down-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes: non-stimulated versus tretinoin [PubChem=444795] and Pam2CSK4 (96h).
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_UNSTIM_VS_RETINOIC_ACID_STIM_FOLLICULAR_DC_UP
Systematic name | M7661
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes up-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes: non-stimulated versus tretinoin [PubChem=444795] (96h).
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_UNSTIM_VS_RETINOIC_ACID_STIM_FOLLICULAR_DC_DN
Systematic name | M7664
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes down-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes: non-stimulated versus tretinoin [PubChem=444795] (96h).
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_UNSTIM_VS_RETINOIC_ACID_AND_PAM2CSK4_STIM_FOLLICULAR_DC_UP
Systematic name | M7665
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes up-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes: non-stimulated versus tretinoin [PubChem=444795] and Pam2CSK4 (96h).
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_PLN_VS_PEYERS_PATCH_FOLLICULAR_DC_UP
Systematic name | M7666
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes up-regulated in ex vivo follicular dendritic cells: peripheral lymph node versus Peyers patch.
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_PLN_VS_PEYERS_PATCH_FOLLICULAR_DC_DN
Systematic name | M7667
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes down-regulated in ex vivo follicular dendritic cells: peripheral lymph node versus Peyers patch.
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_PAM2CSK4_VS_RETINOIC_ACID_AND_PAM2CSK4_STIM_FOLLICULAR_DC_DN
Systematic name | M7668
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes down-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes (96h): Pam2CSK4 versus tretinoin [PubChem=444795] and Pam2CSK4.
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_UNSTIM_VS_PAM2CSK4_STIM_FOLLICULAR_DC_UP
Systematic name | M7670
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes up-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes: unstimulated versus Pam2CSK4 (96h).
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_UNSTIM_VS_PAM2CSK4_STIM_FOLLICULAR_DC_DN
Systematic name | M7671
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes down-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes: unstimulated versus Pam2CSK4 (96h).
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_PAM2CSK4_VS_RETINOIC_ACID_STIM_FOLLICULAR_DC_DN
Systematic name | M7672
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes down-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes (96h): Pam2CSK4 versus tretinoin [PubChem=444795].
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_PAM2CSK4_VS_RETINOIC_ACID_AND_PAM2CSK4_STIM_FOLLICULAR_DC_UP
Systematic name | M7673
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes up-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes (96h): Pam2CSK4 versus tretinoin [PubChem=444795] and Pam2CSK4.
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_PAM2CSK4_VS_RETINOIC_ACID_STIM_FOLLICULAR_DC_UP
Systematic name | M7674
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes up-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes (96h): Pam2CSK4 versus tretinoin [PubChem=444795].
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_RETINOIC_ACID_VS_RETINOIC_ACID_AND_PAM2CSK4_STIM_FOLLICULAR_DC_DN
Systematic name | M7679
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes down-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes (96h): tretinoin [PubChem=444795] versus tretinoin [PubChem=444795] and Pam2CSK4.
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE19401_RETINOIC_ACID_VS_RETINOIC_ACID_AND_PAM2CSK4_STIM_FOLLICULAR_DC_UP
Systematic name | M7680
Organism | Mus musculus
PMID | 20643338
Authors | Suzuki K,Maruya M,Kawamoto S,Sitnik K,Kitamura H,Agace WW,Fagarasan S
Category | C7
Sub-category |
Brief description | Genes up-regulated in the in vitro follicular dendritic cells from peripheral lymph nodes (96h): tretinoin [PubChem=444795] versus tretinoin [PubChem=444795] and Pam2CSK4.
Full description | Germinal centers (GCs) are clusters of activated B cells built on stromal cells known as follicular dendritic cells (FDCs). In the Peyer’s patches (PPs), GCs are chronically induced by bacteria and are the major sites for generation of gut IgA immune responses. Whether FDCs directly contribute to the IgA production in PP GCs is unknown. To investigate the role FDCs in gut immune system, we examined comprehensive gene profiles of FDCs purified from PPs or perypheral lymph nodes (pLNs) with or without immunization. We also tried to reconstitute the PP FDC signature in vitro by pulsed or continuous stimulation of pLN FDCs through TLRs, RARs or simultaneously through TLRs and RARs.

Standard name | GSE20152_HTNFA_OVERXPRESS_ANKLE_VS_CTRL_SPHK1_KO_ANKLE_DN
Systematic name | M7681
Organism | Mus musculus
PMID | 20644167
Authors | Baker DA,Barth J,Chang R,Obeid LM,Gilkeson GS
Category | C7
Sub-category |
Brief description | Genes down-regulated in ankle joints from SPHK1 [GeneID=8877] knockout: TNF [GeneID=7124] over-expression versus control.
Full description | The study analyzes analyzes gene expression changes in the ankle joint in mouse TNFa overexpression models with or without sphingosine kinase 1 activity. SphK1 is a sphingolipid enzyme that converts sphingosine to bioactive sphingosine-1-phosphate (S1P). Recent data suggest a potential relationship between SphK1 and TNFα and have implicated SphK1/S1P in the development and progression of inflammation. Here we further study the relationship of TNFα and SphK1 using an in vivo model. Transgenic hTNFα mice, which develop a spontaneous arthritis (limited to paws) at 20 weeks, were crossed with SphK1 activity null mice (SphK1-/-) to study the development of inflammatory arthritis in the functional absence of SphK1. Results show that hTNF/SphK1-/- have significantly less severity and progression of arthritis and bone erosions as measured through micro-CT images. Additionally, less COX-2 protein, mTNFα transcript levels and fewer Th 17 cells were detected in the joints of hTNF/SphK1-/- compared to hTNF/SphK1+/+ mice. Microarray analysis of the ankle joint showed that hTNF/SphK1-/- mice have increased transcript levels of IL-6 and SOCS3 compared to hTNF/SphK1+/+ mice. Finally, fewer mature osteoclasts were detected in the ankle joints of hTNF/SphK1-/- mice compared to hTNF/SphK1+/+ mice. These data show that SphK1 plays a role in hTNFα induced inflammatory arthritis, potentially through a novel pathway involving IL-6 and SOCS3.

Standard name | GSE20152_SPHK1_KO_VS_HTNFA_OVEREXPRESS_ANKLE_UP
Systematic name | M7682
Organism | Mus musculus
PMID | 20644167
Authors | Baker DA,Barth J,Chang R,Obeid LM,Gilkeson GS
Category | C7
Sub-category |
Brief description | Genes up-regulated in ankle joints: SPHK1 [GeneID=8877] versus wildtype over-expressing TNF [GeneID=7124].
Full description | The study analyzes analyzes gene expression changes in the ankle joint in mouse TNFa overexpression models with or without sphingosine kinase 1 activity. SphK1 is a sphingolipid enzyme that converts sphingosine to bioactive sphingosine-1-phosphate (S1P). Recent data suggest a potential relationship between SphK1 and TNFα and have implicated SphK1/S1P in the development and progression of inflammation. Here we further study the relationship of TNFα and SphK1 using an in vivo model. Transgenic hTNFα mice, which develop a spontaneous arthritis (limited to paws) at 20 weeks, were crossed with SphK1 activity null mice (SphK1-/-) to study the development of inflammatory arthritis in the functional absence of SphK1. Results show that hTNF/SphK1-/- have significantly less severity and progression of arthritis and bone erosions as measured through micro-CT images. Additionally, less COX-2 protein, mTNFα transcript levels and fewer Th 17 cells were detected in the joints of hTNF/SphK1-/- compared to hTNF/SphK1+/+ mice. Microarray analysis of the ankle joint showed that hTNF/SphK1-/- mice have increased transcript levels of IL-6 and SOCS3 compared to hTNF/SphK1+/+ mice. Finally, fewer mature osteoclasts were detected in the ankle joints of hTNF/SphK1-/- mice compared to hTNF/SphK1+/+ mice. These data show that SphK1 plays a role in hTNFα induced inflammatory arthritis, potentially through a novel pathway involving IL-6 and SOCS3.

Standard name | GSE20152_SPHK1_KO_VS_HTNFA_OVEREXPRESS_ANKLE_DN
Systematic name | M7683
Organism | Mus musculus
PMID | 20644167
Authors | Baker DA,Barth J,Chang R,Obeid LM,Gilkeson GS
Category | C7
Sub-category |
Brief description | Genes down-regulated in ankle joints: SPHK1 [GeneID=8877] versus wildtype over-expressing TNF [GeneID=7124].
Full description | The study analyzes analyzes gene expression changes in the ankle joint in mouse TNFa overexpression models with or without sphingosine kinase 1 activity. SphK1 is a sphingolipid enzyme that converts sphingosine to bioactive sphingosine-1-phosphate (S1P). Recent data suggest a potential relationship between SphK1 and TNFα and have implicated SphK1/S1P in the development and progression of inflammation. Here we further study the relationship of TNFα and SphK1 using an in vivo model. Transgenic hTNFα mice, which develop a spontaneous arthritis (limited to paws) at 20 weeks, were crossed with SphK1 activity null mice (SphK1-/-) to study the development of inflammatory arthritis in the functional absence of SphK1. Results show that hTNF/SphK1-/- have significantly less severity and progression of arthritis and bone erosions as measured through micro-CT images. Additionally, less COX-2 protein, mTNFα transcript levels and fewer Th 17 cells were detected in the joints of hTNF/SphK1-/- compared to hTNF/SphK1+/+ mice. Microarray analysis of the ankle joint showed that hTNF/SphK1-/- mice have increased transcript levels of IL-6 and SOCS3 compared to hTNF/SphK1+/+ mice. Finally, fewer mature osteoclasts were detected in the ankle joints of hTNF/SphK1-/- mice compared to hTNF/SphK1+/+ mice. These data show that SphK1 plays a role in hTNFα induced inflammatory arthritis, potentially through a novel pathway involving IL-6 and SOCS3.

Standard name | GSE20152_SPHK1_KO_VS_WT_HTNFA_OVERXPRESS_ANKLE_UP
Systematic name | M7684
Organism | Mus musculus
PMID | 20644167
Authors | Baker DA,Barth J,Chang R,Obeid LM,Gilkeson GS
Category | C7
Sub-category |
Brief description | Genes up-regulated in ankle joints over-expressing TNF [GeneID=7124]: SPHK1 [GeneID=8877] knockout versus wildtype.
Full description | The study analyzes analyzes gene expression changes in the ankle joint in mouse TNFa overexpression models with or without sphingosine kinase 1 activity. SphK1 is a sphingolipid enzyme that converts sphingosine to bioactive sphingosine-1-phosphate (S1P). Recent data suggest a potential relationship between SphK1 and TNFα and have implicated SphK1/S1P in the development and progression of inflammation. Here we further study the relationship of TNFα and SphK1 using an in vivo model. Transgenic hTNFα mice, which develop a spontaneous arthritis (limited to paws) at 20 weeks, were crossed with SphK1 activity null mice (SphK1-/-) to study the development of inflammatory arthritis in the functional absence of SphK1. Results show that hTNF/SphK1-/- have significantly less severity and progression of arthritis and bone erosions as measured through micro-CT images. Additionally, less COX-2 protein, mTNFα transcript levels and fewer Th 17 cells were detected in the joints of hTNF/SphK1-/- compared to hTNF/SphK1+/+ mice. Microarray analysis of the ankle joint showed that hTNF/SphK1-/- mice have increased transcript levels of IL-6 and SOCS3 compared to hTNF/SphK1+/+ mice. Finally, fewer mature osteoclasts were detected in the ankle joints of hTNF/SphK1-/- mice compared to hTNF/SphK1+/+ mice. These data show that SphK1 plays a role in hTNFα induced inflammatory arthritis, potentially through a novel pathway involving IL-6 and SOCS3.

Standard name | GSE20152_SPHK1_KO_VS_WT_HTNFA_OVERXPRESS_ANKLE_DN
Systematic name | M7686
Organism | Mus musculus
PMID | 20644167
Authors | Baker DA,Barth J,Chang R,Obeid LM,Gilkeson GS
Category | C7
Sub-category |
Brief description | Genes down-regulated in ankle joints over-expressing TNF [GeneID=7124]: SPHK1 [GeneID=8877] knockout versus wildtype.
Full description | The study analyzes analyzes gene expression changes in the ankle joint in mouse TNFa overexpression models with or without sphingosine kinase 1 activity. SphK1 is a sphingolipid enzyme that converts sphingosine to bioactive sphingosine-1-phosphate (S1P). Recent data suggest a potential relationship between SphK1 and TNFα and have implicated SphK1/S1P in the development and progression of inflammation. Here we further study the relationship of TNFα and SphK1 using an in vivo model. Transgenic hTNFα mice, which develop a spontaneous arthritis (limited to paws) at 20 weeks, were crossed with SphK1 activity null mice (SphK1-/-) to study the development of inflammatory arthritis in the functional absence of SphK1. Results show that hTNF/SphK1-/- have significantly less severity and progression of arthritis and bone erosions as measured through micro-CT images. Additionally, less COX-2 protein, mTNFα transcript levels and fewer Th 17 cells were detected in the joints of hTNF/SphK1-/- compared to hTNF/SphK1+/+ mice. Microarray analysis of the ankle joint showed that hTNF/SphK1-/- mice have increased transcript levels of IL-6 and SOCS3 compared to hTNF/SphK1+/+ mice. Finally, fewer mature osteoclasts were detected in the ankle joints of hTNF/SphK1-/- mice compared to hTNF/SphK1+/+ mice. These data show that SphK1 plays a role in hTNFα induced inflammatory arthritis, potentially through a novel pathway involving IL-6 and SOCS3.

Standard name | GSE20152_HTNFA_OVERXPRESS_ANKLE_VS_CTRL_SPHK1_KO_ANKLE_UP
Systematic name | M7687
Organism | Mus musculus
PMID | 20644167
Authors | Baker DA,Barth J,Chang R,Obeid LM,Gilkeson GS
Category | C7
Sub-category |
Brief description | Genes up-regulated in ankle joints from SPHK1 [GeneID=8877] knockout: TNF [GeneID=7124] over-expression versus control.
Full description | The study analyzes analyzes gene expression changes in the ankle joint in mouse TNFa overexpression models with or without sphingosine kinase 1 activity. SphK1 is a sphingolipid enzyme that converts sphingosine to bioactive sphingosine-1-phosphate (S1P). Recent data suggest a potential relationship between SphK1 and TNFα and have implicated SphK1/S1P in the development and progression of inflammation. Here we further study the relationship of TNFα and SphK1 using an in vivo model. Transgenic hTNFα mice, which develop a spontaneous arthritis (limited to paws) at 20 weeks, were crossed with SphK1 activity null mice (SphK1-/-) to study the development of inflammatory arthritis in the functional absence of SphK1. Results show that hTNF/SphK1-/- have significantly less severity and progression of arthritis and bone erosions as measured through micro-CT images. Additionally, less COX-2 protein, mTNFα transcript levels and fewer Th 17 cells were detected in the joints of hTNF/SphK1-/- compared to hTNF/SphK1+/+ mice. Microarray analysis of the ankle joint showed that hTNF/SphK1-/- mice have increased transcript levels of IL-6 and SOCS3 compared to hTNF/SphK1+/+ mice. Finally, fewer mature osteoclasts were detected in the ankle joints of hTNF/SphK1-/- mice compared to hTNF/SphK1+/+ mice. These data show that SphK1 plays a role in hTNFα induced inflammatory arthritis, potentially through a novel pathway involving IL-6 and SOCS3.

Standard name | GSE22033_UNTREATED_VS_MRL24_TREATED_MEF_UP
Systematic name | M7688
Organism | Mus musculus
PMID | 20651683
Authors | Choi JH,Banks AS,Estall JL,Kajimura S,Boström P,Laznik D,Ruas JL,Chalmers MJ,Kamenecka TM,Blüher M,Griffin PR,Spiegelman BM
Category | C7
Sub-category |
Brief description | Genes up-regulated in mouse embryonic fibroblasts (MEF): untreated versus MRL24 [PubChem=9958543].
Full description | In order to identify the molecular mechanisms of PPARgamma phosphorylation at Set273, we generated cell-lines of PPARgamma KO MEFs expressing wtPPARgamma or S273APPARgamma. In addition, because our data showed that PPARgamma ligand drugs such as rosiglitazone and MRL24 blocked this phopshorylation, we treated cells with these drugs, then prepared RNA samples to look at the gene profiling.

Standard name | GSE22033_UNTREATED_VS_ROSIGLITAZONE_TREATED_MEF_DN
Systematic name | M7690
Organism | Mus musculus
PMID | 20651683
Authors | Choi JH,Banks AS,Estall JL,Kajimura S,Boström P,Laznik D,Ruas JL,Chalmers MJ,Kamenecka TM,Blüher M,Griffin PR,Spiegelman BM
Category | C7
Sub-category |
Brief description | Genes down-regulated in mouse embryonic fibroblasts (MEF): untreated versus rosiglitazone [PubChem=77999].
Full description | In order to identify the molecular mechanisms of PPARgamma phosphorylation at Set273, we generated cell-lines of PPARgamma KO MEFs expressing wtPPARgamma or S273APPARgamma. In addition, because our data showed that PPARgamma ligand drugs such as rosiglitazone and MRL24 blocked this phopshorylation, we treated cells with these drugs, then prepared RNA samples to look at the gene profiling.

Standard name | GSE22033_WT_VS_PPARG_KO_MEF_DN
Systematic name | M7692
Organism | Mus musculus
PMID | 20651683
Authors | Choi JH,Banks AS,Estall JL,Kajimura S,Boström P,Laznik D,Ruas JL,Chalmers MJ,Kamenecka TM,Blüher M,Griffin PR,Spiegelman BM
Category | C7
Sub-category |
Brief description | Genes down-regulated in mouse embryonic fibroblasts (MEF): wildtype versus PPARG [GeneID=5468] knockout.
Full description | In order to identify the molecular mechanisms of PPARgamma phosphorylation at Set273, we generated cell-lines of PPARgamma KO MEFs expressing wtPPARgamma or S273APPARgamma. In addition, because our data showed that PPARgamma ligand drugs such as rosiglitazone and MRL24 blocked this phopshorylation, we treated cells with these drugs, then prepared RNA samples to look at the gene profiling.

Standard name | GSE22033_WT_VS_PPARG_KO_MEF_UP
Systematic name | M7694
Organism | Mus musculus
PMID | 20651683
Authors | Choi JH,Banks AS,Estall JL,Kajimura S,Boström P,Laznik D,Ruas JL,Chalmers MJ,Kamenecka TM,Blüher M,Griffin PR,Spiegelman BM
Category | C7
Sub-category |
Brief description | Genes up-regulated in mouse embryonic fibroblasts (MEF): wildtype versus PPARG [GeneID=5468] knockout.
Full description | In order to identify the molecular mechanisms of PPARgamma phosphorylation at Set273, we generated cell-lines of PPARgamma KO MEFs expressing wtPPARgamma or S273APPARgamma. In addition, because our data showed that PPARgamma ligand drugs such as rosiglitazone and MRL24 blocked this phopshorylation, we treated cells with these drugs, then prepared RNA samples to look at the gene profiling.

Standard name | GSE22033_UNTREATED_VS_ROSIGLITAZONE_TREATED_MEF_UP
Systematic name | M7695
Organism | Mus musculus
PMID | 20651683
Authors | Choi JH,Banks AS,Estall JL,Kajimura S,Boström P,Laznik D,Ruas JL,Chalmers MJ,Kamenecka TM,Blüher M,Griffin PR,Spiegelman BM
Category | C7
Sub-category |
Brief description | Genes up-regulated in mouse embryonic fibroblasts (MEF): untreated versus rosiglitazone [PubChem=77999].
Full description | In order to identify the molecular mechanisms of PPARgamma phosphorylation at Set273, we generated cell-lines of PPARgamma KO MEFs expressing wtPPARgamma or S273APPARgamma. In addition, because our data showed that PPARgamma ligand drugs such as rosiglitazone and MRL24 blocked this phopshorylation, we treated cells with these drugs, then prepared RNA samples to look at the gene profiling.

Standard name | GSE22033_UNTREATED_VS_MRL24_TREATED_MEF_DN
Systematic name | M7696
Organism | Mus musculus
PMID | 20651683
Authors | Choi JH,Banks AS,Estall JL,Kajimura S,Boström P,Laznik D,Ruas JL,Chalmers MJ,Kamenecka TM,Blüher M,Griffin PR,Spiegelman BM
Category | C7
Sub-category |
Brief description | Genes down-regulated in mouse embryonic fibroblasts (MEF): untreated versus MRL24 [PubChem=9958543].
Full description | In order to identify the molecular mechanisms of PPARgamma phosphorylation at Set273, we generated cell-lines of PPARgamma KO MEFs expressing wtPPARgamma or S273APPARgamma. In addition, because our data showed that PPARgamma ligand drugs such as rosiglitazone and MRL24 blocked this phopshorylation, we treated cells with these drugs, then prepared RNA samples to look at the gene profiling.

Standard name | GSE20500_CTRL_VS_RETINOIC_ACID_TREATED_CD4_TCELL_UP
Systematic name | M7697
Organism | Mus musculus
PMID | 20664575
Authors | Kang SG,Park J,Cho JY,Ulrich B,Kim CH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: control versus tretinoin [PubChem=444795].
Full description | This is to determine the T cell genes regulated by retinoic acid.

Standard name | GSE20500_CTRL_VS_RETINOIC_ACID_TREATED_CD4_TCELL_DN
Systematic name | M7701
Organism | Mus musculus
PMID | 20664575
Authors | Kang SG,Park J,Cho JY,Ulrich B,Kim CH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: control versus tretinoin [PubChem=444795].
Full description | This is to determine the T cell genes regulated by retinoic acid.

Standard name | GSE20500_RETINOIC_ACID_VS_RARA_ANTAGONIST_TREATED_CD4_TCELL_UP
Systematic name | M7702
Organism | Mus musculus
PMID | 20664575
Authors | Kang SG,Park J,Cho JY,Ulrich B,Kim CH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: tretinoin [PubChem=444795] versus Ro 41-5253 [PubChem=5312120].
Full description | This is to determine the T cell genes regulated by retinoic acid.

Standard name | GSE20500_CTRL_VS_RARA_ANTAGONIST_TREATED_CD4_TCELL_UP
Systematic name | M7706
Organism | Mus musculus
PMID | 20664575
Authors | Kang SG,Park J,Cho JY,Ulrich B,Kim CH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: control versus Ro 41-5253 [PubChem=5312120].
Full description | This is to determine the T cell genes regulated by retinoic acid.

Standard name | GSE20500_CTRL_VS_RARA_ANTAGONIST_TREATED_CD4_TCELL_DN
Systematic name | M7707
Organism | Mus musculus
PMID | 20664575
Authors | Kang SG,Park J,Cho JY,Ulrich B,Kim CH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: control versus Ro 41-5253 [PubChem=5312120].
Full description | This is to determine the T cell genes regulated by retinoic acid.

Standard name | GSE20500_RETINOIC_ACID_VS_RARA_ANTAGONIST_TREATED_CD4_TCELL_DN
Systematic name | M7708
Organism | Mus musculus
PMID | 20664575
Authors | Kang SG,Park J,Cho JY,Ulrich B,Kim CH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: tretinoin [PubChem=444795] versus Ro 41-5253 [PubChem=5312120].
Full description | This is to determine the T cell genes regulated by retinoic acid.

Standard name | GSE22527_ANTI_CD3_INVIVO_VS_UNTREATED_MOUSE_TREG_DN
Systematic name | M7709
Organism | Mus musculus
PMID | 20679403
Authors | Nishio J,Feuerer M,Wong J,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg following anti-CD3 in vivo treatment versus control.
Full description | Treatment with anti-CD3 is a promising therapeutic approach for autoimmune diabetes, but its mechanism of action remains unclear. Foxp3+ regulatory T (Treg) cells may be involved, but the evidence has been conflicting, and there is great uncertainty as to possible mechanistic connections. We investigated this issue in mice derived from the NOD model, which were engineered mice in which Treg populations were perturbed, or could be manipulated by acute ablation or transfer. The data highlighted the involvement of Foxp3+ cells in anti-CD3 action. Rather than a generic influence on all Treg cells, the therapeutic effect seemed to involve an striking expansion of previously constrained Treg cell populations; this expansion occurred not through conversion from Foxp3- Tconv cells but from a dramatic proliferative expansion. We found that Treg cells are normally constrained by TCR-specific niches in secondary lymphoid organs, and that intraclonal competition restrains their possibility for conversion and expansion in the spleen and lymph nodes, much as niche competition limits their selection in the thymus. The strong perturbations induced by anti-CD3 overcame these niche limitations, in a process dependent on receptors for trophic cytokines, interleukin-2 receptor (IL-2R) and IL-7R.

Standard name | GSE22527_ANTI_CD3_INVIVO_VS_UNTREATED_MOUSE_TREG_UP
Systematic name | M7710
Organism | Mus musculus
PMID | 20679403
Authors | Nishio J,Feuerer M,Wong J,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg following anti-CD3 in vivo treatment versus control.
Full description | Treatment with anti-CD3 is a promising therapeutic approach for autoimmune diabetes, but its mechanism of action remains unclear. Foxp3+ regulatory T (Treg) cells may be involved, but the evidence has been conflicting, and there is great uncertainty as to possible mechanistic connections. We investigated this issue in mice derived from the NOD model, which were engineered mice in which Treg populations were perturbed, or could be manipulated by acute ablation or transfer. The data highlighted the involvement of Foxp3+ cells in anti-CD3 action. Rather than a generic influence on all Treg cells, the therapeutic effect seemed to involve an striking expansion of previously constrained Treg cell populations; this expansion occurred not through conversion from Foxp3- Tconv cells but from a dramatic proliferative expansion. We found that Treg cells are normally constrained by TCR-specific niches in secondary lymphoid organs, and that intraclonal competition restrains their possibility for conversion and expansion in the spleen and lymph nodes, much as niche competition limits their selection in the thymus. The strong perturbations induced by anti-CD3 overcame these niche limitations, in a process dependent on receptors for trophic cytokines, interleukin-2 receptor (IL-2R) and IL-7R.

Standard name | GSE21033_CTRL_VS_POLYIC_STIM_DC_3H_DN
Systematic name | M7711
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 0h versus 3h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_CTRL_VS_POLYIC_STIM_DC_6H_UP
Systematic name | M7712
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 0h versus 6h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_CTRL_VS_POLYIC_STIM_DC_3H_UP
Systematic name | M7713
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 0h versus 3h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_CTRL_VS_POLYIC_STIM_DC_1H_DN
Systematic name | M7716
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 0h versus 1h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_CTRL_VS_POLYIC_STIM_DC_12H_DN
Systematic name | M7717
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 0h versus 12h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_CTRL_VS_POLYIC_STIM_DC_1H_UP
Systematic name | M7718
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 0h versus 1h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_3H_VS_12H_POLYIC_STIM_DC_DN
Systematic name | M7719
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 3h versus 12h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_1H_VS_12H_POLYIC_STIM_DC_DN
Systematic name | M7720
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 1h versus 12h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_3H_VS_24H_POLYIC_STIM_DC_UP
Systematic name | M7722
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 3h versus 24h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_3H_VS_24H_POLYIC_STIM_DC_DN
Systematic name | M7723
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 3h versus 24h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_1H_VS_12H_POLYIC_STIM_DC_UP
Systematic name | M7725
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 1h versus 12h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_CTRL_VS_POLYIC_STIM_DC_12H_UP
Systematic name | M7726
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 0h versus 12h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_1H_VS_24H_POLYIC_STIM_DC_UP
Systematic name | M7728
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 1h versus 24h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_1H_VS_24H_POLYIC_STIM_DC_DN
Systematic name | M7729
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 1h versus 24h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_3H_VS_12H_POLYIC_STIM_DC_UP
Systematic name | M7730
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 3h versus 12h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_CTRL_VS_POLYIC_STIM_DC_24H_UP
Systematic name | M7731
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 0h versus 24h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_CTRL_VS_POLYIC_STIM_DC_6H_DN
Systematic name | M7733
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 0h versus 6h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE21033_CTRL_VS_POLYIC_STIM_DC_24H_DN
Systematic name | M7734
Organism | Mus musculus
PMID | 20682054
Authors | Olex AL,Hiltbold EM,Leng X,Fetrow JS
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cellstreated by poly(IC): 0h versus 24h.
Full description | BACKGROUND: Dendritic cells (DC) play a central role in primary immune responses and become potent stimulators of the adaptive immune response after undergoing the critical process of maturation. Understanding the dynamics of DC maturation would provide key insights into this important process. Time course microarray experiments can provide unique insights into DC maturation dynamics. Replicate experiments are necessary to address the issues of experimental and biological variability. Statistical methods and averaging are often used to identify significant signals. Here a novel strategy for filtering of replicate time course microarray data, which identifies consistent signals between the replicates, is presented and applied to a DC time course microarray experiment. RESULTS: The temporal dynamics of DC maturation were studied by stimulating DC with poly(I:C) and following gene expression at 5 time points from 1 to 24 hours. The novel filtering strategy uses standard statistical and fold change techniques, along with the consistency of replicate temporal profiles, to identify those differentially expressed genes that were consistent in two biological replicate experiments. To address the issue of cluster reproducibility a consensus clustering method, which identifies clusters of genes whose expression varies consistently between replicates, was also developed and applied. Analysis of the resulting clusters revealed many known and novel characteristics of DC maturation, such as the up-regulation of specific immune response pathways. Intriguingly, more genes were down-regulated than up-regulated. Results identify a more comprehensive program of down-regulation, including many genes involved in protein synthesis, metabolism, and housekeeping needed for maintenance of cellular integrity and metabolism. CONCLUSIONS: The new filtering strategy emphasizes the importance of consistent and reproducible results when analyzing microarray data and utilizes consistency between replicate experiments as a criterion in both feature selection and clustering, without averaging or otherwise combining replicate data. Observation of a significant down-regulation program during DC maturation indicates that DC are preparing for cell death and provides a path to better understand the process. This new filtering strategy can be adapted for use in analyzing other large-scale time course data sets with replicates.

Standard name | GSE23308_WT_VS_MINERALCORTICOID_REC_KO_MACROPHAGE_CORTICOSTERONE_TREATED_UP
Systematic name | M7736
Organism | Mus musculus
PMID | 20697155
Authors | Usher MG,Duan SZ,Ivaschenko CY,Frieler RA,Berger S,Schütz G,Lumeng CN,Mortensen RM
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages treated by corticosterone [PubChem=5839]: wildtype versus NR3C2 [GeneID=4306] knockout.
Full description | Inappropriate excess of the steroid hormone aldosterone, which is a mineralocorticoid receptor (MR) agonist, is associated with increased inflammation and risk of cardiovascular disease. MR antagonists are cardioprotective and antiinflammatory in vivo, and evidence suggests that they mediate these effects in part by aldosterone- independent mechanisms. We used affymetrix to characterize the effect of Mineralocorticoid Receptor deletion on macrophage transcriptional profile, and identify its requirement in normal glucocorticoid signalling.

Standard name | GSE23308_WT_VS_MINERALCORTICOID_REC_KO_MACROPHAGE_DN
Systematic name | M7740
Organism | Mus musculus
PMID | 20697155
Authors | Usher MG,Duan SZ,Ivaschenko CY,Frieler RA,Berger S,Schütz G,Lumeng CN,Mortensen RM
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: wildtype versus NR3C2 [GeneID=4306] knockout.
Full description | Inappropriate excess of the steroid hormone aldosterone, which is a mineralocorticoid receptor (MR) agonist, is associated with increased inflammation and risk of cardiovascular disease. MR antagonists are cardioprotective and antiinflammatory in vivo, and evidence suggests that they mediate these effects in part by aldosterone- independent mechanisms. We used affymetrix to characterize the effect of Mineralocorticoid Receptor deletion on macrophage transcriptional profile, and identify its requirement in normal glucocorticoid signalling.

Standard name | GSE23308_CTRL_VS_CORTICOSTERONE_TREATED_MACROPHAGE_DN
Systematic name | M7741
Organism | Mus musculus
PMID | 20697155
Authors | Usher MG,Duan SZ,Ivaschenko CY,Frieler RA,Berger S,Schütz G,Lumeng CN,Mortensen RM
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: untreated versus corticosterone [PubChem=5839].
Full description | Inappropriate excess of the steroid hormone aldosterone, which is a mineralocorticoid receptor (MR) agonist, is associated with increased inflammation and risk of cardiovascular disease. MR antagonists are cardioprotective and antiinflammatory in vivo, and evidence suggests that they mediate these effects in part by aldosterone- independent mechanisms. We used affymetrix to characterize the effect of Mineralocorticoid Receptor deletion on macrophage transcriptional profile, and identify its requirement in normal glucocorticoid signalling.

Standard name | GSE23308_WT_VS_MINERALCORTICOID_REC_KO_MACROPHAGE_UP
Systematic name | M7742
Organism | Mus musculus
PMID | 20697155
Authors | Usher MG,Duan SZ,Ivaschenko CY,Frieler RA,Berger S,Schütz G,Lumeng CN,Mortensen RM
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: wildtype versus NR3C2 [GeneID=4306] knockout.
Full description | Inappropriate excess of the steroid hormone aldosterone, which is a mineralocorticoid receptor (MR) agonist, is associated with increased inflammation and risk of cardiovascular disease. MR antagonists are cardioprotective and antiinflammatory in vivo, and evidence suggests that they mediate these effects in part by aldosterone- independent mechanisms. We used affymetrix to characterize the effect of Mineralocorticoid Receptor deletion on macrophage transcriptional profile, and identify its requirement in normal glucocorticoid signalling.

Standard name | GSE23308_CTRL_VS_CORTICOSTERONE_TREATED_MACROPHAGE_MINERALCORTICOID_REC_KO_DN
Systematic name | M7744
Organism | Mus musculus
PMID | 20697155
Authors | Usher MG,Duan SZ,Ivaschenko CY,Frieler RA,Berger S,Schütz G,Lumeng CN,Mortensen RM
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with NR3C2 [GeneID=4306] knockout: untreated versus corticosterone [PubChem=5839].
Full description | Inappropriate excess of the steroid hormone aldosterone, which is a mineralocorticoid receptor (MR) agonist, is associated with increased inflammation and risk of cardiovascular disease. MR antagonists are cardioprotective and antiinflammatory in vivo, and evidence suggests that they mediate these effects in part by aldosterone- independent mechanisms. We used affymetrix to characterize the effect of Mineralocorticoid Receptor deletion on macrophage transcriptional profile, and identify its requirement in normal glucocorticoid signalling.

Standard name | GSE23308_CTRL_VS_CORTICOSTERONE_TREATED_MACROPHAGE_UP
Systematic name | M7745
Organism | Mus musculus
PMID | 20697155
Authors | Usher MG,Duan SZ,Ivaschenko CY,Frieler RA,Berger S,Schütz G,Lumeng CN,Mortensen RM
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: untreated versus corticosterone [PubChem=5839].
Full description | Inappropriate excess of the steroid hormone aldosterone, which is a mineralocorticoid receptor (MR) agonist, is associated with increased inflammation and risk of cardiovascular disease. MR antagonists are cardioprotective and antiinflammatory in vivo, and evidence suggests that they mediate these effects in part by aldosterone- independent mechanisms. We used affymetrix to characterize the effect of Mineralocorticoid Receptor deletion on macrophage transcriptional profile, and identify its requirement in normal glucocorticoid signalling.

Standard name | GSE23308_CTRL_VS_CORTICOSTERONE_TREATED_MACROPHAGE_MINERALCORTICOID_REC_KO_UP
Systematic name | M7746
Organism | Mus musculus
PMID | 20697155
Authors | Usher MG,Duan SZ,Ivaschenko CY,Frieler RA,Berger S,Schütz G,Lumeng CN,Mortensen RM
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with NR3C2 [GeneID=4306] knockout: untreated versus corticosterone [PubChem=5839].
Full description | Inappropriate excess of the steroid hormone aldosterone, which is a mineralocorticoid receptor (MR) agonist, is associated with increased inflammation and risk of cardiovascular disease. MR antagonists are cardioprotective and antiinflammatory in vivo, and evidence suggests that they mediate these effects in part by aldosterone- independent mechanisms. We used affymetrix to characterize the effect of Mineralocorticoid Receptor deletion on macrophage transcriptional profile, and identify its requirement in normal glucocorticoid signalling.

Standard name | GSE23308_WT_VS_MINERALCORTICOID_REC_KO_MACROPHAGE_CORTICOSTERONE_TREATED_DN
Systematic name | M7748
Organism | Mus musculus
PMID | 20697155
Authors | Usher MG,Duan SZ,Ivaschenko CY,Frieler RA,Berger S,Schütz G,Lumeng CN,Mortensen RM
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages treated by corticosterone [PubChem=5839]: wildtype versus NR3C2 [GeneID=4306] knockout.
Full description | Inappropriate excess of the steroid hormone aldosterone, which is a mineralocorticoid receptor (MR) agonist, is associated with increased inflammation and risk of cardiovascular disease. MR antagonists are cardioprotective and antiinflammatory in vivo, and evidence suggests that they mediate these effects in part by aldosterone- independent mechanisms. We used affymetrix to characterize the effect of Mineralocorticoid Receptor deletion on macrophage transcriptional profile, and identify its requirement in normal glucocorticoid signalling.

Standard name | GSE22935_WT_VS_MYD88_KO_MACROPHAGE_24H_MBOVIS_BCG_STIM_UP
Systematic name | M7749
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages 24h after M. bovis BCG infection: wildtype versus MYD88 [GeneID=4615] knockout.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_24H_MBOVIS_BCG_STIM_MACROPHAGE_DN
Systematic name | M7750
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: untreated versus 24h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_WT_VS_MYD88_KO_MACROPHAGE_12H_MBOVIS_BCG_STIM_DN
Systematic name | M7751
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages 12h after M. bovis BCG infection: wildtype versus MYD88 [GeneID=4615] knockout.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_12H_MBOVIS_BCG_STIM_MACROPHAGE_UP
Systematic name | M7752
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: untreated versus 12h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_WT_VS_MYD88_KO_MACROPHAGE_24H_MBOVIS_BCG_STIM_DN
Systematic name | M7753
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages 24h after M. bovis BCG infection: wildtype versus MYD88 [GeneID=4615] knockout.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_24H_MBOVIS_BCG_STIM_MACROPHAGE_UP
Systematic name | M7754
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: untreated versus 24h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_24H_VS_48H_MBOVIS_BCG_STIM_MACROPHAGE_DN
Systematic name | M7755
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages after M. bovis BCG infection: 24h versus 48h.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_24H_VS_48H_MBOVIS_BCG_STIM_MYD88_KO_MACROPHAGE_UP
Systematic name | M7756
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with MYD88 [GeneID=4615] knockout after M. bovis BCG infection: 24h versus 48h.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_12H_MBOVIS_BCG_STIM_MACROPHAGE_DN
Systematic name | M7757
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: untreated versus 12h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_12H_MBOVIS_BCG_STIM_MYD88_KO_MACROPHAGE_UP
Systematic name | M7758
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated macrophages with MYD88 [GeneID=4615] knockout: untreated versus 12h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_WT_VS_MYD88_KO_MACROPHAGE_UP
Systematic name | M7760
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: wildtype versus MYD88 [GeneID=4615] knockout.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_WT_VS_MYD88_KO_MACROPHAGE_DN
Systematic name | M7762
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: wildtype versus MYD88 [GeneID=4615] knockout.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_WT_VS_MYD88_KO_MACROPHAGE_12H_MBOVIS_BCG_STIM_UP
Systematic name | M7764
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages 12h after M. bovis BCG infection: wildtype versus MYD88 [GeneID=4615] knockout.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_48H_MBOVIS_BCG_STIM_MYD88_KO_MACROPHAGE_UP
Systematic name | M7765
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated macrophages with MYD88 [GeneID=4615] knockout: untreated versus 48h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_WT_VS_MYD88_KO_MACROPHAGE_48H_MBOVIS_BCG_STIM_UP
Systematic name | M7766
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages 48h after M. bovis BCG infection: wildtype versus MYD88 [GeneID=4615] knockout.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_WT_VS_MYD88_KO_MACROPHAGE_48H_MBOVIS_BCG_STIM_DN
Systematic name | M7767
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages 48h after M. bovis BCG infection: wildtype versus MYD88 [GeneID=4615] knockout.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_24H_MBOVIS_BCG_STIM_MYD88_KO_MACROPHAGE_DN
Systematic name | M7771
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated macrophages with MYD88 [GeneID=4615] knockout: untreated versus 24h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_24H_VS_48H_MBOVIS_BCG_STIM_MYD88_KO_MACROPHAGE_DN
Systematic name | M7773
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with MYD88 [GeneID=4615] knockout after M. bovis BCG infection: 24h versus 48h.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_48H_MBOVIS_BCG_STIM_MYD88_KO_MACROPHAGE_DN
Systematic name | M7774
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated macrophages with MYD88 [GeneID=4615] knockout: untreated versus 48h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_24H_VS_48H_MBOVIS_BCG_STIM_MACROPHAGE_UP
Systematic name | M7776
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages after M. bovis BCG infection: 24h versus 48h.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_48H_MBOVIS_BCG_STIM_MACROPHAGE_UP
Systematic name | M7777
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: untreated versus 48h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_48H_MBOVIS_BCG_STIM_MACROPHAGE_DN
Systematic name | M7779
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: untreated versus 48h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_12H_MBOVIS_BCG_STIM_MYD88_KO_MACROPHAGE_DN
Systematic name | M7780
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes down-regulated macrophages with MYD88 [GeneID=4615] knockout: untreated versus 12h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE22935_UNSTIM_VS_24H_MBOVIS_BCG_STIM_MYD88_KO_MACROPHAGE_UP
Systematic name | M7781
Organism | Mus musculus
PMID | 20716764
Authors | Qualls JE,Neale G,Smith AM,Koo MS,DeFreitas AA,Zhang H,Kaplan G,Watowich SS,Murray PJ
Category | C7
Sub-category |
Brief description | Genes up-regulated macrophages with MYD88 [GeneID=4615] knockout: untreated versus 24h after M. bovis BCG infection.
Full description | Nitric oxide (NO) produced by macrophages (MØs) is toxic to both host tissues and invading pathogens and its regulation is therefore essential to suppress host cytotoxicity. MØ arginase 1 (Arg1) inhibits NO production by competing with NO synthases for arginine, the common substrate of NO synthases and arginases. Two signal transduction pathways control Arg1 expression in MØs. First, a MyD88-dependent pathway induces Arg1 in intracellular infections, while a second Stat6-dependent pathway is required for Arg1 expression in alternativelyactivated MØs. We found that mycobacteria-infected MØs produce soluble factors that induce Arg1 in an autocrine-paracrine manner via Stat3. We identify these factors as IL-6, IL-10 and GCSF. We further establish that Arg1 expression is controlled by the MyD88-dependent production of IL-6, IL-10 and G-CSF rather than cell intrinsic MyD88 signaling to Arg1. Our data reveal the MyD88-dependent pathway of Arg1induction following BCG infection requires Stat3 activation and may result in the development of an immunosuppressive niche in granulomas due to the induced Arg1 production in surrounding uninfected MØs

Standard name | GSE20754_WT_VS_TCF1_KO_MEMORY_CD8_TCELL_DN
Systematic name | M7782
Organism | Mus musculus
PMID | 20727791
Authors | Zhou X,Yu S,Zhao DM,Harty JT,Badovinac VP,Xue HH
Category | C7
Sub-category |
Brief description | Genes down-regulated in memory CD8 T cells: wildtype versus TCF7 [GeneID=6932] knockout.
Full description | TCF-1 is an HMG family transcription factor which is known to be activated by the canonical Wnt signaling pathway and modulated by other signals such as those derived from T cell receptor. We found that during CD8 T cell responses, TCF-1 deficiency impaired long-term maintenance of antigen-specific memory CD8 T cells. We used microarrays to detect gene expression changes in memory CD8 T cells caused by TCF-1 deficiency.

Standard name | GSE20754_WT_VS_TCF1_KO_MEMORY_CD8_TCELL_UP
Systematic name | M7783
Organism | Mus musculus
PMID | 20727791
Authors | Zhou X,Yu S,Zhao DM,Harty JT,Badovinac VP,Xue HH
Category | C7
Sub-category |
Brief description | Genes up-regulated in memory CD8 T cells: wildtype versus TCF7 [GeneID=6932] knockout.
Full description | TCF-1 is an HMG family transcription factor which is known to be activated by the canonical Wnt signaling pathway and modulated by other signals such as those derived from T cell receptor. We found that during CD8 T cell responses, TCF-1 deficiency impaired long-term maintenance of antigen-specific memory CD8 T cells. We used microarrays to detect gene expression changes in memory CD8 T cells caused by TCF-1 deficiency.

Standard name | GSE23695_CD57_POS_VS_NEG_NK_CELL_UP
Systematic name | M7784
Organism | Homo sapiens
PMID | 20733159
Authors | Lopez-Vergès S,Milush JM,Pandey S,York VA,Arakawa-Hoyt J,Pircher H,Norris PJ,Nixon DF,Lanier LL
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells: B3GAT1+ [GeneID=27087] versus B3GAT1- [GeneID=27087].
Full description | Thirty to 60% of CD56dimCD16bright NK cells in healthy adults express CD57, which is not expressed on immature CD56bright NK cells or fetal and newborn NK cells. We hypothesized that CD57+ NK cells within the CD56dim mature NK cell subset are highly mature and might be terminally differentiated. We used microarrays to assess the transcriptional differences between CD57+ and CD57neg NK cells within the CD56dim mature NK subset.

Standard name | GSE23695_CD57_POS_VS_NEG_NK_CELL_DN
Systematic name | M7786
Organism | Homo sapiens
PMID | 20733159
Authors | Lopez-Vergès S,Milush JM,Pandey S,York VA,Arakawa-Hoyt J,Pircher H,Norris PJ,Nixon DF,Lanier LL
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells: B3GAT1+ [GeneID=27087] versus B3GAT1- [GeneID=27087].
Full description | Thirty to 60% of CD56dimCD16bright NK cells in healthy adults express CD57, which is not expressed on immature CD56bright NK cells or fetal and newborn NK cells. We hypothesized that CD57+ NK cells within the CD56dim mature NK cell subset are highly mature and might be terminally differentiated. We used microarrays to assess the transcriptional differences between CD57+ and CD57neg NK cells within the CD56dim mature NK subset.

Standard name | GSE22103_UNSTIM_VS_GMCSF_AND_IFNG_STIM_NEUTROPHIL_UP
Systematic name | M7789
Organism | Homo sapiens
PMID | 20802500
Authors | Kotz KT,Xiao W,Miller-Graziano C,Qian WJ,Russom A,Warner EA,Moldawer LL,De A,Bankey PE,Petritis BO,Camp DG,Rosenbach AE,Goverman J,Fagan SP,Brownstein BH,Irimia D,Xu W,Wilhelmy J,Mindrinos MN,Smith RD,Davis RW,Tompkins RG,Toner M,LastName M
Category | C7
Sub-category |
Brief description | Genes up-regulated in neutrophils: untreated versus stimulated by CSF2 and IFNG [GeneID=1437;3458].
Full description | Neutrophils play critical roles in modulating the immune response. However, neutrophils have a short circulating half life, are readily stimulated in vitro, and have low levels of cellular mRNA when compared to other blood leukocyte populations. All of these factors have made it difficult to evaluate neutrophils from clinical populations for molecular and functional studies. Here we present a robust methodology for rapidly isolating neutrophils directly from whole blood and develop ‘on- chip’ processing for mRNA and protein isolation for genomics and proteomics. We validate this device with an ex vivo stimulation experiment and demonstrate the ability of the device to discriminate subtle differences in the genomic and proteomic response of peripheral blood neutrophils to direct and indirect stimulation. Lastly, we implement this tool as part of a near patient blood processing system within a multi-center clinical study of the immune response to severe trauma and burn injury and demonstrate that this technique is easy to use by nurses and technical staff yielding excellent quality and sufficient quantity of mRNA for sensitive genomic readout of the host response to injury

Standard name | GSE22103_UNSTIM_VS_LPS_STIM_NEUTROPHIL_DN
Systematic name | M7790
Organism | Homo sapiens
PMID | 20802500
Authors | Kotz KT,Xiao W,Miller-Graziano C,Qian WJ,Russom A,Warner EA,Moldawer LL,De A,Bankey PE,Petritis BO,Camp DG,Rosenbach AE,Goverman J,Fagan SP,Brownstein BH,Irimia D,Xu W,Wilhelmy J,Mindrinos MN,Smith RD,Davis RW,Tompkins RG,Toner M,LastName M
Category | C7
Sub-category |
Brief description | Genes down-regulated in neutrophils: untreated versus LPS.
Full description | Neutrophils play critical roles in modulating the immune response. However, neutrophils have a short circulating half life, are readily stimulated in vitro, and have low levels of cellular mRNA when compared to other blood leukocyte populations. All of these factors have made it difficult to evaluate neutrophils from clinical populations for molecular and functional studies. Here we present a robust methodology for rapidly isolating neutrophils directly from whole blood and develop ‘on- chip’ processing for mRNA and protein isolation for genomics and proteomics. We validate this device with an ex vivo stimulation experiment and demonstrate the ability of the device to discriminate subtle differences in the genomic and proteomic response of peripheral blood neutrophils to direct and indirect stimulation. Lastly, we implement this tool as part of a near patient blood processing system within a multi-center clinical study of the immune response to severe trauma and burn injury and demonstrate that this technique is easy to use by nurses and technical staff yielding excellent quality and sufficient quantity of mRNA for sensitive genomic readout of the host response to injury

Standard name | GSE22103_LPS_VS_GMCSF_AND_IFNG_STIM_NEUTROPHIL_DN
Systematic name | M7791
Organism | Homo sapiens
PMID | 20802500
Authors | Kotz KT,Xiao W,Miller-Graziano C,Qian WJ,Russom A,Warner EA,Moldawer LL,De A,Bankey PE,Petritis BO,Camp DG,Rosenbach AE,Goverman J,Fagan SP,Brownstein BH,Irimia D,Xu W,Wilhelmy J,Mindrinos MN,Smith RD,Davis RW,Tompkins RG,Toner M,LastName M
Category | C7
Sub-category |
Brief description | Genes down-regulated in neutrophils: LPS versus stimulated by CSF2 and IFNG [GeneID=1437;3458].
Full description | Neutrophils play critical roles in modulating the immune response. However, neutrophils have a short circulating half life, are readily stimulated in vitro, and have low levels of cellular mRNA when compared to other blood leukocyte populations. All of these factors have made it difficult to evaluate neutrophils from clinical populations for molecular and functional studies. Here we present a robust methodology for rapidly isolating neutrophils directly from whole blood and develop ‘on- chip’ processing for mRNA and protein isolation for genomics and proteomics. We validate this device with an ex vivo stimulation experiment and demonstrate the ability of the device to discriminate subtle differences in the genomic and proteomic response of peripheral blood neutrophils to direct and indirect stimulation. Lastly, we implement this tool as part of a near patient blood processing system within a multi-center clinical study of the immune response to severe trauma and burn injury and demonstrate that this technique is easy to use by nurses and technical staff yielding excellent quality and sufficient quantity of mRNA for sensitive genomic readout of the host response to injury

Standard name | GSE22103_UNSTIM_VS_GMCSF_AND_IFNG_STIM_NEUTROPHIL_DN
Systematic name | M7792
Organism | Homo sapiens
PMID | 20802500
Authors | Kotz KT,Xiao W,Miller-Graziano C,Qian WJ,Russom A,Warner EA,Moldawer LL,De A,Bankey PE,Petritis BO,Camp DG,Rosenbach AE,Goverman J,Fagan SP,Brownstein BH,Irimia D,Xu W,Wilhelmy J,Mindrinos MN,Smith RD,Davis RW,Tompkins RG,Toner M,LastName M
Category | C7
Sub-category |
Brief description | Genes down-regulated in neutrophils: untreated versus stimulated by CSF2 and IFNG [GeneID=1437;3458].
Full description | Neutrophils play critical roles in modulating the immune response. However, neutrophils have a short circulating half life, are readily stimulated in vitro, and have low levels of cellular mRNA when compared to other blood leukocyte populations. All of these factors have made it difficult to evaluate neutrophils from clinical populations for molecular and functional studies. Here we present a robust methodology for rapidly isolating neutrophils directly from whole blood and develop ‘on- chip’ processing for mRNA and protein isolation for genomics and proteomics. We validate this device with an ex vivo stimulation experiment and demonstrate the ability of the device to discriminate subtle differences in the genomic and proteomic response of peripheral blood neutrophils to direct and indirect stimulation. Lastly, we implement this tool as part of a near patient blood processing system within a multi-center clinical study of the immune response to severe trauma and burn injury and demonstrate that this technique is easy to use by nurses and technical staff yielding excellent quality and sufficient quantity of mRNA for sensitive genomic readout of the host response to injury

Standard name | GSE22103_UNSTIM_VS_LPS_STIM_NEUTROPHIL_UP
Systematic name | M7794
Organism | Homo sapiens
PMID | 20802500
Authors | Kotz KT,Xiao W,Miller-Graziano C,Qian WJ,Russom A,Warner EA,Moldawer LL,De A,Bankey PE,Petritis BO,Camp DG,Rosenbach AE,Goverman J,Fagan SP,Brownstein BH,Irimia D,Xu W,Wilhelmy J,Mindrinos MN,Smith RD,Davis RW,Tompkins RG,Toner M,LastName M
Category | C7
Sub-category |
Brief description | Genes up-regulated in neutrophils: untreated versus LPS.
Full description | Neutrophils play critical roles in modulating the immune response. However, neutrophils have a short circulating half life, are readily stimulated in vitro, and have low levels of cellular mRNA when compared to other blood leukocyte populations. All of these factors have made it difficult to evaluate neutrophils from clinical populations for molecular and functional studies. Here we present a robust methodology for rapidly isolating neutrophils directly from whole blood and develop ‘on- chip’ processing for mRNA and protein isolation for genomics and proteomics. We validate this device with an ex vivo stimulation experiment and demonstrate the ability of the device to discriminate subtle differences in the genomic and proteomic response of peripheral blood neutrophils to direct and indirect stimulation. Lastly, we implement this tool as part of a near patient blood processing system within a multi-center clinical study of the immune response to severe trauma and burn injury and demonstrate that this technique is easy to use by nurses and technical staff yielding excellent quality and sufficient quantity of mRNA for sensitive genomic readout of the host response to injury

Standard name | GSE22103_LPS_VS_GMCSF_AND_IFNG_STIM_NEUTROPHIL_UP
Systematic name | M7795
Organism | Homo sapiens
PMID | 20802500
Authors | Kotz KT,Xiao W,Miller-Graziano C,Qian WJ,Russom A,Warner EA,Moldawer LL,De A,Bankey PE,Petritis BO,Camp DG,Rosenbach AE,Goverman J,Fagan SP,Brownstein BH,Irimia D,Xu W,Wilhelmy J,Mindrinos MN,Smith RD,Davis RW,Tompkins RG,Toner M,LastName M
Category | C7
Sub-category |
Brief description | Genes up-regulated in neutrophils: LPS versus stimulated by CSF2 and IFNG [GeneID=1437;3458].
Full description | Neutrophils play critical roles in modulating the immune response. However, neutrophils have a short circulating half life, are readily stimulated in vitro, and have low levels of cellular mRNA when compared to other blood leukocyte populations. All of these factors have made it difficult to evaluate neutrophils from clinical populations for molecular and functional studies. Here we present a robust methodology for rapidly isolating neutrophils directly from whole blood and develop ‘on- chip’ processing for mRNA and protein isolation for genomics and proteomics. We validate this device with an ex vivo stimulation experiment and demonstrate the ability of the device to discriminate subtle differences in the genomic and proteomic response of peripheral blood neutrophils to direct and indirect stimulation. Lastly, we implement this tool as part of a near patient blood processing system within a multi-center clinical study of the immune response to severe trauma and burn injury and demonstrate that this technique is easy to use by nurses and technical staff yielding excellent quality and sufficient quantity of mRNA for sensitive genomic readout of the host response to injury

Standard name | GSE22589_HEALTHY_VS_HIV_AND_SIV_INFECTED_DC_DN
Systematic name | M7796
Organism | Homo sapiens
PMID | 20829794
Authors | Manel N,Hogstad B,Wang Y,Levy DE,Unutmaz D,Littman DR
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: control versus HIV and SIV infection.
Full description | Dendritic cells (DC) serve a key function in host defense, linking innate detection of microbes to the activation of pathogen-specific adaptive immune responses. Whether there is cell-intrinsic recognition of HIV-1 by host innate pattern-recognition receptors and subsequent coupling to antiviral T cell responses is not yet known. DC are largely resistant to infection with HIV-1, but facilitate infection of co-cultured T-helper cells through a process of trans-enhancement. We show here that, when DC resistance to infection is circumvented, HIV-1 induces DC maturation, an antiviral type I interferon response and activation of T cells. This innate response is dependent on the interaction of newly-synthesized HIV-1 capsid (CA) with cellular cyclophilin A (CypA) and the subsequent activation of the transcription factor IRF3. Because the peptidyl-prolyl isomerase CypA also interacts with CA to promote HIV-1 infectivity, our results suggest that CA conformation has evolved under opposing selective pressures for infectivity versus furtiveness. Thus, a cell intrinsic sensor for HIV-1 exists in DC and mediates an antiviral immune response, but it is not typically engaged due to absence of DC infection. The virulence of HIV-1 may be related to evasion of this response, whose manipulation may be necessary to generate an effective HIV-1 vaccine.

Standard name | GSE22589_HEALTHY_VS_SIV_INFECTED_DC_UP
Systematic name | M7798
Organism | Homo sapiens
PMID | 20829794
Authors | Manel N,Hogstad B,Wang Y,Levy DE,Unutmaz D,Littman DR
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: control versus SIV infection.
Full description | Dendritic cells (DC) serve a key function in host defense, linking innate detection of microbes to the activation of pathogen-specific adaptive immune responses. Whether there is cell-intrinsic recognition of HIV-1 by host innate pattern-recognition receptors and subsequent coupling to antiviral T cell responses is not yet known. DC are largely resistant to infection with HIV-1, but facilitate infection of co-cultured T-helper cells through a process of trans-enhancement. We show here that, when DC resistance to infection is circumvented, HIV-1 induces DC maturation, an antiviral type I interferon response and activation of T cells. This innate response is dependent on the interaction of newly-synthesized HIV-1 capsid (CA) with cellular cyclophilin A (CypA) and the subsequent activation of the transcription factor IRF3. Because the peptidyl-prolyl isomerase CypA also interacts with CA to promote HIV-1 infectivity, our results suggest that CA conformation has evolved under opposing selective pressures for infectivity versus furtiveness. Thus, a cell intrinsic sensor for HIV-1 exists in DC and mediates an antiviral immune response, but it is not typically engaged due to absence of DC infection. The virulence of HIV-1 may be related to evasion of this response, whose manipulation may be necessary to generate an effective HIV-1 vaccine.

Standard name | GSE22589_SIV_VS_HIV_AND_SIV_INFECTED_DC_DN
Systematic name | M7799
Organism | Homo sapiens
PMID | 20829794
Authors | Manel N,Hogstad B,Wang Y,Levy DE,Unutmaz D,Littman DR
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells infected by: SIV versus HIV and SIV.
Full description | Dendritic cells (DC) serve a key function in host defense, linking innate detection of microbes to the activation of pathogen-specific adaptive immune responses. Whether there is cell-intrinsic recognition of HIV-1 by host innate pattern-recognition receptors and subsequent coupling to antiviral T cell responses is not yet known. DC are largely resistant to infection with HIV-1, but facilitate infection of co-cultured T-helper cells through a process of trans-enhancement. We show here that, when DC resistance to infection is circumvented, HIV-1 induces DC maturation, an antiviral type I interferon response and activation of T cells. This innate response is dependent on the interaction of newly-synthesized HIV-1 capsid (CA) with cellular cyclophilin A (CypA) and the subsequent activation of the transcription factor IRF3. Because the peptidyl-prolyl isomerase CypA also interacts with CA to promote HIV-1 infectivity, our results suggest that CA conformation has evolved under opposing selective pressures for infectivity versus furtiveness. Thus, a cell intrinsic sensor for HIV-1 exists in DC and mediates an antiviral immune response, but it is not typically engaged due to absence of DC infection. The virulence of HIV-1 may be related to evasion of this response, whose manipulation may be necessary to generate an effective HIV-1 vaccine.

Standard name | GSE22589_HIV_VS_HIV_AND_SIV_INFECTED_DC_UP
Systematic name | M7800
Organism | Homo sapiens
PMID | 20829794
Authors | Manel N,Hogstad B,Wang Y,Levy DE,Unutmaz D,Littman DR
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells infected by: HIV versus HIV and SIV.
Full description | Dendritic cells (DC) serve a key function in host defense, linking innate detection of microbes to the activation of pathogen-specific adaptive immune responses. Whether there is cell-intrinsic recognition of HIV-1 by host innate pattern-recognition receptors and subsequent coupling to antiviral T cell responses is not yet known. DC are largely resistant to infection with HIV-1, but facilitate infection of co-cultured T-helper cells through a process of trans-enhancement. We show here that, when DC resistance to infection is circumvented, HIV-1 induces DC maturation, an antiviral type I interferon response and activation of T cells. This innate response is dependent on the interaction of newly-synthesized HIV-1 capsid (CA) with cellular cyclophilin A (CypA) and the subsequent activation of the transcription factor IRF3. Because the peptidyl-prolyl isomerase CypA also interacts with CA to promote HIV-1 infectivity, our results suggest that CA conformation has evolved under opposing selective pressures for infectivity versus furtiveness. Thus, a cell intrinsic sensor for HIV-1 exists in DC and mediates an antiviral immune response, but it is not typically engaged due to absence of DC infection. The virulence of HIV-1 may be related to evasion of this response, whose manipulation may be necessary to generate an effective HIV-1 vaccine.

Standard name | GSE22589_HIV_VS_HIV_AND_SIV_INFECTED_DC_DN
Systematic name | M7801
Organism | Homo sapiens
PMID | 20829794
Authors | Manel N,Hogstad B,Wang Y,Levy DE,Unutmaz D,Littman DR
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells infected by: HIV versus HIV and SIV.
Full description | Dendritic cells (DC) serve a key function in host defense, linking innate detection of microbes to the activation of pathogen-specific adaptive immune responses. Whether there is cell-intrinsic recognition of HIV-1 by host innate pattern-recognition receptors and subsequent coupling to antiviral T cell responses is not yet known. DC are largely resistant to infection with HIV-1, but facilitate infection of co-cultured T-helper cells through a process of trans-enhancement. We show here that, when DC resistance to infection is circumvented, HIV-1 induces DC maturation, an antiviral type I interferon response and activation of T cells. This innate response is dependent on the interaction of newly-synthesized HIV-1 capsid (CA) with cellular cyclophilin A (CypA) and the subsequent activation of the transcription factor IRF3. Because the peptidyl-prolyl isomerase CypA also interacts with CA to promote HIV-1 infectivity, our results suggest that CA conformation has evolved under opposing selective pressures for infectivity versus furtiveness. Thus, a cell intrinsic sensor for HIV-1 exists in DC and mediates an antiviral immune response, but it is not typically engaged due to absence of DC infection. The virulence of HIV-1 may be related to evasion of this response, whose manipulation may be necessary to generate an effective HIV-1 vaccine.

Standard name | GSE22589_SIV_VS_HIV_AND_SIV_INFECTED_DC_UP
Systematic name | M7802
Organism | Homo sapiens
PMID | 20829794
Authors | Manel N,Hogstad B,Wang Y,Levy DE,Unutmaz D,Littman DR
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells infected by: SIV versus HIV and SIV.
Full description | Dendritic cells (DC) serve a key function in host defense, linking innate detection of microbes to the activation of pathogen-specific adaptive immune responses. Whether there is cell-intrinsic recognition of HIV-1 by host innate pattern-recognition receptors and subsequent coupling to antiviral T cell responses is not yet known. DC are largely resistant to infection with HIV-1, but facilitate infection of co-cultured T-helper cells through a process of trans-enhancement. We show here that, when DC resistance to infection is circumvented, HIV-1 induces DC maturation, an antiviral type I interferon response and activation of T cells. This innate response is dependent on the interaction of newly-synthesized HIV-1 capsid (CA) with cellular cyclophilin A (CypA) and the subsequent activation of the transcription factor IRF3. Because the peptidyl-prolyl isomerase CypA also interacts with CA to promote HIV-1 infectivity, our results suggest that CA conformation has evolved under opposing selective pressures for infectivity versus furtiveness. Thus, a cell intrinsic sensor for HIV-1 exists in DC and mediates an antiviral immune response, but it is not typically engaged due to absence of DC infection. The virulence of HIV-1 may be related to evasion of this response, whose manipulation may be necessary to generate an effective HIV-1 vaccine.

Standard name | GSE22589_HEALTHY_VS_HIV_INFECTED_DC_UP
Systematic name | M7805
Organism | Homo sapiens
PMID | 20829794
Authors | Manel N,Hogstad B,Wang Y,Levy DE,Unutmaz D,Littman DR
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: control versus HIV infection.
Full description | Dendritic cells (DC) serve a key function in host defense, linking innate detection of microbes to the activation of pathogen-specific adaptive immune responses. Whether there is cell-intrinsic recognition of HIV-1 by host innate pattern-recognition receptors and subsequent coupling to antiviral T cell responses is not yet known. DC are largely resistant to infection with HIV-1, but facilitate infection of co-cultured T-helper cells through a process of trans-enhancement. We show here that, when DC resistance to infection is circumvented, HIV-1 induces DC maturation, an antiviral type I interferon response and activation of T cells. This innate response is dependent on the interaction of newly-synthesized HIV-1 capsid (CA) with cellular cyclophilin A (CypA) and the subsequent activation of the transcription factor IRF3. Because the peptidyl-prolyl isomerase CypA also interacts with CA to promote HIV-1 infectivity, our results suggest that CA conformation has evolved under opposing selective pressures for infectivity versus furtiveness. Thus, a cell intrinsic sensor for HIV-1 exists in DC and mediates an antiviral immune response, but it is not typically engaged due to absence of DC infection. The virulence of HIV-1 may be related to evasion of this response, whose manipulation may be necessary to generate an effective HIV-1 vaccine.

Standard name | GSE22589_HEALTHY_VS_HIV_INFECTED_DC_DN
Systematic name | M7807
Organism | Homo sapiens
PMID | 20829794
Authors | Manel N,Hogstad B,Wang Y,Levy DE,Unutmaz D,Littman DR
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: control versus HIV infection.
Full description | Dendritic cells (DC) serve a key function in host defense, linking innate detection of microbes to the activation of pathogen-specific adaptive immune responses. Whether there is cell-intrinsic recognition of HIV-1 by host innate pattern-recognition receptors and subsequent coupling to antiviral T cell responses is not yet known. DC are largely resistant to infection with HIV-1, but facilitate infection of co-cultured T-helper cells through a process of trans-enhancement. We show here that, when DC resistance to infection is circumvented, HIV-1 induces DC maturation, an antiviral type I interferon response and activation of T cells. This innate response is dependent on the interaction of newly-synthesized HIV-1 capsid (CA) with cellular cyclophilin A (CypA) and the subsequent activation of the transcription factor IRF3. Because the peptidyl-prolyl isomerase CypA also interacts with CA to promote HIV-1 infectivity, our results suggest that CA conformation has evolved under opposing selective pressures for infectivity versus furtiveness. Thus, a cell intrinsic sensor for HIV-1 exists in DC and mediates an antiviral immune response, but it is not typically engaged due to absence of DC infection. The virulence of HIV-1 may be related to evasion of this response, whose manipulation may be necessary to generate an effective HIV-1 vaccine.

Standard name | GSE22589_HEALTHY_VS_HIV_AND_SIV_INFECTED_DC_UP
Systematic name | M7808
Organism | Homo sapiens
PMID | 20829794
Authors | Manel N,Hogstad B,Wang Y,Levy DE,Unutmaz D,Littman DR
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocyte-derived dendritic cells: control versus HIV and SIV infection.
Full description | Dendritic cells (DC) serve a key function in host defense, linking innate detection of microbes to the activation of pathogen-specific adaptive immune responses. Whether there is cell-intrinsic recognition of HIV-1 by host innate pattern-recognition receptors and subsequent coupling to antiviral T cell responses is not yet known. DC are largely resistant to infection with HIV-1, but facilitate infection of co-cultured T-helper cells through a process of trans-enhancement. We show here that, when DC resistance to infection is circumvented, HIV-1 induces DC maturation, an antiviral type I interferon response and activation of T cells. This innate response is dependent on the interaction of newly-synthesized HIV-1 capsid (CA) with cellular cyclophilin A (CypA) and the subsequent activation of the transcription factor IRF3. Because the peptidyl-prolyl isomerase CypA also interacts with CA to promote HIV-1 infectivity, our results suggest that CA conformation has evolved under opposing selective pressures for infectivity versus furtiveness. Thus, a cell intrinsic sensor for HIV-1 exists in DC and mediates an antiviral immune response, but it is not typically engaged due to absence of DC infection. The virulence of HIV-1 may be related to evasion of this response, whose manipulation may be necessary to generate an effective HIV-1 vaccine.

Standard name | GSE22589_HEALTHY_VS_SIV_INFECTED_DC_DN
Systematic name | M7809
Organism | Homo sapiens
PMID | 20829794
Authors | Manel N,Hogstad B,Wang Y,Levy DE,Unutmaz D,Littman DR
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocyte-derived dendritic cells: control versus SIV infection.
Full description | Dendritic cells (DC) serve a key function in host defense, linking innate detection of microbes to the activation of pathogen-specific adaptive immune responses. Whether there is cell-intrinsic recognition of HIV-1 by host innate pattern-recognition receptors and subsequent coupling to antiviral T cell responses is not yet known. DC are largely resistant to infection with HIV-1, but facilitate infection of co-cultured T-helper cells through a process of trans-enhancement. We show here that, when DC resistance to infection is circumvented, HIV-1 induces DC maturation, an antiviral type I interferon response and activation of T cells. This innate response is dependent on the interaction of newly-synthesized HIV-1 capsid (CA) with cellular cyclophilin A (CypA) and the subsequent activation of the transcription factor IRF3. Because the peptidyl-prolyl isomerase CypA also interacts with CA to promote HIV-1 infectivity, our results suggest that CA conformation has evolved under opposing selective pressures for infectivity versus furtiveness. Thus, a cell intrinsic sensor for HIV-1 exists in DC and mediates an antiviral immune response, but it is not typically engaged due to absence of DC infection. The virulence of HIV-1 may be related to evasion of this response, whose manipulation may be necessary to generate an effective HIV-1 vaccine.

Standard name | GSE22432_CONVENTIONAL_CDC_VS_PLASMACYTOID_PDC_UP
Systematic name | M7811
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: common versus plasmacytoid.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_CONVENTIONAL_CDC_VS_PLASMACYTOID_PDC_DN
Systematic name | M7814
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: common versus plasmacytoid.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_MULTIPOTENT_PROGENITOR_VS_PDC_DN
Systematic name | M7816
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: amplified common progenitors versus plasmacytoid.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_MULTIPOTENT_PROGENITOR_VS_CDC_UP
Systematic name | M7817
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes up-regulated in amplified multipotent progenitors versus common dendritic cells.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_MULTIPOTENT_PROGENITOR_VS_CDC_DN
Systematic name | M7819
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes down-regulated in amplified multipotent progenitors versus common dendritic cells.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_MULTIPOTENT_PROGENITOR_VS_PDC_UP
Systematic name | M7820
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: amplified common progenitors versus plasmacytoid.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_MULTIPOTENT_VS_COMMON_DC_PROGENITOR_UP
Systematic name | M7821
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes up-regulated in amplified: multipotent progenitors versus common dendritic cell progenitors.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_MULTIPOTENT_VS_COMMON_DC_PROGENITOR_DN
Systematic name | M7822
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes down-regulated in amplified: multipotent progenitors versus common dendritic cell progenitors.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_CDC_VS_COMMON_DC_PROGENITOR_DN
Systematic name | M7824
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes down-regulated in common dendritic cells versus those cultured and untreated.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_UNTREATED_VS_TGFB1_TREATED_COMMON_DC_PROGENITOR_UP
Systematic name | M7826
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes up-regulated in cultured common dendritic cell progenitors: untreated versus TGFB1 [GeneID=7040] for 4h.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_UNTREATED_VS_TGFB1_TREATED_COMMON_DC_PROGENITOR_DN
Systematic name | M7828
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes down-regulated in cultured common dendritic cell progenitors: untreated versus TGFB1 [GeneID=7040] for 4h.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_MULTIPOTENT_VS_COMMON_DC_PROGENITOR_UNTREATED_DN
Systematic name | M7829
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes down-regulated in amplified multipotent progenitors versus cultured untreated common dendritic cell progenitors.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_CDC_VS_COMMON_DC_PROGENITOR_UP
Systematic name | M7831
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes up-regulated in common dendritic cells versus those cultured and untreated.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_MULTIPOTENT_VS_COMMON_DC_PROGENITOR_UNTREATED_UP
Systematic name | M7832
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes up-regulated in amplified multipotent progenitors versus cultured untreated common dendritic cell progenitors.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_PDC_VS_TGFB1_TREATEDCOMMON_DC_PROGENITOR_DN
Systematic name | M7833
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: plasmacytoid versus cultured common progenitors treated by TGFB1 [GeneID=7040] for 4h.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22432_PDC_VS_TGFB1_TREATEDCOMMON_DC_PROGENITOR_UP
Systematic name | M7835
Organism | Mus musculus
PMID | 20881193
Authors | Felker P,Seré K,Lin Q,Becker C,Hristov M,Hieronymus T,Zenke M
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: plasmacytoid versus cultured common progenitors treated by TGFB1 [GeneID=7040] for 4h.
Full description | Dendritic cells (DCs) in lymphoid tissue comprise conventional DCs (cDCs) and plasmacytoid DCs (pDCs) that develop from common DC progenitors (CDPs). CDPs are Flt3+c-kitintM-CSFR+ and reside in bone marrow. Here we describe a two-step culture system that recapitulates DC development from c-kithiFlt3-/lo multipotent progenitors (MPPs) into CDPs and further into cDC and pDC subsets. MPPs and CDPs are amplified in vitro with Flt3 ligand, stem cell factor, hyper-IL-6 and insulin- like growth factor-1. The four-factor cocktail readily induces self-renewal of MPPs and their progression into CDPs and has no self-renewal activity on CDPs. The amplified CDPs respond to all known DC poietins and generate all lymphoid tissue DCs in vivo and in vitro. Additionally, in vitro CDPs recapitulate the cell surface marker and gene expression profile of in vivo CDPs and possess a DC-primed transcription profile. Transforming growth factor-β1 (TGF-β1) impacts on CDPs and directs their differentiation towards cDCs. Genome-wide gene expression profiling of TGF-β1-induced genes identified transcription factors, such as interferon regulatory factor-4 (IRF-4) and RelB, that are implicated as instructive factors for cDC subset specification. TGF-β1 also induced the transcription factor inhibitor of differentiation/DNA binding 2 (Id2) that suppresses pDC development. Thus, TGF-β1 directs CDP differentiation into cDC by inducing both cDC instructive factors and pDC inhibitory factors.

Standard name | GSE22919_RESTING_VS_IL2_IL12_IL15_STIM_NK_CELL_DN
Systematic name | M7836
Organism | Homo sapiens
PMID | 20944005
Authors | Smith MA,Maurin M,Cho HI,Becknell B,Freud AG,Yu J,Wei S,Djeu J,Celis E,Caligiuri MA,Wright KL
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells: fresh versus stimulated with IL2 [GeneID=3558], IL-12 and IL15 [GeneID=3600].
Full description | We used Affymetrix expression arrays to determine changes in gene expression associated with activation of human NK cells mediated through treatment with cytokines IL-2, IL-12 and IL-18 over a 24 hour period.

Standard name | GSE22919_RESTING_VS_IL2_IL12_IL15_STIM_NK_CELL_UP
Systematic name | M7837
Organism | Homo sapiens
PMID | 20944005
Authors | Smith MA,Maurin M,Cho HI,Becknell B,Freud AG,Yu J,Wei S,Djeu J,Celis E,Caligiuri MA,Wright KL
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells: fresh versus stimulated with IL2 [GeneID=3558], IL-12 and IL15 [GeneID=3600].
Full description | We used Affymetrix expression arrays to determine changes in gene expression associated with activation of human NK cells mediated through treatment with cytokines IL-2, IL-12 and IL-18 over a 24 hour period.

Standard name | GSE24210_RESTING_TREG_VS_TCONV_UP
Systematic name | M7839
Organism | Mus musculus
PMID | 20953201
Authors | Collison LW,Chaturvedi V,Henderson AL,Giacomin PR,Guy C,Bankoti J,Finkelstein D,Forbes K,Workman CJ,Brown SA,Rehg JE,Jones ML,Ni HT,Artis D,Turk MJ,Vignali DA
Category | C7
Sub-category |
Brief description | Genes up-regulated in resting T reg versus T conv cells.
Full description | Regulatory T cells (Tregs) play a critical role in the maintenance of immunological self-tolerance. Naïve human or murine T cell treatment with the inhibitory cytokine IL35 induces a regulatory population, termed iTR35, that mediates suppression via IL35, but not IL10 or TGFβ, neither express nor require Foxp3, are strongly suppressive in five in vivo models, and exhibit in vivo stability. Treg-mediated suppression induces iTR35 generation in an IL35- and IL10-dependent manner in vitro, and in inflammatory conditions in vivo in Trichuris-infected intestines and within the tumor microenvironment, where they appear to contribute to the regulatory milieu. iTR35 may constitute a key mediator of infectious tolerance and may contribute to Treg-mediated tumor progression, and ex vivo-generated iTR35 may possess therapeutic utility.

Standard name | GSE24210_RESTING_TREG_VS_TCONV_DN
Systematic name | M7840
Organism | Mus musculus
PMID | 20953201
Authors | Collison LW,Chaturvedi V,Henderson AL,Giacomin PR,Guy C,Bankoti J,Finkelstein D,Forbes K,Workman CJ,Brown SA,Rehg JE,Jones ML,Ni HT,Artis D,Turk MJ,Vignali DA
Category | C7
Sub-category |
Brief description | Genes down-regulated in resting T reg versus T conv cells.
Full description | Regulatory T cells (Tregs) play a critical role in the maintenance of immunological self-tolerance. Naïve human or murine T cell treatment with the inhibitory cytokine IL35 induces a regulatory population, termed iTR35, that mediates suppression via IL35, but not IL10 or TGFβ, neither express nor require Foxp3, are strongly suppressive in five in vivo models, and exhibit in vivo stability. Treg-mediated suppression induces iTR35 generation in an IL35- and IL10-dependent manner in vitro, and in inflammatory conditions in vivo in Trichuris-infected intestines and within the tumor microenvironment, where they appear to contribute to the regulatory milieu. iTR35 may constitute a key mediator of infectious tolerance and may contribute to Treg-mediated tumor progression, and ex vivo-generated iTR35 may possess therapeutic utility.

Standard name | GSE24210_CTRL_VS_IL35_TREATED_TCONV_CD4_TCELL_UP
Systematic name | M7841
Organism | Mus musculus
PMID | 20953201
Authors | Collison LW,Chaturvedi V,Henderson AL,Giacomin PR,Guy C,Bankoti J,Finkelstein D,Forbes K,Workman CJ,Brown SA,Rehg JE,Jones ML,Ni HT,Artis D,Turk MJ,Vignali DA
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv cells: control versus treated with IL35.
Full description | Regulatory T cells (Tregs) play a critical role in the maintenance of immunological self-tolerance. Naïve human or murine T cell treatment with the inhibitory cytokine IL35 induces a regulatory population, termed iTR35, that mediates suppression via IL35, but not IL10 or TGFβ, neither express nor require Foxp3, are strongly suppressive in five in vivo models, and exhibit in vivo stability. Treg-mediated suppression induces iTR35 generation in an IL35- and IL10-dependent manner in vitro, and in inflammatory conditions in vivo in Trichuris-infected intestines and within the tumor microenvironment, where they appear to contribute to the regulatory milieu. iTR35 may constitute a key mediator of infectious tolerance and may contribute to Treg-mediated tumor progression, and ex vivo-generated iTR35 may possess therapeutic utility.

Standard name | GSE24210_CTRL_VS_IL35_TREATED_TCONV_CD4_TCELL_DN
Systematic name | M7842
Organism | Mus musculus
PMID | 20953201
Authors | Collison LW,Chaturvedi V,Henderson AL,Giacomin PR,Guy C,Bankoti J,Finkelstein D,Forbes K,Workman CJ,Brown SA,Rehg JE,Jones ML,Ni HT,Artis D,Turk MJ,Vignali DA
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv cells: control versus treated with IL35.
Full description | Regulatory T cells (Tregs) play a critical role in the maintenance of immunological self-tolerance. Naïve human or murine T cell treatment with the inhibitory cytokine IL35 induces a regulatory population, termed iTR35, that mediates suppression via IL35, but not IL10 or TGFβ, neither express nor require Foxp3, are strongly suppressive in five in vivo models, and exhibit in vivo stability. Treg-mediated suppression induces iTR35 generation in an IL35- and IL10-dependent manner in vitro, and in inflammatory conditions in vivo in Trichuris-infected intestines and within the tumor microenvironment, where they appear to contribute to the regulatory milieu. iTR35 may constitute a key mediator of infectious tolerance and may contribute to Treg-mediated tumor progression, and ex vivo-generated iTR35 may possess therapeutic utility.

Standard name | GSE24210_IL35_TREATED_VS_RESTING_TREG_DN
Systematic name | M7843
Organism | Mus musculus
PMID | 20953201
Authors | Collison LW,Chaturvedi V,Henderson AL,Giacomin PR,Guy C,Bankoti J,Finkelstein D,Forbes K,Workman CJ,Brown SA,Rehg JE,Jones ML,Ni HT,Artis D,Turk MJ,Vignali DA
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv cells treated with IL35 versus resting T reg cells.
Full description | Regulatory T cells (Tregs) play a critical role in the maintenance of immunological self-tolerance. Naïve human or murine T cell treatment with the inhibitory cytokine IL35 induces a regulatory population, termed iTR35, that mediates suppression via IL35, but not IL10 or TGFβ, neither express nor require Foxp3, are strongly suppressive in five in vivo models, and exhibit in vivo stability. Treg-mediated suppression induces iTR35 generation in an IL35- and IL10-dependent manner in vitro, and in inflammatory conditions in vivo in Trichuris-infected intestines and within the tumor microenvironment, where they appear to contribute to the regulatory milieu. iTR35 may constitute a key mediator of infectious tolerance and may contribute to Treg-mediated tumor progression, and ex vivo-generated iTR35 may possess therapeutic utility.

Standard name | GSE24210_TCONV_VS_TREG_DN
Systematic name | M7844
Organism | Mus musculus
PMID | 20953201
Authors | Collison LW,Chaturvedi V,Henderson AL,Giacomin PR,Guy C,Bankoti J,Finkelstein D,Forbes K,Workman CJ,Brown SA,Rehg JE,Jones ML,Ni HT,Artis D,Turk MJ,Vignali DA
Category | C7
Sub-category |
Brief description | Genes down-regulated in control T conv versus resting T reg cells.
Full description | Regulatory T cells (Tregs) play a critical role in the maintenance of immunological self-tolerance. Naïve human or murine T cell treatment with the inhibitory cytokine IL35 induces a regulatory population, termed iTR35, that mediates suppression via IL35, but not IL10 or TGFβ, neither express nor require Foxp3, are strongly suppressive in five in vivo models, and exhibit in vivo stability. Treg-mediated suppression induces iTR35 generation in an IL35- and IL10-dependent manner in vitro, and in inflammatory conditions in vivo in Trichuris-infected intestines and within the tumor microenvironment, where they appear to contribute to the regulatory milieu. iTR35 may constitute a key mediator of infectious tolerance and may contribute to Treg-mediated tumor progression, and ex vivo-generated iTR35 may possess therapeutic utility.

Standard name | GSE24210_IL35_TREATED_VS_UNTREATED_TCONV_CD4_TCELL_UP
Systematic name | M7845
Organism | Mus musculus
PMID | 20953201
Authors | Collison LW,Chaturvedi V,Henderson AL,Giacomin PR,Guy C,Bankoti J,Finkelstein D,Forbes K,Workman CJ,Brown SA,Rehg JE,Jones ML,Ni HT,Artis D,Turk MJ,Vignali DA
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv cells: IL35 treated versus untreated.
Full description | Regulatory T cells (Tregs) play a critical role in the maintenance of immunological self-tolerance. Naïve human or murine T cell treatment with the inhibitory cytokine IL35 induces a regulatory population, termed iTR35, that mediates suppression via IL35, but not IL10 or TGFβ, neither express nor require Foxp3, are strongly suppressive in five in vivo models, and exhibit in vivo stability. Treg-mediated suppression induces iTR35 generation in an IL35- and IL10-dependent manner in vitro, and in inflammatory conditions in vivo in Trichuris-infected intestines and within the tumor microenvironment, where they appear to contribute to the regulatory milieu. iTR35 may constitute a key mediator of infectious tolerance and may contribute to Treg-mediated tumor progression, and ex vivo-generated iTR35 may possess therapeutic utility.

Standard name | GSE24210_IL35_TREATED_VS_RESTING_TREG_UP
Systematic name | M7848
Organism | Mus musculus
PMID | 20953201
Authors | Collison LW,Chaturvedi V,Henderson AL,Giacomin PR,Guy C,Bankoti J,Finkelstein D,Forbes K,Workman CJ,Brown SA,Rehg JE,Jones ML,Ni HT,Artis D,Turk MJ,Vignali DA
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv cells treated with IL35 versus resting T reg cells.
Full description | Regulatory T cells (Tregs) play a critical role in the maintenance of immunological self-tolerance. Naïve human or murine T cell treatment with the inhibitory cytokine IL35 induces a regulatory population, termed iTR35, that mediates suppression via IL35, but not IL10 or TGFβ, neither express nor require Foxp3, are strongly suppressive in five in vivo models, and exhibit in vivo stability. Treg-mediated suppression induces iTR35 generation in an IL35- and IL10-dependent manner in vitro, and in inflammatory conditions in vivo in Trichuris-infected intestines and within the tumor microenvironment, where they appear to contribute to the regulatory milieu. iTR35 may constitute a key mediator of infectious tolerance and may contribute to Treg-mediated tumor progression, and ex vivo-generated iTR35 may possess therapeutic utility.

Standard name | GSE24210_IL35_TREATED_VS_UNTREATED_TCONV_CD4_TCELL_DN
Systematic name | M7850
Organism | Mus musculus
PMID | 20953201
Authors | Collison LW,Chaturvedi V,Henderson AL,Giacomin PR,Guy C,Bankoti J,Finkelstein D,Forbes K,Workman CJ,Brown SA,Rehg JE,Jones ML,Ni HT,Artis D,Turk MJ,Vignali DA
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv cells: IL35 treated versus untreated.
Full description | Regulatory T cells (Tregs) play a critical role in the maintenance of immunological self-tolerance. Naïve human or murine T cell treatment with the inhibitory cytokine IL35 induces a regulatory population, termed iTR35, that mediates suppression via IL35, but not IL10 or TGFβ, neither express nor require Foxp3, are strongly suppressive in five in vivo models, and exhibit in vivo stability. Treg-mediated suppression induces iTR35 generation in an IL35- and IL10-dependent manner in vitro, and in inflammatory conditions in vivo in Trichuris-infected intestines and within the tumor microenvironment, where they appear to contribute to the regulatory milieu. iTR35 may constitute a key mediator of infectious tolerance and may contribute to Treg-mediated tumor progression, and ex vivo-generated iTR35 may possess therapeutic utility.

Standard name | GSE24210_TCONV_VS_TREG_UP
Systematic name | M7851
Organism | Mus musculus
PMID | 20953201
Authors | Collison LW,Chaturvedi V,Henderson AL,Giacomin PR,Guy C,Bankoti J,Finkelstein D,Forbes K,Workman CJ,Brown SA,Rehg JE,Jones ML,Ni HT,Artis D,Turk MJ,Vignali DA
Category | C7
Sub-category |
Brief description | Genes up-regulated in control T conv versus resting T reg cells.
Full description | Regulatory T cells (Tregs) play a critical role in the maintenance of immunological self-tolerance. Naïve human or murine T cell treatment with the inhibitory cytokine IL35 induces a regulatory population, termed iTR35, that mediates suppression via IL35, but not IL10 or TGFβ, neither express nor require Foxp3, are strongly suppressive in five in vivo models, and exhibit in vivo stability. Treg-mediated suppression induces iTR35 generation in an IL35- and IL10-dependent manner in vitro, and in inflammatory conditions in vivo in Trichuris-infected intestines and within the tumor microenvironment, where they appear to contribute to the regulatory milieu. iTR35 may constitute a key mediator of infectious tolerance and may contribute to Treg-mediated tumor progression, and ex vivo-generated iTR35 may possess therapeutic utility.

Standard name | GSE23505_UNTREATED_VS_4DAY_IL6_IL1_TGFB_TREATED_CD4_TCELL_UP
Systematic name | M7852
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated versus IL6 and TGFB1 [GeneID=3569;7040].
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_UNTREATED_VS_4DAY_IL6_IL1_IL23_TREATED_CD4_TCELL_DN
Systematic name | M7853
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated versus IL1B, IL6 [GeneID=3553;3569] and IL-23.
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_UNTREATED_VS_4DAY_IL6_IL1_IL23_TREATED_CD4_TCELL_UP
Systematic name | M7856
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated versus IL1B, IL6 [GeneID=3553;3569] and IL-23.
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_UNTREATED_VS_4DAY_IL6_IL1_TREATED_CD4_TCELL_UP
Systematic name | M7858
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated versus IL1B and IL6 [GeneID=3553;3569].
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_IL6_IL1_VS_IL6_IL1_IL23_TREATED_CD4_TCELL_DN
Systematic name | M7859
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with IL1B and IL6 [GeneID=3553;3569] versus those also treated with IL-23.
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_IL6_IL1_VS_IL6_IL1_TGFB_TREATED_CD4_TCELL_DN
Systematic name | M7861
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with IL1B and IL6 [GeneID=3553;3569] versus those also treated with TGFB1 [GeneID=7040].
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_UNTREATED_VS_4DAY_IL6_IL1_TREATED_CD4_TCELL_DN
Systematic name | M7863
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated versus IL1B and IL6 [GeneID=3553;3569].
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_IL6_IL1_IL23_VS_IL6_IL1_TGFB_TREATED_CD4_TCELL_UP
Systematic name | M7864
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: IL1B, IL6 [GeneID=3553;3569] and IL-23 versus IL1B, IL6 and TGFB1 [GeneID=3553;3569;7040].
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_IL6_IL1_IL23_VS_IL6_IL1_TGFB_TREATED_CD4_TCELL_DN
Systematic name | M7865
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: IL1B, IL6 [GeneID=3553;3569] and IL-23 versus IL1B, IL6 and TGFB1 [GeneID=3553;3569;7040].
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_UNTREATED_VS_4DAY_IL6_IL1_TGFB_TREATED_CD4_TCELL_DN
Systematic name | M7868
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated versus IL6 and TGFB1 [GeneID=3569;7040].
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_IL6_IL1_VS_IL6_IL1_IL23_TREATED_CD4_TCELL_UP
Systematic name | M7869
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with IL1B and IL6 [GeneID=3553;3569] versus those also treated with IL-23.
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE23505_IL6_IL1_VS_IL6_IL1_TGFB_TREATED_CD4_TCELL_UP
Systematic name | M7872
Organism | Mus musculus
PMID | 20962846
Authors | Ghoreschi K,Laurence A,Yang XP,Tato CM,McGeachy MJ,Konkel JE,Ramos HL,Wei L,Davidson TS,Bouladoux N,Grainger JR,Chen Q,Kanno Y,Watford WT,Sun HW,Eberl G,Shevach EM,Belkaid Y,Cua DJ,Chen W,O'Shea JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with IL1B and IL6 [GeneID=3553;3569] versus those also treated with TGFB1 [GeneID=7040].
Full description | CD4+ T cells that selectively produce interleukin (IL)-17, are critical for host defense and autoimmunity1-4. Crucial for T helper17 (Th17) cells in vivo5,6, IL-23 has been thought to be incapable of driving initial differentiation. Rather, IL-6 and transforming growth factor (TGF)-β1 have been argued to be the factors responsible for initiating specification7-10. Herein, we show that Th17 differentiation occurs in the absence of TGF-β signaling. Neither IL-6 nor IL-23 alone efficiently generated Th17 cells; however, these cytokines in combination with IL-1β effectively induced IL-17 production in naïve precursors, independently of TGF-β. Epigenetic modification of the Il17a/Il17f and Rorc promoters proceeded without TGF-β1, allowing the generation of cells that co-expressed Rorγt and T-bet. T-bet+Rorγt+ Th17 cells are generated in vivo during experimental allergic encephalomyelitis (EAE), and adoptively transferred Th17 cells generated with IL-23 in the absence of TGF-β1 were more pathogenic in this experimental disease. These data suggest a new model for Th17 differentiation. Consistent with genetic data linking the IL23R with autoimmunity, our findings re-emphasize the role of IL-23 and therefore have important implications for the development of new therapies.

Standard name | GSE24492_LYVE_NEG_VS_POS_MACROPHAGE_DN
Systematic name | M7873
Organism | Mus musculus
PMID | 20978081
Authors | Gordon EJ,Rao S,Pollard JW,Nutt SL,Lang RA,Harvey NL
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: LYVE1+ [GeneID=10894] versus LYVE1- [GeneID=10894].
Full description | LYVE-1-positive macrophages were observed to be closely spatially associated with the developing lymphatic vasculature. The role of this population of macrophages in the embryo is uncharacterised. We used microarray analyses to investigate which genes are differentially regulated between LYVE-1-positive and LYVE-1-negative macrophages

Standard name | GSE24492_LYVE_NEG_VS_POS_MACROPHAGE_UP
Systematic name | M7875
Organism | Mus musculus
PMID | 20978081
Authors | Gordon EJ,Rao S,Pollard JW,Nutt SL,Lang RA,Harvey NL
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: LYVE1+ [GeneID=10894] versus LYVE1- [GeneID=10894].
Full description | LYVE-1-positive macrophages were observed to be closely spatially associated with the developing lymphatic vasculature. The role of this population of macrophages in the embryo is uncharacterised. We used microarray analyses to investigate which genes are differentially regulated between LYVE-1-positive and LYVE-1-negative macrophages

Standard name | GSE23925_LIGHT_ZONE_VS_DARK_ZONE_BCELL_UP
Systematic name | M7877
Organism | Mus musculus
PMID | 21074050
Authors | Victora GD,Schwickert TA,Fooksman DR,Kamphorst AO,Meyer-Hermann M,Dustin ML,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in B cells: light versus dark zone.
Full description | Microarrays of gene expression in mouse germinal center B cells photoactivated in the light zone or dark zone, and of naïve cells for comparison. We used microarray data to identify genes differentially expressed by B cells in the light and dark zones of the germinal center.

Standard name | GSE23925_LIGHT_ZONE_VS_DARK_ZONE_BCELL_DN
Systematic name | M7878
Organism | Mus musculus
PMID | 21074050
Authors | Victora GD,Schwickert TA,Fooksman DR,Kamphorst AO,Meyer-Hermann M,Dustin ML,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in B cells: light versus dark zone.
Full description | Microarrays of gene expression in mouse germinal center B cells photoactivated in the light zone or dark zone, and of naïve cells for comparison. We used microarray data to identify genes differentially expressed by B cells in the light and dark zones of the germinal center.

Standard name | GSE23925_DARK_ZONE_VS_NAIVE_BCELL_UP
Systematic name | M7879
Organism | Mus musculus
PMID | 21074050
Authors | Victora GD,Schwickert TA,Fooksman DR,Kamphorst AO,Meyer-Hermann M,Dustin ML,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in B cells: dark zone versus naïve.
Full description | Microarrays of gene expression in mouse germinal center B cells photoactivated in the light zone or dark zone, and of naïve cells for comparison. We used microarray data to identify genes differentially expressed by B cells in the light and dark zones of the germinal center.

Standard name | GSE23925_DARK_ZONE_VS_NAIVE_BCELL_DN
Systematic name | M7881
Organism | Mus musculus
PMID | 21074050
Authors | Victora GD,Schwickert TA,Fooksman DR,Kamphorst AO,Meyer-Hermann M,Dustin ML,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in B cells: dark zone versus naïve.
Full description | Microarrays of gene expression in mouse germinal center B cells photoactivated in the light zone or dark zone, and of naïve cells for comparison. We used microarray data to identify genes differentially expressed by B cells in the light and dark zones of the germinal center.

Standard name | GSE23925_LIGHT_ZONE_VS_NAIVE_BCELL_DN
Systematic name | M7884
Organism | Mus musculus
PMID | 21074050
Authors | Victora GD,Schwickert TA,Fooksman DR,Kamphorst AO,Meyer-Hermann M,Dustin ML,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in B cells: light zone versus naïve.
Full description | Microarrays of gene expression in mouse germinal center B cells photoactivated in the light zone or dark zone, and of naïve cells for comparison. We used microarray data to identify genes differentially expressed by B cells in the light and dark zones of the germinal center.

Standard name | GSE23925_LIGHT_ZONE_VS_NAIVE_BCELL_UP
Systematic name | M7885
Organism | Mus musculus
PMID | 21074050
Authors | Victora GD,Schwickert TA,Fooksman DR,Kamphorst AO,Meyer-Hermann M,Dustin ML,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in B cells: light zone versus naïve.
Full description | Microarrays of gene expression in mouse germinal center B cells photoactivated in the light zone or dark zone, and of naïve cells for comparison. We used microarray data to identify genes differentially expressed by B cells in the light and dark zones of the germinal center.

Standard name | GSE16385_MONOCYTE_VS_12H_ROSIGLITAZONE_TREATED_MACROPHAGE_DN
Systematic name | M7886
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (12h) versus macrophages (12h) treated with rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_UNTREATED_VS_12H_ROSIGLITAZONE_IFNG_TNF_TREATED_MACROPHAGE_UP
Systematic name | M7889
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): control versus IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_UNTREATED_VS_12H_ROSIGLITAZONE_IFNG_TNF_TREATED_MACROPHAGE_DN
Systematic name | M7891
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): control versus IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_ROSIGLITAZONE_IFNG_TNF_VS_IL4_STIM_MACROPHAGE_UP
Systematic name | M7892
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999] versus IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_MACROPHAGE_UP
Systematic name | M7893
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes versus macrophages.
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_ROSIGLITAZONE_VS_UNTREATED_IFNG_TNF_STIM_MACROPHAGE_UP
Systematic name | M7894
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999] versus IFNG and TNF [GeneID=3458;7124].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_ROSIGLITAZONE_VS_UNTREATED_IFNG_TNF_STIM_MACROPHAGE_DN
Systematic name | M7896
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999] versus IFNG and TNF [GeneID=3458;7124].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_12H_ROSIGLITAZONE_IL4_TREATED_MACROPHAGE_UP
Systematic name | M7898
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (12h) versus macrophages (12h) treated with IL4 [GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_12H_ROSIGLITAZONE_IL4_TREATED_MACROPHAGE_DN
Systematic name | M7900
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (12h) versus macrophages (12h) treated with IL4 [GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_MACROPHAGE_DN
Systematic name | M7901
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes versus macrophages.
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_12H_ROSIGLITAZONE_IFNG_TNF_TREATED_MACROPHAGE_UP
Systematic name | M7902
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (12h) versus macrophages (12h) treated with IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_12H_IL4_TREATED_MACROPHAGE_UP
Systematic name | M7903
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (12h) versus macrophages (12h) treated with IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_12H_IL4_TREATED_MACROPHAGE_DN
Systematic name | M7904
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (12h) versus macrophages (12h) treated with IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_12H_ROSIGLITAZONE_TREATED_MACROPHAGE_UP
Systematic name | M7905
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (12h) versus macrophages (12h) treated with rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25123_CTRL_VS_ROSIGLITAZONE_STIM_MACROPHAGE_UP
Systematic name | M7906
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype bone marrow-derived macrophages: control versus treated with rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_CTRL_VS_ROSIGLITAZONE_STIM_MACROPHAGE_DN
Systematic name | M7907
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype bone marrow-derived macrophages: control versus treated with rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_CTRL_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_UP
Systematic name | M7908
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype bone marrow-derived macrophages: control versus IL4 [GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_CTRL_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_DN
Systematic name | M7909
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype bone marrow-derived macrophages: control versus IL4 [GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_UNTREATED_VS_12H_ROSIGLITAZONE_IL4_TREATED_MACROPHAGE_UP
Systematic name | M7911
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): control versus rosiglitazone [PubChem=77999] and IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_UNTREATED_VS_12H_ROSIGLITAZONE_IL4_TREATED_MACROPHAGE_DN
Systematic name | M7913
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): control versus rosiglitazone [PubChem=77999] and IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_12H_ROSIGLITAZONE_IFNG_TNF_TREATED_MACROPHAGE_DN
Systematic name | M7915
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (12h) versus macrophages (12h) treated with IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16386_IL4_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_6H_DN
Systematic name | M7916
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (6h): IL4 [GeneID=3565] versus IL4 [GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 6 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml). Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1uM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_12H_IFNG_TNF_TREATED_MACROPHAGE_UP
Systematic name | M7917
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (12h) versus macrophages (12h) treated with IFNG and TNF [GeneID=3458;7124].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_MONOCYTE_VS_12H_IFNG_TNF_TREATED_MACROPHAGE_DN
Systematic name | M7920
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (12h) versus macrophages (12h) treated with IFNG and TNF [GeneID=3458;7124].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25123_WT_VS_PPARG_KO_MACROPHAGE_IL4_AND_ROSIGLITAZONE_STIM_DN
Systematic name | M7921
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages treated with IL4 [GeneID=3565] and rosiglitazone [PubChem=77999]: wildtype versus PPARG [GeneID=5468] knockout.
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_CTRL_VS_IL4_STIM_MACROPHAGE_UP
Systematic name | M7922
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype bone marrow-derived macrophages: control versus treated with IL4 [GeneID=3565].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_CTRL_VS_IL4_STIM_MACROPHAGE_DN
Systematic name | M7924
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype bone marrow-derived macrophages: control versus treated with IL4 [GeneID=3565].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_IFNG_TNF_VS_IL4_STIM_MACROPHAGE_ROSIGLITAZONE_TREATED_DN
Systematic name | M7925
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999] versus rosiglitazone [PubChem=77999] and IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25088_CTRL_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_UP
Systematic name | M7926
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype bone marrow-derived macrophages: control versus treated with IL4 [GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_CTRL_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_DN
Systematic name | M7929
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype bone marrow-derived macrophages: control versus treated with IL4 [GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_CTRL_VS_IL4_STIM_STAT6_KO_MACROPHAGE_UP
Systematic name | M7930
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with STAT6 [GeneID=6778] knockout: control versus treated with IL4 [GeneID=3565].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_CTRL_VS_IL4_STIM_STAT6_KO_MACROPHAGE_DN
Systematic name | M7931
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with STAT6 [GeneID=6778] knockout: control versus treated with IL4 [GeneID=3565].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_CTRL_VS_ROSIGLITAZONE_STIM_STAT6_KO_MACROPHAGE_UP
Systematic name | M7932
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with STAT6 [GeneID=6778] knockout: control versus treated with rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_UNTREATED_VS_12H_IFNG_TNF_TREATED_MACROPHAGE_UP
Systematic name | M7935
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): control versus IFNG and TNF [GeneID=3458;7124].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_UNTREATED_VS_12H_IFNG_TNF_TREATED_MACROPHAGE_DN
Systematic name | M7936
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): control versus IFNG and TNF [GeneID=3458;7124].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25123_WT_VS_PPARG_KO_MACROPHAGE_ROSIGLITAZONE_STIM_DN
Systematic name | M7938
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages treated with rosiglitazone [PubChem=77999]: wildtype versus PPARG [GeneID=5468].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_WT_VS_PPARG_KO_MACROPHAGE_IL4_AND_ROSIGLITAZONE_STIM_UP
Systematic name | M7939
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages treated with IL4 [GeneID=3565] and rosiglitazone [PubChem=77999]: wildtype versus PPARG [GeneID=5468] knockout.
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_UNTREATED_VS_12H_ROSIGLITAZONE_TREATED_MACROPHAGE_UP
Systematic name | M7940
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): control versus rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_UNTREATED_VS_12H_ROSIGLITAZONE_TREATED_MACROPHAGE_DN
Systematic name | M7942
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): control versus rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_IFNG_TNF_VS_IL4_STIM_MACROPHAGE_ROSIGLITAZONE_TREATED_UP
Systematic name | M7943
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999] versus rosiglitazone [PubChem=77999] and IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25088_IL4_VS_IL4_AND_ROSIGLITAZONE_STIM_STAT6_KO_MACROPHAGE_DAY10_UP
Systematic name | M7944
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with STAT6 [GeneID=6778] knockout treated with IL4 [GeneID=3565]: control versus rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_IL4_VS_IL4_AND_ROSIGLITAZONE_STIM_STAT6_KO_MACROPHAGE_DAY10_DN
Systematic name | M7947
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with STAT6 [GeneID=6778] knockout treated with IL4 [GeneID=3565]: control versus rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_ROSIGLITAZONE_VS_IL4_AND_ROSIGLITAZONE_STIM_STAT6_KO_MACROPHAGE_DAY10_UP
Systematic name | M7948
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with STAT6 [GeneID=6778] knockout treated with rosiglitazone [PubChem=77999]: control versus IL4 [GeneID=3565].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_ROSIGLITAZONE_VS_IL4_AND_ROSIGLITAZONE_STIM_STAT6_KO_MACROPHAGE_DAY10_DN
Systematic name | M7950
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with STAT6 [GeneID=6778] knockout treated with rosiglitazone [PubChem=77999]: control versus IL4 [GeneID=3565].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_WT_VS_PPARG_KO_MACROPHAGE_UP
Systematic name | M7951
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: wildtype versus PPARG [GeneID=5468] knockout.
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_WT_VS_PPARG_KO_MACROPHAGE_DN
Systematic name | M7953
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: wildtype versus PPARG [GeneID=5468] knockout.
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_WT_VS_PPARG_KO_MACROPHAGE_IL4_STIM_UP
Systematic name | M7954
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages treated with IL4 [GeneID=3565]: wildtype versus PPARG [GeneID=5468] knockout.
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_WT_VS_PPARG_KO_MACROPHAGE_IL4_STIM_DN
Systematic name | M7958
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages treated with IL4 [GeneID=3565]: wildtype versus PPARG [GeneID=5468] knockout.
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_UNTREATED_VS_12H_IL4_TREATED_MACROPHAGE_UP
Systematic name | M7959
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): control versus IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_UNTREATED_VS_12H_IL4_TREATED_MACROPHAGE_DN
Systematic name | M7960
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): control versus IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25123_CTRL_VS_IL4_AND_ROSIGLITAZONE_STIM_PPARG_KO_MACROPHAGE_DN
Systematic name | M7961
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with PPARG [GeneID=5468] knockout: control versus IL4 [GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_IL4_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_DAY10_UP
Systematic name | M7962
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype bone marrow-derived macrophages treated with IL4 [GeneID=3565]: control versus rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_IL4_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_DAY10_DN
Systematic name | M7965
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype bone marrow-derived macrophages treated with IL4 [GeneID=3565]: control versus rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_ROSIGLITAZONE_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_DAY10_UP
Systematic name | M7967
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype bone marrow-derived macrophages treated with rosiglitazone [PubChem=77999]: control versus IL4 [GeneID=3565].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_ROSIGLITAZONE_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_DAY10_DN
Systematic name | M7969
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype bone marrow-derived macrophages treated with rosiglitazone [PubChem=77999]: control versus IL4 [GeneID=3565].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_IL4_VS_IL4_AND_ROSIGLITAZONE_STIM_PPARG_KO_MACROPHAGE_DAY10_UP
Systematic name | M7971
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with PPARG [GeneID=5468] knockout treated with IL4 [GeneID=3565]: control versus rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_IL4_VS_IL4_AND_ROSIGLITAZONE_STIM_PPARG_KO_MACROPHAGE_DAY10_DN
Systematic name | M7972
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with PPARG [GeneID=5468] knockout treated with IL4 [GeneID=3565]: control versus rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_WT_VS_STAT6_KO_MACROPHAGE_UP
Systematic name | M7973
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: wildtype versus STAT6 [GeneID=6778] knockout.
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_CTRL_VS_IL4_STIM_PPARG_KO_MACROPHAGE_UP
Systematic name | M7975
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with PPARG [GeneID=5468] knockout: control versus IL4 [GeneID=3565].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_CTRL_VS_IL4_STIM_PPARG_KO_MACROPHAGE_DN
Systematic name | M7976
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with PPARG [GeneID=5468] knockout: control versus IL4 [GeneID=3565].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_CTRL_VS_ROSIGLITAZONE_STIM_PPARG_KO_MACROPHAGE_UP
Systematic name | M7977
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with PPARG [GeneID=5468] knockout: control versus rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_WT_VS_PPARG_KO_MACROPHAGE_ROSIGLITAZONE_STIM_UP
Systematic name | M7978
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages treated with rosiglitazone [PubChem=77999]: wildtype versus PPARG [GeneID=5468].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_CTRL_VS_IL4_AND_ROSIGLITAZONE_STIM_PPARG_KO_MACROPHAGE_UP
Systematic name | M7980
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with PPARG [GeneID=5468] knockout: control versus IL4 [GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_IL4_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_DAY10_UP
Systematic name | M7981
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype bone marrow-derived macrophages treated with IL4 [GeneID=3565]: control versus rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_IL4_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_DAY10_DN
Systematic name | M7983
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype bone marrow-derived macrophages treated with IL4 [GeneID=3565]: control versus rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_ROSIGLITAZONE_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_DAY10_UP
Systematic name | M7984
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype bone marrow-derived macrophages treated with rosiglitazone [PubChem=77999]: control versus IL4 [GeneID=3565].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_ROSIGLITAZONE_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_DAY10_DN
Systematic name | M7985
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype bone marrow-derived macrophages treated with rosiglitazone [PubChem=77999]: control versus IL4 [GeneID=3565].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_ROSIGLITAZONE_IL4_VS_ROSIGLITAZONE_ALONE_STIM_MACROPHAGE_UP
Systematic name | M7986
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): rosiglitazone [PubChem=77999] and IL4 [GeneID=3565] versus rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_ROSIGLITAZONE_IL4_VS_ROSIGLITAZONE_ALONE_STIM_MACROPHAGE_DN
Systematic name | M7989
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): rosiglitazone [PubChem=77999] and IL4 [GeneID=3565] versus rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_IFNG_TNF_VS_IL4_STIM_MACROPHAGE_UP
Systematic name | M7990
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): IFNG and TNF [GeneID=3458;7124] versus IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25123_ROSIGLITAZONE_VS_IL4_AND_ROSIGLITAZONE_STIM_PPARG_KO_MACROPHAGE_DAY10_UP
Systematic name | M7991
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with PPARG [GeneID=5468] knockout treated with rosiglitazone [PubChem=77999]: control versus IL4 [GeneID=3565].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_ROSIGLITAZONE_VS_IL4_AND_ROSIGLITAZONE_STIM_PPARG_KO_MACROPHAGE_DAY10_DN
Systematic name | M7992
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with PPARG [GeneID=5468] knockout treated with rosiglitazone [PubChem=77999]: control versus IL4 [GeneID=3565].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_ROSIGLITAZONE_IFNG_TNF_VS_IL4_STIM_MACROPHAGE_DN
Systematic name | M7993
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999] versus IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25088_CTRL_VS_ROSIGLITAZONE_STIM_STAT6_KO_MACROPHAGE_DN
Systematic name | M7996
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with STAT6 [GeneID=6778] knockout: control versus treated with rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25123_CTRL_VS_ROSIGLITAZONE_STIM_PPARG_KO_MACROPHAGE_DN
Systematic name | M7998
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with PPARG [GeneID=5468] knockout: control versus rosiglitazone [PubChem=77999].
Full description | Conditional macrophage-specific PPARg knockout mice were generated on C57Bl/6 background by breeding PPARg fl/- (one allele is floxed, the other is null) and lysozyme Cre transgenic mice. PPARg and IL-4 signaling was analyzed on bone marrow-derived macrophages. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and fresh media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16386_IL4_VS_IL4_AND_ROSIGLITAZONE_STIM_MACROPHAGE_6H_UP
Systematic name | M8000
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (6h): IL4 [GeneID=3565] versus IL4 [GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 6 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml). Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1uM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25088_WT_VS_STAT6_KO_MACROPHAGE_ROSIGLITAZONE_STIM_DN
Systematic name | M8001
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages treated with rosiglitazone [PubChem=77999]: wildtype versus STAT6 [GeneID=6778] knockout.
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_WT_VS_STAT6_KO_MACROPHAGE_ROSIGLITAZONE_AND_IL4_STIM_UP
Systematic name | M8002
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages treated with IL4 [GeneID=3565] and rosiglitazone [PubChem=77999]: wildtype versus STAT6 [GeneID=6778] knockout.
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_WT_VS_STAT6_KO_MACROPHAGE_ROSIGLITAZONE_AND_IL4_STIM_DN
Systematic name | M8003
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages treated with IL4 [GeneID=3565] and rosiglitazone [PubChem=77999]: wildtype versus STAT6 [GeneID=6778] knockout.
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_CTRL_VS_IL4_STIM_MACROPHAGE_UP
Systematic name | M8006
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype bone marrow-derived macrophages: control versus treated with IL4 [GeneID=3565].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_CTRL_VS_IL4_STIM_MACROPHAGE_DN
Systematic name | M8007
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype bone marrow-derived macrophages: control versus treated with IL4 [GeneID=3565].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_CTRL_VS_ROSIGLITAZONE_STIM_MACROPHAGE_UP
Systematic name | M8008
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype bone marrow-derived macrophages: control versus treated with rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_CTRL_VS_ROSIGLITAZONE_STIM_MACROPHAGE_DN
Systematic name | M8010
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype bone marrow-derived macrophages: control versus treated with rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_IFNG_TNF_VS_IL4_STIM_MACROPHAGE_DN
Systematic name | M8011
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): IFNG and TNF [GeneID=3458;7124] versus IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_IFNG_TNF_VS_ROSIGLITAZONE_STIM_MACROPHAGE_UP
Systematic name | M8012
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): IFNG and TNF [GeneID=3458;7124] versus rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_IFNG_TNF_VS_ROSIGLITAZONE_STIM_MACROPHAGE_DN
Systematic name | M8016
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): IFNG and TNF [GeneID=3458;7124] versus rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_IL4_VS_ROSIGLITAZONE_STIM_MACROPHAGE_UP
Systematic name | M8017
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): IL4 [GeneID=3565] versus rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_IL4_VS_ROSIGLITAZONE_STIM_MACROPHAGE_DN
Systematic name | M8018
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): IL4 [GeneID=3565] versus rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25088_WT_VS_STAT6_KO_MACROPHAGE_ROSIGLITAZONE_STIM_UP
Systematic name | M8019
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages treated with rosiglitazone [PubChem=77999]: wildtype versus STAT6 [GeneID=6778] knockout.
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_IFNG_TNF_VS_UNSTIM_MACROPHAGE_ROSIGLITAZONE_TREATED_UP
Systematic name | M8021
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999] versus rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25088_CTRL_VS_IL4_AND_ROSIGLITAZONE_STIM_STAT6_KO_MACROPHAGE_UP
Systematic name | M8022
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with STAT6 [GeneID=6778] knockout: control versus treated with IL4[GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_CTRL_VS_IL4_AND_ROSIGLITAZONE_STIM_STAT6_KO_MACROPHAGE_DN
Systematic name | M8024
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with STAT6 [GeneID=6778] knockout: control versus treated with IL4[GeneID=3565] and rosiglitazone [PubChem=77999].
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_ROSIGLITAZONE_IL4_VS_IFNG_TNF_STIM_MACROPHAGE_DN
Systematic name | M8025
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): rosiglitazone [PubChem=77999] and IL4 [GeneID=3565] versus IFNG and TNF [GeneID=3458;7124].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_ROSIGLITAZONE_IL4_VS_IL4_ALONE_STIM_MACROPHAGE_12H_UP
Systematic name | M8026
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): rosiglitazone [PubChem=77999] and IL4 [GeneID=3565] versus IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE16385_ROSIGLITAZONE_IL4_VS_IL4_ALONE_STIM_MACROPHAGE_12H_DN
Systematic name | M8027
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): rosiglitazone [PubChem=77999] and IL4 [GeneID=3565] versus IL4 [GeneID=3565].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25088_WT_VS_STAT6_KO_MACROPHAGE_IL4_STIM_UP
Systematic name | M8028
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages treated with IL4 [GeneID=3565]: wildtype versus STAT6 [GeneID=6778] knockout.
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE25088_WT_VS_STAT6_KO_MACROPHAGE_IL4_STIM_DN
Systematic name | M8029
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages treated with IL4 [GeneID=3565]: wildtype versus STAT6 [GeneID=6778] knockout.
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_ROSIGLITAZONE_IL4_VS_IFNG_TNF_STIM_MACROPHAGE_UP
Systematic name | M8030
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages (12h): rosiglitazone [PubChem=77999] and IL4 [GeneID=3565] versus IFNG and TNF [GeneID=3458;7124].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE25088_WT_VS_STAT6_KO_MACROPHAGE_DN
Systematic name | M8031
Organism | Mus musculus
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: wildtype versus STAT6 [GeneID=6778] knockout.
Full description | C57Bl/6 wild-type and STAT6 KO mice were used to study PPARg and IL-4 signaling. Bone marrow of 3 mice per group was isolated and differentiated to macrophages with M-CSF (20 ng/ml). 20 ng/ml IL-4 was used to induce alternative macrophage activation and 1 uM Rosiglitazone (RSG) was used to activate PPARg. From each mouse 4 samples were generated: 1. M-CSF, 2. M-CSF+RSG, 3. IL-4 and 4. IL-4+RSG. All compounds were added throughout the whole differentiation process, and frech media was added every other day. Control cells were treated with vehicle (DMSO:ethanol). After 10 days, RNA was isolated and gene expression profiles were analyzed using Mouse Genome 430 2.0 microarrays from Affymetrix.

Standard name | GSE16385_IFNG_TNF_VS_UNSTIM_MACROPHAGE_ROSIGLITAZONE_TREATED_DN
Systematic name | M8032
Organism | Homo sapiens
PMID | 21093321
Authors | Szanto A,Balint BL,Nagy ZS,Barta E,Dezso B,Pap A,Szeles L,Poliska S,Oros M,Evans RM,Barak Y,Schwabe J,Nagy L
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages (12h): IFNG, TNF [GeneID=3458;7124] and rosiglitazone [PubChem=77999] versus rosiglitazone [PubChem=77999].
Full description | Human CD14 positive monocytes were purified from healthy volunteers’ blood and cultured in vitro for 4, 12, 24, 72 hours. While culturing, macrophages were activated alternatively with interleukin-4 (IL-4 100 ng/ml) or classically with interferon-gamma (IFNg 100 ng/ml)+tumor necrosis factor (TNF 50 ng/ml) or left without activation. Simultaneously, macrophages were also treated with vehicle (DMSO:ethanol) or 1mM synthetic PPARg agonist, Rosiglitazone. We used Affymetrix microarrays (U133Plus 2.0) to analyze activation and PPARg-induced gene expression changes.

Standard name | GSE17301_ACD3_ACD28_VS_ACD3_ACD28_AND_IFNA5_STIM_CD8_TCELL_DN
Systematic name | M8033
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells activated by anti-CD3 and anti-CD28 versus those stimulated by IFNA5 [GeneID=3442].
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_CTRL_VS_48H_IFNA2_STIM_CD8_TCELL_DN
Systematic name | M8034
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: control versus stimulated by IFNA2 [GeneID=3440].
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_ACD3_ACD28_VS_ACD3_ACD28_AND_IFNA2_STIM_CD8_TCELL_UP
Systematic name | M8035
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells activated by anti-CD3 and anti-CD28 versus those stimulated by IFNA2 [GeneID=3440].
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_IFNA2_VS_IFNA5_STIM_ACD3_ACD28_ACT_CD8_TCELL_UP
Systematic name | M8036
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells stimulated by IFNA2 [GeneID=3440] versus CD8 T cells stimulated by IFNA5 [GeneID=3442] and activated by anti-CD3 and anti-CD28.
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_IFNA2_VS_IFNA5_STIM_ACD3_ACD28_ACT_CD8_TCELL_DN
Systematic name | M8037
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells stimulated by IFNA2 [GeneID=3440] versus CD8 T cells stimulated by IFNA5 [GeneID=3442] and activated by anti-CD3 and anti-CD28.
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_CTRL_VS_48H_IFNA2_STIM_CD8_TCELL_UP
Systematic name | M8038
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: control versus stimulated by IFNA2 [GeneID=3440].
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_CTRL_VS_48H_ACD3_ACD28_IFNA2_STIM_CD8_TCELL_DN
Systematic name | M8039
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: control versus stimulated by IFNA2 [GeneID=3440] and activated by anti-CD3 and anti-CD28.
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_ACD3_ACD28_VS_ACD3_ACD28_AND_IFNA2_STIM_CD8_TCELL_DN
Systematic name | M8040
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells activated by anti-CD3 and anti-CD28 versus those stimulated by IFNA2 [GeneID=3440].
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_ACD3_ACD28_VS_ACD3_ACD28_AND_IFNA5_STIM_CD8_TCELL_UP
Systematic name | M8041
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells activated by anti-CD3 and anti-CD28 versus those stimulated by IFNA5 [GeneID=3442].
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_IFNA2_VS_IFNA2_AND_ACD3_ACD28_STIM_CD8_TCELL_UP
Systematic name | M8042
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells stimulated by IFNA2 [GeneID=3440] versus those activated by anti-CD3 and anti-CD28.
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_IFNA2_VS_IFNA2_AND_ACD3_ACD28_STIM_CD8_TCELL_DN
Systematic name | M8044
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells stimulated by IFNA2 [GeneID=3440] versus those activated by anti-CD3 and anti-CD28.
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_CTRL_VS_48H_ACD3_ACD28_STIM_CD8_TCELL_UP
Systematic name | M8045
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T lymphocytes: control versus activated by anti-CD3 and anti-CD28.
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_CTRL_VS_48H_ACD3_ACD28_STIM_CD8_TCELL_DN
Systematic name | M8046
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T lymphocytes: control versus activated by anti-CD3 and anti-CD28.
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_CTRL_VS_48H_ACD3_ACD28_IFNA5_STIM_CD8_TCELL_DN
Systematic name | M8048
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: control versus stimulated by IFNA5 [GeneID=3442] and activated by anti-CD3 and anti-CD28.
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_CTRL_VS_48H_ACD3_ACD28_IFNA2_STIM_CD8_TCELL_UP
Systematic name | M8049
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: control versus stimulated by IFNA2 [GeneID=3440] and activated by anti-CD3 and anti-CD28.
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE17301_CTRL_VS_48H_ACD3_ACD28_IFNA5_STIM_CD8_TCELL_UP
Systematic name | M8050
Organism | Homo sapiens
PMID | 21108462
Authors | Hervas-Stubbs S,Riezu-Boj JI,Gonzalez I,Mancheño U,Dubrot J,Azpilicueta A,Gabari I,Palazon A,Aranguren A,Ruiz J,Prieto J,Larrea E,Melero I
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: control versus stimulated by IFNA5 [GeneID=3442] and activated by anti-CD3 and anti-CD28.
Full description | IFN alpha mediated gene expression pattern. The effect of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. This analysis examined the effects of IFN alpha on human CD8 T cells responding to antigen (signal 1) and costimulatory signals (signal 2) provided by beads coated with anti-CD3 and anti-CD28 mAbs. Magnetically sorted untouched CD8+CD45R0- T cells from three different donors were unstimulated or stimulated with IFNa2b or with anti-CD3/CD28 Beads alone or along with IFNa2b or IFNa5 for 48 hours. Individual mRNA samples were analyzed using HG-U133A 2.0 array gene chips.

Standard name | GSE23984_CTRL_VS_HYPOCALEMIC_VITAMIND_ANALOG_TCELL_UP
Systematic name | M8051
Organism | Homo sapiens
PMID | 21131424
Authors | Baeke F,Korf H,Overbergh L,Verstuyf A,Thorrez L,Lommel Van L,Waer M,Schuit F,Gysemans C,Mathieu C
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: control versus TX527 (hypocalemic analog of 25-hydroxyvitamin D3 [PubChem=1593]).
Full description | Hypocalcemic vitamin D analogs are appealing molecules to exploit the immunomodulatory actions of active vitamin D in vivo. The functional modulation of dendritic cells is regarded as the key mechanism underlying their ability to regulate T cell responses. In contrast, the direct actions of vitamin D and structural analogs on T lymphocytes remain less well characterized. Microarray analysis was performed to gain insight into the direct immunomodulatory actions of TX527, a hypocalcemic vitamin D analog, on human T lymphocytes. Gene expression analysis revealed that TX527 regulated a wide variety of genes involved in different aspects of T cell function, including cellular growth and proliferation, cell death, cellular development, cellular movement and cell-to-cell signalling and interaction.

Standard name | GSE23984_CTRL_VS_HYPOCALEMIC_VITAMIND_ANALOG_TCELL_DN
Systematic name | M8052
Organism | Homo sapiens
PMID | 21131424
Authors | Baeke F,Korf H,Overbergh L,Verstuyf A,Thorrez L,Lommel Van L,Waer M,Schuit F,Gysemans C,Mathieu C
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: control versus TX527 (hypocalemic analog of 25-hydroxyvitamin D3 [PubChem=1593]).
Full description | Hypocalcemic vitamin D analogs are appealing molecules to exploit the immunomodulatory actions of active vitamin D in vivo. The functional modulation of dendritic cells is regarded as the key mechanism underlying their ability to regulate T cell responses. In contrast, the direct actions of vitamin D and structural analogs on T lymphocytes remain less well characterized. Microarray analysis was performed to gain insight into the direct immunomodulatory actions of TX527, a hypocalcemic vitamin D analog, on human T lymphocytes. Gene expression analysis revealed that TX527 regulated a wide variety of genes involved in different aspects of T cell function, including cellular growth and proliferation, cell death, cellular development, cellular movement and cell-to-cell signalling and interaction.

Standard name | GSE24292_WT_VS_PPARG_KO_MACROPHAGE_UP
Systematic name | M8053
Organism | Mus musculus
PMID | 21135166
Authors | Roszer T,Menéndez-Gutiérrez MP,Lefterova MI,Alameda D,Núñez V,Lazar MA,Fischer T,Ricote M
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: wildtype versus PPARG [GeneID=5468] knockout.
Full description | PPARg is a nuclear receptor that plays an important role in lipid metabolism, homeostasis and immunity. Microarray analysis of gene expression was performed in macrophages from WT and PPARg KO mice. Differentially expressed genes were selected for further analysis.

Standard name | GSE24292_WT_VS_PPARG_KO_MACROPHAGE_DN
Systematic name | M8054
Organism | Mus musculus
PMID | 21135166
Authors | Roszer T,Menéndez-Gutiérrez MP,Lefterova MI,Alameda D,Núñez V,Lazar MA,Fischer T,Ricote M
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: wildtype versus PPARG [GeneID=5468] knockout.
Full description | PPARg is a nuclear receptor that plays an important role in lipid metabolism, homeostasis and immunity. Microarray analysis of gene expression was performed in macrophages from WT and PPARg KO mice. Differentially expressed genes were selected for further analysis.

Standard name | GSE24726_WT_VS_E2_2_KO_PDC_DAY6_POST_DELETION_DN
Systematic name | M8056
Organism | Mus musculus
PMID | 21145760
Authors | Ghosh HS,Cisse B,Bunin A,Lewis KL,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells (6 days after knockout): wildtype versus TCF4 [GeneID=6925] knockout.
Full description | The interferon-producing plasmacytoid dendritic cells (PDC) share common progenitors with antigen-presenting classical dendritic cells (cDC), yet they possess distinct morphology and molecular features resembling those of lymphocytes. It is unclear whether the unique cell fate of PDC is actively maintained in the steady state. We report that the deletion of transcription factor E2-2 from mature peripheral PDC caused their spontaneous differentiation into cells with cDC properties. This included the loss of PDC markers, increase in MHC class II expression and T cell priming capacity, acquisition of dendritic morphology and induction of cDC signature genes. Genome-wide chromatin immunoprecipitation revealed direct binding of E2-2 to key PDC-specific and lymphoid genes, as well as to certain genes enriched in cDC. Thus, E2-2 actively maintains the cell fate of mature PDC and opposes the “default” cDC fate, in part through direct regulation of lineage-specific gene expression programs.

Standard name | GSE24726_WT_VS_E2_22_KO_PDC_DAY4_POST_DELETION_DN
Systematic name | M8058
Organism | Mus musculus
PMID | 21145760
Authors | Ghosh HS,Cisse B,Bunin A,Lewis KL,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells (4 days after knockout): wildtype versus TCF4 [GeneID=6925] knockout.
Full description | The interferon-producing plasmacytoid dendritic cells (PDC) share common progenitors with antigen-presenting classical dendritic cells (cDC), yet they possess distinct morphology and molecular features resembling those of lymphocytes. It is unclear whether the unique cell fate of PDC is actively maintained in the steady state. We report that the deletion of transcription factor E2-2 from mature peripheral PDC caused their spontaneous differentiation into cells with cDC properties. This included the loss of PDC markers, increase in MHC class II expression and T cell priming capacity, acquisition of dendritic morphology and induction of cDC signature genes. Genome-wide chromatin immunoprecipitation revealed direct binding of E2-2 to key PDC-specific and lymphoid genes, as well as to certain genes enriched in cDC. Thus, E2-2 actively maintains the cell fate of mature PDC and opposes the “default” cDC fate, in part through direct regulation of lineage-specific gene expression programs.

Standard name | GSE24726_WT_VS_E2_2_KO_PDC_UP
Systematic name | M8060
Organism | Mus musculus
PMID | 21145760
Authors | Ghosh HS,Cisse B,Bunin A,Lewis KL,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells: wildtype versus TCF4 [GeneID=6925] knockout.
Full description | The interferon-producing plasmacytoid dendritic cells (PDC) share common progenitors with antigen-presenting classical dendritic cells (cDC), yet they possess distinct morphology and molecular features resembling those of lymphocytes. It is unclear whether the unique cell fate of PDC is actively maintained in the steady state. We report that the deletion of transcription factor E2-2 from mature peripheral PDC caused their spontaneous differentiation into cells with cDC properties. This included the loss of PDC markers, increase in MHC class II expression and T cell priming capacity, acquisition of dendritic morphology and induction of cDC signature genes. Genome-wide chromatin immunoprecipitation revealed direct binding of E2-2 to key PDC-specific and lymphoid genes, as well as to certain genes enriched in cDC. Thus, E2-2 actively maintains the cell fate of mature PDC and opposes the “default” cDC fate, in part through direct regulation of lineage-specific gene expression programs.

Standard name | GSE24726_WT_VS_E2_2_KO_PDC_DN
Systematic name | M8061
Organism | Mus musculus
PMID | 21145760
Authors | Ghosh HS,Cisse B,Bunin A,Lewis KL,Reizis B
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells: wildtype versus TCF4 [GeneID=6925] knockout.
Full description | The interferon-producing plasmacytoid dendritic cells (PDC) share common progenitors with antigen-presenting classical dendritic cells (cDC), yet they possess distinct morphology and molecular features resembling those of lymphocytes. It is unclear whether the unique cell fate of PDC is actively maintained in the steady state. We report that the deletion of transcription factor E2-2 from mature peripheral PDC caused their spontaneous differentiation into cells with cDC properties. This included the loss of PDC markers, increase in MHC class II expression and T cell priming capacity, acquisition of dendritic morphology and induction of cDC signature genes. Genome-wide chromatin immunoprecipitation revealed direct binding of E2-2 to key PDC-specific and lymphoid genes, as well as to certain genes enriched in cDC. Thus, E2-2 actively maintains the cell fate of mature PDC and opposes the “default” cDC fate, in part through direct regulation of lineage-specific gene expression programs.

Standard name | GSE24726_WT_VS_E2_2_KO_PDC_DAY6_POST_DELETION_UP
Systematic name | M8063
Organism | Mus musculus
PMID | 21145760
Authors | Ghosh HS,Cisse B,Bunin A,Lewis KL,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells (6 days after knockout): wildtype versus TCF4 [GeneID=6925] knockout.
Full description | The interferon-producing plasmacytoid dendritic cells (PDC) share common progenitors with antigen-presenting classical dendritic cells (cDC), yet they possess distinct morphology and molecular features resembling those of lymphocytes. It is unclear whether the unique cell fate of PDC is actively maintained in the steady state. We report that the deletion of transcription factor E2-2 from mature peripheral PDC caused their spontaneous differentiation into cells with cDC properties. This included the loss of PDC markers, increase in MHC class II expression and T cell priming capacity, acquisition of dendritic morphology and induction of cDC signature genes. Genome-wide chromatin immunoprecipitation revealed direct binding of E2-2 to key PDC-specific and lymphoid genes, as well as to certain genes enriched in cDC. Thus, E2-2 actively maintains the cell fate of mature PDC and opposes the “default” cDC fate, in part through direct regulation of lineage-specific gene expression programs.

Standard name | GSE24726_WT_VS_E2_2_KO_PDC_DAY4_POST_DELETION_UP
Systematic name | M8064
Organism | Mus musculus
PMID | 21145760
Authors | Ghosh HS,Cisse B,Bunin A,Lewis KL,Reizis B
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells (4 days after knockout): wildtype versus TCF4 [GeneID=6925] knockout.
Full description | The interferon-producing plasmacytoid dendritic cells (PDC) share common progenitors with antigen-presenting classical dendritic cells (cDC), yet they possess distinct morphology and molecular features resembling those of lymphocytes. It is unclear whether the unique cell fate of PDC is actively maintained in the steady state. We report that the deletion of transcription factor E2-2 from mature peripheral PDC caused their spontaneous differentiation into cells with cDC properties. This included the loss of PDC markers, increase in MHC class II expression and T cell priming capacity, acquisition of dendritic morphology and induction of cDC signature genes. Genome-wide chromatin immunoprecipitation revealed direct binding of E2-2 to key PDC-specific and lymphoid genes, as well as to certain genes enriched in cDC. Thus, E2-2 actively maintains the cell fate of mature PDC and opposes the “default” cDC fate, in part through direct regulation of lineage-specific gene expression programs.

Standard name | GSE22282_HYPOXIA_VS_NORMOXIA_MYELOID_DC_DN
Systematic name | M8065
Organism | Homo sapiens
PMID | 21148811
Authors | Bosco MC,Pierobon D,Blengio F,Raggi F,Vanni C,Gattorno M,Eva A,Novelli F,Cappello P,Giovarelli M,Varesio L
Category | C7
Sub-category |
Brief description | Genes down-regulated in myeloid dendritic cells: hypoxia versus normoxia.
Full description | Dendritic cells (DCs) are professional antigen-presenting cells whose activity is intrinsically linked to the microenvironment. Hypoxia is a condition of low oxygen tension occurring in inflammatory tissues that creates a special microenvironment conditioning cell physiology. We studied the effects of hypoxia on the differentiation of human monocytes into DCs and maturation into mature DCs. Mature DCs were differentiated in vitro from human monocytes under normoxic or hypoxic conditions and the gene expression profile was determined.

Standard name | GSE22282_HYPOXIA_VS_NORMOXIA_MYELOID_DC_UP
Systematic name | M8068
Organism | Homo sapiens
PMID | 21148811
Authors | Bosco MC,Pierobon D,Blengio F,Raggi F,Vanni C,Gattorno M,Eva A,Novelli F,Cappello P,Giovarelli M,Varesio L
Category | C7
Sub-category |
Brief description | Genes up-regulated in myeloid dendritic cells: hypoxia versus normoxia.
Full description | Dendritic cells (DCs) are professional antigen-presenting cells whose activity is intrinsically linked to the microenvironment. Hypoxia is a condition of low oxygen tension occurring in inflammatory tissues that creates a special microenvironment conditioning cell physiology. We studied the effects of hypoxia on the differentiation of human monocytes into DCs and maturation into mature DCs. Mature DCs were differentiated in vitro from human monocytes under normoxic or hypoxic conditions and the gene expression profile was determined.

Standard name | GSE25085_FETAL_LIVER_VS_ADULT_BM_SP4_THYMIC_IMPLANT_DN
Systematic name | M8069
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic implants from fetal liver versus those from adult bone marrow.
Full description | Human fetal and adult hematopoietic stem cells (HSC) were obtained from fetal liver, fetal bone marrow (BM), and adult BM. These were injected into human fetal thymic implants in SCID-hu Thy/Liv mice (4-6 separate mice per HSC donor) and allowed to mature into single positive CD4+ (SP4) thymocytes over the course of 7-8 weeks. SP4 thymocytes from injected stem cells were subsequently sort-purified from thymic implants and gene expression was performed.

Standard name | GSE25085_FETAL_BM_VS_ADULT_BM_SP4_THYMIC_IMPLANT_DN
Systematic name | M8070
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic implants from fetal versus those from adult bone marrow.
Full description | Human fetal and adult hematopoietic stem cells (HSC) were obtained from fetal liver, fetal bone marrow (BM), and adult BM. These were injected into human fetal thymic implants in SCID-hu Thy/Liv mice (4-6 separate mice per HSC donor) and allowed to mature into single positive CD4+ (SP4) thymocytes over the course of 7-8 weeks. SP4 thymocytes from injected stem cells were subsequently sort-purified from thymic implants and gene expression was performed.

Standard name | GSE25085_FETAL_LIVER_VS_ADULT_BM_SP4_THYMIC_IMPLANT_UP
Systematic name | M8072
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic implants from fetal liver versus those from adult bone marrow.
Full description | Human fetal and adult hematopoietic stem cells (HSC) were obtained from fetal liver, fetal bone marrow (BM), and adult BM. These were injected into human fetal thymic implants in SCID-hu Thy/Liv mice (4-6 separate mice per HSC donor) and allowed to mature into single positive CD4+ (SP4) thymocytes over the course of 7-8 weeks. SP4 thymocytes from injected stem cells were subsequently sort-purified from thymic implants and gene expression was performed.

Standard name | GSE25085_FETAL_BM_VS_ADULT_BM_SP4_THYMIC_IMPLANT_UP
Systematic name | M8073
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic implants from fetal versus those from adult bone marrow.
Full description | Human fetal and adult hematopoietic stem cells (HSC) were obtained from fetal liver, fetal bone marrow (BM), and adult BM. These were injected into human fetal thymic implants in SCID-hu Thy/Liv mice (4-6 separate mice per HSC donor) and allowed to mature into single positive CD4+ (SP4) thymocytes over the course of 7-8 weeks. SP4 thymocytes from injected stem cells were subsequently sort-purified from thymic implants and gene expression was performed.

Standard name | GSE25085_FETAL_LIVER_VS_FETAL_BM_SP4_THYMIC_IMPLANT_UP
Systematic name | M8075
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic implants from fetal liver versus those from fetal bone marrow.
Full description | Human fetal and adult hematopoietic stem cells (HSC) were obtained from fetal liver, fetal bone marrow (BM), and adult BM. These were injected into human fetal thymic implants in SCID-hu Thy/Liv mice (4-6 separate mice per HSC donor) and allowed to mature into single positive CD4+ (SP4) thymocytes over the course of 7-8 weeks. SP4 thymocytes from injected stem cells were subsequently sort-purified from thymic implants and gene expression was performed.

Standard name | GSE25085_FETAL_LIVER_VS_FETAL_BM_SP4_THYMIC_IMPLANT_DN
Systematic name | M8076
Organism | Homo sapiens
PMID | 21164017
Authors | Mold JE,Venkatasubrahmanyam S,Burt TD,Michaëlsson J,Rivera JM,Galkina SA,Weinberg K,Stoddart CA,McCune JM
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic implants from fetal liver versus those from fetal bone marrow.
Full description | Human fetal and adult hematopoietic stem cells (HSC) were obtained from fetal liver, fetal bone marrow (BM), and adult BM. These were injected into human fetal thymic implants in SCID-hu Thy/Liv mice (4-6 separate mice per HSC donor) and allowed to mature into single positive CD4+ (SP4) thymocytes over the course of 7-8 weeks. SP4 thymocytes from injected stem cells were subsequently sort-purified from thymic implants and gene expression was performed.

STANDARD_NAME="GSE23398_WT_VS_IL2_KO_CD4_TCELL_SCURFY_MOUSE_DN" SYSTEMATIC_NAME="M8079" HISTORICAL_NAME="" ORGANISM="Mus musculus" PMID="21169543" AUTHORS="Sharma R,Sharma PR,Kim YC,Leitinger N,Lee JK,Fu SM,Ju ST" GEOID="GSE23398" EXACT_SOURCE="GSE23398_3081_200_DN" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes down-regulated in lymph node CD4 [GeneID=920] T cells: scurfy (non-functional form of FOXP3 [GeneID=50943]) versus scurfy and IL2 [GeneID=3558] knockout." DESCRIPTION_FULL="The goal of the study was to identify the genes which are regulated by Interleukin-2 in the CD4+ T cells of the scurfy mice during regulatory T-cell deficiency. Scurfy (Sf) mice bear a mutation in the forkhead box P3 (Foxp3) transcription factor, lack regulatory T-cells (Treg), develop multi-organ inflammation, and die prematurely. The major target organs affected are skin, lungs, and liver. Sf mice lacking the Il2 gene (Sf.Il2-/-), despite devoid of Treg, did not develop skin and lung inflammation, but the inflammation in liver, pancreas, submandibular gland and colon remained. Genome-wide microarray analysis revealed hundreds of genes were differentially regulated among Sf, Sf.Il2-/-, and B6 CD4+ T-cells but the most changes were those encoding receptors for trafficking/chemotaxis/retention and lymphokines. Our study suggests that IL-2 controls the skin and lung inflammation in Sf mice in an apparent \organ-specific\ manner through two novel mechanisms: by regulating the expression of genes encoding receptors for T-cell trafficking/chemotaxis/retention and by regulating Th2 cell expansion and lymphokine production. Thus, IL-2 is a master regulator for multi-organ inflammation and an underlying etiological factor for various diseases associated with skin and lung inflammation. Methods: CD4+ T cells were purified by Fluorescence Assisted Cell Sorting from the peripheral lymph nodes of (A) three individual Scurfy (Sf; B6.Cg-Foxp3sf/J) male mice, (B) three individual Sf.Il2-/- male mice (Scurfy mice carrying a null Interleukin (IL)-2 gene (B6.129P2-Il2tm1Hor/J)) and (C) a pooled sample of lymph nodes from two B6 (C57BL/6J) mice. All the mice were 3 weeks old. Total RNA was prepared using RNeasy mini kit (Qiagen). RNA samples were converted to cRNA, labeled and hybridized to Affymetrix Mouse 430_2 chips (Mouse Genome 430 2.0 Array, Affymetrix, Santa Clara, CA) at the University of Virginia DNA Sciences Core Facility." STANDARD_NAME="GSE23398_WT_VS_IL2_KO_CD4_TCELL_SCURFY_MOUSE_UP" SYSTEMATIC_NAME="M8080" HISTORICAL_NAME="" ORGANISM="Mus musculus" PMID="21169543" AUTHORS="Sharma R,Sharma PR,Kim YC,Leitinger N,Lee JK,Fu SM,Ju ST" GEOID="GSE23398" EXACT_SOURCE="GSE23398_3081_200_UP" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="" CHIP="HUMAN_GENE_SYMBOL" CATEGORY_CODE="C7" SUB_CATEGORY_CODE="" CONTRIBUTOR="Jernej Godec" CONTRIBUTOR_ORG="Dana-Farber Cancer Institute" DESCRIPTION_BRIEF="Genes up-regulated in lymph node CD4 [GeneID=920] T cells: scurfy (non-functional form of FOXP3 [GeneID=50943]) versus scurfy and IL2 [GeneID=3558] knockout." DESCRIPTION_FULL="The goal of the study was to identify the genes which are regulated by Interleukin-2 in the CD4+ T cells of the scurfy mice during regulatory T-cell deficiency. Scurfy (Sf) mice bear a mutation in the forkhead box P3 (Foxp3) transcription factor, lack regulatory T-cells (Treg), develop multi-organ inflammation, and die prematurely. The major target organs affected are skin, lungs, and liver. Sf mice lacking the Il2 gene (Sf.Il2-/-), despite devoid of Treg, did not develop skin and lung inflammation, but the inflammation in liver, pancreas, submandibular gland and colon remained. Genome-wide microarray analysis revealed hundreds of genes were differentially regulated among Sf, Sf.Il2-/-, and B6 CD4+ T-cells but the most changes were those encoding receptors for trafficking/chemotaxis/retention and lymphokines. Our study suggests that IL-2 controls the skin and lung inflammation in Sf mice in an apparent \organ-specific\ manner through two novel mechanisms: by regulating the expression of genes encoding receptors for T-cell trafficking/chemotaxis/retention and by regulating Th2 cell expansion and lymphokine production. Thus, IL-2 is a master regulator for multi-organ inflammation and an underlying etiological factor for various diseases associated with skin and lung inflammation. Methods: CD4+ T cells were purified by Fluorescence Assisted Cell Sorting from the peripheral lymph nodes of (A) three individual Scurfy (Sf; B6.Cg-Foxp3sf/J) male mice, (B) three individual Sf.Il2-/- male mice (Scurfy mice carrying a null Interleukin (IL)-2 gene (B6.129P2-Il2tm1Hor/J)) and (C) a pooled sample of lymph nodes from two B6 (C57BL/6J) mice. All the mice were 3 weeks old. Total RNA was prepared using RNeasy mini kit (Qiagen). RNA samples were converted to cRNA, labeled and hybridized to Affymetrix Mouse 430_2 chips (Mouse Genome 430 2.0 Array, Affymetrix, Santa Clara, CA) at the University of Virginia DNA Sciences Core Facility."

Standard name | GSE23502_BM_VS_COLON_TUMOR_HDC_KO_MYELOID_DERIVED_SUPPRESSOR_CELL_DN
Systematic name | M8081
Organism | Mus musculus
PMID | 21170045
Authors | Yang XD,Ai W,Asfaha S,Bhagat G,Friedman RA,Jin G,Park H,Shykind B,Diacovo TG,Falus A,Wang TC
Category | C7
Sub-category |
Brief description | Genes down-regulated in myeloid-derived suppressor cells with HDC [GeneID=3067] knockout: bone marrow versus colon tumor.
Full description | Differentially expressed genes of CD11b+Gr-1+ immature myeloid cells (IMCs) in the bone marrow and colonic tumor setting of histidine decarboxylase (HDC)-KO mice were examined by microarray (Affymetrix Mouse 430.2 array). Myeloid differentiation-related candidate genes were sought to be isolated and functionally studied.

Standard name | GSE23502_BM_VS_COLON_TUMOR_HDC_KO_MYELOID_DERIVED_SUPPRESSOR_CELL_UP
Systematic name | M8082
Organism | Mus musculus
PMID | 21170045
Authors | Yang XD,Ai W,Asfaha S,Bhagat G,Friedman RA,Jin G,Park H,Shykind B,Diacovo TG,Falus A,Wang TC
Category | C7
Sub-category |
Brief description | Genes up-regulated in myeloid-derived suppressor cells with HDC [GeneID=3067] knockout: bone marrow versus colon tumor.
Full description | Differentially expressed genes of CD11b+Gr-1+ immature myeloid cells (IMCs) in the bone marrow and colonic tumor setting of histidine decarboxylase (HDC)-KO mice were examined by microarray (Affymetrix Mouse 430.2 array). Myeloid differentiation-related candidate genes were sought to be isolated and functionally studied.

Standard name | GSE23502_WT_VS_HDC_KO_MYELOID_DERIVED_SUPPRESSOR_CELL_COLON_TUMOR_UP
Systematic name | M8085
Organism | Mus musculus
PMID | 21170045
Authors | Yang XD,Ai W,Asfaha S,Bhagat G,Friedman RA,Jin G,Park H,Shykind B,Diacovo TG,Falus A,Wang TC
Category | C7
Sub-category |
Brief description | Genes up-regulated in myeloid-derived suppressor cells from colon tumors: wildtype versus HDC [GeneID=3067] knockout.
Full description | Differentially expressed genes of CD11b+Gr-1+ immature myeloid cells (IMCs) in the bone marrow and colonic tumor setting of histidine decarboxylase (HDC)-KO mice were examined by microarray (Affymetrix Mouse 430.2 array). Myeloid differentiation-related candidate genes were sought to be isolated and functionally studied.

Standard name | GSE23502_WT_VS_HDC_KO_MYELOID_DERIVED_SUPPRESSOR_CELL_COLON_TUMOR_DN
Systematic name | M8086
Organism | Mus musculus
PMID | 21170045
Authors | Yang XD,Ai W,Asfaha S,Bhagat G,Friedman RA,Jin G,Park H,Shykind B,Diacovo TG,Falus A,Wang TC
Category | C7
Sub-category |
Brief description | Genes down-regulated in myeloid-derived suppressor cells from colon tumors: wildtype versus HDC [GeneID=3067] knockout.
Full description | Differentially expressed genes of CD11b+Gr-1+ immature myeloid cells (IMCs) in the bone marrow and colonic tumor setting of histidine decarboxylase (HDC)-KO mice were examined by microarray (Affymetrix Mouse 430.2 array). Myeloid differentiation-related candidate genes were sought to be isolated and functionally studied.

Standard name | GSE23502_BM_VS_COLON_TUMOR_MYELOID_DERIVED_SUPPRESSOR_CELL_UP
Systematic name | M8087
Organism | Mus musculus
PMID | 21170045
Authors | Yang XD,Ai W,Asfaha S,Bhagat G,Friedman RA,Jin G,Park H,Shykind B,Diacovo TG,Falus A,Wang TC
Category | C7
Sub-category |
Brief description | Genes up-regulated in myeloid-derived suppressor cells: bone marrow versus colon tumor.
Full description | Differentially expressed genes of CD11b+Gr-1+ immature myeloid cells (IMCs) in the bone marrow and colonic tumor setting of histidine decarboxylase (HDC)-KO mice were examined by microarray (Affymetrix Mouse 430.2 array). Myeloid differentiation-related candidate genes were sought to be isolated and functionally studied.

Standard name | GSE23502_BM_VS_COLON_TUMOR_MYELOID_DERIVED_SUPPRESSOR_CELL_DN
Systematic name | M8088
Organism | Mus musculus
PMID | 21170045
Authors | Yang XD,Ai W,Asfaha S,Bhagat G,Friedman RA,Jin G,Park H,Shykind B,Diacovo TG,Falus A,Wang TC
Category | C7
Sub-category |
Brief description | Genes down-regulated in myeloid-derived suppressor cells: bone marrow versus colon tumor.
Full description | Differentially expressed genes of CD11b+Gr-1+ immature myeloid cells (IMCs) in the bone marrow and colonic tumor setting of histidine decarboxylase (HDC)-KO mice were examined by microarray (Affymetrix Mouse 430.2 array). Myeloid differentiation-related candidate genes were sought to be isolated and functionally studied.

Standard name | GSE23502_WT_VS_HDC_KO_MYELOID_DERIVED_SUPPRESSOR_CELL_BM_DN
Systematic name | M8089
Organism | Mus musculus
PMID | 21170045
Authors | Yang XD,Ai W,Asfaha S,Bhagat G,Friedman RA,Jin G,Park H,Shykind B,Diacovo TG,Falus A,Wang TC
Category | C7
Sub-category |
Brief description | Genes down-regulated in myeloid-derived suppressor cells from bone marrow: wildtype versus HDC [GeneID=3067] knockout.
Full description | Differentially expressed genes of CD11b+Gr-1+ immature myeloid cells (IMCs) in the bone marrow and colonic tumor setting of histidine decarboxylase (HDC)-KO mice were examined by microarray (Affymetrix Mouse 430.2 array). Myeloid differentiation-related candidate genes were sought to be isolated and functionally studied.

Standard name | GSE23502_WT_VS_HDC_KO_MYELOID_DERIVED_SUPPRESSOR_CELL_BM_UP
Systematic name | M8090
Organism | Mus musculus
PMID | 21170045
Authors | Yang XD,Ai W,Asfaha S,Bhagat G,Friedman RA,Jin G,Park H,Shykind B,Diacovo TG,Falus A,Wang TC
Category | C7
Sub-category |
Brief description | Genes up-regulated in myeloid-derived suppressor cells from bone marrow: wildtype versus HDC [GeneID=3067] knockout.
Full description | Differentially expressed genes of CD11b+Gr-1+ immature myeloid cells (IMCs) in the bone marrow and colonic tumor setting of histidine decarboxylase (HDC)-KO mice were examined by microarray (Affymetrix Mouse 430.2 array). Myeloid differentiation-related candidate genes were sought to be isolated and functionally studied.

Standard name | GSE24972_WT_VS_IRF8_KO_SPLEEN_FOLLICULAR_BCELL_UP
Systematic name | M8092
Organism | Mus musculus
PMID | 21178004
Authors | Feng J,Wang H,Shin DM,Masiuk M,Qi CF,Morse HC
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen follicular B lymphocytes: wildtype versus IRF8 [GeneID=3394] knockout.
Full description | Conditional IRF8 KO mice (mice with a conditional allele of Irf8 crossed with CD19-Cre mice) showed increased numbers of both Gene expression data spleen marginal zone (MZ) and Gene expression data spleen follicular (FO) B cells compared to control mice. To evaluate gene expression patterns that distinguished FO or MZ B cells derived from conditional KO and control mice, we used Affymetrix GeneChip® Mouse gene 1.0 ST Array.

Standard name | GSE24972_MARGINAL_ZONE_BCELL_VS_FOLLICULAR_BCELL_IRF8_KO_DN
Systematic name | M8093
Organism | Mus musculus
PMID | 21178004
Authors | Feng J,Wang H,Shin DM,Masiuk M,Qi CF,Morse HC
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen B lymphocytes with IRF8 [GeneID=3394] knockout: marginal zone versus follicular.
Full description | Conditional IRF8 KO mice (mice with a conditional allele of Irf8 crossed with CD19-Cre mice) showed increased numbers of both Gene expression data spleen marginal zone (MZ) and Gene expression data spleen follicular (FO) B cells compared to control mice. To evaluate gene expression patterns that distinguished FO or MZ B cells derived from conditional KO and control mice, we used Affymetrix GeneChip® Mouse gene 1.0 ST Array.

Standard name | GSE24972_WT_VS_IRF8_KO_MARGINAL_ZONE_SPLEEN_BCELL_DN
Systematic name | M8094
Organism | Mus musculus
PMID | 21178004
Authors | Feng J,Wang H,Shin DM,Masiuk M,Qi CF,Morse HC
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen marginal zone B lymphocytes: wildtype versus IRF8 [GeneID=3394] knockout.
Full description | Conditional IRF8 KO mice (mice with a conditional allele of Irf8 crossed with CD19-Cre mice) showed increased numbers of both Gene expression data spleen marginal zone (MZ) and Gene expression data spleen follicular (FO) B cells compared to control mice. To evaluate gene expression patterns that distinguished FO or MZ B cells derived from conditional KO and control mice, we used Affymetrix GeneChip® Mouse gene 1.0 ST Array.

Standard name | GSE24972_MARGINAL_ZONE_BCELL_VS_FOLLICULAR_BCELL_DN
Systematic name | M8095
Organism | Mus musculus
PMID | 21178004
Authors | Feng J,Wang H,Shin DM,Masiuk M,Qi CF,Morse HC
Category | C7
Sub-category |
Brief description | Genes down-regulated in speen B lymphocytes: marginal zone versus follicular.
Full description | Conditional IRF8 KO mice (mice with a conditional allele of Irf8 crossed with CD19-Cre mice) showed increased numbers of both Gene expression data spleen marginal zone (MZ) and Gene expression data spleen follicular (FO) B cells compared to control mice. To evaluate gene expression patterns that distinguished FO or MZ B cells derived from conditional KO and control mice, we used Affymetrix GeneChip® Mouse gene 1.0 ST Array.

Standard name | GSE24972_WT_VS_IRF8_KO_SPLEEN_FOLLICULAR_BCELL_DN
Systematic name | M8096
Organism | Mus musculus
PMID | 21178004
Authors | Feng J,Wang H,Shin DM,Masiuk M,Qi CF,Morse HC
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen follicular B lymphocytes: wildtype versus IRF8 [GeneID=3394] knockout.
Full description | Conditional IRF8 KO mice (mice with a conditional allele of Irf8 crossed with CD19-Cre mice) showed increased numbers of both Gene expression data spleen marginal zone (MZ) and Gene expression data spleen follicular (FO) B cells compared to control mice. To evaluate gene expression patterns that distinguished FO or MZ B cells derived from conditional KO and control mice, we used Affymetrix GeneChip® Mouse gene 1.0 ST Array.

Standard name | GSE24972_WT_VS_IRF8_KO_MARGINAL_ZONE_SPLEEN_BCELL_UP
Systematic name | M8097
Organism | Mus musculus
PMID | 21178004
Authors | Feng J,Wang H,Shin DM,Masiuk M,Qi CF,Morse HC
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen marginal zone B lymphocytes: wildtype versus IRF8 [GeneID=3394] knockout.
Full description | Conditional IRF8 KO mice (mice with a conditional allele of Irf8 crossed with CD19-Cre mice) showed increased numbers of both Gene expression data spleen marginal zone (MZ) and Gene expression data spleen follicular (FO) B cells compared to control mice. To evaluate gene expression patterns that distinguished FO or MZ B cells derived from conditional KO and control mice, we used Affymetrix GeneChip® Mouse gene 1.0 ST Array.

Standard name | GSE24972_MARGINAL_ZONE_BCELL_VS_FOLLICULAR_BCELL_UP
Systematic name | M8098
Organism | Mus musculus
PMID | 21178004
Authors | Feng J,Wang H,Shin DM,Masiuk M,Qi CF,Morse HC
Category | C7
Sub-category |
Brief description | Genes up-regulated in speen B lymphocytes: marginal zone versus follicular.
Full description | Conditional IRF8 KO mice (mice with a conditional allele of Irf8 crossed with CD19-Cre mice) showed increased numbers of both Gene expression data spleen marginal zone (MZ) and Gene expression data spleen follicular (FO) B cells compared to control mice. To evaluate gene expression patterns that distinguished FO or MZ B cells derived from conditional KO and control mice, we used Affymetrix GeneChip® Mouse gene 1.0 ST Array.

Standard name | GSE24972_MARGINAL_ZONE_BCELL_VS_FOLLICULAR_BCELL_IRF8_KO_UP
Systematic name | M8099
Organism | Mus musculus
PMID | 21178004
Authors | Feng J,Wang H,Shin DM,Masiuk M,Qi CF,Morse HC
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen B lymphocytes with IRF8 [GeneID=3394] knockout: marginal zone versus follicular.
Full description | Conditional IRF8 KO mice (mice with a conditional allele of Irf8 crossed with CD19-Cre mice) showed increased numbers of both Gene expression data spleen marginal zone (MZ) and Gene expression data spleen follicular (FO) B cells compared to control mice. To evaluate gene expression patterns that distinguished FO or MZ B cells derived from conditional KO and control mice, we used Affymetrix GeneChip® Mouse gene 1.0 ST Array.

Standard name | GSE19941_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_NFKBP50_KO_MACROPHAGE_DN
Systematic name | M8100
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes down-regulated in NFKB1 and IL10 [GeneID=4790;3586] knockout macrophages stimulated by LPS versus those also stimulated by IL10 [GeneID=3586].
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_IL10_KO_VS_IL10_KO_AND_NFKBP50_KO_LPS_STIM_MACROPHAGE_DN
Systematic name | M8102
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages stimulated by LPS: IL10 [GeneID=3586] knockout versus IL10 and NFKB1 [GeneID=3586;4790] knockout.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_UNSTIM_VS_LPS_STIM_IL10_KO_NFKBP50_KO_MACROPHAGE_UP
Systematic name | M8103
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes up-regulated in unstimulated IL10 [GeneID=3586] knockout macrophages versus NFKB1 and IL10 [GeneID=4790;3586] knockout macrophages stimulated by LPS.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_UNSTIM_VS_LPS_STIM_IL10_KO_MACROPHAGE_UP
Systematic name | M8105
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes up-regulated in IL10 [GeneID=3586] knockout macrophages: unstimulated versus LPS.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_UNSTIM_VS_LPS_STIM_IL10_KO_MACROPHAGE_DN
Systematic name | M8106
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes down-regulated in IL10 [GeneID=3586] knockout macrophages: unstimulated versus LPS.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_UNSTIM_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_UP
Systematic name | M8107
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes up-regulated in IL10 [GeneID=3586] knockout macrophages: unstimulated versus stimulated by IL10 [GeneID=3586] and LPS.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_UNSTIM_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_DN
Systematic name | M8109
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes down-regulated in IL10 [GeneID=3586] knockout macrophages: unstimulated versus stimulated by IL10 [GeneID=3586] and LPS.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_IL10_KO_VS_IL10_KO_AND_NFKBP50_KO_UNSTIM_MACROPHAGE_DN
Systematic name | M8110
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes down-regulated in unstimulated macrophages: IL10 [GeneID=3586] knockout versus NFKB1 [GeneID=4790] knockout.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_UNSTIM_VS_LPS_STIM_IL10_KO_NFKBP50_KO_MACROPHAGE_DN
Systematic name | M8111
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes down-regulated in unstimulated IL10 [GeneID=3586] knockout macrophages versus NFKB1 and IL10 [GeneID=4790;3586] knockout macrophages stimulated by LPS.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_IL10_KO_VS_IL10_KO_AND_NFKBP50_KO_UNSTIM_MACROPHAGE_UP
Systematic name | M8112
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes up-regulated in unstimulated macrophages: IL10 [GeneID=3586] knockout versus NFKB1 [GeneID=4790] knockout.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_UNSTIM_VS_LPS_AND_IL10_STIM_IL10_KO_NFKBP50_KO_MACROPHAGE_DN
Systematic name | M8113
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes down-regulated in IL10 and NFKB1 [GeneID=4790;3586] knockout macrophages: unstimulated versus stimulated by IL10 [GeneID=3586] and LPS.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_IL10_KO_VS_IL10_KO_AND_NFKBP50_KO_LPS_AND_IL10_STIM_MACROPHAGE_UP
Systematic name | M8115
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes up-regulated in IL10 [GeneID=3586] knockout macrophages stimulated by IL10 [GeneID=3586] versus NFKB1 [GeneID=4790] knockout macrophages stimulated by IL10 [GeneID=3586] and LPS.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_IL10_KO_VS_IL10_KO_AND_NFKBP50_KO_LPS_STIM_MACROPHAGE_UP
Systematic name | M8117
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages stimulated by LPS: IL10 [GeneID=3586] knockout versus IL10 and NFKB1 [GeneID=3586;4790] knockout.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_NFKBP50_KO_MACROPHAGE_UP
Systematic name | M8119
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes up-regulated in NFKB1 and IL10 [GeneID=4790;3586] knockout macrophages stimulated by LPS versus those also stimulated by IL10 [GeneID=3586].
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_UNSTIM_VS_LPS_AND_IL10_STIM_IL10_KO_NFKBP50_KO_MACROPHAGE_UP
Systematic name | M8120
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes up-regulated in IL10 and NFKB1 [GeneID=4790;3586] knockout macrophages: unstimulated versus stimulated by IL10 [GeneID=3586] and LPS.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_IL10_KO_VS_IL10_KO_AND_NFKBP50_KO_LPS_AND_IL10_STIM_MACROPHAGE_DN
Systematic name | M8121
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes down-regulated in IL10 [GeneID=3586] knockout macrophages stimulated by IL10 [GeneID=3586] versus NFKB1 [GeneID=4790] knockout macrophages stimulated by IL10 [GeneID=3586] and LPS.
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_DN
Systematic name | M8125
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes down-regulated in IL10 [GeneID=3586] knockout macrophages stimulated by LPS versus those also stimulated by IL10 [GeneID=3586].
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE19941_LPS_VS_LPS_AND_IL10_STIM_IL10_KO_MACROPHAGE_UP
Systematic name | M8126
Organism | Mus musculus
PMID | 21217011
Authors | Yang HT,Wang Y,Zhao X,Demissie E,Papoutsopoulou S,Mambole A,O'Garra A,Tomczak MF,Erdman SE,Fox JG,Ley SC,Horwitz BH
Category | C7
Sub-category |
Brief description | Genes up-regulated in IL10 [GeneID=3586] knockout macrophages stimulated by LPS versus those also stimulated by IL10 [GeneID=3586].
Full description | Bone marrow-derived macrophages were produced from mice lacking IL-10 alone (IL10-def) or mice lacking both IL-10 and the p50/p105 subunit of NF-kB (p50/IL10), and left unstimulated, stimulated with LPS (1 ng/ml) or stimulated with LPS and IL-10 (0.3 ng/ml).

Standard name | GSE25146_UNSTIM_VS_HELIOBACTER_PYLORI_LPS_STIM_AGS_CELL_UP
Systematic name | M8127
Organism | Homo sapiens
PMID | 21220698
Authors | Smith SM,Moran AP,Duggan SP,Ahmed SE,Mohamed AS,Windle HJ,O'Neill LA,Kelleher DP
Category | C7
Sub-category |
Brief description | Genes up-regulated in AGS cells (gastric adenocarcinoma): control versus H. pylori LPS.
Full description | This study set out to identify global changes in gene expression in AGS gastric epithelial cells following 8 hours stimulation with 10 μg/ml lipopolysaccharide (LPS) from the gastric pathogen H. pylori. Microarray analysis was used to compare changes in gene expression between cells treated with 10 μg/ml H. pylori LPS and untreated cells at the same time point.

Standard name | GSE25147_UNSTIM_VS_HELIOBACTER_PYLORI_LPS_STIM_MKN45_CELL_DN
Systematic name | M8128
Organism | Homo sapiens
PMID | 21220698
Authors | Smith SM,Moran AP,Duggan SP,Ahmed SE,Mohamed AS,Windle HJ,O'Neill LA,Kelleher DP
Category | C7
Sub-category |
Brief description | Genes down-regulated in MKN45 cells (stomach cancer): control versus H. pylori LPS.
Full description | This study set out to identify global changes in gene expression in MKN45 gastric epithelial cells following 8 hours stimulation with 10 μg/ml lipopolysaccharide (LPS) from the gastric pathogen H. pylori. Microarray analysis was used to compare changes in gene expression between cells treated with 10 μg/ml H. pylori LPS and untreated cells at the same time point.

Standard name | GSE25146_UNSTIM_VS_HELIOBACTER_PYLORI_LPS_STIM_AGS_CELL_DN
Systematic name | M8129
Organism | Homo sapiens
PMID | 21220698
Authors | Smith SM,Moran AP,Duggan SP,Ahmed SE,Mohamed AS,Windle HJ,O'Neill LA,Kelleher DP
Category | C7
Sub-category |
Brief description | Genes down-regulated in AGS cells (gastric adenocarcinoma): control versus H. pylori LPS.
Full description | This study set out to identify global changes in gene expression in AGS gastric epithelial cells following 8 hours stimulation with 10 μg/ml lipopolysaccharide (LPS) from the gastric pathogen H. pylori. Microarray analysis was used to compare changes in gene expression between cells treated with 10 μg/ml H. pylori LPS and untreated cells at the same time point.

Standard name | GSE25147_UNSTIM_VS_HELIOBACTER_PYLORI_LPS_STIM_MKN45_CELL_UP
Systematic name | M8130
Organism | Homo sapiens
PMID | 21220698
Authors | Smith SM,Moran AP,Duggan SP,Ahmed SE,Mohamed AS,Windle HJ,O'Neill LA,Kelleher DP
Category | C7
Sub-category |
Brief description | Genes up-regulated in MKN45 cells (stomach cancer): control versus H. pylori LPS.
Full description | This study set out to identify global changes in gene expression in MKN45 gastric epithelial cells following 8 hours stimulation with 10 μg/ml lipopolysaccharide (LPS) from the gastric pathogen H. pylori. Microarray analysis was used to compare changes in gene expression between cells treated with 10 μg/ml H. pylori LPS and untreated cells at the same time point.

Standard name | GSE22342_CD11C_HIGH_VS_LOW_DECIDUAL_MACROPHAGES_UP
Systematic name | M8131
Organism | Homo sapiens
PMID | 21257965
Authors | Houser BL,Tilburgs T,Hill J,Nicotra ML,Strominger JL
Category | C7
Sub-category |
Brief description | Genes up-regulated in decidual macrophages with ITGAX [GeneID=3687] high versus low.
Full description | Decidual macrophage populations, CD11cHI and CD11cLO cells were analyzed for expression profiles and unique characteristics. We used microarrays to detail the global program of gene expression and to determine differences between these two unique decidual macrophage populations.

Standard name | GSE22342_CD11C_HIGH_VS_LOW_DECIDUAL_MACROPHAGES_DN
Systematic name | M8132
Organism | Homo sapiens
PMID | 21257965
Authors | Houser BL,Tilburgs T,Hill J,Nicotra ML,Strominger JL
Category | C7
Sub-category |
Brief description | Genes down-regulated in decidual macrophages with ITGAX [GeneID=3687] high versus low.
Full description | Decidual macrophage populations, CD11cHI and CD11cLO cells were analyzed for expression profiles and unique characteristics. We used microarrays to detail the global program of gene expression and to determine differences between these two unique decidual macrophage populations.

Standard name | GSE26290_CTRL_VS_AKT_INHIBITOR_TREATED_ANTI_CD3_AND_IL2_STIM_CD8_TCELL_DN
Systematic name | M8133
Organism | Mus musculus
PMID | 21295499
Authors | Macintyre AN,Finlay D,Preston G,Sinclair LV,Waugh CM,Tamas P,Feijoo C,Okkenhaug K,Cantrell DA
Category | C7
Sub-category |
Brief description | Genes down-regulated in cytotoxic T cells: control versus treated with Akt inhibitor VIII [PubChem=10196499].
Full description | In cytotoxic T cells (CTL), Protein Kinase B /Akt is activated by the T cell antigen receptor (TCR) and the cytokine Interleukin 2 (IL2), in part by phosophorylation of Akt by Phospholipid dependent kinase 1 (PDK1). The role of PDK1 and Akt in CTL has however not been fully defined. In order to explore the relative roles of these kinases in CTL we used microarrays to profile the gene expression of control and PDK1 null CTL. In separate experiments we compared the gene expression profiles of control and Akt inhibitor treated CTL.

Standard name | GSE26290_WT_VS_PDK1_KO_ANTI_CD3_AND_IL2_STIM_CD8_TCELL_UP
Systematic name | M8134
Organism | Mus musculus
PMID | 21295499
Authors | Macintyre AN,Finlay D,Preston G,Sinclair LV,Waugh CM,Tamas P,Feijoo C,Okkenhaug K,Cantrell DA
Category | C7
Sub-category |
Brief description | Genes up-regulated in cytotoxic T cells: wildtype versus PDK1 [GeneID=5163] knockout.
Full description | In cytotoxic T cells (CTL), Protein Kinase B /Akt is activated by the T cell antigen receptor (TCR) and the cytokine Interleukin 2 (IL2), in part by phosophorylation of Akt by Phospholipid dependent kinase 1 (PDK1). The role of PDK1 and Akt in CTL has however not been fully defined. In order to explore the relative roles of these kinases in CTL we used microarrays to profile the gene expression of control and PDK1 null CTL. In separate experiments we compared the gene expression profiles of control and Akt inhibitor treated CTL.

Standard name | GSE26290_CTRL_VS_AKT_INHIBITOR_TREATED_ANTI_CD3_AND_IL2_STIM_CD8_TCELL_UP
Systematic name | M8135
Organism | Mus musculus
PMID | 21295499
Authors | Macintyre AN,Finlay D,Preston G,Sinclair LV,Waugh CM,Tamas P,Feijoo C,Okkenhaug K,Cantrell DA
Category | C7
Sub-category |
Brief description | Genes up-regulated in cytotoxic T cells: control versus treated with Akt inhibitor VIII [PubChem=10196499].
Full description | In cytotoxic T cells (CTL), Protein Kinase B /Akt is activated by the T cell antigen receptor (TCR) and the cytokine Interleukin 2 (IL2), in part by phosophorylation of Akt by Phospholipid dependent kinase 1 (PDK1). The role of PDK1 and Akt in CTL has however not been fully defined. In order to explore the relative roles of these kinases in CTL we used microarrays to profile the gene expression of control and PDK1 null CTL. In separate experiments we compared the gene expression profiles of control and Akt inhibitor treated CTL.

Standard name | GSE26290_WT_VS_PDK1_KO_ANTI_CD3_AND_IL2_STIM_CD8_TCELL_DN
Systematic name | M8136
Organism | Mus musculus
PMID | 21295499
Authors | Macintyre AN,Finlay D,Preston G,Sinclair LV,Waugh CM,Tamas P,Feijoo C,Okkenhaug K,Cantrell DA
Category | C7
Sub-category |
Brief description | Genes down-regulated in cytotoxic T cells: wildtype versus PDK1 [GeneID=5163] knockout.
Full description | In cytotoxic T cells (CTL), Protein Kinase B /Akt is activated by the T cell antigen receptor (TCR) and the cytokine Interleukin 2 (IL2), in part by phosophorylation of Akt by Phospholipid dependent kinase 1 (PDK1). The role of PDK1 and Akt in CTL has however not been fully defined. In order to explore the relative roles of these kinases in CTL we used microarrays to profile the gene expression of control and PDK1 null CTL. In separate experiments we compared the gene expression profiles of control and Akt inhibitor treated CTL.

Standard name | GSE25846_IL10_POS_VS_NEG_CD8_TCELL_DAY7_POST_CORONAVIRUS_BRAIN_UP
Systematic name | M8140
Organism | Mus musculus
PMID | 21317392
Authors | Trandem K,Zhao J,Fleming E,Perlman S
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: IL10+ [GeneID=3586] versus IL10- [GeneID=3586].
Full description | IL-10 is an anti-inflammatory cytokine that has been shown to be produced by antigen-specific CD8 T cells at the peak of viral encephalitis. We found that IL-10+CD8 T cells are more activated and cytolytic than IL-10-CD8 T cells. We used microarrays to detect gene expression changes in directly ex vivo sorted CNS IL-10+ and IL-10- CD8 T cells from a neurotropic J2.2-V-1-infected mouse.

Standard name | GSE25846_IL10_POS_VS_NEG_CD8_TCELL_DAY7_POST_CORONAVIRUS_BRAIN_DN
Systematic name | M8142
Organism | Mus musculus
PMID | 21317392
Authors | Trandem K,Zhao J,Fleming E,Perlman S
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: IL10+ [GeneID=3586] versus IL10- [GeneID=3586].
Full description | IL-10 is an anti-inflammatory cytokine that has been shown to be produced by antigen-specific CD8 T cells at the peak of viral encephalitis. We found that IL-10+CD8 T cells are more activated and cytolytic than IL-10-CD8 T cells. We used microarrays to detect gene expression changes in directly ex vivo sorted CNS IL-10+ and IL-10- CD8 T cells from a neurotropic J2.2-V-1-infected mouse.

Standard name | GSE26023_PHD3_KO_VS_WT_NEUTROPHIL_HYPOXIA_DN
Systematic name | M8143
Organism | Mus musculus
PMID | 21317538
Authors | Walmsley SR,Chilvers ER,Thompson AA,Vaughan K,Marriott HM,Parker LC,Shaw G,Parmar S,Schneider M,Sabroe I,Dockrell DH,Milo M,Taylor CT,Johnson RS,Pugh CW,Ratcliffe PJ,Maxwell PH,Carmeliet P,Whyte MK
Category | C7
Sub-category |
Brief description | Genes down-regulated in neutrophils under hypoxia: EGLN3 [GeneID=112399] knockout versus wildtype.
Full description | Neutrophils were isolated form peripheral blood of wildtype and Phd3 null mice, cultured for 4 hours in hypoxia (3% O2) and micro array analysis performed The aim of the present study is to identify the mechanism by which phd3 is required for the hypoxia mediated survival of neutrophils

Standard name | GSE26023_PHD3_KO_VS_WT_NEUTROPHIL_HYPOXIA_UP
Systematic name | M8146
Organism | Mus musculus
PMID | 21317538
Authors | Walmsley SR,Chilvers ER,Thompson AA,Vaughan K,Marriott HM,Parker LC,Shaw G,Parmar S,Schneider M,Sabroe I,Dockrell DH,Milo M,Taylor CT,Johnson RS,Pugh CW,Ratcliffe PJ,Maxwell PH,Carmeliet P,Whyte MK
Category | C7
Sub-category |
Brief description | Genes up-regulated in neutrophils under hypoxia: EGLN3 [GeneID=112399] knockout versus wildtype.
Full description | Neutrophils were isolated form peripheral blood of wildtype and Phd3 null mice, cultured for 4 hours in hypoxia (3% O2) and micro array analysis performed The aim of the present study is to identify the mechanism by which phd3 is required for the hypoxia mediated survival of neutrophils

Standard name | GSE22611_UNSTIM_VS_6H_MDP_STIM_NOD2_TRANSDUCED_HEK293T_CELL_UP
Systematic name | M8147
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells over-expressing wildtype NOD2 [GeneID=64127]: untreated versus muramyl dipeptide [PubChem=11620162] for 6h.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_MUTANT_NOD2_TRANSDUCED_VS_CTRL_HEK293T_STIMULATED_WITH_MDP_6H_DN
Systematic name | M8148
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells at 6h after stimulation by muramyl dipeptide [PubChem=11620162]: over-expressing mutant NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_UNSTIM_VS_2H_MDP_STIM_NOD2_TRANSDUCED_HEK293T_CELL_UP
Systematic name | M8151
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells over-expressing wildtype NOD2 [GeneID=64127]: untreated versus muramyl dipeptide [PubChem=11620162] for 2h.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_UNSTIM_VS_2H_MDP_STIM_NOD2_TRANSDUCED_HEK293T_CELL_DN
Systematic name | M8152
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells over-expressing wildtype NOD2 [GeneID=64127]: untreated versus muramyl dipeptide [PubChem=11620162] for 2h.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_MUTANT_NOD2_TRANSDUCED_VS_CTRL_HEK293T_STIMULATED_WITH_MDP_6H_UP
Systematic name | M8157
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells at 6h after stimulation by muramyl dipeptide [PubChem=11620162]: over-expressing mutant NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_UNSTIM_VS_2H_MDP_STIM_MUTANT_NOD2_TRANSDUCED_HEK293T_CELL_UP
Systematic name | M8158
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells expressing mutant NOD2 [GeneID=64127]: untreated versus muramyl dipeptide [PubChem=11620162] for 2h.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_NOD2_TRANSD_VS_CTRL_TRANSD_HEK293_MDP_STIM_6H_UP
Systematic name | M8159
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells at 6h after stimulation by muramyl dipeptide [PubChem=11620162]: over-expressing wildtype NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_NOD2_TRANSD_VS_CTRL_TRANSD_HEK293_MDP_STIM_6H_DN
Systematic name | M8160
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells at 6h after stimulation by muramyl dipeptide [PubChem=11620162]: over-expressing wildtype NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_NOD2_TRANSD_VS_CTRL_TRANSD_HEK293_MDP_STIM_2H_UP
Systematic name | M8161
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells at 2h after stimulation by muramyl dipeptide [PubChem=11620162]: over-expressing mutant NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_UNSTIM_VS_6H_MDP_STIM_MUTANT_NOD2_TRANSDUCED_HEK293T_CELL_UP
Systematic name | M8162
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells expressing mutant NOD2 [GeneID=64127]: untreated versus muramyl dipeptide [PubChem=11620162] for 6h.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_UNSTIM_VS_6H_MDP_STIM_MUTANT_NOD2_TRANSDUCED_HEK293T_CELL_DN
Systematic name | M8163
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells expressing mutant NOD2 [GeneID=64127]: untreated versus muramyl dipeptide [PubChem=11620162] for 6h.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_NOD2_VS_MUTANT_NOD2_TRANSDUCED_HEK293T_CELL_UP
Systematic name | M8164
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells expressing: wildtype NOD2 [GeneID=64127] versus mutant NOD2 [GeneID=64127].
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_NOD2_VS_MUTANT_NOD2_TRANSDUCED_HEK293T_CELL_DN
Systematic name | M8165
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells expressing: wildtype NOD2 [GeneID=64127] versus mutant NOD2 [GeneID=64127].
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_NOD2_VS_CTRL_TRANSDUCED_HEK293T_CELL_UP
Systematic name | M8166
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells: over-expressing wildtype NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_NOD2_VS_CTRL_TRANSDUCED_HEK293T_CELL_DN
Systematic name | M8169
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells: over-expressing wildtype NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_MUTANT_NOD2_VS_CTRL_TRANSDUCED_HEK293T_CELL_UP
Systematic name | M8170
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells: expressing mutant NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_MUTANT_NOD2_VS_CTRL_TRANSDUCED_HEK293T_CELL_DN
Systematic name | M8171
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells: expressing mutant NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_UNSTIM_VS_6H_MDP_STIM_NOD2_TRANSDUCED_HEK293T_CELL_DN
Systematic name | M8173
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells over-expressing wildtype NOD2 [GeneID=64127]: untreated versus muramyl dipeptide [PubChem=11620162] for 6h.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_NOD2_TRANSD_VS_CTRL_TRANSD_HEK293_MDP_STIM_2H_DN
Systematic name | M8174
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells at 2h after stimulation by muramyl dipeptide [PubChem=11620162]: over-expressing mutant NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_UNSTIM_VS_2H_MDP_STIM_MUTANT_NOD2_TRANSDUCED_HEK293T_CELL_DN
Systematic name | M8175
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells expressing mutant NOD2 [GeneID=64127]: untreated versus muramyl dipeptide [PubChem=11620162] for 2h.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_NOD2_TRANSDUCED_VS_CTRL_HEK293T_STIMULATED_WITH_MDP_2H_UP
Systematic name | M8177
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes up-regulated in HEK293 cells at 2h after stimulation by muramyl dipeptide [PubChem=11620162]: over-expressing wildtype NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE22611_NOD2_TRANSDUCED_VS_CTRL_HEK293T_STIMULATED_WITH_MDP_2H_DN
Systematic name | M8178
Organism | Homo sapiens
PMID | 21335489
Authors | Billmann-Born S,Till A,Arlt A,Lipinski S,Sina C,Latiano A,Annese V,Häsler R,Kerick M,Manke T,Seegert D,Hanidu A,Schäfer H,Heel van D,Li J,Schreiber S,Rosenstiel P
Category | C7
Sub-category |
Brief description | Genes down-regulated in HEK293 cells at 2h after stimulation by muramyl dipeptide [PubChem=11620162]: over-expressing wildtype NOD2 [GeneID=64127] versus control.
Full description | NOD2 is an intracellular receptor for the bacterial cell wall component muramyl dipeptide (MDP) and variants of NOD2 are associated with chronic inflammatory diseases of barrier organs e.g. Crohn disease, asthma and atopic eczema. It is known that activation of NOD2 induces a variety of inflammatory and antibacterial factors. The exact transcriptomal signatures that define the cellular programs downstream of NOD2 activation and the influence of the Crohn-associated variant L1007fsinsC are yet to be defined. To describe the MDP-induced activation program, we analyzed the transcriptomal reactions of isogenic HEK293 cells expressing NOD2wt or NOD2L1007fsinsC to stimulation with MDP. Importantly, a clear loss-of-function could be observed in the cells carrying the Crohn-associated variant L1007fsinsC, while the NOD2wt cells showed differential regulation of growth factors, chemokines and several antagonists of NF-κB, e.g. TNFAIP3 (A20) and IER3.

Standard name | GSE25677_MPL_VS_MPL_AND_R848_STIM_BCELL_DN
Systematic name | M8181
Organism | Mus musculus
PMID | 21350488
Authors | Kasturi SP,Skountzou I,Albrecht RA,Koutsonanos D,Hua T,Nakaya HI,Ravindran R,Stewart S,Alam M,Kwissa M,Villinger F,Murthy N,Steel J,Jacob J,Hogan RJ,García-Sastre A,Compans R,Pulendran B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes immunized with: monophosphoryl lipid A (MPL) versus MPL and imiquimod [PubChem=13982876].
Full description | Many successful vaccines induce persistent antibody responses that can last a lifetime. The mechanisms by which they do so remain unclear, but emerging evidence suggests that activate dendritic cells (DCs) via Toll-like receptors (TLRs). For example, the yellow fever vaccine YF-17D, one of the most successful empiric vaccines ever developed, activates DCs via multiple TLRs to stimulate pro-inflammatory cytokines. Triggering specific combinations of TLRs in DCs can induce synergistic production of cytokines, which results in enhanced T cell responses, but its impact on antibody responses remain unknown. Learning the critical parameters of innate immunity that programs such antibody responses remains a major challenge in vaccinology. We demonstrated that immunization of mice with synthetic nanoparticles containing antigens plus Toll-like receptor (TLR) ligands 4 (MPL) + 7 (R837) induces synergistic increases in antigen-specific, neutralizing antibodies compared to immunization with a single TLR ligand. To determine whether there was any early programming of B cells, we isolated isotype switched, TCRbeta-CD11b-CD19+IgD-IgG+ B cells by FACS at 7 days post immunization with nanoparticles containing various adjuvants plus OVA, and performed microarray analyses to assess their molecular signatures.

Standard name | GSE25677_R848_VS_MPL_AND_R848_STIM_BCELL_DN
Systematic name | M8182
Organism | Mus musculus
PMID | 21350488
Authors | Kasturi SP,Skountzou I,Albrecht RA,Koutsonanos D,Hua T,Nakaya HI,Ravindran R,Stewart S,Alam M,Kwissa M,Villinger F,Murthy N,Steel J,Jacob J,Hogan RJ,García-Sastre A,Compans R,Pulendran B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes immunized with: imiquimod [PubChem=13982876] versus monophosphoryl lipid A and imiquimod [PubChem=13982876].
Full description | Many successful vaccines induce persistent antibody responses that can last a lifetime. The mechanisms by which they do so remain unclear, but emerging evidence suggests that activate dendritic cells (DCs) via Toll-like receptors (TLRs). For example, the yellow fever vaccine YF-17D, one of the most successful empiric vaccines ever developed, activates DCs via multiple TLRs to stimulate pro-inflammatory cytokines. Triggering specific combinations of TLRs in DCs can induce synergistic production of cytokines, which results in enhanced T cell responses, but its impact on antibody responses remain unknown. Learning the critical parameters of innate immunity that programs such antibody responses remains a major challenge in vaccinology. We demonstrated that immunization of mice with synthetic nanoparticles containing antigens plus Toll-like receptor (TLR) ligands 4 (MPL) + 7 (R837) induces synergistic increases in antigen-specific, neutralizing antibodies compared to immunization with a single TLR ligand. To determine whether there was any early programming of B cells, we isolated isotype switched, TCRbeta-CD11b-CD19+IgD-IgG+ B cells by FACS at 7 days post immunization with nanoparticles containing various adjuvants plus OVA, and performed microarray analyses to assess their molecular signatures.

Standard name | GSE25677_MPL_VS_MPL_AND_R848_STIM_BCELL_UP
Systematic name | M8183
Organism | Mus musculus
PMID | 21350488
Authors | Kasturi SP,Skountzou I,Albrecht RA,Koutsonanos D,Hua T,Nakaya HI,Ravindran R,Stewart S,Alam M,Kwissa M,Villinger F,Murthy N,Steel J,Jacob J,Hogan RJ,García-Sastre A,Compans R,Pulendran B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes immunized with: monophosphoryl lipid A (MPL) versus MPL and imiquimod [PubChem=13982876].
Full description | Many successful vaccines induce persistent antibody responses that can last a lifetime. The mechanisms by which they do so remain unclear, but emerging evidence suggests that activate dendritic cells (DCs) via Toll-like receptors (TLRs). For example, the yellow fever vaccine YF-17D, one of the most successful empiric vaccines ever developed, activates DCs via multiple TLRs to stimulate pro-inflammatory cytokines. Triggering specific combinations of TLRs in DCs can induce synergistic production of cytokines, which results in enhanced T cell responses, but its impact on antibody responses remain unknown. Learning the critical parameters of innate immunity that programs such antibody responses remains a major challenge in vaccinology. We demonstrated that immunization of mice with synthetic nanoparticles containing antigens plus Toll-like receptor (TLR) ligands 4 (MPL) + 7 (R837) induces synergistic increases in antigen-specific, neutralizing antibodies compared to immunization with a single TLR ligand. To determine whether there was any early programming of B cells, we isolated isotype switched, TCRbeta-CD11b-CD19+IgD-IgG+ B cells by FACS at 7 days post immunization with nanoparticles containing various adjuvants plus OVA, and performed microarray analyses to assess their molecular signatures.

Standard name | GSE25677_R848_VS_MPL_AND_R848_STIM_BCELL_UP
Systematic name | M8185
Organism | Mus musculus
PMID | 21350488
Authors | Kasturi SP,Skountzou I,Albrecht RA,Koutsonanos D,Hua T,Nakaya HI,Ravindran R,Stewart S,Alam M,Kwissa M,Villinger F,Murthy N,Steel J,Jacob J,Hogan RJ,García-Sastre A,Compans R,Pulendran B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes immunized with: imiquimod [PubChem=13982876] versus monophosphoryl lipid A and imiquimod [PubChem=13982876].
Full description | Many successful vaccines induce persistent antibody responses that can last a lifetime. The mechanisms by which they do so remain unclear, but emerging evidence suggests that activate dendritic cells (DCs) via Toll-like receptors (TLRs). For example, the yellow fever vaccine YF-17D, one of the most successful empiric vaccines ever developed, activates DCs via multiple TLRs to stimulate pro-inflammatory cytokines. Triggering specific combinations of TLRs in DCs can induce synergistic production of cytokines, which results in enhanced T cell responses, but its impact on antibody responses remain unknown. Learning the critical parameters of innate immunity that programs such antibody responses remains a major challenge in vaccinology. We demonstrated that immunization of mice with synthetic nanoparticles containing antigens plus Toll-like receptor (TLR) ligands 4 (MPL) + 7 (R837) induces synergistic increases in antigen-specific, neutralizing antibodies compared to immunization with a single TLR ligand. To determine whether there was any early programming of B cells, we isolated isotype switched, TCRbeta-CD11b-CD19+IgD-IgG+ B cells by FACS at 7 days post immunization with nanoparticles containing various adjuvants plus OVA, and performed microarray analyses to assess their molecular signatures.

Standard name | GSE25677_MPL_VS_R848_STIM_BCELL_UP
Systematic name | M8186
Organism | Mus musculus
PMID | 21350488
Authors | Kasturi SP,Skountzou I,Albrecht RA,Koutsonanos D,Hua T,Nakaya HI,Ravindran R,Stewart S,Alam M,Kwissa M,Villinger F,Murthy N,Steel J,Jacob J,Hogan RJ,García-Sastre A,Compans R,Pulendran B
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes after immunization with: monophosphoryl lipid A versus imiquimod [PubChem=13982876].
Full description | Many successful vaccines induce persistent antibody responses that can last a lifetime. The mechanisms by which they do so remain unclear, but emerging evidence suggests that activate dendritic cells (DCs) via Toll-like receptors (TLRs). For example, the yellow fever vaccine YF-17D, one of the most successful empiric vaccines ever developed, activates DCs via multiple TLRs to stimulate pro-inflammatory cytokines. Triggering specific combinations of TLRs in DCs can induce synergistic production of cytokines, which results in enhanced T cell responses, but its impact on antibody responses remain unknown. Learning the critical parameters of innate immunity that programs such antibody responses remains a major challenge in vaccinology. We demonstrated that immunization of mice with synthetic nanoparticles containing antigens plus Toll-like receptor (TLR) ligands 4 (MPL) + 7 (R837) induces synergistic increases in antigen-specific, neutralizing antibodies compared to immunization with a single TLR ligand. To determine whether there was any early programming of B cells, we isolated isotype switched, TCRbeta-CD11b-CD19+IgD-IgG+ B cells by FACS at 7 days post immunization with nanoparticles containing various adjuvants plus OVA, and performed microarray analyses to assess their molecular signatures.

Standard name | GSE25677_MPL_VS_R848_STIM_BCELL_DN
Systematic name | M8187
Organism | Mus musculus
PMID | 21350488
Authors | Kasturi SP,Skountzou I,Albrecht RA,Koutsonanos D,Hua T,Nakaya HI,Ravindran R,Stewart S,Alam M,Kwissa M,Villinger F,Murthy N,Steel J,Jacob J,Hogan RJ,García-Sastre A,Compans R,Pulendran B
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes after immunization with: monophosphoryl lipid A versus imiquimod [PubChem=13982876].
Full description | Many successful vaccines induce persistent antibody responses that can last a lifetime. The mechanisms by which they do so remain unclear, but emerging evidence suggests that activate dendritic cells (DCs) via Toll-like receptors (TLRs). For example, the yellow fever vaccine YF-17D, one of the most successful empiric vaccines ever developed, activates DCs via multiple TLRs to stimulate pro-inflammatory cytokines. Triggering specific combinations of TLRs in DCs can induce synergistic production of cytokines, which results in enhanced T cell responses, but its impact on antibody responses remain unknown. Learning the critical parameters of innate immunity that programs such antibody responses remains a major challenge in vaccinology. We demonstrated that immunization of mice with synthetic nanoparticles containing antigens plus Toll-like receptor (TLR) ligands 4 (MPL) + 7 (R837) induces synergistic increases in antigen-specific, neutralizing antibodies compared to immunization with a single TLR ligand. To determine whether there was any early programming of B cells, we isolated isotype switched, TCRbeta-CD11b-CD19+IgD-IgG+ B cells by FACS at 7 days post immunization with nanoparticles containing various adjuvants plus OVA, and performed microarray analyses to assess their molecular signatures.

Standard name | GSE26488_WT_VS_VP16_TRANSGENIC_HDAC7_KO_DOUBLE_POSITIVE_THYMOCYTE_DN
Systematic name | M8188
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes: wildtype versus over-expressing HDAC7[GeneID=51564] fused with VP16.
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_CTRL_VS_PEPTIDE_INJECTION_OT2_THYMOCYTE_DN
Systematic name | M8189
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes from OT-2 transgenic mice: control versus injected with agonist peptide.
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_HDAC7_KO_VS_VP16_TRANSGENIC_HDAC7_KO_DOUBLE_POSITIVE_THYMOCYTE_UP
Systematic name | M8190
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes: HDAC7 [GeneID=51564] knockout versus over-expressing HDAC7 [GeneID=51564] fused with VP16.
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_CTRL_VS_PEPTIDE_INJECTION_OT2_THYMOCYTE_UP
Systematic name | M8193
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes from OT-2 transgenic mice: control versus injected with agonist peptide.
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_WT_VS_HDAC7_KO_DOUBLE_POSITIVE_THYMOCYTE_UP
Systematic name | M8194
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes: wildtype versus HDAC7 [GeneID=51563] knockout.
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_WT_VS_HDAC7_KO_DOUBLE_POSITIVE_THYMOCYTE_DN
Systematic name | M8195
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes: wildtype versus HDAC7 [GeneID=51563] knockout.
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_HDAC7_KO_VS_VP16_TRANSGENIC_HDAC7_KO_DOUBLE_POSITIVE_THYMOCYTE_DN
Systematic name | M8196
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocytes: HDAC7 [GeneID=51564] knockout versus over-expressing HDAC7 [GeneID=51564] fused with VP16.
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_WT_VS_HDAC7_DELTAP_TG_OT2_THYMOCYTE_WITH_PEPTIDE_INJECTION_DN
Systematic name | M8197
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes down-regulated in dobule positive thymocytefrom OT-2 transgenic mice injected with agonist peptide: wildtype versus expressing deltaP form of HDAC7 [GeneID=51564].
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_WT_VS_HDAC7_DELTAP_TG_OT2_THYMOCYTE_WITH_PEPTIDE_INJECTION_UP
Systematic name | M8198
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes up-regulated in dobule positive thymocytefrom OT-2 transgenic mice injected with agonist peptide: wildtype versus expressing deltaP form of HDAC7 [GeneID=51564].
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_CTRL_VS_PEPTIDE_INJECTION_HDAC7_DELTAP_TG_OT2_THYMOCYTE_DN
Systematic name | M8199
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes down-regulated in double positive thymocyte from OT-2 transgenic mice: control versus HDAC7 [GeneID=51564] deltaP form after injection with agonist peptide.
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_WT_VS_VP16_TRANSGENIC_HDAC7_KO_DOUBLE_POSITIVE_THYMOCYTE_UP
Systematic name | M8200
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocytes: wildtype versus over-expressing HDAC7[GeneID=51564] fused with VP16.
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE26488_CTRL_VS_PEPTIDE_INJECTION_HDAC7_DELTAP_TG_OT2_THYMOCYTE_UP
Systematic name | M8201
Organism | Mus musculus
PMID | 21398603
Authors | Kasler HG,Young BD,Mottet D,Lim HW,Collins AM,Olson EN,Verdin E
Category | C7
Sub-category |
Brief description | Genes up-regulated in double positive thymocyte from OT-2 transgenic mice: control versus HDAC7 [GeneID=51564] deltaP form after injection with agonist peptide.
Full description | Abstract of publicaton: CD4/CD8 double-positive (DP) thymocytes express the transcriptional repressor Histone Deacetylase 7 (HDAC7), a class IIa HDAC that is exported from the cell nucleus after T cell receptor (TCR) engagement. Through signal-dependent nuclear export, class IIa HDACs such as HDAC7 mediate signal-dependent changes in gene expression that are important to developmental fate decisions in multiple tissues. We report that HDAC7 is exported from the cell nucleus during positive selection in thymocytes, and regulates genes mediating the coupling between TCR engagement and downstream events that determine cell survival. Thymocytes lacking HDAC7 are inefficiently positively selected due to a severely shortened lifespan and exhibit a truncated repertoire of TCR Jalpha segments. The expression of multiple important mediators and modulators of the response to TCR engagement is altered in HDAC7-deficient thymocytes, resulting in increased tonic MAP kinase activity that contributes to the observed loss of viability. Remarkably, the activity of Protein Kinase D, the kinase that mediates nuclear export of HDAC7 in response to TCR signaling, is also increased in HDAC7-deficient thymocytes, suggesting that HDAC7 nuclear export governs a self-sustaining auto-excitatory loop. These experiments add to the understanding of the life/death decision in thymic T cell development, define a novel function for class IIa HDACs, and point to a novel feed-forward mechanism whereby these molecules regulate their own state and mediate stable developmental transitions. Title of manuscript: Nuclear Export of Histone Deacetylase 7 During Thymic Selection Mediates Immune Self-tolerance. abstract of manuscript: Histone Deacetylase 7 (HDAC7) is a TCR signal-dependent regulator of differentiation that is highly expressed in CD4/CD8 double-positive (DP) thymocytes. Here we examine the effect of blocking TCR-dependent nuclear export of HDAC7 during thymic selection, through expression of a signal-resistant mutant of HDAC7 (HDAC7-delta-P) in thymocytes. We find that HDAC7-delta-P Transgenic thymocytes exhibit a profound block in negative thymic selection, but can still undergo positive selection, resulting in the escape of autoreactive T cells into the periphery. Gene expression profiling reveals a comprehensive suppression of the negative selection-associated gene expression program in DP thymocytes, associated with a defect in the activation of MAP kinase pathways by TCR signals. The consequence of this block in vivo is a lethal autoimmune syndrome involving the exocrine pancreas and other abdominal organs. These experiments establish a novel molecular model of autoimmunity and cast new light on the relationship between thymic selection and immune self-tolerance. Goal of Microarray experiment: We did these experiments to determine how alteration of the function of HDAC7, a site-specific and signal-dependent repressor of transcription, changes gene expression in CD4/CD8 DP thymocytes.

Standard name | GSE27092_WT_VS_HDAC7_PHOSPHO_DEFICIENT_CD8_TCELL_UP
Systematic name | M8203
Organism | Mus musculus
PMID | 21399638
Authors | Navarro MN,Goebel J,Feijoo-Carnero C,Morrice N,Cantrell DA
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype cytotoxic T lymphocytes versus those overexpressing phosphorylation deficient form of HDAC7 [GeneID=51564].
Full description | The present study reports an unbiased analysis of the cytotoxic T cell serine-threonine phosphoproteome using high resolution mass spectrometry. Approximately 2,000 phosphorylations were identified in CTLs of which approximately 450 were controlled by TCR signaling. A significantly overrepresented group of molecules identified in the phosphoproteomic screen were transcription activators, co-repressors and chromatin regulators. A focus on the chromatin regulators revealed that CTLs have high expression of the histone deacetylase HDAC7 but continually phosphorylate and export this transcriptional repressor from the nucleus. HDAC7 dephosphorylation results in its nuclear accumulation and suppressed expression of genes encoding key cytokines, cytokine receptors and adhesion molecules that determine CTL function. The screening of the CTL phosphoproteome thus reveals intrinsic pathways of serine-threonine phosphorylation that target chromatin regulators in CTLs and determine the CTL functional program. We used Affymetrix microarray analysis to explore the molecular basis for the role of HDAC7 in CTLs and the impact of GFP-HDAC7 phosphorylation deficient mutant expression on the CTL transcriptional profile.

Standard name | GSE27092_WT_VS_HDAC7_PHOSPHO_DEFICIENT_CD8_TCELL_DN
Systematic name | M8204
Organism | Mus musculus
PMID | 21399638
Authors | Navarro MN,Goebel J,Feijoo-Carnero C,Morrice N,Cantrell DA
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype cytotoxic T lymphocytes versus those overexpressing phosphorylation deficient form of HDAC7 [GeneID=51564].
Full description | The present study reports an unbiased analysis of the cytotoxic T cell serine-threonine phosphoproteome using high resolution mass spectrometry. Approximately 2,000 phosphorylations were identified in CTLs of which approximately 450 were controlled by TCR signaling. A significantly overrepresented group of molecules identified in the phosphoproteomic screen were transcription activators, co-repressors and chromatin regulators. A focus on the chromatin regulators revealed that CTLs have high expression of the histone deacetylase HDAC7 but continually phosphorylate and export this transcriptional repressor from the nucleus. HDAC7 dephosphorylation results in its nuclear accumulation and suppressed expression of genes encoding key cytokines, cytokine receptors and adhesion molecules that determine CTL function. The screening of the CTL phosphoproteome thus reveals intrinsic pathways of serine-threonine phosphorylation that target chromatin regulators in CTLs and determine the CTL functional program. We used Affymetrix microarray analysis to explore the molecular basis for the role of HDAC7 in CTLs and the impact of GFP-HDAC7 phosphorylation deficient mutant expression on the CTL transcriptional profile.

Standard name | GSE26912_TUMORICIDAL_VS_CTRL_MACROPHAGE_UP
Systematic name | M8205
Organism | Mus musculus
PMID | 21407206
Authors | Haabeth OA,Lorvik KB,Hammarström C,Donaldson IM,Haraldsen G,Bogen B,Corthay A
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: tumoricidal versus control.
Full description | The immune system can both promote and suppress cancer. Chronic inflammation and proinflammatory cytokines such as interleukin (IL)-1 and IL-6 are considered tumor-promoting. In contrast, the exact nature of protective antitumor immunity remains obscure. In this study, we have quantified locally secreted cytokines during primary immune responses against myeloma and B-cell lymphoma in mice. Strikingly, successful cancer immunosurveillance mediated by tumor-specific CD4+ T cells was consistently associated with elevated local levels of both proinflammatory (IL-1aplha, IL-1beta, and IL-6) and T helper 1 (Th1)-associated cytokines (interferon-alpha, IL-2, IL-12). Cancer eradication was achieved by a collaboration between tumor-specific Th1 cells and tumor-infiltrating, antigen-presenting macrophages. Th1 cells induced secretion of IL-1-beta and IL-6 by macrophages. Th1-derived interferon-gamma was shown to render macrophages directly cytotoxic to cancer cells, and to induce macrophages to secrete the angiostatic chemokines CXCL9/MIG and CXCL10/IP-10. Thus, inflammation, when driven by tumor-specific Th1 cells, may prevent rather than promote cancer.

Standard name | GSE26912_TUMORICIDAL_VS_CTRL_MACROPHAGE_DN
Systematic name | M8206
Organism | Mus musculus
PMID | 21407206
Authors | Haabeth OA,Lorvik KB,Hammarström C,Donaldson IM,Haraldsen G,Bogen B,Corthay A
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: tumoricidal versus control.
Full description | The immune system can both promote and suppress cancer. Chronic inflammation and proinflammatory cytokines such as interleukin (IL)-1 and IL-6 are considered tumor-promoting. In contrast, the exact nature of protective antitumor immunity remains obscure. In this study, we have quantified locally secreted cytokines during primary immune responses against myeloma and B-cell lymphoma in mice. Strikingly, successful cancer immunosurveillance mediated by tumor-specific CD4+ T cells was consistently associated with elevated local levels of both proinflammatory (IL-1aplha, IL-1beta, and IL-6) and T helper 1 (Th1)-associated cytokines (interferon-alpha, IL-2, IL-12). Cancer eradication was achieved by a collaboration between tumor-specific Th1 cells and tumor-infiltrating, antigen-presenting macrophages. Th1 cells induced secretion of IL-1-beta and IL-6 by macrophages. Th1-derived interferon-gamma was shown to render macrophages directly cytotoxic to cancer cells, and to induce macrophages to secrete the angiostatic chemokines CXCL9/MIG and CXCL10/IP-10. Thus, inflammation, when driven by tumor-specific Th1 cells, may prevent rather than promote cancer.

Standard name | GSE27670_CTRL_VS_BLIMP1_TRANSDUCED_GC_BCELL_DN
Systematic name | M8208
Organism | Homo sapiens
PMID | 21411757
Authors | Vrzalikova K,Vockerodt M,Leonard S,Bell A,Wei W,Schrader A,Wright KL,Kube D,Rowe M,Woodman CB,Murray PG
Category | C7
Sub-category |
Brief description | Genes down-regulated in germinal center B lymphocytes: control versus over-expressing PRDM1 [GeneID=639].
Full description | In this study, we have investigated the effect of BLIMP1α on gene expression, cell differentiation and pathogenesis in normal human GC B cells using a non-viral vector based system

Standard name | GSE27670_BLIMP1_VS_LMP1_TRANSDUCED_GC_BCELL_UP
Systematic name | M8209
Organism | Homo sapiens
PMID | 21411757
Authors | Vrzalikova K,Vockerodt M,Leonard S,Bell A,Wei W,Schrader A,Wright KL,Kube D,Rowe M,Woodman CB,Murray PG
Category | C7
Sub-category |
Brief description | Genes up-regulated in germinal center B lymphocytes over-expressing: PRDM1 [GeneID=639] versus Epstein-Barr virus protein LMP1.
Full description | In this study, we have investigated the effect of BLIMP1α on gene expression, cell differentiation and pathogenesis in normal human GC B cells using a non-viral vector based system

Standard name | GSE27670_BLIMP1_VS_LMP1_TRANSDUCED_GC_BCELL_DN
Systematic name | M8211
Organism | Homo sapiens
PMID | 21411757
Authors | Vrzalikova K,Vockerodt M,Leonard S,Bell A,Wei W,Schrader A,Wright KL,Kube D,Rowe M,Woodman CB,Murray PG
Category | C7
Sub-category |
Brief description | Genes down-regulated in germinal center B lymphocytes over-expressing: PRDM1 [GeneID=639] versus Epstein-Barr virus protein LMP1.
Full description | In this study, we have investigated the effect of BLIMP1α on gene expression, cell differentiation and pathogenesis in normal human GC B cells using a non-viral vector based system

Standard name | GSE27670_CTRL_VS_BLIMP1_TRANSDUCED_GC_BCELL_UP
Systematic name | M8212
Organism | Homo sapiens
PMID | 21411757
Authors | Vrzalikova K,Vockerodt M,Leonard S,Bell A,Wei W,Schrader A,Wright KL,Kube D,Rowe M,Woodman CB,Murray PG
Category | C7
Sub-category |
Brief description | Genes up-regulated in germinal center B lymphocytes: control versus over-expressing PRDM1 [GeneID=639].
Full description | In this study, we have investigated the effect of BLIMP1α on gene expression, cell differentiation and pathogenesis in normal human GC B cells using a non-viral vector based system

Standard name | GSE27670_CTRL_VS_LMP1_TRANSDUCED_GC_BCELL_UP
Systematic name | M8216
Organism | Homo sapiens
PMID | 21411757
Authors | Vrzalikova K,Vockerodt M,Leonard S,Bell A,Wei W,Schrader A,Wright KL,Kube D,Rowe M,Woodman CB,Murray PG
Category | C7
Sub-category |
Brief description | Genes up-regulated in germinal center B lymphocytes: control versus over-expressing Epstein-Barr virus protein LMP1.
Full description | In this study, we have investigated the effect of BLIMP1α on gene expression, cell differentiation and pathogenesis in normal human GC B cells using a non-viral vector based system

Standard name | GSE27670_CTRL_VS_LMP1_TRANSDUCED_GC_BCELL_DN
Systematic name | M8217
Organism | Homo sapiens
PMID | 21411757
Authors | Vrzalikova K,Vockerodt M,Leonard S,Bell A,Wei W,Schrader A,Wright KL,Kube D,Rowe M,Woodman CB,Murray PG
Category | C7
Sub-category |
Brief description | Genes down-regulated in germinal center B lymphocytes: control versus over-expressing Epstein-Barr virus protein LMP1.
Full description | In this study, we have investigated the effect of BLIMP1α on gene expression, cell differentiation and pathogenesis in normal human GC B cells using a non-viral vector based system

Standard name | GSE22443_IL2_VS_IL12_TREATED_ACT_CD8_TCELL_DN
Systematic name | M8218
Organism | Mus musculus
PMID | 21430221
Authors | Lisiero DN,Soto H,Liau LM,Prins RM
Category | C7
Sub-category |
Brief description | Genes down-regulated in Pmel-1 CD8 T cells primed with cognate antigen: IL2 [GeneID=3558] versus IL-12.
Full description | The expansion, trafficking and functional effectiveness of adoptively transferred CD8+ T-cells play a critical role in mediating effective anti-tumor immunity. However, the mechanisms which program the highly proliferative and functional state of CD8+ T-cells are not completely understood. We hypothesized that IL-12, a cytokine commonly induced by TLR activation, could enhance T-cell priming by altering responsiveness to antigen and cytokines. Priming of tumor specific CD8+ T-cells in the presence of IL-12 induced the acquisition of a 'polyfunctional' effector response and increased the generation of memory cells. Moreover, IL-12 priming also promoted high levels of the IL-2 receptor alpha-chain (CD25) and robust IL-2 mediated activation of STAT5. This sensitivity to IL-2 translated into enhanced in vivo proliferation of adoptively transferred CD8+ T-cells. Furthermore, real-time, in vivo imaging of T-cell trafficking confirmed the ability of IL-12 priming to drive in vivo proliferation. IL-12 priming enhanced the anti-tumor function of adoptively transferred cells by reducing established subcutaneous tumor burden, and significantly increasing survival in an established intracranial tumor model. Finally, IL-12 priming of human PBMCs generates tumor specific T-cells phenotypically and functionally similar to IL-12 primed Pmel-1 T-cells. These results highlight IL-12 as an important mediator of CD8+ T-cell effector function and anti-tumor immunity.

Standard name | GSE22443_NAIVE_VS_ACT_AND_IL2_TREATED_CD8_TCELL_DN
Systematic name | M8220
Organism | Mus musculus
PMID | 21430221
Authors | Lisiero DN,Soto H,Liau LM,Prins RM
Category | C7
Sub-category |
Brief description | Genes down-regulated in Pmel-1 CD8 T cells: naïve versus primed with cognate antigen (gp100) and IL2 [GeneID=3558].
Full description | The expansion, trafficking and functional effectiveness of adoptively transferred CD8+ T-cells play a critical role in mediating effective anti-tumor immunity. However, the mechanisms which program the highly proliferative and functional state of CD8+ T-cells are not completely understood. We hypothesized that IL-12, a cytokine commonly induced by TLR activation, could enhance T-cell priming by altering responsiveness to antigen and cytokines. Priming of tumor specific CD8+ T-cells in the presence of IL-12 induced the acquisition of a 'polyfunctional' effector response and increased the generation of memory cells. Moreover, IL-12 priming also promoted high levels of the IL-2 receptor alpha-chain (CD25) and robust IL-2 mediated activation of STAT5. This sensitivity to IL-2 translated into enhanced in vivo proliferation of adoptively transferred CD8+ T-cells. Furthermore, real-time, in vivo imaging of T-cell trafficking confirmed the ability of IL-12 priming to drive in vivo proliferation. IL-12 priming enhanced the anti-tumor function of adoptively transferred cells by reducing established subcutaneous tumor burden, and significantly increasing survival in an established intracranial tumor model. Finally, IL-12 priming of human PBMCs generates tumor specific T-cells phenotypically and functionally similar to IL-12 primed Pmel-1 T-cells. These results highlight IL-12 as an important mediator of CD8+ T-cell effector function and anti-tumor immunity.

Standard name | GSE22443_NAIVE_VS_ACT_AND_IL12_TREATED_CD8_TCELL_UP
Systematic name | M8221
Organism | Mus musculus
PMID | 21430221
Authors | Lisiero DN,Soto H,Liau LM,Prins RM
Category | C7
Sub-category |
Brief description | Genes up-regulated in Pmel-1 CD8 T cells: naïve versus primed with cognate antigen (gp100) and IL-12.
Full description | The expansion, trafficking and functional effectiveness of adoptively transferred CD8+ T-cells play a critical role in mediating effective anti-tumor immunity. However, the mechanisms which program the highly proliferative and functional state of CD8+ T-cells are not completely understood. We hypothesized that IL-12, a cytokine commonly induced by TLR activation, could enhance T-cell priming by altering responsiveness to antigen and cytokines. Priming of tumor specific CD8+ T-cells in the presence of IL-12 induced the acquisition of a 'polyfunctional' effector response and increased the generation of memory cells. Moreover, IL-12 priming also promoted high levels of the IL-2 receptor alpha-chain (CD25) and robust IL-2 mediated activation of STAT5. This sensitivity to IL-2 translated into enhanced in vivo proliferation of adoptively transferred CD8+ T-cells. Furthermore, real-time, in vivo imaging of T-cell trafficking confirmed the ability of IL-12 priming to drive in vivo proliferation. IL-12 priming enhanced the anti-tumor function of adoptively transferred cells by reducing established subcutaneous tumor burden, and significantly increasing survival in an established intracranial tumor model. Finally, IL-12 priming of human PBMCs generates tumor specific T-cells phenotypically and functionally similar to IL-12 primed Pmel-1 T-cells. These results highlight IL-12 as an important mediator of CD8+ T-cell effector function and anti-tumor immunity.

Standard name | GSE22443_NAIVE_VS_ACT_AND_IL2_TREATED_CD8_TCELL_UP
Systematic name | M8222
Organism | Mus musculus
PMID | 21430221
Authors | Lisiero DN,Soto H,Liau LM,Prins RM
Category | C7
Sub-category |
Brief description | Genes up-regulated in Pmel-1 CD8 T cells: naïve versus primed with cognate antigen (gp100) and IL2 [GeneID=3558].
Full description | The expansion, trafficking and functional effectiveness of adoptively transferred CD8+ T-cells play a critical role in mediating effective anti-tumor immunity. However, the mechanisms which program the highly proliferative and functional state of CD8+ T-cells are not completely understood. We hypothesized that IL-12, a cytokine commonly induced by TLR activation, could enhance T-cell priming by altering responsiveness to antigen and cytokines. Priming of tumor specific CD8+ T-cells in the presence of IL-12 induced the acquisition of a 'polyfunctional' effector response and increased the generation of memory cells. Moreover, IL-12 priming also promoted high levels of the IL-2 receptor alpha-chain (CD25) and robust IL-2 mediated activation of STAT5. This sensitivity to IL-2 translated into enhanced in vivo proliferation of adoptively transferred CD8+ T-cells. Furthermore, real-time, in vivo imaging of T-cell trafficking confirmed the ability of IL-12 priming to drive in vivo proliferation. IL-12 priming enhanced the anti-tumor function of adoptively transferred cells by reducing established subcutaneous tumor burden, and significantly increasing survival in an established intracranial tumor model. Finally, IL-12 priming of human PBMCs generates tumor specific T-cells phenotypically and functionally similar to IL-12 primed Pmel-1 T-cells. These results highlight IL-12 as an important mediator of CD8+ T-cell effector function and anti-tumor immunity.

Standard name | GSE22443_IL2_VS_IL12_TREATED_ACT_CD8_TCELL_UP
Systematic name | M8223
Organism | Mus musculus
PMID | 21430221
Authors | Lisiero DN,Soto H,Liau LM,Prins RM
Category | C7
Sub-category |
Brief description | Genes up-regulated in Pmel-1 CD8 T cells primed with cognate antigen: IL2 [GeneID=3558] versus IL-12.
Full description | The expansion, trafficking and functional effectiveness of adoptively transferred CD8+ T-cells play a critical role in mediating effective anti-tumor immunity. However, the mechanisms which program the highly proliferative and functional state of CD8+ T-cells are not completely understood. We hypothesized that IL-12, a cytokine commonly induced by TLR activation, could enhance T-cell priming by altering responsiveness to antigen and cytokines. Priming of tumor specific CD8+ T-cells in the presence of IL-12 induced the acquisition of a 'polyfunctional' effector response and increased the generation of memory cells. Moreover, IL-12 priming also promoted high levels of the IL-2 receptor alpha-chain (CD25) and robust IL-2 mediated activation of STAT5. This sensitivity to IL-2 translated into enhanced in vivo proliferation of adoptively transferred CD8+ T-cells. Furthermore, real-time, in vivo imaging of T-cell trafficking confirmed the ability of IL-12 priming to drive in vivo proliferation. IL-12 priming enhanced the anti-tumor function of adoptively transferred cells by reducing established subcutaneous tumor burden, and significantly increasing survival in an established intracranial tumor model. Finally, IL-12 priming of human PBMCs generates tumor specific T-cells phenotypically and functionally similar to IL-12 primed Pmel-1 T-cells. These results highlight IL-12 as an important mediator of CD8+ T-cell effector function and anti-tumor immunity.

Standard name | GSE22443_NAIVE_VS_ACT_AND_IL12_TREATED_CD8_TCELL_DN
Systematic name | M8225
Organism | Mus musculus
PMID | 21430221
Authors | Lisiero DN,Soto H,Liau LM,Prins RM
Category | C7
Sub-category |
Brief description | Genes down-regulated in Pmel-1 CD8 T cells: naïve versus primed with cognate antigen (gp100) and IL-12.
Full description | The expansion, trafficking and functional effectiveness of adoptively transferred CD8+ T-cells play a critical role in mediating effective anti-tumor immunity. However, the mechanisms which program the highly proliferative and functional state of CD8+ T-cells are not completely understood. We hypothesized that IL-12, a cytokine commonly induced by TLR activation, could enhance T-cell priming by altering responsiveness to antigen and cytokines. Priming of tumor specific CD8+ T-cells in the presence of IL-12 induced the acquisition of a 'polyfunctional' effector response and increased the generation of memory cells. Moreover, IL-12 priming also promoted high levels of the IL-2 receptor alpha-chain (CD25) and robust IL-2 mediated activation of STAT5. This sensitivity to IL-2 translated into enhanced in vivo proliferation of adoptively transferred CD8+ T-cells. Furthermore, real-time, in vivo imaging of T-cell trafficking confirmed the ability of IL-12 priming to drive in vivo proliferation. IL-12 priming enhanced the anti-tumor function of adoptively transferred cells by reducing established subcutaneous tumor burden, and significantly increasing survival in an established intracranial tumor model. Finally, IL-12 priming of human PBMCs generates tumor specific T-cells phenotypically and functionally similar to IL-12 primed Pmel-1 T-cells. These results highlight IL-12 as an important mediator of CD8+ T-cell effector function and anti-tumor immunity.

Standard name | GSE27241_CTRL_VS_DIGOXIN_TREATED_RORGT_KO_CD4_TCELL_IN_TH17_POLARIZING_CONDITIONS_UP
Systematic name | M8226
Organism | Mus musculus
PMID | 21441909
Authors | Huh JR,Leung MW,Huang P,Ryan DA,Krout MR,Malapaka RR,Chow J,Manel N,Ciofani M,Kim SV,Cuesta A,Santori FR,Lafaille JJ,Xu HE,Gin DY,Rastinejad F,Littman DR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polarizing CD4 [GeneID=920] Th17 cells: wildtype untreated versus RORC [GeneID=6097] knockout treated by digoxin [PubChem=2724385].
Full description | CD4+ T helper lymphocytes that express interleukin-17 (Th17 cells) have critical roles in mouse models of autoimmunity, and there is mounting evidence that they also influence inflammatory processes in humans. Genome-wide association studies in humans have linked genes involved in Th17 cell differentiation and function with susceptibility to Crohn’s disease, rheumatoid arthritis, and psoriasis1-3. Thus, the pathway towards differentiation of Th17 cells and, perhaps, of related innate lymphoid cells with similar effector functions4, 5, is an attractive target for therapeutic applications. Mouse and human Th17 cells are distinguished by expression of the retinoic acid receptor-related orphan nuclear receptor RORγt, which is required for induction of IL-17 transcription and for the manifestation of Th17-dependent autoimmune disease in mice6. By performing a chemical screen with an insect cell-based reporter system, we identified the cardiac glycoside digoxin as a specific inhibitor of RORγt transcriptional activity. Digoxin inhibited murine Th17 cell differentiation without affecting differentiation of other T cell lineages and was effective in delaying the onset and reducing the severity of autoimmune disease in mice. At high concentrations, digoxin is toxic for human cells, but non-toxic synthetic derivatives, 20,22-dihydrodigoxin-21,23-diol (Dig(dhd)) and digoxin-21-salicylidene (Dig(sal)), specifically inhibited induction of IL-17 in human CD4+ T cells. Using these small molecule compounds, we demonstrated that RORγt is imporant for the maintenance of IL-17 expression in mouse and human effector T cells. These data suggest that derivatives of digoxin can be used as chemical probes for development of RORγt-targeted therapeutic agents that attenuate inflammatory lymphocyte function and autoimmune disease.

Standard name | GSE27241_CTRL_VS_DIGOXIN_TREATED_CD4_TCELL_IN_TH17_POLARIZING_CONDITIONS_DN
Systematic name | M8227
Organism | Mus musculus
PMID | 21441909
Authors | Huh JR,Leung MW,Huang P,Ryan DA,Krout MR,Malapaka RR,Chow J,Manel N,Ciofani M,Kim SV,Cuesta A,Santori FR,Lafaille JJ,Xu HE,Gin DY,Rastinejad F,Littman DR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polarizing CD4 [GeneID=920] Th17 cells: untreated versus digoxin [PubChem=2724385].
Full description | CD4+ T helper lymphocytes that express interleukin-17 (Th17 cells) have critical roles in mouse models of autoimmunity, and there is mounting evidence that they also influence inflammatory processes in humans. Genome-wide association studies in humans have linked genes involved in Th17 cell differentiation and function with susceptibility to Crohn’s disease, rheumatoid arthritis, and psoriasis1-3. Thus, the pathway towards differentiation of Th17 cells and, perhaps, of related innate lymphoid cells with similar effector functions4, 5, is an attractive target for therapeutic applications. Mouse and human Th17 cells are distinguished by expression of the retinoic acid receptor-related orphan nuclear receptor RORγt, which is required for induction of IL-17 transcription and for the manifestation of Th17-dependent autoimmune disease in mice6. By performing a chemical screen with an insect cell-based reporter system, we identified the cardiac glycoside digoxin as a specific inhibitor of RORγt transcriptional activity. Digoxin inhibited murine Th17 cell differentiation without affecting differentiation of other T cell lineages and was effective in delaying the onset and reducing the severity of autoimmune disease in mice. At high concentrations, digoxin is toxic for human cells, but non-toxic synthetic derivatives, 20,22-dihydrodigoxin-21,23-diol (Dig(dhd)) and digoxin-21-salicylidene (Dig(sal)), specifically inhibited induction of IL-17 in human CD4+ T cells. Using these small molecule compounds, we demonstrated that RORγt is imporant for the maintenance of IL-17 expression in mouse and human effector T cells. These data suggest that derivatives of digoxin can be used as chemical probes for development of RORγt-targeted therapeutic agents that attenuate inflammatory lymphocyte function and autoimmune disease.

Standard name | GSE27241_WT_VS_RORGT_KO_TH17_POLARIZED_CD4_TCELL_TREATED_WITH_DIGOXIN_DN
Systematic name | M8233
Organism | Mus musculus
PMID | 21441909
Authors | Huh JR,Leung MW,Huang P,Ryan DA,Krout MR,Malapaka RR,Chow J,Manel N,Ciofani M,Kim SV,Cuesta A,Santori FR,Lafaille JJ,Xu HE,Gin DY,Rastinejad F,Littman DR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polarizing CD4 [GeneID=920] Th17 cells treated by digoxin [PubChem=2724385]: wildtype versus RORC [GeneID=6097] knockout.
Full description | CD4+ T helper lymphocytes that express interleukin-17 (Th17 cells) have critical roles in mouse models of autoimmunity, and there is mounting evidence that they also influence inflammatory processes in humans. Genome-wide association studies in humans have linked genes involved in Th17 cell differentiation and function with susceptibility to Crohn’s disease, rheumatoid arthritis, and psoriasis1-3. Thus, the pathway towards differentiation of Th17 cells and, perhaps, of related innate lymphoid cells with similar effector functions4, 5, is an attractive target for therapeutic applications. Mouse and human Th17 cells are distinguished by expression of the retinoic acid receptor-related orphan nuclear receptor RORγt, which is required for induction of IL-17 transcription and for the manifestation of Th17-dependent autoimmune disease in mice6. By performing a chemical screen with an insect cell-based reporter system, we identified the cardiac glycoside digoxin as a specific inhibitor of RORγt transcriptional activity. Digoxin inhibited murine Th17 cell differentiation without affecting differentiation of other T cell lineages and was effective in delaying the onset and reducing the severity of autoimmune disease in mice. At high concentrations, digoxin is toxic for human cells, but non-toxic synthetic derivatives, 20,22-dihydrodigoxin-21,23-diol (Dig(dhd)) and digoxin-21-salicylidene (Dig(sal)), specifically inhibited induction of IL-17 in human CD4+ T cells. Using these small molecule compounds, we demonstrated that RORγt is imporant for the maintenance of IL-17 expression in mouse and human effector T cells. These data suggest that derivatives of digoxin can be used as chemical probes for development of RORγt-targeted therapeutic agents that attenuate inflammatory lymphocyte function and autoimmune disease.

Standard name | GSE27241_WT_CTRL_VS_DIGOXIN_TREATED_RORGT_KO_CD4_TCELL_IN_TH17_POLARIZING_CONDITIONS_UP
Systematic name | M8234
Organism | Mus musculus
PMID | 21441909
Authors | Huh JR,Leung MW,Huang P,Ryan DA,Krout MR,Malapaka RR,Chow J,Manel N,Ciofani M,Kim SV,Cuesta A,Santori FR,Lafaille JJ,Xu HE,Gin DY,Rastinejad F,Littman DR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polarizing CD4 [GeneID=920] Th17 cells: wildtype vs RORC [GeneID=6097] knockout treated with digoxin [PubChem=2724385].
Full description | CD4+ T helper lymphocytes that express interleukin-17 (Th17 cells) have critical roles in mouse models of autoimmunity, and there is mounting evidence that they also influence inflammatory processes in humans. Genome-wide association studies in humans have linked genes involved in Th17 cell differentiation and function with susceptibility to Crohn’s disease, rheumatoid arthritis, and psoriasis1-3. Thus, the pathway towards differentiation of Th17 cells and, perhaps, of related innate lymphoid cells with similar effector functions4, 5, is an attractive target for therapeutic applications. Mouse and human Th17 cells are distinguished by expression of the retinoic acid receptor-related orphan nuclear receptor RORγt, which is required for induction of IL-17 transcription and for the manifestation of Th17-dependent autoimmune disease in mice6. By performing a chemical screen with an insect cell-based reporter system, we identified the cardiac glycoside digoxin as a specific inhibitor of RORγt transcriptional activity. Digoxin inhibited murine Th17 cell differentiation without affecting differentiation of other T cell lineages and was effective in delaying the onset and reducing the severity of autoimmune disease in mice. At high concentrations, digoxin is toxic for human cells, but non-toxic synthetic derivatives, 20,22-dihydrodigoxin-21,23-diol (Dig(dhd)) and digoxin-21-salicylidene (Dig(sal)), specifically inhibited induction of IL-17 in human CD4+ T cells. Using these small molecule compounds, we demonstrated that RORγt is imporant for the maintenance of IL-17 expression in mouse and human effector T cells. These data suggest that derivatives of digoxin can be used as chemical probes for development of RORγt-targeted therapeutic agents that attenuate inflammatory lymphocyte function and autoimmune disease.

Standard name | GSE27241_WT_VS_RORGT_KO_TH17_POLARIZED_CD4_TCELL_UP
Systematic name | M8235
Organism | Mus musculus
PMID | 21441909
Authors | Huh JR,Leung MW,Huang P,Ryan DA,Krout MR,Malapaka RR,Chow J,Manel N,Ciofani M,Kim SV,Cuesta A,Santori FR,Lafaille JJ,Xu HE,Gin DY,Rastinejad F,Littman DR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polarizing CD4 [GeneID=920] Th17 cells: wildtype versus RORC [GeneID=6097] knockout.
Full description | CD4+ T helper lymphocytes that express interleukin-17 (Th17 cells) have critical roles in mouse models of autoimmunity, and there is mounting evidence that they also influence inflammatory processes in humans. Genome-wide association studies in humans have linked genes involved in Th17 cell differentiation and function with susceptibility to Crohn’s disease, rheumatoid arthritis, and psoriasis1-3. Thus, the pathway towards differentiation of Th17 cells and, perhaps, of related innate lymphoid cells with similar effector functions4, 5, is an attractive target for therapeutic applications. Mouse and human Th17 cells are distinguished by expression of the retinoic acid receptor-related orphan nuclear receptor RORγt, which is required for induction of IL-17 transcription and for the manifestation of Th17-dependent autoimmune disease in mice6. By performing a chemical screen with an insect cell-based reporter system, we identified the cardiac glycoside digoxin as a specific inhibitor of RORγt transcriptional activity. Digoxin inhibited murine Th17 cell differentiation without affecting differentiation of other T cell lineages and was effective in delaying the onset and reducing the severity of autoimmune disease in mice. At high concentrations, digoxin is toxic for human cells, but non-toxic synthetic derivatives, 20,22-dihydrodigoxin-21,23-diol (Dig(dhd)) and digoxin-21-salicylidene (Dig(sal)), specifically inhibited induction of IL-17 in human CD4+ T cells. Using these small molecule compounds, we demonstrated that RORγt is imporant for the maintenance of IL-17 expression in mouse and human effector T cells. These data suggest that derivatives of digoxin can be used as chemical probes for development of RORγt-targeted therapeutic agents that attenuate inflammatory lymphocyte function and autoimmune disease.

Standard name | GSE27241_CTRL_VS_DIGOXIN_TREATED_RORGT_KO_CD4_TCELL_IN_TH17_POLARIZING_CONDITIONS_DN
Systematic name | M8238
Organism | Mus musculus
PMID | 21441909
Authors | Huh JR,Leung MW,Huang P,Ryan DA,Krout MR,Malapaka RR,Chow J,Manel N,Ciofani M,Kim SV,Cuesta A,Santori FR,Lafaille JJ,Xu HE,Gin DY,Rastinejad F,Littman DR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polarizing CD4 [GeneID=920] Th17 cells: wildtype untreated versus RORC [GeneID=6097] knockout treated by digoxin [PubChem=2724385].
Full description | CD4+ T helper lymphocytes that express interleukin-17 (Th17 cells) have critical roles in mouse models of autoimmunity, and there is mounting evidence that they also influence inflammatory processes in humans. Genome-wide association studies in humans have linked genes involved in Th17 cell differentiation and function with susceptibility to Crohn’s disease, rheumatoid arthritis, and psoriasis1-3. Thus, the pathway towards differentiation of Th17 cells and, perhaps, of related innate lymphoid cells with similar effector functions4, 5, is an attractive target for therapeutic applications. Mouse and human Th17 cells are distinguished by expression of the retinoic acid receptor-related orphan nuclear receptor RORγt, which is required for induction of IL-17 transcription and for the manifestation of Th17-dependent autoimmune disease in mice6. By performing a chemical screen with an insect cell-based reporter system, we identified the cardiac glycoside digoxin as a specific inhibitor of RORγt transcriptional activity. Digoxin inhibited murine Th17 cell differentiation without affecting differentiation of other T cell lineages and was effective in delaying the onset and reducing the severity of autoimmune disease in mice. At high concentrations, digoxin is toxic for human cells, but non-toxic synthetic derivatives, 20,22-dihydrodigoxin-21,23-diol (Dig(dhd)) and digoxin-21-salicylidene (Dig(sal)), specifically inhibited induction of IL-17 in human CD4+ T cells. Using these small molecule compounds, we demonstrated that RORγt is imporant for the maintenance of IL-17 expression in mouse and human effector T cells. These data suggest that derivatives of digoxin can be used as chemical probes for development of RORγt-targeted therapeutic agents that attenuate inflammatory lymphocyte function and autoimmune disease.

Standard name | GSE27241_WT_VS_RORGT_KO_TH17_POLARIZED_CD4_TCELL_TREATED_WITH_DIGOXIN_UP
Systematic name | M8239
Organism | Mus musculus
PMID | 21441909
Authors | Huh JR,Leung MW,Huang P,Ryan DA,Krout MR,Malapaka RR,Chow J,Manel N,Ciofani M,Kim SV,Cuesta A,Santori FR,Lafaille JJ,Xu HE,Gin DY,Rastinejad F,Littman DR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polarizing CD4 [GeneID=920] Th17 cells treated by digoxin [PubChem=2724385]: wildtype versus RORC [GeneID=6097] knockout.
Full description | CD4+ T helper lymphocytes that express interleukin-17 (Th17 cells) have critical roles in mouse models of autoimmunity, and there is mounting evidence that they also influence inflammatory processes in humans. Genome-wide association studies in humans have linked genes involved in Th17 cell differentiation and function with susceptibility to Crohn’s disease, rheumatoid arthritis, and psoriasis1-3. Thus, the pathway towards differentiation of Th17 cells and, perhaps, of related innate lymphoid cells with similar effector functions4, 5, is an attractive target for therapeutic applications. Mouse and human Th17 cells are distinguished by expression of the retinoic acid receptor-related orphan nuclear receptor RORγt, which is required for induction of IL-17 transcription and for the manifestation of Th17-dependent autoimmune disease in mice6. By performing a chemical screen with an insect cell-based reporter system, we identified the cardiac glycoside digoxin as a specific inhibitor of RORγt transcriptional activity. Digoxin inhibited murine Th17 cell differentiation without affecting differentiation of other T cell lineages and was effective in delaying the onset and reducing the severity of autoimmune disease in mice. At high concentrations, digoxin is toxic for human cells, but non-toxic synthetic derivatives, 20,22-dihydrodigoxin-21,23-diol (Dig(dhd)) and digoxin-21-salicylidene (Dig(sal)), specifically inhibited induction of IL-17 in human CD4+ T cells. Using these small molecule compounds, we demonstrated that RORγt is imporant for the maintenance of IL-17 expression in mouse and human effector T cells. These data suggest that derivatives of digoxin can be used as chemical probes for development of RORγt-targeted therapeutic agents that attenuate inflammatory lymphocyte function and autoimmune disease.

Standard name | GSE27241_WT_CTRL_VS_DIGOXIN_TREATED_RORGT_KO_CD4_TCELL_IN_TH17_POLARIZING_CONDITIONS_DN
Systematic name | M8241
Organism | Mus musculus
PMID | 21441909
Authors | Huh JR,Leung MW,Huang P,Ryan DA,Krout MR,Malapaka RR,Chow J,Manel N,Ciofani M,Kim SV,Cuesta A,Santori FR,Lafaille JJ,Xu HE,Gin DY,Rastinejad F,Littman DR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polarizing CD4 [GeneID=920] Th17 cells: wildtype vs RORC [GeneID=6097] knockout treated with digoxin [PubChem=2724385].
Full description | CD4+ T helper lymphocytes that express interleukin-17 (Th17 cells) have critical roles in mouse models of autoimmunity, and there is mounting evidence that they also influence inflammatory processes in humans. Genome-wide association studies in humans have linked genes involved in Th17 cell differentiation and function with susceptibility to Crohn’s disease, rheumatoid arthritis, and psoriasis1-3. Thus, the pathway towards differentiation of Th17 cells and, perhaps, of related innate lymphoid cells with similar effector functions4, 5, is an attractive target for therapeutic applications. Mouse and human Th17 cells are distinguished by expression of the retinoic acid receptor-related orphan nuclear receptor RORγt, which is required for induction of IL-17 transcription and for the manifestation of Th17-dependent autoimmune disease in mice6. By performing a chemical screen with an insect cell-based reporter system, we identified the cardiac glycoside digoxin as a specific inhibitor of RORγt transcriptional activity. Digoxin inhibited murine Th17 cell differentiation without affecting differentiation of other T cell lineages and was effective in delaying the onset and reducing the severity of autoimmune disease in mice. At high concentrations, digoxin is toxic for human cells, but non-toxic synthetic derivatives, 20,22-dihydrodigoxin-21,23-diol (Dig(dhd)) and digoxin-21-salicylidene (Dig(sal)), specifically inhibited induction of IL-17 in human CD4+ T cells. Using these small molecule compounds, we demonstrated that RORγt is imporant for the maintenance of IL-17 expression in mouse and human effector T cells. These data suggest that derivatives of digoxin can be used as chemical probes for development of RORγt-targeted therapeutic agents that attenuate inflammatory lymphocyte function and autoimmune disease.

Standard name | GSE27241_WT_VS_RORGT_KO_TH17_POLARIZED_CD4_TCELL_DN
Systematic name | M8242
Organism | Mus musculus
PMID | 21441909
Authors | Huh JR,Leung MW,Huang P,Ryan DA,Krout MR,Malapaka RR,Chow J,Manel N,Ciofani M,Kim SV,Cuesta A,Santori FR,Lafaille JJ,Xu HE,Gin DY,Rastinejad F,Littman DR
Category | C7
Sub-category |
Brief description | Genes down-regulated in polarizing CD4 [GeneID=920] Th17 cells: wildtype versus RORC [GeneID=6097] knockout.
Full description | CD4+ T helper lymphocytes that express interleukin-17 (Th17 cells) have critical roles in mouse models of autoimmunity, and there is mounting evidence that they also influence inflammatory processes in humans. Genome-wide association studies in humans have linked genes involved in Th17 cell differentiation and function with susceptibility to Crohn’s disease, rheumatoid arthritis, and psoriasis1-3. Thus, the pathway towards differentiation of Th17 cells and, perhaps, of related innate lymphoid cells with similar effector functions4, 5, is an attractive target for therapeutic applications. Mouse and human Th17 cells are distinguished by expression of the retinoic acid receptor-related orphan nuclear receptor RORγt, which is required for induction of IL-17 transcription and for the manifestation of Th17-dependent autoimmune disease in mice6. By performing a chemical screen with an insect cell-based reporter system, we identified the cardiac glycoside digoxin as a specific inhibitor of RORγt transcriptional activity. Digoxin inhibited murine Th17 cell differentiation without affecting differentiation of other T cell lineages and was effective in delaying the onset and reducing the severity of autoimmune disease in mice. At high concentrations, digoxin is toxic for human cells, but non-toxic synthetic derivatives, 20,22-dihydrodigoxin-21,23-diol (Dig(dhd)) and digoxin-21-salicylidene (Dig(sal)), specifically inhibited induction of IL-17 in human CD4+ T cells. Using these small molecule compounds, we demonstrated that RORγt is imporant for the maintenance of IL-17 expression in mouse and human effector T cells. These data suggest that derivatives of digoxin can be used as chemical probes for development of RORγt-targeted therapeutic agents that attenuate inflammatory lymphocyte function and autoimmune disease.

Standard name | GSE27241_CTRL_VS_DIGOXIN_TREATED_CD4_TCELL_IN_TH17_POLARIZING_CONDITIONS_UP
Systematic name | M8243
Organism | Mus musculus
PMID | 21441909
Authors | Huh JR,Leung MW,Huang P,Ryan DA,Krout MR,Malapaka RR,Chow J,Manel N,Ciofani M,Kim SV,Cuesta A,Santori FR,Lafaille JJ,Xu HE,Gin DY,Rastinejad F,Littman DR
Category | C7
Sub-category |
Brief description | Genes up-regulated in polarizing CD4 [GeneID=920] Th17 cells: untreated versus digoxin [PubChem=2724385].
Full description | CD4+ T helper lymphocytes that express interleukin-17 (Th17 cells) have critical roles in mouse models of autoimmunity, and there is mounting evidence that they also influence inflammatory processes in humans. Genome-wide association studies in humans have linked genes involved in Th17 cell differentiation and function with susceptibility to Crohn’s disease, rheumatoid arthritis, and psoriasis1-3. Thus, the pathway towards differentiation of Th17 cells and, perhaps, of related innate lymphoid cells with similar effector functions4, 5, is an attractive target for therapeutic applications. Mouse and human Th17 cells are distinguished by expression of the retinoic acid receptor-related orphan nuclear receptor RORγt, which is required for induction of IL-17 transcription and for the manifestation of Th17-dependent autoimmune disease in mice6. By performing a chemical screen with an insect cell-based reporter system, we identified the cardiac glycoside digoxin as a specific inhibitor of RORγt transcriptional activity. Digoxin inhibited murine Th17 cell differentiation without affecting differentiation of other T cell lineages and was effective in delaying the onset and reducing the severity of autoimmune disease in mice. At high concentrations, digoxin is toxic for human cells, but non-toxic synthetic derivatives, 20,22-dihydrodigoxin-21,23-diol (Dig(dhd)) and digoxin-21-salicylidene (Dig(sal)), specifically inhibited induction of IL-17 in human CD4+ T cells. Using these small molecule compounds, we demonstrated that RORγt is imporant for the maintenance of IL-17 expression in mouse and human effector T cells. These data suggest that derivatives of digoxin can be used as chemical probes for development of RORγt-targeted therapeutic agents that attenuate inflammatory lymphocyte function and autoimmune disease.

Standard name | GSE27896_HDAC6_KO_VS_WT_TREG_DN
Systematic name | M8246
Organism | Mus musculus
PMID | 21444725
Authors | Zoeten de EF,Wang L,Butler K,Beier UH,Akimova T,Sai H,Bradner JE,Mazitschek R,Kozikowski AP,Matthias P,Hancock WW
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: HDAC6 [GeneID=10013] knockout versus wildtype.
Full description | Foxp3+ T-regulatory cells (Tregs) are key to immune homeostasis such that their diminished numbers or function can cause autoimmunity and allograft rejection. Foxp3+ Tregs express histone/protein deacetylases (HDACs) that regulate chromatin remodeling, gene expression and protein function. Pan-HDAC inhibitors developed for oncology enhance Treg production and suppression but have limited non-oncologic applications given their broad effects. We show, using HDAC6-deficient mice and WT mice treated with HDAC6-specific inhibitors, that HDAC6 inhibition promotes Treg suppressive activity in models of inflammation and autoimmunity, including multiple forms of experimental colitis and fully MHC-incompatible cardiac allograft rejection. Many of the beneficial effects of HDAC6 targeting are also achieved by inhibition of the HDAC6-regulated protein, HSP90. Hence, selective targeting of a single HDAC isoform, HDAC6, or its downstream target, HSP90, can promote Treg-dependent suppression of autoimmunity and transplant rejection.

Standard name | GSE27896_HDAC6_KO_VS_WT_TREG_UP
Systematic name | M8248
Organism | Mus musculus
PMID | 21444725
Authors | Zoeten de EF,Wang L,Butler K,Beier UH,Akimova T,Sai H,Bradner JE,Mazitschek R,Kozikowski AP,Matthias P,Hancock WW
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: HDAC6 [GeneID=10013] knockout versus wildtype.
Full description | Foxp3+ T-regulatory cells (Tregs) are key to immune homeostasis such that their diminished numbers or function can cause autoimmunity and allograft rejection. Foxp3+ Tregs express histone/protein deacetylases (HDACs) that regulate chromatin remodeling, gene expression and protein function. Pan-HDAC inhibitors developed for oncology enhance Treg production and suppression but have limited non-oncologic applications given their broad effects. We show, using HDAC6-deficient mice and WT mice treated with HDAC6-specific inhibitors, that HDAC6 inhibition promotes Treg suppressive activity in models of inflammation and autoimmunity, including multiple forms of experimental colitis and fully MHC-incompatible cardiac allograft rejection. Many of the beneficial effects of HDAC6 targeting are also achieved by inhibition of the HDAC6-regulated protein, HSP90. Hence, selective targeting of a single HDAC isoform, HDAC6, or its downstream target, HSP90, can promote Treg-dependent suppression of autoimmunity and transplant rejection.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_8H_UP
Systematic name | M8249
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: control versus stimulated by anti-IgM for 8h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_3H_DN
Systematic name | M8250
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: control versus stimulated by anti-IgM for 3h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_3H_UP
Systematic name | M8251
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: control versus stimulated by anti-IgM for 3h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_WT_VS_NFATC1_KO_16H_ANTI_IGM_STIM_BCELL_DN
Systematic name | M8252
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes stimulated by anti-IgM for 16h: wildtype versus NFATC1 [GeneID=4772] knockout.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_WT_VS_NFATC1_KO_3H_ANTI_IGM_STIM_BCELL_DN
Systematic name | M8253
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes stimulated by anti-IgM for 3h: wildtype versus NFATC1 [GeneID=4772] knockout.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_3H_VS_16H_ANTI_IGM_STIM_NFATC1_KOBCELL_UP
Systematic name | M8255
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes with NFATC1 [GeneID=4772] knockout stimulated by anti-IgM: 3h versus 16h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_3H_VS_16H_ANTI_IGM_STIM_NFATC1_KOBCELL_DN
Systematic name | M8257
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes with NFATC1 [GeneID=4772] knockout stimulated by anti-IgM: 3h versus 16h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_NFATC1_KO_16H_UP
Systematic name | M8258
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes with NFATC1 [GeneID=4772] knockout: control versus stimulated by anti-IgM for 16h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_NFATC1_KO_16H_DN
Systematic name | M8259
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes with NFATC1 [GeneID=4772] knockout: control versus stimulated by anti-IgM for 16h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_WT_VS_NFATC1_KO_BCELL_UP
Systematic name | M8260
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: wildtype versus NFATC1 [GeneID=4772] knockout.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_WT_VS_NFATC1_KO_BCELL_DN
Systematic name | M8261
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: wildtype versus NFATC1 [GeneID=4772] knockout.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_WT_VS_NFATC1_KO_3H_ANTI_IGM_STIM_BCELL_UP
Systematic name | M8263
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes stimulated by anti-IgM for 3h: wildtype versus NFATC1 [GeneID=4772] knockout.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_3H_VS_16H_ANTI_IGM_STIM_BCELL_UP
Systematic name | M8264
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes stimulated by anti-IgM: 3h versus 16h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_8H_DN
Systematic name | M8265
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: control versus stimulated by anti-IgM for 8h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_16H_UP
Systematic name | M8266
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: control versus stimulated by anti-IgM for 16h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_16H_DN
Systematic name | M8267
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: control versus stimulated by anti-IgM for 16h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_WT_VS_NFATC1_KO_16H_ANTI_IGM_STIM_BCELL_UP
Systematic name | M8269
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes stimulated by anti-IgM for 16h: wildtype versus NFATC1 [GeneID=4772] knockout.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_3H_VS_16H_ANTI_IGM_STIM_BCELL_DN
Systematic name | M8271
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes stimulated by anti-IgM: 3h versus 16h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_NFATC1_KO_8H_UP
Systematic name | M8272
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes with NFATC1 [GeneID=4772] knockout: control versus stimulated by anti-IgM for 8h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_NFATC1_KO_8H_DN
Systematic name | M8274
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes with NFATC1 [GeneID=4772] knockout: control versus stimulated by anti-IgM for 8h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_NFATC1_KO_3H_DN
Systematic name | M8275
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes with NFATC1 [GeneID=4772] knockout: control versus stimulated by anti-IgM for 3h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_WT_VS_NFATC1_KO_8H_ANTI_IGM_STIM_BCELL_UP
Systematic name | M8277
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes stimulated by anti-IgM for 8h: wildtype versus NFATC1 [GeneID=4772] knockout.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_WT_VS_NFATC1_KO_8H_ANTI_IGM_STIM_BCELL_DN
Systematic name | M8278
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes stimulated by anti-IgM for 8h: wildtype versus NFATC1 [GeneID=4772] knockout.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE21063_CTRL_VS_ANTI_IGM_STIM_BCELL_NFATC1_KO_3H_UP
Systematic name | M8279
Organism | Mus musculus
PMID | 21464221
Authors | Bhattacharyya S,Deb J,Patra AK,Pham Thuy DA,Chen W,Vaeth M,Berberich-Siebelt F,Klein-Hessling S,Lamperti ED,Reifenberg K,Jellusova J,Schweizer A,Nitschke L,Leich E,Rosenwald A,Brunner C,Engelmann S,Bommhardt U,Avots A,Müller MR,Kondo E,Serfling E
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes with NFATC1 [GeneID=4772] knockout: control versus stimulated by anti-IgM for 3h.
Full description | Triggering of B cell receptors (BCR) induces a massive synthesis of NFATc1 in splenic B cells. By inactivating the Nfatc1 gene and re-expressing NFATc1 we show that NFATc1 levels are critical for the survival of splenic B cells upon BCR stimulation. NFATc1 ablation led to decreased BCR-induced Ca++ flux and proliferation of splenic B cells, increased apoptosis and suppressed germinal centre formation and immunoglobulin class switch by T cell-independent antigens. By controlling IL-10 synthesis in B cells, NFATc1 supported the proliferation and IL-2 synthesis of T cells in vitro and appeared to contribute to the mild clinical course of Experimental Autoimmune Encephalomyelitis in mice bearing NFATc1-/- B cells. These data indicate NFATc1 as a key factor controlling B cell function.

Standard name | GSE25502_WT_VS_KLF13_KO_THYMIC_MEMORY_LIKE_CD8_TCELL_UP
Systematic name | M8282
Organism | Mus musculus
PMID | 21482696
Authors | Lai D,Zhu J,Wang T,Hu-Li J,Terabe M,Berzofsky JA,Clayberger C,Krensky AM
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic memory like CD8 cells: wildtype versus KFL13 [GeneID=51621] knockout.
Full description | “Memory-like T cells” are a subset of thymic cells that acquire effector function through the maturation process rather than interaction with specific antigen. Disruption of genes encoding T cell signaling proteins or transcription factors have provided insights into the differentiation of such cells. We show here that in BALB/c but not C57BL/6 mice, a large portion of thymic CD4-CD8+ T cells exhibit a memory-like phenotype. In BALB/c mice, IL-4 secreted by invariant natural killer T (iNKT) cells is both essential and sufficient for the generation of memory-like T cells. In C57BL/6 mice, iNKT cells are less abundant, producing IL-4 that is insufficient to induce thymic memory-like CD8+ T cells. BALB/c mice deficient in the transcription factor Kruppel-like factor (KLF) 13 have comparable numbers of iNKT cells to C57BL/6 mice and extremely low levels of thymic memory-like CD8+ T cells. This work documents the dramatic impact of a small number of KLF13-dependent iNKT cells.

Standard name | GSE25502_WT_VS_KLF13_KO_THYMIC_MEMORY_LIKE_CD8_TCELL_DN
Systematic name | M8283
Organism | Mus musculus
PMID | 21482696
Authors | Lai D,Zhu J,Wang T,Hu-Li J,Terabe M,Berzofsky JA,Clayberger C,Krensky AM
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic memory like CD8 cells: wildtype versus KFL13 [GeneID=51621] knockout.
Full description | “Memory-like T cells” are a subset of thymic cells that acquire effector function through the maturation process rather than interaction with specific antigen. Disruption of genes encoding T cell signaling proteins or transcription factors have provided insights into the differentiation of such cells. We show here that in BALB/c but not C57BL/6 mice, a large portion of thymic CD4-CD8+ T cells exhibit a memory-like phenotype. In BALB/c mice, IL-4 secreted by invariant natural killer T (iNKT) cells is both essential and sufficient for the generation of memory-like T cells. In C57BL/6 mice, iNKT cells are less abundant, producing IL-4 that is insufficient to induce thymic memory-like CD8+ T cells. BALB/c mice deficient in the transcription factor Kruppel-like factor (KLF) 13 have comparable numbers of iNKT cells to C57BL/6 mice and extremely low levels of thymic memory-like CD8+ T cells. This work documents the dramatic impact of a small number of KLF13-dependent iNKT cells.

Standard name | GSE23114_WT_VS_SLE2C1_MOUSE_PERITONEAL_CAVITY_B1A_BCELL_UP
Systematic name | M8284
Organism | Mus musculus
PMID | 21543644
Authors | Xu Z,Potula HH,Vallurupalli A,Perry D,Baker H,Croker BP,Dozmorov I,Morel L
Category | C7
Sub-category |
Brief description | Genes up-regulated in peritoneal cavity B lymphocytes: wildtype versus lupus susceptibility locus Sle2c1.
Full description | Sle2c1 is an NZM2410-derived lupus susceptibility locus that induces an expansion of the B1a cell compartment. B1a cells have a repertoire enriched for autoreactivity, and an expansion of this B cell subset occurs in several mouse models of lupus. Here we showed that expression of Sle2c1 enhances NZB cellular phenotypes that have been associated with autoimmune pathogenesis. A combination of genetic mapping and candidate gene analysis presents Cdkn2c, a gene encoding for cyclin kinase inhibitor p18INK4c (p18), as the top candidate gene for inducing the Slec2c1 associated expansion of B1a cells. A novel SNP in the Cdkn2c promoter is associated with a significantly reduced Cdkn2c expression in the splenic B cells and B1a cells from Sle2c1-carrying mice, which leads to defective G1 cell cycle arrest in splenic B cells and increased proliferation of Pc B1a cells. As cell cycle is differentially regulated in B1a and B2 cells, these results suggest that Cdkn2c play a critical role in B1a cell self renewal, and that its impaired expression leads to an accumulation of these cells with high autoreactive potential.

Standard name | GSE23114_WT_VS_SLE2C1_MOUSE_PERITONEAL_CAVITY_B1A_BCELL_DN
Systematic name | M8285
Organism | Mus musculus
PMID | 21543644
Authors | Xu Z,Potula HH,Vallurupalli A,Perry D,Baker H,Croker BP,Dozmorov I,Morel L
Category | C7
Sub-category |
Brief description | Genes down-regulated in peritoneal cavity B lymphocytes: wildtype versus lupus susceptibility locus Sle2c1.
Full description | Sle2c1 is an NZM2410-derived lupus susceptibility locus that induces an expansion of the B1a cell compartment. B1a cells have a repertoire enriched for autoreactivity, and an expansion of this B cell subset occurs in several mouse models of lupus. Here we showed that expression of Sle2c1 enhances NZB cellular phenotypes that have been associated with autoimmune pathogenesis. A combination of genetic mapping and candidate gene analysis presents Cdkn2c, a gene encoding for cyclin kinase inhibitor p18INK4c (p18), as the top candidate gene for inducing the Slec2c1 associated expansion of B1a cells. A novel SNP in the Cdkn2c promoter is associated with a significantly reduced Cdkn2c expression in the splenic B cells and B1a cells from Sle2c1-carrying mice, which leads to defective G1 cell cycle arrest in splenic B cells and increased proliferation of Pc B1a cells. As cell cycle is differentially regulated in B1a and B2 cells, these results suggest that Cdkn2c play a critical role in B1a cell self renewal, and that its impaired expression leads to an accumulation of these cells with high autoreactive potential.

Standard name | GSE23114_PERITONEAL_CAVITY_B1A_BCELL_VS_SPLEEN_BCELL_UP
Systematic name | M8287
Organism | Mus musculus
PMID | 21543644
Authors | Xu Z,Potula HH,Vallurupalli A,Perry D,Baker H,Croker BP,Dozmorov I,Morel L
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes from: peritoneal cavity versus spleen.
Full description | Sle2c1 is an NZM2410-derived lupus susceptibility locus that induces an expansion of the B1a cell compartment. B1a cells have a repertoire enriched for autoreactivity, and an expansion of this B cell subset occurs in several mouse models of lupus. Here we showed that expression of Sle2c1 enhances NZB cellular phenotypes that have been associated with autoimmune pathogenesis. A combination of genetic mapping and candidate gene analysis presents Cdkn2c, a gene encoding for cyclin kinase inhibitor p18INK4c (p18), as the top candidate gene for inducing the Slec2c1 associated expansion of B1a cells. A novel SNP in the Cdkn2c promoter is associated with a significantly reduced Cdkn2c expression in the splenic B cells and B1a cells from Sle2c1-carrying mice, which leads to defective G1 cell cycle arrest in splenic B cells and increased proliferation of Pc B1a cells. As cell cycle is differentially regulated in B1a and B2 cells, these results suggest that Cdkn2c play a critical role in B1a cell self renewal, and that its impaired expression leads to an accumulation of these cells with high autoreactive potential.

Standard name | GSE23114_PERITONEAL_CAVITY_B1A_BCELL_VS_SPLEEN_BCELL_IN_SLE2C1_MOUSE_DN
Systematic name | M8288
Organism | Mus musculus
PMID | 21543644
Authors | Xu Z,Potula HH,Vallurupalli A,Perry D,Baker H,Croker BP,Dozmorov I,Morel L
Category | C7
Sub-category |
Brief description | Genes down-regulated in lupus susceptibility locus Sle2c1 B lymphocytes from: peritoneal cavity versus spleen.
Full description | Sle2c1 is an NZM2410-derived lupus susceptibility locus that induces an expansion of the B1a cell compartment. B1a cells have a repertoire enriched for autoreactivity, and an expansion of this B cell subset occurs in several mouse models of lupus. Here we showed that expression of Sle2c1 enhances NZB cellular phenotypes that have been associated with autoimmune pathogenesis. A combination of genetic mapping and candidate gene analysis presents Cdkn2c, a gene encoding for cyclin kinase inhibitor p18INK4c (p18), as the top candidate gene for inducing the Slec2c1 associated expansion of B1a cells. A novel SNP in the Cdkn2c promoter is associated with a significantly reduced Cdkn2c expression in the splenic B cells and B1a cells from Sle2c1-carrying mice, which leads to defective G1 cell cycle arrest in splenic B cells and increased proliferation of Pc B1a cells. As cell cycle is differentially regulated in B1a and B2 cells, these results suggest that Cdkn2c play a critical role in B1a cell self renewal, and that its impaired expression leads to an accumulation of these cells with high autoreactive potential.

Standard name | GSE23114_WT_VS_SLE2C1_MOUSE_SPLEEN_B1A_BCELL_DN
Systematic name | M8289
Organism | Mus musculus
PMID | 21543644
Authors | Xu Z,Potula HH,Vallurupalli A,Perry D,Baker H,Croker BP,Dozmorov I,Morel L
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen B lymphocytes: wildtype versus lupus susceptibility locus Sle2c1.
Full description | Sle2c1 is an NZM2410-derived lupus susceptibility locus that induces an expansion of the B1a cell compartment. B1a cells have a repertoire enriched for autoreactivity, and an expansion of this B cell subset occurs in several mouse models of lupus. Here we showed that expression of Sle2c1 enhances NZB cellular phenotypes that have been associated with autoimmune pathogenesis. A combination of genetic mapping and candidate gene analysis presents Cdkn2c, a gene encoding for cyclin kinase inhibitor p18INK4c (p18), as the top candidate gene for inducing the Slec2c1 associated expansion of B1a cells. A novel SNP in the Cdkn2c promoter is associated with a significantly reduced Cdkn2c expression in the splenic B cells and B1a cells from Sle2c1-carrying mice, which leads to defective G1 cell cycle arrest in splenic B cells and increased proliferation of Pc B1a cells. As cell cycle is differentially regulated in B1a and B2 cells, these results suggest that Cdkn2c play a critical role in B1a cell self renewal, and that its impaired expression leads to an accumulation of these cells with high autoreactive potential.

Standard name | GSE23114_WT_VS_SLE2C1_MOUSE_SPLEEN_B1A_BCELL_UP
Systematic name | M8290
Organism | Mus musculus
PMID | 21543644
Authors | Xu Z,Potula HH,Vallurupalli A,Perry D,Baker H,Croker BP,Dozmorov I,Morel L
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen B lymphocytes: wildtype versus lupus susceptibility locus Sle2c1.
Full description | Sle2c1 is an NZM2410-derived lupus susceptibility locus that induces an expansion of the B1a cell compartment. B1a cells have a repertoire enriched for autoreactivity, and an expansion of this B cell subset occurs in several mouse models of lupus. Here we showed that expression of Sle2c1 enhances NZB cellular phenotypes that have been associated with autoimmune pathogenesis. A combination of genetic mapping and candidate gene analysis presents Cdkn2c, a gene encoding for cyclin kinase inhibitor p18INK4c (p18), as the top candidate gene for inducing the Slec2c1 associated expansion of B1a cells. A novel SNP in the Cdkn2c promoter is associated with a significantly reduced Cdkn2c expression in the splenic B cells and B1a cells from Sle2c1-carrying mice, which leads to defective G1 cell cycle arrest in splenic B cells and increased proliferation of Pc B1a cells. As cell cycle is differentially regulated in B1a and B2 cells, these results suggest that Cdkn2c play a critical role in B1a cell self renewal, and that its impaired expression leads to an accumulation of these cells with high autoreactive potential.

Standard name | GSE23114_PERITONEAL_CAVITY_B1A_BCELL_VS_SPLEEN_BCELL_IN_SLE2C1_MOUSE_UP
Systematic name | M8294
Organism | Mus musculus
PMID | 21543644
Authors | Xu Z,Potula HH,Vallurupalli A,Perry D,Baker H,Croker BP,Dozmorov I,Morel L
Category | C7
Sub-category |
Brief description | Genes up-regulated in lupus susceptibility locus Sle2c1 B lymphocytes from: peritoneal cavity versus spleen.
Full description | Sle2c1 is an NZM2410-derived lupus susceptibility locus that induces an expansion of the B1a cell compartment. B1a cells have a repertoire enriched for autoreactivity, and an expansion of this B cell subset occurs in several mouse models of lupus. Here we showed that expression of Sle2c1 enhances NZB cellular phenotypes that have been associated with autoimmune pathogenesis. A combination of genetic mapping and candidate gene analysis presents Cdkn2c, a gene encoding for cyclin kinase inhibitor p18INK4c (p18), as the top candidate gene for inducing the Slec2c1 associated expansion of B1a cells. A novel SNP in the Cdkn2c promoter is associated with a significantly reduced Cdkn2c expression in the splenic B cells and B1a cells from Sle2c1-carrying mice, which leads to defective G1 cell cycle arrest in splenic B cells and increased proliferation of Pc B1a cells. As cell cycle is differentially regulated in B1a and B2 cells, these results suggest that Cdkn2c play a critical role in B1a cell self renewal, and that its impaired expression leads to an accumulation of these cells with high autoreactive potential.

Standard name | GSE23114_PERITONEAL_CAVITY_B1A_BCELL_VS_SPLEEN_BCELL_DN
Systematic name | M8297
Organism | Mus musculus
PMID | 21543644
Authors | Xu Z,Potula HH,Vallurupalli A,Perry D,Baker H,Croker BP,Dozmorov I,Morel L
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes from: peritoneal cavity versus spleen.
Full description | Sle2c1 is an NZM2410-derived lupus susceptibility locus that induces an expansion of the B1a cell compartment. B1a cells have a repertoire enriched for autoreactivity, and an expansion of this B cell subset occurs in several mouse models of lupus. Here we showed that expression of Sle2c1 enhances NZB cellular phenotypes that have been associated with autoimmune pathogenesis. A combination of genetic mapping and candidate gene analysis presents Cdkn2c, a gene encoding for cyclin kinase inhibitor p18INK4c (p18), as the top candidate gene for inducing the Slec2c1 associated expansion of B1a cells. A novel SNP in the Cdkn2c promoter is associated with a significantly reduced Cdkn2c expression in the splenic B cells and B1a cells from Sle2c1-carrying mice, which leads to defective G1 cell cycle arrest in splenic B cells and increased proliferation of Pc B1a cells. As cell cycle is differentially regulated in B1a and B2 cells, these results suggest that Cdkn2c play a critical role in B1a cell self renewal, and that its impaired expression leads to an accumulation of these cells with high autoreactive potential.

Standard name | GSE26156_DOUBLE_POSITIVE_VS_CD4_SINGLE_POSITIVE_THYMOCYTE_UP
Systematic name | M8298
Organism | Homo sapiens
PMID | 21551231
Authors | Ghisi M,Corradin A,Basso K,Frasson C,Serafin V,Mukherjee S,Mussolin L,Ruggero K,Bonanno L,Guffanti A,Bellis De G,Gerosa G,Stellin G,D'Agostino DM,Basso G,Bronte V,Indraccolo S,Amadori A,Zanovello P
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymocytes: double positive versus CD4 [GeneID=920] single positive.
Full description | Gene expression of Double Positive, and Single Positive CD4+ human thymocytes

Standard name | GSE26156_DOUBLE_POSITIVE_VS_CD4_SINGLE_POSITIVE_THYMOCYTE_DN
Systematic name | M8299
Organism | Homo sapiens
PMID | 21551231
Authors | Ghisi M,Corradin A,Basso K,Frasson C,Serafin V,Mukherjee S,Mussolin L,Ruggero K,Bonanno L,Guffanti A,Bellis De G,Gerosa G,Stellin G,D'Agostino DM,Basso G,Bronte V,Indraccolo S,Amadori A,Zanovello P
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymocytes: double positive versus CD4 [GeneID=920] single positive.
Full description | Gene expression of Double Positive, and Single Positive CD4+ human thymocytes

Standard name | GSE26727_WT_VS_KLF2_KO_LPS_STIM_MACROPHAGE_UP
Systematic name | M8301
Organism | Mus musculus
PMID | 21565532
Authors | Mahabeleshwar GH,Kawanami D,Sharma N,Takami Y,Zhou G,Shi H,Nayak L,Jeyaraj D,Grealy R,White M,McManus R,Ryan T,Leahy P,Lin Z,Haldar SM,Atkins GB,Wong HR,Lingrel JB,Jain MK
Category | C7
Sub-category |
Brief description | Genes up-regulated in peritoneal macrophages treated with LPS: wildtype versus KLF2 [GeneID=10365] knockout.
Full description | Gene expression profile of LysMCre/Cre and KLF2∆/∆ primary peritoneal macrophages following 6 hours of LPS treatment. We used microarrays to detail the global program of gene expression following LPS stimulation of LysMCre/Cre and KLF2∆/∆ primary peritoneal macrophages. We identified distinct classes of genes that were altered following LPS stimulation.

Standard name | GSE26727_WT_VS_KLF2_KO_LPS_STIM_MACROPHAGE_DN
Systematic name | M8302
Organism | Mus musculus
PMID | 21565532
Authors | Mahabeleshwar GH,Kawanami D,Sharma N,Takami Y,Zhou G,Shi H,Nayak L,Jeyaraj D,Grealy R,White M,McManus R,Ryan T,Leahy P,Lin Z,Haldar SM,Atkins GB,Wong HR,Lingrel JB,Jain MK
Category | C7
Sub-category |
Brief description | Genes down-regulated in peritoneal macrophages treated with LPS: wildtype versus KLF2 [GeneID=10365] knockout.
Full description | Gene expression profile of LysMCre/Cre and KLF2∆/∆ primary peritoneal macrophages following 6 hours of LPS treatment. We used microarrays to detail the global program of gene expression following LPS stimulation of LysMCre/Cre and KLF2∆/∆ primary peritoneal macrophages. We identified distinct classes of genes that were altered following LPS stimulation.

Standard name | GSE28726_NAIVE_CD4_TCELL_VS_NAIVE_VA24NEG_NKTCELL_DN
Systematic name | M8303
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve T cells: CD4 [GeneID=920] versus Va24- NKT.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_ACT_CD4_TCELL_VS_ACT_VA24NEG_NKTCELL_UP
Systematic name | M8305
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated T cells: CD4 [GeneID=920] versus Va24- NKT.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_ACT_CD4_TCELL_VS_ACT_VA24NEG_NKTCELL_DN
Systematic name | M8306
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated T cells: CD4 [GeneID=920] versus Va24- NKT.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_NAIVE_CD4_TCELL_VS_NAIVE_VA24NEG_NKTCELL_UP
Systematic name | M8308
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve T cells: CD4 [GeneID=920] versus Va24- NKT.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_NAIVE_VS_ACTIVATED_VA24NEG_NKTCELL_DN
Systematic name | M8309
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes down-regulated in Va24- NKT cells: naïve versus activated.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_NAIVE_CD4_TCELL_VS_NAIVE_NKTCELL_UP
Systematic name | M8310
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve T cells: CD4 [GeneID=920] versus NK.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_NAIVE_CD4_TCELL_VS_NAIVE_NKTCELL_DN
Systematic name | M8311
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve T cells: CD4 [GeneID=920] versus NK.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_ACT_CD4_TCELL_VS_ACT_NKTCELL_UP
Systematic name | M8312
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated T cells: CD4 [GeneID=920] versus NKT.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_ACT_CD4_TCELL_VS_ACT_NKTCELL_DN
Systematic name | M8313
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated T cells: CD4 [GeneID=920] versus NKT.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_NAIVE_VS_ACTIVATED_CD4_TCELL_DN
Systematic name | M8314
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: naïve versus activated.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_NAIVE_VS_ACTIVATED_NKTCELL_UP
Systematic name | M8318
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes up-regulated in NKT cells: naïve versus activated.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_NAIVE_VS_ACTIVATED_NKTCELL_DN
Systematic name | M8319
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes down-regulated in NKT cells: naïve versus activated.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_NAIVE_VS_ACTIVATED_CD4_TCELL_UP
Systematic name | M8320
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: naïve versus activated.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE28726_NAIVE_VS_ACTIVATED_VA24NEG_NKTCELL_UP
Systematic name | M8322
Organism | Homo sapiens
PMID | 21632718
Authors | Constantinides MG,Picard D,Savage AK,Bendelac A
Category | C7
Sub-category |
Brief description | Genes up-regulated in Va24- NKT cells: naïve versus activated.
Full description | Microarray analysis was performed to determine the transcriptional profiles of NKT, CD1d-aGC+ Va24-, and CD4 T cells.

Standard name | GSE24574_BCL6_HIGH_VS_LOW_TFH_CD4_TCELL_UP
Systematic name | M8324
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular helper T cells: BCL6 [GeneID=604] high versus BCL6 [GeneID=604] low.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_HIGH_VS_LOW_TFH_CD4_TCELL_DN
Systematic name | M8325
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular helper T cells: BCL6 [GeneID=604] high versus BCL6 [GeneID=604] low.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_HIGH_TFH_VS_NAIVE_CD4_TCELL_UP
Systematic name | M8326
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes up-regulated in BCL6 [GeneID=604] high follicular helper T cells versus naïve T CD4 [GeneID=920] cells.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_HIGH_TFH_VS_NAIVE_CD4_TCELL_DN
Systematic name | M8327
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes down-regulated in BCL6 [GeneID=604] high follicular helper T cells versus naïve T CD4 [GeneID=920] cells.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_NAIVE_VS_TCONV_CD4_TCELL_UP
Systematic name | M8328
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes up-regulated in naïve CD4 [GeneID=920] Tcells versus T conv cells.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_NAIVE_VS_TCONV_CD4_TCELL_DN
Systematic name | M8330
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes down-regulated in naïve CD4 [GeneID=920] Tcells versus T conv cells.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_HIGH_TFH_VS_TFH_CD4_TCELL_DN
Systematic name | M8331
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes down-regulated in BCL6 [GeneID=604] high follicular helper T cells (Tfh) versus all Tfh.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_LOW_TFH_VS_TCONV_CD4_TCELL_DN
Systematic name | M8332
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes down-regulated in BCL6 [GeneID=604] low follicular helper T cells versus T conv cells.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_HIGH_TFH_VS_TCONV_CD4_TCELL_DN
Systematic name | M8335
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes down-regulated in BCL6 [GeneID=604] high follicular helper T cells versus T conv cells.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_LOW_TFH_VS_NAIVE_CD4_TCELL_UP
Systematic name | M8336
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes up-regulated in BCL6 [GeneID=604] low follicular helper T cells versus naïve CD4 [GeneID=620] T cells.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_HIGH_TFH_VS_TFH_CD4_TCELL_UP
Systematic name | M8337
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes up-regulated in BCL6 [GeneID=604] high follicular helper T cells (Tfh) versus all Tfh.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_HIGH_TFH_VS_TCONV_CD4_TCELL_UP
Systematic name | M8338
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes up-regulated in BCL6 [GeneID=604] high follicular helper T cells versus T conv cells.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_LOW_TFH_VS_NAIVE_CD4_TCELL_DN
Systematic name | M8339
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes down-regulated in BCL6 [GeneID=604] low follicular helper T cells versus naïve CD4 [GeneID=620] T cells.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE24574_BCL6_LOW_TFH_VS_TCONV_CD4_TCELL_UP
Systematic name | M8340
Organism | Mus musculus
PMID | 21636294
Authors | Kitano M,Moriyama S,Ando Y,Hikida M,Mori Y,Kurosaki T,Okada T
Category | C7
Sub-category |
Brief description | Genes up-regulated in BCL6 [GeneID=604] low follicular helper T cells versus T conv cells.
Full description | We found that a number of Tfh cells downmodulated BCL6 protein after their development, and we sought to compare the gene expression between BCL6-hi Tfh cells and BCL6-low Tfh cells.

Standard name | GSE28130_ACTIVATED_VS_INDUCEED_TREG_UP
Systematic name | M8343
Organism | Mus musculus
PMID | 21642545
Authors | Kuczma M,Lee JR,Kraj P
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated versus induced T reg cells.
Full description | Induced and activated regulatory CD4+ Foxp3+ cells compared

Standard name | GSE28130_ACTIVATED_VS_INDUCEED_TREG_DN
Systematic name | M8345
Organism | Mus musculus
PMID | 21642545
Authors | Kuczma M,Lee JR,Kraj P
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated versus induced T reg cells.
Full description | Induced and activated regulatory CD4+ Foxp3+ cells compared

Standard name | GSE28449_WT_VS_LRF_KO_GERMINAL_CENTER_BCELL_DN
Systematic name | M8346
Organism | Mus musculus
PMID | 21646720
Authors | Sakurai N,Maeda M,Lee SU,Ishikawa Y,Li M,Williams JC,Wang L,Su L,Suzuki M,Saito TI,Chiba S,Casola S,Yagita H,Teruya-Feldstein J,Tsuzuki S,Bhatia R,Maeda T
Category | C7
Sub-category |
Brief description | Genes down-regulated in germinal center B lymphocytes: wildtype versus ZBTB7A [GeneID=51341] knockout.
Full description | B cells are indispensable for humoral immunity, as they ultimately give rise to antibody-secreting plasma cells. During T cell-dependent antibody responses, naive B cells form germinal centers (GCs), a distinct histologic structure found in secondary lymphoid organs. Naive B cells become activated upon interaction with T cells and antigen presenting cells, and begin to rapidly proliferate and form the characteristic GC structure. To elucidate the overall effect of LRF loss in the GCB cell transcriptome, gene expression microarray analysis of FACS-sorted GCB cells was performed. LRF Flox/+ mb-1 Cre+ mice were used as a control to normalize the potential effects of Cre recombinase, and four RNA samples for each genotype were used for the analysis.

Standard name | GSE28449_WT_VS_LRF_KO_GERMINAL_CENTER_BCELL_UP
Systematic name | M8347
Organism | Mus musculus
PMID | 21646720
Authors | Sakurai N,Maeda M,Lee SU,Ishikawa Y,Li M,Williams JC,Wang L,Su L,Suzuki M,Saito TI,Chiba S,Casola S,Yagita H,Teruya-Feldstein J,Tsuzuki S,Bhatia R,Maeda T
Category | C7
Sub-category |
Brief description | Genes up-regulated in germinal center B lymphocytes: wildtype versus ZBTB7A [GeneID=51341] knockout.
Full description | B cells are indispensable for humoral immunity, as they ultimately give rise to antibody-secreting plasma cells. During T cell-dependent antibody responses, naive B cells form germinal centers (GCs), a distinct histologic structure found in secondary lymphoid organs. Naive B cells become activated upon interaction with T cells and antigen presenting cells, and begin to rapidly proliferate and form the characteristic GC structure. To elucidate the overall effect of LRF loss in the GCB cell transcriptome, gene expression microarray analysis of FACS-sorted GCB cells was performed. LRF Flox/+ mb-1 Cre+ mice were used as a control to normalize the potential effects of Cre recombinase, and four RNA samples for each genotype were used for the analysis.

Standard name | GSE28783_ANTI_MIR33_VS_UNTREATED_ATHEROSCLEROSIS_MACROPHAGE_UP
Systematic name | M8351
Organism | Mus musculus
PMID | 21646721
Authors | Rayner KJ,Sheedy FJ,Esau CC,Hussain FN,Temel RE,Parathath S,Gils van JM,Rayner AJ,Chang AN,Suarez Y,Fernandez-Hernando C,Fisher EA,Moore KJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in atherosclerosis macrophages: anti miR-33 versus untreated.
Full description | Inhibition of miR-33 results in increased cholesterol efflux and HDL-cholesterol levels in mice. In this study we examined the effect of miR-33 inhibition in a mouse model of atherosclerosis and observed significant reduction in atherosclerotic plaque size. At the end of the study, gene expression in macrophages from the atherosclerotic plaques was assessed. The results demonstrated a reduction in inflammatory gene expression and increased levels of mRNAs containing miR-33 binding sites.

Standard name | GSE28783_ANTI_MIR33_VS_UNTREATED_ATHEROSCLEROSIS_MACROPHAGE_DN
Systematic name | M8352
Organism | Mus musculus
PMID | 21646721
Authors | Rayner KJ,Sheedy FJ,Esau CC,Hussain FN,Temel RE,Parathath S,Gils van JM,Rayner AJ,Chang AN,Suarez Y,Fernandez-Hernando C,Fisher EA,Moore KJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in atherosclerosis macrophages: anti miR-33 versus untreated.
Full description | Inhibition of miR-33 results in increased cholesterol efflux and HDL-cholesterol levels in mice. In this study we examined the effect of miR-33 inhibition in a mouse model of atherosclerosis and observed significant reduction in atherosclerotic plaque size. At the end of the study, gene expression in macrophages from the atherosclerotic plaques was assessed. The results demonstrated a reduction in inflammatory gene expression and increased levels of mRNAs containing miR-33 binding sites.

Standard name | GSE28783_CTRL_ANTI_MIR_VS_UNTREATED_ATHEROSCLEROSIS_MACROPHAGE_UP
Systematic name | M8354
Organism | Mus musculus
PMID | 21646721
Authors | Rayner KJ,Sheedy FJ,Esau CC,Hussain FN,Temel RE,Parathath S,Gils van JM,Rayner AJ,Chang AN,Suarez Y,Fernandez-Hernando C,Fisher EA,Moore KJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in atherosclerosis macrophages: control anti miR ctrl versus untreated.
Full description | Inhibition of miR-33 results in increased cholesterol efflux and HDL-cholesterol levels in mice. In this study we examined the effect of miR-33 inhibition in a mouse model of atherosclerosis and observed significant reduction in atherosclerotic plaque size. At the end of the study, gene expression in macrophages from the atherosclerotic plaques was assessed. The results demonstrated a reduction in inflammatory gene expression and increased levels of mRNAs containing miR-33 binding sites.

Standard name | GSE28783_ANTI_MIR33_VS_CTRL_ATHEROSCLEROSIS_MACROPHAGE_DN
Systematic name | M8355
Organism | Mus musculus
PMID | 21646721
Authors | Rayner KJ,Sheedy FJ,Esau CC,Hussain FN,Temel RE,Parathath S,Gils van JM,Rayner AJ,Chang AN,Suarez Y,Fernandez-Hernando C,Fisher EA,Moore KJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in atherosclerosis macrophages: anti miR-33 versus anti miR.
Full description | Inhibition of miR-33 results in increased cholesterol efflux and HDL-cholesterol levels in mice. In this study we examined the effect of miR-33 inhibition in a mouse model of atherosclerosis and observed significant reduction in atherosclerotic plaque size. At the end of the study, gene expression in macrophages from the atherosclerotic plaques was assessed. The results demonstrated a reduction in inflammatory gene expression and increased levels of mRNAs containing miR-33 binding sites.

Standard name | GSE28783_CTRL_ANTI_MIR_VS_UNTREATED_ATHEROSCLEROSIS_MACROPHAGE_DN
Systematic name | M8356
Organism | Mus musculus
PMID | 21646721
Authors | Rayner KJ,Sheedy FJ,Esau CC,Hussain FN,Temel RE,Parathath S,Gils van JM,Rayner AJ,Chang AN,Suarez Y,Fernandez-Hernando C,Fisher EA,Moore KJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in atherosclerosis macrophages: control anti miR ctrl versus untreated.
Full description | Inhibition of miR-33 results in increased cholesterol efflux and HDL-cholesterol levels in mice. In this study we examined the effect of miR-33 inhibition in a mouse model of atherosclerosis and observed significant reduction in atherosclerotic plaque size. At the end of the study, gene expression in macrophages from the atherosclerotic plaques was assessed. The results demonstrated a reduction in inflammatory gene expression and increased levels of mRNAs containing miR-33 binding sites.

Standard name | GSE28783_ANTI_MIR33_VS_CTRL_ATHEROSCLEROSIS_MACROPHAGE_UP
Systematic name | M8357
Organism | Mus musculus
PMID | 21646721
Authors | Rayner KJ,Sheedy FJ,Esau CC,Hussain FN,Temel RE,Parathath S,Gils van JM,Rayner AJ,Chang AN,Suarez Y,Fernandez-Hernando C,Fisher EA,Moore KJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in atherosclerosis macrophages: anti miR-33 versus anti miR.
Full description | Inhibition of miR-33 results in increased cholesterol efflux and HDL-cholesterol levels in mice. In this study we examined the effect of miR-33 inhibition in a mouse model of atherosclerosis and observed significant reduction in atherosclerotic plaque size. At the end of the study, gene expression in macrophages from the atherosclerotic plaques was assessed. The results demonstrated a reduction in inflammatory gene expression and increased levels of mRNAs containing miR-33 binding sites.

Standard name | GSE19512_NAUTRAL_VS_INDUCED_TREG_DN
Systematic name | M8359
Organism | Mus musculus
PMID | 21723159
Authors | Haribhai D,Williams JB,Jia S,Nickerson D,Schmitt EG,Edwards B,Ziegelbauer J,Yassai M,Li SH,Relland LM,Wise PM,Chen A,Zheng YQ,Simpson PM,Gorski J,Salzman NH,Hessner MJ,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: natural versus induced cells.
Full description | The relative contribution of induced and natural Foxp3+ regulatory T cells (iTreg and nTreg cells, respectively) to the maintenance of tolerance is unknown. We examined their respective roles by in vivo adoptive transfer immunotherapy of newborn Foxp3-deficient BALB/c mice. Survival, weight gain, tissue infiltration, T cell activation, and the concentration of proinflammatory cytokines were used as outcome measurements. Treatment with iTreg cells alone was not successful. While effective in preventing death, treatment with nTreg cells alone was associated with chronic inflammation and autoimmunity. Outcomes markedly improved when conventional T (Tconv) cells were transferred together with the nTreg cells, where 10% of the peripheral Treg cell pool was derived by in-situ conversion. This enhancement depended upon the capacity of Tconv cells to express Foxp3. The gene expression profile of in vivo derived iTreg cells was similar to the established nTreg cell genetic signature. These results identify iTreg cells as an essential regulatory subset that supplements tolerance maintained by nTreg cells.

Standard name | GSE19512_NAUTRAL_VS_INDUCED_TREG_UP
Systematic name | M8361
Organism | Mus musculus
PMID | 21723159
Authors | Haribhai D,Williams JB,Jia S,Nickerson D,Schmitt EG,Edwards B,Ziegelbauer J,Yassai M,Li SH,Relland LM,Wise PM,Chen A,Zheng YQ,Simpson PM,Gorski J,Salzman NH,Hessner MJ,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: natural versus induced cells.
Full description | The relative contribution of induced and natural Foxp3+ regulatory T cells (iTreg and nTreg cells, respectively) to the maintenance of tolerance is unknown. We examined their respective roles by in vivo adoptive transfer immunotherapy of newborn Foxp3-deficient BALB/c mice. Survival, weight gain, tissue infiltration, T cell activation, and the concentration of proinflammatory cytokines were used as outcome measurements. Treatment with iTreg cells alone was not successful. While effective in preventing death, treatment with nTreg cells alone was associated with chronic inflammation and autoimmunity. Outcomes markedly improved when conventional T (Tconv) cells were transferred together with the nTreg cells, where 10% of the peripheral Treg cell pool was derived by in-situ conversion. This enhancement depended upon the capacity of Tconv cells to express Foxp3. The gene expression profile of in vivo derived iTreg cells was similar to the established nTreg cell genetic signature. These results identify iTreg cells as an essential regulatory subset that supplements tolerance maintained by nTreg cells.

Standard name | GSE22501_PERIPHERAL_BLOOD_VS_CORD_BLOOD_TREG_DN
Systematic name | M8367
Organism | Homo sapiens
PMID | 21732086
Authors | Torelli GF,Maggio R,Peragine N,Chiaretti S,Propris De MS,Lucarelli B,Screnci M,Mascolo MG,Milano F,Iori AP,Girelli G,Guarini A,Foà R
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg from: peripheral blood versus cord blood.
Full description | Since the role of cord blood (CB) regulatory T cells (Tregs) for the suppression of the allogeneic T-cell response is under investigation, we analyzed and compared the functional properties and gene expression profile of Tregs expanded from CB units or from the peripheral blood (PB) of helathy donors. Tregs were purified from 23 CB units and from the PB of 13 donors and expanded for 6 days with anti-CD3, anti-CD28 and IL-2. Immunophenotypic analyses were performed, and suppressor activity of expanded Tregs was measured in mixed lymphocyte reaction (MLR) cultures. The IL-10 production capacity was tested and gene expression profile experiments were performed on 6 Tregs from PB and 4 from CB. CB and PB Tregs had similar immunophenotypic features. Tregs from CB presented a higher expansion capacity and genomic characterization showed in CB-derived Tregs a significant enrichments of genes involved in cell proliferation, chromatin modification and regulation of gene expression in CB-derived Tregs. All samples were positive for the Foxp3 gene and protein after expansion. CB and PB expanded Tregs exerted a comparable and potent suppressive function of MLR and presented a high in vitro IL-10 production capacity. Gene profile analysis also revealed for PB Tregs a significant enrichments of genes involved in the adaptive immune response.

Standard name | GSE22501_PERIPHERAL_BLOOD_VS_CORD_BLOOD_TREG_UP
Systematic name | M8370
Organism | Homo sapiens
PMID | 21732086
Authors | Torelli GF,Maggio R,Peragine N,Chiaretti S,Propris De MS,Lucarelli B,Screnci M,Mascolo MG,Milano F,Iori AP,Girelli G,Guarini A,Foà R
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg from: peripheral blood versus cord blood.
Full description | Since the role of cord blood (CB) regulatory T cells (Tregs) for the suppression of the allogeneic T-cell response is under investigation, we analyzed and compared the functional properties and gene expression profile of Tregs expanded from CB units or from the peripheral blood (PB) of helathy donors. Tregs were purified from 23 CB units and from the PB of 13 donors and expanded for 6 days with anti-CD3, anti-CD28 and IL-2. Immunophenotypic analyses were performed, and suppressor activity of expanded Tregs was measured in mixed lymphocyte reaction (MLR) cultures. The IL-10 production capacity was tested and gene expression profile experiments were performed on 6 Tregs from PB and 4 from CB. CB and PB Tregs had similar immunophenotypic features. Tregs from CB presented a higher expansion capacity and genomic characterization showed in CB-derived Tregs a significant enrichments of genes involved in cell proliferation, chromatin modification and regulation of gene expression in CB-derived Tregs. All samples were positive for the Foxp3 gene and protein after expansion. CB and PB expanded Tregs exerted a comparable and potent suppressive function of MLR and presented a high in vitro IL-10 production capacity. Gene profile analysis also revealed for PB Tregs a significant enrichments of genes involved in the adaptive immune response.

Standard name | GSE22025_UNTREATED_VS_TGFB1_TREATED_CD4_TCELL_UP
Systematic name | M8371
Organism | Homo sapiens
PMID | 21768398
Authors | Lee JH,Ulrich B,Cho J,Park J,Kim CH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated versus TGFB1 [GeneID=7040].
Full description | We examined the global gene expression pattern of T cells regulated by progesterone to gain further insights into the regulatory mechanisms of progesterone. We found 325-347 cord blood T cell genes up or down-regulated by P4 in the presence or absence of exogenous TGFb1. Peripheral blood T cells were relatively unresponsive with only 30-70 genes regulated by P4. IL-6 receptor (IL-6R) expression was greatly down-regulated by progesterone in cord blood, but not PB, T cells. Overall, these differences in gene expression are consistent with the differential responses of cord blood and peripheral blood T cells to progesterone. To gain insights into the differences of progesterone and control dendritic cells, we performed a microarray study and found ~180 genes regulated by progesterone in dendritic cells. The gene expression information suggests that progesterone has the potential to alter dendritic cell responses to cytokines, chemokine production, and migration which in combination would control T cell differentiation.

Standard name | GSE22025_UNTREATED_VS_PROGESTERONE_TREATED_CD4_TCELL_UP
Systematic name | M8377
Organism | Homo sapiens
PMID | 21768398
Authors | Lee JH,Ulrich B,Cho J,Park J,Kim CH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated versus progesterone [PubChem=5994].
Full description | We examined the global gene expression pattern of T cells regulated by progesterone to gain further insights into the regulatory mechanisms of progesterone. We found 325-347 cord blood T cell genes up or down-regulated by P4 in the presence or absence of exogenous TGFb1. Peripheral blood T cells were relatively unresponsive with only 30-70 genes regulated by P4. IL-6 receptor (IL-6R) expression was greatly down-regulated by progesterone in cord blood, but not PB, T cells. Overall, these differences in gene expression are consistent with the differential responses of cord blood and peripheral blood T cells to progesterone. To gain insights into the differences of progesterone and control dendritic cells, we performed a microarray study and found ~180 genes regulated by progesterone in dendritic cells. The gene expression information suggests that progesterone has the potential to alter dendritic cell responses to cytokines, chemokine production, and migration which in combination would control T cell differentiation.

Standard name | GSE22025_PROGESTERONE_VS_TGFB1_AND_PROGESTERONE_TREATED_CD4_TCELL_DN
Systematic name | M8379
Organism | Homo sapiens
PMID | 21768398
Authors | Lee JH,Ulrich B,Cho J,Park J,Kim CH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: progesterone [PubChem=5994] versus TGFB1 [GeneID=7040] and progesterone [PubChem=5994].
Full description | We examined the global gene expression pattern of T cells regulated by progesterone to gain further insights into the regulatory mechanisms of progesterone. We found 325-347 cord blood T cell genes up or down-regulated by P4 in the presence or absence of exogenous TGFb1. Peripheral blood T cells were relatively unresponsive with only 30-70 genes regulated by P4. IL-6 receptor (IL-6R) expression was greatly down-regulated by progesterone in cord blood, but not PB, T cells. Overall, these differences in gene expression are consistent with the differential responses of cord blood and peripheral blood T cells to progesterone. To gain insights into the differences of progesterone and control dendritic cells, we performed a microarray study and found ~180 genes regulated by progesterone in dendritic cells. The gene expression information suggests that progesterone has the potential to alter dendritic cell responses to cytokines, chemokine production, and migration which in combination would control T cell differentiation.

Standard name | GSE22025_TGFB1_VS_TGFB1_AND_PROGESTERONE_TREATED_CD4_TCELL_UP
Systematic name | M8380
Organism | Homo sapiens
PMID | 21768398
Authors | Lee JH,Ulrich B,Cho J,Park J,Kim CH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: TGFB1 [GeneID=7040] versus TGFB1 [GeneID=7040] and progesterone [PubChem=5994].
Full description | We examined the global gene expression pattern of T cells regulated by progesterone to gain further insights into the regulatory mechanisms of progesterone. We found 325-347 cord blood T cell genes up or down-regulated by P4 in the presence or absence of exogenous TGFb1. Peripheral blood T cells were relatively unresponsive with only 30-70 genes regulated by P4. IL-6 receptor (IL-6R) expression was greatly down-regulated by progesterone in cord blood, but not PB, T cells. Overall, these differences in gene expression are consistent with the differential responses of cord blood and peripheral blood T cells to progesterone. To gain insights into the differences of progesterone and control dendritic cells, we performed a microarray study and found ~180 genes regulated by progesterone in dendritic cells. The gene expression information suggests that progesterone has the potential to alter dendritic cell responses to cytokines, chemokine production, and migration which in combination would control T cell differentiation.

Standard name | GSE22025_PROGESTERONE_VS_TGFB1_AND_PROGESTERONE_TREATED_CD4_TCELL_UP
Systematic name | M8381
Organism | Homo sapiens
PMID | 21768398
Authors | Lee JH,Ulrich B,Cho J,Park J,Kim CH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: progesterone [PubChem=5994] versus TGFB1 [GeneID=7040] and progesterone [PubChem=5994].
Full description | We examined the global gene expression pattern of T cells regulated by progesterone to gain further insights into the regulatory mechanisms of progesterone. We found 325-347 cord blood T cell genes up or down-regulated by P4 in the presence or absence of exogenous TGFb1. Peripheral blood T cells were relatively unresponsive with only 30-70 genes regulated by P4. IL-6 receptor (IL-6R) expression was greatly down-regulated by progesterone in cord blood, but not PB, T cells. Overall, these differences in gene expression are consistent with the differential responses of cord blood and peripheral blood T cells to progesterone. To gain insights into the differences of progesterone and control dendritic cells, we performed a microarray study and found ~180 genes regulated by progesterone in dendritic cells. The gene expression information suggests that progesterone has the potential to alter dendritic cell responses to cytokines, chemokine production, and migration which in combination would control T cell differentiation.

Standard name | GSE22025_UNTREATED_VS_TGFB1_AND_PROGESTERONE_TREATED_CD4_TCELL_UP
Systematic name | M8383
Organism | Homo sapiens
PMID | 21768398
Authors | Lee JH,Ulrich B,Cho J,Park J,Kim CH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: untreated versus TGFB1 [GeneID=7040] and progesterone [PubChem=5994].
Full description | We examined the global gene expression pattern of T cells regulated by progesterone to gain further insights into the regulatory mechanisms of progesterone. We found 325-347 cord blood T cell genes up or down-regulated by P4 in the presence or absence of exogenous TGFb1. Peripheral blood T cells were relatively unresponsive with only 30-70 genes regulated by P4. IL-6 receptor (IL-6R) expression was greatly down-regulated by progesterone in cord blood, but not PB, T cells. Overall, these differences in gene expression are consistent with the differential responses of cord blood and peripheral blood T cells to progesterone. To gain insights into the differences of progesterone and control dendritic cells, we performed a microarray study and found ~180 genes regulated by progesterone in dendritic cells. The gene expression information suggests that progesterone has the potential to alter dendritic cell responses to cytokines, chemokine production, and migration which in combination would control T cell differentiation.

Standard name | GSE22025_UNTREATED_VS_PROGESTERONE_TREATED_CD4_TCELL_DN
Systematic name | M8384
Organism | Homo sapiens
PMID | 21768398
Authors | Lee JH,Ulrich B,Cho J,Park J,Kim CH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated versus progesterone [PubChem=5994].
Full description | We examined the global gene expression pattern of T cells regulated by progesterone to gain further insights into the regulatory mechanisms of progesterone. We found 325-347 cord blood T cell genes up or down-regulated by P4 in the presence or absence of exogenous TGFb1. Peripheral blood T cells were relatively unresponsive with only 30-70 genes regulated by P4. IL-6 receptor (IL-6R) expression was greatly down-regulated by progesterone in cord blood, but not PB, T cells. Overall, these differences in gene expression are consistent with the differential responses of cord blood and peripheral blood T cells to progesterone. To gain insights into the differences of progesterone and control dendritic cells, we performed a microarray study and found ~180 genes regulated by progesterone in dendritic cells. The gene expression information suggests that progesterone has the potential to alter dendritic cell responses to cytokines, chemokine production, and migration which in combination would control T cell differentiation.

Standard name | GSE22025_UNTREATED_VS_TGFB1_TREATED_CD4_TCELL_DN
Systematic name | M8385
Organism | Homo sapiens
PMID | 21768398
Authors | Lee JH,Ulrich B,Cho J,Park J,Kim CH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated versus TGFB1 [GeneID=7040].
Full description | We examined the global gene expression pattern of T cells regulated by progesterone to gain further insights into the regulatory mechanisms of progesterone. We found 325-347 cord blood T cell genes up or down-regulated by P4 in the presence or absence of exogenous TGFb1. Peripheral blood T cells were relatively unresponsive with only 30-70 genes regulated by P4. IL-6 receptor (IL-6R) expression was greatly down-regulated by progesterone in cord blood, but not PB, T cells. Overall, these differences in gene expression are consistent with the differential responses of cord blood and peripheral blood T cells to progesterone. To gain insights into the differences of progesterone and control dendritic cells, we performed a microarray study and found ~180 genes regulated by progesterone in dendritic cells. The gene expression information suggests that progesterone has the potential to alter dendritic cell responses to cytokines, chemokine production, and migration which in combination would control T cell differentiation.

Standard name | GSE22025_UNTREATED_VS_TGFB1_AND_PROGESTERONE_TREATED_CD4_TCELL_DN
Systematic name | M8386
Organism | Homo sapiens
PMID | 21768398
Authors | Lee JH,Ulrich B,Cho J,Park J,Kim CH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: untreated versus TGFB1 [GeneID=7040] and progesterone [PubChem=5994].
Full description | We examined the global gene expression pattern of T cells regulated by progesterone to gain further insights into the regulatory mechanisms of progesterone. We found 325-347 cord blood T cell genes up or down-regulated by P4 in the presence or absence of exogenous TGFb1. Peripheral blood T cells were relatively unresponsive with only 30-70 genes regulated by P4. IL-6 receptor (IL-6R) expression was greatly down-regulated by progesterone in cord blood, but not PB, T cells. Overall, these differences in gene expression are consistent with the differential responses of cord blood and peripheral blood T cells to progesterone. To gain insights into the differences of progesterone and control dendritic cells, we performed a microarray study and found ~180 genes regulated by progesterone in dendritic cells. The gene expression information suggests that progesterone has the potential to alter dendritic cell responses to cytokines, chemokine production, and migration which in combination would control T cell differentiation.

Standard name | GSE22025_TGFB1_VS_TGFB1_AND_PROGESTERONE_TREATED_CD4_TCELL_DN
Systematic name | M8388
Organism | Homo sapiens
PMID | 21768398
Authors | Lee JH,Ulrich B,Cho J,Park J,Kim CH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: TGFB1 [GeneID=7040] versus TGFB1 [GeneID=7040] and progesterone [PubChem=5994].
Full description | We examined the global gene expression pattern of T cells regulated by progesterone to gain further insights into the regulatory mechanisms of progesterone. We found 325-347 cord blood T cell genes up or down-regulated by P4 in the presence or absence of exogenous TGFb1. Peripheral blood T cells were relatively unresponsive with only 30-70 genes regulated by P4. IL-6 receptor (IL-6R) expression was greatly down-regulated by progesterone in cord blood, but not PB, T cells. Overall, these differences in gene expression are consistent with the differential responses of cord blood and peripheral blood T cells to progesterone. To gain insights into the differences of progesterone and control dendritic cells, we performed a microarray study and found ~180 genes regulated by progesterone in dendritic cells. The gene expression information suggests that progesterone has the potential to alter dendritic cell responses to cytokines, chemokine production, and migration which in combination would control T cell differentiation.

Standard name | GSE29949_MICROGLIA_BRAIN_VS_MONOCYTE_BONE_MARROW_DN
Systematic name | M8389
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes down-regulated in brain microglia versus bone marrow monocytes.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_CD8_NEG_DC_SPLEEN_VS_CD8_POS_DC_SPLEEN_UP
Systematic name | M8390
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen dendritic cells: CD8- versus CD8+.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_CD8_NEG_DC_SPLEEN_VS_CD8_POS_DC_SPLEEN_DN
Systematic name | M8391
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen dendritic cells: CD8- versus CD8+.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_CD8_NEG_DC_SPLEEN_VS_DC_BRAIN_UP
Systematic name | M8394
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: spleen CD8- versus brain.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_MICROGLIA_BRAIN_VS_CD8_POS_DC_SPLEEN_UP
Systematic name | M8396
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes up-regulated in brain microglia versus spleen CD8+ dendritic cells.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_MICROGLIA_BRAIN_VS_CD8_POS_DC_SPLEEN_DN
Systematic name | M8398
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes down-regulated in brain microglia versus spleen CD8+ dendritic cells.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_MICROGLIA_VS_DC_BRAIN_UP
Systematic name | M8399
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes up-regulated in brain: microglia versus dendritic cells.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_MICROGLIA_BRAIN_VS_CD8_NEG_DC_SPLEEN_DN
Systematic name | M8400
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes down-regulated in brain microglia versus spleen CD8- dendritic cells.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_MICROGLIA_BRAIN_VS_MONOCYTE_BONE_MARROW_UP
Systematic name | M8401
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes up-regulated in brain microglia versus bone marrow monocytes.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_CD8_NEG_DC_SPLEEN_VS_DC_BRAIN_DN
Systematic name | M8403
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: spleen CD8- versus brain.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_CD8_NEG_DC_SPLEEN_VS_MONOCYTE_BONE_MARROW_UP
Systematic name | M8404
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen CD8- dendritic cells versus bone marrow monocytes.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_MICROGLIA_VS_DC_BRAIN_DN
Systematic name | M8405
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes down-regulated in brain: microglia versus dendritic cells.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_CD8_POS_DC_SPLEEN_VS_DC_BRAIN_UP
Systematic name | M8407
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: CD8+ spleen versus brain.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_CD8_POS_DC_SPLEEN_VS_DC_BRAIN_DN
Systematic name | M8408
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: CD8+ spleen versus brain.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_CD8_POS_DC_SPLEEN_VS_MONOCYTE_BONE_MARROW_UP
Systematic name | M8414
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen CD8+ dendritic cells versus bone marrow monocytes.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_CD8_POS_DC_SPLEEN_VS_MONOCYTE_BONE_MARROW_DN
Systematic name | M8415
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen CD8+ dendritic cells versus bone marrow monocytes.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_DC_BRAIN_VS_MONOCYTE_BONE_MARROW_UP
Systematic name | M8418
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes up-regulated in brain dendritic cells versus bone marrow monocytes.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_DC_BRAIN_VS_MONOCYTE_BONE_MARROW_DN
Systematic name | M8419
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes down-regulated in brain dendritic cells versus bone marrow monocytes.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_CD8_NEG_DC_SPLEEN_VS_MONOCYTE_BONE_MARROW_DN
Systematic name | M8420
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen CD8- dendritic cells versus bone marrow monocytes.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE29949_MICROGLIA_BRAIN_VS_CD8_NEG_DC_SPLEEN_UP
Systematic name | M8421
Organism | Mus musculus
PMID | 21788405
Authors | Anandasabapathy N,Victora GD,Meredith M,Feder R,Dong B,Kluger C,Yao K,Dustin ML,Nussenzweig MC,Steinman RM,Liu K
Category | C7
Sub-category |
Brief description | Genes up-regulated in brain microglia versus spleen CD8- dendritic cells.
Full description | To understand the functional relationship between brain dendritic cells (brain DCs) and other myeloid cells, we compared the gene expression profile of m/chDCs to that of bone marrow monocytes, brain microglia and classical spleen CD8+ and CD8- DCs. In order to obtain enough brain DCs for mRNA extraction, we expanded brain DCs with in vivo Flt3L treatment before purification.

Standard name | GSE26559_TCF1_KO_VS_WT_LIN_NEG_CELL_DN
Systematic name | M8422
Organism | Mus musculus
PMID | 21814277
Authors | Weber BN,Chi AW,Chavez A,Yashiro-Ohtani Y,Yang Q,Shestova O,Bhandoola A
Category | C7
Sub-category |
Brief description | Genes down-regulated in lin- cells: TCF7 [GeneID=6932] knockout versus wildtype.
Full description | Tcf1 is necessary for optimal T lineage development. Tcf1 deficient progenitors fail to initiate the T lineage program in vitro and development is severely defective in vivo. We used microarrays to assess the overal global gene expression differences from Tcf1 wildtype and deficient lymphoid biased progenitors cultures on Notch-ligand expressing stroma to determine if Tcf1 deficient progenitors are able to intiate the T lineage specification program. Abstract of manuscript: The thymus imposes the T cell fate on incoming multipotent progenitors, but the molecular mechanisms are poorly understood. We show that transcription factor Tcf1 initiates T-lineage-specific gene expression. Tcf1 is downstream of Notch1 signaling and expressed in early T-cell progenitors. Progenitors deficient for Tcf1 are unable to initiate normal T-lineage specification. Conversely, ectopic expression of Tcf1 in hematopoietic progenitors is sufficient to induce expression of T-lineage specific genes in vitro. Thus, our study identifies Tcf1 as critically involved in the establishment T cell identity.

Standard name | GSE26559_TCF1_KO_VS_WT_LIN_NEG_CELL_UP
Systematic name | M8423
Organism | Mus musculus
PMID | 21814277
Authors | Weber BN,Chi AW,Chavez A,Yashiro-Ohtani Y,Yang Q,Shestova O,Bhandoola A
Category | C7
Sub-category |
Brief description | Genes up-regulated in lin- cells: TCF7 [GeneID=6932] knockout versus wildtype.
Full description | Tcf1 is necessary for optimal T lineage development. Tcf1 deficient progenitors fail to initiate the T lineage program in vitro and development is severely defective in vivo. We used microarrays to assess the overal global gene expression differences from Tcf1 wildtype and deficient lymphoid biased progenitors cultures on Notch-ligand expressing stroma to determine if Tcf1 deficient progenitors are able to intiate the T lineage specification program. Abstract of manuscript: The thymus imposes the T cell fate on incoming multipotent progenitors, but the molecular mechanisms are poorly understood. We show that transcription factor Tcf1 initiates T-lineage-specific gene expression. Tcf1 is downstream of Notch1 signaling and expressed in early T-cell progenitors. Progenitors deficient for Tcf1 are unable to initiate normal T-lineage specification. Conversely, ectopic expression of Tcf1 in hematopoietic progenitors is sufficient to induce expression of T-lineage specific genes in vitro. Thus, our study identifies Tcf1 as critically involved in the establishment T cell identity.

Standard name | GSE30153_LUPUS_VS_HEALTHY_DONOR_BCELL_DN
Systematic name | M8424
Organism | Homo sapiens
PMID | 21886837
Authors | Garaud JC,Schickel JN,Blaison G,Knapp AM,Dembele D,Ruer-Laventie J,Korganow AS,Martin T,Soulas-Sprauel P,Pasquali JL
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: systemic lupus erythematosous (SLE) versus healthy.
Full description | Systemic lupus erythematosous (SLE) is an autoimmune disease with an important clinical and biological heterogeneity. B lymphocytes appear central to the development of SLE which is characterized by the production of a large variety of autoantibodies and hypergammaglobulinemia. In mice, immature B cells from spontaneous lupus prone animals are able to produce autoantibodies when transferred into immunodeficient mice, strongly suggesting the existence of intrinsic B cell defects during lupus. In order to approach these defects in humans, we compared the peripheral B cell transcriptomes of quiescent lupus patients to normal B cell transcriptomes.

Standard name | GSE30153_LUPUS_VS_HEALTHY_DONOR_BCELL_UP
Systematic name | M8425
Organism | Homo sapiens
PMID | 21886837
Authors | Garaud JC,Schickel JN,Blaison G,Knapp AM,Dembele D,Ruer-Laventie J,Korganow AS,Martin T,Soulas-Sprauel P,Pasquali JL
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: systemic lupus erythematosous (SLE) versus healthy.
Full description | Systemic lupus erythematosous (SLE) is an autoimmune disease with an important clinical and biological heterogeneity. B lymphocytes appear central to the development of SLE which is characterized by the production of a large variety of autoantibodies and hypergammaglobulinemia. In mice, immature B cells from spontaneous lupus prone animals are able to produce autoantibodies when transferred into immunodeficient mice, strongly suggesting the existence of intrinsic B cell defects during lupus. In order to approach these defects in humans, we compared the peripheral B cell transcriptomes of quiescent lupus patients to normal B cell transcriptomes.

Standard name | GSE24814_STAT5_KO_VS_WT_PRE_BCELL_UP
Systematic name | M8426
Organism | Mus musculus
PMID | 21911423
Authors | Hurtz C,Hatzi K,Cerchietti L,Braig M,Park E,Kim YM,Herzog S,Ramezani-Rad P,Jumaa H,Müller MC,Hofmann WK,Hochhaus A,Ye BH,Agarwal A,Druker BJ,Shah NP,Melnick AM,Müschen M
Category | C7
Sub-category |
Brief description | Genes up-regulated in pre-B cells: STAT5 knockout versus wildtype.
Full description | In order to investigate the function of STAT5 in ALL, we isolated bone marrow cells from STAT5 fl/fl mice and transformed them with BCR-ABL1. In a second transduction the BCR-ABL1 driven pre-B cells were transformed either with CRE-GFP or empty vector control (GFP) and subjected to gene expression analysis.

Standard name | GSE24814_STAT5_KO_VS_WT_PRE_BCELL_DN
Systematic name | M8427
Organism | Mus musculus
PMID | 21911423
Authors | Hurtz C,Hatzi K,Cerchietti L,Braig M,Park E,Kim YM,Herzog S,Ramezani-Rad P,Jumaa H,Müller MC,Hofmann WK,Hochhaus A,Ye BH,Agarwal A,Druker BJ,Shah NP,Melnick AM,Müschen M
Category | C7
Sub-category |
Brief description | Genes down-regulated in pre-B cells: STAT5 knockout versus wildtype.
Full description | In order to investigate the function of STAT5 in ALL, we isolated bone marrow cells from STAT5 fl/fl mice and transformed them with BCR-ABL1. In a second transduction the BCR-ABL1 driven pre-B cells were transformed either with CRE-GFP or empty vector control (GFP) and subjected to gene expression analysis.

Standard name | GSE23321_EFFECTOR_MEMORY_VS_NAIVE_CD8_TCELL_UP
Systematic name | M8428
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: effector memory versus naïve.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_CD8_STEM_CELL_MEMORY_VS_EFFECTOR_MEMORY_CD8_TCELL_UP
Systematic name | M8429
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: stem cell memory versus effector memory.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_CD8_STEM_CELL_MEMORY_VS_EFFECTOR_MEMORY_CD8_TCELL_DN
Systematic name | M8430
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: stem cell memory versus effector memory.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_CENTRAL_MEMORY_VS_NAIVE_CD8_TCELL_DN
Systematic name | M8431
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: central memory versus naïve.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_CENTRAL_VS_EFFECTOR_MEMORY_CD8_TCELL_UP
Systematic name | M8433
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: central memory versus effector memory.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_CENTRAL_VS_EFFECTOR_MEMORY_CD8_TCELL_DN
Systematic name | M8434
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: central memory versus effector memory.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_CENTRAL_MEMORY_VS_NAIVE_CD8_TCELL_UP
Systematic name | M8435
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: central memory versus naïve.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_CD8_STEM_CELL_MEMORY_VS_CENTRAL_MEMORY_CD8_TCELL_UP
Systematic name | M8436
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: stem cell memory versus central memory.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_CD8_STEM_CELL_MEMORY_VS_CENTRAL_MEMORY_CD8_TCELL_DN
Systematic name | M8438
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: stem cell memory versus central memory.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_CD8_STEM_CELL_MEMORY_VS_NAIVE_CD8_TCELL_UP
Systematic name | M8440
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: stem cell memory versus naïve.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_CD8_STEM_CELL_MEMORY_VS_NAIVE_CD8_TCELL_DN
Systematic name | M8441
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: stem cell memory versus naïve.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE23321_EFFECTOR_MEMORY_VS_NAIVE_CD8_TCELL_DN
Systematic name | M8442
Organism | Homo sapiens
PMID | 21926977
Authors | Gattinoni L,Lugli E,Ji Y,Pos Z,Paulos CM,Quigley MF,Almeida JR,Gostick E,Yu Z,Carpenito C,Wang E,Douek DC,Price DA,June CH,Marincola FM,Roederer M,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: effector memory versus naïve.
Full description | An early-differentiated CD8+ memory T cell subset with stem cell-like properties (TSCM) can be identified within the naïve-like T cell population by the expression of CD95/Fas. Based on experiments including exon- and gene-level expression analysis, we provide evidence that this subset of antigen-specific cells represents an early precursor of conventional central (TCM) and effector (TEM) memory CD8+ T cells with enhanced self-renewal capacity and proliferative potential. We identified 900 genes differentially expressed between major T cell subsets defined along with memory T cell commitment. Based on the analysis of these genes, CD95+ naïve T cells (TSCM) cluster closer to the CD8+ T memory compartment than to classical (CD95-) naïve T (TN) cells, and display an intermittent phenotype between classical TN and TCM cells in terms of all major T cell differentiation markers analyzed.

Standard name | GSE46468_LUNG_INNATE_LYMPHOID_CELL_VS_SPLEEN_CD4_TCELL_UP
Systematic name | M8443
Organism | Mus musculus
PMID | 21946417
Authors | Monticelli LA,Sonnenberg GF,Abt MC,Alenghat T,Ziegler CG,Doering TA,Angelosanto JM,Laidlaw BJ,Yang CY,Sathaliyawala T,Kubota M,Turner D,Diamond JM,Goldrath AW,Farber DL,Collman RG,Wherry EJ,Artis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in lung innate lymphoid cells versus spleen CD4 [GeneID=920] T cells.
Full description | Innate lymphoid cells (ILCs) are a recently recognized heterogenous group of immune cells that are critical in orchestrating immunity and inflammation in the intestine, but whether ILCs influence immune responses or tissue homeostasis at other mucosal sites remains poorly characterized. Here we identify a population of lung-resident ILCs in mice and humans that expressed the alloantigen Thy-1 (CD90), interleukin 2 (IL-2) receptor a-chain (CD25), IL-7 receptor a-chain (CD127) and the IL-33 receptor subunit T1-ST2. Notably, mouse ILCs accumulated in the lung after infection with influenza virus, and depletion of ILCs resulted in loss of airway epithelial integrity, diminished lung function and impaired airway remodeling. These defects were restored by administration of the lung ILC product amphiregulin. Collectively, our results demonstrate a critical role for lung ILCs in restoring airway epithelial integrity and tissue homeostasis after infection with influenza virus. As part of this study, we performed gene expression profiling to examine how the transcriptional signatures compared between murine naïve group 2 lung ILC and group 3 splenic LTi cell populations.

Standard name | GSE46468_LUNG_INNATE_LYMPHOID_CELL_VS_SPLEEN_CD4_TCELL_DN
Systematic name | M8444
Organism | Mus musculus
PMID | 21946417
Authors | Monticelli LA,Sonnenberg GF,Abt MC,Alenghat T,Ziegler CG,Doering TA,Angelosanto JM,Laidlaw BJ,Yang CY,Sathaliyawala T,Kubota M,Turner D,Diamond JM,Goldrath AW,Farber DL,Collman RG,Wherry EJ,Artis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in lung innate lymphoid cells versus spleen CD4 [GeneID=920] T cells.
Full description | Innate lymphoid cells (ILCs) are a recently recognized heterogenous group of immune cells that are critical in orchestrating immunity and inflammation in the intestine, but whether ILCs influence immune responses or tissue homeostasis at other mucosal sites remains poorly characterized. Here we identify a population of lung-resident ILCs in mice and humans that expressed the alloantigen Thy-1 (CD90), interleukin 2 (IL-2) receptor a-chain (CD25), IL-7 receptor a-chain (CD127) and the IL-33 receptor subunit T1-ST2. Notably, mouse ILCs accumulated in the lung after infection with influenza virus, and depletion of ILCs resulted in loss of airway epithelial integrity, diminished lung function and impaired airway remodeling. These defects were restored by administration of the lung ILC product amphiregulin. Collectively, our results demonstrate a critical role for lung ILCs in restoring airway epithelial integrity and tissue homeostasis after infection with influenza virus. As part of this study, we performed gene expression profiling to examine how the transcriptional signatures compared between murine naïve group 2 lung ILC and group 3 splenic LTi cell populations.

Standard name | GSE27291_0H_VS_6H_STIM_GAMMADELTA_TCELL_UP
Systematic name | M8446
Organism | Homo sapiens
PMID | 21968650
Authors | Pont F,Familiades J,Déjean S,Fruchon S,Cendron D,Poupot M,Poupot R,L'faqihi-Olive F,Prade N,Ycart B,Fournié JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in gamma delta T cells activated by phophoantigen BrHPP and IL2 [GeneID=3558]: 0h versus 6h.
Full description | We used microarrays to detail the global programme of gene expression by circulating TCRVgamma9+ gamma delta T cells isolated from healthy individuals,tested either as resting cells or cells activated by phosphoantigen BrHPP and IL-2at an early(+6hrs) and a late (+7days) timepoint. We find that with more “NK cell” genes than alphabeta T cells and more “T cell” genes than NK cells, the circulating TCRVgamma9+ gamma delta T cells cells have a hybrid transcriptome. The gene signature of the activated cells recapitulates their physiological functions: Th1 cytokine, chemokine and cytotoxic activities at first and mitotic activity at later time points. The gene expression pattern of activated normal gamma delta T cells is nevertheless clearly distinctive from that of NK/T and peripheral T cell lymphomas of the gamma delta subtype.

Standard name | GSE27291_0H_VS_7D_STIM_GAMMADELTA_TCELL_UP
Systematic name | M8452
Organism | Homo sapiens
PMID | 21968650
Authors | Pont F,Familiades J,Déjean S,Fruchon S,Cendron D,Poupot M,Poupot R,L'faqihi-Olive F,Prade N,Ycart B,Fournié JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in gamma delta T cells activated by phophoantigen BrHPP and IL2 [GeneID=3558]: 0h versus 7 days.
Full description | We used microarrays to detail the global programme of gene expression by circulating TCRVgamma9+ gamma delta T cells isolated from healthy individuals,tested either as resting cells or cells activated by phosphoantigen BrHPP and IL-2at an early(+6hrs) and a late (+7days) timepoint. We find that with more “NK cell” genes than alphabeta T cells and more “T cell” genes than NK cells, the circulating TCRVgamma9+ gamma delta T cells cells have a hybrid transcriptome. The gene signature of the activated cells recapitulates their physiological functions: Th1 cytokine, chemokine and cytotoxic activities at first and mitotic activity at later time points. The gene expression pattern of activated normal gamma delta T cells is nevertheless clearly distinctive from that of NK/T and peripheral T cell lymphomas of the gamma delta subtype.

Standard name | GSE27291_0H_VS_6H_STIM_GAMMADELTA_TCELL_DN
Systematic name | M8453
Organism | Homo sapiens
PMID | 21968650
Authors | Pont F,Familiades J,Déjean S,Fruchon S,Cendron D,Poupot M,Poupot R,L'faqihi-Olive F,Prade N,Ycart B,Fournié JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in gamma delta T cells activated by phophoantigen BrHPP and IL2 [GeneID=3558]: 0h versus 6h.
Full description | We used microarrays to detail the global programme of gene expression by circulating TCRVgamma9+ gamma delta T cells isolated from healthy individuals,tested either as resting cells or cells activated by phosphoantigen BrHPP and IL-2at an early(+6hrs) and a late (+7days) timepoint. We find that with more “NK cell” genes than alphabeta T cells and more “T cell” genes than NK cells, the circulating TCRVgamma9+ gamma delta T cells cells have a hybrid transcriptome. The gene signature of the activated cells recapitulates their physiological functions: Th1 cytokine, chemokine and cytotoxic activities at first and mitotic activity at later time points. The gene expression pattern of activated normal gamma delta T cells is nevertheless clearly distinctive from that of NK/T and peripheral T cell lymphomas of the gamma delta subtype.

Standard name | GSE27291_0H_VS_7D_STIM_GAMMADELTA_TCELL_DN
Systematic name | M8457
Organism | Homo sapiens
PMID | 21968650
Authors | Pont F,Familiades J,Déjean S,Fruchon S,Cendron D,Poupot M,Poupot R,L'faqihi-Olive F,Prade N,Ycart B,Fournié JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in gamma delta T cells activated by phophoantigen BrHPP and IL2 [GeneID=3558]: 0h versus 7 days.
Full description | We used microarrays to detail the global programme of gene expression by circulating TCRVgamma9+ gamma delta T cells isolated from healthy individuals,tested either as resting cells or cells activated by phosphoantigen BrHPP and IL-2at an early(+6hrs) and a late (+7days) timepoint. We find that with more “NK cell” genes than alphabeta T cells and more “T cell” genes than NK cells, the circulating TCRVgamma9+ gamma delta T cells cells have a hybrid transcriptome. The gene signature of the activated cells recapitulates their physiological functions: Th1 cytokine, chemokine and cytotoxic activities at first and mitotic activity at later time points. The gene expression pattern of activated normal gamma delta T cells is nevertheless clearly distinctive from that of NK/T and peripheral T cell lymphomas of the gamma delta subtype.

Standard name | GSE27291_6H_VS_7D_STIM_GAMMADELTA_TCELL_UP
Systematic name | M8459
Organism | Homo sapiens
PMID | 21968650
Authors | Pont F,Familiades J,Déjean S,Fruchon S,Cendron D,Poupot M,Poupot R,L'faqihi-Olive F,Prade N,Ycart B,Fournié JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in gamma delta T cells activated by phosphoantigen BrHPP and IL2 [GeneID=3558]: 6h versus 7 days.
Full description | We used microarrays to detail the global programme of gene expression by circulating TCRVgamma9+ gamma delta T cells isolated from healthy individuals,tested either as resting cells or cells activated by phosphoantigen BrHPP and IL-2at an early(+6hrs) and a late (+7days) timepoint. We find that with more “NK cell” genes than alphabeta T cells and more “T cell” genes than NK cells, the circulating TCRVgamma9+ gamma delta T cells cells have a hybrid transcriptome. The gene signature of the activated cells recapitulates their physiological functions: Th1 cytokine, chemokine and cytotoxic activities at first and mitotic activity at later time points. The gene expression pattern of activated normal gamma delta T cells is nevertheless clearly distinctive from that of NK/T and peripheral T cell lymphomas of the gamma delta subtype.

Standard name | GSE27291_6H_VS_7D_STIM_GAMMADELTA_TCELL_DN
Systematic name | M8460
Organism | Homo sapiens
PMID | 21968650
Authors | Pont F,Familiades J,Déjean S,Fruchon S,Cendron D,Poupot M,Poupot R,L'faqihi-Olive F,Prade N,Ycart B,Fournié JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in gamma delta T cells activated by phosphoantigen BrHPP and IL2 [GeneID=3558]: 6h versus 7 days.
Full description | We used microarrays to detail the global programme of gene expression by circulating TCRVgamma9+ gamma delta T cells isolated from healthy individuals,tested either as resting cells or cells activated by phosphoantigen BrHPP and IL-2at an early(+6hrs) and a late (+7days) timepoint. We find that with more “NK cell” genes than alphabeta T cells and more “T cell” genes than NK cells, the circulating TCRVgamma9+ gamma delta T cells cells have a hybrid transcriptome. The gene signature of the activated cells recapitulates their physiological functions: Th1 cytokine, chemokine and cytotoxic activities at first and mitotic activity at later time points. The gene expression pattern of activated normal gamma delta T cells is nevertheless clearly distinctive from that of NK/T and peripheral T cell lymphomas of the gamma delta subtype.

Standard name | GSE32533_WT_VS_MIR17_OVEREXPRESS_ACT_CD4_TCELL_UP
Systematic name | M8462
Organism | Mus musculus
PMID | 21972292
Authors | Jiang S,Li C,Olive V,Lykken E,Feng F,Sevilla J,Wan Y,He L,Li QJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated CD4 [GeneID=920] T cells: wildtype versus over-expressing MIR17 [GeneID=406952].
Full description | miR-17 from the miR-17-92 cluster regulate activation-induced cell death in T cells and modulate inducible regulatory T cell differentiation. We used microarrays to detail the global program of gene expression modulated by miR-17 and aim to identify the potential targets of miR-17.

Standard name | GSE32533_WT_VS_MIR17_KO_ACT_CD4_TCELL_DN
Systematic name | M8464
Organism | Mus musculus
PMID | 21972292
Authors | Jiang S,Li C,Olive V,Lykken E,Feng F,Sevilla J,Wan Y,He L,Li QJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated CD4 [GeneID=920] T cells: wildtype versus MIR17 [GeneID=406952] knockout.
Full description | miR-17 from the miR-17-92 cluster regulate activation-induced cell death in T cells and modulate inducible regulatory T cell differentiation. We used microarrays to detail the global program of gene expression modulated by miR-17 and aim to identify the potential targets of miR-17.

Standard name | GSE32533_WT_VS_MIR17_OVEREXPRESS_ACT_CD4_TCELL_DN
Systematic name | M8465
Organism | Mus musculus
PMID | 21972292
Authors | Jiang S,Li C,Olive V,Lykken E,Feng F,Sevilla J,Wan Y,He L,Li QJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated CD4 [GeneID=920] T cells: wildtype versus over-expressing MIR17 [GeneID=406952].
Full description | miR-17 from the miR-17-92 cluster regulate activation-induced cell death in T cells and modulate inducible regulatory T cell differentiation. We used microarrays to detail the global program of gene expression modulated by miR-17 and aim to identify the potential targets of miR-17.

Standard name | GSE32533_MIR17_KO_VS_MIR17_OVEREXPRESS_ACT_CD4_TCELL_UP
Systematic name | M8468
Organism | Mus musculus
PMID | 21972292
Authors | Jiang S,Li C,Olive V,Lykken E,Feng F,Sevilla J,Wan Y,He L,Li QJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated CD4 [GeneID=920] T cells with MIR17 [GeneID=406952] perturbation: knockout versus over-expression.
Full description | miR-17 from the miR-17-92 cluster regulate activation-induced cell death in T cells and modulate inducible regulatory T cell differentiation. We used microarrays to detail the global program of gene expression modulated by miR-17 and aim to identify the potential targets of miR-17.

Standard name | GSE32533_WT_VS_MIR17_KO_ACT_CD4_TCELL_UP
Systematic name | M8469
Organism | Mus musculus
PMID | 21972292
Authors | Jiang S,Li C,Olive V,Lykken E,Feng F,Sevilla J,Wan Y,He L,Li QJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated CD4 [GeneID=920] T cells: wildtype versus MIR17 [GeneID=406952] knockout.
Full description | miR-17 from the miR-17-92 cluster regulate activation-induced cell death in T cells and modulate inducible regulatory T cell differentiation. We used microarrays to detail the global program of gene expression modulated by miR-17 and aim to identify the potential targets of miR-17.

Standard name | GSE32533_MIR17_KO_VS_MIR17_OVEREXPRESS_ACT_CD4_TCELL_DN
Systematic name | M8470
Organism | Mus musculus
PMID | 21972292
Authors | Jiang S,Li C,Olive V,Lykken E,Feng F,Sevilla J,Wan Y,He L,Li QJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated CD4 [GeneID=920] T cells with MIR17 [GeneID=406952] perturbation: knockout versus over-expression.
Full description | miR-17 from the miR-17-92 cluster regulate activation-induced cell death in T cells and modulate inducible regulatory T cell differentiation. We used microarrays to detail the global program of gene expression modulated by miR-17 and aim to identify the potential targets of miR-17.

Standard name | GSE31622_WT_VS_KLF3_KO_BCELL_DN
Systematic name | M8471
Organism | Mus musculus
PMID | 22003205
Authors | Vu TT,Gatto D,Turner V,Funnell AP,Mak KS,Norton LJ,Kaplan W,Cowley MJ,Agenès F,Kirberg J,Brink R,Pearson RC,Crossley M
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenic B lymphocytes: wildtype versus KLF3 [GeneID=51274] knockout.
Full description | To investigate the roles of Klf3 in B lymphopoiesis, CD19+ B cells were sorted from the spleens of WT and Klf3 KO mice (Molecular and Cellular Biology (2008); 28:3967–3978). Following RNA extraction, gene expression was compared in WT and Klf3 KO CD19+splenic B cells using Affymetrix microarrays.

Standard name | GSE31622_WT_VS_KLF3_KO_BCELL_UP
Systematic name | M8473
Organism | Mus musculus
PMID | 22003205
Authors | Vu TT,Gatto D,Turner V,Funnell AP,Mak KS,Norton LJ,Kaplan W,Cowley MJ,Agenès F,Kirberg J,Brink R,Pearson RC,Crossley M
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenic B lymphocytes: wildtype versus KLF3 [GeneID=51274] knockout.
Full description | To investigate the roles of Klf3 in B lymphopoiesis, CD19+ B cells were sorted from the spleens of WT and Klf3 KO mice (Molecular and Cellular Biology (2008); 28:3967–3978). Following RNA extraction, gene expression was compared in WT and Klf3 KO CD19+splenic B cells using Affymetrix microarrays.

Standard name | GSE26351_UNSTIM_VS_WNT_PATHWAY_STIM_HEMATOPOIETIC_PROGENITORS_DN
Systematic name | M8476
Organism | Homo sapiens
PMID | 22036566
Authors | Trompouki E,Bowman TV,Lawton LN,Fan ZP,Wu DC,DiBiase A,Martin CS,Cech JN,Sessa AK,Leblanc JL,Li P,Durand EM,Mosimann C,Heffner GC,Daley GQ,Paulson RF,Young RA,Zon LI
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD34+ [GeneID=947] cells: control versus treated with GSK-3 Inhibitor IX (BIO) [PubChem=5287844].
Full description | Analysis of mobilized peripheral blood CD34+ cells from a healthy volunteer under erythroid differentiation conditions with and without stimulation to the BMP or Wnt signaling pathways. For erythroid differentiation, expanded CD34+ cells were placed in Stemspan SFEM medium supplemented with 2% pen/strep, 20ng/ml SCF, 1U/ml Epo, 5ng/ml IL3, 2uM dexamethasone, and 1uM beta-estradiol. Arrays were performed 2 hours after addition of cytokines. For signaling pathway stimulation, cells were exposed to 0.5uM BIO (a GSK3 inhibitor) for Wnt pathway activation, 25ng/ml rhBMP4 for BMP pathway activation, or vehicle control for 2 hours. Three biological replicates were performed per treatment group. We used microarrays to detail the global program of gene expression changes after Wnt or BMP pathway stimulation in human CD34+ hematopoietic progenitors under erythroid differentiation conditions.

Standard name | GSE26351_WNT_VS_BMP_PATHWAY_STIM_HEMATOPOIETIC_PROGENITORS_UP
Systematic name | M8477
Organism | Homo sapiens
PMID | 22036566
Authors | Trompouki E,Bowman TV,Lawton LN,Fan ZP,Wu DC,DiBiase A,Martin CS,Cech JN,Sessa AK,Leblanc JL,Li P,Durand EM,Mosimann C,Heffner GC,Daley GQ,Paulson RF,Young RA,Zon LI
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD34+ [GeneID=947] cells treated with GSK-3 Inhibitor IX (BIO) [PubChem=5287844] versus those stimulated by BMP4 [GeneID=652].
Full description | Analysis of mobilized peripheral blood CD34+ cells from a healthy volunteer under erythroid differentiation conditions with and without stimulation to the BMP or Wnt signaling pathways. For erythroid differentiation, expanded CD34+ cells were placed in Stemspan SFEM medium supplemented with 2% pen/strep, 20ng/ml SCF, 1U/ml Epo, 5ng/ml IL3, 2uM dexamethasone, and 1uM beta-estradiol. Arrays were performed 2 hours after addition of cytokines. For signaling pathway stimulation, cells were exposed to 0.5uM BIO (a GSK3 inhibitor) for Wnt pathway activation, 25ng/ml rhBMP4 for BMP pathway activation, or vehicle control for 2 hours. Three biological replicates were performed per treatment group. We used microarrays to detail the global program of gene expression changes after Wnt or BMP pathway stimulation in human CD34+ hematopoietic progenitors under erythroid differentiation conditions.

Standard name | GSE26351_WNT_VS_BMP_PATHWAY_STIM_HEMATOPOIETIC_PROGENITORS_DN
Systematic name | M8480
Organism | Homo sapiens
PMID | 22036566
Authors | Trompouki E,Bowman TV,Lawton LN,Fan ZP,Wu DC,DiBiase A,Martin CS,Cech JN,Sessa AK,Leblanc JL,Li P,Durand EM,Mosimann C,Heffner GC,Daley GQ,Paulson RF,Young RA,Zon LI
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD34+ [GeneID=947] cells treated with GSK-3 Inhibitor IX (BIO) [PubChem=5287844] versus those stimulated by BMP4 [GeneID=652].
Full description | Analysis of mobilized peripheral blood CD34+ cells from a healthy volunteer under erythroid differentiation conditions with and without stimulation to the BMP or Wnt signaling pathways. For erythroid differentiation, expanded CD34+ cells were placed in Stemspan SFEM medium supplemented with 2% pen/strep, 20ng/ml SCF, 1U/ml Epo, 5ng/ml IL3, 2uM dexamethasone, and 1uM beta-estradiol. Arrays were performed 2 hours after addition of cytokines. For signaling pathway stimulation, cells were exposed to 0.5uM BIO (a GSK3 inhibitor) for Wnt pathway activation, 25ng/ml rhBMP4 for BMP pathway activation, or vehicle control for 2 hours. Three biological replicates were performed per treatment group. We used microarrays to detail the global program of gene expression changes after Wnt or BMP pathway stimulation in human CD34+ hematopoietic progenitors under erythroid differentiation conditions.

Standard name | GSE26351_UNSTIM_VS_BMP_PATHWAY_STIM_HEMATOPOIETIC_PROGENITORS_DN
Systematic name | M8481
Organism | Homo sapiens
PMID | 22036566
Authors | Trompouki E,Bowman TV,Lawton LN,Fan ZP,Wu DC,DiBiase A,Martin CS,Cech JN,Sessa AK,Leblanc JL,Li P,Durand EM,Mosimann C,Heffner GC,Daley GQ,Paulson RF,Young RA,Zon LI
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD34+ [GeneID=947] cells: control versus stimulated by BMP4 [GeneID=652].
Full description | Analysis of mobilized peripheral blood CD34+ cells from a healthy volunteer under erythroid differentiation conditions with and without stimulation to the BMP or Wnt signaling pathways. For erythroid differentiation, expanded CD34+ cells were placed in Stemspan SFEM medium supplemented with 2% pen/strep, 20ng/ml SCF, 1U/ml Epo, 5ng/ml IL3, 2uM dexamethasone, and 1uM beta-estradiol. Arrays were performed 2 hours after addition of cytokines. For signaling pathway stimulation, cells were exposed to 0.5uM BIO (a GSK3 inhibitor) for Wnt pathway activation, 25ng/ml rhBMP4 for BMP pathway activation, or vehicle control for 2 hours. Three biological replicates were performed per treatment group. We used microarrays to detail the global program of gene expression changes after Wnt or BMP pathway stimulation in human CD34+ hematopoietic progenitors under erythroid differentiation conditions.

Standard name | GSE26351_UNSTIM_VS_WNT_PATHWAY_STIM_HEMATOPOIETIC_PROGENITORS_UP
Systematic name | M8482
Organism | Homo sapiens
PMID | 22036566
Authors | Trompouki E,Bowman TV,Lawton LN,Fan ZP,Wu DC,DiBiase A,Martin CS,Cech JN,Sessa AK,Leblanc JL,Li P,Durand EM,Mosimann C,Heffner GC,Daley GQ,Paulson RF,Young RA,Zon LI
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD34+ [GeneID=947] cells: control versus treated with GSK-3 Inhibitor IX (BIO) [PubChem=5287844].
Full description | Analysis of mobilized peripheral blood CD34+ cells from a healthy volunteer under erythroid differentiation conditions with and without stimulation to the BMP or Wnt signaling pathways. For erythroid differentiation, expanded CD34+ cells were placed in Stemspan SFEM medium supplemented with 2% pen/strep, 20ng/ml SCF, 1U/ml Epo, 5ng/ml IL3, 2uM dexamethasone, and 1uM beta-estradiol. Arrays were performed 2 hours after addition of cytokines. For signaling pathway stimulation, cells were exposed to 0.5uM BIO (a GSK3 inhibitor) for Wnt pathway activation, 25ng/ml rhBMP4 for BMP pathway activation, or vehicle control for 2 hours. Three biological replicates were performed per treatment group. We used microarrays to detail the global program of gene expression changes after Wnt or BMP pathway stimulation in human CD34+ hematopoietic progenitors under erythroid differentiation conditions.

Standard name | GSE26351_UNSTIM_VS_BMP_PATHWAY_STIM_HEMATOPOIETIC_PROGENITORS_UP
Systematic name | M8483
Organism | Homo sapiens
PMID | 22036566
Authors | Trompouki E,Bowman TV,Lawton LN,Fan ZP,Wu DC,DiBiase A,Martin CS,Cech JN,Sessa AK,Leblanc JL,Li P,Durand EM,Mosimann C,Heffner GC,Daley GQ,Paulson RF,Young RA,Zon LI
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD34+ [GeneID=947] cells: control versus stimulated by BMP4 [GeneID=652].
Full description | Analysis of mobilized peripheral blood CD34+ cells from a healthy volunteer under erythroid differentiation conditions with and without stimulation to the BMP or Wnt signaling pathways. For erythroid differentiation, expanded CD34+ cells were placed in Stemspan SFEM medium supplemented with 2% pen/strep, 20ng/ml SCF, 1U/ml Epo, 5ng/ml IL3, 2uM dexamethasone, and 1uM beta-estradiol. Arrays were performed 2 hours after addition of cytokines. For signaling pathway stimulation, cells were exposed to 0.5uM BIO (a GSK3 inhibitor) for Wnt pathway activation, 25ng/ml rhBMP4 for BMP pathway activation, or vehicle control for 2 hours. Three biological replicates were performed per treatment group. We used microarrays to detail the global program of gene expression changes after Wnt or BMP pathway stimulation in human CD34+ hematopoietic progenitors under erythroid differentiation conditions.

Standard name | GSE29164_UNTREATED_VS_CD8_TCELL_AND_IL12_TREATED_MELANOMA_DAY3_UP
Systematic name | M8484
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in B16 melanoma (day 3): untreated versus mock treatment during adoptive transfer therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_UNTREATED_VS_CD8_TCELL_AND_IL12_TREATED_MELANOMA_DAY3_DN
Systematic name | M8485
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in B16 melanoma (day 3): untreated versus mock treatment during adoptive transfer therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_UNTREATED_VS_CD8_TCELL_TREATED_MELANOMA_DAY3_DN
Systematic name | M8486
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in B16 melanoma (day 3): untreated versus adoptive transfer therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_DAY3_VS_DAY7_UNTREATED_MELANOMA_DN
Systematic name | M8487
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in untreated B16 melanoma: day 3 versus day 7.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_DAY3_VS_DAY7_CD8_TCELL_TREATED_MELANOMA_UP
Systematic name | M8488
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in mock treatment during adoptive transfer therapy of B16 melanoma: day 3 versus day 7.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_UNTREATED_VS_CD8_TCELL_TREATED_MELANOMA_DAY3_UP
Systematic name | M8489
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in B16 melanoma (day 3): untreated versus adoptive transfer therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_DAY3_VS_DAY7_CD8_TCELL_AND_IL12_TREATED_MELANOMA_DN
Systematic name | M8490
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in B16 melanoma during adoptive transfer therapy: day 3 versus day 7.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_CD8_TCELL_VS_CD8_TCELL_AND_IL12_TREATED_MELANOMA_DAY3_UP
Systematic name | M8491
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in B16 melanoma at day 3 of adoptive transfer treatment: mock versus therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_DAY3_VS_DAY7_CD8_TCELL_TREATED_MELANOMA_DN
Systematic name | M8494
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in mock treatment during adoptive transfer therapy of B16 melanoma: day 3 versus day 7.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_DAY3_VS_DAY7_CD8_TCELL_AND_IL12_TREATED_MELANOMA_UP
Systematic name | M8495
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in B16 melanoma during adoptive transfer therapy: day 3 versus day 7.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_UNTREATED_VS_CD8_TCELL_TREATED_MELANOMA_DAY7_DN
Systematic name | M8496
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in B16 melanoma (day 7): untreated versus adoptive transfer therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_UNTREATED_VS_CD8_TCELL_AND_IL12_TREATED_MELANOMA_DAY7_UP
Systematic name | M8497
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in B16 melanoma (day 7): untreated versus mock treatment during adoptive transfer therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_UNTREATED_VS_CD8_TCELL_AND_IL12_TREATED_MELANOMA_DAY7_DN
Systematic name | M8498
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in B16 melanoma (day 7): untreated versus mock treatment during adoptive transfer therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_CD8_TCELL_VS_CD8_TCELL_AND_IL12_TREATED_MELANOMA_DAY7_UP
Systematic name | M8500
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in B16 melanoma at day 7 of adoptive transfer treatment: mock versus therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_CD8_TCELL_VS_CD8_TCELL_AND_IL12_TREATED_MELANOMA_DAY7_DN
Systematic name | M8502
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in B16 melanoma at day 7 of adoptive transfer treatment: mock versus therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_DAY3_VS_DAY7_UNTREATED_MELANOMA_UP
Systematic name | M8503
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in untreated B16 melanoma: day 3 versus day 7.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_CD8_TCELL_VS_CD8_TCELL_AND_IL12_TREATED_MELANOMA_DAY3_DN
Systematic name | M8504
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in B16 melanoma at day 3 of adoptive transfer treatment: mock versus therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE29164_UNTREATED_VS_CD8_TCELL_TREATED_MELANOMA_DAY7_UP
Systematic name | M8505
Organism | Mus musculus
PMID | 22056381
Authors | Kerkar SP,Goldszmid RS,Muranski P,Chinnasamy D,Yu Z,Reger RN,Leonardi AJ,Morgan RA,Wang E,Marincola FM,Trinchieri G,Rosenberg SA,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in B16 melanoma (day 7): untreated versus adoptive transfer therapy.
Full description | Myeloid-derived cells comprising the tumor stroma represent a heterogeneous population of cells critical to the structure, function and growth of established cancers. We have recently found that engineering tumor-specific CD8+ T cells to secrete IL-12 (IL-12TD) can lead to striking improvements in T-cell activity against established melanomas in murine models. Surprisingly, IL-12-dependent enhancement of CD8+ T-cell anti-tumor function did not occur through direct ligation of receptors on lymphocytes or NK cells. Instead, IL-12 sensitized host bone marrow-derived tumor-stromal cells, partly through interferon-gamma, to indirectly enhance the effects of adoptively-transferred T cells. Direct presentation of antigen by tumor was not necessary, but MHC class I expression on endogenous cells was essential for IL-12 mediated anti-tumor enhancements. Upon successful treatment with IL-12TD cells, we observed the selective elimination of tumor-infiltrating CD11b+ F4/80+ macrophages, CD11b+/ClassII+/CD11c+ dendritic cells and CD11b+/Ly6C+/Ly6G- but not CD11b+/Ly6C+/Ly6G+ myeloid-derived suppressor cells within regressing lesions. These results are consistent with a model whereby IL-12 triggers the maturation of myeloid-derived cells into competent antigen cross-presenting cells. Licensed recognition of these antigens by effector T cells may in turn trigger the collapse of the tumor stroma and aid in the regression of large vascularized lesions.

Standard name | GSE23568_ID3_TRANSDUCED_VS_ID3_KO_CD8_TCELL_DN
Systematic name | M8506
Organism | Mus musculus
PMID | 22057288
Authors | Ji Y,Pos Z,Rao M,Klebanoff CA,Yu Z,Sukumar M,Reger RN,Palmer DC,Borman ZA,Muranski P,Wang E,Schrump DS,Marincola FM,Restifo NP,Gattinoni L
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: over-expressing ID3 [GeneID=3399] versus ID3 [GeneID=3399] knockout.
Full description | Mouse CD8+ T cells affected by ID3 (Inhibitor of DNA binding 3) display patterns of gene expression suggesting enhanced persistance and survival. In this study, we identified genes differentially expressed between ID32a transduced and mock transduced, and ID32a knockout and wild type mouse CD8+ T cells. Most prominent functions of differentially expressed genes include DNA replication-associated repair, maintenance of chromosome stability and mitotic cell divison machinery. Overall, these data suggest that ID3 acts in favor of maintained survival in CD8+ mouse T cells.

Standard name | GSE23568_CTRL_VS_ID3_TRANSDUCED_CD8_TCELL_DN
Systematic name | M8507
Organism | Mus musculus
PMID | 22057288
Authors | Ji Y,Pos Z,Rao M,Klebanoff CA,Yu Z,Sukumar M,Reger RN,Palmer DC,Borman ZA,Muranski P,Wang E,Schrump DS,Marincola FM,Restifo NP,Gattinoni L
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: control versus over-expressing ID3 [GeneID=3399].
Full description | Mouse CD8+ T cells affected by ID3 (Inhibitor of DNA binding 3) display patterns of gene expression suggesting enhanced persistance and survival. In this study, we identified genes differentially expressed between ID32a transduced and mock transduced, and ID32a knockout and wild type mouse CD8+ T cells. Most prominent functions of differentially expressed genes include DNA replication-associated repair, maintenance of chromosome stability and mitotic cell divison machinery. Overall, these data suggest that ID3 acts in favor of maintained survival in CD8+ mouse T cells.

Standard name | GSE23568_CTRL_VS_ID3_TRANSDUCED_CD8_TCELL_UP
Systematic name | M8514
Organism | Mus musculus
PMID | 22057288
Authors | Ji Y,Pos Z,Rao M,Klebanoff CA,Yu Z,Sukumar M,Reger RN,Palmer DC,Borman ZA,Muranski P,Wang E,Schrump DS,Marincola FM,Restifo NP,Gattinoni L
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: control versus over-expressing ID3 [GeneID=3399].
Full description | Mouse CD8+ T cells affected by ID3 (Inhibitor of DNA binding 3) display patterns of gene expression suggesting enhanced persistance and survival. In this study, we identified genes differentially expressed between ID32a transduced and mock transduced, and ID32a knockout and wild type mouse CD8+ T cells. Most prominent functions of differentially expressed genes include DNA replication-associated repair, maintenance of chromosome stability and mitotic cell divison machinery. Overall, these data suggest that ID3 acts in favor of maintained survival in CD8+ mouse T cells.

Standard name | GSE23568_ID3_KO_VS_WT_CD8_TCELL_UP
Systematic name | M8515
Organism | Mus musculus
PMID | 22057288
Authors | Ji Y,Pos Z,Rao M,Klebanoff CA,Yu Z,Sukumar M,Reger RN,Palmer DC,Borman ZA,Muranski P,Wang E,Schrump DS,Marincola FM,Restifo NP,Gattinoni L
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: ID3 [GeneID=3399] knockout versus wildtype.
Full description | Mouse CD8+ T cells affected by ID3 (Inhibitor of DNA binding 3) display patterns of gene expression suggesting enhanced persistance and survival. In this study, we identified genes differentially expressed between ID32a transduced and mock transduced, and ID32a knockout and wild type mouse CD8+ T cells. Most prominent functions of differentially expressed genes include DNA replication-associated repair, maintenance of chromosome stability and mitotic cell divison machinery. Overall, these data suggest that ID3 acts in favor of maintained survival in CD8+ mouse T cells.

Standard name | GSE23568_ID3_TRANSDUCED_VS_ID3_KO_CD8_TCELL_UP
Systematic name | M8517
Organism | Mus musculus
PMID | 22057288
Authors | Ji Y,Pos Z,Rao M,Klebanoff CA,Yu Z,Sukumar M,Reger RN,Palmer DC,Borman ZA,Muranski P,Wang E,Schrump DS,Marincola FM,Restifo NP,Gattinoni L
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: over-expressing ID3 [GeneID=3399] versus ID3 [GeneID=3399] knockout.
Full description | Mouse CD8+ T cells affected by ID3 (Inhibitor of DNA binding 3) display patterns of gene expression suggesting enhanced persistance and survival. In this study, we identified genes differentially expressed between ID32a transduced and mock transduced, and ID32a knockout and wild type mouse CD8+ T cells. Most prominent functions of differentially expressed genes include DNA replication-associated repair, maintenance of chromosome stability and mitotic cell divison machinery. Overall, these data suggest that ID3 acts in favor of maintained survival in CD8+ mouse T cells.

Standard name | GSE23568_ID3_KO_VS_WT_CD8_TCELL_DN
Systematic name | M8518
Organism | Mus musculus
PMID | 22057288
Authors | Ji Y,Pos Z,Rao M,Klebanoff CA,Yu Z,Sukumar M,Reger RN,Palmer DC,Borman ZA,Muranski P,Wang E,Schrump DS,Marincola FM,Restifo NP,Gattinoni L
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: ID3 [GeneID=3399] knockout versus wildtype.
Full description | Mouse CD8+ T cells affected by ID3 (Inhibitor of DNA binding 3) display patterns of gene expression suggesting enhanced persistance and survival. In this study, we identified genes differentially expressed between ID32a transduced and mock transduced, and ID32a knockout and wild type mouse CD8+ T cells. Most prominent functions of differentially expressed genes include DNA replication-associated repair, maintenance of chromosome stability and mitotic cell divison machinery. Overall, these data suggest that ID3 acts in favor of maintained survival in CD8+ mouse T cells.

Standard name | GSE23568_CTRL_TRANSDUCED_VS_WT_CD8_TCELL_DN
Systematic name | M8521
Organism | Mus musculus
PMID | 22057288
Authors | Ji Y,Pos Z,Rao M,Klebanoff CA,Yu Z,Sukumar M,Reger RN,Palmer DC,Borman ZA,Muranski P,Wang E,Schrump DS,Marincola FM,Restifo NP,Gattinoni L
Category | C7
Sub-category |
Brief description | Genes down-regulated CD8 T cells: mock transduced versus wildtype.
Full description | Mouse CD8+ T cells affected by ID3 (Inhibitor of DNA binding 3) display patterns of gene expression suggesting enhanced persistance and survival. In this study, we identified genes differentially expressed between ID32a transduced and mock transduced, and ID32a knockout and wild type mouse CD8+ T cells. Most prominent functions of differentially expressed genes include DNA replication-associated repair, maintenance of chromosome stability and mitotic cell divison machinery. Overall, these data suggest that ID3 acts in favor of maintained survival in CD8+ mouse T cells.

Standard name | GSE23568_CTRL_TRANSDUCED_VS_WT_CD8_TCELL_UP
Systematic name | M8522
Organism | Mus musculus
PMID | 22057288
Authors | Ji Y,Pos Z,Rao M,Klebanoff CA,Yu Z,Sukumar M,Reger RN,Palmer DC,Borman ZA,Muranski P,Wang E,Schrump DS,Marincola FM,Restifo NP,Gattinoni L
Category | C7
Sub-category |
Brief description | Genes up-regulated CD8 T cells: mock transduced versus wildtype.
Full description | Mouse CD8+ T cells affected by ID3 (Inhibitor of DNA binding 3) display patterns of gene expression suggesting enhanced persistance and survival. In this study, we identified genes differentially expressed between ID32a transduced and mock transduced, and ID32a knockout and wild type mouse CD8+ T cells. Most prominent functions of differentially expressed genes include DNA replication-associated repair, maintenance of chromosome stability and mitotic cell divison machinery. Overall, these data suggest that ID3 acts in favor of maintained survival in CD8+ mouse T cells.

Standard name | GSE32164_RESTING_DIFFERENTIATED_VS_ALTERNATIVELY_ACT_M2_MACROPHAGE_DN
Systematic name | M8524
Organism | Homo sapiens
PMID | 22067385
Authors | Pello OM,Pizzol De M,Mirolo M,Soucek L,Zammataro L,Amabile A,Doni A,Nebuloni M,Swigart LB,Evan GI,Mantovani A,Locati M
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: resting differentiated versus alternatively activated M2.
Full description | In response to microenvironmental signals macrophages undergo different activation, indicated as classic/M1 and alternative/M2 polarization. C-Myc transcription factor could be an essential player in M2 polarization. Functional relevance of c-Myc in M2 macrophage biology is investigated by evaluating the effect of 100-58F4, on the transcriptional profile induced on human macrophages by IL-4.

Standard name | GSE32164_RESTING_DIFFERENTIATED_VS_ALTERNATIVELY_ACT_M2_MACROPHAGE_UP
Systematic name | M8527
Organism | Homo sapiens
PMID | 22067385
Authors | Pello OM,Pizzol De M,Mirolo M,Soucek L,Zammataro L,Amabile A,Doni A,Nebuloni M,Swigart LB,Evan GI,Mantovani A,Locati M
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: resting differentiated versus alternatively activated M2.
Full description | In response to microenvironmental signals macrophages undergo different activation, indicated as classic/M1 and alternative/M2 polarization. C-Myc transcription factor could be an essential player in M2 polarization. Functional relevance of c-Myc in M2 macrophage biology is investigated by evaluating the effect of 100-58F4, on the transcriptional profile induced on human macrophages by IL-4.

Standard name | GSE32164_ALTERNATIVELY_ACT_M2_VS_CMYC_INHIBITED_MACROPHAGE_UP
Systematic name | M8528
Organism | Homo sapiens
PMID | 22067385
Authors | Pello OM,Pizzol De M,Mirolo M,Soucek L,Zammataro L,Amabile A,Doni A,Nebuloni M,Swigart LB,Evan GI,Mantovani A,Locati M
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: alternatively activated M2 versus MYC [GeneID=4609] inhibited.
Full description | In response to microenvironmental signals macrophages undergo different activation, indicated as classic/M1 and alternative/M2 polarization. C-Myc transcription factor could be an essential player in M2 polarization. Functional relevance of c-Myc in M2 macrophage biology is investigated by evaluating the effect of 100-58F4, on the transcriptional profile induced on human macrophages by IL-4.

Standard name | GSE32164_ALTERNATIVELY_ACT_M2_VS_CMYC_INHIBITED_MACROPHAGE_DN
Systematic name | M8530
Organism | Homo sapiens
PMID | 22067385
Authors | Pello OM,Pizzol De M,Mirolo M,Soucek L,Zammataro L,Amabile A,Doni A,Nebuloni M,Swigart LB,Evan GI,Mantovani A,Locati M
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: alternatively activated M2 versus MYC [GeneID=4609] inhibited.
Full description | In response to microenvironmental signals macrophages undergo different activation, indicated as classic/M1 and alternative/M2 polarization. C-Myc transcription factor could be an essential player in M2 polarization. Functional relevance of c-Myc in M2 macrophage biology is investigated by evaluating the effect of 100-58F4, on the transcriptional profile induced on human macrophages by IL-4.

Standard name | GSE32164_RESTING_DIFFERENTIATED_VS_CMYC_INHIBITED_MACROPHAGE_DN
Systematic name | M8531
Organism | Homo sapiens
PMID | 22067385
Authors | Pello OM,Pizzol De M,Mirolo M,Soucek L,Zammataro L,Amabile A,Doni A,Nebuloni M,Swigart LB,Evan GI,Mantovani A,Locati M
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: resting differentiated versus MYC [GeneID=4609] inhibited.
Full description | In response to microenvironmental signals macrophages undergo different activation, indicated as classic/M1 and alternative/M2 polarization. C-Myc transcription factor could be an essential player in M2 polarization. Functional relevance of c-Myc in M2 macrophage biology is investigated by evaluating the effect of 100-58F4, on the transcriptional profile induced on human macrophages by IL-4.

Standard name | GSE32164_RESTING_DIFFERENTIATED_VS_CMYC_INHIBITED_MACROPHAGE_UP
Systematic name | M8532
Organism | Homo sapiens
PMID | 22067385
Authors | Pello OM,Pizzol De M,Mirolo M,Soucek L,Zammataro L,Amabile A,Doni A,Nebuloni M,Swigart LB,Evan GI,Mantovani A,Locati M
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: resting differentiated versus MYC [GeneID=4609] inhibited.
Full description | In response to microenvironmental signals macrophages undergo different activation, indicated as classic/M1 and alternative/M2 polarization. C-Myc transcription factor could be an essential player in M2 polarization. Functional relevance of c-Myc in M2 macrophage biology is investigated by evaluating the effect of 100-58F4, on the transcriptional profile induced on human macrophages by IL-4.

Standard name | GSE33374_CD8_ALPHAALPHA_VS_ALPHABETA_CD161_HIGH_TCELL_DN
Systematic name | M8533
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes down-regulated in KLRB1 high [GeneID=3820] T cells: CD8A [GeneID=925] versus CD8A CD8B [GeneID=925;926].
Full description | We used microarrays to compare gene expression between healthy human CD161++CD8aa and CD161++CD8ab T cells.

Standard name | GSE33424_CD161_HIGH_VS_INT_CD8_TCELL_UP
Systematic name | M8534
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: KLRB1 high [GeneID=3820] versus KLRB1 int [GeneID=3820].
Full description | We used microarray to compare gene expression between CD161++/CD161+/CD161-CD8+ T cells from human cord blood.

Standard name | GSE33374_CD8_ALPHAALPHA_VS_ALPHABETA_CD161_HIGH_TCELL_UP
Systematic name | M8538
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes up-regulated in KLRB1 high [GeneID=3820] T cells: CD8A [GeneID=925] versus CD8A CD8B [GeneID=925;926].
Full description | We used microarrays to compare gene expression between healthy human CD161++CD8aa and CD161++CD8ab T cells.

Standard name | GSE33425_CD161_INT_VS_NEG_CD8_TCELL_UP
Systematic name | M8539
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: KLRB1 int [GeneID=3820] versus KLRB1- [GeneID=3820].
Full description | This SuperSeries is composed of the SubSeries listed below.

Standard name | GSE33424_CD161_HIGH_VS_INT_CD8_TCELL_DN
Systematic name | M8540
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: KLRB1 high [GeneID=3820] versus KLRB1 int [GeneID=3820].
Full description | We used microarray to compare gene expression between CD161++/CD161+/CD161-CD8+ T cells from human cord blood.

Standard name | GSE33424_CD161_HIGH_VS_NEG_CD8_TCELL_UP
Systematic name | M8541
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: KLRB1 high [GeneID=3820] versus KLRB1- [GeneID=3820].
Full description | We used microarray to compare gene expression between CD161++/CD161+/CD161-CD8+ T cells from human cord blood.

Standard name | GSE33424_CD161_HIGH_VS_NEG_CD8_TCELL_DN
Systematic name | M8542
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: KLRB1 high [GeneID=3820] versus KLRB1- [GeneID=3820].
Full description | We used microarray to compare gene expression between CD161++/CD161+/CD161-CD8+ T cells from human cord blood.

Standard name | GSE33425_CD161_INT_VS_NEG_CD8_TCELL_DN
Systematic name | M8543
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: KLRB1 int [GeneID=3820] versus KLRB1- [GeneID=3820].
Full description | This SuperSeries is composed of the SubSeries listed below.

Standard name | GSE33425_CD161_HIGH_VS_INT_CD8_TCELL_DN
Systematic name | M8545
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: KLRB1 high [GeneID=3820] versus KLRB1 int [GeneID=3820].
Full description | This SuperSeries is composed of the SubSeries listed below.

Standard name | GSE33425_CD8_ALPHAALPHA_VS_ALPHABETA_CD161_HIGH_TCELL_UP
Systematic name | M8547
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes up-regulated in KLRB1 high [GeneID=3820] T cells: CD8A [GeneID=925] versus CD8A CD8B [GeneID=925;926].
Full description | This SuperSeries is composed of the SubSeries listed below.

Standard name | GSE33425_CD8_ALPHAALPHA_VS_ALPHABETA_CD161_HIGH_TCELL_DN
Systematic name | M8548
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes down-regulated in KLRB1 high [GeneID=3820] T cells: CD8A [GeneID=925] versus CD8A CD8B [GeneID=925;926].
Full description | This SuperSeries is composed of the SubSeries listed below.

Standard name | GSE33425_CD161_HIGH_VS_INT_CD8_TCELL_UP
Systematic name | M8550
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: KLRB1 high [GeneID=3820] versus KLRB1 int [GeneID=3820].
Full description | This SuperSeries is composed of the SubSeries listed below.

Standard name | GSE33425_CD161_HIGH_VS_NEG_CD8_TCELL_UP
Systematic name | M8551
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: KLRB1 high [GeneID=3820] versus KLRB1- [GeneID=3820].
Full description | This SuperSeries is composed of the SubSeries listed below.

Standard name | GSE33425_CD161_HIGH_VS_NEG_CD8_TCELL_DN
Systematic name | M8552
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: KLRB1 high [GeneID=3820] versus KLRB1- [GeneID=3820].
Full description | This SuperSeries is composed of the SubSeries listed below.

Standard name | GSE33424_CD161_INT_VS_NEG_CD8_TCELL_DN
Systematic name | M8553
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: KLRB1 int [GeneID=3820] versus KLRB1- [GeneID=3820].
Full description | We used microarray to compare gene expression between CD161++/CD161+/CD161-CD8+ T cells from human cord blood.

Standard name | GSE33424_CD161_INT_VS_NEG_CD8_TCELL_UP
Systematic name | M8554
Organism | Homo sapiens
PMID | 22086415
Authors | Walker LJ,Kang YH,Smith MO,Tharmalingham H,Ramamurthy N,Fleming VM,Sahgal N,Leslie A,Oo Y,Geremia A,Scriba TJ,Hanekom WA,Lauer GM,Lantz O,Adams DH,Powrie F,Barnes E,Klenerman P
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: KLRB1 int [GeneID=3820] versus KLRB1- [GeneID=3820].
Full description | We used microarray to compare gene expression between CD161++/CD161+/CD161-CD8+ T cells from human cord blood.

Standard name | GSE26890_CXCR1_NEG_VS_POS_EFFECTOR_CD8_TCELL_DN
Systematic name | M8558
Organism | Homo sapiens
PMID | 22174157
Authors | Takata H,Naruto T,Takiguchi M
Category | C7
Sub-category |
Brief description | Genes down-regulated in effector CD8 T cells: CXCR1+ [GeneID=3577] versus CXCR1- [GeneID=3577].
Full description | Effector CD8+ T cells are believed to be terminally differentiated cells having cytotoxic activity and the ability to produce effector cytokines such as INF-γ and TNF-α. We investigated the difference between CXCR1+ and CXCR1- subsets of human effector CD27-CD28-CD8+ T cells. Both subsets similarly expressed cytolytic molecules and exerted substantial cytolytic activity, whereas only the CXCR1- subset had IL-2 productivity and self-proliferative activity and was more resistant to cell death than the CXCR1+ subset. These differences were explained by the specific up-regulation of CAMK4, SPRY2, and IL-7R in the CXCR1- subset and that of pro-apoptotic DAPK1 in the CXCR1+ subset. The IL-2 producers were more frequently found in the IL-7R+ subset of the CXCR1- effector CD8+ T cells than in the IL-7R- subset. IL-7/IL-7R signaling promoted cell survival only in the CXCR1- subset. The present study has highlighted a novel subset of effector CD8+ T cells producing IL-2 and suggests the importance of this subset in the homeostasis of effector CD8+ T cells.

Standard name | GSE26890_CXCR1_NEG_VS_POS_EFFECTOR_CD8_TCELL_UP
Systematic name | M8559
Organism | Homo sapiens
PMID | 22174157
Authors | Takata H,Naruto T,Takiguchi M
Category | C7
Sub-category |
Brief description | Genes up-regulated in effector CD8 T cells: CXCR1+ [GeneID=3577] versus CXCR1- [GeneID=3577].
Full description | Effector CD8+ T cells are believed to be terminally differentiated cells having cytotoxic activity and the ability to produce effector cytokines such as INF-γ and TNF-α. We investigated the difference between CXCR1+ and CXCR1- subsets of human effector CD27-CD28-CD8+ T cells. Both subsets similarly expressed cytolytic molecules and exerted substantial cytolytic activity, whereas only the CXCR1- subset had IL-2 productivity and self-proliferative activity and was more resistant to cell death than the CXCR1+ subset. These differences were explained by the specific up-regulation of CAMK4, SPRY2, and IL-7R in the CXCR1- subset and that of pro-apoptotic DAPK1 in the CXCR1+ subset. The IL-2 producers were more frequently found in the IL-7R+ subset of the CXCR1- effector CD8+ T cells than in the IL-7R- subset. IL-7/IL-7R signaling promoted cell survival only in the CXCR1- subset. The present study has highlighted a novel subset of effector CD8+ T cells producing IL-2 and suggests the importance of this subset in the homeostasis of effector CD8+ T cells.

Standard name | GSE26030_TH1_VS_TH17_DAY5_POST_POLARIZATION_DN
Systematic name | M8561
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in T helper cells 5 days post polarization: Th1 versus Th17.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_TH1_VS_TH17_DAY15_POST_POLARIZATION_UP
Systematic name | M8562
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in T helper cells 15 days post polarization: Th1 versus Th17.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_TH1_VS_TH17_DAY5_POST_POLARIZATION_UP
Systematic name | M8564
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in T helper cells 5 days post polarization: Th1 versus Th17.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_UNSTIM_VS_RESTIM_TH1_DAY5_POST_POLARIZATION_UP
Systematic name | M8567
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in Th1 cells 5 days post polarization: control versus stimulated with anti-CD3 and anti-CD28.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_UNSTIM_VS_RESTIM_TH1_DAY5_POST_POLARIZATION_DN
Systematic name | M8568
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in Th1 cells 5 days post polarization: control versus stimulated with anti-CD3 and anti-CD28.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_UNSTIM_VS_RESTIM_TH1_DAY15_POST_POLARIZATION_UP
Systematic name | M8569
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in Th1 cells 15 days post polarization: control versus stimulated with anti-CD3 and anti-CD28.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_TH1_VS_TH17_RESTIMULATED_DAY15_POST_POLARIZATION_DN
Systematic name | M8571
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in T helper cells 15 days post polarization and stimulated with anti-CD3 and anti-CD28: Th1 versus Th17.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_UNSTIM_VS_RESTIM_TH17_DAY15_POST_POLARIZATION_DN
Systematic name | M8572
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in Th17 cells 15 days post polarization: control versus stimulated with anti-CD3 and anti-CD28.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_TH1_VS_TH17_RESTIMULATED_DAY5_POST_POLARIZATION_UP
Systematic name | M8573
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in T helper cells 5 days post polarization and stimulated with anti-CD3 and anti-CD28: Th1 versus Th17.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_TH1_VS_TH17_RESTIMULATED_DAY5_POST_POLARIZATION_DN
Systematic name | M8574
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in T helper cells 5 days post polarization and stimulated with anti-CD3 and anti-CD28: Th1 versus Th17.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_TH1_VS_TH17_DAY15_POST_POLARIZATION_DN
Systematic name | M8575
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in T helper cells 15 days post polarization: Th1 versus Th17.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_UNSTIM_VS_RESTIM_TH1_DAY15_POST_POLARIZATION_DN
Systematic name | M8576
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in Th1 cells 15 days post polarization: control versus stimulated with anti-CD3 and anti-CD28.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_UNSTIM_VS_RESTIM_TH17_DAY15_POST_POLARIZATION_UP
Systematic name | M8578
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in Th17 cells 15 days post polarization: control versus stimulated with anti-CD3 and anti-CD28.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_UNSTIM_VS_RESTIM_TH17_DAY5_POST_POLARIZATION_UP
Systematic name | M8579
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in Th17 cells 5 days post polarization: control versus stimulated with anti-CD3 and anti-CD28.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_TH1_VS_TH17_RESTIMULATED_DAY15_POST_POLARIZATION_UP
Systematic name | M8580
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes up-regulated in T helper cells 15 days post polarization and stimulated with anti-CD3 and anti-CD28: Th1 versus Th17.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE26030_UNSTIM_VS_RESTIM_TH17_DAY5_POST_POLARIZATION_DN
Systematic name | M8581
Organism | Mus musculus
PMID | 22177921
Authors | Muranski P,Borman ZA,Kerkar SP,Klebanoff CA,Ji Y,Sanchez-Perez L,Sukumar M,Reger RN,Yu Z,Kern SJ,Roychoudhuri R,Ferreyra GA,Shen W,Durum SK,Feigenbaum L,Palmer DC,Antony PA,Chan CC,Laurence A,Danner RL,Gattinoni L,Restifo NP
Category | C7
Sub-category |
Brief description | Genes down-regulated in Th17 cells 5 days post polarization: control versus stimulated with anti-CD3 and anti-CD28.
Full description | Serial comparison between Th1 and Th17 tumor-specific cells cultured in vitro and ex vivo after transferred into sublethaly irradiated B6.PL mice. Th17-derived cells acquire Th1-like properties in vivo but maintain a distinct molecular profile.

Standard name | GSE22313_HEALTHY_VS_SLE_MOUSE_CD4_TCELL_DN
Systematic name | M8584
Organism | Mus musculus
PMID | 22180614
Authors | Cuda CM,Li S,Liang S,Yin Y,Potula HH,Xu Z,Sengupta M,Chen Y,Butfiloski E,Baker H,Chang LJ,Dozmorov I,Sobel ES,Morel L
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: healthy versus systemic lupus erythematosus (SLE).
Full description | Sle1a.1 is part of the Sle1a lupus susceptibility locus which results in the production of activated and autoreactive CD4+ T cells as well as a reduction in the peripheral regulatory T cell (Treg) pool. Sle1a.1 CD4+ T cells showed a defective response to retinoic acid (RA) expansion of TGFβ-induced Tregs. At the molecular level, Sle1a.1 corresponds to an increased expression of a novel splice isoform of Pbx1, Pbx1-d. Pbx1-d over-expression is sufficient to induce an activated/inflammatory phenotype in Jurkat T cells, and to decrease their apoptotic response to RA. PBX1-d is expressed more frequently in lupus patients than in healthy controls, and its presence correlates with an increased memory T cell population. These findings indicate that Pbx1 is a novel lupus susceptibility gene that regulates T cell activation and tolerance.

Standard name | GSE22313_HEALTHY_VS_SLE_MOUSE_CD4_TCELL_UP
Systematic name | M8586
Organism | Mus musculus
PMID | 22180614
Authors | Cuda CM,Li S,Liang S,Yin Y,Potula HH,Xu Z,Sengupta M,Chen Y,Butfiloski E,Baker H,Chang LJ,Dozmorov I,Sobel ES,Morel L
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: healthy versus systemic lupus erythematosus (SLE).
Full description | Sle1a.1 is part of the Sle1a lupus susceptibility locus which results in the production of activated and autoreactive CD4+ T cells as well as a reduction in the peripheral regulatory T cell (Treg) pool. Sle1a.1 CD4+ T cells showed a defective response to retinoic acid (RA) expansion of TGFβ-induced Tregs. At the molecular level, Sle1a.1 corresponds to an increased expression of a novel splice isoform of Pbx1, Pbx1-d. Pbx1-d over-expression is sufficient to induce an activated/inflammatory phenotype in Jurkat T cells, and to decrease their apoptotic response to RA. PBX1-d is expressed more frequently in lupus patients than in healthy controls, and its presence correlates with an increased memory T cell population. These findings indicate that Pbx1 is a novel lupus susceptibility gene that regulates T cell activation and tolerance.

Standard name | GSE27859_MACROPHAGE_VS_CD11C_INT_F480_INT_DC_DN
Systematic name | M8587
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages versus dendritic cells sorted as ITGAX int [GeneID=3687] and EMR1 int [GeneID=2015].
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_MACROPHAGE_VS_DC_DN
Systematic name | M8588
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages versus dendritic cells.
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_MACROPHAGE_VS_CD11C_INT_F480_HI_MACROPHAGE_DN
Systematic name | M8589
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages versus those sorted as ITGAX int [GeneID=3687] and EMR1 high [GeneID=2015].
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_MACROPHAGE_VS_DC_UP
Systematic name | M8590
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages versus dendritic cells.
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_CD11C_INT_F480_HI_MACROPHAGE_VS_CD11C_ING_F480_INT_DC_UP
Systematic name | M8591
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in cells sorted as ITGAX int [GeneID=3687]: EMR1 high [GeneID=2015] macrophages versus EMR1 int [GeneID=2015] dendritic cells.
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_MACROPHAGE_VS_CD11C_INT_F480_HI_MACROPHAGE_UP
Systematic name | M8593
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages versus those sorted as ITGAX int [GeneID=3687] and EMR1 high [GeneID=2015].
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_MACROPHAGE_VS_CD11C_INT_F480_INT_DC_UP
Systematic name | M8594
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages versus dendritic cells sorted as ITGAX int [GeneID=3687] and EMR1 int [GeneID=2015].
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_DC_VS_CD11C_INT_F480_HI_MACROPHAGE_DN
Systematic name | M8595
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells versus macrophages sorted as ITGAX int [GeneID=3687] and EMR1 high [GeneID=2015].
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_DC_VS_CD11C_INT_F480_INT_DC_UP
Systematic name | M8596
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells versus those sorted as ITGAX int [GeneID=3687] and EMR1 int [GeneID=2015].
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_DC_VS_CD11C_INT_F480_HI_MACROPHAGE_UP
Systematic name | M8597
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells versus macrophages sorted as ITGAX int [GeneID=3687] and EMR1 high [GeneID=2015].
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_CD11C_INT_F480_HI_MACROPHAGE_VS_CD11C_ING_F480_INT_DC_DN
Systematic name | M8598
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in cells sorted as ITGAX int [GeneID=3687]: EMR1 high [GeneID=2015] macrophages versus EMR1 int [GeneID=2015] dendritic cells.
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE27859_DC_VS_CD11C_INT_F480_INT_DC_DN
Systematic name | M8600
Organism | Mus musculus
PMID | 22231304
Authors | Rivollier A,He J,Kole A,Valatas V,Kelsall BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells versus those sorted as ITGAX int [GeneID=3687] and EMR1 int [GeneID=2015].
Full description | Dendritic cells (DCs) and macrophages (MPs) are important for immunological homeostasis in the colon. We found that F4/80hi CX3CR1hi (CD11b+CD103-) cells account for 80% of mouse colonic lamina propria (cLP) MHC-IIhi cells. Both CD11c+ and CD11c- cells within this population were identified as MPs based on multiple criteria, including a MP transcriptome revealed by microarray analysis. These MPs constitutively released high levels of IL-10 at least partially in response to the microbiota via an MyD88-independent mechanism. In contrast, cells expressing low to intermediate levels of F4/80 and CX3CR1 were identified as DCs, based on phenotypic and functional analysis and comprise three separate CD11chi cell populations: CD103+CX3CR1-CD11b- DCs, CD103+CX3CR1-CD11b+ DCs and CD103-CX3CR1intCD11b+ DCs. In non-inflammatory conditions, Ly6Chi monocytes differentiated primarily into CD11c+, but not CD11c- MPs. In contrast, during colitis, Ly6Chi monocytes massively invaded the colon and differentiated into pro-inflammatory CD103-CX3CR1intCD11b+ DCs, which produced high levels of IL-12, IL-23, iNOS and TNF. These findings demonstrate the dual capacity of Ly6Chi blood monocytes to differentiate into either regulatory MPs or inflammatory DCs in the colon, and that the balance of these immunologically antagonistic cell types is dictated by microenvironmental conditions.

Standard name | GSE32128_INOS_DEPENDENT_VS_INOS_INDEPENDENT_ACTIVATED_TCELL_DN
Systematic name | M8602
Organism | Mus musculus
PMID | 22238459
Authors | Johnson RM,Kerr MS,Slaven JE
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cell activation mechanism that was NOS2 [GeneID=4843] dependent versus NOS2 [GeneID=4843] independent activation.
Full description | Comparison of two Chlamydia-specific CD4 T cells that are dependent on iNOS to terminate Chlamydia replication in epithelial cells to two Chlamydia-specific CD4 T cells that are iNOS-independent: Chlamydia trachomatis urogenital serovars replicate predominately in epithelial cells lining the reproductive tract. This tissue tropism poses a unique challenge for the host immune system and vaccine development. Studies utilizing the Chlamydia muridarum mouse model have shown that CD4 T cells are critical and sufficient to clear primary genital tract infections. In vitro studies have shown that CD4 T cells terminate the infection in epithelial cells by up regulating epithelial iNOS transcription and nitric oxide production via IFN-gamma and T cell-epithelial cell interactions mediated by LFA-1-ICAM-1. This mechanism however is not critical as iNOS-deficient mice clear infections normally, and IFN-gamma deficient mice clear 99.9% of the infection with near normal kinetics. We recently showed that a subset of Chlamydia-specific CD4 T cell clones were able to terminate replication in epithelial cells using a mechanism that was independent of iNOS and IFN-gamma. That mechanism did not require physical lysis of infected cells, but instead required T cell degranulation. In this study we advanced that work using gene expression microarrays to compare CD4 T cell clones that are able to terminate epithelial replication via an iNOS-independent mechanism to iNOS-dependent CD4 T cell clones. Micro array experiments showed that Plac8 was differentially expressed by the T cell clones having the iNOS-independent mechanism. Plac8-deficient mice had significantly delayed clearance of C. muridarum genital tract infections, and that the large majority of Plac8-deficient mice treated with the iNOS-inhibitor N-monomethyl-L-arginine (MLA) were unable to resolve a C. muridarum genital tract infection over 8 weeks. These results demonstrate that there are two independent and redundant T cell mechanisms for clearing C. muridarum genital tract infections; one mechanism dependent on iNOS, the other mechanism dependent on Plac8. While T cells subsets have been defined by cytokine profiles, there are important subdivisions by effector functions, in this case CD4Plac8.

Standard name | GSE32128_INOS_DEPENDENT_VS_INOS_INDEPENDENT_ACTIVATED_TCELL_UP
Systematic name | M8605
Organism | Mus musculus
PMID | 22238459
Authors | Johnson RM,Kerr MS,Slaven JE
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cell activation mechanism that was NOS2 [GeneID=4843] dependent versus NOS2 [GeneID=4843] independent activation.
Full description | Comparison of two Chlamydia-specific CD4 T cells that are dependent on iNOS to terminate Chlamydia replication in epithelial cells to two Chlamydia-specific CD4 T cells that are iNOS-independent: Chlamydia trachomatis urogenital serovars replicate predominately in epithelial cells lining the reproductive tract. This tissue tropism poses a unique challenge for the host immune system and vaccine development. Studies utilizing the Chlamydia muridarum mouse model have shown that CD4 T cells are critical and sufficient to clear primary genital tract infections. In vitro studies have shown that CD4 T cells terminate the infection in epithelial cells by up regulating epithelial iNOS transcription and nitric oxide production via IFN-gamma and T cell-epithelial cell interactions mediated by LFA-1-ICAM-1. This mechanism however is not critical as iNOS-deficient mice clear infections normally, and IFN-gamma deficient mice clear 99.9% of the infection with near normal kinetics. We recently showed that a subset of Chlamydia-specific CD4 T cell clones were able to terminate replication in epithelial cells using a mechanism that was independent of iNOS and IFN-gamma. That mechanism did not require physical lysis of infected cells, but instead required T cell degranulation. In this study we advanced that work using gene expression microarrays to compare CD4 T cell clones that are able to terminate epithelial replication via an iNOS-independent mechanism to iNOS-dependent CD4 T cell clones. Micro array experiments showed that Plac8 was differentially expressed by the T cell clones having the iNOS-independent mechanism. Plac8-deficient mice had significantly delayed clearance of C. muridarum genital tract infections, and that the large majority of Plac8-deficient mice treated with the iNOS-inhibitor N-monomethyl-L-arginine (MLA) were unable to resolve a C. muridarum genital tract infection over 8 weeks. These results demonstrate that there are two independent and redundant T cell mechanisms for clearing C. muridarum genital tract infections; one mechanism dependent on iNOS, the other mechanism dependent on Plac8. While T cells subsets have been defined by cytokine profiles, there are important subdivisions by effector functions, in this case CD4Plac8.

Standard name | GSE32986_UNSTIM_VS_GMCSF_AND_CURDLAN_HIGHDOSE_STIM_DC_DN
Systematic name | M8606
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells: unstimulated versus CSF2 [GeneID=1437] and high dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_UNSTIM_VS_GMCSF_AND_CURDLAN_HIGHDOSE_STIM_DC_UP
Systematic name | M8608
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells: unstimulated versus CSF2 [GeneID=1437] and high dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_UNSTIM_VS_GMCSF_STIM_DC_UP
Systematic name | M8609
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells: unstimulated versus CSF2 [GeneID=1437].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_GMCSF_VS_GMCSF_AND_CURDLAN_LOWDOSE_STIM_DC_UP
Systematic name | M8610
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells CSF2 [GeneID=1437] versus CSF2 [GeneID=1437] and low dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_GMCSF_VS_GMCSF_AND_CURDLAN_LOWDOSE_STIM_DC_DN
Systematic name | M8611
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells CSF2 [GeneID=1437] versus CSF2 [GeneID=1437] and low dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_UNSTIM_VS_CURDLAN_LOWDOSE_STIM_DC_DN
Systematic name | M8612
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells: unstimulated versus low dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_UNSTIM_VS_CURDLAN_HIGHDOSE_STIM_DC_UP
Systematic name | M8614
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells: unstimulated versus high dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_UNSTIM_VS_CURDLAN_HIGHDOSE_STIM_DC_DN
Systematic name | M8618
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells: unstimulated versus high dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_UNSTIM_VS_GMCSF_AND_CURDLAN_LOWDOSE_STIM_DC_UP
Systematic name | M8619
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells: unstimulated versus CSF2 [GeneID=1437] and low dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_UNSTIM_VS_GMCSF_AND_CURDLAN_LOWDOSE_STIM_DC_DN
Systematic name | M8620
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells: unstimulated versus CSF2 [GeneID=1437] and low dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_GMCSF_AND_CURDLAN_LOWDOSE_VS_GMCSF_AND_CURDLAN_HIGHDOSE_STIM_DC_DN
Systematic name | M8622
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells treated by CSF2 [GeneID=1437] and 1,3-beta-D-oligoglucan [PubChem=11375554]: low dose versus high dose.
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_GMCSF_VS_GMCSF_AND_CURDLAN_HIGHDOSE_STIM_DC_DN
Systematic name | M8624
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells CSF2 [GeneID=1437] versus CSF2 [GeneID=1437] and high dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_CURDLAN_LOWDOSE_VS_GMCSF_AND_CURDLAN_LOWDOSE_STIM_DC_UP
Systematic name | M8625
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells: low dose of 1,3-beta-D-oligoglucan [PubChem=11375554] versus CSF2 [GeneID=1437] and low dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_CURDLAN_LOWDOSE_VS_GMCSF_AND_CURDLAN_LOWDOSE_STIM_DC_DN
Systematic name | M8628
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells: low dose of 1,3-beta-D-oligoglucan [PubChem=11375554] versus CSF2 [GeneID=1437] and low dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_GMCSF_VS_GMCSF_AND_CURDLAN_HIGHDOSE_STIM_DC_UP
Systematic name | M8630
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells CSF2 [GeneID=1437] versus CSF2 [GeneID=1437] and high dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_CURDLAN_HIGHDOSE_VS_GMCSF_AND_CURDLAN_HIGHDOSE_STIM_DC_DN
Systematic name | M8631
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells: high dose of 1,3-beta-D-oligoglucan [PubChem=11375554] versus CSF2 [GeneID=1437] and high dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_CURDLAN_LOWDOSE_VS_CURDLAN_HIGHDOSE_STIM_DC_UP
Systematic name | M8632
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells treated with 1,3-beta-D-oligoglucan [PubChem=11375554]: low dose versus high dose.
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_CURDLAN_LOWDOSE_VS_CURDLAN_HIGHDOSE_STIM_DC_DN
Systematic name | M8635
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells treated with 1,3-beta-D-oligoglucan [PubChem=11375554]: low dose versus high dose.
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_CURDLAN_HIGHDOSE_VS_GMCSF_AND_CURDLAN_HIGHDOSE_STIM_DC_UP
Systematic name | M8636
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells: high dose of 1,3-beta-D-oligoglucan [PubChem=11375554] versus CSF2 [GeneID=1437] and high dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_UNSTIM_VS_CURDLAN_LOWDOSE_STIM_DC_UP
Systematic name | M8638
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells: unstimulated versus low dose of 1,3-beta-D-oligoglucan [PubChem=11375554].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_GMCSF_AND_CURDLAN_LOWDOSE_VS_GMCSF_AND_CURDLAN_HIGHDOSE_STIM_DC_UP
Systematic name | M8639
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived dendritic cells treated by CSF2 [GeneID=1437] and 1,3-beta-D-oligoglucan [PubChem=11375554]: low dose versus high dose.
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE32986_UNSTIM_VS_GMCSF_STIM_DC_DN
Systematic name | M8641
Organism | Mus musculus
PMID | 22250091
Authors | Min L,Isa SA,Fam WN,Sze SK,Beretta O,Mortellaro A,Ruedl C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived dendritic cells: unstimulated versus CSF2 [GeneID=1437].
Full description | A simultaneous engagement of different pathogen recognition receptors provides a tailor made adaptive immunity for an efficient defence against distinct pathogens. For example, cross talk of TLR and c-type lectin signalling effectively shapes distinct gene expression patterns by integrating the signals at the level of NF-κB. Here, we extend this principle to a strong synergism between the Dectin-1 agonist, curdlan, and an inflammatory growth factor, GM-CSF. Both together act in synergy in inducing a strong inflammatory signature which converts immature DCs to potent effector DCs. A variety of cytokines (IL-1β, IL-6, TNF-α, IL-2 and IL-12p70), costimulatory molecules (CD80, CD86, CD40 and CD70), chemokines (CxCl1, CxCl2, CxCl3, CCl12, CCl17) as well as receptors and molecules involved in fugal recognition and immunity such as Mincle, Dectin-1, Dectin-2 and Pentraxin 3 are strongly up-regulated in DC treated simultaneously with curdlan and GM-CSF. The synergistic effect of both stimuli resulted in strong IKBα phosphorylation, in its rapid degradation and in enhanced nuclear translocation of all NF-κB subunits. We further identified MAPK ERK, as one possible integration site of both signals, since its phosphorylation was clearly augmented when curdlan was co-applied with GM-CSF. Our data demonstrate that the immunomodulatory activity of curdlan requires an additional signal provided by GM-CSF to successfully initiate a robust β-glucan specific cytokine and chemokine response. The integration of both signals clearly prime and tailor a more effective innate and adaptive response against invading microbes and fungi.

Standard name | GSE26343_WT_VS_NFAT5_KO_MACROPHAGE_LPS_STIM_UP
Systematic name | M8642
Organism | Mus musculus
PMID | 22312110
Authors | Buxadé M,Lunazzi G,Minguillón J,Iborra S,Berga-Bolaños R,Val Del M,Aramburu J,López-Rodríguez C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages stimulated with LPS: wildtype versus NFAT5 [GeneID=10725] knockout.
Full description | Gene expression from WT and NFAT5 KO primary macrophage cultures.

Standard name | GSE26343_UNSTIM_VS_LPS_STIM_NFAT5_KO_MACROPHAGE_DN
Systematic name | M8643
Organism | Mus musculus
PMID | 22312110
Authors | Buxadé M,Lunazzi G,Minguillón J,Iborra S,Berga-Bolaños R,Val Del M,Aramburu J,López-Rodríguez C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with NFAT5 [GeneID=10725] knockout: control versus stimulated with LPS.
Full description | Gene expression from WT and NFAT5 KO primary macrophage cultures.

Standard name | GSE26343_WT_VS_NFAT5_KO_MACROPHAGE_UP
Systematic name | M8644
Organism | Mus musculus
PMID | 22312110
Authors | Buxadé M,Lunazzi G,Minguillón J,Iborra S,Berga-Bolaños R,Val Del M,Aramburu J,López-Rodríguez C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: wildtype versus NFAT5 [GeneID=10725] knockout.
Full description | Gene expression from WT and NFAT5 KO primary macrophage cultures.

Standard name | GSE26343_WT_VS_NFAT5_KO_MACROPHAGE_DN
Systematic name | M8647
Organism | Mus musculus
PMID | 22312110
Authors | Buxadé M,Lunazzi G,Minguillón J,Iborra S,Berga-Bolaños R,Val Del M,Aramburu J,López-Rodríguez C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: wildtype versus NFAT5 [GeneID=10725] knockout.
Full description | Gene expression from WT and NFAT5 KO primary macrophage cultures.

Standard name | GSE26343_UNSTIM_VS_LPS_STIM_MACROPHAGE_DN
Systematic name | M8648
Organism | Mus musculus
PMID | 22312110
Authors | Buxadé M,Lunazzi G,Minguillón J,Iborra S,Berga-Bolaños R,Val Del M,Aramburu J,López-Rodríguez C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: control versus stimulated with LPS.
Full description | Gene expression from WT and NFAT5 KO primary macrophage cultures.

Standard name | GSE26343_UNSTIM_VS_LPS_STIM_NFAT5_KO_MACROPHAGE_UP
Systematic name | M8649
Organism | Mus musculus
PMID | 22312110
Authors | Buxadé M,Lunazzi G,Minguillón J,Iborra S,Berga-Bolaños R,Val Del M,Aramburu J,López-Rodríguez C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with NFAT5 [GeneID=10725] knockout: control versus stimulated with LPS.
Full description | Gene expression from WT and NFAT5 KO primary macrophage cultures.

Standard name | GSE26343_UNSTIM_VS_LPS_STIM_MACROPHAGE_UP
Systematic name | M8650
Organism | Mus musculus
PMID | 22312110
Authors | Buxadé M,Lunazzi G,Minguillón J,Iborra S,Berga-Bolaños R,Val Del M,Aramburu J,López-Rodríguez C
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: control versus stimulated with LPS.
Full description | Gene expression from WT and NFAT5 KO primary macrophage cultures.

Standard name | GSE26343_WT_VS_NFAT5_KO_MACROPHAGE_LPS_STIM_DN
Systematic name | M8651
Organism | Mus musculus
PMID | 22312110
Authors | Buxadé M,Lunazzi G,Minguillón J,Iborra S,Berga-Bolaños R,Val Del M,Aramburu J,López-Rodríguez C
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages stimulated with LPS: wildtype versus NFAT5 [GeneID=10725] knockout.
Full description | Gene expression from WT and NFAT5 KO primary macrophage cultures.

Standard name | GSE34392_ST2_KO_VS_WT_DAY8_LCMV_EFFECTOR_CD8_TCELL_UP
Systematic name | M8653
Organism | Mus musculus
PMID | 22323740
Authors | Bonilla WV,Fröhlich A,Senn K,Kallert S,Fernandez M,Johnson S,Kreutzfeldt M,Hegazy AN,Schrick C,Fallon PG,Klemenz R,Nakae S,Adler H,Merkler D,Löhning M,Pinschewer DD
Category | C7
Sub-category |
Brief description | Genes up-regulated in P14 CD8+ T cells: ST2 [GeneID=6761] knockout versus wildtype.
Full description | Pathogen-associated molecular patterns decisively influence antiviral immune responses, whereas the contribution of endogenous signals of tissue damage, also known as “damage-associated molecular patterns” or “alarmins”, remains ill-defined. We show that interleukin-33 (IL-33), an alarmin released from necrotic cells, is necessary for potent CD8+ T cell (CTL) responses to replicating, prototypic RNA and DNA viruses in mice. IL-33 signaled through its receptor on activated CTLs, enhanced clonal expansion in a MyD88-dependent, CTL-intrinsic fashion, determined polyfunctional effector cell differentiation and was necessary for virus control. Moreover, recombinant IL-33 augmented vaccine-induced CTL responses. Radio-resistant cells of the splenic T cell zone produced IL-33, and efficient CTL responses required IL-33 from radio-resistant cells but not from hematopoietic cells. Thus, alarmin release by radio-resistant cells orchestrates protective antiviral CTL responses.

Standard name | GSE34392_ST2_KO_VS_WT_DAY8_LCMV_EFFECTOR_CD8_TCELL_DN
Systematic name | M8654
Organism | Mus musculus
PMID | 22323740
Authors | Bonilla WV,Fröhlich A,Senn K,Kallert S,Fernandez M,Johnson S,Kreutzfeldt M,Hegazy AN,Schrick C,Fallon PG,Klemenz R,Nakae S,Adler H,Merkler D,Löhning M,Pinschewer DD
Category | C7
Sub-category |
Brief description | Genes down-regulated in P14 CD8+ T cells: ST2 [GeneID=6761] knockout versus wildtype.
Full description | Pathogen-associated molecular patterns decisively influence antiviral immune responses, whereas the contribution of endogenous signals of tissue damage, also known as “damage-associated molecular patterns” or “alarmins”, remains ill-defined. We show that interleukin-33 (IL-33), an alarmin released from necrotic cells, is necessary for potent CD8+ T cell (CTL) responses to replicating, prototypic RNA and DNA viruses in mice. IL-33 signaled through its receptor on activated CTLs, enhanced clonal expansion in a MyD88-dependent, CTL-intrinsic fashion, determined polyfunctional effector cell differentiation and was necessary for virus control. Moreover, recombinant IL-33 augmented vaccine-induced CTL responses. Radio-resistant cells of the splenic T cell zone produced IL-33, and efficient CTL responses required IL-33 from radio-resistant cells but not from hematopoietic cells. Thus, alarmin release by radio-resistant cells orchestrates protective antiviral CTL responses.

Standard name | GSE35825_IFNA_VS_IFNG_STIM_MACROPHAGE_DN
Systematic name | M8656
Organism | Mus musculus
PMID | 22371602
Authors | Liu SY,Sanchez DJ,Aliyari R,Lu S,Cheng G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: interferon alpha versus IFNG [GeneID=3458].
Full description | We used microarrays to compare interferon-alpha (IFNa)- and interferon-gamma (IFNg)-stimulated genes under an equivalent biological input. The goal was to compare IFNa- and IFNg-stimulated genes, as well as to identify common and distinct sets of type I and II ISGs.

Standard name | GSE35825_UNTREATED_VS_IFNG_STIM_MACROPHAGE_UP
Systematic name | M8657
Organism | Mus musculus
PMID | 22371602
Authors | Liu SY,Sanchez DJ,Aliyari R,Lu S,Cheng G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: untreated versus stimulated by IFNG [GeneID=3458].
Full description | We used microarrays to compare interferon-alpha (IFNa)- and interferon-gamma (IFNg)-stimulated genes under an equivalent biological input. The goal was to compare IFNa- and IFNg-stimulated genes, as well as to identify common and distinct sets of type I and II ISGs.

Standard name | GSE35825_UNTREATED_VS_IFNA_STIM_MACROPHAGE_UP
Systematic name | M8658
Organism | Mus musculus
PMID | 22371602
Authors | Liu SY,Sanchez DJ,Aliyari R,Lu S,Cheng G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: untreated versus stimulated by interferon alpha.
Full description | We used microarrays to compare interferon-alpha (IFNa)- and interferon-gamma (IFNg)-stimulated genes under an equivalent biological input. The goal was to compare IFNa- and IFNg-stimulated genes, as well as to identify common and distinct sets of type I and II ISGs.

Standard name | GSE35825_UNTREATED_VS_IFNA_STIM_MACROPHAGE_DN
Systematic name | M8661
Organism | Mus musculus
PMID | 22371602
Authors | Liu SY,Sanchez DJ,Aliyari R,Lu S,Cheng G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: untreated versus stimulated by interferon alpha.
Full description | We used microarrays to compare interferon-alpha (IFNa)- and interferon-gamma (IFNg)-stimulated genes under an equivalent biological input. The goal was to compare IFNa- and IFNg-stimulated genes, as well as to identify common and distinct sets of type I and II ISGs.

Standard name | GSE35825_UNTREATED_VS_IFNG_STIM_MACROPHAGE_DN
Systematic name | M8662
Organism | Mus musculus
PMID | 22371602
Authors | Liu SY,Sanchez DJ,Aliyari R,Lu S,Cheng G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: untreated versus stimulated by IFNG [GeneID=3458].
Full description | We used microarrays to compare interferon-alpha (IFNa)- and interferon-gamma (IFNg)-stimulated genes under an equivalent biological input. The goal was to compare IFNa- and IFNg-stimulated genes, as well as to identify common and distinct sets of type I and II ISGs.

Standard name | GSE35825_IFNA_VS_IFNG_STIM_MACROPHAGE_UP
Systematic name | M8663
Organism | Mus musculus
PMID | 22371602
Authors | Liu SY,Sanchez DJ,Aliyari R,Lu S,Cheng G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: interferon alpha versus IFNG [GeneID=3458].
Full description | We used microarrays to compare interferon-alpha (IFNa)- and interferon-gamma (IFNg)-stimulated genes under an equivalent biological input. The goal was to compare IFNa- and IFNg-stimulated genes, as well as to identify common and distinct sets of type I and II ISGs.

Standard name | GSE34156_UNTREATED_VS_6H_NOD2_AND_TLR1_TLR2_LIGAND_TREATED_MONOCYTE_DN
Systematic name | M8664
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (6h): untreated versus muramyl dipeptide [PubChem=11620162] andM. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_6H_NOD2_LIGAND_TREATED_MONOCYTE_UP
Systematic name | M8665
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (6h): untreated versus muramyl dipeptide [PubChem=11620162].
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_6H_NOD2_LIGAND_TREATED_MONOCYTE_DN
Systematic name | M8666
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (6h): untreated versus muramyl dipeptide [PubChem=11620162].
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_6H_TLR1_TLR2_LIGAND_TREATED_MONOCYTE_DN
Systematic name | M8667
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (6h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_6H_NOD2_AND_TLR1_TLR2_LIGAND_TREATED_MONOCYTE_UP
Systematic name | M8668
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (6h): untreated versus muramyl dipeptide [PubChem=11620162] andM. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_24H_NOD2_AND_TLR1_TLR2_LIGAND_TREATED_MONOCYTE_DN
Systematic name | M8670
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (24h): untreated versus muramyl dipeptide [PubChem=11620162] andM. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_NOD2_LIGAND_VS_TLR1_TLR2_LIGAND_24H_TREATED_MONOCYTE_UP
Systematic name | M8671
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (24h): muramyl dipeptide [PubChem=11620162] versus M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_6H_TLR1_TLR2_LIGAND_TREATED_MONOCYTE_UP
Systematic name | M8672
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (6h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_24H_NOD2_AND_TLR1_TLR2_LIGAND_TREATED_MONOCYTE_UP
Systematic name | M8674
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (24h): untreated versus muramyl dipeptide [PubChem=11620162] andM. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_NOD2_LIGAND_VS_NOD2_AND_TLR1_TLR2_LIGAND_24H_TREATED_MONOCYTE_DN
Systematic name | M8675
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (24h): muramyl dipeptide [PubChem=11620162] versus muramyl dipeptide [PubChem=11620162] and M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_TLR1_TLR2_LIGAND_VS_NOD2_AND_TLR1_TLR2_LIGAND_24H_TREATED_MONOCYTE_UP
Systematic name | M8676
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (24h): M. tuberculosis 19 kDa lipopeptide versus M. tuberculosis 19 kDa lipopeptide and muramyl dipeptide [PubChem=11620162].
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_NOD2_LIGAND_VS_TLR1_TLR2_LIGAND_24H_TREATED_MONOCYTE_DN
Systematic name | M8678
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (24h): muramyl dipeptide [PubChem=11620162] versus M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_NOD2_LIGAND_VS_NOD2_AND_TLR1_TLR2_LIGAND_24H_TREATED_MONOCYTE_UP
Systematic name | M8679
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (24h): muramyl dipeptide [PubChem=11620162] versus muramyl dipeptide [PubChem=11620162] and M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_TLR1_TLR2_LIGAND_VS_NOD2_AND_TLR1_TLR2_LIGAND_6H_TREATED_MONOCYTE_DN
Systematic name | M8680
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (6h): M. tuberculosis 19 kDa lipopeptide versus M. tuberculosis 19 kDa lipopeptide and muramyl dipeptide [PubChem=11620162].
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_24H_NOD2_LIGAND_TREATED_MONOCYTE_UP
Systematic name | M8681
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (24h): untreated versus muramyl dipeptide [PubChem=11620162].
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_24H_NOD2_LIGAND_TREATED_MONOCYTE_DN
Systematic name | M8682
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (24h): untreated versus muramyl dipeptide [PubChem=11620162].
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_24H_TLR1_TLR2_LIGAND_TREATED_MONOCYTE_UP
Systematic name | M8683
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (24h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_UNTREATED_VS_24H_TLR1_TLR2_LIGAND_TREATED_MONOCYTE_DN
Systematic name | M8685
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (24h): untreated versus M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_NOD2_LIGAND_VS_TLR1_TLR2_LIGAND_6H_TREATED_MONOCYTE_DN
Systematic name | M8686
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (6h): muramyl dipeptide [PubChem=11620162] versus M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_NOD2_LIGAND_VS_NOD2_AND_TLR1_TLR2_LIGAND_6H_TREATED_MONOCYTE_UP
Systematic name | M8687
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (6h): muramyl dipeptide [PubChem=11620162] versus muramyl dipeptide [PubChem=11620162] and M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_NOD2_LIGAND_VS_NOD2_AND_TLR1_TLR2_LIGAND_6H_TREATED_MONOCYTE_DN
Systematic name | M8688
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (6h): muramyl dipeptide [PubChem=11620162] versus muramyl dipeptide [PubChem=11620162] and M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_NOD2_LIGAND_VS_TLR1_TLR2_LIGAND_6H_TREATED_MONOCYTE_UP
Systematic name | M8690
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (6h): muramyl dipeptide [PubChem=11620162] versus M. tuberculosis 19 kDa lipopeptide.
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_TLR1_TLR2_LIGAND_VS_NOD2_AND_TLR1_TLR2_LIGAND_24H_TREATED_MONOCYTE_DN
Systematic name | M8691
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes (24h): M. tuberculosis 19 kDa lipopeptide versus M. tuberculosis 19 kDa lipopeptide and muramyl dipeptide [PubChem=11620162].
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE34156_TLR1_TLR2_LIGAND_VS_NOD2_AND_TLR1_TLR2_LIGAND_6H_TREATED_MONOCYTE_UP
Systematic name | M8693
Organism | Homo sapiens
PMID | 22447076
Authors | Schenk M,Krutzik SR,Sieling PA,Lee DJ,Teles RM,Ochoa MT,Komisopoulou E,Sarno EN,Rea TH,Graeber TG,Kim S,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes (6h): M. tuberculosis 19 kDa lipopeptide versus M. tuberculosis 19 kDa lipopeptide and muramyl dipeptide [PubChem=11620162].
Full description | human blood monocytes were isolated, activated and harvested at several timepoints In this study, we identified genes that were differentially expressed in human monocytes activated with eiter NOD2L and/or TLR2/1L.

Standard name | GSE30971_2H_VS_4H_LPS_STIM_MACROPHAGE_WBP7_KO_DN
Systematic name | M8694
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with MLL4 [GeneID=9757] knockout: 2h LPS versus 4h LPS.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_WBP7_HET_VS_KO_MACROPHAGE_UP
Systematic name | M8698
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages: heterozygous versus homozygous knockout of MLL4 [GeneID=9757].
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_2H_VS_4H_LPS_STIM_MACROPHAGE_WBP7_KO_UP
Systematic name | M8703
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with MLL4 [GeneID=9757] knockout: 2h LPS versus 4h LPS.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_CTRL_VS_LPS_STIM_MACROPHAGE_WBP7_HET_4H_UP
Systematic name | M8705
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with heterozygous MLL4 [GeneID=9757] knockout: control versus treated with LPS for 4h.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_CTRL_VS_LPS_STIM_MACROPHAGE_WBP7_HET_4H_DN
Systematic name | M8707
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with heterozygous MLL4 [GeneID=9757] knockout: control versus treated with LPS for 4h.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_CTRL_VS_LPS_STIM_MACROPHAGE_WBP7_HET_2H_UP
Systematic name | M8708
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with heterozygous MLL4 [GeneID=9757] knockout: control versus treated with LPS for 2h.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_CTRL_VS_LPS_STIM_MACROPHAGE_WBP7_HET_2H_DN
Systematic name | M8709
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with heterozygous MLL4 [GeneID=9757] knockout: control versus treated with LPS for 2h.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_CTRL_VS_LPS_STIM_MACROPHAGE_WBP7_KO_2H_UP
Systematic name | M8710
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with MLL4 [GeneID=9757] knockout: control versus treated with LPS for 2h.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_CTRL_VS_LPS_STIM_MACROPHAGE_WBP7_KO_2H_DN
Systematic name | M8712
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with MLL4 [GeneID=9757] knockout: control versus treated with LPS for 2h.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_CTRL_VS_LPS_STIM_MACROPHAGE_WBP7_KO_4H_UP
Systematic name | M8714
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with MLL4 [GeneID=9757] knockout: control versus treated with LPS for 4h.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_CTRL_VS_LPS_STIM_MACROPHAGE_WBP7_KO_4H_DN
Systematic name | M8717
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with MLL4 [GeneID=9757] knockout: control versus treated with LPS for 4h.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_WBP7_HET_VS_KO_MACROPHAGE_DN
Systematic name | M8721
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages: heterozygous versus homozygous knockout of MLL4 [GeneID=9757].
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_WBP7_HET_VS_KO_MACROPHAGE_2H_LPS_STIM_UP
Systematic name | M8722
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages treated with LPS for 2h: heterozygous versus homozygous knockout of MLL4 [GeneID=9757].
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_WBP7_HET_VS_KO_MACROPHAGE_2H_LPS_STIM_DN
Systematic name | M8723
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages treated with LPS for 2h: heterozygous versus homozygous knockout of MLL4 [GeneID=9757].
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_2H_VS_4H_LPS_STIM_MACROPHAGE_WBP7_HET_UP
Systematic name | M8724
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages with heterozygous MLL4 [GeneID=9757] knockout: 2h LPS versus 4h LPS.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_2H_VS_4H_LPS_STIM_MACROPHAGE_WBP7_HET_DN
Systematic name | M8725
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages with heterozygous MLL4 [GeneID=9757] knockout: 2h LPS versus 4h LPS.
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_WBP7_HET_VS_KO_MACROPHAGE_4H_LPS_STIM_DN
Systematic name | M8726
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived macrophages treated with LPS for 4h: heterozygous versus homozygous knockout of MLL4 [GeneID=9757].
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE30971_WBP7_HET_VS_KO_MACROPHAGE_4H_LPS_STIM_UP
Systematic name | M8727
Organism | Mus musculus
PMID | 22483804
Authors | Austenaa L,Barozzi I,Chronowska A,Termanini A,Ostuni R,Prosperini E,Stewart AF,Testa G,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived macrophages treated with LPS for 4h: heterozygous versus homozygous knockout of MLL4 [GeneID=9757].
Full description | Histone methyltransferases catalyze site-specific deposition of methyl groups, enabling recruitment of transcriptional regulators. In mammals, trimethylation of lysine 4 in histone H3, a modification localized at the transcription start sites of active genes, is catalyzed by six enzymes (SET1a and SET1b, MLL1–MLL4) whose specific functions are largely unknown. By using a genomic approach, we found that in macrophages, MLL4 (also known as Wbp7) was required for the expression of Pigp, an essential component of the GPI-GlcNAc transferase, the enzyme catalyzing the first step of glycosylphosphatidylinositol (GPI) anchor synthesis. Impaired Pigp expression in Wbp7-/- macrophages abolished GPI anchor-dependent loading of proteins on the cell membrane. Consistently, loss of GPI-anchored CD14, the coreceptor for lipopolysaccharide (LPS) and other bacterial molecules, markedly attenuated LPS-triggered intracellular signals and gene expression changes. These data link a histone-modifying enzyme to a biosynthetic pathway and indicate a specialized biological role for Wbp7 in macrophage function and antimicrobial response.

Standard name | GSE36888_STAT5_AB_KNOCKIN_VS_WT_TCELL_IL2_TREATED_2H_UP
Systematic name | M8730
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells stimulated by IL2 [GeneID=3558] for 2h: STAT5 double knock-in versus wildtype.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_STAT5_AB_KNOCKIN_TCELL_2H_UP
Systematic name | M8733
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in STAT5 double knock-in T cells: control versus IL2 [GeneID=3558] stimulation for 2h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_TCELL_17H_UP
Systematic name | M8734
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: control versus IL2 [GeneID=3558] stimulation for 17h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_TCELL_17H_DN
Systematic name | M8735
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: control versus IL2 [GeneID=3558] stimulation for 17h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_TCELL_2H_DN
Systematic name | M8736
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: control versus IL2 [GeneID=3558] stimulation for 2h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_STAT5_AB_KNOCKIN_TCELL_6H_UP
Systematic name | M8737
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in STAT5 double knock-in T cells: control versus IL2 [GeneID=3558] stimulation for 6h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_STAT5_AB_KNOCKIN_TCELL_6H_DN
Systematic name | M8738
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in STAT5 double knock-in T cells: control versus IL2 [GeneID=3558] stimulation for 6h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_TCELL_6H_UP
Systematic name | M8739
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: control versus IL2 [GeneID=3558] stimulation for 6h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_TCELL_6H_DN
Systematic name | M8741
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells: control versus IL2 [GeneID=3558] stimulation for 6h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_STAT5_AB_KNOCKIN_TCELL_17H_UP
Systematic name | M8742
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in STAT5 double knock-in T cells: control versus IL2 [GeneID=3558] stimulation for 17h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_STAT5_AB_KNOCKIN_TCELL_17H_DN
Systematic name | M8743
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in STAT5 double knock-in T cells: control versus IL2 [GeneID=3558] stimulation for 17h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_STAT5_AB_KNOCKIN_VS_WT_TCELL_IL2_TREATED_6H_UP
Systematic name | M8744
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells stimulated by IL2 [GeneID=3558] for 6h: STAT5 double knock-in versus wildtype.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_STAT5_AB_KNOCKIN_VS_WT_TCELL_IL2_TREATED_6H_DN
Systematic name | M8745
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells stimulated by IL2 [GeneID=3558] for 6h: STAT5 double knock-in versus wildtype.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_STAT5_AB_KNOCKIN_VS_WT_TCELL_IL2_TREATED_17H_UP
Systematic name | M8748
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells stimulated by IL2 [GeneID=3558] for 17h: STAT5 double knock-in versus wildtype.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_STAT5_AB_KNOCKIN_VS_WT_TCELL_IL2_TREATED_2H_DN
Systematic name | M8750
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells stimulated by IL2 [GeneID=3558] for 2h: STAT5 double knock-in versus wildtype.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_TCELL_2H_UP
Systematic name | M8752
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T cells: control versus IL2 [GeneID=3558] stimulation for 2h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_STAT5_AB_KNOCKIN_VS_WT_TCELL_IL2_TREATED_17H_DN
Systematic name | M8755
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T cells stimulated by IL2 [GeneID=3558] for 17h: STAT5 double knock-in versus wildtype.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE36888_UNTREATED_VS_IL2_TREATED_STAT5_AB_KNOCKIN_TCELL_2H_DN
Systematic name | M8757
Organism | Mus musculus
PMID | 22520852
Authors | Lin JX,Li P,Liu D,Jin HT,He J,Rasheed Ur Ata M,Rochman Y,Wang L,Cui K,Liu C,Kelsall BL,Ahmed R,Leonard WJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in STAT5 double knock-in T cells: control versus IL2 [GeneID=3558] stimulation for 2h.
Full description | Cytokine-activated STAT proteins dimerize and bind to high-affinity motifs, and N-terminal domain-mediated oligomerization of dimers allows tetramer formation and binding to low-affinity tandem motifs, but the functions of dimers versus tetramers are unknown. We generated Stat5a and Stat5b double knock-in (DKI) N-domain mutant mice that form dimers but not tetramers, identified cytokine-regulated genes whose expression required STAT5 tetramers, and defined consensus motifs for dimers versus tetramers. Whereas Stat5- deficient mice exhibited perinatal lethality, DKI mice were viable, indicating that STAT5 dimers were sufficient for survival. Nevertheless, STAT5 DKI mice had fewer CD4+CD25+ T cells, NK cells, and CD8+ T cells, with impaired cytokine-induced proliferation and homeostatic proliferation of CD8+ T cells. DKI CD8+ T cell proliferation following viral infection was diminished and DKI Treg cells did not efficiently control colitis. Thus, tetramerization of STAT5 is dispensable for survival but is critical for cytokine responses and normal immune function.

Standard name | GSE34515_CD16_NEG_MONOCYTE_VS_DC_UP
Systematic name | M8761
Organism | Homo sapiens
PMID | 22531920
Authors | Frankenberger M,Hofer TP,Marei A,Dayyani F,Schewe S,Strasser C,Aldraihim A,Stanzel F,Lang R,Hoffmann R,Costa da Prazeres O,Buch T,Ziegler-Heitbrock L
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD16- monocytes versus dendritic cells.
Full description | In this study gene expression of human blood classical monocytes (CD14++CD16-), CD16 positive monocytes (consisting of non-classical CD14+16++ and intermediate CD14++CD16+ monocytes) and CD1c+ CD19- dendritic cells from healthy subjects were investigated.

Standard name | GSE34515_CD16_NEG_VS_POS_MONOCYTE_DN
Systematic name | M8762
Organism | Homo sapiens
PMID | 22531920
Authors | Frankenberger M,Hofer TP,Marei A,Dayyani F,Schewe S,Strasser C,Aldraihim A,Stanzel F,Lang R,Hoffmann R,Costa da Prazeres O,Buch T,Ziegler-Heitbrock L
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes: CD16- versus CD16+.
Full description | In this study gene expression of human blood classical monocytes (CD14++CD16-), CD16 positive monocytes (consisting of non-classical CD14+16++ and intermediate CD14++CD16+ monocytes) and CD1c+ CD19- dendritic cells from healthy subjects were investigated.

Standard name | GSE34515_CD16_POS_MONOCYTE_VS_DC_DN
Systematic name | M8763
Organism | Homo sapiens
PMID | 22531920
Authors | Frankenberger M,Hofer TP,Marei A,Dayyani F,Schewe S,Strasser C,Aldraihim A,Stanzel F,Lang R,Hoffmann R,Costa da Prazeres O,Buch T,Ziegler-Heitbrock L
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD16+ monocytes versus dendritic cells.
Full description | In this study gene expression of human blood classical monocytes (CD14++CD16-), CD16 positive monocytes (consisting of non-classical CD14+16++ and intermediate CD14++CD16+ monocytes) and CD1c+ CD19- dendritic cells from healthy subjects were investigated.

Standard name | GSE34515_CD16_NEG_VS_POS_MONOCYTE_UP
Systematic name | M8764
Organism | Homo sapiens
PMID | 22531920
Authors | Frankenberger M,Hofer TP,Marei A,Dayyani F,Schewe S,Strasser C,Aldraihim A,Stanzel F,Lang R,Hoffmann R,Costa da Prazeres O,Buch T,Ziegler-Heitbrock L
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes: CD16- versus CD16+.
Full description | In this study gene expression of human blood classical monocytes (CD14++CD16-), CD16 positive monocytes (consisting of non-classical CD14+16++ and intermediate CD14++CD16+ monocytes) and CD1c+ CD19- dendritic cells from healthy subjects were investigated.

Standard name | GSE34515_CD16_POS_MONOCYTE_VS_DC_UP
Systematic name | M8765
Organism | Homo sapiens
PMID | 22531920
Authors | Frankenberger M,Hofer TP,Marei A,Dayyani F,Schewe S,Strasser C,Aldraihim A,Stanzel F,Lang R,Hoffmann R,Costa da Prazeres O,Buch T,Ziegler-Heitbrock L
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD16+ monocytes versus dendritic cells.
Full description | In this study gene expression of human blood classical monocytes (CD14++CD16-), CD16 positive monocytes (consisting of non-classical CD14+16++ and intermediate CD14++CD16+ monocytes) and CD1c+ CD19- dendritic cells from healthy subjects were investigated.

Standard name | GSE34515_CD16_NEG_MONOCYTE_VS_DC_DN
Systematic name | M8766
Organism | Homo sapiens
PMID | 22531920
Authors | Frankenberger M,Hofer TP,Marei A,Dayyani F,Schewe S,Strasser C,Aldraihim A,Stanzel F,Lang R,Hoffmann R,Costa da Prazeres O,Buch T,Ziegler-Heitbrock L
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD16- monocytes versus dendritic cells.
Full description | In this study gene expression of human blood classical monocytes (CD14++CD16-), CD16 positive monocytes (consisting of non-classical CD14+16++ and intermediate CD14++CD16+ monocytes) and CD1c+ CD19- dendritic cells from healthy subjects were investigated.

Standard name | GSE36009_UNSTIM_VS_LPS_STIM_NLRP10_KO_DC_UP
Systematic name | M8767
Organism | Mus musculus
PMID | 22538615
Authors | Eisenbarth SC,Williams A,Colegio OR,Meng H,Strowig T,Rongvaux A,Henao-Mejia J,Thaiss CA,Joly S,Gonzalez DG,Xu L,Zenewicz LA,Haberman AM,Elinav E,Kleinstein SH,Sutterwala FS,Flavell RA
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells with knockout of NLRP10 [GeneID=338322]: control versus LPS.
Full description | Nlrp10-deficient mice have a profound defect in helper T cell-driven immune responses. T cell priming is impaired due to a defect in the emigration of a dendritic cells from inflamed tissue and antigen transport to draining lymph nodes. DC chemotaxis to CCR7-dependent and independent ligands is intact in the absence of Nlrp10. Therefore to identify novel molecules potentially involved in Nlrp10-dependent DC function we used an unbiased gene array approach on Nlrp10-deficient BMDCs treated with or without LPS.

Standard name | GSE36009_UNSTIM_VS_LPS_STIM_NLRP10_KO_DC_DN
Systematic name | M8768
Organism | Mus musculus
PMID | 22538615
Authors | Eisenbarth SC,Williams A,Colegio OR,Meng H,Strowig T,Rongvaux A,Henao-Mejia J,Thaiss CA,Joly S,Gonzalez DG,Xu L,Zenewicz LA,Haberman AM,Elinav E,Kleinstein SH,Sutterwala FS,Flavell RA
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells with knockout of NLRP10 [GeneID=338322]: control versus LPS.
Full description | Nlrp10-deficient mice have a profound defect in helper T cell-driven immune responses. T cell priming is impaired due to a defect in the emigration of a dendritic cells from inflamed tissue and antigen transport to draining lymph nodes. DC chemotaxis to CCR7-dependent and independent ligands is intact in the absence of Nlrp10. Therefore to identify novel molecules potentially involved in Nlrp10-dependent DC function we used an unbiased gene array approach on Nlrp10-deficient BMDCs treated with or without LPS.

Standard name | GSE36009_WT_VS_NLRP10_KO_DC_LPS_STIM_UP
Systematic name | M8769
Organism | Mus musculus
PMID | 22538615
Authors | Eisenbarth SC,Williams A,Colegio OR,Meng H,Strowig T,Rongvaux A,Henao-Mejia J,Thaiss CA,Joly S,Gonzalez DG,Xu L,Zenewicz LA,Haberman AM,Elinav E,Kleinstein SH,Sutterwala FS,Flavell RA
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells in response to LPS: wildtype versus NLRP10 [GeneID=338322] knockout.
Full description | Nlrp10-deficient mice have a profound defect in helper T cell-driven immune responses. T cell priming is impaired due to a defect in the emigration of a dendritic cells from inflamed tissue and antigen transport to draining lymph nodes. DC chemotaxis to CCR7-dependent and independent ligands is intact in the absence of Nlrp10. Therefore to identify novel molecules potentially involved in Nlrp10-dependent DC function we used an unbiased gene array approach on Nlrp10-deficient BMDCs treated with or without LPS.

Standard name | GSE36009_WT_VS_NLRP10_KO_DC_LPS_STIM_DN
Systematic name | M8770
Organism | Mus musculus
PMID | 22538615
Authors | Eisenbarth SC,Williams A,Colegio OR,Meng H,Strowig T,Rongvaux A,Henao-Mejia J,Thaiss CA,Joly S,Gonzalez DG,Xu L,Zenewicz LA,Haberman AM,Elinav E,Kleinstein SH,Sutterwala FS,Flavell RA
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells in response to LPS: wildtype versus NLRP10 [GeneID=338322] knockout.
Full description | Nlrp10-deficient mice have a profound defect in helper T cell-driven immune responses. T cell priming is impaired due to a defect in the emigration of a dendritic cells from inflamed tissue and antigen transport to draining lymph nodes. DC chemotaxis to CCR7-dependent and independent ligands is intact in the absence of Nlrp10. Therefore to identify novel molecules potentially involved in Nlrp10-dependent DC function we used an unbiased gene array approach on Nlrp10-deficient BMDCs treated with or without LPS.

Standard name | GSE36009_UNSTIM_VS_LPS_STIM_DC_DN
Systematic name | M8774
Organism | Mus musculus
PMID | 22538615
Authors | Eisenbarth SC,Williams A,Colegio OR,Meng H,Strowig T,Rongvaux A,Henao-Mejia J,Thaiss CA,Joly S,Gonzalez DG,Xu L,Zenewicz LA,Haberman AM,Elinav E,Kleinstein SH,Sutterwala FS,Flavell RA
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: control versus LPS.
Full description | Nlrp10-deficient mice have a profound defect in helper T cell-driven immune responses. T cell priming is impaired due to a defect in the emigration of a dendritic cells from inflamed tissue and antigen transport to draining lymph nodes. DC chemotaxis to CCR7-dependent and independent ligands is intact in the absence of Nlrp10. Therefore to identify novel molecules potentially involved in Nlrp10-dependent DC function we used an unbiased gene array approach on Nlrp10-deficient BMDCs treated with or without LPS.

Standard name | GSE36009_WT_VS_NLRP10_KO_DC_UP
Systematic name | M8775
Organism | Mus musculus
PMID | 22538615
Authors | Eisenbarth SC,Williams A,Colegio OR,Meng H,Strowig T,Rongvaux A,Henao-Mejia J,Thaiss CA,Joly S,Gonzalez DG,Xu L,Zenewicz LA,Haberman AM,Elinav E,Kleinstein SH,Sutterwala FS,Flavell RA
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: wildtype versus NLRP10 [GeneID=338322] knockout.
Full description | Nlrp10-deficient mice have a profound defect in helper T cell-driven immune responses. T cell priming is impaired due to a defect in the emigration of a dendritic cells from inflamed tissue and antigen transport to draining lymph nodes. DC chemotaxis to CCR7-dependent and independent ligands is intact in the absence of Nlrp10. Therefore to identify novel molecules potentially involved in Nlrp10-dependent DC function we used an unbiased gene array approach on Nlrp10-deficient BMDCs treated with or without LPS.

Standard name | GSE36009_WT_VS_NLRP10_KO_DC_DN
Systematic name | M8777
Organism | Mus musculus
PMID | 22538615
Authors | Eisenbarth SC,Williams A,Colegio OR,Meng H,Strowig T,Rongvaux A,Henao-Mejia J,Thaiss CA,Joly S,Gonzalez DG,Xu L,Zenewicz LA,Haberman AM,Elinav E,Kleinstein SH,Sutterwala FS,Flavell RA
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: wildtype versus NLRP10 [GeneID=338322] knockout.
Full description | Nlrp10-deficient mice have a profound defect in helper T cell-driven immune responses. T cell priming is impaired due to a defect in the emigration of a dendritic cells from inflamed tissue and antigen transport to draining lymph nodes. DC chemotaxis to CCR7-dependent and independent ligands is intact in the absence of Nlrp10. Therefore to identify novel molecules potentially involved in Nlrp10-dependent DC function we used an unbiased gene array approach on Nlrp10-deficient BMDCs treated with or without LPS.

Standard name | GSE36009_UNSTIM_VS_LPS_STIM_DC_UP
Systematic name | M8778
Organism | Mus musculus
PMID | 22538615
Authors | Eisenbarth SC,Williams A,Colegio OR,Meng H,Strowig T,Rongvaux A,Henao-Mejia J,Thaiss CA,Joly S,Gonzalez DG,Xu L,Zenewicz LA,Haberman AM,Elinav E,Kleinstein SH,Sutterwala FS,Flavell RA
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: control versus LPS.
Full description | Nlrp10-deficient mice have a profound defect in helper T cell-driven immune responses. T cell priming is impaired due to a defect in the emigration of a dendritic cells from inflamed tissue and antigen transport to draining lymph nodes. DC chemotaxis to CCR7-dependent and independent ligands is intact in the absence of Nlrp10. Therefore to identify novel molecules potentially involved in Nlrp10-dependent DC function we used an unbiased gene array approach on Nlrp10-deficient BMDCs treated with or without LPS.

Standard name | GSE36891_UNSTIM_VS_POLYIC_TLR3_STIM_PERITONEAL_MACROPHAGE_DN
Systematic name | M8781
Organism | Mus musculus
PMID | 22573805
Authors | Freitas de A,Banerjee S,Xie N,Cui H,Davis KI,Friggeri A,Fu M,Abraham E,Liu G
Category | C7
Sub-category |
Brief description | Genes down-regulated in peritoneal macrophages: untreated versus poly(IC).
Full description | We have identified more than 50 genes that have upregulated expression in TLR3 activated (PMI-1,2), but have downregulated expression in TLR2 activated (PMP-1,2) macrophages, as compared to control cells (PMC-1,2)

Standard name | GSE36891_UNSTIM_VS_PAM_TLR2_STIM_PERITONEAL_MACROPHAGE_UP
Systematic name | M8782
Organism | Mus musculus
PMID | 22573805
Authors | Freitas de A,Banerjee S,Xie N,Cui H,Davis KI,Friggeri A,Fu M,Abraham E,Liu G
Category | C7
Sub-category |
Brief description | Genes up-regulated in peritoneal macrophages: control versus Pam3Cys-Ser-(Lys)4 [PubChem=130704].
Full description | We have identified more than 50 genes that have upregulated expression in TLR3 activated (PMI-1,2), but have downregulated expression in TLR2 activated (PMP-1,2) macrophages, as compared to control cells (PMC-1,2)

Standard name | GSE36891_POLYIC_TLR3_VS_PAM_TLR2_STIM_PERITONEAL_MACROPHAGE_DN
Systematic name | M8784
Organism | Mus musculus
PMID | 22573805
Authors | Freitas de A,Banerjee S,Xie N,Cui H,Davis KI,Friggeri A,Fu M,Abraham E,Liu G
Category | C7
Sub-category |
Brief description | Genes down-regulated in peritoneal macrophages: poly(IC) versus Pam3Cys-Ser-(Lys)4 [PubChem=130704].
Full description | We have identified more than 50 genes that have upregulated expression in TLR3 activated (PMI-1,2), but have downregulated expression in TLR2 activated (PMP-1,2) macrophages, as compared to control cells (PMC-1,2)

Standard name | GSE36891_UNSTIM_VS_POLYIC_TLR3_STIM_PERITONEAL_MACROPHAGE_UP
Systematic name | M8786
Organism | Mus musculus
PMID | 22573805
Authors | Freitas de A,Banerjee S,Xie N,Cui H,Davis KI,Friggeri A,Fu M,Abraham E,Liu G
Category | C7
Sub-category |
Brief description | Genes up-regulated in peritoneal macrophages: untreated versus poly(IC).
Full description | We have identified more than 50 genes that have upregulated expression in TLR3 activated (PMI-1,2), but have downregulated expression in TLR2 activated (PMP-1,2) macrophages, as compared to control cells (PMC-1,2)

Standard name | GSE36891_UNSTIM_VS_PAM_TLR2_STIM_PERITONEAL_MACROPHAGE_DN
Systematic name | M8788
Organism | Mus musculus
PMID | 22573805
Authors | Freitas de A,Banerjee S,Xie N,Cui H,Davis KI,Friggeri A,Fu M,Abraham E,Liu G
Category | C7
Sub-category |
Brief description | Genes down-regulated in peritoneal macrophages: control versus Pam3Cys-Ser-(Lys)4 [PubChem=130704].
Full description | We have identified more than 50 genes that have upregulated expression in TLR3 activated (PMI-1,2), but have downregulated expression in TLR2 activated (PMP-1,2) macrophages, as compared to control cells (PMC-1,2)

Standard name | GSE36891_POLYIC_TLR3_VS_PAM_TLR2_STIM_PERITONEAL_MACROPHAGE_UP
Systematic name | M8789
Organism | Mus musculus
PMID | 22573805
Authors | Freitas de A,Banerjee S,Xie N,Cui H,Davis KI,Friggeri A,Fu M,Abraham E,Liu G
Category | C7
Sub-category |
Brief description | Genes up-regulated in peritoneal macrophages: poly(IC) versus Pam3Cys-Ser-(Lys)4 [PubChem=130704].
Full description | We have identified more than 50 genes that have upregulated expression in TLR3 activated (PMI-1,2), but have downregulated expression in TLR2 activated (PMP-1,2) macrophages, as compared to control cells (PMC-1,2)

Standard name | GSE37605_FOXP3_FUSION_GFP_VS_IRES_GFP_TREG_C57BL6_DN
Systematic name | M8790
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg (FOXP3+ [GeneID=50943]) cells from B6 mice: Foxp3-Fusion-GFP versus Foxp3-ires-GFP.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_TREG_VS_TCONV_C57BL6_FOXP3_IRES_GFP_UP
Systematic name | M8791
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenocytes from Foxp3-ires-GFP B6 mice: T reg (FOXP3+ [GeneID=50943]) versus T conv (FOXP3- [GeneID=50943]).
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_FOXP3_FUSION_GFP_VS_IRES_GFP_TREG_C57BL6_UP
Systematic name | M8792
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg (FOXP3+ [GeneID=50943]) cells from B6 mice: Foxp3-Fusion-GFP versus Foxp3-ires-GFP.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_TREG_VS_TCONV_C57BL6_FOXP3_FUSION_GFP_UP
Systematic name | M8793
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenocytes from Foxp3-Fusion-GFP B6 mice: T reg (FOXP3+ [GeneID=50943]) versus T conv (FOXP3- [GeneID=50943]) cells.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_TREG_VS_TCONV_C57BL6_FOXP3_FUSION_GFP_DN
Systematic name | M8794
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenocytes from Foxp3-Fusion-GFP B6 mice: T reg (FOXP3+ [GeneID=50943]) versus T conv (FOXP3- [GeneID=50943]) cells.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_TREG_VS_TCONV_NOD_FOXP3_FUSION_GFP_UP
Systematic name | M8796
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenocytes from Foxp3-Fusion-GFP NOD mice: T reg (FOXP3+ [GeneID=50943]) versus T conv (FOXP3- [GeneID=50943]) cells.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_TREG_VS_TCONV_NOD_FOXP3_FUSION_GFP_DN
Systematic name | M8799
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenocytes from Foxp3-Fusion-GFP NOD mice: T reg (FOXP3+ [GeneID=50943]) versus T conv (FOXP3- [GeneID=50943]) cells.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_C57BL6_VS_NOD_FOXP3_FUSION_GFP_TREG_UP
Systematic name | M8800
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in Foxp3-Fusion-GFP T reg (FOXP3+ [GeneID=50943]): B6 versus NOD background.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_C57BL6_VS_NOD_FOXP3_FUSION_GFP_TREG_DN
Systematic name | M8802
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in Foxp3-Fusion-GFP T reg (FOXP3+ [GeneID=50943]): B6 versus NOD background.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_C57BL6_VS_NOD_FOXP3_IRES_GFP_TREG_UP
Systematic name | M8803
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in Foxp3-ires-GFP T reg (FOXP3+ [GeneID=50943]): B6 versus NOD background.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_C57BL6_VS_NOD_FOXP3_IRES_GFP_TREG_DN
Systematic name | M8805
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in Foxp3-ires-GFP T reg (FOXP3+ [GeneID=50943]): B6 versus NOD background.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_FOXP3_FUSION_GFP_VS_IRES_GFP_TREG_NOD_UP
Systematic name | M8810
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg (FOXP3+ [GeneID=50943]) cells from NOD mice: Foxp3-Fusion-GFP versus Foxp3-ires-GFP.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_TREG_VS_TCONV_C57BL6_FOXP3_IRES_GFP_DN
Systematic name | M8811
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenocytes from Foxp3-ires-GFP B6 mice: T reg (FOXP3+ [GeneID=50943]) versus T conv (FOXP3- [GeneID=50943]).
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_NOD_VS_C57BL6_IRES_GFP_TREG_UP
Systematic name | M8814
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in FoxP3-IRES-GFP: NOD T reg (FOXP3+ [GeneID=50943]) versus B6 splenocytes.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_NOD_VS_C57BL6_IRES_GFP_TREG_DN
Systematic name | M8815
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in FoxP3-IRES-GFP: NOD T reg (FOXP3+ [GeneID=50943]) versus B6 splenocytes.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_C57BL6_VS_NOD_FOXP3_IRES_GFP_TCONV_UP
Systematic name | M8819
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in Foxp3-ires-GFP T conv (FOXP3- [GeneID=50943]): B6 versus NOD background.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_FOXP3_FUSION_GFP_VS_IRES_GFP_TREG_NOD_DN
Systematic name | M8820
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg (FOXP3+ [GeneID=50943]) cells from NOD mice: Foxp3-Fusion-GFP versus Foxp3-ires-GFP.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_C57BL6_VS_NOD_FOXP3_FUSION_GFP_TCONV_UP
Systematic name | M8823
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in Foxp3-Fusion-GFP T conv (FOXP3- [GeneID=50943]): B6 versus NOD background.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_C57BL6_VS_NOD_FOXP3_FUSION_GFP_TCONV_DN
Systematic name | M8824
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in Foxp3-Fusion-GFP T conv (FOXP3- [GeneID=50943]): B6 versus NOD background.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37605_C57BL6_VS_NOD_FOXP3_IRES_GFP_TCONV_DN
Systematic name | M8827
Organism | Mus musculus
PMID | 22579475
Authors | Darce J,Rudra D,Li L,Nishio J,Cipolletta D,Rudensky AY,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in Foxp3-ires-GFP T conv (FOXP3- [GeneID=50943]): B6 versus NOD background.
Full description | The aim of this study was to quantify the impact of chimeric Foxp3-GFP protein on the Treg cell transcriptional program.

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_LYMPHOID_PRIMED_MPP_UP
Systematic name | M8828
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus lymphoid primed multipotent progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_LYMPHOID_PRIMED_MPP_DN
Systematic name | M8829
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus lymphoid primed multipotent progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_MULTIPOTENT_PROGENITOR_DN
Systematic name | M8830
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus multipotent progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_GRANULOCYTE_MONOCYTE_PROGENITOR_VS_RAG2_KO_NK_CELL_UP
Systematic name | M8832
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in granulocyte-monocyte progenitor versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_GRANULOCYTE_MONOCYTE_PROGENITOR_VS_RAG2_KO_NK_CELL_DN
Systematic name | M8833
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in granulocyte-monocyte progenitor versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_MULTIPOTENT_PROGENITOR_UP
Systematic name | M8836
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus multipotent progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_COMMON_LYMPHOID_PROGENITOR_DN
Systematic name | M8842
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in multipotent progenitors versus common lymphoid progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_PRO_BCELL_UP
Systematic name | M8843
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in multipotent progenitors versus pro-B cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_RAG2_KO_VS_RAG2_AND_ETS1_KO_NK_CELL_UP
Systematic name | M8844
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells: RAG2 [GeneID=5897] knockout versus RAG2 and ETS1 [GeneID=5897;2113] knockout.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_RAG2_KO_VS_RAG2_AND_ETS1_KO_NK_CELL_DN
Systematic name | M8846
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells: RAG2 [GeneID=5897] knockout versus RAG2 and ETS1 [GeneID=5897;2113] knockout.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_CD4_TCELL_DN
Systematic name | M8847
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in multipotent progenitors versus CD4 [GeneID=920] T cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_GRAN_MONO_PROGENITOR_UP
Systematic name | M8848
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in multipotent progenitors versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_GRAN_MONO_PROGENITOR_DN
Systematic name | M8849
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in multipotent progenitors versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_RAG2_KO_NK_CELL_UP
Systematic name | M8850
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in multipotent progenitors versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_RAG2_KO_NK_CELL_DN
Systematic name | M8851
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in multipotent progenitors versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_LYMPHOID_PRIMED_MPP_VS_COMMON_LYMPHOID_PROGENITOR_UP
Systematic name | M8853
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphoid primed multipotent progenitors versus common lymphoid progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_LYMPHOID_PRIMED_MPP_VS_COMMON_LYMPHOID_PROGENITOR_DN
Systematic name | M8854
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphoid primed multipotent progenitors versus common lymphoid progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_LYMPHOID_PRIMED_MPP_VS_PRO_BCELL_UP
Systematic name | M8855
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphoid primed multipotent progenitors versus pro-B cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_LYMPHOID_PRIMED_MPP_VS_PRO_BCELL_DN
Systematic name | M8856
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphoid primed multipotent progenitors versus pro-B cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_LYMPHOID_PRIMED_MPP_VS_CD4_TCELL_UP
Systematic name | M8858
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphoid primed multipotent progenitors versus CD4 [GeneID=920] T cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_LYMPHOID_PRIMED_MPP_VS_CD4_TCELL_DN
Systematic name | M8859
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphoid primed multipotent progenitors versus CD4 [GeneID=920] T cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_LYMPHOID_PRIMED_MPP_VS_GRAN_MONO_PROGENITOR_UP
Systematic name | M8860
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphoid primed multipotent progenitors versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_LYMPHOID_PRIMED_MPP_VS_GRAN_MONO_PROGENITOR_DN
Systematic name | M8861
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphoid primed multipotent progenitors versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_LYMPHOID_PRIMED_MPP_VS_RAG2_KO_NK_CELL_UP
Systematic name | M8863
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphoid primed multipotent progenitors versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_LYMPHOID_PRIMED_MPP_VS_RAG2_KO_NK_CELL_DN
Systematic name | M8864
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphoid primed multipotent progenitors versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_COMMON_LYMPHOID_PROGENITOR_VS_PRO_BCELL_UP
Systematic name | M8866
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in common lymphoid progenitor versus pro-B cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_COMMON_LYMPHOID_PROGENITOR_VS_PRO_BCELL_DN
Systematic name | M8867
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in common lymphoid progenitor versus pro-B cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_COMMON_LYMPHOID_PROGENITOR_VS_CD4_TCELL_UP
Systematic name | M8868
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in common lymphoid progenitors versus CD4 [GeneID=920] T cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_COMMON_LYMPHOID_PROGENITOR_VS_CD4_TCELL_DN
Systematic name | M8869
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in common lymphoid progenitors versus CD4 [GeneID=920] T cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_COMMON_LYMPHOID_PROGENITOR_VS_GRAN_MONO_PROGENITOR_UP
Systematic name | M8870
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in common lymphoid progenitors versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_COMMON_LYMPHOID_PROGENITOR_VS_GRAN_MONO_PROGENITOR_DN
Systematic name | M8871
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in common lymphoid progenitors versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_COMMON_LYMPHOID_PROGENITOR_VS_RAG2_KO_NK_CELL_UP
Systematic name | M8872
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in common lymphoid progenitors versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_COMMON_LYMPHOID_PROGENITOR_VS_RAG2_KO_NK_CELL_DN
Systematic name | M8874
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in common lymphoid progenitors versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_COMMON_LYMPHOID_PROGENITOR_UP
Systematic name | M8875
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus common lymphoid progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_COMMON_LYMPHOID_PROGENITOR_DN
Systematic name | M8877
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus common lymphoid progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_PRO_BCELL_UP
Systematic name | M8878
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus pro-B cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_PRO_BCELL_DN
Systematic name | M8879
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus pro-B cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_CD4_TCELL_UP
Systematic name | M8881
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus CD4 [GeneID=920] T cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_CD4_TCELL_DN
Systematic name | M8882
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus CD4 [GeneID=920] T cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_GRAN_MONO_PROGENITOR_UP
Systematic name | M8883
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_GRAN_MONO_PROGENITOR_DN
Systematic name | M8884
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_RAG2_KO_NK_CELL_UP
Systematic name | M8885
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in hematopoietic stem cells versus NK cells with RAG2 [GeneID=5897] knockout.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_HEMATOPOIETIC_STEM_CELL_VS_RAG2_KO_NK_CELL_DN
Systematic name | M8886
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in hematopoietic stem cells versus NK cells with RAG2 [GeneID=5897] knockout.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_LYMPHOID_PRIMED_MPP_UP
Systematic name | M8888
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in multipotent progenitors (MPP) versus lymphoid primed MPP cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_LYMPHOID_PRIMED_MPP_DN
Systematic name | M8889
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in multipotent progenitors (MPP) versus lymphoid primed MPP cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_COMMON_LYMPHOID_PROGENITOR_UP
Systematic name | M8890
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in multipotent progenitors versus common lymphoid progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_PRO_BCELL_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_DN
Systematic name | M8892
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in pro-B cells versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_PRO_BCELL_VS_CD4_TCELL_UP
Systematic name | M8893
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in pro-B cells versus CD4 [GeneID=920] T cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_PRO_BCELL_DN
Systematic name | M8894
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in multipotent progenitors versus pro-B cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_MULTIPOTENT_PROGENITOR_VS_CD4_TCELL_UP
Systematic name | M8896
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in multipotent progenitors versus CD4 [GeneID=920] T cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_CD4_TCELL_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_DN
Systematic name | M8898
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_PRO_BCELL_VS_RAG2_KO_NK_CELL_UP
Systematic name | M8899
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in pro-B cells versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_PRO_BCELL_VS_RAG2_KO_NK_CELL_DN
Systematic name | M8900
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in pro-B cells versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_CD4_TCELL_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_UP
Systematic name | M8903
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_PRO_BCELL_VS_GRANULOCYTE_MONOCYTE_PROGENITOR_UP
Systematic name | M8904
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in pro-B cells versus granulocyte-monocyte progenitors.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_CD4_TCELL_VS_RAG2_KO_NK_CELL_UP
Systematic name | M8905
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_CD4_TCELL_VS_RAG2_KO_NK_CELL_DN
Systematic name | M8906
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells versus RAG2 [GeneID=5897] knockout NK cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE37301_PRO_BCELL_VS_CD4_TCELL_DN
Systematic name | M8907
Organism | Mus musculus
PMID | 22608498
Authors | Ramirez K,Chandler KJ,Spaulding C,Zandi S,Sigvardsson M,Graves BJ,Kee BL
Category | C7
Sub-category |
Brief description | Genes down-regulated in pro-B cells versus CD4 [GeneID=920] T cells.
Full description | Expression profiling of Rag2-deficient Ets1++ and Rag2-deficient Ets1-- mature NK cells and WT bone marrow progenitors, WT T cells, and WT Pro B cells

Standard name | GSE32255_WT_UNSTIM_VS_JMJD2D_KNOCKDOWN_4H_LPS_STIM_DC_UP
Systematic name | M8908
Organism | Mus musculus
PMID | 22633489
Authors | Zhu Y,Essen van D,Saccani S
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: unstimulated wildtype versus KDM4D [GeneID=55693] knockdown (shRNA) stimulated by LPS.
Full description | In dendritic cells, expression of the H3K9me3 demethylase JmjD2d is upregulated by LPS stimulation. To identify genes whose induction by LPS depends on JmjD2d activity, we performed a microarray analysis of wild-type and JmjD2d-knockdown dendritic cells, before and after stimulation with LPS.

Standard name | GSE32255_WT_UNSTIM_VS_JMJD2D_KNOCKDOWN_4H_LPS_STIM_DC_DN
Systematic name | M8909
Organism | Mus musculus
PMID | 22633489
Authors | Zhu Y,Essen van D,Saccani S
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: unstimulated wildtype versus KDM4D [GeneID=55693] knockdown (shRNA) stimulated by LPS.
Full description | In dendritic cells, expression of the H3K9me3 demethylase JmjD2d is upregulated by LPS stimulation. To identify genes whose induction by LPS depends on JmjD2d activity, we performed a microarray analysis of wild-type and JmjD2d-knockdown dendritic cells, before and after stimulation with LPS.

Standard name | GSE32255_WT_VS_JMJD2D_KNOCKDOWN_4H_LPS_STIM_DC_DN
Systematic name | M8911
Organism | Mus musculus
PMID | 22633489
Authors | Zhu Y,Essen van D,Saccani S
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells stimulated by LPS: wildtype versus KDM4D [GeneID=55693].
Full description | In dendritic cells, expression of the H3K9me3 demethylase JmjD2d is upregulated by LPS stimulation. To identify genes whose induction by LPS depends on JmjD2d activity, we performed a microarray analysis of wild-type and JmjD2d-knockdown dendritic cells, before and after stimulation with LPS.

Standard name | GSE32255_UNSTIM_VS_4H_LPS_STIM_DC_DN
Systematic name | M8912
Organism | Mus musculus
PMID | 22633489
Authors | Zhu Y,Essen van D,Saccani S
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: unstimulated versus LPS.
Full description | In dendritic cells, expression of the H3K9me3 demethylase JmjD2d is upregulated by LPS stimulation. To identify genes whose induction by LPS depends on JmjD2d activity, we performed a microarray analysis of wild-type and JmjD2d-knockdown dendritic cells, before and after stimulation with LPS.

Standard name | GSE32255_WT_VS_JMJD2D_KNOCKDOWN_4H_LPS_STIM_DC_UP
Systematic name | M8913
Organism | Mus musculus
PMID | 22633489
Authors | Zhu Y,Essen van D,Saccani S
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells stimulated by LPS: wildtype versus KDM4D [GeneID=55693].
Full description | In dendritic cells, expression of the H3K9me3 demethylase JmjD2d is upregulated by LPS stimulation. To identify genes whose induction by LPS depends on JmjD2d activity, we performed a microarray analysis of wild-type and JmjD2d-knockdown dendritic cells, before and after stimulation with LPS.

Standard name | GSE32255_UNSTIM_VS_4H_LPS_STIM_DC_UP
Systematic name | M8914
Organism | Mus musculus
PMID | 22633489
Authors | Zhu Y,Essen van D,Saccani S
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: unstimulated versus LPS.
Full description | In dendritic cells, expression of the H3K9me3 demethylase JmjD2d is upregulated by LPS stimulation. To identify genes whose induction by LPS depends on JmjD2d activity, we performed a microarray analysis of wild-type and JmjD2d-knockdown dendritic cells, before and after stimulation with LPS.

Standard name | GSE34217_MIR17_92_OVEREXPRESS_VS_WT_ACT_CD8_TCELL_DN
Systematic name | M8915
Organism | Mus musculus
PMID | 22665768
Authors | Wu T,Wieland A,Araki K,Davis CW,Ye L,Hale JS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in act CD8 T cells: over-expressing MIR17HG [GeneID=407975] versus activated control.
Full description | During acute viral infections, effector CD8+ T cells differentiate into memory precursors or short-lived terminal effectors. miR-17-92a over-expression skews CD8+ effector cells to the terminal differentiation. We used microarray to identify the genes that are differentially expressed caused by miR-17-92a over-expression.

Standard name | GSE34217_MIR17_92_OVEREXPRESS_VS_WT_ACT_CD8_TCELL_UP
Systematic name | M8917
Organism | Mus musculus
PMID | 22665768
Authors | Wu T,Wieland A,Araki K,Davis CW,Ye L,Hale JS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in act CD8 T cells: over-expressing MIR17HG [GeneID=407975] versus activated control.
Full description | During acute viral infections, effector CD8+ T cells differentiate into memory precursors or short-lived terminal effectors. miR-17-92a over-expression skews CD8+ effector cells to the terminal differentiation. We used microarray to identify the genes that are differentially expressed caused by miR-17-92a over-expression.

Standard name | GSE37319_WT_VS_RC3H1_KO_CD44LOW_CD8_TCELL_UP
Systematic name | M8918
Organism | Mus musculus
PMID | 22685317
Authors | Chang PP,Lee SK,Hu X,Davey G,Duan G,Cho JH,Karupiah G,Sprent J,Heath WR,Bertram EM,Vinuesa CG
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD44 low [GeneID=960] CD8 T cells: wildtype versus RC3H1 [GeneID=149041] knockout.
Full description | We used microarrays to detect the primary changes caused by the 'san' mutation in Roquin gene by comparing the gene expression profiles of naive (CD44lo) CD8+ T cell population.

Standard name | GSE37319_WT_VS_RC3H1_KO_CD44LOW_CD8_TCELL_DN
Systematic name | M8919
Organism | Mus musculus
PMID | 22685317
Authors | Chang PP,Lee SK,Hu X,Davey G,Duan G,Cho JH,Karupiah G,Sprent J,Heath WR,Bertram EM,Vinuesa CG
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD44 low [GeneID=960] CD8 T cells: wildtype versus RC3H1 [GeneID=149041] knockout.
Full description | We used microarrays to detect the primary changes caused by the 'san' mutation in Roquin gene by comparing the gene expression profiles of naive (CD44lo) CD8+ T cell population.

Standard name | GSE32901_TH1_VS_TH17_ENRICHED_CD4_TCELL_DN
Systematic name | M8920
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: Th1 versus Th17 enriched.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_TH1_VS_TH17_NEG_CD4_TCELL_UP
Systematic name | M8922
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: Th1 versus Th17 negative.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_TH1_VS_TH17_NEG_CD4_TCELL_DN
Systematic name | M8923
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: Th1 versus Th17 negative.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_TH1_VS_TH17_ENRICHED_CD4_TCELL_UP
Systematic name | M8925
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: Th1 versus Th17 enriched.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_NAIVE_VS_TH1_CD4_TCELL_DN
Systematic name | M8926
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: naïve versus Th1.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_NAIVE_VS_TH17_ENRICHED_CD4_TCELL_UP
Systematic name | M8927
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] naïve versus Th17 enriched.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_NAIVE_VS_TH17_ENRICHED_CD4_TCELL_DN
Systematic name | M8928
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] naïve versus Th17 enriched.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_TH17_EMRICHED_VS_TH17_NEG_CD4_TCELL_UP
Systematic name | M8929
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] Th17 T cells: enriched versus negative.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_NAIVE_VS_TH17_NEG_CD4_TCELL_DN
Systematic name | M8930
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: naïve versus Th17 negative.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_TH17_EMRICHED_VS_TH17_NEG_CD4_TCELL_DN
Systematic name | M8931
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] Th17 T cells: enriched versus negative.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_NAIVE_VS_TH17_NEG_CD4_TCELL_UP
Systematic name | M8932
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: naïve versus Th17 negative.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE32901_NAIVE_VS_TH1_CD4_TCELL_UP
Systematic name | M8933
Organism | Homo sapiens
PMID | 22715389
Authors | Zhang W,Ferguson J,Ng SM,Hui K,Goh G,Lin A,Esplugues E,Flavell RA,Abraham C,Zhao H,Cho JH
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: naïve versus Th1.
Full description | In this study, we examined differential gene expression in naïve human CD4+ T cells, as well as in effector Th1, Th17-negative and Th17-enriched CD4- T cell subsets. We observed a marked enrichment for increased gene expression in effector CD4+ T cells compared to naive CD4+ among immune-mediated disease oci genes. Within effector T cells, expression of disease-associated genes was increased in Th17-enriched compared to Th17-negative cells. We used microarray to examine the gene expresssion profile and level of human naïve, Th1 and effector T cell subsets.

Standard name | GSE36095_WT_VS_HDAC9_KO_TREG_UP
Systematic name | M8934
Organism | Mus musculus
PMID | 22715468
Authors | Beier UH,Wang L,Han R,Akimova T,Liu Y,Hancock WW
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: wildtype versus HDAC9 [GeneID=9734] knockout.
Full description | Targeting histone/protein deacetylase (HDAC)-6, -9, or Sirtuin-1 (Sirt1) augments the suppressive functions of Foxp3+ T regulatory (Treg) cells, but it is unclear if this involves different mechanisms, such that combined inhibition would be beneficial. We compared the suppressive functions of Tregs from wild-type C57BL/6 mice or mice with global (HDAC6-/-, HDAC9-/-, dual HDAC6/9-/-) or conditional deletion (CD4-Cre or Foxp3-Cre and floxed Sirt1; GSE26425) alone, or after treatment with isoform-selective HDAC inhibitors (HDACi). We found the heat shock response was crucial in mediating the effects of HDAC6, but not Sirt1 inhibition. Furthermore, while HDAC6, HDAC9 and Sirt1 all deacetylate Foxp3, each has diverse effects on Foxp3 transcription, and loss of HDAC9 is associated with stabilization of Stat5 acetylation and its transcriptional activity. Targeting different HDAC can increase Treg function by multiple and additive mechanisms, indicating the therapeutic potential for combinations of HDACi in the management of autoimmunity and alloresponses post-transplant.

Standard name | GSE36095_WT_VS_HDAC9_KO_TREG_DN
Systematic name | M8936
Organism | Mus musculus
PMID | 22715468
Authors | Beier UH,Wang L,Han R,Akimova T,Liu Y,Hancock WW
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: wildtype versus HDAC9 [GeneID=9734] knockout.
Full description | Targeting histone/protein deacetylase (HDAC)-6, -9, or Sirtuin-1 (Sirt1) augments the suppressive functions of Foxp3+ T regulatory (Treg) cells, but it is unclear if this involves different mechanisms, such that combined inhibition would be beneficial. We compared the suppressive functions of Tregs from wild-type C57BL/6 mice or mice with global (HDAC6-/-, HDAC9-/-, dual HDAC6/9-/-) or conditional deletion (CD4-Cre or Foxp3-Cre and floxed Sirt1; GSE26425) alone, or after treatment with isoform-selective HDAC inhibitors (HDACi). We found the heat shock response was crucial in mediating the effects of HDAC6, but not Sirt1 inhibition. Furthermore, while HDAC6, HDAC9 and Sirt1 all deacetylate Foxp3, each has diverse effects on Foxp3 transcription, and loss of HDAC9 is associated with stabilization of Stat5 acetylation and its transcriptional activity. Targeting different HDAC can increase Treg function by multiple and additive mechanisms, indicating the therapeutic potential for combinations of HDACi in the management of autoimmunity and alloresponses post-transplant.

Standard name | GSE37532_TREG_VS_TCONV_CD4_TCELL_FROM_VISCERAL_ADIPOSE_TISSUE_DN
Systematic name | M8937
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in visceral adipose tissue of aged mice: T reg versus T conv.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_VISCERAL_ADIPOSE_TISSUE_VS_LN_DERIVED_PPARG_KO_TCONV_CD4_TCELL_DN
Systematic name | M8938
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv cells from aged PPARG [GeneID=5468] knockout mice: visceral adipose tissue versus lymph node.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_TREG_VS_TCONV_CD4_TCELL_FROM_VISCERAL_ADIPOSE_TISSUE_UP
Systematic name | M8939
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in visceral adipose tissue of aged mice: T reg versus T conv.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_VISCERAL_ADIPOSE_TISSUE_VS_LN_DERIVED_TREG_CD4_TCELL_UP
Systematic name | M8940
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg of aged mice: visceral adipose tissue versus lymph node.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_VISCERAL_ADIPOSE_TISSUE_VS_LN_DERIVED_TREG_CD4_TCELL_DN
Systematic name | M8944
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg of aged mice: visceral adipose tissue versus lymph node.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_VISCERAL_ADIPOSE_TISSUE_VS_LN_DERIVED_TCONV_CD4_TCELL_UP
Systematic name | M8945
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv from aged mice: visceral adipose tissue versus lymph node.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_VISCERAL_ADIPOSE_TISSUE_VS_LN_DERIVED_TCONV_CD4_TCELL_DN
Systematic name | M8946
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv from aged mice: visceral adipose tissue versus lymph node.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_VISCERAL_ADIPOSE_TISSUE_VS_LN_DERIVED_PPARG_KO_TREG_CD4_TCELL_UP
Systematic name | M8947
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg cells from aged PPARG [GeneID=5468] knockout mice: visceral adipose tissue versus lymph node.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_VISCERAL_ADIPOSE_TISSUE_VS_LN_DERIVED_PPARG_KO_TREG_CD4_TCELL_DN
Systematic name | M8948
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg cells from aged PPARG [GeneID=5468] knockout mice: visceral adipose tissue versus lymph node.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_VISCERAL_ADIPOSE_TISSUE_VS_LN_DERIVED_PPARG_KO_TCONV_CD4_TCELL_UP
Systematic name | M8949
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv cells from aged PPARG [GeneID=5468] knockout: visceral adipose tissue versus lymph node.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_WT_VS_PPARG_KO_LN_TREG_UP
Systematic name | M8952
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg from lypmh nodes of elderly (retired breeder) mice: wildtype versus PPARG [GeneID=5468] knockout.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_WT_VS_PPARG_KO_LN_TREG_DN
Systematic name | M8953
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg from lypmh nodes of elderly (retired breeder) mice: wildtype versus PPARG [GeneID=5468] knockout.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_WT_VS_PPARG_KO_LN_TCONV_UP
Systematic name | M8954
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv from lymph node of elderly (retired breeder) mice: wildtype versus PPARG [GeneID=5468] knockout.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_TREG_VS_TCONV_PPARG_KO_CD4_TCELL_FROM_VISCERAL_ADIPOSE_TISSUE_UP
Systematic name | M8955
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in visceral adipose tissue from aged PPARG [GeneID=5468] knockout mice: T reg versus T conv.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_TREG_VS_TCONV_PPARG_KO_CD4_TCELL_FROM_VISCERAL_ADIPOSE_TISSUE_DN
Systematic name | M8956
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in visceral adipose tissue from aged PPARG [GeneID=5468] knockout mice: T reg versus T conv.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_TREG_VS_TCONV_CD4_TCELL_FROM_LN_UP
Systematic name | M8957
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymph node from aged mice: T reg versus T conv.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_TREG_VS_TCONV_CD4_TCELL_FROM_LN_DN
Systematic name | M8958
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymph node from aged mice: T reg versus T conv.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_TREG_VS_TCONV_PPARG_KO_CD4_TCELL_FROM_LN_UP
Systematic name | M8959
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymph node from aged PPARG [GeneID=5468] knockout mice: T reg versus T conv.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_TREG_VS_TCONV_PPARG_KO_CD4_TCELL_FROM_LN_DN
Systematic name | M8960
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymph node from aged PPARG [GeneID=5468] knockout mice: T reg versus T conv.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_WT_VS_PPARG_KO_VISCERAL_ADIPOSE_TISSUE_TREG_UP
Systematic name | M8961
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg from visceral adipose tissue of aged mice: wildtype versus PPARG [GeneID=5468] knockout.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_WT_VS_PPARG_KO_VISCERAL_ADIPOSE_TISSUE_TREG_DN
Systematic name | M8962
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg from visceral adipose tissue of aged mice: wildtype versus PPARG [GeneID=5468] knockout.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_WT_VS_PPARG_KO_VISCERAL_ADIPOSE_TISSUE_TCONV_UP
Systematic name | M8964
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv from visceral adipose tissue in aged mice: wildtype versus PPARG [GeneID=5468] knockout.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37532_WT_VS_PPARG_KO_VISCERAL_ADIPOSE_TISSUE_TCONV_DN
Systematic name | M8966
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv from visceral adipose tissue in aged mice: wildtype versus PPARG [GeneID=5468] knockout.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE37533_PPARG1_FOXP3_VS_FOXP3_TRANSDUCED_CD4_TCELL_DN
Systematic name | M8967
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] over-expressing: FOXP3 [GeneID=50943] and PPARg1 form of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG2_FOXP3_VS_FOXP3_TRANSDUCED_CD4_TCELL_UP
Systematic name | M8968
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] over-expressing: FOXP3 [GeneID=50943] and PPARg2 form of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG2_FOXP3_VS_FOXP3_TRANSDUCED_CD4_TCELL_DN
Systematic name | M8969
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] over-expressing: FOXP3 [GeneID=50943] and PPARg2 form of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG1_FOXP3_VS_PPARG2_FOXP3_TRANSDUCED_CD4_TCELL_PIOGLITAZONE_TREATED_UP
Systematic name | M8970
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with pioglitazone [PubChem=4829] and over-expressing: FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943] and PPARg2 form of PPARG [GeneID=5468].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG1_FOXP3_VS_PPARG2_FOXP3_TRANSDUCED_CD4_TCELL_PIOGLITAZONE_TREATED_DN
Systematic name | M8971
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with pioglitazone [PubChem=4829] and over-expressing: FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943] and PPARg2 form of PPARG [GeneID=5468].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG1_FOXP3_VS_FOXP3_TRANSDUCED_CD4_TCELL_PIOGLITAZONE_TREATED_UP
Systematic name | M8972
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with pioglitazone [PubChem=4829] and over-expressing: FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG1_FOXP3_VS_FOXP3_TRANSDUCED_CD4_TCELL_PIOGLITAZONE_TREATED_DN
Systematic name | M8974
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with pioglitazone [PubChem=4829] and over-expressing: FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG2_FOXP3_VS_FOXP3_TRANSDUCED_CD4_TCELL_PIOGLITAZONE_TREATED_UP
Systematic name | M8975
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with pioglitazone [PubChem=4829] and over-expressing: FOXP3 [GeneID=50943] and PPARg2 isoform of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG2_FOXP3_VS_FOXP3_TRANSDUCED_CD4_TCELL_PIOGLITAZONE_TREATED_DN
Systematic name | M8977
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with pioglitazone [PubChem=4829] and over-expressing: FOXP3 [GeneID=50943] and PPARg2 isoform of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37534_UNTREATED_VS_GW1929_TREATED_CD4_TCELL_PPARG1_AND_FOXP3_TRASDUCED_UP
Systematic name | M8978
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468]: untreated versus GW1929 [PubChem=6518171].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_UNTREATED_VS_GW1929_TREATED_CD4_TCELL_PPARG1_AND_FOXP3_TRASDUCED_DN
Systematic name | M8979
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468]: untreated versus GW1929 [PubChem=6518171].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_UNTREATED_VS_PIOGLITAZONE_TREATED_CD4_TCELL_PPARG1_AND_FOXP3_TRASDUCED_UP
Systematic name | M8980
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and PPARg1 form of PPARG [GeneID=5468]: untreated versus pioglitazone [PubChem=4829].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_UNTREATED_VS_PIOGLITAZONE_TREATED_CD4_TCELL_PPARG1_AND_FOXP3_TRASDUCED_DN
Systematic name | M8982
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and PPARg1 form of PPARG [GeneID=5468]: untreated versus pioglitazone [PubChem=4829].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_UNTREATED_VS_ROSIGLITAZONE_TREATED_CD4_TCELL_PPARG1_AND_FOXP3_TRASDUCED_UP
Systematic name | M8983
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T ceels over-expressing FOXP3 [GeneID=920] and PPARg1 isoform of PPARG [GeneID=5468]: untreated versus rosiglitazone [PubChem=77999].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_UNTREATED_VS_ROSIGLITAZONE_TREATED_CD4_TCELL_PPARG1_AND_FOXP3_TRASDUCED_DN
Systematic name | M8984
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T ceels over-expressing FOXP3 [GeneID=920] and PPARg1 isoform of PPARG [GeneID=5468]: untreated versus rosiglitazone [PubChem=77999].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_GW1929_VS_PIOGLITAZONE_TREATED_CD4_TCELL_PPARG1_FOXP3_TRANSDUCED_UP
Systematic name | M8985
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468]: GW1929 [PubChem=6518171] versus pioglitazone [PubChem=4829].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_GW1929_VS_PIOGLITAZONE_TREATED_CD4_TCELL_PPARG1_FOXP3_TRANSDUCED_DN
Systematic name | M8986
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468]: GW1929 [PubChem=6518171] versus pioglitazone [PubChem=4829].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_GW1929_VS_ROSIGLITAZONE_TREATED_CD4_TCELL_PPARG1_FOXP3_TRANSDUCED_UP
Systematic name | M8987
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468]: GW1929 [PubChem=6518171] versus rosiglitazone [PubChem=77999].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_GW1929_VS_ROSIGLITAZONE_TREATED_CD4_TCELL_PPARG1_FOXP3_TRANSDUCED_DN
Systematic name | M8989
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468]: GW1929 [PubChem=6518171] versus rosiglitazone [PubChem=77999].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_PIOGLITAZONE_VS_ROSIGLITAZONE_TREATED_CD4_TCELL_PPARG1_FOXP3_TRANSDUCED_UP
Systematic name | M8990
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells treated with rosiglitazone [PubChem=77999] and over-expressing: FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943] and PPARg2 isoform of PPARG [GeneID=5468].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37534_PIOGLITAZONE_VS_ROSIGLITAZONE_TREATED_CD4_TCELL_PPARG1_FOXP3_TRANSDUCED_DN
Systematic name | M8992
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells treated with rosiglitazone [PubChem=77999] and over-expressing: FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943] and PPARg2 isoform of PPARG [GeneID=5468].
Full description | Pioglitazone treatment of CD4+FoxP3- T cells transduced with Pparg and Foxp3 up-regulated a set of genes whose products have been implicated in lipid metabolism pathways. To verify the specificity of this treatment, we performed microarray analysis on Foxp3+Pparg1-transduced CD4+FoxP3- T cells after treatment with other PPARg agonists such as Rosiglitazone (TZD) and GW1929 (non-TZD).

Standard name | GSE37533_UNTREATED_VS_PIOGLIZATONE_TREATED_CD4_TCELL_PPARG2_AND_FOXP3_TRASDUCED_DN
Systematic name | M8993
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and Pparg2 isoform of PPARG [GeneID=5468]: untreated versus pioglitazone [PubChem=4829].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_UNTREATED_VS_PIOGLIZATONE_TREATED_CD4_TCELL_FOXP3_TRASDUCED_CD4_TCELL_UP
Systematic name | M8994
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943]: untreated versus pioglitazone [PubChem=4829].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_UNTREATED_VS_PIOGLIZATONE_TREATED_CD4_TCELL_FOXP3_TRASDUCED_CD4_TCELL_DN
Systematic name | M8995
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943]: untreated versus pioglitazone [PubChem=4829].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG1_FOXP3_VS_PPARG2_FOXP3_TRANSDUCED_CD4_TCELL_UP
Systematic name | M8996
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells over-expressing: FOXP3 [GeneID=50943] and PPARg1 isoform of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943] and PPARg2 isoform of PPARG [GeneID=5468].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG1_FOXP3_VS_PPARG2_FOXP3_TRANSDUCED_CD4_TCELL_DN
Systematic name | M8997
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in PPARg1 Foxp3 transduced CD4 T cell versus PPARg2 Foxp3 transduced CD4 T cell.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_PPARG1_FOXP3_VS_FOXP3_TRANSDUCED_CD4_TCELL_UP
Systematic name | M9000
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] over-expressing: FOXP3 [GeneID=50943] and PPARg1 form of PPARG [GeneID=5468] versus FOXP3 [GeneID=50943].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_UNTREATED_VS_PIOGLIZATONE_TREATED_CD4_TCELL_PPARG1_AND_FOXP3_TRASDUCED_UP
Systematic name | M9001
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and Pparg1 isoform of PPARG [GeneID=5468]: untreated versus pioglitazone [PubChem=4829].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_UNTREATED_VS_PIOGLIZATONE_TREATED_CD4_TCELL_PPARG1_AND_FOXP3_TRASDUCED_DN
Systematic name | M9002
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and Pparg1 isoform of PPARG [GeneID=5468]: untreated versus pioglitazone [PubChem=4829].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37533_UNTREATED_VS_PIOGLIZATONE_TREATED_CD4_TCELL_PPARG2_AND_FOXP3_TRASDUCED_UP
Systematic name | M9003
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells over-expressing FOXP3 [GeneID=50943] and Pparg2 isoform of PPARG [GeneID=5468]: untreated versus pioglitazone [PubChem=4829].
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To explore the contribution of Pparg1 and 2 in the generation of the VAT Tregs-specific gene signatures, CD4+FoxP3- T cells were transduced with Foxp3+/- Pparg1 (or Pparg2), treated with Pioglitazone or vehicle, and double sorted for microarray analysis.

Standard name | GSE37532_WT_VS_PPARG_KO_LN_TCONV_DN
Systematic name | M9004
Organism | Mus musculus
PMID | 22722857
Authors | Cipolletta D,Feuerer M,Li A,Kamei N,Lee J,Shoelson SE,Benoist C,Mathis D
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv from lymph node of elderly (retired breeder) mice: wildtype versus PPARG [GeneID=5468] knockout.
Full description | We identified Pparg as a major orchestrator of the phenotype of adipose-tissue resident regulatory T cells (VAT Tregs). To establish the role of Pparg in shaping the VAT Tregs gene profile and cell dynamics, Tregs from lymph nodes and visceral adipose tissue of mice sufficient and deficient of Pparg expression in Tregs were double sorted for microarray analysis.

Standard name | GSE38696_LIGHT_ZONE_VS_DARK_ZONE_BCELL_UP
Systematic name | M9005
Organism | Mus musculus
PMID | 22740445
Authors | Victora GD,Dominguez-Sola D,Holmes AB,Deroubaix S,Dalla-Favera R,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: light zone versus dark zone.
Full description | Microarrays of gene expression in mouse germinal center light zone and dark zone B cells sorted according to the expression of cell surface molecules CD83 and CXCR4 We used microarray data to identify genes differentially expressed by B cells in the light and dark zones of germinal centers from mouse skin-draining lymph nodes 12 days after subcutaneous immunization with NP-OVA in alum.

Standard name | GSE38696_LIGHT_ZONE_VS_DARK_ZONE_BCELL_DN
Systematic name | M9006
Organism | Mus musculus
PMID | 22740445
Authors | Victora GD,Dominguez-Sola D,Holmes AB,Deroubaix S,Dalla-Favera R,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: light zone versus dark zone.
Full description | Microarrays of gene expression in mouse germinal center light zone and dark zone B cells sorted according to the expression of cell surface molecules CD83 and CXCR4 We used microarray data to identify genes differentially expressed by B cells in the light and dark zones of germinal centers from mouse skin-draining lymph nodes 12 days after subcutaneous immunization with NP-OVA in alum.

Standard name | GSE38697_LIGHT_ZONE_VS_DARK_ZONE_BCELL_UP
Systematic name | M9007
Organism | Homo sapiens
PMID | 22740445
Authors | Victora GD,Dominguez-Sola D,Holmes AB,Deroubaix S,Dalla-Favera R,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: light zone versus dark zone.
Full description | Microarrays of gene expression in human germinal center light zone and dark zone B cells sorted according to the expression of cell surface molecules CD83 and CXCR4 We used microarray data to identify genes differentially expressed by B cells in the light and dark zones of germinal centers from human tonsil specimens.

Standard name | GSE38697_LIGHT_ZONE_VS_DARK_ZONE_BCELL_DN
Systematic name | M9010
Organism | Homo sapiens
PMID | 22740445
Authors | Victora GD,Dominguez-Sola D,Holmes AB,Deroubaix S,Dalla-Favera R,Nussenzweig MC
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: light zone versus dark zone.
Full description | Microarrays of gene expression in human germinal center light zone and dark zone B cells sorted according to the expression of cell surface molecules CD83 and CXCR4 We used microarray data to identify genes differentially expressed by B cells in the light and dark zones of germinal centers from human tonsil specimens.

Standard name | GSE37563_WT_VS_CTLA4_KO_CD4_TCELL_D4_POST_IMMUNIZATION_DN
Systematic name | M9014
Organism | Mus musculus
PMID | 22753941
Authors | Corse E,Allison JP
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] cells after immunization: wildtype versus CTLA4 [GeneID=1493] knockout.
Full description | CTLA-4 is thought to inhibit effector T cells both intrinsically, by competing with CD28 for B7 ligands, and extrinsically, through the action of regulatory T cells. We studied in vivo responses of normal and CTLA-4-deficient antigen-specific murine effector CD4+ T cells. In order to do these studies in a physiological model of immunity to foreign antigen, we transferred small numbers of congenically marked RAG2-deficient 5C.C7 T cells with either a normal or knockout allele of CTLA-4 into normal syngeneic B10.A recipient mice. The T cells were then activated by immunization with MCC peptide and LPS. To look for transcriptional signatures of negative regulation of T cell responses by CTLA-4, we used microarray analysis to compare transcripts in wild type and CTLA-4 KO 5C.C7 T cells four days after immunization. This is the first instance in which differences are observed in extent of accumulation of wild type and CTLA-4 KO 5C.C7 T cells.

Standard name | GSE37563_WT_VS_CTLA4_KO_CD4_TCELL_D4_POST_IMMUNIZATION_UP
Systematic name | M9015
Organism | Mus musculus
PMID | 22753941
Authors | Corse E,Allison JP
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] cells after immunization: wildtype versus CTLA4 [GeneID=1493] knockout.
Full description | CTLA-4 is thought to inhibit effector T cells both intrinsically, by competing with CD28 for B7 ligands, and extrinsically, through the action of regulatory T cells. We studied in vivo responses of normal and CTLA-4-deficient antigen-specific murine effector CD4+ T cells. In order to do these studies in a physiological model of immunity to foreign antigen, we transferred small numbers of congenically marked RAG2-deficient 5C.C7 T cells with either a normal or knockout allele of CTLA-4 into normal syngeneic B10.A recipient mice. The T cells were then activated by immunization with MCC peptide and LPS. To look for transcriptional signatures of negative regulation of T cell responses by CTLA-4, we used microarray analysis to compare transcripts in wild type and CTLA-4 KO 5C.C7 T cells four days after immunization. This is the first instance in which differences are observed in extent of accumulation of wild type and CTLA-4 KO 5C.C7 T cells.

Standard name | GSE39022_LN_VS_SPLEEN_DC_UP
Systematic name | M9017
Organism | Mus musculus
PMID | 22760781
Authors | Vitali C,Mingozzi F,Broggi A,Barresi S,Zolezzi F,Bayry J,Raimondi G,Zanoni I,Granucci F
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells from: lymph node versus spleen.
Full description | Spleen and lymph node dendritic cells have a differential capacity do induce and retain iTreg cells. Therefore we performed a comparative analysis of the dendritic cells derived from these two compartments to identify the responsible genes

Standard name | GSE39022_LN_VS_SPLEEN_DC_DN
Systematic name | M9018
Organism | Mus musculus
PMID | 22760781
Authors | Vitali C,Mingozzi F,Broggi A,Barresi S,Zolezzi F,Bayry J,Raimondi G,Zanoni I,Granucci F
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells from: lymph node versus spleen.
Full description | Spleen and lymph node dendritic cells have a differential capacity do induce and retain iTreg cells. Therefore we performed a comparative analysis of the dendritic cells derived from these two compartments to identify the responsible genes

Standard name | GSE38681_WT_VS_LYL1_KO_LYMPHOID_PRIMED_MULTIPOTENT_PROGENITOR_UP
Systematic name | M9019
Organism | Mus musculus
PMID | 22772404
Authors | Zohren F,Souroullas GP,Luo M,Gerdemann U,Imperato MR,Wilson NK,Göttgens B,Lukov GL,Goodell MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in lymphoid primed multipotent progenitors: wildtype versus LYL1 [GeneID=4066] knockout.
Full description | We compared gene expression differences in Lyl-1 knockout vs wildtype LMPPs KO allele described in Pub Med ID: 21387538

Standard name | GSE38681_WT_VS_LYL1_KO_LYMPHOID_PRIMED_MULTIPOTENT_PROGENITOR_DN
Systematic name | M9020
Organism | Mus musculus
PMID | 22772404
Authors | Zohren F,Souroullas GP,Luo M,Gerdemann U,Imperato MR,Wilson NK,Göttgens B,Lukov GL,Goodell MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in lymphoid primed multipotent progenitors: wildtype versus LYL1 [GeneID=4066] knockout.
Full description | We compared gene expression differences in Lyl-1 knockout vs wildtype LMPPs KO allele described in Pub Med ID: 21387538

Standard name | GSE36527_CD62L_HIGH_VS_CD62L_LOW_TREG_CD69_NEG_KLRG1_NEG_DN
Systematic name | M9022
Organism | Mus musculus
PMID | 22786769
Authors | Cheng G,Yuan X,Tsai MS,Podack ER,Yu A,Malek TR
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD69- KRLG1- [GeneID=969;10219] T reg: SELL high [GeneID=6402] versus SELL low [GeneID=6402].
Full description | Thymic-derived natural T regulatory cells (nTregs) are characterized by functional and phenotypic heterogeneity. Recently, a small fraction of peripheral Tregs have been shown to express Klrg1, but it remains unclear the extent Klrg1 defines a unique Treg subset. Here we show that Klrg1+ Tregs represent a terminally differentiated Treg subset derived from Klrg1- Tregs. This subset is a recent antigen-responsive and a highly activated short-lived Treg population that expresses enhanced levels of Treg suppressive molecules and that preferentially resides within mucosal tissues. The development of Klrg1+ Tregs also requires extensive IL-2R signaling. This activity represents a distinct function for IL-2, independent from its contribution to Treg homeostasis and competitive fitness. These and other properties are analogous to terminally differentiated short-lived CD8+ T effector cells. Our findings suggest that an important pathway driving antigen-activated conventional T lymphocytes also operates for Tregs. Gene expression analysis was performed of this and other Treg subsets based on expression of CD62L, CD69, and Klrg1 to define the molecular properties of Klrg1+ Tregs and its relationship to other Treg subsets found in the peripheral immune tissues.

Standard name | GSE36527_CD62L_HIGH_VS_CD62L_LOW_TREG_CD69_NEG_KLRG1_NEG_UP
Systematic name | M9023
Organism | Mus musculus
PMID | 22786769
Authors | Cheng G,Yuan X,Tsai MS,Podack ER,Yu A,Malek TR
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD69- KRLG1- [GeneID=969;10219] T reg: SELL high [GeneID=6402] versus SELL low [GeneID=6402].
Full description | Thymic-derived natural T regulatory cells (nTregs) are characterized by functional and phenotypic heterogeneity. Recently, a small fraction of peripheral Tregs have been shown to express Klrg1, but it remains unclear the extent Klrg1 defines a unique Treg subset. Here we show that Klrg1+ Tregs represent a terminally differentiated Treg subset derived from Klrg1- Tregs. This subset is a recent antigen-responsive and a highly activated short-lived Treg population that expresses enhanced levels of Treg suppressive molecules and that preferentially resides within mucosal tissues. The development of Klrg1+ Tregs also requires extensive IL-2R signaling. This activity represents a distinct function for IL-2, independent from its contribution to Treg homeostasis and competitive fitness. These and other properties are analogous to terminally differentiated short-lived CD8+ T effector cells. Our findings suggest that an important pathway driving antigen-activated conventional T lymphocytes also operates for Tregs. Gene expression analysis was performed of this and other Treg subsets based on expression of CD62L, CD69, and Klrg1 to define the molecular properties of Klrg1+ Tregs and its relationship to other Treg subsets found in the peripheral immune tissues.

Standard name | GSE36527_CD62L_HIGH_CD69_NEG_VS_CD62L_LOW_CD69_POS_TREG_KLRG1_NEG_UP
Systematic name | M9027
Organism | Mus musculus
PMID | 22786769
Authors | Cheng G,Yuan X,Tsai MS,Podack ER,Yu A,Malek TR
Category | C7
Sub-category |
Brief description | Genes up-regulated in KLRG1- [GeneID=10219] T reg:SELL high CD69- [GeneID=6402;969] versus SELL low CD69+ [GeneID=6402;969].
Full description | Thymic-derived natural T regulatory cells (nTregs) are characterized by functional and phenotypic heterogeneity. Recently, a small fraction of peripheral Tregs have been shown to express Klrg1, but it remains unclear the extent Klrg1 defines a unique Treg subset. Here we show that Klrg1+ Tregs represent a terminally differentiated Treg subset derived from Klrg1- Tregs. This subset is a recent antigen-responsive and a highly activated short-lived Treg population that expresses enhanced levels of Treg suppressive molecules and that preferentially resides within mucosal tissues. The development of Klrg1+ Tregs also requires extensive IL-2R signaling. This activity represents a distinct function for IL-2, independent from its contribution to Treg homeostasis and competitive fitness. These and other properties are analogous to terminally differentiated short-lived CD8+ T effector cells. Our findings suggest that an important pathway driving antigen-activated conventional T lymphocytes also operates for Tregs. Gene expression analysis was performed of this and other Treg subsets based on expression of CD62L, CD69, and Klrg1 to define the molecular properties of Klrg1+ Tregs and its relationship to other Treg subsets found in the peripheral immune tissues.

Standard name | GSE36527_CD62L_HIGH_CD69_NEG_VS_CD62L_LOW_CD69_POS_TREG_KLRG1_NEG_DN
Systematic name | M9028
Organism | Mus musculus
PMID | 22786769
Authors | Cheng G,Yuan X,Tsai MS,Podack ER,Yu A,Malek TR
Category | C7
Sub-category |
Brief description | Genes down-regulated in KLRG1- [GeneID=10219] T reg:SELL high CD69- [GeneID=6402;969] versus SELL low CD69+ [GeneID=6402;969].
Full description | Thymic-derived natural T regulatory cells (nTregs) are characterized by functional and phenotypic heterogeneity. Recently, a small fraction of peripheral Tregs have been shown to express Klrg1, but it remains unclear the extent Klrg1 defines a unique Treg subset. Here we show that Klrg1+ Tregs represent a terminally differentiated Treg subset derived from Klrg1- Tregs. This subset is a recent antigen-responsive and a highly activated short-lived Treg population that expresses enhanced levels of Treg suppressive molecules and that preferentially resides within mucosal tissues. The development of Klrg1+ Tregs also requires extensive IL-2R signaling. This activity represents a distinct function for IL-2, independent from its contribution to Treg homeostasis and competitive fitness. These and other properties are analogous to terminally differentiated short-lived CD8+ T effector cells. Our findings suggest that an important pathway driving antigen-activated conventional T lymphocytes also operates for Tregs. Gene expression analysis was performed of this and other Treg subsets based on expression of CD62L, CD69, and Klrg1 to define the molecular properties of Klrg1+ Tregs and its relationship to other Treg subsets found in the peripheral immune tissues.

Standard name | GSE36527_CD69_NEG_VS_POS_TREG_CD62L_LOS_KLRG1_NEG_DN
Systematic name | M9029
Organism | Mus musculus
PMID | 22786769
Authors | Cheng G,Yuan X,Tsai MS,Podack ER,Yu A,Malek TR
Category | C7
Sub-category |
Brief description | Genes down-regulated in KLRG1- SELL low [GeneID=10219;6402] T reg: CD69- [GeneID=969] versus CD69+ [GeneID=969].
Full description | Thymic-derived natural T regulatory cells (nTregs) are characterized by functional and phenotypic heterogeneity. Recently, a small fraction of peripheral Tregs have been shown to express Klrg1, but it remains unclear the extent Klrg1 defines a unique Treg subset. Here we show that Klrg1+ Tregs represent a terminally differentiated Treg subset derived from Klrg1- Tregs. This subset is a recent antigen-responsive and a highly activated short-lived Treg population that expresses enhanced levels of Treg suppressive molecules and that preferentially resides within mucosal tissues. The development of Klrg1+ Tregs also requires extensive IL-2R signaling. This activity represents a distinct function for IL-2, independent from its contribution to Treg homeostasis and competitive fitness. These and other properties are analogous to terminally differentiated short-lived CD8+ T effector cells. Our findings suggest that an important pathway driving antigen-activated conventional T lymphocytes also operates for Tregs. Gene expression analysis was performed of this and other Treg subsets based on expression of CD62L, CD69, and Klrg1 to define the molecular properties of Klrg1+ Tregs and its relationship to other Treg subsets found in the peripheral immune tissues.

Standard name | GSE36527_CD69_NEG_VS_POS_TREG_CD62L_LOS_KLRG1_NEG_UP
Systematic name | M9030
Organism | Mus musculus
PMID | 22786769
Authors | Cheng G,Yuan X,Tsai MS,Podack ER,Yu A,Malek TR
Category | C7
Sub-category |
Brief description | Genes up-regulated in KLRG1- SELL low [GeneID=10219;6402] T reg: CD69- [GeneID=969] versus CD69+ [GeneID=969].
Full description | Thymic-derived natural T regulatory cells (nTregs) are characterized by functional and phenotypic heterogeneity. Recently, a small fraction of peripheral Tregs have been shown to express Klrg1, but it remains unclear the extent Klrg1 defines a unique Treg subset. Here we show that Klrg1+ Tregs represent a terminally differentiated Treg subset derived from Klrg1- Tregs. This subset is a recent antigen-responsive and a highly activated short-lived Treg population that expresses enhanced levels of Treg suppressive molecules and that preferentially resides within mucosal tissues. The development of Klrg1+ Tregs also requires extensive IL-2R signaling. This activity represents a distinct function for IL-2, independent from its contribution to Treg homeostasis and competitive fitness. These and other properties are analogous to terminally differentiated short-lived CD8+ T effector cells. Our findings suggest that an important pathway driving antigen-activated conventional T lymphocytes also operates for Tregs. Gene expression analysis was performed of this and other Treg subsets based on expression of CD62L, CD69, and Klrg1 to define the molecular properties of Klrg1+ Tregs and its relationship to other Treg subsets found in the peripheral immune tissues.

Standard name | GSE33162_UNTREATED_VS_4H_LPS_STIM_HDAC3_HET_MACROPHAGE_DN
Systematic name | M9031
Organism | Mus musculus
PMID | 22802645
Authors | Chen X,Barozzi I,Termanini A,Prosperini E,Recchiuti A,Dalli J,Mietton F,Matteoli G,Hiebert S,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with heterozygous knockout of HDAC3 [GeneID=8841]: untreated versus LPS.
Full description | Pan-Hdac inhibitors (HDACi) are endowed with a potent anti-inflammatory activity, but the relative role of each of the eleven Hdac proteins sensitive to HDACi to the inflammatory gene expression program is unknown. Using an integrated genomic approach we found that Hdac3-deficient macrophages are unable to activate almost half of the inflammatory gene expression program when stimulated with lipopolysaccharide (LPS). A large part of the activation defect is due to loss of basal and LPS-inducible expression of IFNb, which in basal cells maintains Stat1 protein levels, and after stimulation acts in an autocrine/paracrine manner to promote a secondary wave of Stat1-dependent gene expression. We show that loss of Hdac3-mediated repression of nuclear receptors leads to hyperacetylation of thousands of genomic sites and associated gene derepression. The upregulation of the constitutively expressed prostaglandin endoperoxide synthase, Ptgs1 (Cox-1), has a causative role in the phenotype, since its chemical inhibition reverts the Ifnb activation defect. These data may have relevance for the use of selective Hdac inhibitors as anti-inflammatory agents.

Standard name | GSE33162_UNTREATED_VS_4H_LPS_STIM_HDAC3_KO_MACROPHAGE_UP
Systematic name | M9033
Organism | Mus musculus
PMID | 22802645
Authors | Chen X,Barozzi I,Termanini A,Prosperini E,Recchiuti A,Dalli J,Mietton F,Matteoli G,Hiebert S,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with knockout of HDAC3 [GeneID=8841]: untreated versus LPS.
Full description | Pan-Hdac inhibitors (HDACi) are endowed with a potent anti-inflammatory activity, but the relative role of each of the eleven Hdac proteins sensitive to HDACi to the inflammatory gene expression program is unknown. Using an integrated genomic approach we found that Hdac3-deficient macrophages are unable to activate almost half of the inflammatory gene expression program when stimulated with lipopolysaccharide (LPS). A large part of the activation defect is due to loss of basal and LPS-inducible expression of IFNb, which in basal cells maintains Stat1 protein levels, and after stimulation acts in an autocrine/paracrine manner to promote a secondary wave of Stat1-dependent gene expression. We show that loss of Hdac3-mediated repression of nuclear receptors leads to hyperacetylation of thousands of genomic sites and associated gene derepression. The upregulation of the constitutively expressed prostaglandin endoperoxide synthase, Ptgs1 (Cox-1), has a causative role in the phenotype, since its chemical inhibition reverts the Ifnb activation defect. These data may have relevance for the use of selective Hdac inhibitors as anti-inflammatory agents.

Standard name | GSE33162_UNTREATED_VS_4H_LPS_STIM_HDAC3_HET_MACROPHAGE_UP
Systematic name | M9035
Organism | Mus musculus
PMID | 22802645
Authors | Chen X,Barozzi I,Termanini A,Prosperini E,Recchiuti A,Dalli J,Mietton F,Matteoli G,Hiebert S,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with heterozygous knockout of HDAC3 [GeneID=8841]: untreated versus LPS.
Full description | Pan-Hdac inhibitors (HDACi) are endowed with a potent anti-inflammatory activity, but the relative role of each of the eleven Hdac proteins sensitive to HDACi to the inflammatory gene expression program is unknown. Using an integrated genomic approach we found that Hdac3-deficient macrophages are unable to activate almost half of the inflammatory gene expression program when stimulated with lipopolysaccharide (LPS). A large part of the activation defect is due to loss of basal and LPS-inducible expression of IFNb, which in basal cells maintains Stat1 protein levels, and after stimulation acts in an autocrine/paracrine manner to promote a secondary wave of Stat1-dependent gene expression. We show that loss of Hdac3-mediated repression of nuclear receptors leads to hyperacetylation of thousands of genomic sites and associated gene derepression. The upregulation of the constitutively expressed prostaglandin endoperoxide synthase, Ptgs1 (Cox-1), has a causative role in the phenotype, since its chemical inhibition reverts the Ifnb activation defect. These data may have relevance for the use of selective Hdac inhibitors as anti-inflammatory agents.

Standard name | GSE33162_UNTREATED_VS_4H_LPS_STIM_HDAC3_KO_MACROPHAGE_DN
Systematic name | M9037
Organism | Mus musculus
PMID | 22802645
Authors | Chen X,Barozzi I,Termanini A,Prosperini E,Recchiuti A,Dalli J,Mietton F,Matteoli G,Hiebert S,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with knockout of HDAC3 [GeneID=8841]: untreated versus LPS.
Full description | Pan-Hdac inhibitors (HDACi) are endowed with a potent anti-inflammatory activity, but the relative role of each of the eleven Hdac proteins sensitive to HDACi to the inflammatory gene expression program is unknown. Using an integrated genomic approach we found that Hdac3-deficient macrophages are unable to activate almost half of the inflammatory gene expression program when stimulated with lipopolysaccharide (LPS). A large part of the activation defect is due to loss of basal and LPS-inducible expression of IFNb, which in basal cells maintains Stat1 protein levels, and after stimulation acts in an autocrine/paracrine manner to promote a secondary wave of Stat1-dependent gene expression. We show that loss of Hdac3-mediated repression of nuclear receptors leads to hyperacetylation of thousands of genomic sites and associated gene derepression. The upregulation of the constitutively expressed prostaglandin endoperoxide synthase, Ptgs1 (Cox-1), has a causative role in the phenotype, since its chemical inhibition reverts the Ifnb activation defect. These data may have relevance for the use of selective Hdac inhibitors as anti-inflammatory agents.

Standard name | GSE33162_HDAC3_KO_VS_HDAC3_KO_MACROPHAGE_UP
Systematic name | M9038
Organism | Mus musculus
PMID | 22802645
Authors | Chen X,Barozzi I,Termanini A,Prosperini E,Recchiuti A,Dalli J,Mietton F,Matteoli G,Hiebert S,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with knockout of HDAC3 [GeneID=8841]: heterozygous versus homozygous.
Full description | Pan-Hdac inhibitors (HDACi) are endowed with a potent anti-inflammatory activity, but the relative role of each of the eleven Hdac proteins sensitive to HDACi to the inflammatory gene expression program is unknown. Using an integrated genomic approach we found that Hdac3-deficient macrophages are unable to activate almost half of the inflammatory gene expression program when stimulated with lipopolysaccharide (LPS). A large part of the activation defect is due to loss of basal and LPS-inducible expression of IFNb, which in basal cells maintains Stat1 protein levels, and after stimulation acts in an autocrine/paracrine manner to promote a secondary wave of Stat1-dependent gene expression. We show that loss of Hdac3-mediated repression of nuclear receptors leads to hyperacetylation of thousands of genomic sites and associated gene derepression. The upregulation of the constitutively expressed prostaglandin endoperoxide synthase, Ptgs1 (Cox-1), has a causative role in the phenotype, since its chemical inhibition reverts the Ifnb activation defect. These data may have relevance for the use of selective Hdac inhibitors as anti-inflammatory agents.

Standard name | GSE33162_HDAC3_KO_VS_HDAC3_KO_MACROPHAGE_DN
Systematic name | M9039
Organism | Mus musculus
PMID | 22802645
Authors | Chen X,Barozzi I,Termanini A,Prosperini E,Recchiuti A,Dalli J,Mietton F,Matteoli G,Hiebert S,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with knockout of HDAC3 [GeneID=8841]: heterozygous versus homozygous.
Full description | Pan-Hdac inhibitors (HDACi) are endowed with a potent anti-inflammatory activity, but the relative role of each of the eleven Hdac proteins sensitive to HDACi to the inflammatory gene expression program is unknown. Using an integrated genomic approach we found that Hdac3-deficient macrophages are unable to activate almost half of the inflammatory gene expression program when stimulated with lipopolysaccharide (LPS). A large part of the activation defect is due to loss of basal and LPS-inducible expression of IFNb, which in basal cells maintains Stat1 protein levels, and after stimulation acts in an autocrine/paracrine manner to promote a secondary wave of Stat1-dependent gene expression. We show that loss of Hdac3-mediated repression of nuclear receptors leads to hyperacetylation of thousands of genomic sites and associated gene derepression. The upregulation of the constitutively expressed prostaglandin endoperoxide synthase, Ptgs1 (Cox-1), has a causative role in the phenotype, since its chemical inhibition reverts the Ifnb activation defect. These data may have relevance for the use of selective Hdac inhibitors as anti-inflammatory agents.

Standard name | GSE33162_HDAC3_KO_VS_HDAC3_KO_4H_LPS_STIM_MACROPHAGE_DN
Systematic name | M9040
Organism | Mus musculus
PMID | 22802645
Authors | Chen X,Barozzi I,Termanini A,Prosperini E,Recchiuti A,Dalli J,Mietton F,Matteoli G,Hiebert S,Natoli G
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages with knockout of HDAC3 [GeneID=8841] after LPS treatment: heterozygous versus homozygous.
Full description | Pan-Hdac inhibitors (HDACi) are endowed with a potent anti-inflammatory activity, but the relative role of each of the eleven Hdac proteins sensitive to HDACi to the inflammatory gene expression program is unknown. Using an integrated genomic approach we found that Hdac3-deficient macrophages are unable to activate almost half of the inflammatory gene expression program when stimulated with lipopolysaccharide (LPS). A large part of the activation defect is due to loss of basal and LPS-inducible expression of IFNb, which in basal cells maintains Stat1 protein levels, and after stimulation acts in an autocrine/paracrine manner to promote a secondary wave of Stat1-dependent gene expression. We show that loss of Hdac3-mediated repression of nuclear receptors leads to hyperacetylation of thousands of genomic sites and associated gene derepression. The upregulation of the constitutively expressed prostaglandin endoperoxide synthase, Ptgs1 (Cox-1), has a causative role in the phenotype, since its chemical inhibition reverts the Ifnb activation defect. These data may have relevance for the use of selective Hdac inhibitors as anti-inflammatory agents.

Standard name | GSE33162_HDAC3_KO_VS_HDAC3_KO_4H_LPS_STIM_MACROPHAGE_UP
Systematic name | M9041
Organism | Mus musculus
PMID | 22802645
Authors | Chen X,Barozzi I,Termanini A,Prosperini E,Recchiuti A,Dalli J,Mietton F,Matteoli G,Hiebert S,Natoli G
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages with knockout of HDAC3 [GeneID=8841] after LPS treatment: heterozygous versus homozygous.
Full description | Pan-Hdac inhibitors (HDACi) are endowed with a potent anti-inflammatory activity, but the relative role of each of the eleven Hdac proteins sensitive to HDACi to the inflammatory gene expression program is unknown. Using an integrated genomic approach we found that Hdac3-deficient macrophages are unable to activate almost half of the inflammatory gene expression program when stimulated with lipopolysaccharide (LPS). A large part of the activation defect is due to loss of basal and LPS-inducible expression of IFNb, which in basal cells maintains Stat1 protein levels, and after stimulation acts in an autocrine/paracrine manner to promote a secondary wave of Stat1-dependent gene expression. We show that loss of Hdac3-mediated repression of nuclear receptors leads to hyperacetylation of thousands of genomic sites and associated gene derepression. The upregulation of the constitutively expressed prostaglandin endoperoxide synthase, Ptgs1 (Cox-1), has a causative role in the phenotype, since its chemical inhibition reverts the Ifnb activation defect. These data may have relevance for the use of selective Hdac inhibitors as anti-inflammatory agents.

Standard name | GSE34006_WT_VS_A2AR_KO_TREG_DN
Systematic name | M9042
Organism | Mus musculus
PMID | 22835488
Authors | Kinsey GR,Huang L,Jaworska K,Khutsishvili K,Becker DA,Ye H,Lobo PI,Okusa MD
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: wildtype versus ADORA2A [GeneID=135].
Full description | The adenosine 2A receptor (A2AR) is expressed on regulatory T cells (Tregs), but the functional significance is currently unknown. We compared the gene expression between wild-type (WT) and A2AR knockout (KO) Tregs and between WT Tregs treated with vehicle or a selective A2AR agonist.

Standard name | GSE34006_UNTREATED_VS_A2AR_AGONIST_TREATED_TREG_UP
Systematic name | M9045
Organism | Mus musculus
PMID | 22835488
Authors | Kinsey GR,Huang L,Jaworska K,Khutsishvili K,Becker DA,Ye H,Lobo PI,Okusa MD
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: untreated versus ZM 241385 [PubChem=176407].
Full description | The adenosine 2A receptor (A2AR) is expressed on regulatory T cells (Tregs), but the functional significance is currently unknown. We compared the gene expression between wild-type (WT) and A2AR knockout (KO) Tregs and between WT Tregs treated with vehicle or a selective A2AR agonist.

Standard name | GSE34006_WT_VS_A2AR_KO_TREG_UP
Systematic name | M9047
Organism | Mus musculus
PMID | 22835488
Authors | Kinsey GR,Huang L,Jaworska K,Khutsishvili K,Becker DA,Ye H,Lobo PI,Okusa MD
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: wildtype versus ADORA2A [GeneID=135].
Full description | The adenosine 2A receptor (A2AR) is expressed on regulatory T cells (Tregs), but the functional significance is currently unknown. We compared the gene expression between wild-type (WT) and A2AR knockout (KO) Tregs and between WT Tregs treated with vehicle or a selective A2AR agonist.

Standard name | GSE34006_A2AR_KO_VS_A2AR_AGONIST_TREATED_TREG_DN
Systematic name | M9049
Organism | Mus musculus
PMID | 22835488
Authors | Kinsey GR,Huang L,Jaworska K,Khutsishvili K,Becker DA,Ye H,Lobo PI,Okusa MD
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: untreated ADORA2A [GeneID=135] knockout versus wildtype treated by ZM 241385 [PubChem=176407].
Full description | The adenosine 2A receptor (A2AR) is expressed on regulatory T cells (Tregs), but the functional significance is currently unknown. We compared the gene expression between wild-type (WT) and A2AR knockout (KO) Tregs and between WT Tregs treated with vehicle or a selective A2AR agonist.

Standard name | GSE34006_UNTREATED_VS_A2AR_AGONIST_TREATED_TREG_DN
Systematic name | M9050
Organism | Mus musculus
PMID | 22835488
Authors | Kinsey GR,Huang L,Jaworska K,Khutsishvili K,Becker DA,Ye H,Lobo PI,Okusa MD
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: untreated versus ZM 241385 [PubChem=176407].
Full description | The adenosine 2A receptor (A2AR) is expressed on regulatory T cells (Tregs), but the functional significance is currently unknown. We compared the gene expression between wild-type (WT) and A2AR knockout (KO) Tregs and between WT Tregs treated with vehicle or a selective A2AR agonist.

Standard name | GSE34006_A2AR_KO_VS_A2AR_AGONIST_TREATED_TREG_UP
Systematic name | M9051
Organism | Mus musculus
PMID | 22835488
Authors | Kinsey GR,Huang L,Jaworska K,Khutsishvili K,Becker DA,Ye H,Lobo PI,Okusa MD
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: untreated ADORA2A [GeneID=135] knockout versus wildtype treated by ZM 241385 [PubChem=176407].
Full description | The adenosine 2A receptor (A2AR) is expressed on regulatory T cells (Tregs), but the functional significance is currently unknown. We compared the gene expression between wild-type (WT) and A2AR knockout (KO) Tregs and between WT Tregs treated with vehicle or a selective A2AR agonist.

Standard name | GSE32034_LY6C_HIGH_VS_LOW_MONOCYTE_UP
Systematic name | M9053
Organism | Mus musculus
PMID | 22855714
Authors | Gautier EL,Chow A,Spanbroek R,Marcelin G,Greter M,Jakubzick C,Bogunovic M,Leboeuf M,Rooijen van N,Habenicht AJ,Merad M,Randolph GJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in Ly6C monocytes: high versus low.
Full description | PPARγ is known for its anti-inflammatory actions in macrophages. However, which macrophage populations express PPARγ in vivo and how it regulates tissue homeostasis in the steady state and during inflammation is not completely understood. We show that lung and spleen macrophages constitutively expressed PPARγ, while other macrophage populations did not. Recruitment of monocytes to sites of inflammation was associated with induction of PPARγ as they differentiated to macrophages. Its absence in these macrophages led to failed resolution of inflammation, characterized by persistent, low-level recruitment of leukocytes. Conversely, PPARγ agonists supported an earlier cessation in leukocyte recruitment during resolution of acute inflammation and likewise suppressed monocyte recruitment to chronically inflamed atherosclerotic vessels. In the steady state, PPARγ deficiency in macrophages had no obvious impact in the spleen but profoundly altered cellular lipid homeostasis in lung macrophages. Reminiscent of pulmonary alveolar proteinosis, LysM-Cre x PPARγflox/flox mice displayed mild leukocytic inflammation in the steady-state lung and succumbed faster to mortality upon infection with S. pneumoniae. Surprisingly, this mortality was not due to overly exuberant inflammation, but instead to impaired bacterial clearance. Thus, in addition to its anti-inflammatory role in promoting resolution of inflammation, PPARγ sustains functionality in lung macrophages and thereby has a pivotal role in supporting pulmonary host defense.

Standard name | GSE32034_LY6C_HIGH_VS_LOW_MONOCYTE_DN
Systematic name | M9055
Organism | Mus musculus
PMID | 22855714
Authors | Gautier EL,Chow A,Spanbroek R,Marcelin G,Greter M,Jakubzick C,Bogunovic M,Leboeuf M,Rooijen van N,Habenicht AJ,Merad M,Randolph GJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in Ly6C monocytes: high versus low.
Full description | PPARγ is known for its anti-inflammatory actions in macrophages. However, which macrophage populations express PPARγ in vivo and how it regulates tissue homeostasis in the steady state and during inflammation is not completely understood. We show that lung and spleen macrophages constitutively expressed PPARγ, while other macrophage populations did not. Recruitment of monocytes to sites of inflammation was associated with induction of PPARγ as they differentiated to macrophages. Its absence in these macrophages led to failed resolution of inflammation, characterized by persistent, low-level recruitment of leukocytes. Conversely, PPARγ agonists supported an earlier cessation in leukocyte recruitment during resolution of acute inflammation and likewise suppressed monocyte recruitment to chronically inflamed atherosclerotic vessels. In the steady state, PPARγ deficiency in macrophages had no obvious impact in the spleen but profoundly altered cellular lipid homeostasis in lung macrophages. Reminiscent of pulmonary alveolar proteinosis, LysM-Cre x PPARγflox/flox mice displayed mild leukocytic inflammation in the steady-state lung and succumbed faster to mortality upon infection with S. pneumoniae. Surprisingly, this mortality was not due to overly exuberant inflammation, but instead to impaired bacterial clearance. Thus, in addition to its anti-inflammatory role in promoting resolution of inflammation, PPARγ sustains functionality in lung macrophages and thereby has a pivotal role in supporting pulmonary host defense.

Standard name | GSE32034_UNTREATED_VS_ROSIGLIZATONE_TREATED_LY6C_LOW_MONOCYTE_UP
Systematic name | M9056
Organism | Mus musculus
PMID | 22855714
Authors | Gautier EL,Chow A,Spanbroek R,Marcelin G,Greter M,Jakubzick C,Bogunovic M,Leboeuf M,Rooijen van N,Habenicht AJ,Merad M,Randolph GJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in Ly6C low monocytes: untreated versus rosiglitazone [PubChem=77999].
Full description | PPARγ is known for its anti-inflammatory actions in macrophages. However, which macrophage populations express PPARγ in vivo and how it regulates tissue homeostasis in the steady state and during inflammation is not completely understood. We show that lung and spleen macrophages constitutively expressed PPARγ, while other macrophage populations did not. Recruitment of monocytes to sites of inflammation was associated with induction of PPARγ as they differentiated to macrophages. Its absence in these macrophages led to failed resolution of inflammation, characterized by persistent, low-level recruitment of leukocytes. Conversely, PPARγ agonists supported an earlier cessation in leukocyte recruitment during resolution of acute inflammation and likewise suppressed monocyte recruitment to chronically inflamed atherosclerotic vessels. In the steady state, PPARγ deficiency in macrophages had no obvious impact in the spleen but profoundly altered cellular lipid homeostasis in lung macrophages. Reminiscent of pulmonary alveolar proteinosis, LysM-Cre x PPARγflox/flox mice displayed mild leukocytic inflammation in the steady-state lung and succumbed faster to mortality upon infection with S. pneumoniae. Surprisingly, this mortality was not due to overly exuberant inflammation, but instead to impaired bacterial clearance. Thus, in addition to its anti-inflammatory role in promoting resolution of inflammation, PPARγ sustains functionality in lung macrophages and thereby has a pivotal role in supporting pulmonary host defense.

Standard name | GSE32034_UNTREATED_VS_ROSIGLIZATONE_TREATED_LY6C_LOW_MONOCYTE_DN
Systematic name | M9057
Organism | Mus musculus
PMID | 22855714
Authors | Gautier EL,Chow A,Spanbroek R,Marcelin G,Greter M,Jakubzick C,Bogunovic M,Leboeuf M,Rooijen van N,Habenicht AJ,Merad M,Randolph GJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in Ly6C low monocytes: untreated versus rosiglitazone [PubChem=77999].
Full description | PPARγ is known for its anti-inflammatory actions in macrophages. However, which macrophage populations express PPARγ in vivo and how it regulates tissue homeostasis in the steady state and during inflammation is not completely understood. We show that lung and spleen macrophages constitutively expressed PPARγ, while other macrophage populations did not. Recruitment of monocytes to sites of inflammation was associated with induction of PPARγ as they differentiated to macrophages. Its absence in these macrophages led to failed resolution of inflammation, characterized by persistent, low-level recruitment of leukocytes. Conversely, PPARγ agonists supported an earlier cessation in leukocyte recruitment during resolution of acute inflammation and likewise suppressed monocyte recruitment to chronically inflamed atherosclerotic vessels. In the steady state, PPARγ deficiency in macrophages had no obvious impact in the spleen but profoundly altered cellular lipid homeostasis in lung macrophages. Reminiscent of pulmonary alveolar proteinosis, LysM-Cre x PPARγflox/flox mice displayed mild leukocytic inflammation in the steady-state lung and succumbed faster to mortality upon infection with S. pneumoniae. Surprisingly, this mortality was not due to overly exuberant inflammation, but instead to impaired bacterial clearance. Thus, in addition to its anti-inflammatory role in promoting resolution of inflammation, PPARγ sustains functionality in lung macrophages and thereby has a pivotal role in supporting pulmonary host defense.

Standard name | GSE32034_LY6C_HIGH_VS_LOW_ROSIGLIZATONE_TREATED_MONOCYTE_UP
Systematic name | M9059
Organism | Mus musculus
PMID | 22855714
Authors | Gautier EL,Chow A,Spanbroek R,Marcelin G,Greter M,Jakubzick C,Bogunovic M,Leboeuf M,Rooijen van N,Habenicht AJ,Merad M,Randolph GJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in monocytes treated by rosiglitazone [PubChem=77999]: Ly6C high versus Ly6C low.
Full description | PPARγ is known for its anti-inflammatory actions in macrophages. However, which macrophage populations express PPARγ in vivo and how it regulates tissue homeostasis in the steady state and during inflammation is not completely understood. We show that lung and spleen macrophages constitutively expressed PPARγ, while other macrophage populations did not. Recruitment of monocytes to sites of inflammation was associated with induction of PPARγ as they differentiated to macrophages. Its absence in these macrophages led to failed resolution of inflammation, characterized by persistent, low-level recruitment of leukocytes. Conversely, PPARγ agonists supported an earlier cessation in leukocyte recruitment during resolution of acute inflammation and likewise suppressed monocyte recruitment to chronically inflamed atherosclerotic vessels. In the steady state, PPARγ deficiency in macrophages had no obvious impact in the spleen but profoundly altered cellular lipid homeostasis in lung macrophages. Reminiscent of pulmonary alveolar proteinosis, LysM-Cre x PPARγflox/flox mice displayed mild leukocytic inflammation in the steady-state lung and succumbed faster to mortality upon infection with S. pneumoniae. Surprisingly, this mortality was not due to overly exuberant inflammation, but instead to impaired bacterial clearance. Thus, in addition to its anti-inflammatory role in promoting resolution of inflammation, PPARγ sustains functionality in lung macrophages and thereby has a pivotal role in supporting pulmonary host defense.

Standard name | GSE32034_UNTREATED_VS_ROSIGLIZATONE_TREATED_LY6C_HIGH_MONOCYTE_UP
Systematic name | M9060
Organism | Mus musculus
PMID | 22855714
Authors | Gautier EL,Chow A,Spanbroek R,Marcelin G,Greter M,Jakubzick C,Bogunovic M,Leboeuf M,Rooijen van N,Habenicht AJ,Merad M,Randolph GJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in Ly6C high monocytes: untreated versus rosiglitazone [PubChem=77999].
Full description | PPARγ is known for its anti-inflammatory actions in macrophages. However, which macrophage populations express PPARγ in vivo and how it regulates tissue homeostasis in the steady state and during inflammation is not completely understood. We show that lung and spleen macrophages constitutively expressed PPARγ, while other macrophage populations did not. Recruitment of monocytes to sites of inflammation was associated with induction of PPARγ as they differentiated to macrophages. Its absence in these macrophages led to failed resolution of inflammation, characterized by persistent, low-level recruitment of leukocytes. Conversely, PPARγ agonists supported an earlier cessation in leukocyte recruitment during resolution of acute inflammation and likewise suppressed monocyte recruitment to chronically inflamed atherosclerotic vessels. In the steady state, PPARγ deficiency in macrophages had no obvious impact in the spleen but profoundly altered cellular lipid homeostasis in lung macrophages. Reminiscent of pulmonary alveolar proteinosis, LysM-Cre x PPARγflox/flox mice displayed mild leukocytic inflammation in the steady-state lung and succumbed faster to mortality upon infection with S. pneumoniae. Surprisingly, this mortality was not due to overly exuberant inflammation, but instead to impaired bacterial clearance. Thus, in addition to its anti-inflammatory role in promoting resolution of inflammation, PPARγ sustains functionality in lung macrophages and thereby has a pivotal role in supporting pulmonary host defense.

Standard name | GSE32034_UNTREATED_VS_ROSIGLIZATONE_TREATED_LY6C_HIGH_MONOCYTE_DN
Systematic name | M9061
Organism | Mus musculus
PMID | 22855714
Authors | Gautier EL,Chow A,Spanbroek R,Marcelin G,Greter M,Jakubzick C,Bogunovic M,Leboeuf M,Rooijen van N,Habenicht AJ,Merad M,Randolph GJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in Ly6C high monocytes: untreated versus rosiglitazone [PubChem=77999].
Full description | PPARγ is known for its anti-inflammatory actions in macrophages. However, which macrophage populations express PPARγ in vivo and how it regulates tissue homeostasis in the steady state and during inflammation is not completely understood. We show that lung and spleen macrophages constitutively expressed PPARγ, while other macrophage populations did not. Recruitment of monocytes to sites of inflammation was associated with induction of PPARγ as they differentiated to macrophages. Its absence in these macrophages led to failed resolution of inflammation, characterized by persistent, low-level recruitment of leukocytes. Conversely, PPARγ agonists supported an earlier cessation in leukocyte recruitment during resolution of acute inflammation and likewise suppressed monocyte recruitment to chronically inflamed atherosclerotic vessels. In the steady state, PPARγ deficiency in macrophages had no obvious impact in the spleen but profoundly altered cellular lipid homeostasis in lung macrophages. Reminiscent of pulmonary alveolar proteinosis, LysM-Cre x PPARγflox/flox mice displayed mild leukocytic inflammation in the steady-state lung and succumbed faster to mortality upon infection with S. pneumoniae. Surprisingly, this mortality was not due to overly exuberant inflammation, but instead to impaired bacterial clearance. Thus, in addition to its anti-inflammatory role in promoting resolution of inflammation, PPARγ sustains functionality in lung macrophages and thereby has a pivotal role in supporting pulmonary host defense.

Standard name | GSE32034_LY6C_HIGH_VS_LOW_ROSIGLIZATONE_TREATED_MONOCYTE_DN
Systematic name | M9062
Organism | Mus musculus
PMID | 22855714
Authors | Gautier EL,Chow A,Spanbroek R,Marcelin G,Greter M,Jakubzick C,Bogunovic M,Leboeuf M,Rooijen van N,Habenicht AJ,Merad M,Randolph GJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in monocytes treated by rosiglitazone [PubChem=77999]: Ly6C high versus Ly6C low.
Full description | PPARγ is known for its anti-inflammatory actions in macrophages. However, which macrophage populations express PPARγ in vivo and how it regulates tissue homeostasis in the steady state and during inflammation is not completely understood. We show that lung and spleen macrophages constitutively expressed PPARγ, while other macrophage populations did not. Recruitment of monocytes to sites of inflammation was associated with induction of PPARγ as they differentiated to macrophages. Its absence in these macrophages led to failed resolution of inflammation, characterized by persistent, low-level recruitment of leukocytes. Conversely, PPARγ agonists supported an earlier cessation in leukocyte recruitment during resolution of acute inflammation and likewise suppressed monocyte recruitment to chronically inflamed atherosclerotic vessels. In the steady state, PPARγ deficiency in macrophages had no obvious impact in the spleen but profoundly altered cellular lipid homeostasis in lung macrophages. Reminiscent of pulmonary alveolar proteinosis, LysM-Cre x PPARγflox/flox mice displayed mild leukocytic inflammation in the steady-state lung and succumbed faster to mortality upon infection with S. pneumoniae. Surprisingly, this mortality was not due to overly exuberant inflammation, but instead to impaired bacterial clearance. Thus, in addition to its anti-inflammatory role in promoting resolution of inflammation, PPARγ sustains functionality in lung macrophages and thereby has a pivotal role in supporting pulmonary host defense.

Standard name | GSE39864_WT_VS_GATA3_KO_TREG_DN
Systematic name | M9063
Organism | Mus musculus
PMID | 22922362
Authors | Rudra D,deRoos P,Chaudhry A,Niec RE,Arvey A,Samstein RM,Leslie C,Shaffer SA,Goodlett DR,Rudensky AY
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg cells: wildtype versus GATA3 [GeneID=2625] knockout.
Full description | The transcription factor Foxp3 is indispensible for the differentiation and function of regulatory T cells (Treg cells). To gain insights into the molecular mechanisms of Foxp3 mediated gene expression we purified Foxp3 complexes and explored their composition. Biochemical and mass-spectrometric analyses revealed that Foxp3 forms multi-protein complexes of 400-800 kDa or larger and identified 361 associated proteins ~30% of which are transcription-related. Foxp3 directly regulates expression of a large proportion of the genes encoding its co-factors. Reciprocally, some transcription factor partners of Foxp3 facilitate its expression. Functional analysis of Foxp3 cooperation with one such partner, Gata3, provided further evidence for a network of transcriptional regulation afforded by Foxp3 and its associates to control distinct aspects of Treg cell biology. Gene expression profile of Treg specific knock-out of Gata3 vs. their littermate controls were analyzed to gain insight into Gata3 dependendent genes in Treg cells.

Standard name | GSE39864_WT_VS_GATA3_KO_TREG_UP
Systematic name | M9064
Organism | Mus musculus
PMID | 22922362
Authors | Rudra D,deRoos P,Chaudhry A,Niec RE,Arvey A,Samstein RM,Leslie C,Shaffer SA,Goodlett DR,Rudensky AY
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg cells: wildtype versus GATA3 [GeneID=2625] knockout.
Full description | The transcription factor Foxp3 is indispensible for the differentiation and function of regulatory T cells (Treg cells). To gain insights into the molecular mechanisms of Foxp3 mediated gene expression we purified Foxp3 complexes and explored their composition. Biochemical and mass-spectrometric analyses revealed that Foxp3 forms multi-protein complexes of 400-800 kDa or larger and identified 361 associated proteins ~30% of which are transcription-related. Foxp3 directly regulates expression of a large proportion of the genes encoding its co-factors. Reciprocally, some transcription factor partners of Foxp3 facilitate its expression. Functional analysis of Foxp3 cooperation with one such partner, Gata3, provided further evidence for a network of transcriptional regulation afforded by Foxp3 and its associates to control distinct aspects of Treg cell biology. Gene expression profile of Treg specific knock-out of Gata3 vs. their littermate controls were analyzed to gain insight into Gata3 dependendent genes in Treg cells.

Standard name | GSE39152_SPLEEN_CD103_NEG_VS_BRAIN_CD103_POS_MEMORY_CD8_TCELL_DN
Systematic name | M9067
Organism | Mus musculus
PMID | 22922816
Authors | Wakim LM,Woodward-Davis A,Liu R,Hu Y,Villadangos J,Smyth G,Bevan MJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in memory CD8 T cells: ITGAE- [GeneID=3682] from spleen versus ITGAE+ [GeneID=3682] from brain.
Full description | Tissue resident memory (Trm) represent a newly described memory T cell population. We have previously characterized a population of Trm that persists within the brain following acute virus infection. Although capable of providing marked protection against a subsequent local challenge, brain Trm do not undergo recall expansion following dissociation from the tissue. Furthermore, these Trm do not depend on the same survival factors as the circulating memory T cell pool as assessed either in vivo or in vitro. To gain greater insight into this population of cells we compared the gene-expression profiles of Trm isolated from the brain to circulating memory T cells isolated from the spleen following an acute virus infection. Trm displayed altered expression of genes involved in chemotaxis, expressed a distinct set of transcription factors and overexpressed several inhibitory receptors. Cumulatively, these data indicates that Trm are a distinct memory T cell population disconnected from the circulating memory T cell pool and displaying a unique molecular signature which likely results in optimal survival and function within their local environment.

Standard name | GSE39152_BRAIN_VS_SPLEEN_CD103_NEG_MEMORY_CD8_TCELL_DN
Systematic name | M9071
Organism | Mus musculus
PMID | 22922816
Authors | Wakim LM,Woodward-Davis A,Liu R,Hu Y,Villadangos J,Smyth G,Bevan MJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in memory CD8 T cells, ITGAE- [GeneID=3682] population: brain versus spleen sources.
Full description | Tissue resident memory (Trm) represent a newly described memory T cell population. We have previously characterized a population of Trm that persists within the brain following acute virus infection. Although capable of providing marked protection against a subsequent local challenge, brain Trm do not undergo recall expansion following dissociation from the tissue. Furthermore, these Trm do not depend on the same survival factors as the circulating memory T cell pool as assessed either in vivo or in vitro. To gain greater insight into this population of cells we compared the gene-expression profiles of Trm isolated from the brain to circulating memory T cells isolated from the spleen following an acute virus infection. Trm displayed altered expression of genes involved in chemotaxis, expressed a distinct set of transcription factors and overexpressed several inhibitory receptors. Cumulatively, these data indicates that Trm are a distinct memory T cell population disconnected from the circulating memory T cell pool and displaying a unique molecular signature which likely results in optimal survival and function within their local environment.

Standard name | GSE39152_CD103_NEG_VS_POS_MEMORY_CD8_TCELL_UP
Systematic name | M9073
Organism | Mus musculus
PMID | 22922816
Authors | Wakim LM,Woodward-Davis A,Liu R,Hu Y,Villadangos J,Smyth G,Bevan MJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in memory CD8 T cells from brain: ITGAE- [GeneID=3682] versus ITGAE+ [GeneID=3682].
Full description | Tissue resident memory (Trm) represent a newly described memory T cell population. We have previously characterized a population of Trm that persists within the brain following acute virus infection. Although capable of providing marked protection against a subsequent local challenge, brain Trm do not undergo recall expansion following dissociation from the tissue. Furthermore, these Trm do not depend on the same survival factors as the circulating memory T cell pool as assessed either in vivo or in vitro. To gain greater insight into this population of cells we compared the gene-expression profiles of Trm isolated from the brain to circulating memory T cells isolated from the spleen following an acute virus infection. Trm displayed altered expression of genes involved in chemotaxis, expressed a distinct set of transcription factors and overexpressed several inhibitory receptors. Cumulatively, these data indicates that Trm are a distinct memory T cell population disconnected from the circulating memory T cell pool and displaying a unique molecular signature which likely results in optimal survival and function within their local environment.

Standard name | GSE39152_CD103_NEG_VS_POS_MEMORY_CD8_TCELL_DN
Systematic name | M9074
Organism | Mus musculus
PMID | 22922816
Authors | Wakim LM,Woodward-Davis A,Liu R,Hu Y,Villadangos J,Smyth G,Bevan MJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in memory CD8 T cells from brain: ITGAE- [GeneID=3682] versus ITGAE+ [GeneID=3682].
Full description | Tissue resident memory (Trm) represent a newly described memory T cell population. We have previously characterized a population of Trm that persists within the brain following acute virus infection. Although capable of providing marked protection against a subsequent local challenge, brain Trm do not undergo recall expansion following dissociation from the tissue. Furthermore, these Trm do not depend on the same survival factors as the circulating memory T cell pool as assessed either in vivo or in vitro. To gain greater insight into this population of cells we compared the gene-expression profiles of Trm isolated from the brain to circulating memory T cells isolated from the spleen following an acute virus infection. Trm displayed altered expression of genes involved in chemotaxis, expressed a distinct set of transcription factors and overexpressed several inhibitory receptors. Cumulatively, these data indicates that Trm are a distinct memory T cell population disconnected from the circulating memory T cell pool and displaying a unique molecular signature which likely results in optimal survival and function within their local environment.

Standard name | GSE39152_BRAIN_VS_SPLEEN_CD103_NEG_MEMORY_CD8_TCELL_UP
Systematic name | M9075
Organism | Mus musculus
PMID | 22922816
Authors | Wakim LM,Woodward-Davis A,Liu R,Hu Y,Villadangos J,Smyth G,Bevan MJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in memory CD8 T cells, ITGAE- [GeneID=3682] population: brain versus spleen sources.
Full description | Tissue resident memory (Trm) represent a newly described memory T cell population. We have previously characterized a population of Trm that persists within the brain following acute virus infection. Although capable of providing marked protection against a subsequent local challenge, brain Trm do not undergo recall expansion following dissociation from the tissue. Furthermore, these Trm do not depend on the same survival factors as the circulating memory T cell pool as assessed either in vivo or in vitro. To gain greater insight into this population of cells we compared the gene-expression profiles of Trm isolated from the brain to circulating memory T cells isolated from the spleen following an acute virus infection. Trm displayed altered expression of genes involved in chemotaxis, expressed a distinct set of transcription factors and overexpressed several inhibitory receptors. Cumulatively, these data indicates that Trm are a distinct memory T cell population disconnected from the circulating memory T cell pool and displaying a unique molecular signature which likely results in optimal survival and function within their local environment.

Standard name | GSE39152_SPLEEN_CD103_NEG_VS_BRAIN_CD103_POS_MEMORY_CD8_TCELL_UP
Systematic name | M9076
Organism | Mus musculus
PMID | 22922816
Authors | Wakim LM,Woodward-Davis A,Liu R,Hu Y,Villadangos J,Smyth G,Bevan MJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in memory CD8 T cells: ITGAE- [GeneID=3682] from spleen versus ITGAE+ [GeneID=3682] from brain.
Full description | Tissue resident memory (Trm) represent a newly described memory T cell population. We have previously characterized a population of Trm that persists within the brain following acute virus infection. Although capable of providing marked protection against a subsequent local challenge, brain Trm do not undergo recall expansion following dissociation from the tissue. Furthermore, these Trm do not depend on the same survival factors as the circulating memory T cell pool as assessed either in vivo or in vitro. To gain greater insight into this population of cells we compared the gene-expression profiles of Trm isolated from the brain to circulating memory T cells isolated from the spleen following an acute virus infection. Trm displayed altered expression of genes involved in chemotaxis, expressed a distinct set of transcription factors and overexpressed several inhibitory receptors. Cumulatively, these data indicates that Trm are a distinct memory T cell population disconnected from the circulating memory T cell pool and displaying a unique molecular signature which likely results in optimal survival and function within their local environment.

Standard name | GSE35685_CD34POS_CD38NEG_VS_CD34POS_CD10POS_BONE_MARROW_UP
Systematic name | M9077
Organism | Homo sapiens
PMID | 22941246
Authors | Kohn LA,Hao QL,Sasidharan R,Parekh C,Ge S,Zhu Y,Mikkola HK,Crooks GM
Category | C7
Sub-category |
Brief description | Genes up-regulated in the bone marrow CD34+ [GeneID=947] cells: CD38- [GeneID=952] versus MME+ [GeneID=4311].
Full description | Studies of adult human hematopoiesis have until now relied on the expression of CD10 to define lymphoid commitment. We report a novel lymphoid-primed population in human bone marrow that is generated from hematopoietic stem cells (HSC) prior to the onset of CD10 expression and B cell commitment, and is identified by high levels of the homing molecule L-selectin (CD62L). CD10-CD62Lhi progenitors have full lymphoid (B/T/NK) potential, and show reduced myeloid and absent erythroid potential. Genome-wide gene expression analysis demonstrates that the CD10-CD62Lhi population represents an intermediate stage of differentiation between CD34+CD38- HSC and CD34+lin-CD10+ progenitors marked by down-regulation of TAL1 and MPL, upregulation of E2A, CD3E and IL2RG expression, and absent B cell commitment or RAG1/2 expression. Immature CD34+CD1a- thymocytes are also CD62Lhi and L-selectin ligands are expressed at the cortico-medullary junction, suggesting a possible role for L-selectin in human thymic homing. These studies identify the earliest stage of lymphoid priming in human bone marrow.

Standard name | GSE35685_CD34POS_CD38NEG_VS_CD34POS_CD10POS_BONE_MARROW_DN
Systematic name | M9079
Organism | Homo sapiens
PMID | 22941246
Authors | Kohn LA,Hao QL,Sasidharan R,Parekh C,Ge S,Zhu Y,Mikkola HK,Crooks GM
Category | C7
Sub-category |
Brief description | Genes down-regulated in the bone marrow CD34+ [GeneID=947] cells: CD38- [GeneID=952] versus MME+ [GeneID=4311].
Full description | Studies of adult human hematopoiesis have until now relied on the expression of CD10 to define lymphoid commitment. We report a novel lymphoid-primed population in human bone marrow that is generated from hematopoietic stem cells (HSC) prior to the onset of CD10 expression and B cell commitment, and is identified by high levels of the homing molecule L-selectin (CD62L). CD10-CD62Lhi progenitors have full lymphoid (B/T/NK) potential, and show reduced myeloid and absent erythroid potential. Genome-wide gene expression analysis demonstrates that the CD10-CD62Lhi population represents an intermediate stage of differentiation between CD34+CD38- HSC and CD34+lin-CD10+ progenitors marked by down-regulation of TAL1 and MPL, upregulation of E2A, CD3E and IL2RG expression, and absent B cell commitment or RAG1/2 expression. Immature CD34+CD1a- thymocytes are also CD62Lhi and L-selectin ligands are expressed at the cortico-medullary junction, suggesting a possible role for L-selectin in human thymic homing. These studies identify the earliest stage of lymphoid priming in human bone marrow.

Standard name | GSE35685_CD34POS_CD10NEG_CD62LPOS_VS_CD34POS_CD10POS_BONE_MARROW_UP
Systematic name | M9080
Organism | Homo sapiens
PMID | 22941246
Authors | Kohn LA,Hao QL,Sasidharan R,Parekh C,Ge S,Zhu Y,Mikkola HK,Crooks GM
Category | C7
Sub-category |
Brief description | Genes up-regulated in the bone marrow CD34+ [GeneID=947] cells: MME- SELL+[GeneID=4311;6402] versus MME+ [GeneID=4311].
Full description | Studies of adult human hematopoiesis have until now relied on the expression of CD10 to define lymphoid commitment. We report a novel lymphoid-primed population in human bone marrow that is generated from hematopoietic stem cells (HSC) prior to the onset of CD10 expression and B cell commitment, and is identified by high levels of the homing molecule L-selectin (CD62L). CD10-CD62Lhi progenitors have full lymphoid (B/T/NK) potential, and show reduced myeloid and absent erythroid potential. Genome-wide gene expression analysis demonstrates that the CD10-CD62Lhi population represents an intermediate stage of differentiation between CD34+CD38- HSC and CD34+lin-CD10+ progenitors marked by down-regulation of TAL1 and MPL, upregulation of E2A, CD3E and IL2RG expression, and absent B cell commitment or RAG1/2 expression. Immature CD34+CD1a- thymocytes are also CD62Lhi and L-selectin ligands are expressed at the cortico-medullary junction, suggesting a possible role for L-selectin in human thymic homing. These studies identify the earliest stage of lymphoid priming in human bone marrow.

Standard name | GSE35685_CD34POS_CD10NEG_CD62LPOS_VS_CD34POS_CD10POS_BONE_MARROW_DN
Systematic name | M9081
Organism | Homo sapiens
PMID | 22941246
Authors | Kohn LA,Hao QL,Sasidharan R,Parekh C,Ge S,Zhu Y,Mikkola HK,Crooks GM
Category | C7
Sub-category |
Brief description | Genes down-regulated in the bone marrow CD34+ [GeneID=947] cells: MME- SELL+[GeneID=4311;6402] versus MME+ [GeneID=4311].
Full description | Studies of adult human hematopoiesis have until now relied on the expression of CD10 to define lymphoid commitment. We report a novel lymphoid-primed population in human bone marrow that is generated from hematopoietic stem cells (HSC) prior to the onset of CD10 expression and B cell commitment, and is identified by high levels of the homing molecule L-selectin (CD62L). CD10-CD62Lhi progenitors have full lymphoid (B/T/NK) potential, and show reduced myeloid and absent erythroid potential. Genome-wide gene expression analysis demonstrates that the CD10-CD62Lhi population represents an intermediate stage of differentiation between CD34+CD38- HSC and CD34+lin-CD10+ progenitors marked by down-regulation of TAL1 and MPL, upregulation of E2A, CD3E and IL2RG expression, and absent B cell commitment or RAG1/2 expression. Immature CD34+CD1a- thymocytes are also CD62Lhi and L-selectin ligands are expressed at the cortico-medullary junction, suggesting a possible role for L-selectin in human thymic homing. These studies identify the earliest stage of lymphoid priming in human bone marrow.

Standard name | GSE35685_CD34POS_CD38NEG_VS_CD34POS_CD10NEG_CD62LPOS_BONE_MARROW_UP
Systematic name | M9083
Organism | Homo sapiens
PMID | 22941246
Authors | Kohn LA,Hao QL,Sasidharan R,Parekh C,Ge S,Zhu Y,Mikkola HK,Crooks GM
Category | C7
Sub-category |
Brief description | Genes up-regulated in the bone marrow CD34+ [GeneID=947] cells: CD38- [GeneID=952] versus MME- SELL+ [GeneID=4311;6402].
Full description | Studies of adult human hematopoiesis have until now relied on the expression of CD10 to define lymphoid commitment. We report a novel lymphoid-primed population in human bone marrow that is generated from hematopoietic stem cells (HSC) prior to the onset of CD10 expression and B cell commitment, and is identified by high levels of the homing molecule L-selectin (CD62L). CD10-CD62Lhi progenitors have full lymphoid (B/T/NK) potential, and show reduced myeloid and absent erythroid potential. Genome-wide gene expression analysis demonstrates that the CD10-CD62Lhi population represents an intermediate stage of differentiation between CD34+CD38- HSC and CD34+lin-CD10+ progenitors marked by down-regulation of TAL1 and MPL, upregulation of E2A, CD3E and IL2RG expression, and absent B cell commitment or RAG1/2 expression. Immature CD34+CD1a- thymocytes are also CD62Lhi and L-selectin ligands are expressed at the cortico-medullary junction, suggesting a possible role for L-selectin in human thymic homing. These studies identify the earliest stage of lymphoid priming in human bone marrow.

Standard name | GSE35685_CD34POS_CD38NEG_VS_CD34POS_CD10NEG_CD62LPOS_BONE_MARROW_DN
Systematic name | M9084
Organism | Homo sapiens
PMID | 22941246
Authors | Kohn LA,Hao QL,Sasidharan R,Parekh C,Ge S,Zhu Y,Mikkola HK,Crooks GM
Category | C7
Sub-category |
Brief description | Genes down-regulated in the bone marrow CD34+ [GeneID=947] cells: CD38- [GeneID=952] versus MME- SELL+ [GeneID=4311;6402].
Full description | Studies of adult human hematopoiesis have until now relied on the expression of CD10 to define lymphoid commitment. We report a novel lymphoid-primed population in human bone marrow that is generated from hematopoietic stem cells (HSC) prior to the onset of CD10 expression and B cell commitment, and is identified by high levels of the homing molecule L-selectin (CD62L). CD10-CD62Lhi progenitors have full lymphoid (B/T/NK) potential, and show reduced myeloid and absent erythroid potential. Genome-wide gene expression analysis demonstrates that the CD10-CD62Lhi population represents an intermediate stage of differentiation between CD34+CD38- HSC and CD34+lin-CD10+ progenitors marked by down-regulation of TAL1 and MPL, upregulation of E2A, CD3E and IL2RG expression, and absent B cell commitment or RAG1/2 expression. Immature CD34+CD1a- thymocytes are also CD62Lhi and L-selectin ligands are expressed at the cortico-medullary junction, suggesting a possible role for L-selectin in human thymic homing. These studies identify the earliest stage of lymphoid priming in human bone marrow.

Standard name | GSE40274_CTRL_VS_IRF4_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9085
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of IRF4 [GeneID=3662].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_IRF4_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9086
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of IRF4 [GeneID=3662].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_SATB1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9087
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of SATB1 [GeneID=6304].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_SATB1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9089
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of SATB1 [GeneID=6304].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_LEF1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9090
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of LEF1 [GeneID=51176].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_LEF1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9091
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of LEF1 [GeneID=51176].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_XBP1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9092
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of XBP1 [GeneID=7494].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_XBP1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9094
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of XBP1 [GeneID=7494].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_GATA1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9095
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of GATA1 [GeneID=2623].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_GATA1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9099
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of GATA1 [GeneID=2623].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_HELIOS_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9100
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of IKZF2 [GeneID=22807].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_HELIOS_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9101
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of IKZF2 [GeneID=22807].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_EOS_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9102
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of IKZF4 and FOXP3 [GeneID=64375;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_EOS_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9104
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of IKZF4 and FOXP3 [GeneID=64375;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_PBX1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9105
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of PBX1 and FOXP3 [GeneID=5087;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_PBX1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9106
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of PBX1 and FOXP3 [GeneID=5087;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_GATA1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9107
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of GATA1 and FOXP3 [GeneID=2623;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_GATA1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9108
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of GATA1 and FOXP3 [GeneID=2623;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_LEF1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9109
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of LEF1 and FOXP3 [GeneID=51176;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_LEF1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9110
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of LEF1 and FOXP3 [GeneID=51176;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_IRF4_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9111
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of IRF4 and FOXP3 [GeneID=3662;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_IRF4_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9113
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of IRF4 and FOXP3 [GeneID=3662;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_SATB1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9114
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of SATB1 and FOXP3 [GeneID=6304;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_SATB1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9115
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of SATB1 and FOXP3 [GeneID=6304;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_XBP1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9116
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of XBP1 and FOXP3 [GeneID=7494;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_XBP1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9117
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of XBP1 and FOXP3 [GeneID=7494;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_HELIOS_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9119
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of IKZF2 and FOXP3 [GeneID=22807;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_AND_HELIOS_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9120
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of IKZF2 and FOXP3 [GeneID=22807;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_EOS_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9121
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus IKZF4 and FOXP3 [GeneID=64375;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_EOS_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9122
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus IKZF4 and FOXP3 [GeneID=64375;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40273_XBP1_KO_VS_WT_TREG_UP
Systematic name | M9123
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: XBP1 [GeneID=7494] knockout versus wildtype.
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40273_XBP1_KO_VS_WT_TREG_DN
Systematic name | M9124
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: XBP1 [GeneID=7494] knockout versus wildtype.
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40273_EOS_KO_VS_WT_TREG_UP
Systematic name | M9127
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: IKZF4 [GeneID=64375] versus wildtype.
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40273_EOS_KO_VS_WT_TREG_DN
Systematic name | M9130
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: IKZF4 [GeneID=64375] versus wildtype.
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40273_GATA1_KO_VS_WT_TREG_UP
Systematic name | M9132
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: GATA1 [GeneID=2623] knockout versus wildtype.
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40273_GATA1_KO_VS_WT_TREG_DN
Systematic name | M9133
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: GATA1 [GeneID=2623] knockout versus wildtype.
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9135
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of FOXP3 [GeneID=50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_FOXP3_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9136
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of FOXP3 [GeneID=50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_EOS_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9137
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv: control versus over-expression of IKZF4 [GeneID=64375].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_CTRL_VS_EOS_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9139
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv: control versus over-expression of IKZF4 [GeneID=64375].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_SATB1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9141
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus SATB1 and FOXP3 [GeneID=6304;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_SATB1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9145
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus SATB1 and FOXP3 [GeneID=6304;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_XBP1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9146
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus XBP1 and FOXP3 [GeneID=7494;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_XBP1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9147
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus XBP1 and FOXP3 [GeneID=7494;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_HELIOS_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9148
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus IKZF2 and FOXP3 [GeneID=22807;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_HELIOS_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9149
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus IKZF2 and FOXP3 [GeneID=22807;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_EOS_VS_FOXP3_AND_EOS_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9151
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing: IKZF4 [GeneID=64375] versus IKZF4 and FOXP3 [GeneID=64375;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_EOS_VS_FOXP3_AND_EOS_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9153
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing: IKZF4 [GeneID=64375] versus IKZF4 and FOXP3 [GeneID=64375;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_IRF4_VS_FOXP3_AND_IRF4_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9154
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing: IRF4 [GeneID=3662] versus IRF4 and FOXP3 [GeneID=3662;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_IRF4_VS_FOXP3_AND_IRF4_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9155
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing: IRF4 [GeneID=3662] versus IRF4 and FOXP3 [GeneID=3662;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_SATB1_VS_FOXP3_AND_SATB1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9156
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing SATB1 [GeneID=6304] versus SATB1 and FOX3P [GeneID=6304;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_SATB1_VS_FOXP3_AND_SATB1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9157
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing SATB1 [GeneID=6304] versus SATB1 and FOX3P [GeneID=6304;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_LEF1_VS_FOXP3_AND_LEF1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9158
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing LEF1 [GeneID=51176] versus LEF1 and FOX3P [GeneID=51176;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_LEF1_VS_FOXP3_AND_LEF1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9159
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing LEF1 [GeneID=51176] versus LEF1 and FOX3P [GeneID=51176;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_XBP1_VS_FOXP3_AND_XBP1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9161
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing XBP1 [GeneID=7494] versus XBP1 and FOX3P [GeneID=7494;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_XBP1_VS_FOXP3_AND_XBP1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9163
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing XBP1 [GeneID=7494] versus XBP1 and FOX3P [GeneID=7494;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_GATA1_VS_FOXP3_AND_GATA1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9164
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing GATA1 [GeneID=2623] versus GATA1 and FOX3P [GeneID=2623;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_GATA1_VS_FOXP3_AND_GATA1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9165
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing GATA1 [GeneID=2623] versus GATA1 and FOX3P [GeneID=2623;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_HELIOS_VS_FOXP3_AND_HELIOS_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9166
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing IKZF2 [GeneID=22807] versus IKZF2 and FOX3P [GeneID=22807;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_HELIOS_VS_FOXP3_AND_HELIOS_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9168
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing IKZF2 [GeneID=22807] versus IKZF2 and FOX3P [GeneID=22807;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40277_EOS_AND_LEF1_TRANSDUCED_VS_GATA1_AND_SATB1_TRANSDUCED_CD4_TCELL_UP
Systematic name | M9169
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T conv over-expressing: IKZF4 and LEF1 [GeneID=64375;52276] versus GATA1 and SATB1 [GeneID=6304] versus GATA1 and SATB1 [GeneID=6304;2623].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40277_EOS_AND_LEF1_TRANSDUCED_VS_GATA1_AND_SATB1_TRANSDUCED_CD4_TCELL_DN
Systematic name | M9170
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T conv over-expressing: IKZF4 and LEF1 [GeneID=64375;52276] versus GATA1 and SATB1 [GeneID=6304] versus GATA1 and SATB1 [GeneID=6304;2623].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40277_EOS_AND_LEF1_TRANSDUCED_VS_CTRL_CD4_TCELL_UP
Systematic name | M9171
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T conv: over-expressing IKZF4 and LEF1 [GeneID=64375;52276] versus control.
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40277_EOS_AND_LEF1_TRANSDUCED_VS_CTRL_CD4_TCELL_DN
Systematic name | M9173
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T conv: over-expressing IKZF4 and LEF1 [GeneID=64375;52276] versus control.
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40277_GATA1_AND_SATB1_TRANSDUCED_VS_CTRL_CD4_TCELL_UP
Systematic name | M9175
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T conv over-expressing: GATA1 and SATB1 [GeneID=6304;2623] versus control.
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40277_GATA1_AND_SATB1_TRANSDUCED_VS_CTRL_CD4_TCELL_DN
Systematic name | M9178
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T conv over-expressing: GATA1 and SATB1 [GeneID=6304;2623] versus control.
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_IRF4_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9179
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus IRF4 and FOXP3 [GeneID=3662;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_GATA1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9180
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing FOXP3 [GeneID=50943] versus GATA1 and FOXP3 [GeneID=2623;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_PBX1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9181
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus PBX1 and FOXP3 [GeneID=5087;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_PBX1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9184
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus PBX1 and FOXP3 [GeneID=5087;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_GATA1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9186
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing FOXP3 [GeneID=50943] versus GATA1 and FOXP3 [GeneID=2623;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_LEF1_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9187
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus LEF1 and FOXP3 [GeneID=51176;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_LEF1_TRANSDUCED_ACTIVATED_CD4_TCELL_DN
Systematic name | M9188
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus LEF1 and FOXP3 [GeneID=51176;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40274_FOXP3_VS_FOXP3_AND_IRF4_TRANSDUCED_ACTIVATED_CD4_TCELL_UP
Systematic name | M9190
Organism | Mus musculus
PMID | 22961053
Authors | Fu W,Ergun A,Lu T,Hill JA,Haxhinasto S,Fassett MS,Gazit R,Adoro S,Glimcher L,Chan S,Kastner P,Rossi D,Collins JJ,Mathis D,Benoist C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 T conv over-expressing: FOXP3 [GeneID=50943] versus IRF4 and FOXP3 [GeneID=3662;50943].
Full description | The transcription factor FoxP3 partakes dominantly in the specification and function of FoxP3+ CD4+ T regulatory cells (Tregs), but is neither strictly necessary nor sufficient to determine the characteristic Treg transcriptional signature. Computational network inference and experimental testing assessed the contribution of several other transcription factors (TFs). Enforced expression of Helios or Xbp1 elicited specific signatures, but Eos, Irf4, Satb1, Lef1 and Gata1 elicited exactly the same outcome, synergizing with FoxP3 to activate most of the Treg signature, including key TFs, and enhancing FoxP3 occupancy at its genomic targets. Conversely, the Treg signature was robust to inactivation of any single cofactor. A redundant genetic switch thus locks-in the Treg phenotype, a model which accounts for several aspects of Treg physiology, differentiation and stability.

Standard name | GSE40441_NRP1_POS_INDUCED_TREG_VS_NRP1_NEG_NATURAL_TREG_DN
Systematic name | M9195
Organism | Mus musculus
PMID | 22966001
Authors | Weiss JM,Bilate AM,Gobert M,Ding Y,Lafaille de Curotto MA,Parkhurst CN,Xiong H,Dolpady J,Frey AB,Ruocco MG,Yang Y,Floess S,Huehn J,Oh S,Li MO,Niec RE,Rudensky AY,Dustin ML,Littman DR,Lafaille JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: NRP1+ [GeneID=8829] versus NRP1- [GeneID=8829].
Full description | To compare subpopulations of Treg cells in wild type mice based upon Nrp1 Expression, differentiating nTreg and iTreg

Standard name | GSE40441_NRP1_POS_INDUCED_TREG_VS_NRP1_NEG_NATURAL_TREG_UP
Systematic name | M9196
Organism | Mus musculus
PMID | 22966001
Authors | Weiss JM,Bilate AM,Gobert M,Ding Y,Lafaille de Curotto MA,Parkhurst CN,Xiong H,Dolpady J,Frey AB,Ruocco MG,Yang Y,Floess S,Huehn J,Oh S,Li MO,Niec RE,Rudensky AY,Dustin ML,Littman DR,Lafaille JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: NRP1+ [GeneID=8829] versus NRP1- [GeneID=8829].
Full description | To compare subpopulations of Treg cells in wild type mice based upon Nrp1 Expression, differentiating nTreg and iTreg

Standard name | GSE40443_INDUCED_VS_TOTAL_TREG_UP
Systematic name | M9198
Organism | Mus musculus
PMID | 22966001
Authors | Weiss JM,Bilate AM,Gobert M,Ding Y,Lafaille de Curotto MA,Parkhurst CN,Xiong H,Dolpady J,Frey AB,Ruocco MG,Yang Y,Floess S,Huehn J,Oh S,Li MO,Niec RE,Rudensky AY,Dustin ML,Littman DR,Lafaille JJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: induced versus total.
Full description | iTreg cells from Tbmc mLN mice treated with one week of 1% Oral Ova were compared to Total Treg from WT mice.

Standard name | GSE40443_INDUCED_VS_TOTAL_TREG_DN
Systematic name | M9201
Organism | Mus musculus
PMID | 22966001
Authors | Weiss JM,Bilate AM,Gobert M,Ding Y,Lafaille de Curotto MA,Parkhurst CN,Xiong H,Dolpady J,Frey AB,Ruocco MG,Yang Y,Floess S,Huehn J,Oh S,Li MO,Niec RE,Rudensky AY,Dustin ML,Littman DR,Lafaille JJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: induced versus total.
Full description | iTreg cells from Tbmc mLN mice treated with one week of 1% Oral Ova were compared to Total Treg from WT mice.

Standard name | GSE40666_NAIVE_VS_EFFECTOR_CD8_TCELL_UP
Systematic name | M9203
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus day 8 after LCMV infection.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_NAIVE_VS_EFFECTOR_CD8_TCELL_DN
Systematic name | M9204
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus day 8 after LCMV infection.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_WT_VS_STAT1_KO_CD8_TCELL_UP
Systematic name | M9205
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: wildtype versus STAT1 [GeneID=6772] knockout.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_WT_VS_STAT1_KO_CD8_TCELL_DN
Systematic name | M9207
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: wildtype versus STAT1 [GeneID=6772] knockout.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_NAIVE_VS_EFFECTOR_CD8_TCELL_WITH_IFNA_STIM_90MIN_UP
Systematic name | M9208
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells treated by interferon alpha: naïve versus day 8 after LCMV infection.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_NAIVE_VS_EFFECTOR_CD8_TCELL_WITH_IFNA_STIM_90MIN_DN
Systematic name | M9211
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells treated by interferon alpha: naïve versus day 8 after LCMV infection.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_WT_VS_STAT1_KO_CD8_TCELL_WITH_IFNA_STIM_90MIN_UP
Systematic name | M9214
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells treated by interferon alpha: STAT1 [GeneID=6772] knockout versus STAT4 [GeneID=6775].
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_WT_VS_STAT1_KO_CD8_TCELL_WITH_IFNA_STIM_90MIN_DN
Systematic name | M9215
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells treated by interferon alpha: STAT1 [GeneID=6772] knockout versus STAT4 [GeneID=6775].
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_WT_VS_STAT4_KO_CD8_TCELL_WITH_IFNA_STIM_90MIN_UP
Systematic name | M9216
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells treated by inteferon alpha: wildtype versus STAT4 [GeneID=6775] knockout.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_WT_VS_STAT4_KO_CD8_TCELL_WITH_IFNA_STIM_90MIN_DN
Systematic name | M9217
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells treated by inteferon alpha: wildtype versus STAT4 [GeneID=6775] knockout.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_STAT1_KO_VS_STAT4_KO_CD8_TCELL_WITH_IFNA_STIM_90MIN_UP
Systematic name | M9218
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells treated by interferon alpha: STAT1 [GeneID=6772] knockout versus STAT4 [GeneID=6775].
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_STAT1_KO_VS_STAT4_KO_CD8_TCELL_WITH_IFNA_STIM_90MIN_DN
Systematic name | M9219
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells treated by interferon alpha: STAT1 [GeneID=6772] knockout versus STAT4 [GeneID=6775].
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_STAT1_KO_VS_STAT4_KO_CD8_TCELL_UP
Systematic name | M9220
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: STAT1 [GeneID=6772] knockout versus STAT4 [GeneID=6775] knockout.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_STAT1_KO_VS_STAT4_KO_CD8_TCELL_DN
Systematic name | M9222
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: STAT1 [GeneID=6772] knockout versus STAT4 [GeneID=6775] knockout.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_WT_VS_STAT4_KO_CD8_TCELL_DN
Systematic name | M9223
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: wildtype versus STAT4 [GeneID=6775] knockout.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_UNTREATED_VS_IFNA_STIM_CD8_TCELL_90MIN_UP
Systematic name | M9225
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: untreated versus interferon alpha.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_UNTREATED_VS_IFNA_STIM_CD8_TCELL_90MIN_DN
Systematic name | M9227
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: untreated versus interferon alpha.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_WT_VS_STAT4_KO_CD8_TCELL_UP
Systematic name | M9228
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: wildtype versus STAT4 [GeneID=6775] knockout.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_UNTREATED_VS_IFNA_STIM_EFFECTOR_CD8_TCELL_90MIN_DN
Systematic name | M9229
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells at day 8 after LCMV infection: untreated versus interferon alpha.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_UNTREATED_VS_IFNA_STIM_STAT1_KO_CD8_TCELL_90MIN_UP
Systematic name | M9233
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells with STAT1 [GeneID=6772]: untreated versus interferon alpha.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_UNTREATED_VS_IFNA_STIM_STAT1_KO_CD8_TCELL_90MIN_DN
Systematic name | M9234
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells with STAT1 [GeneID=6772]: untreated versus interferon alpha.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_UNTREATED_VS_IFNA_STIM_EFFECTOR_CD8_TCELL_90MIN_UP
Systematic name | M9235
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells at day 8 after LCMV infection: untreated versus interferon alpha.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_UNTREATED_VS_IFNA_STIM_STAT4_KO_EFFECTOR_CD8_TCELL_90MIN_DN
Systematic name | M9236
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells with STAT4 [GeneID=6775]: untreated versus interferon alpha.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40666_UNTREATED_VS_IFNA_STIM_STAT4_KO_EFFECTOR_CD8_TCELL_90MIN_UP
Systematic name | M9237
Organism | Mus musculus
PMID | 22968462
Authors | Gil MP,Ploquin MJ,Watford WT,Lee SH,Kim K,Wang X,Kanno Y,O'Shea JJ,Biron CA
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells with STAT4 [GeneID=6775]: untreated versus interferon alpha.
Full description | Type 1 IFNs can conditionally activate all of the signal transducers and activators of transcription molecules (STATs), including STAT4. The best-characterized signaling pathways use STAT1, however, and type 1 IFN inhibition of cell proliferation is STAT1 dependent. We report that type 1 IFNs can basally stimulate STAT1- and STAT4- dependent effects in CD8 T cells, but that CD8 T cells responding to infections of mice with lymphocytic choriomenigitis virus have elevated STAT4 and lower STAT1 expression with significant consequences for modifying the effects of type 1 IFN exposure. The phenotype was associated with preferential type 1 IFN activation of STAT4 as compared to STAT1. Stimulation through the TCR induced elevated STAT4 expression, and STAT4 was required for peak expansion of antigen-specific CD8 T cells, low STAT1 levels, and resistance to type 1 IFN-mediated inhibition of proliferation. Thus, a mechanism is discovered for regulating the consequences of type 1 IFN exposure in CD8 T cells, with STAT4 acting as a key molecule in driving optimal antigen-specific responses and overcoming STAT1-dependent inhibition of proliferation.

Standard name | GSE40225_WT_VS_RIP_B7X_DIABETIC_MOUSE_PANCREATIC_CD8_TCELL_UP
Systematic name | M9238
Organism | Mus musculus
PMID | 22972920
Authors | Lee JS,Scandiuzzi L,Ray A,Wei J,Hofmeyer KA,Abadi YM,Loke P,Lin J,Yuan J,Serreze DV,Allison JP,Zang X
Category | C7
Sub-category |
Brief description | Genes up-regulated in pancreatic CD8 T cells from mice with: type 1 diabetes mellitus versus healthy controls.
Full description | B7x (B7-H4 or B7S1) is the seventh member of the B7 family and the in vivo function remains largely unknown. Despite new genetic data linking the B7x gene with autoimmune diseases, how exactly it contributes to peripheral tolerance and autoimmunity is unclear. Here we showed that B7x protein was not detected on antigen-presenting cells or T cells in both human and mice, which is unique in the B7 family. As B7x protein is expressed in some peripheral cells such as pancreatic b cells, we utilized a CD8 T cell-mediated diabetes model (AI4ab) in which CD8 T cells recognize an endogenous self-antigen, and found that mice lacking B7x developed more severe diabetes than control AI4ab mice. Conversely, mice overexpressing B7x in the b cells (Rip-B7xAI4ab) were diabetes free. Furthermore, adoptive transfer of effector AI4ab CD8 T cells induced diabetes in control mice, but not in Rip-B7xAI4ab mice. Mechanistic studies revealed that pathogenic effector CD8 T cells were capable of migrating to the pancreas but failed to robustly destroy tissue when encountering local B7x in Rip-B7xAI4ab mice. Although AI4ab CD8 T cells in Rip-B7xAI4ab mice and AI4ab mice showed similar cytotoxic function, cell death, and global gene expression profiles, these cells had greater proliferation in AI4ab mice than in RIP-B7xAI4ab mice. These results suggest that B7x in nonlymphoid organs prevents peripheral autoimmunity partially through inhibiting proliferation of tissue-specific CD8 T cells and that local overexpression of B7x on pancreatic b cells is sufficient to abolish CD8 T cell-induced diabetes.

Standard name | GSE40225_WT_VS_RIP_B7X_DIABETIC_MOUSE_PANCREATIC_CD8_TCELL_DN
Systematic name | M9240
Organism | Mus musculus
PMID | 22972920
Authors | Lee JS,Scandiuzzi L,Ray A,Wei J,Hofmeyer KA,Abadi YM,Loke P,Lin J,Yuan J,Serreze DV,Allison JP,Zang X
Category | C7
Sub-category |
Brief description | Genes down-regulated in pancreatic CD8 T cells from mice with: type 1 diabetes mellitus versus healthy controls.
Full description | B7x (B7-H4 or B7S1) is the seventh member of the B7 family and the in vivo function remains largely unknown. Despite new genetic data linking the B7x gene with autoimmune diseases, how exactly it contributes to peripheral tolerance and autoimmunity is unclear. Here we showed that B7x protein was not detected on antigen-presenting cells or T cells in both human and mice, which is unique in the B7 family. As B7x protein is expressed in some peripheral cells such as pancreatic b cells, we utilized a CD8 T cell-mediated diabetes model (AI4ab) in which CD8 T cells recognize an endogenous self-antigen, and found that mice lacking B7x developed more severe diabetes than control AI4ab mice. Conversely, mice overexpressing B7x in the b cells (Rip-B7xAI4ab) were diabetes free. Furthermore, adoptive transfer of effector AI4ab CD8 T cells induced diabetes in control mice, but not in Rip-B7xAI4ab mice. Mechanistic studies revealed that pathogenic effector CD8 T cells were capable of migrating to the pancreas but failed to robustly destroy tissue when encountering local B7x in Rip-B7xAI4ab mice. Although AI4ab CD8 T cells in Rip-B7xAI4ab mice and AI4ab mice showed similar cytotoxic function, cell death, and global gene expression profiles, these cells had greater proliferation in AI4ab mice than in RIP-B7xAI4ab mice. These results suggest that B7x in nonlymphoid organs prevents peripheral autoimmunity partially through inhibiting proliferation of tissue-specific CD8 T cells and that local overexpression of B7x on pancreatic b cells is sufficient to abolish CD8 T cell-induced diabetes.

Standard name | GSE20727_DNFB_ALLERGEN_VS_ROS_INH_AND_DNFB_ALLERGEN_TREATED_DC_UP
Systematic name | M9241
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: 2,4-dinitrofluorobenzene (DNFB) [PubChem=6264] versus diphenyleneiodonium (DPI) [PubChem=2733504].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_CTRL_VS_ROS_INHIBITOR_TREATED_DC_DN
Systematic name | M9242
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: untreated versus diphenyleneiodonium (DPI) [PubChem=2733504].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_CTRL_VS_H2O2_TREATED_DC_DN
Systematic name | M9243
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: untreated versus hydrogen peroxide [PubChem=784].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_CTRL_VS_ROS_INHIBITOR_TREATED_DC_UP
Systematic name | M9244
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: untreated versus diphenyleneiodonium (DPI) [PubChem=2733504].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_CTRL_VS_H2O2_TREATED_DC_UP
Systematic name | M9245
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: untreated versus hydrogen peroxide [PubChem=784].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_CTRL_VS_ROS_INH_AND_DNFB_ALLERGEN_TREATED_DC_DN
Systematic name | M9247
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: control versus 2,4-dinitrofluorobenzene (DNFB) [PubChem=6264] and diphenyleneiodonium (DPI) [PubChem=2733504].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_ROS_INH_VS_ROS_INH_AND_DNFB_ALLERGEN_TREATED_DC_DN
Systematic name | M9248
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: diphenyleneiodonium (DPI) [PubChem=2733504] versus DPI and 2,4-dinitrofluorobenzene (DNFB) [PubChem=6264].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_CTRL_VS_DNFB_ALLERGEN_TREATED_DC_DN
Systematic name | M9249
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: untreated versus 2,4-dinitrofluorobenzene (DNFB) [PubChem=6264].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_CTRL_VS_ROS_INH_AND_DNFB_ALLERGEN_TREATED_DC_UP
Systematic name | M9250
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: control versus 2,4-dinitrofluorobenzene (DNFB) [PubChem=6264] and diphenyleneiodonium (DPI) [PubChem=2733504].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_ROS_INH_VS_ROS_INH_AND_DNFB_ALLERGEN_TREATED_DC_UP
Systematic name | M9252
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: diphenyleneiodonium (DPI) [PubChem=2733504] versus DPI and 2,4-dinitrofluorobenzene (DNFB) [PubChem=6264].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_H2O2_VS_ROS_INHIBITOR_TREATED_DC_DN
Systematic name | M9253
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: hydrogen peroxide [PubChem=784] versus diphenyleneiodonium (DPI) [PubChem=2733504].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_CTRL_VS_DNFB_ALLERGEN_TREATED_DC_UP
Systematic name | M9254
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: untreated versus 2,4-dinitrofluorobenzene (DNFB) [PubChem=6264].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_H2O2_VS_ROS_INHIBITOR_TREATED_DC_UP
Systematic name | M9255
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: hydrogen peroxide [PubChem=784] versus diphenyleneiodonium (DPI) [PubChem=2733504].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE20727_DNFB_ALLERGEN_VS_ROS_INH_AND_DNFB_ALLERGEN_TREATED_DC_DN
Systematic name | M9256
Organism | Mus musculus
PMID | 22974541
Authors | Miyazawa M,Takashima A
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: 2,4-dinitrofluorobenzene (DNFB) [PubChem=6264] versus diphenyleneiodonium (DPI) [PubChem=2733504].
Full description | Identification of ROS induced genes on dendritic cells Dendritic cells were incubated for 15 min with or without a ROS inhibitor (DPI), washed extensively and incubated for 30 min with a chemical allergen (DNFB), hydrogen peroxide, and vehicle alone in HBSS containing DPI or vehicle. After washed extensively, the samples were post-incubated for 5.5 h with DNFB, hydrogen peroxide, or vehicle in complete culture medium containing DPI or vehicle.

Standard name | GSE40068_CXCR5POS_BCL6POS_TFH_VS_CXCR5NEG_BCL6NEG_CD4_TCELL_UP
Systematic name | M9258
Organism | Mus musculus
PMID | 22987803
Authors | Liu X,Yan X,Zhong B,Nurieva RI,Wang A,Wang X,Martin-Orozco N,Wang Y,Chang SH,Esplugues E,Flavell RA,Tian Q,Dong C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CXCR5+ BCL6+ [GeneID=643;604] follicular helper T cells versus CXCR5- BCL6- CD4+ [GeneID=643;604;920] T cells.
Full description | T follicular helper (Tfh) cells play a pivotal role in germinal center reactions, which requires Bcl6 transcription factor. To analyze their relationships with other effector T cell lineages and their stability in vivo, we developed and analyzed a new Bcl6 reporter mouse alone or together with other lineage reporter systems. Assisted with genome-wide transcriptome analysis, we show substantial plasticity of T cell differentiation in the early phase of immune response. At this stage, CXCR5 appears to be expressed in a Bcl6-independent manner. Once Bcl6 is highly expressed, Tfh cells can persist in vivo and some of them develop into memory cells. Together, our results indicate Bcl6 as a bona fide marker for Tfh polarized program.

Standard name | GSE40068_BCL6_POS_VS_NEG_CXCR5_POS_TFH_UP
Systematic name | M9259
Organism | Mus musculus
PMID | 22987803
Authors | Liu X,Yan X,Zhong B,Nurieva RI,Wang A,Wang X,Martin-Orozco N,Wang Y,Chang SH,Esplugues E,Flavell RA,Tian Q,Dong C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CXCR5+ BCL6+ [GeneID=643;604] follicular helper T cells versus CXCR5+ BCL6- CD4+ [GeneID=643;604;920] T cells.
Full description | T follicular helper (Tfh) cells play a pivotal role in germinal center reactions, which requires Bcl6 transcription factor. To analyze their relationships with other effector T cell lineages and their stability in vivo, we developed and analyzed a new Bcl6 reporter mouse alone or together with other lineage reporter systems. Assisted with genome-wide transcriptome analysis, we show substantial plasticity of T cell differentiation in the early phase of immune response. At this stage, CXCR5 appears to be expressed in a Bcl6-independent manner. Once Bcl6 is highly expressed, Tfh cells can persist in vivo and some of them develop into memory cells. Together, our results indicate Bcl6 as a bona fide marker for Tfh polarized program.

Standard name | GSE40068_BCL6_POS_VS_NEG_CXCR5_POS_TFH_DN
Systematic name | M9260
Organism | Mus musculus
PMID | 22987803
Authors | Liu X,Yan X,Zhong B,Nurieva RI,Wang A,Wang X,Martin-Orozco N,Wang Y,Chang SH,Esplugues E,Flavell RA,Tian Q,Dong C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CXCR5+ BCL6+ [GeneID=643;604] follicular helper T cells versus CXCR5+ BCL6- CD4+ [GeneID=643;604;920] T cells.
Full description | T follicular helper (Tfh) cells play a pivotal role in germinal center reactions, which requires Bcl6 transcription factor. To analyze their relationships with other effector T cell lineages and their stability in vivo, we developed and analyzed a new Bcl6 reporter mouse alone or together with other lineage reporter systems. Assisted with genome-wide transcriptome analysis, we show substantial plasticity of T cell differentiation in the early phase of immune response. At this stage, CXCR5 appears to be expressed in a Bcl6-independent manner. Once Bcl6 is highly expressed, Tfh cells can persist in vivo and some of them develop into memory cells. Together, our results indicate Bcl6 as a bona fide marker for Tfh polarized program.

Standard name | GSE40068_CXCR5NEG_BCL6NEG_CD4_TCELL_VS_CXCR5POS_BCL6NEG_TFH_UP
Systematic name | M9261
Organism | Mus musculus
PMID | 22987803
Authors | Liu X,Yan X,Zhong B,Nurieva RI,Wang A,Wang X,Martin-Orozco N,Wang Y,Chang SH,Esplugues E,Flavell RA,Tian Q,Dong C
Category | C7
Sub-category |
Brief description | Genes up-regulated in CXCR5- BCL6- CD4+ [GeneID=643;604;920] T cells versus CXCR5+ BCL6- [GeneID=643;604] follicular helper T cells.
Full description | T follicular helper (Tfh) cells play a pivotal role in germinal center reactions, which requires Bcl6 transcription factor. To analyze their relationships with other effector T cell lineages and their stability in vivo, we developed and analyzed a new Bcl6 reporter mouse alone or together with other lineage reporter systems. Assisted with genome-wide transcriptome analysis, we show substantial plasticity of T cell differentiation in the early phase of immune response. At this stage, CXCR5 appears to be expressed in a Bcl6-independent manner. Once Bcl6 is highly expressed, Tfh cells can persist in vivo and some of them develop into memory cells. Together, our results indicate Bcl6 as a bona fide marker for Tfh polarized program.

Standard name | GSE40068_CXCR5POS_BCL6POS_TFH_VS_CXCR5NEG_BCL6NEG_CD4_TCELL_DN
Systematic name | M9262
Organism | Mus musculus
PMID | 22987803
Authors | Liu X,Yan X,Zhong B,Nurieva RI,Wang A,Wang X,Martin-Orozco N,Wang Y,Chang SH,Esplugues E,Flavell RA,Tian Q,Dong C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CXCR5+ BCL6+ [GeneID=643;604] follicular helper T cells versus CXCR5- BCL6- CD4+ [GeneID=643;604;920] T cells.
Full description | T follicular helper (Tfh) cells play a pivotal role in germinal center reactions, which requires Bcl6 transcription factor. To analyze their relationships with other effector T cell lineages and their stability in vivo, we developed and analyzed a new Bcl6 reporter mouse alone or together with other lineage reporter systems. Assisted with genome-wide transcriptome analysis, we show substantial plasticity of T cell differentiation in the early phase of immune response. At this stage, CXCR5 appears to be expressed in a Bcl6-independent manner. Once Bcl6 is highly expressed, Tfh cells can persist in vivo and some of them develop into memory cells. Together, our results indicate Bcl6 as a bona fide marker for Tfh polarized program.

Standard name | GSE40068_CXCR5NEG_BCL6NEG_CD4_TCELL_VS_CXCR5POS_BCL6NEG_TFH_DN
Systematic name | M9263
Organism | Mus musculus
PMID | 22987803
Authors | Liu X,Yan X,Zhong B,Nurieva RI,Wang A,Wang X,Martin-Orozco N,Wang Y,Chang SH,Esplugues E,Flavell RA,Tian Q,Dong C
Category | C7
Sub-category |
Brief description | Genes down-regulated in CXCR5- BCL6- CD4+ [GeneID=643;604;920] T cells versus CXCR5+ BCL6- [GeneID=643;604] follicular helper T cells.
Full description | T follicular helper (Tfh) cells play a pivotal role in germinal center reactions, which requires Bcl6 transcription factor. To analyze their relationships with other effector T cell lineages and their stability in vivo, we developed and analyzed a new Bcl6 reporter mouse alone or together with other lineage reporter systems. Assisted with genome-wide transcriptome analysis, we show substantial plasticity of T cell differentiation in the early phase of immune response. At this stage, CXCR5 appears to be expressed in a Bcl6-independent manner. Once Bcl6 is highly expressed, Tfh cells can persist in vivo and some of them develop into memory cells. Together, our results indicate Bcl6 as a bona fide marker for Tfh polarized program.

Standard name | GSE39916_B_CELL_SPLEEN_VS_PLASMA_CELL_BONE_MARROW_UP
Systematic name | M9269
Organism | Mus musculus
PMID | 22991471
Authors | Benson MJ,Aijö T,Chang X,Gagnon J,Pape UJ,Anantharaman V,Aravind L,Pursiheimo JP,Oberdoerffer S,Liu XS,Lahesmaa R,Lähdesmäki H,Rao A
Category | C7
Sub-category |
Brief description | Genes up-regulated in spleen B lymphocytes versus bone marrow plasma cells.
Full description | CD138+ B220- plasma cells were sorted from bone marrow and B220+ CD23+ mature follicular B cells were sorted from the spleens. Plasma cells were sorted from C57BL/6 mice 7 days after boosting with antigen, with mice first primed with an i.p. injection of KLH/IFA followed by boost at day 21 with KLH/PBS i.p. Mature B cells were sorted from antigen-naïve C57BL/6 mice. We compared expression profiles of plasma cells and mature B cells to identify differentially expressed transcripts.

Standard name | GSE39916_B_CELL_SPLEEN_VS_PLASMA_CELL_BONE_MARROW_DN
Systematic name | M9272
Organism | Mus musculus
PMID | 22991471
Authors | Benson MJ,Aijö T,Chang X,Gagnon J,Pape UJ,Anantharaman V,Aravind L,Pursiheimo JP,Oberdoerffer S,Liu XS,Lahesmaa R,Lähdesmäki H,Rao A
Category | C7
Sub-category |
Brief description | Genes down-regulated in spleen B lymphocytes versus bone marrow plasma cells.
Full description | CD138+ B220- plasma cells were sorted from bone marrow and B220+ CD23+ mature follicular B cells were sorted from the spleens. Plasma cells were sorted from C57BL/6 mice 7 days after boosting with antigen, with mice first primed with an i.p. injection of KLH/IFA followed by boost at day 21 with KLH/PBS i.p. Mature B cells were sorted from antigen-naïve C57BL/6 mice. We compared expression profiles of plasma cells and mature B cells to identify differentially expressed transcripts.

Standard name | GSE38304_MYC_NEG_VS_POS_GC_BCELL_UP
Systematic name | M9273
Organism | Mus musculus
PMID | 23001145
Authors | Dominguez-Sola D,Victora GD,Ying CY,Phan RT,Saito M,Nussenzweig MC,Dalla-Favera R
Category | C7
Sub-category |
Brief description | Genes up-regulated in germinal celter B lymphocytes: MYC- [GeneID=4609] versus MYC+ [GeneID=4609].
Full description | Germinal centers (GC) arise within B cell follicles upon antigenic challenge. In the dark zones (DZ) of GCs, B cells proliferate and hypermutate their immunoglobulin genes, and mutants with increased affinity are positively selected in the light zone (LZ) to either differentiate into plasma and memory cells, or re-enter the DZ for further refinement. However, the molecular circuits governing GC positive selection are not known. Here, we show that the GC reaction requires the biphasic regulation of c-MYC expression, involving its transient induction during early GC commitment, its repression by BCL6 in DZ B cells, and its re-induction in a subpopulation of positively selected LZ B cells destined to DZ re-entry. Accordingly, acute disruption of MYC function in vivo leads to GC collapse, indicating an essential role in GC physiology. These results have implications for our understanding of GC selection and the role of MYC deregulation in B cell lymphomas. We used microarrays to determine the global gene expression programs that distinguish MYC+ GC B cells from their MYC- negative counterparts.

Standard name | GSE38304_MYC_NEG_VS_POS_GC_BCELL_DN
Systematic name | M9274
Organism | Mus musculus
PMID | 23001145
Authors | Dominguez-Sola D,Victora GD,Ying CY,Phan RT,Saito M,Nussenzweig MC,Dalla-Favera R
Category | C7
Sub-category |
Brief description | Genes down-regulated in germinal celter B lymphocytes: MYC- [GeneID=4609] versus MYC+ [GeneID=4609].
Full description | Germinal centers (GC) arise within B cell follicles upon antigenic challenge. In the dark zones (DZ) of GCs, B cells proliferate and hypermutate their immunoglobulin genes, and mutants with increased affinity are positively selected in the light zone (LZ) to either differentiate into plasma and memory cells, or re-enter the DZ for further refinement. However, the molecular circuits governing GC positive selection are not known. Here, we show that the GC reaction requires the biphasic regulation of c-MYC expression, involving its transient induction during early GC commitment, its repression by BCL6 in DZ B cells, and its re-induction in a subpopulation of positively selected LZ B cells destined to DZ re-entry. Accordingly, acute disruption of MYC function in vivo leads to GC collapse, indicating an essential role in GC physiology. These results have implications for our understanding of GC selection and the role of MYC deregulation in B cell lymphomas. We used microarrays to determine the global gene expression programs that distinguish MYC+ GC B cells from their MYC- negative counterparts.

Standard name | GSE39110_UNTREATED_VS_IL2_TREATED_CD8_TCELL_DAY3_POST_IMMUNIZATION_DN
Systematic name | M9275
Organism | Mus musculus
PMID | 23018461
Authors | Castro I,Dee MJ,Malek TR
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells 3 days after immunization: control versus IL2 [GeneID=3558] treatment.
Full description | Much is known concerning the cellular and molecular basis for CD8+ T memory immune responses. Nevertheless, conditions that selectively support memory generation have remained elusive. Here we show that an immunization regimen that delivers TCR signals through a defined antigenic peptide, inflammatory signals through LPS, and growth and differentiation signals through the IL-2R initially favors antigen-specific CD8+ T cells to rapidly and substantially develop into tissue-residing T effector-memory cells by TCR transgenic OVA-specific OT-I CD8+ T cells. Amplified CD8+ T memory development depends upon a critical frequency of antigen-specific T cells and direct responsiveness to IL-2. A homologous prime-boost immunization protocol with transiently enhanced IL-2R signaling in normal mice led to persistent polyclonal antigen-specific CD8+ T cells that supported protective immunity to Listeria monocytogenes. These results identify a general approach for amplified T memory development that may be useful to optimize vaccines aimed at generating robust cell-mediated immunity. Gene expression analysis was performed for OT-I T cells on day 3 and day 5 after activation with ovalbumin and LPS in vivo with and without treatment with IL-2 using an agonists IL-2/anti-IL-2 complexes (IL2/Jes-6.1)

Standard name | GSE39110_DAY3_VS_DAY6_POST_IMMUNIZATION_CD8_TCELL_UP
Systematic name | M9276
Organism | Mus musculus
PMID | 23018461
Authors | Castro I,Dee MJ,Malek TR
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells after immunization: day 3 versus day 6.
Full description | Much is known concerning the cellular and molecular basis for CD8+ T memory immune responses. Nevertheless, conditions that selectively support memory generation have remained elusive. Here we show that an immunization regimen that delivers TCR signals through a defined antigenic peptide, inflammatory signals through LPS, and growth and differentiation signals through the IL-2R initially favors antigen-specific CD8+ T cells to rapidly and substantially develop into tissue-residing T effector-memory cells by TCR transgenic OVA-specific OT-I CD8+ T cells. Amplified CD8+ T memory development depends upon a critical frequency of antigen-specific T cells and direct responsiveness to IL-2. A homologous prime-boost immunization protocol with transiently enhanced IL-2R signaling in normal mice led to persistent polyclonal antigen-specific CD8+ T cells that supported protective immunity to Listeria monocytogenes. These results identify a general approach for amplified T memory development that may be useful to optimize vaccines aimed at generating robust cell-mediated immunity. Gene expression analysis was performed for OT-I T cells on day 3 and day 5 after activation with ovalbumin and LPS in vivo with and without treatment with IL-2 using an agonists IL-2/anti-IL-2 complexes (IL2/Jes-6.1)

Standard name | GSE39110_DAY3_VS_DAY6_POST_IMMUNIZATION_CD8_TCELL_DN
Systematic name | M9277
Organism | Mus musculus
PMID | 23018461
Authors | Castro I,Dee MJ,Malek TR
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells after immunization: day 3 versus day 6.
Full description | Much is known concerning the cellular and molecular basis for CD8+ T memory immune responses. Nevertheless, conditions that selectively support memory generation have remained elusive. Here we show that an immunization regimen that delivers TCR signals through a defined antigenic peptide, inflammatory signals through LPS, and growth and differentiation signals through the IL-2R initially favors antigen-specific CD8+ T cells to rapidly and substantially develop into tissue-residing T effector-memory cells by TCR transgenic OVA-specific OT-I CD8+ T cells. Amplified CD8+ T memory development depends upon a critical frequency of antigen-specific T cells and direct responsiveness to IL-2. A homologous prime-boost immunization protocol with transiently enhanced IL-2R signaling in normal mice led to persistent polyclonal antigen-specific CD8+ T cells that supported protective immunity to Listeria monocytogenes. These results identify a general approach for amplified T memory development that may be useful to optimize vaccines aimed at generating robust cell-mediated immunity. Gene expression analysis was performed for OT-I T cells on day 3 and day 5 after activation with ovalbumin and LPS in vivo with and without treatment with IL-2 using an agonists IL-2/anti-IL-2 complexes (IL2/Jes-6.1)

Standard name | GSE39110_UNTREATED_VS_IL2_TREATED_CD8_TCELL_DAY3_POST_IMMUNIZATION_UP
Systematic name | M9278
Organism | Mus musculus
PMID | 23018461
Authors | Castro I,Dee MJ,Malek TR
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells 3 days after immunization: control versus IL2 [GeneID=3558] treatment.
Full description | Much is known concerning the cellular and molecular basis for CD8+ T memory immune responses. Nevertheless, conditions that selectively support memory generation have remained elusive. Here we show that an immunization regimen that delivers TCR signals through a defined antigenic peptide, inflammatory signals through LPS, and growth and differentiation signals through the IL-2R initially favors antigen-specific CD8+ T cells to rapidly and substantially develop into tissue-residing T effector-memory cells by TCR transgenic OVA-specific OT-I CD8+ T cells. Amplified CD8+ T memory development depends upon a critical frequency of antigen-specific T cells and direct responsiveness to IL-2. A homologous prime-boost immunization protocol with transiently enhanced IL-2R signaling in normal mice led to persistent polyclonal antigen-specific CD8+ T cells that supported protective immunity to Listeria monocytogenes. These results identify a general approach for amplified T memory development that may be useful to optimize vaccines aimed at generating robust cell-mediated immunity. Gene expression analysis was performed for OT-I T cells on day 3 and day 5 after activation with ovalbumin and LPS in vivo with and without treatment with IL-2 using an agonists IL-2/anti-IL-2 complexes (IL2/Jes-6.1)

Standard name | GSE39110_DAY3_VS_DAY6_POST_IMMUNIZATION_CD8_TCELL_WITH_IL2_TREATMENT_UP
Systematic name | M9281
Organism | Mus musculus
PMID | 23018461
Authors | Castro I,Dee MJ,Malek TR
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells after immunization: day 3 versus day 6 and IL2 [GeneID=3558] treatment.
Full description | Much is known concerning the cellular and molecular basis for CD8+ T memory immune responses. Nevertheless, conditions that selectively support memory generation have remained elusive. Here we show that an immunization regimen that delivers TCR signals through a defined antigenic peptide, inflammatory signals through LPS, and growth and differentiation signals through the IL-2R initially favors antigen-specific CD8+ T cells to rapidly and substantially develop into tissue-residing T effector-memory cells by TCR transgenic OVA-specific OT-I CD8+ T cells. Amplified CD8+ T memory development depends upon a critical frequency of antigen-specific T cells and direct responsiveness to IL-2. A homologous prime-boost immunization protocol with transiently enhanced IL-2R signaling in normal mice led to persistent polyclonal antigen-specific CD8+ T cells that supported protective immunity to Listeria monocytogenes. These results identify a general approach for amplified T memory development that may be useful to optimize vaccines aimed at generating robust cell-mediated immunity. Gene expression analysis was performed for OT-I T cells on day 3 and day 5 after activation with ovalbumin and LPS in vivo with and without treatment with IL-2 using an agonists IL-2/anti-IL-2 complexes (IL2/Jes-6.1)

Standard name | GSE39110_DAY3_VS_DAY6_POST_IMMUNIZATION_CD8_TCELL_WITH_IL2_TREATMENT_DN
Systematic name | M9283
Organism | Mus musculus
PMID | 23018461
Authors | Castro I,Dee MJ,Malek TR
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells after immunization: day 3 versus day 6 and IL2 [GeneID=3558] treatment.
Full description | Much is known concerning the cellular and molecular basis for CD8+ T memory immune responses. Nevertheless, conditions that selectively support memory generation have remained elusive. Here we show that an immunization regimen that delivers TCR signals through a defined antigenic peptide, inflammatory signals through LPS, and growth and differentiation signals through the IL-2R initially favors antigen-specific CD8+ T cells to rapidly and substantially develop into tissue-residing T effector-memory cells by TCR transgenic OVA-specific OT-I CD8+ T cells. Amplified CD8+ T memory development depends upon a critical frequency of antigen-specific T cells and direct responsiveness to IL-2. A homologous prime-boost immunization protocol with transiently enhanced IL-2R signaling in normal mice led to persistent polyclonal antigen-specific CD8+ T cells that supported protective immunity to Listeria monocytogenes. These results identify a general approach for amplified T memory development that may be useful to optimize vaccines aimed at generating robust cell-mediated immunity. Gene expression analysis was performed for OT-I T cells on day 3 and day 5 after activation with ovalbumin and LPS in vivo with and without treatment with IL-2 using an agonists IL-2/anti-IL-2 complexes (IL2/Jes-6.1)

Standard name | GSE39110_UNTREATED_VS_IL2_TREATED_CD8_TCELL_DAY6_POST_IMMUNIZATION_UP
Systematic name | M9284
Organism | Mus musculus
PMID | 23018461
Authors | Castro I,Dee MJ,Malek TR
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells 6 days after immunization: control versus IL2 [GeneID=3558] treatment.
Full description | Much is known concerning the cellular and molecular basis for CD8+ T memory immune responses. Nevertheless, conditions that selectively support memory generation have remained elusive. Here we show that an immunization regimen that delivers TCR signals through a defined antigenic peptide, inflammatory signals through LPS, and growth and differentiation signals through the IL-2R initially favors antigen-specific CD8+ T cells to rapidly and substantially develop into tissue-residing T effector-memory cells by TCR transgenic OVA-specific OT-I CD8+ T cells. Amplified CD8+ T memory development depends upon a critical frequency of antigen-specific T cells and direct responsiveness to IL-2. A homologous prime-boost immunization protocol with transiently enhanced IL-2R signaling in normal mice led to persistent polyclonal antigen-specific CD8+ T cells that supported protective immunity to Listeria monocytogenes. These results identify a general approach for amplified T memory development that may be useful to optimize vaccines aimed at generating robust cell-mediated immunity. Gene expression analysis was performed for OT-I T cells on day 3 and day 5 after activation with ovalbumin and LPS in vivo with and without treatment with IL-2 using an agonists IL-2/anti-IL-2 complexes (IL2/Jes-6.1)

Standard name | GSE39110_UNTREATED_VS_IL2_TREATED_CD8_TCELL_DAY6_POST_IMMUNIZATION_DN
Systematic name | M9285
Organism | Mus musculus
PMID | 23018461
Authors | Castro I,Dee MJ,Malek TR
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells 6 days after immunization: control versus IL2 [GeneID=3558] treatment.
Full description | Much is known concerning the cellular and molecular basis for CD8+ T memory immune responses. Nevertheless, conditions that selectively support memory generation have remained elusive. Here we show that an immunization regimen that delivers TCR signals through a defined antigenic peptide, inflammatory signals through LPS, and growth and differentiation signals through the IL-2R initially favors antigen-specific CD8+ T cells to rapidly and substantially develop into tissue-residing T effector-memory cells by TCR transgenic OVA-specific OT-I CD8+ T cells. Amplified CD8+ T memory development depends upon a critical frequency of antigen-specific T cells and direct responsiveness to IL-2. A homologous prime-boost immunization protocol with transiently enhanced IL-2R signaling in normal mice led to persistent polyclonal antigen-specific CD8+ T cells that supported protective immunity to Listeria monocytogenes. These results identify a general approach for amplified T memory development that may be useful to optimize vaccines aimed at generating robust cell-mediated immunity. Gene expression analysis was performed for OT-I T cells on day 3 and day 5 after activation with ovalbumin and LPS in vivo with and without treatment with IL-2 using an agonists IL-2/anti-IL-2 complexes (IL2/Jes-6.1)

Standard name | GSE36078_WT_VS_IL1R_KO_LUNG_DC_AFTER_AD5_INF_UP
Systematic name | M9286
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes up-regulated in Lung dendritic cell from Ad5 infection wildtype mice versus Lung dendritic cell from Ad5 inf IL-1R mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_WT_VS_IL1R_KO_LUNG_DC_AFTER_AD5_INF_DN
Systematic name | M9288
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes down-regulated in Lung dendritic cell from Ad5 infection wildtype mice versus Lung dendritic cell from Ad5 inf IL-1R mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_UNTREATED_VS_AD5_INF_MOUSE_LUNG_DC_UP
Systematic name | M9289
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD11c+ monocytes: control versus HAdv5 infection.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_WT_VS_IL1R_KO_LUNG_DC_DN
Systematic name | M9290
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes down-regulated in Lung dendritic cell from untreated wildtype mice versus Lung dendritic cell from untreated IL-1R mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_UNTREATED_VS_AD5_INF_MOUSE_LUNG_DC_DN
Systematic name | M9292
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD11c+ monocytes: control versus HAdv5 infection.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_UNTREATED_VS_AD5_T425A_HEXON_INF_MOUSE_LUNG_DC_UP
Systematic name | M9293
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes up-regulated in Lung dendritic cell from untreated wildtype mice versus Lung dendritic cell from Ad5 T424A hexon infection wildtype mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_WT_VS_IL1R_KO_LUNG_DC_AFTER_AD5_T425A_HEXON_INF_UP
Systematic name | M9294
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes up-regulated in Lung dendritic cell from Ad5 T424A hexon infection wildtype mice versus Lung dendritic cell from Ad5 T424A hexon inf IL-1R mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_WT_VS_IL1R_KO_LUNG_DC_AFTER_AD5_T425A_HEXON_INF_DN
Systematic name | M9295
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes down-regulated in Lung dendritic cell from Ad5 T424A hexon infection wildtype mice versus Lung dendritic cell from Ad5 T424A hexon inf IL-1R mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_UNTREATED_VS_AD5_INF_IL1R_KO_MOUSE_LUNG_DC_DN
Systematic name | M9296
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes down-regulated in Lung dendritic cell from untreated IL-1R mice versus Lung dendritic cell from Ad5 inf IL-1R mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_UNTREATED_VS_AD5_T425A_HEXON_INF_IL1R_KO_MOUSE_LUNG_DC_UP
Systematic name | M9297
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes up-regulated in Lung dendritic cell from untreated IL-1R mice versus Lung dendritic cell from Ad5 T424A hexon inf IL-1R mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_UNTREATED_VS_AD5_T425A_HEXON_INF_IL1R_KO_MOUSE_LUNG_DC_DN
Systematic name | M9298
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes down-regulated in Lung dendritic cell from untreated IL-1R mice versus Lung dendritic cell from Ad5 T424A hexon inf IL-1R mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_WT_VS_IL1R_KO_LUNG_DC_UP
Systematic name | M9299
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes up-regulated in Lung dendritic cell from untreated wildtype mice versus Lung dendritic cell from untreated IL-1R mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_UNTREATED_VS_AD5_INF_IL1R_KO_MOUSE_LUNG_DC_UP
Systematic name | M9301
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes up-regulated in Lung dendritic cell from untreated IL-1R mice versus Lung dendritic cell from Ad5 inf IL-1R mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE36078_UNTREATED_VS_AD5_T425A_HEXON_INF_MOUSE_LUNG_DC_DN
Systematic name | M9302
Organism | Mus musculus
PMID | 23019612
Authors | Doronin K,Flatt JW,Paolo Di NC,Khare R,Kalyuzhniy O,Acchione M,Sumida JP,Ohto U,Shimizu T,Akashi-Takamura S,Miyake K,MacDonald JW,Bammler TK,Beyer RP,Farin FM,Stewart PL,Shayakhmetov DM
Category | C7
Sub-category |
Brief description | Genes down-regulated in Lung dendritic cell from untreated wildtype mice versus Lung dendritic cell from Ad5 T424A hexon infection wildtype mice.
Full description | Discrimination between self vs. non-self and adequate response to infection and tissue damage are fundamental functions of the immune system. The rapid and global spread of known and emerging viruses is a testament that the timely detection of viral pathogens that reproduce within host cells, presents a formidable challenge to the immune system. To gain access to a proper reproductive niche, many pathogens travel via the host vasculature and therefore become exposed to humoral factors of the innate immune system. Although a cascade of coagulation factors plays a fundamental role in host defense for “living fossils” such as horseshoe crabs (Xiphosurida spp), the role of the coagulation system in activation of innate responses to pathogens in higher organisms remains unclear. When human type C adenovirus (HAdv) enters the circulation, 240 copies of coagulation factor X (FX) bind to the virus particle with picomolar affinity. Here, using molecular dynamics flexible fitting (MDFF) and high resolution cryo-electron microscopy (cryo-EM), we defined the interface between the HAdv5 hexon protein and FX at pseudo-atomic level. Based on this structural data, we introduced a single amino acid substitution, T424A, in the hexon that completely abrogated FX interaction with the virus. In vivo genome-wide transcriptional profiling revealed that FX-binding-ablated virus failed to activate a distinct network of the early response genes, whose expression depends on transcription factor NFKB1. Deconvolution of the signaling network responsible for early gene activation showed that the FX-HAdv complex triggers MyD88/TRIF/TRAF6 signaling upon activation of toll-like receptor 4 (TLR4) that serves as a principal sensor of FX-virus complex in vivo. Our study implicates host factor “decoration” of the virus as a mechanism to trigger innate immune sensor that respond to a misplacement of coagulation FX from the blood into intracellular macrophage compartments upon virus entry into the cell. Our results further the mounting evidence of evolutionary conservation between the coagulation system and innate immunity.

Standard name | GSE40685_NAIVE_CD4_TCELL_VS_TREG_DN
Systematic name | M9303
Organism | Mus musculus
PMID | 23021222
Authors | Samstein RM,Arvey A,Josefowicz SZ,Peng X,Reynolds A,Sandstrom R,Neph S,Sabo P,Kim JM,Liao W,Li MO,Leslie C,Stamatoyannopoulos JA,Rudensky AY
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920]: naïve versus FOXP3+ [GeneID=50943] T reg.
Full description | Regulatory T (Treg) cells, whose identity and function are defined by the transcription factor Foxp3, are indispensable for immune homeostasis. It is unclear whether Foxp3 exerts its Treg lineage specification function through active modification of the chromatin landscape and establishment of new enhancers or by exploiting a pre-existing enhancer landscape. Analysis of the chromatin accessibility of Foxp3-bound enhancers in Treg and Foxp3-negative T cells showed that Foxp3 was bound overwhelmingly to pre-accessible enhancers occupied by its cofactors in precursor cells or a structurally related predecessor. Furthermore, the bulk of Foxp3-bound Treg cell enhancers inaccessible in Foxp3- CD4+ cells became accessible upon T cell receptor activation prior to Foxp3 expression with only a small subset associated with several functionally important genes being exclusively Treg cell-specific. Thus, in a late cellular differentiation process Foxp3 defines Treg cell functionality in an “opportunistic” manner by largely exploiting the preformed enhancer network instead of establishing a new enhancer landscape.

Standard name | GSE40685_NAIVE_CD4_TCELL_VS_FOXP3_KO_TREG_PRECURSOR_UP
Systematic name | M9304
Organism | Mus musculus
PMID | 23021222
Authors | Samstein RM,Arvey A,Josefowicz SZ,Peng X,Reynolds A,Sandstrom R,Neph S,Sabo P,Kim JM,Liao W,Li MO,Leslie C,Stamatoyannopoulos JA,Rudensky AY
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4: naïve versus FOXP3 [GeneID=50943] knockout T reg precursors.
Full description | Regulatory T (Treg) cells, whose identity and function are defined by the transcription factor Foxp3, are indispensable for immune homeostasis. It is unclear whether Foxp3 exerts its Treg lineage specification function through active modification of the chromatin landscape and establishment of new enhancers or by exploiting a pre-existing enhancer landscape. Analysis of the chromatin accessibility of Foxp3-bound enhancers in Treg and Foxp3-negative T cells showed that Foxp3 was bound overwhelmingly to pre-accessible enhancers occupied by its cofactors in precursor cells or a structurally related predecessor. Furthermore, the bulk of Foxp3-bound Treg cell enhancers inaccessible in Foxp3- CD4+ cells became accessible upon T cell receptor activation prior to Foxp3 expression with only a small subset associated with several functionally important genes being exclusively Treg cell-specific. Thus, in a late cellular differentiation process Foxp3 defines Treg cell functionality in an “opportunistic” manner by largely exploiting the preformed enhancer network instead of establishing a new enhancer landscape.

Standard name | GSE40685_NAIVE_CD4_TCELL_VS_TREG_UP
Systematic name | M9305
Organism | Mus musculus
PMID | 23021222
Authors | Samstein RM,Arvey A,Josefowicz SZ,Peng X,Reynolds A,Sandstrom R,Neph S,Sabo P,Kim JM,Liao W,Li MO,Leslie C,Stamatoyannopoulos JA,Rudensky AY
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920]: naïve versus FOXP3+ [GeneID=50943] T reg.
Full description | Regulatory T (Treg) cells, whose identity and function are defined by the transcription factor Foxp3, are indispensable for immune homeostasis. It is unclear whether Foxp3 exerts its Treg lineage specification function through active modification of the chromatin landscape and establishment of new enhancers or by exploiting a pre-existing enhancer landscape. Analysis of the chromatin accessibility of Foxp3-bound enhancers in Treg and Foxp3-negative T cells showed that Foxp3 was bound overwhelmingly to pre-accessible enhancers occupied by its cofactors in precursor cells or a structurally related predecessor. Furthermore, the bulk of Foxp3-bound Treg cell enhancers inaccessible in Foxp3- CD4+ cells became accessible upon T cell receptor activation prior to Foxp3 expression with only a small subset associated with several functionally important genes being exclusively Treg cell-specific. Thus, in a late cellular differentiation process Foxp3 defines Treg cell functionality in an “opportunistic” manner by largely exploiting the preformed enhancer network instead of establishing a new enhancer landscape.

Standard name | GSE40685_TREG_VS_FOXP3_KO_TREG_PRECURSOR_UP
Systematic name | M9306
Organism | Mus musculus
PMID | 23021222
Authors | Samstein RM,Arvey A,Josefowicz SZ,Peng X,Reynolds A,Sandstrom R,Neph S,Sabo P,Kim JM,Liao W,Li MO,Leslie C,Stamatoyannopoulos JA,Rudensky AY
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4: FOXP3+ [GeneID=50943] T reg versus FOXP3 [GeneID=50943] knockout T reg precursor.
Full description | Regulatory T (Treg) cells, whose identity and function are defined by the transcription factor Foxp3, are indispensable for immune homeostasis. It is unclear whether Foxp3 exerts its Treg lineage specification function through active modification of the chromatin landscape and establishment of new enhancers or by exploiting a pre-existing enhancer landscape. Analysis of the chromatin accessibility of Foxp3-bound enhancers in Treg and Foxp3-negative T cells showed that Foxp3 was bound overwhelmingly to pre-accessible enhancers occupied by its cofactors in precursor cells or a structurally related predecessor. Furthermore, the bulk of Foxp3-bound Treg cell enhancers inaccessible in Foxp3- CD4+ cells became accessible upon T cell receptor activation prior to Foxp3 expression with only a small subset associated with several functionally important genes being exclusively Treg cell-specific. Thus, in a late cellular differentiation process Foxp3 defines Treg cell functionality in an “opportunistic” manner by largely exploiting the preformed enhancer network instead of establishing a new enhancer landscape.

Standard name | GSE40685_TREG_VS_FOXP3_KO_TREG_PRECURSOR_DN
Systematic name | M9308
Organism | Mus musculus
PMID | 23021222
Authors | Samstein RM,Arvey A,Josefowicz SZ,Peng X,Reynolds A,Sandstrom R,Neph S,Sabo P,Kim JM,Liao W,Li MO,Leslie C,Stamatoyannopoulos JA,Rudensky AY
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4: FOXP3+ [GeneID=50943] T reg versus FOXP3 [GeneID=50943] knockout T reg precursor.
Full description | Regulatory T (Treg) cells, whose identity and function are defined by the transcription factor Foxp3, are indispensable for immune homeostasis. It is unclear whether Foxp3 exerts its Treg lineage specification function through active modification of the chromatin landscape and establishment of new enhancers or by exploiting a pre-existing enhancer landscape. Analysis of the chromatin accessibility of Foxp3-bound enhancers in Treg and Foxp3-negative T cells showed that Foxp3 was bound overwhelmingly to pre-accessible enhancers occupied by its cofactors in precursor cells or a structurally related predecessor. Furthermore, the bulk of Foxp3-bound Treg cell enhancers inaccessible in Foxp3- CD4+ cells became accessible upon T cell receptor activation prior to Foxp3 expression with only a small subset associated with several functionally important genes being exclusively Treg cell-specific. Thus, in a late cellular differentiation process Foxp3 defines Treg cell functionality in an “opportunistic” manner by largely exploiting the preformed enhancer network instead of establishing a new enhancer landscape.

Standard name | GSE40685_NAIVE_CD4_TCELL_VS_FOXP3_KO_TREG_PRECURSOR_DN
Systematic name | M9309
Organism | Mus musculus
PMID | 23021222
Authors | Samstein RM,Arvey A,Josefowicz SZ,Peng X,Reynolds A,Sandstrom R,Neph S,Sabo P,Kim JM,Liao W,Li MO,Leslie C,Stamatoyannopoulos JA,Rudensky AY
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4: naïve versus FOXP3 [GeneID=50943] knockout T reg precursors.
Full description | Regulatory T (Treg) cells, whose identity and function are defined by the transcription factor Foxp3, are indispensable for immune homeostasis. It is unclear whether Foxp3 exerts its Treg lineage specification function through active modification of the chromatin landscape and establishment of new enhancers or by exploiting a pre-existing enhancer landscape. Analysis of the chromatin accessibility of Foxp3-bound enhancers in Treg and Foxp3-negative T cells showed that Foxp3 was bound overwhelmingly to pre-accessible enhancers occupied by its cofactors in precursor cells or a structurally related predecessor. Furthermore, the bulk of Foxp3-bound Treg cell enhancers inaccessible in Foxp3- CD4+ cells became accessible upon T cell receptor activation prior to Foxp3 expression with only a small subset associated with several functionally important genes being exclusively Treg cell-specific. Thus, in a late cellular differentiation process Foxp3 defines Treg cell functionality in an “opportunistic” manner by largely exploiting the preformed enhancer network instead of establishing a new enhancer landscape.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_GERMINAL_CENTER_BCELL_DAY40_DN
Systematic name | M9310
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_MEMORY_BCELL_DAY40_DN
Systematic name | M9311
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B cells versus day 40 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_GERMINAL_CENTER_BCELL_DAY40_UP
Systematic name | M9313
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_PLASMA_CELL_DAY7_UP
Systematic name | M9314
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B cells versus day 7 plasma cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_PLASMA_CELL_DAY7_DN
Systematic name | M9315
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B cells versus day 7 plasma cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_MEMORY_BCELL_DAY40_UP
Systematic name | M9316
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B cells versus day 40 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MARGINAL_ZONE_BCELL_VS_GERMINAL_CENTER_BCELL_DAY40_UP
Systematic name | M9317
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in marginal zone B cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MARGINAL_ZONE_BCELL_VS_GERMINAL_CENTER_BCELL_DAY40_DN
Systematic name | M9318
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in marginal zone B cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MEMORY_BCELL_DAY7_VS_GERMINAL_CENTER_BCELL_DAY7_UP
Systematic name | M9319
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in day 7 memory B cells versus day 7 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MARGINAL_ZONE_BCELL_VS_GERMINAL_CENTER_BCELL_DAY7_UP
Systematic name | M9320
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in marginal zone B cells versus day 7 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MARGINAL_ZONE_BCELL_VS_GERMINAL_CENTER_BCELL_DAY7_DN
Systematic name | M9321
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in marginal zone B cells versus day 7 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MARGINAL_ZONE_BCELL_VS_PLASMA_CELL_DAY7_UP
Systematic name | M9322
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in marginal zone B cells versus day 7 plasma cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MARGINAL_ZONE_BCELL_VS_PLASMA_CELL_DAY7_DN
Systematic name | M9323
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in marginal zone B cells versus day 7 plasma cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MARGINAL_ZONE_BCELL_VS_MEMORY_BCELL_DAY40_UP
Systematic name | M9324
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in marginal zone B cells versus day 40 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MARGINAL_ZONE_BCELL_VS_MEMORY_BCELL_DAY40_DN
Systematic name | M9327
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in marginal zone B cells versus day 40 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_GERMINAL_CENTER_BCELL_DAY7_VS_MEMORY_BCELL_DAY40_DN
Systematic name | M9328
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in day 7 germinal center B cells versus day 40 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_GERMINAL_CENTER_BCELL_DAY7_VS_GERMINAL_CENTER_BCELL_DAY40_UP
Systematic name | M9330
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in day 7 germinal center B cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_GERMINAL_CENTER_BCELL_DAY7_VS_GERMINAL_CENTER_BCELL_DAY40_DN
Systematic name | M9332
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in day 7 germinal center B cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_UNSTIM_VS_ANTI_IGM_AND_CD40_STIM_6H_FOLLICULAR_BCELL_UP
Systematic name | M9333
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B cells versus those stimulated with anti-IgM and CD40 [GeneID=958] for 6h.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_UNSTIM_VS_ANTI_IGM_AND_CD40_STIM_6H_FOLLICULAR_BCELL_DN
Systematic name | M9335
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B cells versus those stimulated with anti-IgM and CD40 [GeneID=958] for 6h.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MARGINAL_ZONE_BCELL_VS_MEMORY_BCELL_DAY7_UP
Systematic name | M9336
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in marginal zone B cells versus day 7 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MARGINAL_ZONE_BCELL_VS_MEMORY_BCELL_DAY7_DN
Systematic name | M9337
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in marginal zone B cells versus day 7 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_MEMORY_BCELL_DAY7_UP
Systematic name | M9338
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B cells versus day 7 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_MEMORY_BCELL_DAY7_DN
Systematic name | M9339
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B cells versus day 7 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_GERMINAL_CENTER_BCELL_DAY7_UP
Systematic name | M9340
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B cells versus day 7 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_GERMINAL_CENTER_BCELL_DAY7_DN
Systematic name | M9341
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B cells versus day 7 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE28737_WT_VS_BCL6_HET_MARGINAL_ZONE_BCELL_UP
Systematic name | M9342
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in marginal zone B lymphocytes: wildtype versus heterozygotic knockout of BCL6 [GeneID=604].
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_WT_VS_BCL6_HET_MARGINAL_ZONE_BCELL_DN
Systematic name | M9344
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in marginal zone B lymphocytes: wildtype versus heterozygotic knockout of BCL6 [GeneID=604].
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_WT_VS_BCL6_KO_MARGINAL_ZONE_BCELL_UP
Systematic name | M9345
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in marginal zone B lymphocytes: wildtype versus BCL6 [GeneID=604] knockout.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_WT_VS_BCL6_KO_MARGINAL_ZONE_BCELL_DN
Systematic name | M9346
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in marginal zone B lymphocytes: wildtype versus BCL6 [GeneID=604] knockout.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_BCL6_HET_VS_BCL6_KO_MARGINAL_ZONE_BCELL_UP
Systematic name | M9348
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in marginal zone B lymphocytes with knockout of BCL6 [GeneID=604]: heterozygous versus homozygous.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_BCL6_HET_VS_BCL6_KO_MARGINAL_ZONE_BCELL_DN
Systematic name | M9349
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in marginal zone B lymphocytes with knockout of BCL6 [GeneID=604]: heterozygous versus homozygous.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_FOLLICULAR_VS_MARGINAL_ZONE_BCELL_UP
Systematic name | M9351
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B lymphocytes versus marginal zone B cells.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_FOLLICULAR_VS_MARGINAL_ZONE_BCELL_DN
Systematic name | M9352
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B lymphocytes versus marginal zone B cells.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_FOLLICULAR_VS_MARGINAL_ZONE_BCELL_BCL6_HET_UP
Systematic name | M9354
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in heterozygous knockout of BCL6 [GeneID=604]: follicular versus marginal zone source.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_FOLLICULAR_VS_MARGINAL_ZONE_BCELL_BCL6_HET_DN
Systematic name | M9356
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in heterozygous knockout of BCL6 [GeneID=604]: follicular versus marginal zone source.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE11961_MEMORY_BCELL_DAY7_VS_MEMORY_BCELL_DAY40_DN
Systematic name | M9357
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in day 7 memory B cells versus day 40 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MEMORY_BCELL_DAY7_VS_GERMINAL_CENTER_BCELL_DAY40_UP
Systematic name | M9358
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in day 7 memory B cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MEMORY_BCELL_DAY7_VS_GERMINAL_CENTER_BCELL_DAY40_DN
Systematic name | M9359
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in day 7 memory B cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_GERMINAL_CENTER_BCELL_DAY7_VS_PLASMA_CELL_DAY7_UP
Systematic name | M9360
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in day 7 germinal center B cells versus day 7 plasma cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_GERMINAL_CENTER_BCELL_DAY7_VS_PLASMA_CELL_DAY7_DN
Systematic name | M9361
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in day 7 germinal center B cells versus day 7 plasma cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_GERMINAL_CENTER_BCELL_DAY7_VS_MEMORY_BCELL_DAY40_UP
Systematic name | M9363
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in day 7 germinal center B cells versus day 40 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MEMORY_BCELL_DAY7_VS_PLASMA_CELL_DAY7_UP
Systematic name | M9366
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in day 7 memory B cells versus day 7 plasma cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MEMORY_BCELL_DAY7_VS_PLASMA_CELL_DAY7_DN
Systematic name | M9368
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in day 7 memory B cells versus day 7 plasma cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MEMORY_BCELL_DAY7_VS_MEMORY_BCELL_DAY40_UP
Systematic name | M9369
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in day 7 memory B cells versus day 40 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MEMORY_BCELL_DAY7_VS_GERMINAL_CENTER_BCELL_DAY7_DN
Systematic name | M9370
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in day 7 memory B cells versus day 7 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_MARGINAL_ZONE_BCELL_DN
Systematic name | M9373
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B cells versus marginal zone B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE28737_WT_VS_BCL6_KO_FOLLICULAR_BCELL_DN
Systematic name | M9374
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B lymphocytes: wildtype versus BCL6 [GeneID=604] knockout.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_BCL6_HET_VS_BCL6_KO_FOLLICULAR_BCELL_UP
Systematic name | M9380
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B lymphocytes with BCL6 [GeneID=604] knockout: heterozygotic versus homozygotic strains.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE11961_FOLLICULAR_BCELL_VS_MARGINAL_ZONE_BCELL_UP
Systematic name | M9381
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B cells versus marginal zone B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_MEMORY_BCELL_DAY40_VS_GERMINAL_CENTER_BCELL_DAY40_DN
Systematic name | M9382
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in day 40 memory B cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE28737_WT_VS_BCL6_HET_FOLLICULAR_BCELL_DN
Systematic name | M9383
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B lymphocytes: wildtype versus heterozygotic knockout of BCL6 [GeneID=604].
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE11961_PLASMA_CELL_DAY7_VS_MEMORY_BCELL_DAY40_UP
Systematic name | M9384
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in day 7 plasma cells versus day 40 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE28737_BCL6_HET_VS_BCL6_KO_FOLLICULAR_BCELL_DN
Systematic name | M9385
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular B lymphocytes with BCL6 [GeneID=604] knockout: heterozygotic versus homozygotic strains.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE11961_MEMORY_BCELL_DAY40_VS_GERMINAL_CENTER_BCELL_DAY40_UP
Systematic name | M9386
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in day 40 memory B cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE28737_WT_VS_BCL6_KO_FOLLICULAR_BCELL_UP
Systematic name | M9390
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B lymphocytes: wildtype versus BCL6 [GeneID=604] knockout.
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE28737_WT_VS_BCL6_HET_FOLLICULAR_BCELL_UP
Systematic name | M9391
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular B lymphocytes: wildtype versus heterozygotic knockout of BCL6 [GeneID=604].
Full description | Bcl6 germline deletion causes a prominent inflammatory disease, owing to over-expression of Th2 cytokines, and affects the properties of B cells prior to immunization. Therefore we established the B cell-specific Bcl6 deletion mice and analyze the gene expression of naive B cells under physiological conditions.

Standard name | GSE11961_PLASMA_CELL_DAY7_VS_GERMINAL_CENTER_BCELL_DAY40_UP
Systematic name | M9392
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes up-regulated in day 7 plasma cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_PLASMA_CELL_DAY7_VS_GERMINAL_CENTER_BCELL_DAY40_DN
Systematic name | M9393
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in day 7 plasma cells versus day 40 germinal center B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE11961_PLASMA_CELL_DAY7_VS_MEMORY_BCELL_DAY40_DN
Systematic name | M9396
Organism | Mus musculus
PMID | 23027924
Authors | Kaji T,Ishige A,Hikida M,Taka J,Hijikata A,Kubo M,Nagashima T,Takahashi Y,Kurosaki T,Okada M,Ohara O,Rajewsky K,Takemori T
Category | C7
Sub-category |
Brief description | Genes down-regulated in day 7 plasma cells versus day 40 memory B cells.
Full description | To obtain insight into the genetic basis of the increase of functional activity of memory B cells over time, we compared the gene expression profiles of day 7 and day 40 NP-specific/IgG1 memory B cells, GC B cells and plasma cells in immunized WT mice and naïve B cells, before and after activation in vitro.

Standard name | GSE34179_THPOK_KO_VS_WT_VA14I_NKTCELL_UP
Systematic name | M9397
Organism | Mus musculus
PMID | 23034280
Authors | Engel I,Zhao M,Kappes D,Taniuchi I,Kronenberg M
Category | C7
Sub-category |
Brief description | Genes up-regulated in Va14 invariant NKT cells: ZBTB7B [GeneID=51043] knockout versus wildtype.
Full description | We sought to identify genes regulated by the transcription factor Th-POK (Zbtb7b) in liver Va14i NKT cells, by RNA microarray analysis of global gene expression in Va14i NKT cells from mice homozygous for the Th-POK-inactivating hd point mutation as compared with the same cell population isolated from heterozygous or wild-type age-matched mice.

Standard name | GSE34179_THPOK_KO_VS_WT_VA14I_NKTCELL_DN
Systematic name | M9398
Organism | Mus musculus
PMID | 23034280
Authors | Engel I,Zhao M,Kappes D,Taniuchi I,Kronenberg M
Category | C7
Sub-category |
Brief description | Genes down-regulated in Va14 invariant NKT cells: ZBTB7B [GeneID=51043] knockout versus wildtype.
Full description | We sought to identify genes regulated by the transcription factor Th-POK (Zbtb7b) in liver Va14i NKT cells, by RNA microarray analysis of global gene expression in Va14i NKT cells from mice homozygous for the Th-POK-inactivating hd point mutation as compared with the same cell population isolated from heterozygous or wild-type age-matched mice.

Standard name | GSE40493_BCL6_KO_VS_WT_TREG_UP
Systematic name | M9401
Organism | Mus musculus
PMID | 23053511
Authors | Sawant DV,Sehra S,Nguyen ET,Jadhav R,Englert K,Shinnakasu R,Hangoc G,Broxmeyer HE,Nakayama T,Perumal NB,Kaplan MH,Dent AL
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: BCL6 [GeneID=604] knockout versus wildtype.
Full description | gene expression data from wild-type and Bcl6-/- regulatory T cells in order to find genes regulated by Bcl6 in Treg cells

Standard name | GSE40493_BCL6_KO_VS_WT_TREG_DN
Systematic name | M9403
Organism | Mus musculus
PMID | 23053511
Authors | Sawant DV,Sehra S,Nguyen ET,Jadhav R,Englert K,Shinnakasu R,Hangoc G,Broxmeyer HE,Nakayama T,Perumal NB,Kaplan MH,Dent AL
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: BCL6 [GeneID=604] knockout versus wildtype.
Full description | gene expression data from wild-type and Bcl6-/- regulatory T cells in order to find genes regulated by Bcl6 in Treg cells

Standard name | GSE40184_HEALTHY_VS_HCV_INFECTED_DONOR_PBMC_DN
Systematic name | M9404
Organism | Homo sapiens
PMID | 23067362
Authors | Bolen CR,Robek MD,Brodsky L,Schulz V,Lim JK,Taylor MW,Kleinstein SH
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood monocytes (PBMC): healthy donors versus patients with HCV infection.
Full description | This study characterizes the effects of chronic Hepatitis C virus (HCV) infection on gene expression by analyzing blood samples from 10 treatment-naive HCV patients and 6 healthy volunteers. Differential expression analysis of microarray data from peripheral blood mononuclear cells (PBMCs) identified a 136 gene signature, including 66 genes elevated in infected individuals. Most of the up-regulated genes were associated with interferon (IFN) activity (including members of the OAS and MX families, ISG15 and IRF7), suggesting an ongoing immune response. This HCV signature was also found to be consistently enriched in many other viral infection and vaccination datasets. Validation of these genes was carried out using a second cohort composed of 5 HCV patients and 5 healthy volunteers, confirming the up-regulation of the IFN signature. In summary, this is the first study to directly compare blood transcriptional profiles from HCV patients with healthy controls. The results show that chronic HCV infection has a pronounced effect on gene expression in PBMCs of infected individuals, and significantly elevates the expression of a subset of interferon-stimulated genes.

Standard name | GSE40184_HEALTHY_VS_HCV_INFECTED_DONOR_PBMC_UP
Systematic name | M9405
Organism | Homo sapiens
PMID | 23067362
Authors | Bolen CR,Robek MD,Brodsky L,Schulz V,Lim JK,Taylor MW,Kleinstein SH
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood monocytes (PBMC): healthy donors versus patients with HCV infection.
Full description | This study characterizes the effects of chronic Hepatitis C virus (HCV) infection on gene expression by analyzing blood samples from 10 treatment-naive HCV patients and 6 healthy volunteers. Differential expression analysis of microarray data from peripheral blood mononuclear cells (PBMCs) identified a 136 gene signature, including 66 genes elevated in infected individuals. Most of the up-regulated genes were associated with interferon (IFN) activity (including members of the OAS and MX families, ISG15 and IRF7), suggesting an ongoing immune response. This HCV signature was also found to be consistently enriched in many other viral infection and vaccination datasets. Validation of these genes was carried out using a second cohort composed of 5 HCV patients and 5 healthy volunteers, confirming the up-regulation of the IFN signature. In summary, this is the first study to directly compare blood transcriptional profiles from HCV patients with healthy controls. The results show that chronic HCV infection has a pronounced effect on gene expression in PBMCs of infected individuals, and significantly elevates the expression of a subset of interferon-stimulated genes.

Standard name | GSE39556_CD8A_DC_VS_NK_CELL_UP
Systematic name | M9406
Organism | Mus musculus
PMID | 23084923
Authors | Baranek T,Manh TP,Alexandre Y,Maqbool MA,Cabeza JZ,Tomasello E,Crozat K,Bessou G,Zucchini N,Robbins SH,Vivier E,Kalinke U,Ferrier P,Dalod M
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A [GeneID=925] dendritic cells versus NK cells.
Full description | The injection of the pathogen-associated molecular pattern Polyinosinic-polycytidylic acid (poly(I:C)) leads to the activation of various immune cells, including dendritic cells (DCs) and Natural Killer (NK) cells. This activation is due to different innate cytokines produced early after injection, in particular IFN-I. The objective of the study was to compare the pattern of expression of IFN-I stimulated genes between DC and NK cells. The project focused on a specific subset of conventional DC, CD8a DC, which responsiveness to IFN-I determines the capacity to activate CD8 T cells by cross-presentation of exogenous antigens. To identify the responses to IFN-I selectively induced in CD8a+ DC, we compared their gene expression profile to that of NK cells, using gene chips, before and after poly(I:C) stimulation.

Standard name | GSE39556_CD8A_DC_VS_NK_CELL_DN
Systematic name | M9407
Organism | Mus musculus
PMID | 23084923
Authors | Baranek T,Manh TP,Alexandre Y,Maqbool MA,Cabeza JZ,Tomasello E,Crozat K,Bessou G,Zucchini N,Robbins SH,Vivier E,Kalinke U,Ferrier P,Dalod M
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A [GeneID=925] dendritic cells versus NK cells.
Full description | The injection of the pathogen-associated molecular pattern Polyinosinic-polycytidylic acid (poly(I:C)) leads to the activation of various immune cells, including dendritic cells (DCs) and Natural Killer (NK) cells. This activation is due to different innate cytokines produced early after injection, in particular IFN-I. The objective of the study was to compare the pattern of expression of IFN-I stimulated genes between DC and NK cells. The project focused on a specific subset of conventional DC, CD8a DC, which responsiveness to IFN-I determines the capacity to activate CD8 T cells by cross-presentation of exogenous antigens. To identify the responses to IFN-I selectively induced in CD8a+ DC, we compared their gene expression profile to that of NK cells, using gene chips, before and after poly(I:C) stimulation.

Standard name | GSE39556_UNTREATED_VS_3H_POLYIC_INJ_MOUSE_CD8A_DC_DN
Systematic name | M9408
Organism | Mus musculus
PMID | 23084923
Authors | Baranek T,Manh TP,Alexandre Y,Maqbool MA,Cabeza JZ,Tomasello E,Crozat K,Bessou G,Zucchini N,Robbins SH,Vivier E,Kalinke U,Ferrier P,Dalod M
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A [GeneID=935] dendritic cells: untreated versus poly(IC).
Full description | The injection of the pathogen-associated molecular pattern Polyinosinic-polycytidylic acid (poly(I:C)) leads to the activation of various immune cells, including dendritic cells (DCs) and Natural Killer (NK) cells. This activation is due to different innate cytokines produced early after injection, in particular IFN-I. The objective of the study was to compare the pattern of expression of IFN-I stimulated genes between DC and NK cells. The project focused on a specific subset of conventional DC, CD8a DC, which responsiveness to IFN-I determines the capacity to activate CD8 T cells by cross-presentation of exogenous antigens. To identify the responses to IFN-I selectively induced in CD8a+ DC, we compared their gene expression profile to that of NK cells, using gene chips, before and after poly(I:C) stimulation.

Standard name | GSE39556_UNTREATED_VS_3H_POLYIC_INJ_MOUSE_NK_CELL_UP
Systematic name | M9410
Organism | Mus musculus
PMID | 23084923
Authors | Baranek T,Manh TP,Alexandre Y,Maqbool MA,Cabeza JZ,Tomasello E,Crozat K,Bessou G,Zucchini N,Robbins SH,Vivier E,Kalinke U,Ferrier P,Dalod M
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells: untreated versus poly(IC).
Full description | The injection of the pathogen-associated molecular pattern Polyinosinic-polycytidylic acid (poly(I:C)) leads to the activation of various immune cells, including dendritic cells (DCs) and Natural Killer (NK) cells. This activation is due to different innate cytokines produced early after injection, in particular IFN-I. The objective of the study was to compare the pattern of expression of IFN-I stimulated genes between DC and NK cells. The project focused on a specific subset of conventional DC, CD8a DC, which responsiveness to IFN-I determines the capacity to activate CD8 T cells by cross-presentation of exogenous antigens. To identify the responses to IFN-I selectively induced in CD8a+ DC, we compared their gene expression profile to that of NK cells, using gene chips, before and after poly(I:C) stimulation.

Standard name | GSE39556_UNTREATED_VS_3H_POLYIC_INJ_MOUSE_NK_CELL_DN
Systematic name | M9411
Organism | Mus musculus
PMID | 23084923
Authors | Baranek T,Manh TP,Alexandre Y,Maqbool MA,Cabeza JZ,Tomasello E,Crozat K,Bessou G,Zucchini N,Robbins SH,Vivier E,Kalinke U,Ferrier P,Dalod M
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells: untreated versus poly(IC).
Full description | The injection of the pathogen-associated molecular pattern Polyinosinic-polycytidylic acid (poly(I:C)) leads to the activation of various immune cells, including dendritic cells (DCs) and Natural Killer (NK) cells. This activation is due to different innate cytokines produced early after injection, in particular IFN-I. The objective of the study was to compare the pattern of expression of IFN-I stimulated genes between DC and NK cells. The project focused on a specific subset of conventional DC, CD8a DC, which responsiveness to IFN-I determines the capacity to activate CD8 T cells by cross-presentation of exogenous antigens. To identify the responses to IFN-I selectively induced in CD8a+ DC, we compared their gene expression profile to that of NK cells, using gene chips, before and after poly(I:C) stimulation.

Standard name | GSE39556_UNTREATED_VS_3H_POLYIC_INJ_MOUSE_CD8A_DC_UP
Systematic name | M9414
Organism | Mus musculus
PMID | 23084923
Authors | Baranek T,Manh TP,Alexandre Y,Maqbool MA,Cabeza JZ,Tomasello E,Crozat K,Bessou G,Zucchini N,Robbins SH,Vivier E,Kalinke U,Ferrier P,Dalod M
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A [GeneID=935] dendritic cells: untreated versus poly(IC).
Full description | The injection of the pathogen-associated molecular pattern Polyinosinic-polycytidylic acid (poly(I:C)) leads to the activation of various immune cells, including dendritic cells (DCs) and Natural Killer (NK) cells. This activation is due to different innate cytokines produced early after injection, in particular IFN-I. The objective of the study was to compare the pattern of expression of IFN-I stimulated genes between DC and NK cells. The project focused on a specific subset of conventional DC, CD8a DC, which responsiveness to IFN-I determines the capacity to activate CD8 T cells by cross-presentation of exogenous antigens. To identify the responses to IFN-I selectively induced in CD8a+ DC, we compared their gene expression profile to that of NK cells, using gene chips, before and after poly(I:C) stimulation.

Standard name | GSE39556_CD8A_DC_VS_NK_CELL_MOUSE_3H_POST_POLYIC_INJ_DN
Systematic name | M9418
Organism | Mus musculus
PMID | 23084923
Authors | Baranek T,Manh TP,Alexandre Y,Maqbool MA,Cabeza JZ,Tomasello E,Crozat K,Bessou G,Zucchini N,Robbins SH,Vivier E,Kalinke U,Ferrier P,Dalod M
Category | C7
Sub-category |
Brief description | Genes down-regulated after poly(IC) injection: CD8A [GeneID=925] dendritic cells versus NK cells.
Full description | The injection of the pathogen-associated molecular pattern Polyinosinic-polycytidylic acid (poly(I:C)) leads to the activation of various immune cells, including dendritic cells (DCs) and Natural Killer (NK) cells. This activation is due to different innate cytokines produced early after injection, in particular IFN-I. The objective of the study was to compare the pattern of expression of IFN-I stimulated genes between DC and NK cells. The project focused on a specific subset of conventional DC, CD8a DC, which responsiveness to IFN-I determines the capacity to activate CD8 T cells by cross-presentation of exogenous antigens. To identify the responses to IFN-I selectively induced in CD8a+ DC, we compared their gene expression profile to that of NK cells, using gene chips, before and after poly(I:C) stimulation.

Standard name | GSE39556_CD8A_DC_VS_NK_CELL_MOUSE_3H_POST_POLYIC_INJ_UP
Systematic name | M9419
Organism | Mus musculus
PMID | 23084923
Authors | Baranek T,Manh TP,Alexandre Y,Maqbool MA,Cabeza JZ,Tomasello E,Crozat K,Bessou G,Zucchini N,Robbins SH,Vivier E,Kalinke U,Ferrier P,Dalod M
Category | C7
Sub-category |
Brief description | Genes up-regulated after poly(IC) injection: CD8A [GeneID=925] dendritic cells versus NK cells.
Full description | The injection of the pathogen-associated molecular pattern Polyinosinic-polycytidylic acid (poly(I:C)) leads to the activation of various immune cells, including dendritic cells (DCs) and Natural Killer (NK) cells. This activation is due to different innate cytokines produced early after injection, in particular IFN-I. The objective of the study was to compare the pattern of expression of IFN-I stimulated genes between DC and NK cells. The project focused on a specific subset of conventional DC, CD8a DC, which responsiveness to IFN-I determines the capacity to activate CD8 T cells by cross-presentation of exogenous antigens. To identify the responses to IFN-I selectively induced in CD8a+ DC, we compared their gene expression profile to that of NK cells, using gene chips, before and after poly(I:C) stimulation.

Standard name | GSE33292_WT_VS_TCF1_KO_DN3_THYMOCYTE_UP
Systematic name | M9420
Organism | Mus musculus
PMID | 23103132
Authors | Yu S,Zhou X,Steinke FC,Liu C,Chen SC,Zagorodna O,Jing X,Yokota Y,Meyerholz DK,Mullighan CG,Knudson CM,Zhao DM,Xue HH
Category | C7
Sub-category |
Brief description | Genes up-regulated in DN3 thymocytes: wildtype versus TCF7 [GeneID=6932] knockout.
Full description | TCF-1 is an HMG family transcription factor which is known to be critical for T cell development. We discovered that it has a unique role in suppressing malignant transformation of developing thymocytes at early stages. We identified ID2 and LEF-1 as key TCF-1 target genens in tumor suppression. We used microarrays to detect gene expression changes in WT and TCF-1 deficient DN3 thymocytes as well as T cell lymphoma cells developed in TCF-1 KO mice.

Standard name | GSE33292_WT_VS_TCF1_KO_DN3_THYMOCYTE_DN
Systematic name | M9422
Organism | Mus musculus
PMID | 23103132
Authors | Yu S,Zhou X,Steinke FC,Liu C,Chen SC,Zagorodna O,Jing X,Yokota Y,Meyerholz DK,Mullighan CG,Knudson CM,Zhao DM,Xue HH
Category | C7
Sub-category |
Brief description | Genes down-regulated in DN3 thymocytes: wildtype versus TCF7 [GeneID=6932] knockout.
Full description | TCF-1 is an HMG family transcription factor which is known to be critical for T cell development. We discovered that it has a unique role in suppressing malignant transformation of developing thymocytes at early stages. We identified ID2 and LEF-1 as key TCF-1 target genens in tumor suppression. We used microarrays to detect gene expression changes in WT and TCF-1 deficient DN3 thymocytes as well as T cell lymphoma cells developed in TCF-1 KO mice.

Standard name | GSE33292_DN3_THYMOCYTE_VS_TCELL_LYMPHOMA_FROM_TCF1_KO_DN
Systematic name | M9423
Organism | Mus musculus
PMID | 23103132
Authors | Yu S,Zhou X,Steinke FC,Liu C,Chen SC,Zagorodna O,Jing X,Yokota Y,Meyerholz DK,Mullighan CG,Knudson CM,Zhao DM,Xue HH
Category | C7
Sub-category |
Brief description | Genes down-regulated in TCF7 [GeneID=6932] knockout: DN3 thymocytes versus T cell lymphoma cells.
Full description | TCF-1 is an HMG family transcription factor which is known to be critical for T cell development. We discovered that it has a unique role in suppressing malignant transformation of developing thymocytes at early stages. We identified ID2 and LEF-1 as key TCF-1 target genens in tumor suppression. We used microarrays to detect gene expression changes in WT and TCF-1 deficient DN3 thymocytes as well as T cell lymphoma cells developed in TCF-1 KO mice.

Standard name | GSE33292_DN3_THYMOCYTE_VS_TCF1_KO_TCELL_LYMPHOMA_UP
Systematic name | M9424
Organism | Mus musculus
PMID | 23103132
Authors | Yu S,Zhou X,Steinke FC,Liu C,Chen SC,Zagorodna O,Jing X,Yokota Y,Meyerholz DK,Mullighan CG,Knudson CM,Zhao DM,Xue HH
Category | C7
Sub-category |
Brief description | Genes up-regulated in wildtype DN3 thymocytes versus T cell lymphoma cells from TCF7 [GeneID=6932] knockout.
Full description | TCF-1 is an HMG family transcription factor which is known to be critical for T cell development. We discovered that it has a unique role in suppressing malignant transformation of developing thymocytes at early stages. We identified ID2 and LEF-1 as key TCF-1 target genens in tumor suppression. We used microarrays to detect gene expression changes in WT and TCF-1 deficient DN3 thymocytes as well as T cell lymphoma cells developed in TCF-1 KO mice.

Standard name | GSE33292_DN3_THYMOCYTE_VS_TCELL_LYMPHOMA_FROM_TCF1_KO_UP
Systematic name | M9425
Organism | Mus musculus
PMID | 23103132
Authors | Yu S,Zhou X,Steinke FC,Liu C,Chen SC,Zagorodna O,Jing X,Yokota Y,Meyerholz DK,Mullighan CG,Knudson CM,Zhao DM,Xue HH
Category | C7
Sub-category |
Brief description | Genes up-regulated in TCF7 [GeneID=6932] knockout: DN3 thymocytes versus T cell lymphoma cells.
Full description | TCF-1 is an HMG family transcription factor which is known to be critical for T cell development. We discovered that it has a unique role in suppressing malignant transformation of developing thymocytes at early stages. We identified ID2 and LEF-1 as key TCF-1 target genens in tumor suppression. We used microarrays to detect gene expression changes in WT and TCF-1 deficient DN3 thymocytes as well as T cell lymphoma cells developed in TCF-1 KO mice.

Standard name | GSE33292_DN3_THYMOCYTE_VS_TCF1_KO_TCELL_LYMPHOMA_DN
Systematic name | M9427
Organism | Mus musculus
PMID | 23103132
Authors | Yu S,Zhou X,Steinke FC,Liu C,Chen SC,Zagorodna O,Jing X,Yokota Y,Meyerholz DK,Mullighan CG,Knudson CM,Zhao DM,Xue HH
Category | C7
Sub-category |
Brief description | Genes down-regulated in wildtype DN3 thymocytes versus T cell lymphoma cells from TCF7 [GeneID=6932] knockout.
Full description | TCF-1 is an HMG family transcription factor which is known to be critical for T cell development. We discovered that it has a unique role in suppressing malignant transformation of developing thymocytes at early stages. We identified ID2 and LEF-1 as key TCF-1 target genens in tumor suppression. We used microarrays to detect gene expression changes in WT and TCF-1 deficient DN3 thymocytes as well as T cell lymphoma cells developed in TCF-1 KO mice.

Standard name | GSE35543_IN_VIVO_NTREG_VS_IN_VITRO_ITREG_DN
Systematic name | M9428
Organism | Mus musculus
PMID | 23125413
Authors | Schmitt EG,Haribhai D,Williams JB,Aggarwal P,Jia S,Charbonnier LM,Yan K,Lorier R,Turner A,Ziegelbauer J,Georgiev P,Simpson P,Salzman NH,Hessner MJ,Broeckel U,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: in vivo versus in vitro.
Full description | Induced Treg (iTreg) cells are essential for tolerance and can be used therapeutically, yet their stability in vivo and mechanisms of suppression are unresolved. Here, we used a treatment model of colitis to examine the role of autologous IL-10 in iTreg cell function. Mice treated with IL-10+/+ iTreg cells in combination with IL-10–/– natural Treg (nTreg) cells survived and gained weight, even though iTreg cells were numerically disadvantaged and comprised just ~20% of all Treg cells in treated mice. Notably, ~85% of the transferred iTreg cells lost Foxp3 expression (ex-iTreg) but retained a portion of the iTreg transcriptome which failed to limit their pathogenic potential. The TCR repertoires of iTreg and ex-iTreg cells exhibited almost no overlap, which indicates that the two populations are clonally unrelated and maintained by different selective pressures. These data demonstrate a potent and critical role for iTreg cell produced IL-10 that can supplant the IL-10 produced by nTreg cells and compensate for the inherent instability of the iTreg population.

Standard name | GSE35543_IN_VIVO_NTREG_VS_CONVERTED_EX_ITREG_UP
Systematic name | M9429
Organism | Mus musculus
PMID | 23125413
Authors | Schmitt EG,Haribhai D,Williams JB,Aggarwal P,Jia S,Charbonnier LM,Yan K,Lorier R,Turner A,Ziegelbauer J,Georgiev P,Simpson P,Salzman NH,Hessner MJ,Broeckel U,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison between in vivo derived natural T reg (nTreg) and converted ex-iTreg (induced T reg that lost FOXP3 [GeneID=50943] expression).
Full description | Induced Treg (iTreg) cells are essential for tolerance and can be used therapeutically, yet their stability in vivo and mechanisms of suppression are unresolved. Here, we used a treatment model of colitis to examine the role of autologous IL-10 in iTreg cell function. Mice treated with IL-10+/+ iTreg cells in combination with IL-10–/– natural Treg (nTreg) cells survived and gained weight, even though iTreg cells were numerically disadvantaged and comprised just ~20% of all Treg cells in treated mice. Notably, ~85% of the transferred iTreg cells lost Foxp3 expression (ex-iTreg) but retained a portion of the iTreg transcriptome which failed to limit their pathogenic potential. The TCR repertoires of iTreg and ex-iTreg cells exhibited almost no overlap, which indicates that the two populations are clonally unrelated and maintained by different selective pressures. These data demonstrate a potent and critical role for iTreg cell produced IL-10 that can supplant the IL-10 produced by nTreg cells and compensate for the inherent instability of the iTreg population.

Standard name | GSE35543_IN_VIVO_NTREG_VS_IN_VITRO_ITREG_UP
Systematic name | M9430
Organism | Mus musculus
PMID | 23125413
Authors | Schmitt EG,Haribhai D,Williams JB,Aggarwal P,Jia S,Charbonnier LM,Yan K,Lorier R,Turner A,Ziegelbauer J,Georgiev P,Simpson P,Salzman NH,Hessner MJ,Broeckel U,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: in vivo versus in vitro.
Full description | Induced Treg (iTreg) cells are essential for tolerance and can be used therapeutically, yet their stability in vivo and mechanisms of suppression are unresolved. Here, we used a treatment model of colitis to examine the role of autologous IL-10 in iTreg cell function. Mice treated with IL-10+/+ iTreg cells in combination with IL-10–/– natural Treg (nTreg) cells survived and gained weight, even though iTreg cells were numerically disadvantaged and comprised just ~20% of all Treg cells in treated mice. Notably, ~85% of the transferred iTreg cells lost Foxp3 expression (ex-iTreg) but retained a portion of the iTreg transcriptome which failed to limit their pathogenic potential. The TCR repertoires of iTreg and ex-iTreg cells exhibited almost no overlap, which indicates that the two populations are clonally unrelated and maintained by different selective pressures. These data demonstrate a potent and critical role for iTreg cell produced IL-10 that can supplant the IL-10 produced by nTreg cells and compensate for the inherent instability of the iTreg population.

Standard name | GSE35543_IN_VIVO_NTREG_VS_CONVERTED_EX_ITREG_DN
Systematic name | M9434
Organism | Mus musculus
PMID | 23125413
Authors | Schmitt EG,Haribhai D,Williams JB,Aggarwal P,Jia S,Charbonnier LM,Yan K,Lorier R,Turner A,Ziegelbauer J,Georgiev P,Simpson P,Salzman NH,Hessner MJ,Broeckel U,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison between in vivo derived natural T reg (nTreg) and converted ex-iTreg (induced T reg that lost FOXP3 [GeneID=50943] expression).
Full description | Induced Treg (iTreg) cells are essential for tolerance and can be used therapeutically, yet their stability in vivo and mechanisms of suppression are unresolved. Here, we used a treatment model of colitis to examine the role of autologous IL-10 in iTreg cell function. Mice treated with IL-10+/+ iTreg cells in combination with IL-10–/– natural Treg (nTreg) cells survived and gained weight, even though iTreg cells were numerically disadvantaged and comprised just ~20% of all Treg cells in treated mice. Notably, ~85% of the transferred iTreg cells lost Foxp3 expression (ex-iTreg) but retained a portion of the iTreg transcriptome which failed to limit their pathogenic potential. The TCR repertoires of iTreg and ex-iTreg cells exhibited almost no overlap, which indicates that the two populations are clonally unrelated and maintained by different selective pressures. These data demonstrate a potent and critical role for iTreg cell produced IL-10 that can supplant the IL-10 produced by nTreg cells and compensate for the inherent instability of the iTreg population.

Standard name | GSE35543_IN_VITRO_ITREG_VS_CONVERTED_EX_ITREG_DN
Systematic name | M9436
Organism | Mus musculus
PMID | 23125413
Authors | Schmitt EG,Haribhai D,Williams JB,Aggarwal P,Jia S,Charbonnier LM,Yan K,Lorier R,Turner A,Ziegelbauer J,Georgiev P,Simpson P,Salzman NH,Hessner MJ,Broeckel U,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes down-regulated in comparison between in vitro derived induced T reg (iTreg) and converted ex iTreg.
Full description | Induced Treg (iTreg) cells are essential for tolerance and can be used therapeutically, yet their stability in vivo and mechanisms of suppression are unresolved. Here, we used a treatment model of colitis to examine the role of autologous IL-10 in iTreg cell function. Mice treated with IL-10+/+ iTreg cells in combination with IL-10–/– natural Treg (nTreg) cells survived and gained weight, even though iTreg cells were numerically disadvantaged and comprised just ~20% of all Treg cells in treated mice. Notably, ~85% of the transferred iTreg cells lost Foxp3 expression (ex-iTreg) but retained a portion of the iTreg transcriptome which failed to limit their pathogenic potential. The TCR repertoires of iTreg and ex-iTreg cells exhibited almost no overlap, which indicates that the two populations are clonally unrelated and maintained by different selective pressures. These data demonstrate a potent and critical role for iTreg cell produced IL-10 that can supplant the IL-10 produced by nTreg cells and compensate for the inherent instability of the iTreg population.

Standard name | GSE35543_IN_VITRO_ITREG_VS_CONVERTED_EX_ITREG_UP
Systematic name | M9437
Organism | Mus musculus
PMID | 23125413
Authors | Schmitt EG,Haribhai D,Williams JB,Aggarwal P,Jia S,Charbonnier LM,Yan K,Lorier R,Turner A,Ziegelbauer J,Georgiev P,Simpson P,Salzman NH,Hessner MJ,Broeckel U,Chatila TA,Williams CB
Category | C7
Sub-category |
Brief description | Genes up-regulated in comparison between in vitro derived induced T reg (iTreg) and converted ex iTreg.
Full description | Induced Treg (iTreg) cells are essential for tolerance and can be used therapeutically, yet their stability in vivo and mechanisms of suppression are unresolved. Here, we used a treatment model of colitis to examine the role of autologous IL-10 in iTreg cell function. Mice treated with IL-10+/+ iTreg cells in combination with IL-10–/– natural Treg (nTreg) cells survived and gained weight, even though iTreg cells were numerically disadvantaged and comprised just ~20% of all Treg cells in treated mice. Notably, ~85% of the transferred iTreg cells lost Foxp3 expression (ex-iTreg) but retained a portion of the iTreg transcriptome which failed to limit their pathogenic potential. The TCR repertoires of iTreg and ex-iTreg cells exhibited almost no overlap, which indicates that the two populations are clonally unrelated and maintained by different selective pressures. These data demonstrate a potent and critical role for iTreg cell produced IL-10 that can supplant the IL-10 produced by nTreg cells and compensate for the inherent instability of the iTreg population.

Standard name | GSE40655_FOXO1_KO_VS_WT_NTREG_UP
Systematic name | M9439
Organism | Mus musculus
PMID | 23135404
Authors | Ouyang W,Liao W,Luo CT,Yin N,Huse M,Kim MV,Peng M,Chan P,Ma Q,Mo Y,Meijer D,Zhao K,Rudensky AY,Atwal G,Zhang MQ,Li MO
Category | C7
Sub-category |
Brief description | Genes up-regulated in normal T reg (nTreg): FOXO1 [GeneID=2308] versus wildtype.
Full description | Regulatory T (Treg) cells characterized by expression of the transcription factor forkhead box P3 (Foxp3) maintain immune homeostasis by suppressing self-destructive immune responses1-4. Foxp3 operates as a late acting differentiation factor controlling Treg cell homeostasis and function5, whereas the early Treg cell lineage commitment is regulated by the Akt kinase and the forkhead box O (Foxo) family of transcription factors6-10. However, whether Foxo proteins act beyond the Treg cell commitment stage to control Treg cell homeostasis and function remains largely unexplored. Here we show that Foxo1 is a pivotal regulator of Treg cell function. Treg cells express high amounts of Foxo1, and display reduced T-cell receptor-induced Akt activation, Foxo1 phosphorylation, and Foxo1 nuclear exclusion. Mice with Treg cell-specific deletion of Foxo1 develop a fatal inflammatory disorder similar in severity to Foxp3-deficient mice, but without the loss of Treg cells. Genome-wide analysis of Foxo1 binding sites reveals ~300 Foxo1-bound target genes, including the proinflammatory cytokine Ifng, that do not appear to be directly regulated by Foxp3. These findings demonstrate that the evolutionarily ancient Akt-Foxo1 signaling module controls a novel genetic program indispensable for Treg cell function.

Standard name | GSE40655_FOXO1_KO_VS_WT_NTREG_DN
Systematic name | M9441
Organism | Mus musculus
PMID | 23135404
Authors | Ouyang W,Liao W,Luo CT,Yin N,Huse M,Kim MV,Peng M,Chan P,Ma Q,Mo Y,Meijer D,Zhao K,Rudensky AY,Atwal G,Zhang MQ,Li MO
Category | C7
Sub-category |
Brief description | Genes down-regulated in normal T reg (nTreg): FOXO1 [GeneID=2308] versus wildtype.
Full description | Regulatory T (Treg) cells characterized by expression of the transcription factor forkhead box P3 (Foxp3) maintain immune homeostasis by suppressing self-destructive immune responses1-4. Foxp3 operates as a late acting differentiation factor controlling Treg cell homeostasis and function5, whereas the early Treg cell lineage commitment is regulated by the Akt kinase and the forkhead box O (Foxo) family of transcription factors6-10. However, whether Foxo proteins act beyond the Treg cell commitment stage to control Treg cell homeostasis and function remains largely unexplored. Here we show that Foxo1 is a pivotal regulator of Treg cell function. Treg cells express high amounts of Foxo1, and display reduced T-cell receptor-induced Akt activation, Foxo1 phosphorylation, and Foxo1 nuclear exclusion. Mice with Treg cell-specific deletion of Foxo1 develop a fatal inflammatory disorder similar in severity to Foxp3-deficient mice, but without the loss of Treg cells. Genome-wide analysis of Foxo1 binding sites reveals ~300 Foxo1-bound target genes, including the proinflammatory cytokine Ifng, that do not appear to be directly regulated by Foxp3. These findings demonstrate that the evolutionarily ancient Akt-Foxo1 signaling module controls a novel genetic program indispensable for Treg cell function.

Standard name | GSE24671_CTRL_VS_SENDAI_VIRUS_INFECTED_MOUSE_SPLENOCYTES_DN
Systematic name | M9443
Organism | Mus musculus
PMID | 23142781
Authors | Yu P,Lübben W,Slomka H,Gebler J,Konert M,Cai C,Neubrandt L,Costa da Prazeres O,Paul S,Dehnert S,Döhne K,Thanisch M,Storsberg S,Wiegand L,Kaufmann A,Nain M,Quintanilla-Martinez L,Bettio S,Schnierle B,Kolesnikova L,Becker S,Schnare M,Bauer S
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenocytes: control versus infected with Sendai virus.
Full description | The genome of vertebrates contains endogenous retroviruses (ERVs) that have resulted from ancestral infections by exogenous retroviruses. ERVs are germline encoded, transmitted in a Mendelian fashion and account for about 8% of the human and 9.9% of the murine genome, respectively1, 2. By spontaneous activation and reintegration ERVs may cause insertional mutagenesis and thus participate in the process of malignant transformation or progression of tumor growth3, 4. However, if the innate immune system is able to recognize and control ERVs has not yet been elucidated. Here we report that, in vitro, nucleic-acid sensing TLRs on dendritic cells are activated by retroviral RNA and DNA from infected cells in vitro. Infection of TLR competent wild type mice with murine leukemia virus (MuLV)-like ERV isolates results in non-canonical gene upregulation, independent of type I IFN. In vivo, TLR3, -7 and -9 triple deficient mice (TLR379-/-) and mice with non functional TLR3, 7 and 9 signaling due to a mutation in UNC93B develop spontaneous ERV-induced viremia. More importantly, in TLR379-/- mice ERV-induced viremia correlates with acute T cell lymphoblastic leukemia (T-ALL). Multiple independent TLR379-/- T cell leukemia lines produce infectious MuLV of endogenous origin. These cell lines display de novo retroviral integration into the Nup214 or Notch1 gene locus leading to gene dysregulation that is reminiscent of aberrant Nup214 and Notch1 expression in human T-ALLs5. Overall, our results demonstrate that in addition to their role in innate immune defense against exogenous pathogens, TLR3,-7, and -9 may be essential for the control of endogenous retroviral mediated T-cell lymphomagenesis.

Standard name | GSE24671_BAKIMULC_VS_SENDAI_VIRUS_INFECTED_MOUSE_SPLENOCYTES_UP
Systematic name | M9444
Organism | Mus musculus
PMID | 23142781
Authors | Yu P,Lübben W,Slomka H,Gebler J,Konert M,Cai C,Neubrandt L,Costa da Prazeres O,Paul S,Dehnert S,Döhne K,Thanisch M,Storsberg S,Wiegand L,Kaufmann A,Nain M,Quintanilla-Martinez L,Bettio S,Schnierle B,Kolesnikova L,Becker S,Schnare M,Bauer S
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenocytes with viral infection: Baki-1 MuLV versus Sendai.
Full description | The genome of vertebrates contains endogenous retroviruses (ERVs) that have resulted from ancestral infections by exogenous retroviruses. ERVs are germline encoded, transmitted in a Mendelian fashion and account for about 8% of the human and 9.9% of the murine genome, respectively1, 2. By spontaneous activation and reintegration ERVs may cause insertional mutagenesis and thus participate in the process of malignant transformation or progression of tumor growth3, 4. However, if the innate immune system is able to recognize and control ERVs has not yet been elucidated. Here we report that, in vitro, nucleic-acid sensing TLRs on dendritic cells are activated by retroviral RNA and DNA from infected cells in vitro. Infection of TLR competent wild type mice with murine leukemia virus (MuLV)-like ERV isolates results in non-canonical gene upregulation, independent of type I IFN. In vivo, TLR3, -7 and -9 triple deficient mice (TLR379-/-) and mice with non functional TLR3, 7 and 9 signaling due to a mutation in UNC93B develop spontaneous ERV-induced viremia. More importantly, in TLR379-/- mice ERV-induced viremia correlates with acute T cell lymphoblastic leukemia (T-ALL). Multiple independent TLR379-/- T cell leukemia lines produce infectious MuLV of endogenous origin. These cell lines display de novo retroviral integration into the Nup214 or Notch1 gene locus leading to gene dysregulation that is reminiscent of aberrant Nup214 and Notch1 expression in human T-ALLs5. Overall, our results demonstrate that in addition to their role in innate immune defense against exogenous pathogens, TLR3,-7, and -9 may be essential for the control of endogenous retroviral mediated T-cell lymphomagenesis.

Standard name | GSE24671_CTRL_VS_BAKIMULC_INFECTED_MOUSE_SPLENOCYTES_DN
Systematic name | M9445
Organism | Mus musculus
PMID | 23142781
Authors | Yu P,Lübben W,Slomka H,Gebler J,Konert M,Cai C,Neubrandt L,Costa da Prazeres O,Paul S,Dehnert S,Döhne K,Thanisch M,Storsberg S,Wiegand L,Kaufmann A,Nain M,Quintanilla-Martinez L,Bettio S,Schnierle B,Kolesnikova L,Becker S,Schnare M,Bauer S
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenocytes: control versus infected with Baki-1 MuLV virus.
Full description | The genome of vertebrates contains endogenous retroviruses (ERVs) that have resulted from ancestral infections by exogenous retroviruses. ERVs are germline encoded, transmitted in a Mendelian fashion and account for about 8% of the human and 9.9% of the murine genome, respectively1, 2. By spontaneous activation and reintegration ERVs may cause insertional mutagenesis and thus participate in the process of malignant transformation or progression of tumor growth3, 4. However, if the innate immune system is able to recognize and control ERVs has not yet been elucidated. Here we report that, in vitro, nucleic-acid sensing TLRs on dendritic cells are activated by retroviral RNA and DNA from infected cells in vitro. Infection of TLR competent wild type mice with murine leukemia virus (MuLV)-like ERV isolates results in non-canonical gene upregulation, independent of type I IFN. In vivo, TLR3, -7 and -9 triple deficient mice (TLR379-/-) and mice with non functional TLR3, 7 and 9 signaling due to a mutation in UNC93B develop spontaneous ERV-induced viremia. More importantly, in TLR379-/- mice ERV-induced viremia correlates with acute T cell lymphoblastic leukemia (T-ALL). Multiple independent TLR379-/- T cell leukemia lines produce infectious MuLV of endogenous origin. These cell lines display de novo retroviral integration into the Nup214 or Notch1 gene locus leading to gene dysregulation that is reminiscent of aberrant Nup214 and Notch1 expression in human T-ALLs5. Overall, our results demonstrate that in addition to their role in innate immune defense against exogenous pathogens, TLR3,-7, and -9 may be essential for the control of endogenous retroviral mediated T-cell lymphomagenesis.

Standard name | GSE24671_CTRL_VS_SENDAI_VIRUS_INFECTED_MOUSE_SPLENOCYTES_UP
Systematic name | M9446
Organism | Mus musculus
PMID | 23142781
Authors | Yu P,Lübben W,Slomka H,Gebler J,Konert M,Cai C,Neubrandt L,Costa da Prazeres O,Paul S,Dehnert S,Döhne K,Thanisch M,Storsberg S,Wiegand L,Kaufmann A,Nain M,Quintanilla-Martinez L,Bettio S,Schnierle B,Kolesnikova L,Becker S,Schnare M,Bauer S
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenocytes: control versus infected with Sendai virus.
Full description | The genome of vertebrates contains endogenous retroviruses (ERVs) that have resulted from ancestral infections by exogenous retroviruses. ERVs are germline encoded, transmitted in a Mendelian fashion and account for about 8% of the human and 9.9% of the murine genome, respectively1, 2. By spontaneous activation and reintegration ERVs may cause insertional mutagenesis and thus participate in the process of malignant transformation or progression of tumor growth3, 4. However, if the innate immune system is able to recognize and control ERVs has not yet been elucidated. Here we report that, in vitro, nucleic-acid sensing TLRs on dendritic cells are activated by retroviral RNA and DNA from infected cells in vitro. Infection of TLR competent wild type mice with murine leukemia virus (MuLV)-like ERV isolates results in non-canonical gene upregulation, independent of type I IFN. In vivo, TLR3, -7 and -9 triple deficient mice (TLR379-/-) and mice with non functional TLR3, 7 and 9 signaling due to a mutation in UNC93B develop spontaneous ERV-induced viremia. More importantly, in TLR379-/- mice ERV-induced viremia correlates with acute T cell lymphoblastic leukemia (T-ALL). Multiple independent TLR379-/- T cell leukemia lines produce infectious MuLV of endogenous origin. These cell lines display de novo retroviral integration into the Nup214 or Notch1 gene locus leading to gene dysregulation that is reminiscent of aberrant Nup214 and Notch1 expression in human T-ALLs5. Overall, our results demonstrate that in addition to their role in innate immune defense against exogenous pathogens, TLR3,-7, and -9 may be essential for the control of endogenous retroviral mediated T-cell lymphomagenesis.

Standard name | GSE24671_CTRL_VS_BAKIMULC_INFECTED_MOUSE_SPLENOCYTES_UP
Systematic name | M9447
Organism | Mus musculus
PMID | 23142781
Authors | Yu P,Lübben W,Slomka H,Gebler J,Konert M,Cai C,Neubrandt L,Costa da Prazeres O,Paul S,Dehnert S,Döhne K,Thanisch M,Storsberg S,Wiegand L,Kaufmann A,Nain M,Quintanilla-Martinez L,Bettio S,Schnierle B,Kolesnikova L,Becker S,Schnare M,Bauer S
Category | C7
Sub-category |
Brief description | Genes up-regulated in splenocytes: control versus infected with Baki-1 MuLV virus.
Full description | The genome of vertebrates contains endogenous retroviruses (ERVs) that have resulted from ancestral infections by exogenous retroviruses. ERVs are germline encoded, transmitted in a Mendelian fashion and account for about 8% of the human and 9.9% of the murine genome, respectively1, 2. By spontaneous activation and reintegration ERVs may cause insertional mutagenesis and thus participate in the process of malignant transformation or progression of tumor growth3, 4. However, if the innate immune system is able to recognize and control ERVs has not yet been elucidated. Here we report that, in vitro, nucleic-acid sensing TLRs on dendritic cells are activated by retroviral RNA and DNA from infected cells in vitro. Infection of TLR competent wild type mice with murine leukemia virus (MuLV)-like ERV isolates results in non-canonical gene upregulation, independent of type I IFN. In vivo, TLR3, -7 and -9 triple deficient mice (TLR379-/-) and mice with non functional TLR3, 7 and 9 signaling due to a mutation in UNC93B develop spontaneous ERV-induced viremia. More importantly, in TLR379-/- mice ERV-induced viremia correlates with acute T cell lymphoblastic leukemia (T-ALL). Multiple independent TLR379-/- T cell leukemia lines produce infectious MuLV of endogenous origin. These cell lines display de novo retroviral integration into the Nup214 or Notch1 gene locus leading to gene dysregulation that is reminiscent of aberrant Nup214 and Notch1 expression in human T-ALLs5. Overall, our results demonstrate that in addition to their role in innate immune defense against exogenous pathogens, TLR3,-7, and -9 may be essential for the control of endogenous retroviral mediated T-cell lymphomagenesis.

Standard name | GSE24671_BAKIMULC_VS_SENDAI_VIRUS_INFECTED_MOUSE_SPLENOCYTES_DN
Systematic name | M9448
Organism | Mus musculus
PMID | 23142781
Authors | Yu P,Lübben W,Slomka H,Gebler J,Konert M,Cai C,Neubrandt L,Costa da Prazeres O,Paul S,Dehnert S,Döhne K,Thanisch M,Storsberg S,Wiegand L,Kaufmann A,Nain M,Quintanilla-Martinez L,Bettio S,Schnierle B,Kolesnikova L,Becker S,Schnare M,Bauer S
Category | C7
Sub-category |
Brief description | Genes down-regulated in splenocytes with viral infection: Baki-1 MuLV versus Sendai.
Full description | The genome of vertebrates contains endogenous retroviruses (ERVs) that have resulted from ancestral infections by exogenous retroviruses. ERVs are germline encoded, transmitted in a Mendelian fashion and account for about 8% of the human and 9.9% of the murine genome, respectively1, 2. By spontaneous activation and reintegration ERVs may cause insertional mutagenesis and thus participate in the process of malignant transformation or progression of tumor growth3, 4. However, if the innate immune system is able to recognize and control ERVs has not yet been elucidated. Here we report that, in vitro, nucleic-acid sensing TLRs on dendritic cells are activated by retroviral RNA and DNA from infected cells in vitro. Infection of TLR competent wild type mice with murine leukemia virus (MuLV)-like ERV isolates results in non-canonical gene upregulation, independent of type I IFN. In vivo, TLR3, -7 and -9 triple deficient mice (TLR379-/-) and mice with non functional TLR3, 7 and 9 signaling due to a mutation in UNC93B develop spontaneous ERV-induced viremia. More importantly, in TLR379-/- mice ERV-induced viremia correlates with acute T cell lymphoblastic leukemia (T-ALL). Multiple independent TLR379-/- T cell leukemia lines produce infectious MuLV of endogenous origin. These cell lines display de novo retroviral integration into the Nup214 or Notch1 gene locus leading to gene dysregulation that is reminiscent of aberrant Nup214 and Notch1 expression in human T-ALLs5. Overall, our results demonstrate that in addition to their role in innate immune defense against exogenous pathogens, TLR3,-7, and -9 may be essential for the control of endogenous retroviral mediated T-cell lymphomagenesis.

Standard name | GSE41867_DAY8_VS_DAY15_LCMV_CLONE13_EFFECTOR_CD8_TCELL_UP
Systematic name | M9449
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T effector cells during chronic infection with LCMV-Clone 13: day 8 versus day 15.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY8_VS_DAY15_LCMV_CLONE13_EFFECTOR_CD8_TCELL_DN
Systematic name | M9451
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T effector cells during chronic infection with LCMV-Clone 13: day 8 versus day 15.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY15_EFFECTOR_VS_DAY30_EXHAUSTED_CD8_TCELL_LCMV_CLONE13_UP
Systematic name | M9452
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells during chronic infection with LCMV-Clone 13: effectors at day 15 versus exhausted at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY15_EFFECTOR_VS_DAY30_EXHAUSTED_CD8_TCELL_LCMV_CLONE13_DN
Systematic name | M9453
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells during chronic infection with LCMV-Clone 13: effectors at day 15 versus exhausted at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY6_LCMV_EFFECTOR_CD8_TCELL_UP
Systematic name | M9455
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus effectors at day 6.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_VS_DAY8_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_UP
Systematic name | M9456
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T effector cells, acute infection with LCMV-Armstrong: day 6 versus day 8.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_VS_DAY8_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_DN
Systematic name | M9457
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T effector cells, acute infection with LCMV-Armstrong: day 6 versus day 8.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_EFFECTOR_VS_DAY30_MEMORY_CD8_TCELL_LCMV_ARMSTRONG_UP
Systematic name | M9458
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells, acute infection with LCMV-Armstrong: effectors at day 6 versus memory at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_EFFECTOR_VS_DAY30_MEMORY_CD8_TCELL_LCMV_ARMSTRONG_DN
Systematic name | M9459
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells, acute infection with LCMV-Armstrong: effectors at day 6 versus memory at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY8_EFFECTOR_VS_DAY30_MEMORY_CD8_TCELL_LCMV_ARMSTRONG_UP
Systematic name | M9462
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells, acute infection with LCMV-Armstrong: effectors at day 8 versus memory at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY6_LCMV_EFFECTOR_CD8_TCELL_DN
Systematic name | M9463
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus effectors at day 6.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY8_LCMV_EFFECTOR_CD8_TCELL_UP
Systematic name | M9467
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus effectors at day 8.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY8_LCMV_EFFECTOR_CD8_TCELL_DN
Systematic name | M9469
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus effectors at day 8.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY15_LCMV_EFFECTOR_CD8_TCELL_UP
Systematic name | M9470
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus effectors at day 15.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY15_LCMV_EFFECTOR_CD8_TCELL_DN
Systematic name | M9472
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus effectors at day 15.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_EFFECTOR_CD8_TCELL_UP
Systematic name | M9474
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus effectors.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_EFFECTOR_CD8_TCELL_DN
Systematic name | M9475
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus effectors.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY30_LCMV_CLONE13_EXHAUSTED_CD8_TCELL_DN
Systematic name | M9476
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus exhausted at day 30 chronic infection with LCMV-clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_LCMV_ARMSTRONG_VS_CLONE13_DAY6_EFFECTOR_CD8_TCELL_DN
Systematic name | M9477
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T effector cells at day 6 of chronic infection: LCMV-Armstrong versus LCMV-Clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_LCMV_ARMSTRONG_VS_CLONE13_DAY8_EFFECTOR_CD8_TCELL_UP
Systematic name | M9478
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T effector cells at day 8 of chronic infection: LCMV-Armstrong versus LCMV-Clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_LCMV_ARMSTRONG_VS_CLONE13_DAY8_EFFECTOR_CD8_TCELL_DN
Systematic name | M9479
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T effector cells at day 8 of chronic infection: LCMV-Armstrong versus LCMV-Clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_MEMORY_VS_EXHAUSTED_CD8_TCELL_DAY30_LCMV_UP
Systematic name | M9480
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells at day 30: memory cells after acute infection with LCMV-Armstrong versus exhausted cells during chronic infection with LCMV-Clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_MEMORY_VS_EXHAUSTED_CD8_TCELL_DAY30_LCMV_DN
Systematic name | M9482
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells at day 30: memory cells after acute infection with LCMV-Armstrong versus exhausted cells during chronic infection with LCMV-Clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY8_EFFECTOR_VS_DAY30_MEMORY_CD8_TCELL_LCMV_ARMSTRONG_DN
Systematic name | M9484
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells, acute infection with LCMV-Armstrong: effectors at day 8 versus memory at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_VS_DAY8_LCMV_CLONE13_EFFECTOR_CD8_TCELL_UP
Systematic name | M9485
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T effector cells during chronic infection with LCMV-Clone 13: day 6 versus day 8.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_VS_DAY8_LCMV_CLONE13_EFFECTOR_CD8_TCELL_DN
Systematic name | M9486
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T effector cells during chronic infection with LCMV-Clone 13: day 6 versus day 8.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_EFFECTOR_VS_DAY30_EXHAUSTED_CD8_TCELL_LCMV_CLONE13_UP
Systematic name | M9489
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells during chronic infection with LCMV-Clone 13: effectors at day 6 versus exhausted at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_EFFECTOR_VS_DAY30_EXHAUSTED_CD8_TCELL_LCMV_CLONE13_DN
Systematic name | M9490
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells during chronic infection with LCMV-Clone 13: effectors at day 6 versus exhausted at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY8_EFFECTOR_VS_DAY30_EXHAUSTED_CD8_TCELL_LCMV_CLONE13_UP
Systematic name | M9491
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells during chronic infection with LCMV-Clone 13: effectors at day 8 versus exhausted at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY8_EFFECTOR_VS_DAY30_EXHAUSTED_CD8_TCELL_LCMV_CLONE13_DN
Systematic name | M9492
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells during chronic infection with LCMV-Clone 13: effectors at day 8 versus exhausted at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_LCMV_ARMSTRONG_VS_CLONE13_DAY6_EFFECTOR_CD8_TCELL_UP
Systematic name | M9493
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T effector cells at day 6 of chronic infection: LCMV-Armstrong versus LCMV-Clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY6_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_UP
Systematic name | M9495
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus effectors at day 6 after acute infection with LCMV-Armstrong.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY6_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_DN
Systematic name | M9496
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus effectors at day 6 after acute infection with LCMV-Armstrong.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY8_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_UP
Systematic name | M9497
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus effectors at day 8 after acute infection with LCMV-Armstrong.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY8_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_DN
Systematic name | M9498
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus effectors at day 8 after acute infection with LCMV-Armstrong.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY15_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_UP
Systematic name | M9499
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus effectors at day 15 after acute infection with LCMV-Armstrong.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY15_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_DN
Systematic name | M9501
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus effectors at day 15 after acute infection with LCMV-Armstrong.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY30_LCMV_ARMSTRONG_MEMORY_CD8_TCELL_UP
Systematic name | M9502
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus memory at day 30 after acute infection with LCMV-Armstrong.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY30_LCMV_ARMSTRONG_MEMORY_CD8_TCELL_DN
Systematic name | M9504
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus memory at day 30 after acute infection with LCMV-Armstrong.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY8_LCMV_CLONE13_EFFECTOR_CD8_TCELL_UP
Systematic name | M9505
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus effectors at day 8 chronic infection with LCMV-clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY8_LCMV_CLONE13_EFFECTOR_CD8_TCELL_DN
Systematic name | M9506
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus effectors at day 8 chronic infection with LCMV-clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY15_LCMV_CONE13_EFFECTOR_CD8_TCELL_UP
Systematic name | M9507
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus effectors at day 15 chronic infection with LCMV-clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY15_LCMV_CONE13_EFFECTOR_CD8_TCELL_DN
Systematic name | M9508
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: naïve versus effectors at day 15 chronic infection with LCMV-clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_NAIVE_VS_DAY30_LCMV_CLONE13_EXHAUSTED_CD8_TCELL_UP
Systematic name | M9509
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: naïve versus exhausted at day 30 chronic infection with LCMV-clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_LCMV_ARMSTRONG_VS_CLONE13_DAY15_EFFECTOR_CD8_TCELL_DN
Systematic name | M9510
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T effector cells at day 15 of: acute infection with LCMV-Armstrong versus chronic infection with LCMV-Clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_VS_DAY15_LCMV_CLONE13_EFFECTOR_CD8_TCELL_UP
Systematic name | M9512
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T effector cells during chronic infection with LCMV-Clone 13: day 6 versus day 15.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_VS_DAY15_LCMV_CLONE13_EFFECTOR_CD8_TCELL_DN
Systematic name | M9513
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T effector cells during chronic infection with LCMV-Clone 13: day 6 versus day 15.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_VS_DAY15_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_DN
Systematic name | M9515
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T effectors at acute infection with LCMV-Armstrong: day 6 versus day 15.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY8_VS_DAY15_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_UP
Systematic name | M9517
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T effectors at acute infection with LCMV-Armstrong: day 8 versus day 15.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY8_VS_DAY15_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_DN
Systematic name | M9519
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T effectors at acute infection with LCMV-Armstrong: day 8 versus day 15.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY6_VS_DAY15_LCMV_ARMSTRONG_EFFECTOR_CD8_TCELL_UP
Systematic name | M9520
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T effectors at acute infection with LCMV-Armstrong: day 6 versus day 15.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY15_EFFECTOR_VS_DAY30_MEMORY_CD8_TCELL_LCMV_ARMSTRONG_DN
Systematic name | M9521
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD5 T cells at acute infection with LCMV-Armstrong: effectors at day 15 versus memory at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_LCMV_ARMSTRONG_VS_CLONE13_DAY15_EFFECTOR_CD8_TCELL_UP
Systematic name | M9522
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T effector cells at day 15 of: acute infection with LCMV-Armstrong versus chronic infection with LCMV-Clone 13.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41867_DAY15_EFFECTOR_VS_DAY30_MEMORY_CD8_TCELL_LCMV_ARMSTRONG_UP
Systematic name | M9523
Organism | Mus musculus
PMID | 23159438
Authors | Doering TA,Crawford A,Angelosanto JM,Paley MA,Ziegler CG,Wherry EJ
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD5 T cells at acute infection with LCMV-Armstrong: effectors at day 15 versus memory at day 30.
Full description | During acute viral infections, naïve CD8+ T cells differentiate into effector CD8+ T cells and, after viral control, into memory CD8+ T cells. Memory CD8+ T cells are highly functional, proliferate rapidly upon reinfection and persist long-term without antigen. In contrast, during chronic infections, CD8+ T cells become “exhausted” and have poor effector function, express multiple inhibitory receptors, possess low proliferative capacity, and cannot persist without antigen. To compare the development of functional memory T cells with poorly functional exhausted T cells, we generated longitudinal transcriptional profiles for each.

Standard name | GSE41087_WT_VS_FOXP3_MUT_ANTI_CD3_CD28_STIM_CD4_TCELL_UP
Systematic name | M9527
Organism | Homo sapiens
PMID | 23169781
Authors | McMurchy AN,Gillies J,Gizzi MC,Riba M,Garcia-Manteiga JM,Cittaro D,Lazarevic D,Nunzio Di S,Piras IS,Bulfone A,Roncarolo MG,Stupka E,Bacchetta R,Levings MK
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated CD4 [GeneID=920] T cells expressing: wildtype versus mutant form of FOXP3 [GeneID=50943].
Full description | Investigation of the role of FOXP3 in CD4+ T effector cells. FOXP3 is transiently upregulated in T effector cells under activation. This temporary expression in Teff cells is insufficient to suppress expression of reported targets of FOXP3 repressor activity. The role of FOXP3 in T effector cells remains unclear. We used microarray analysis to detail the differentially expressed genes between FOXP3 wild type and 2T>C(mut) clones and identified classes of up-regulated or down-regulated genes based upon FOXP3 expression.

Standard name | GSE41087_WT_VS_FOXP3_MUT_ANTI_CD3_CD28_STIM_CD4_TCELL_DN
Systematic name | M9528
Organism | Homo sapiens
PMID | 23169781
Authors | McMurchy AN,Gillies J,Gizzi MC,Riba M,Garcia-Manteiga JM,Cittaro D,Lazarevic D,Nunzio Di S,Piras IS,Bulfone A,Roncarolo MG,Stupka E,Bacchetta R,Levings MK
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated CD4 [GeneID=920] T cells expressing: wildtype versus mutant form of FOXP3 [GeneID=50943].
Full description | Investigation of the role of FOXP3 in CD4+ T effector cells. FOXP3 is transiently upregulated in T effector cells under activation. This temporary expression in Teff cells is insufficient to suppress expression of reported targets of FOXP3 repressor activity. The role of FOXP3 in T effector cells remains unclear. We used microarray analysis to detail the differentially expressed genes between FOXP3 wild type and 2T>C(mut) clones and identified classes of up-regulated or down-regulated genes based upon FOXP3 expression.

Standard name | GSE36826_WT_VS_IL1R_KO_SKIN_DN
Systematic name | M9530
Organism | Mus musculus
PMID | 23209417
Authors | Cho JS,Guo Y,Ramos RI,Hebroni F,Plaisier SB,Xuan C,Granick JL,Matsushima H,Takashima A,Iwakura Y,Cheung AL,Cheng G,Lee DJ,Simon SI,Miller LS
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin: wildtype versus IL1R1 [GeneID=3554] knockout.
Full description | Neutrophil abscess formation is critical in innate immunity against many pathogens. Here, the mechanism of neutrophil abscess formation was investigated using a mouse model of Staphylococcus aureus cutaneous infection. Gene expression analysis of S. aureus-infected skin revealed that induction of neutrophil recruitment genes was largely dependent upon IL-1beta/IL-1R activation. Unexpectedly, using IL 1beta reporter mice, neutrophils were identified as the primary source of IL-1beta at the site of infection. Furthermore, IL-1beta-producing neutrophils were necessary and sufficient for abscess formation and bacterial clearance. S. aureus-induced IL 1beta production by neutrophils required TLR2, NOD2, FPRs and the ASC/NLRP3 inflammasome. Taken together, IL-1beta and neutrophil abscess formation during an infection are functionally, spatially and temporally linked as a consequence of direct IL-1beta production by neutrophils.

Standard name | GSE36826_NORMAL_VS_STAPH_AUREUS_INF_IL1R_KO_SKIN_UP
Systematic name | M9531
Organism | Mus musculus
PMID | 23209417
Authors | Cho JS,Guo Y,Ramos RI,Hebroni F,Plaisier SB,Xuan C,Granick JL,Matsushima H,Takashima A,Iwakura Y,Cheung AL,Cheng G,Lee DJ,Simon SI,Miller LS
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin with IL1R1 [GeneID=3554] knockout: uninfected versus S. aureus infection.
Full description | Neutrophil abscess formation is critical in innate immunity against many pathogens. Here, the mechanism of neutrophil abscess formation was investigated using a mouse model of Staphylococcus aureus cutaneous infection. Gene expression analysis of S. aureus-infected skin revealed that induction of neutrophil recruitment genes was largely dependent upon IL-1beta/IL-1R activation. Unexpectedly, using IL 1beta reporter mice, neutrophils were identified as the primary source of IL-1beta at the site of infection. Furthermore, IL-1beta-producing neutrophils were necessary and sufficient for abscess formation and bacterial clearance. S. aureus-induced IL 1beta production by neutrophils required TLR2, NOD2, FPRs and the ASC/NLRP3 inflammasome. Taken together, IL-1beta and neutrophil abscess formation during an infection are functionally, spatially and temporally linked as a consequence of direct IL-1beta production by neutrophils.

Standard name | GSE36826_NORMAL_VS_STAPH_AUREUS_INF_IL1R_KO_SKIN_DN
Systematic name | M9532
Organism | Mus musculus
PMID | 23209417
Authors | Cho JS,Guo Y,Ramos RI,Hebroni F,Plaisier SB,Xuan C,Granick JL,Matsushima H,Takashima A,Iwakura Y,Cheung AL,Cheng G,Lee DJ,Simon SI,Miller LS
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin with IL1R1 [GeneID=3554] knockout: uninfected versus S. aureus infection.
Full description | Neutrophil abscess formation is critical in innate immunity against many pathogens. Here, the mechanism of neutrophil abscess formation was investigated using a mouse model of Staphylococcus aureus cutaneous infection. Gene expression analysis of S. aureus-infected skin revealed that induction of neutrophil recruitment genes was largely dependent upon IL-1beta/IL-1R activation. Unexpectedly, using IL 1beta reporter mice, neutrophils were identified as the primary source of IL-1beta at the site of infection. Furthermore, IL-1beta-producing neutrophils were necessary and sufficient for abscess formation and bacterial clearance. S. aureus-induced IL 1beta production by neutrophils required TLR2, NOD2, FPRs and the ASC/NLRP3 inflammasome. Taken together, IL-1beta and neutrophil abscess formation during an infection are functionally, spatially and temporally linked as a consequence of direct IL-1beta production by neutrophils.

Standard name | GSE36826_WT_VS_IL1R_KO_SKIN_STAPH_AUREUS_INF_DN
Systematic name | M9533
Organism | Mus musculus
PMID | 23209417
Authors | Cho JS,Guo Y,Ramos RI,Hebroni F,Plaisier SB,Xuan C,Granick JL,Matsushima H,Takashima A,Iwakura Y,Cheung AL,Cheng G,Lee DJ,Simon SI,Miller LS
Category | C7
Sub-category |
Brief description | Genes down-regulated in lesional skin biopsies after S. aureus infection: wildtype versus IL1R1 [GeneID=3554].
Full description | Neutrophil abscess formation is critical in innate immunity against many pathogens. Here, the mechanism of neutrophil abscess formation was investigated using a mouse model of Staphylococcus aureus cutaneous infection. Gene expression analysis of S. aureus-infected skin revealed that induction of neutrophil recruitment genes was largely dependent upon IL-1beta/IL-1R activation. Unexpectedly, using IL 1beta reporter mice, neutrophils were identified as the primary source of IL-1beta at the site of infection. Furthermore, IL-1beta-producing neutrophils were necessary and sufficient for abscess formation and bacterial clearance. S. aureus-induced IL 1beta production by neutrophils required TLR2, NOD2, FPRs and the ASC/NLRP3 inflammasome. Taken together, IL-1beta and neutrophil abscess formation during an infection are functionally, spatially and temporally linked as a consequence of direct IL-1beta production by neutrophils.

Standard name | GSE36826_NORMAL_VS_STAPH_AUREUS_INF_SKIN_UP
Systematic name | M9534
Organism | Mus musculus
PMID | 23209417
Authors | Cho JS,Guo Y,Ramos RI,Hebroni F,Plaisier SB,Xuan C,Granick JL,Matsushima H,Takashima A,Iwakura Y,Cheung AL,Cheng G,Lee DJ,Simon SI,Miller LS
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin: uninfected versus S. aureus infection.
Full description | Neutrophil abscess formation is critical in innate immunity against many pathogens. Here, the mechanism of neutrophil abscess formation was investigated using a mouse model of Staphylococcus aureus cutaneous infection. Gene expression analysis of S. aureus-infected skin revealed that induction of neutrophil recruitment genes was largely dependent upon IL-1beta/IL-1R activation. Unexpectedly, using IL 1beta reporter mice, neutrophils were identified as the primary source of IL-1beta at the site of infection. Furthermore, IL-1beta-producing neutrophils were necessary and sufficient for abscess formation and bacterial clearance. S. aureus-induced IL 1beta production by neutrophils required TLR2, NOD2, FPRs and the ASC/NLRP3 inflammasome. Taken together, IL-1beta and neutrophil abscess formation during an infection are functionally, spatially and temporally linked as a consequence of direct IL-1beta production by neutrophils.

Standard name | GSE36826_NORMAL_VS_STAPH_AUREUS_INF_SKIN_DN
Systematic name | M9535
Organism | Mus musculus
PMID | 23209417
Authors | Cho JS,Guo Y,Ramos RI,Hebroni F,Plaisier SB,Xuan C,Granick JL,Matsushima H,Takashima A,Iwakura Y,Cheung AL,Cheng G,Lee DJ,Simon SI,Miller LS
Category | C7
Sub-category |
Brief description | Genes down-regulated in skin: uninfected versus S. aureus infection.
Full description | Neutrophil abscess formation is critical in innate immunity against many pathogens. Here, the mechanism of neutrophil abscess formation was investigated using a mouse model of Staphylococcus aureus cutaneous infection. Gene expression analysis of S. aureus-infected skin revealed that induction of neutrophil recruitment genes was largely dependent upon IL-1beta/IL-1R activation. Unexpectedly, using IL 1beta reporter mice, neutrophils were identified as the primary source of IL-1beta at the site of infection. Furthermore, IL-1beta-producing neutrophils were necessary and sufficient for abscess formation and bacterial clearance. S. aureus-induced IL 1beta production by neutrophils required TLR2, NOD2, FPRs and the ASC/NLRP3 inflammasome. Taken together, IL-1beta and neutrophil abscess formation during an infection are functionally, spatially and temporally linked as a consequence of direct IL-1beta production by neutrophils.

Standard name | GSE36826_WT_VS_IL1R_KO_SKIN_STAPH_AUREUS_INF_UP
Systematic name | M9536
Organism | Mus musculus
PMID | 23209417
Authors | Cho JS,Guo Y,Ramos RI,Hebroni F,Plaisier SB,Xuan C,Granick JL,Matsushima H,Takashima A,Iwakura Y,Cheung AL,Cheng G,Lee DJ,Simon SI,Miller LS
Category | C7
Sub-category |
Brief description | Genes up-regulated in lesional skin biopsies after S. aureus infection: wildtype versus IL1R1 [GeneID=3554].
Full description | Neutrophil abscess formation is critical in innate immunity against many pathogens. Here, the mechanism of neutrophil abscess formation was investigated using a mouse model of Staphylococcus aureus cutaneous infection. Gene expression analysis of S. aureus-infected skin revealed that induction of neutrophil recruitment genes was largely dependent upon IL-1beta/IL-1R activation. Unexpectedly, using IL 1beta reporter mice, neutrophils were identified as the primary source of IL-1beta at the site of infection. Furthermore, IL-1beta-producing neutrophils were necessary and sufficient for abscess formation and bacterial clearance. S. aureus-induced IL 1beta production by neutrophils required TLR2, NOD2, FPRs and the ASC/NLRP3 inflammasome. Taken together, IL-1beta and neutrophil abscess formation during an infection are functionally, spatially and temporally linked as a consequence of direct IL-1beta production by neutrophils.

Standard name | GSE36826_WT_VS_IL1R_KO_SKIN_UP
Systematic name | M9537
Organism | Mus musculus
PMID | 23209417
Authors | Cho JS,Guo Y,Ramos RI,Hebroni F,Plaisier SB,Xuan C,Granick JL,Matsushima H,Takashima A,Iwakura Y,Cheung AL,Cheng G,Lee DJ,Simon SI,Miller LS
Category | C7
Sub-category |
Brief description | Genes up-regulated in skin: wildtype versus IL1R1 [GeneID=3554] knockout.
Full description | Neutrophil abscess formation is critical in innate immunity against many pathogens. Here, the mechanism of neutrophil abscess formation was investigated using a mouse model of Staphylococcus aureus cutaneous infection. Gene expression analysis of S. aureus-infected skin revealed that induction of neutrophil recruitment genes was largely dependent upon IL-1beta/IL-1R activation. Unexpectedly, using IL 1beta reporter mice, neutrophils were identified as the primary source of IL-1beta at the site of infection. Furthermore, IL-1beta-producing neutrophils were necessary and sufficient for abscess formation and bacterial clearance. S. aureus-induced IL 1beta production by neutrophils required TLR2, NOD2, FPRs and the ASC/NLRP3 inflammasome. Taken together, IL-1beta and neutrophil abscess formation during an infection are functionally, spatially and temporally linked as a consequence of direct IL-1beta production by neutrophils.

Standard name | GSE39382_IL3_VS_IL3_IL33_TREATED_MAST_CELL_DN
Systematic name | M9539
Organism | Mus musculus
PMID | 23248261
Authors | Jung MY,Smrž D,Desai A,Bandara G,Ito T,Iwaki S,Kang JH,Andrade MV,Hilderbrand SC,Brown JM,Beaven MA,Metcalfe DD,Gilfillan AM
Category | C7
Sub-category |
Brief description | Genes down-regulated in bone marrow-derived mast cells treated with IL3 [GeneID=3562]: control versus IL33 [GeneID=90865].
Full description | Interleukin-33 (IL-33) is elevated in afflicted tissues of patients with mast cell-dependent chronic allergic diseases. Based on its acute effects on mouse mast cells (MCs), IL-33 is thought to play a role in the pathogenesis of allergic disease through MC activation. However, the manifestations of chronic IL-33 exposure on human MC function, which best reflect the conditions associated with chronic allergic disease, are unknown. We now find that long-term exposure of human and mouse MCs to IL-33 results in a substantial reduction of MC activation in response to antigen. This reduction required >72 h exposure to IL-33 for onset and 1-2 wk for reversion following IL-33 removal. This hypo-responsive phenotype was determined to be a consequence of MyD88-dependent attenuation of signaling processes necessary for MC activation including antigen-mediated calcium mobilization and cytoskeletal reorganization; potentially as a consequence of down-regulation of the expression of PLCg1 and Hck. These findings suggest that IL-33 may play a protective, rather than a causative role in MC activation under chronic conditions and, furthermore, reveal regulated plasticity in the MC activation phenotype. The ability to down-regulate MC activation in this manner may provide alternative approaches for treatment of MC-driven disease.

Standard name | GSE39382_IL3_VS_IL3_IL33_TREATED_MAST_CELL_UP
Systematic name | M9540
Organism | Mus musculus
PMID | 23248261
Authors | Jung MY,Smrž D,Desai A,Bandara G,Ito T,Iwaki S,Kang JH,Andrade MV,Hilderbrand SC,Brown JM,Beaven MA,Metcalfe DD,Gilfillan AM
Category | C7
Sub-category |
Brief description | Genes up-regulated in bone marrow-derived mast cells treated with IL3 [GeneID=3562]: control versus IL33 [GeneID=90865].
Full description | Interleukin-33 (IL-33) is elevated in afflicted tissues of patients with mast cell-dependent chronic allergic diseases. Based on its acute effects on mouse mast cells (MCs), IL-33 is thought to play a role in the pathogenesis of allergic disease through MC activation. However, the manifestations of chronic IL-33 exposure on human MC function, which best reflect the conditions associated with chronic allergic disease, are unknown. We now find that long-term exposure of human and mouse MCs to IL-33 results in a substantial reduction of MC activation in response to antigen. This reduction required >72 h exposure to IL-33 for onset and 1-2 wk for reversion following IL-33 removal. This hypo-responsive phenotype was determined to be a consequence of MyD88-dependent attenuation of signaling processes necessary for MC activation including antigen-mediated calcium mobilization and cytoskeletal reorganization; potentially as a consequence of down-regulation of the expression of PLCg1 and Hck. These findings suggest that IL-33 may play a protective, rather than a causative role in MC activation under chronic conditions and, furthermore, reveal regulated plasticity in the MC activation phenotype. The ability to down-regulate MC activation in this manner may provide alternative approaches for treatment of MC-driven disease.

Standard name | GSE35435_RESTING_VS_IL4_TREATED_MACROPHAGE_UP
Systematic name | M9542
Organism | Mus musculus
PMID | 23293084
Authors | Martinez FO,Helming L,Milde R,Varin A,Melgert BN,Draijer C,Thomas B,Fabbri M,Crawshaw A,Ho LP,Hacken Ten NH,Jiménez Cobos V,Kootstra NA,Hamann J,Greaves DR,Locati M,Mantovani A,Gordon S
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: resting versus stimulated by IL4 [GeneID=3565].
Full description | Analysis of alternative activation of macrophages at gene expression level. The study forms part of a wider study where we compare the effects of IL-4 in different human and mouse macrophages. Our results support the notion that in vitro culture conditions greatly affect the macrophage response to IL-4. Total RNA obtained from bone marrow derived macrophages upon exposure to 20 ng/ml of IL-4 for 18 hours.

Standard name | GSE35435_RESTING_VS_IL4_TREATED_MACROPHAGE_DN
Systematic name | M9543
Organism | Mus musculus
PMID | 23293084
Authors | Martinez FO,Helming L,Milde R,Varin A,Melgert BN,Draijer C,Thomas B,Fabbri M,Crawshaw A,Ho LP,Hacken Ten NH,Jiménez Cobos V,Kootstra NA,Hamann J,Greaves DR,Locati M,Mantovani A,Gordon S
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: resting versus stimulated by IL4 [GeneID=3565].
Full description | Analysis of alternative activation of macrophages at gene expression level. The study forms part of a wider study where we compare the effects of IL-4 in different human and mouse macrophages. Our results support the notion that in vitro culture conditions greatly affect the macrophage response to IL-4. Total RNA obtained from bone marrow derived macrophages upon exposure to 20 ng/ml of IL-4 for 18 hours.

Standard name | GSE28408_LY6G_POS_VS_NEG_DC_DN
Systematic name | M9545
Organism | Mus musculus
PMID | 23305731
Authors | Matsushima H,Geng S,Lu R,Okamoto T,Yao Y,Mayuzumi N,Kotol PF,Chojnacki BJ,Miyazaki T,Gallo RL,Takashima A
Category | C7
Sub-category |
Brief description | Genes down-regulated dendritic cells: Ly6G+ versus Ly6G-.
Full description | To investigate the functional properties of Ly6G+ DC, we employed GeneChip analysis to compare the gene expression profiles between Ly6G+ DC and Ly6C- DC.

Standard name | GSE28408_LY6G_POS_VS_NEG_DC_UP
Systematic name | M9547
Organism | Mus musculus
PMID | 23305731
Authors | Matsushima H,Geng S,Lu R,Okamoto T,Yao Y,Mayuzumi N,Kotol PF,Chojnacki BJ,Miyazaki T,Gallo RL,Takashima A
Category | C7
Sub-category |
Brief description | Genes up-regulated dendritic cells: Ly6G+ versus Ly6G-.
Full description | To investigate the functional properties of Ly6G+ DC, we employed GeneChip analysis to compare the gene expression profiles between Ly6G+ DC and Ly6C- DC.

Standard name | GSE41978_WT_VS_ID2_KO_AND_BIM_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_DN
Systematic name | M9548
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: wildtype versus ID2 and BCL2L11 [GeneID=3398;10018] knockout.
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_WT_VS_ID2_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_DN
Systematic name | M9549
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: wildtype versus ID2 [GeneID=3398].
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_WT_VS_ID2_KO_AND_BIM_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_UP
Systematic name | M9550
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: wildtype versus ID2 and BCL2L11 [GeneID=3398;10018] knockout.
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_KLRG1_HIGH_VS_LOW_EFFECTOR_CD8_TCELL_UP
Systematic name | M9551
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T effector cells during infection: KLRG1 high [GeneID=10219] versus KLRG1 low [GeneID=10219].
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_KLRG1_HIGH_VS_LOW_EFFECTOR_CD8_TCELL_DN
Systematic name | M9552
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T effector cells during infection: KLRG1 high [GeneID=10219] versus KLRG1 low [GeneID=10219].
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_WT_VS_ID2_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_UP
Systematic name | M9553
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: wildtype versus ID2 [GeneID=3398].
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_WT_VS_BIM_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_DN
Systematic name | M9554
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: wildtype versus BCL2L11 [GeneID=10018] knockout.
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_ID2_KO_VS_ID2_KO_AND_BIM_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_UP
Systematic name | M9555
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: ID2 [GeneID=3398] knockout versus ID2 and BCL2L11 [GeneID=3398;10018] knockout.
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_ID2_KO_VS_ID2_KO_AND_BIM_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_DN
Systematic name | M9560
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: ID2 [GeneID=3398] knockout versus ID2 and BCL2L11 [GeneID=3398;10018] knockout.
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_WT_VS_BIM_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_UP
Systematic name | M9562
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: wildtype versus BCL2L11 [GeneID=10018] knockout.
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_ID2_KO_VS_BIM_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_DN
Systematic name | M9563
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: ID2 [GeneID=10219] knockout versus BCL2L11 [GeneID=10018] knockout.
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_ID2_KO_AND_BIM_KO_VS_BIM_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_UP
Systematic name | M9566
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: ID2 and BCL2L11 [GeneID=3398;10018] versus BCL2L11 [GeneID=10018] knockout.
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_ID2_KO_AND_BIM_KO_VS_BIM_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_DN
Systematic name | M9567
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes down-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: ID2 and BCL2L11 [GeneID=3398;10018] versus BCL2L11 [GeneID=10018] knockout.
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE41978_ID2_KO_VS_BIM_KO_KLRG1_LOW_EFFECTOR_CD8_TCELL_UP
Systematic name | M9568
Organism | Mus musculus
PMID | 23325888
Authors | Knell J,Best JA,Lind NA,Yang E,D'Cruz LM,Goldrath AW
Category | C7
Sub-category |
Brief description | Genes up-regulated in KLRG1 low [GeneID=10219] CD8 T effector cells during infection: ID2 [GeneID=10219] knockout versus BCL2L11 [GeneID=10018] knockout.
Full description | CD8+ T cells play a crucial role in the clearance of intracellular pathogens through the generation of cytotoxic effector cells that eliminate infected cells and long-lived memory cells that provide enhanced protection against reinfection. We have previously shown that the inhibitor of E protein transcription factors, Id2, is necessary for accumulation of effector and memory CD8+ T cells during infection. Here we show that CD8+ T cells lacking Id2 did not generate a robust terminally-differentiated KLRG1hi effector population, but displayed a cell-surface phenotype and cytokine profile consistent with memory precursors, raising the question as to whether loss of Id2 impairs the differentiation and/or survival of effector-memory cells. We found that deletion of Bim rescued Id2-deficient CD8+ cell survival during infection. However, the dramatic reduction in KLRG1hi cells caused by loss of Id2 remained in the absence of Bim, such that Id2/Bim double-deficient cells form an exclusively KLRG1loCD127hi memory precursor population. Thus we describe a role for Id2 in both the survival and differentation of normal CD8+ effector and memory populations.

Standard name | GSE42021_TREG_PLN_VS_TREG_PRECURSORS_THYMUS_UP
Systematic name | M9569
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg from: peripheral lymph nodes versus thymic precursors.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TREG_PLN_VS_TREG_PRECURSORS_THYMUS_DN
Systematic name | M9570
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg from: peripheral lymph nodes versus thymic precursors.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TCONV_PLN_VS_TREG_PRECURSORS_THYMUS_UP
Systematic name | M9571
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv from: peripheral lymph nodes versus thymic precursors.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TREG_VS_TCONV_PLN_UP
Systematic name | M9572
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in cells from peripheral lymph nodes: T reg versus T conv.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TREG_VS_TCONV_PLN_DN
Systematic name | M9574
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in cells from peripheral lymph nodes: T reg versus T conv.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TREG_PLN_VS_CD24INT_TREG_THYMUS_DN
Systematic name | M9576
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: peripheral lymph nodes versus thymic CD24 int [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TREG_PLN_VS_CD24LO_TREG_THYMUS_UP
Systematic name | M9578
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: peripheral lymph nodes versus thymic CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TREG_PLN_VS_CD24LO_TREG_THYMUS_DN
Systematic name | M9580
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: peripheral lymph nodes versus thymic CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24HI_VS_CD24INT_TREG_THYMUS_UP
Systematic name | M9584
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic T reg: CD24 high [GeneID=100133941] versus CD24 int [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24HI_VS_CD24INT_TREG_THYMUS_DN
Systematic name | M9586
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic T reg: CD24 high [GeneID=100133941] versus CD24 int [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24HI_VS_CD24LOW_TREG_THYMUS_UP
Systematic name | M9587
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic T reg: CD24 high [GeneID=100133941] versus CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24HI_VS_CD24LOW_TREG_THYMUS_DN
Systematic name | M9588
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic T reg: CD24 high [GeneID=100133941] versus CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24INT_VS_CD24LOW_TREG_THYMUS_UP
Systematic name | M9589
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic T reg: CD24 int [GeneID=100133941] versus CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24INT_VS_CD24LOW_TREG_THYMUS_DN
Systematic name | M9590
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic T reg: CD24 int [GeneID=100133941] versus CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24HI_VS_CD24INT_TCONV_THYMUS_UP
Systematic name | M9591
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic T conv: CD24 high [GeneID=100133941] versus CD24 int [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24HI_VS_CD24INT_TCONV_THYMUS_DN
Systematic name | M9593
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic T conv: CD24 high [GeneID=100133941] versus CD24 int [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24HI_VS_CD24LOW_TCONV_THYMUS_UP
Systematic name | M9594
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic T conv: CD24 high [GeneID=100133941] versus CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24HI_VS_CD24LOW_TCONV_THYMUS_DN
Systematic name | M9595
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic T conv: CD24 high [GeneID=100133941] versus CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24INT_VS_CD24LOW_TCONV_THYMUS_UP
Systematic name | M9596
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in thymic T conv: CD24 int [GeneID=100133941] versus CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24INT_VS_CD24LOW_TCONV_THYMUS_DN
Systematic name | M9597
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in thymic T conv: CD24 int [GeneID=100133941] versus CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TCONV_PLN_VS_CD24HI_TCONV_THYMUS_UP
Systematic name | M9598
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv: peripheral lymph nodes versus thymic CD24 high [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TCONV_PLN_VS_CD24HI_TCONV_THYMUS_DN
Systematic name | M9599
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv: peripheral lymph nodes versus thymic CD24 high [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TCONV_PLN_VS_CD24INT_TCONV_THYMUS_UP
Systematic name | M9600
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv: peripheral lymph nodes versus thymic CD24 int [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TCONV_PLN_VS_CD24INT_TCONV_THYMUS_DN
Systematic name | M9603
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv: peripheral lymph nodes versus thymic CD24 int [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TCONV_PLN_VS_CD24LO_TCONV_THYMUS_UP
Systematic name | M9605
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in T conv: peripheral lymph nodes versus thymic CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TCONV_PLN_VS_CD24LO_TCONV_THYMUS_DN
Systematic name | M9606
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv: peripheral lymph nodes versus thymic CD24 low [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24INT_TREG_VS_CD24INT_TCONV_THYMUS_DN
Systematic name | M9607
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD42 int [GeneID=100133941] cells from thymus: T reg versus T conv.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24LO_TREG_VS_CD24LO_TCONV_THYMUS_UP
Systematic name | M9608
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD42 low [GeneID=100133941] cells from thymus: T reg versus T conv.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24LO_TREG_VS_CD24LO_TCONV_THYMUS_DN
Systematic name | M9609
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD42 low [GeneID=100133941] cells from thymus: T reg versus T conv.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TREG_PLN_VS_CD24HI_TREG_THYMUS_UP
Systematic name | M9610
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: peripheral lymph nodes versus thymic CD24 high [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TREG_PLN_VS_CD24HI_TREG_THYMUS_DN
Systematic name | M9613
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: peripheral lymph nodes versus thymic CD24 high [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TREG_PLN_VS_CD24INT_TREG_THYMUS_UP
Systematic name | M9614
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: peripheral lymph nodes versus thymic CD24 int [GeneID=100133941].
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24HI_TREG_VS_CD24HI_TCONV_THYMUS_UP
Systematic name | M9615
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD42 high [GeneID=100133941] cells from thymus: T reg versus T conv.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24HI_TREG_VS_CD24HI_TCONV_THYMUS_DN
Systematic name | M9616
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD42 high [GeneID=100133941] cells from thymus: T reg versus T conv.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_CD24INT_TREG_VS_CD24INT_TCONV_THYMUS_UP
Systematic name | M9618
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD42 int [GeneID=100133941] cells from thymus: T reg versus T conv.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE42021_TCONV_PLN_VS_TREG_PRECURSORS_THYMUS_DN
Systematic name | M9619
Organism | Mus musculus
PMID | 23420886
Authors | Toker A,Engelbert D,Garg G,Polansky JK,Floess S,Miyao T,Baron U,Düber S,Geffers R,Giehr P,Schallenberg S,Kretschmer K,Olek S,Walter J,Weiss S,Hori S,Hamann A,Huehn J
Category | C7
Sub-category |
Brief description | Genes down-regulated in T conv from: peripheral lymph nodes versus thymic precursors.
Full description | We investigated at which stage of maturation commitment to a stable Foxp3-expressing phenotype takes place. We assessed stability of Foxp3 expression in thymic Foxp3+ Treg subsets of different maturity, defined by CD24 expression. Next we compared gene expression profiles of Foxp3+ Treg subsets (+) of different maturity (24lo, 24int, 24hi) and could identify a set of genes that were specifically up or downregulated in Foxp3+ Tregs, but not in Foxp3- conventional T cells, in a maturation-dependent manner.

Standard name | GSE27434_WT_VS_DNMT1_KO_TREG_UP
Systematic name | M9620
Organism | Mus musculus
PMID | 23444399
Authors | Wang L,Liu Y,Beier UH,Han R,Bhatti TR,Akimova T,Hancock WW
Category | C7
Sub-category |
Brief description | Genes up-regulated in T reg: wildtype versus DNMT1 [GeneID=1786] knockout.
Full description | We investigated the role of DNMT1 in immune homeostasis by generating mice lacking DNMT1 in Foxp3+ T-regulatory (Treg) cells. These mice showed decreased peripheral Foxp3+ Tregs, complete loss of Foxp3+ Treg suppressive functions in vitro and in vivo, and died from autoimmunity by 3-4 weeks unless they received perinatal transfer of wild-type Tregs that prolonged their survival. Methylation of CpG-sites in the TSDR region of Foxp3 was unaffected by DNMT1 deletion, but microarray revealed more >500 proinflammatory and other genes were upregulated in DNMT1-/- Tregs. CD4-Cre-mediated DNMT1 deletion showed inability of conventional T cells to convert to Foxp3+ Treg under appropriate polarizing conditions. Hence, DNMT1 is absolutely necessary for maintenance of the gene program required for normal Treg development and function.

Standard name | GSE27434_WT_VS_DNMT1_KO_TREG_DN
Systematic name | M9621
Organism | Mus musculus
PMID | 23444399
Authors | Wang L,Liu Y,Beier UH,Han R,Bhatti TR,Akimova T,Hancock WW
Category | C7
Sub-category |
Brief description | Genes down-regulated in T reg: wildtype versus DNMT1 [GeneID=1786] knockout.
Full description | We investigated the role of DNMT1 in immune homeostasis by generating mice lacking DNMT1 in Foxp3+ T-regulatory (Treg) cells. These mice showed decreased peripheral Foxp3+ Tregs, complete loss of Foxp3+ Treg suppressive functions in vitro and in vivo, and died from autoimmunity by 3-4 weeks unless they received perinatal transfer of wild-type Tregs that prolonged their survival. Methylation of CpG-sites in the TSDR region of Foxp3 was unaffected by DNMT1 deletion, but microarray revealed more >500 proinflammatory and other genes were upregulated in DNMT1-/- Tregs. CD4-Cre-mediated DNMT1 deletion showed inability of conventional T cells to convert to Foxp3+ Treg under appropriate polarizing conditions. Hence, DNMT1 is absolutely necessary for maintenance of the gene program required for normal Treg development and function.

Standard name | GSE43700_UNTREATED_VS_IL10_TREATED_PBMC_UP
Systematic name | M9622
Organism | Homo sapiens
PMID | 23449998
Authors | Teles RM,Graeber TG,Krutzik SR,Montoya D,Schenk M,Lee DJ,Komisopoulou E,Kelly-Scumpia K,Chun R,Iyer SS,Sarno EN,Rea TH,Hewison M,Adams JS,Popper SJ,Relman DA,Stenger S,Bloom BR,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes up-regulated in peripheral blood monocytes (PBMC): control versus IL10 [GeneID=3586].
Full description | The immune mechanisms that control resistance vs. susceptibility to mycobacterial infection in humans were investigated by studying leprosy skin lesions, the site where the battle between the host and the pathogen is joined. Using an integrative genomics approach, we found an inverse correlation between of IFN-beta and IFN-gamma gene expression programs at the site of disease. The Type II IFN, IFN-gamma and its downstream vitamin D-dependent antimicrobial genes were preferentially expressed in the lesions from patients with the self-healing tuberculoid form of the disease and mediated antimicrobial activity against the pathogen, Mycobacterium leprae in vitro. In contrast, the Type I IFN, IFN-beta and its downstream genes, including IL-27 and IL-10, were induced in monocytes by M. leprae in vitro, and were preferentially expressed in the lesions of disseminated and progressive lepromatous form. The IFN-gamma induced macrophage antimicrobial response was inhibited by IFN-beta/IL-10, by a mechanism involving blocking the generation of bioactive 1,25-dihyroxy vitamin D as well as inhibiting induction of antimicrobial peptides cathelicidin and DEFB4. The ability of IFN-B to inhibit the IFN-gamma induced vitamin D pathway including antimicrobial activity was reversed by neutralization of IL-10, suggesting a possible target for therapeutic intervention. Finally, a common IFN-beta and IL-10 gene signature was identified in both the skin lesions of leprosy patients and in the peripheral blood of active tuberculosis patients. Together these data suggest that the ability of IFN-beta to downregulate protective IFN-gamma responses provides one general mechanism by which some bacterial pathogens of humans evade protective host responses and contribute to pathogenesis.

Standard name | GSE43700_UNTREATED_VS_IL10_TREATED_PBMC_DN
Systematic name | M9623
Organism | Homo sapiens
PMID | 23449998
Authors | Teles RM,Graeber TG,Krutzik SR,Montoya D,Schenk M,Lee DJ,Komisopoulou E,Kelly-Scumpia K,Chun R,Iyer SS,Sarno EN,Rea TH,Hewison M,Adams JS,Popper SJ,Relman DA,Stenger S,Bloom BR,Cheng G,Modlin RL
Category | C7
Sub-category |
Brief description | Genes down-regulated in peripheral blood monocytes (PBMC): control versus IL10 [GeneID=3586].
Full description | The immune mechanisms that control resistance vs. susceptibility to mycobacterial infection in humans were investigated by studying leprosy skin lesions, the site where the battle between the host and the pathogen is joined. Using an integrative genomics approach, we found an inverse correlation between of IFN-beta and IFN-gamma gene expression programs at the site of disease. The Type II IFN, IFN-gamma and its downstream vitamin D-dependent antimicrobial genes were preferentially expressed in the lesions from patients with the self-healing tuberculoid form of the disease and mediated antimicrobial activity against the pathogen, Mycobacterium leprae in vitro. In contrast, the Type I IFN, IFN-beta and its downstream genes, including IL-27 and IL-10, were induced in monocytes by M. leprae in vitro, and were preferentially expressed in the lesions of disseminated and progressive lepromatous form. The IFN-gamma induced macrophage antimicrobial response was inhibited by IFN-beta/IL-10, by a mechanism involving blocking the generation of bioactive 1,25-dihyroxy vitamin D as well as inhibiting induction of antimicrobial peptides cathelicidin and DEFB4. The ability of IFN-B to inhibit the IFN-gamma induced vitamin D pathway including antimicrobial activity was reversed by neutralization of IL-10, suggesting a possible target for therapeutic intervention. Finally, a common IFN-beta and IL-10 gene signature was identified in both the skin lesions of leprosy patients and in the peripheral blood of active tuberculosis patients. Together these data suggest that the ability of IFN-beta to downregulate protective IFN-gamma responses provides one general mechanism by which some bacterial pathogens of humans evade protective host responses and contribute to pathogenesis.

Standard name | GSE43957_UNTREATED_VS_NACL_TREATED_ANTI_CD3_CD28_STIM_CD4_TCELL_UP
Systematic name | M9624
Organism | Mus musculus
PMID | 23467085
Authors | Wu C,Yosef N,Thalhamer T,Zhu C,Xiao S,Kishi Y,Regev A,Kuchroo VK
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th0: control versus NaCl treatment.
Full description | Th17 cells are highly proinflammatory cells that are critical for clearing extracellular pathogens like fungal infections and for induction of multiple autoimmune diseases1. IL-23 plays a critical role in stabilizing and endowing Th17 cells with pathogenic effector functions2. Previous studies have shown that IL-23 signaling reinforces the Th17 phenotype by increasing expression of IL-23 receptor (IL-23R)3. However, the precise molecular mechanism by which IL-23 sustains the Th17 response and induces pathogenic effector functions has not been elucidated. Here, we used unbiased transcriptional profiling of developing Th17 cells to construct a model of their signaling network and identify major nodes that regulate Th17 development. We identified serum glucocorticoid kinase-1 (SGK1), as an essential node downstream of IL-23 signaling, critical for regulating IL-23R expression and for stabilizing the Th17 cell phenotype by deactivation of Foxo1, a direct repressor of IL-23R expression. A serine-threonine kinase homologous to AKT4, SGK1 has been associated with cell cycle and apoptosis, and has been shown to govern Na+ transport and homeostasis5, 6 7, 8. We here show that a modest increase in salt (NaCl) concentration induces SGK1 expression, promotes IL-23R expression and enhances Th17 cell differentiation in vitro and in vivo, ultimately accelerating the development of autoimmunity. The loss of SGK1 resulted in abrogation of Na+-mediated Th17 differentiation in an IL-23-dependent manner. These data indicate that SGK1 is a critical regulator for the induction of pathogenic Th17 cells and provides a molecular insight by which an environmental factor such as a high salt diet could trigger Th17 development and promote tissue inflammation.

Standard name | GSE43957_UNTREATED_VS_NACL_TREATED_ANTI_CD3_CD28_STIM_CD4_TCELL_DN
Systematic name | M9625
Organism | Mus musculus
PMID | 23467085
Authors | Wu C,Yosef N,Thalhamer T,Zhu C,Xiao S,Kishi Y,Regev A,Kuchroo VK
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th0: control versus NaCl treatment.
Full description | Th17 cells are highly proinflammatory cells that are critical for clearing extracellular pathogens like fungal infections and for induction of multiple autoimmune diseases1. IL-23 plays a critical role in stabilizing and endowing Th17 cells with pathogenic effector functions2. Previous studies have shown that IL-23 signaling reinforces the Th17 phenotype by increasing expression of IL-23 receptor (IL-23R)3. However, the precise molecular mechanism by which IL-23 sustains the Th17 response and induces pathogenic effector functions has not been elucidated. Here, we used unbiased transcriptional profiling of developing Th17 cells to construct a model of their signaling network and identify major nodes that regulate Th17 development. We identified serum glucocorticoid kinase-1 (SGK1), as an essential node downstream of IL-23 signaling, critical for regulating IL-23R expression and for stabilizing the Th17 cell phenotype by deactivation of Foxo1, a direct repressor of IL-23R expression. A serine-threonine kinase homologous to AKT4, SGK1 has been associated with cell cycle and apoptosis, and has been shown to govern Na+ transport and homeostasis5, 6 7, 8. We here show that a modest increase in salt (NaCl) concentration induces SGK1 expression, promotes IL-23R expression and enhances Th17 cell differentiation in vitro and in vivo, ultimately accelerating the development of autoimmunity. The loss of SGK1 resulted in abrogation of Na+-mediated Th17 differentiation in an IL-23-dependent manner. These data indicate that SGK1 is a critical regulator for the induction of pathogenic Th17 cells and provides a molecular insight by which an environmental factor such as a high salt diet could trigger Th17 development and promote tissue inflammation.

Standard name | GSE43956_WT_VS_SGK1_KO_TH17_DIFFERENTIATED_CD4_TCELL_UP
Systematic name | M9627
Organism | Mus musculus
PMID | 23467085
Authors | Wu C,Yosef N,Thalhamer T,Zhu C,Xiao S,Kishi Y,Regev A,Kuchroo VK
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper Th17 cells: wildtype versus SGK1 [GeneID-6446] knockout.
Full description | Th17 cells are highly proinflammatory cells that are critical for clearing extracellular pathogens like fungal infections and for induction of multiple autoimmune diseases1. IL-23 plays a critical role in stabilizing and endowing Th17 cells with pathogenic effector functions2. Previous studies have shown that IL-23 signaling reinforces the Th17 phenotype by increasing expression of IL-23 receptor (IL-23R)3. However, the precise molecular mechanism by which IL-23 sustains the Th17 response and induces pathogenic effector functions has not been elucidated. Here, we used unbiased transcriptional profiling of developing Th17 cells to construct a model of their signaling network and identify major nodes that regulate Th17 development. We identified serum glucocorticoid kinase-1 (SGK1), as an essential node downstream of IL-23 signaling, critical for regulating IL-23R expression and for stabilizing the Th17 cell phenotype by deactivation of Foxo1, a direct repressor of IL-23R expression. A serine-threonine kinase homologous to AKT4, SGK1 has been associated with cell cycle and apoptosis, and has been shown to govern Na+ transport and homeostasis5, 6 7, 8. We here show that a modest increase in salt (NaCl) concentration induces SGK1 expression, promotes IL-23R expression and enhances Th17 cell differentiation in vitro and in vivo, ultimately accelerating the development of autoimmunity. The loss of SGK1 resulted in abrogation of Na+-mediated Th17 differentiation in an IL-23-dependent manner. These data indicate that SGK1 is a critical regulator for the induction of pathogenic Th17 cells and provides a molecular insight by which an environmental factor such as a high salt diet could trigger Th17 development and promote tissue inflammation.

Standard name | GSE43956_WT_VS_SGK1_KO_TH17_DIFFERENTIATED_CD4_TCELL_DN
Systematic name | M9628
Organism | Mus musculus
PMID | 23467085
Authors | Wu C,Yosef N,Thalhamer T,Zhu C,Xiao S,Kishi Y,Regev A,Kuchroo VK
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper Th17 cells: wildtype versus SGK1 [GeneID-6446] knockout.
Full description | Th17 cells are highly proinflammatory cells that are critical for clearing extracellular pathogens like fungal infections and for induction of multiple autoimmune diseases1. IL-23 plays a critical role in stabilizing and endowing Th17 cells with pathogenic effector functions2. Previous studies have shown that IL-23 signaling reinforces the Th17 phenotype by increasing expression of IL-23 receptor (IL-23R)3. However, the precise molecular mechanism by which IL-23 sustains the Th17 response and induces pathogenic effector functions has not been elucidated. Here, we used unbiased transcriptional profiling of developing Th17 cells to construct a model of their signaling network and identify major nodes that regulate Th17 development. We identified serum glucocorticoid kinase-1 (SGK1), as an essential node downstream of IL-23 signaling, critical for regulating IL-23R expression and for stabilizing the Th17 cell phenotype by deactivation of Foxo1, a direct repressor of IL-23R expression. A serine-threonine kinase homologous to AKT4, SGK1 has been associated with cell cycle and apoptosis, and has been shown to govern Na+ transport and homeostasis5, 6 7, 8. We here show that a modest increase in salt (NaCl) concentration induces SGK1 expression, promotes IL-23R expression and enhances Th17 cell differentiation in vitro and in vivo, ultimately accelerating the development of autoimmunity. The loss of SGK1 resulted in abrogation of Na+-mediated Th17 differentiation in an IL-23-dependent manner. These data indicate that SGK1 is a critical regulator for the induction of pathogenic Th17 cells and provides a molecular insight by which an environmental factor such as a high salt diet could trigger Th17 development and promote tissue inflammation.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_42H_UP
Systematic name | M9629
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells (42h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_42H_DN
Systematic name | M9632
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells (42h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_52H_UP
Systematic name | M9633
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells (52h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_1H_UP
Systematic name | M9635
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells (1h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_1H_DN
Systematic name | M9637
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells (1h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_4H_UP
Systematic name | M9640
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells (4h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_4H_DN
Systematic name | M9641
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells (4h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_10H_UP
Systematic name | M9643
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells (10h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_10H_DN
Systematic name | M9644
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells (10h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_20H_UP
Systematic name | M9646
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells (20h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_20H_DN
Systematic name | M9647
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells (20h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_30H_UP
Systematic name | M9649
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells (30h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_30H_DN
Systematic name | M9650
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells (30h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_60H_ACT_CD4_TCELL_DN
Systematic name | M9651
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th0: 1h versus 60h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_IL23_TH17_ACT_CD4_TCELL_52H_UP
Systematic name | M9652
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells (52h): Th0 versus Th17 treated with TGFB1, IL6 [GeneID=7040;3569] and IL-23.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_IL23_TH17_ACT_CD4_TCELL_52H_DN
Systematic name | M9653
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells (52h): Th0 versus Th17 treated with TGFB1, IL6 [GeneID=7040;3569] and IL-23.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_52H_DN
Systematic name | M9654
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells (52h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_60H_UP
Systematic name | M9655
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells (60h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_TH17_ACT_CD4_TCELL_60H_DN
Systematic name | M9657
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells (60h): Th0 versus TGFB1 and IL6 [GeneID=7040;3569].
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_10H_ACT_CD4_TCELL_UP
Systematic name | M9658
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th0: 1h versus 10h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_10H_ACT_CD4_TCELL_DN
Systematic name | M9659
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th0: 1h versus 10h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_20H_ACT_CD4_TCELL_UP
Systematic name | M9660
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th0: 1h versus 20h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_20H_ACT_CD4_TCELL_DN
Systematic name | M9662
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th0: 1h versus 20h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_42H_ACT_CD4_TCELL_UP
Systematic name | M9663
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th0: 1h versus 42h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_42H_ACT_CD4_TCELL_DN
Systematic name | M9665
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th0: 1h versus 42h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_60H_ACT_CD4_TCELL_UP
Systematic name | M9666
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th0: 1h versus 60h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TGFB_IL6_VS_TGFB_IL6_IL23_TH17_ACT_CD4_TCELL_52H_UP
Systematic name | M9667
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th17 (52h): TGFB1 and IL6 [GeneID=7040;3569] versus TGFB1, IL6 [GeneID=7040;3569] and IL-23.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TGFB_IL6_VS_TGFB_IL6_IL23_TH17_ACT_CD4_TCELL_52H_DN
Systematic name | M9668
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th17 (52h): TGFB1 and IL6 [GeneID=7040;3569] versus TGFB1, IL6 [GeneID=7040;3569] and IL-23.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TGFB_IL6_VS_TGFB_IL6_IL23_TH17_ACT_CD4_TCELL_60H_UP
Systematic name | M9671
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th17 (60h): TGFB1 and IL6 [GeneID=7040;3569] versus TGFB1, IL6 [GeneID=7040;3569] and IL-23.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TGFB_IL6_VS_TGFB_IL6_IL23_TH17_ACT_CD4_TCELL_60H_DN
Systematic name | M9672
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th17 (60h): TGFB1 and IL6 [GeneID=7040;3569] versus TGFB1, IL6 [GeneID=7040;3569] and IL-23.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_10H_ACT_CD4_TCELL_WITH_TGFB_IL6_UP
Systematic name | M9674
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 1h versus 10h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_10H_ACT_CD4_TCELL_WITH_TGFB_IL6_DN
Systematic name | M9675
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 1h versus 10h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_20H_ACT_CD4_TCELL_WITH_TGFB_IL6_UP
Systematic name | M9676
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 1h versus 20h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_20H_ACT_CD4_TCELL_WITH_TGFB_IL6_DN
Systematic name | M9677
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 1h versus 20h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_42H_ACT_CD4_TCELL_WITH_TGFB_IL6_UP
Systematic name | M9679
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 1h versus 42h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_42H_ACT_CD4_TCELL_WITH_TGFB_IL6_DN
Systematic name | M9680
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 1h versus 42h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_60H_ACT_CD4_TCELL_WITH_TGFB_IL6_UP
Systematic name | M9682
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 1h versus 60h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_1H_VS_60H_ACT_CD4_TCELL_WITH_TGFB_IL6_DN
Systematic name | M9685
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 1h versus 60h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_10H_VS_60H_ACT_CD4_TCELL_WITH_TGFB_IL6_UP
Systematic name | M9686
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 10h versus 60h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_10H_VS_60H_ACT_CD4_TCELL_WITH_TGFB_IL6_DN
Systematic name | M9687
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 10h versus 60h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_IL23_TH17_ACT_CD4_TCELL_60H_DN
Systematic name | M9688
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells (60h): Th0 versus Th17 treated with TGFB1, IL6 [GeneID=7040;3569] and IL-23.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_10H_VS_30H_ACT_CD4_TCELL_UP
Systematic name | M9689
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th0: 10h versus 30h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_10H_VS_30H_ACT_CD4_TCELL_DN
Systematic name | M9690
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th0: 10h versus 30h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_TH0_VS_TGFB_IL6_IL23_TH17_ACT_CD4_TCELL_60H_UP
Systematic name | M9691
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells (60h): Th0 versus Th17 treated with TGFB1, IL6 [GeneID=7040;3569] and IL-23.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_10H_VS_60H_ACT_CD4_TCELL_DN
Systematic name | M9692
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th0: 10h versus 60h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_10H_VS_30H_ACT_CD4_TCELL_WITH_TGFB_IL6_UP
Systematic name | M9696
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 10h versus 30h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_10H_VS_30H_ACT_CD4_TCELL_WITH_TGFB_IL6_DN
Systematic name | M9697
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T helper cells Th17 treated with TGFB1 and IL6 [GeneID=7040;3569]: 10h versus 30h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE43955_10H_VS_60H_ACT_CD4_TCELL_UP
Systematic name | M9698
Organism | Mus musculus
PMID | 23467089
Authors | Yosef N,Shalek AK,Gaublomme JT,Jin H,Lee Y,Awasthi A,Wu C,Karwacz K,Xiao S,Jorgolli M,Gennert D,Satija R,Shakya A,Lu DY,Trombetta JJ,Pillai MR,Ratcliffe PJ,Coleman ML,Bix M,Tantin D,Park H,Kuchroo VK,Regev A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T helper cells Th0: 10h versus 60h.
Full description | Despite their enormous importance, the molecular circuits that control the differentiation of Th17 cells remain largely unknown. Recent studies have reconstructed regulatory networks in mammalian cells, but have focused on short-term responses and relied on perturbation approaches that cannot be applied to primary T cells. Here, we develop a systematic strategy – combining transcriptional profiling at high temporal resolution, novel computational algorithms, and innovative nanowire-based tools for performing gene perturbations in primary T cells – to derive and experimentally validate a temporal model of the dynamic regulatory network that controls Th17 differentiation. The network is arranged into two self-reinforcing and mutually antagonistic modules that either suppress or promote Th17 differentiation. The two modules contain 12 novel regulators with no previous implication in Th17 differentiation, which may be essential to maintain the appropriate balance of Th17 and other CD4+ T cell subsets. Overall, our study identifies and validates 39 regulatory factors that are embedded within a comprehensive temporal network and identifies novel drug targets and organizational principles for the differentiation of Th17 cells.

Standard name | GSE44732_UNSTIM_VS_IL27_STIM_IMATURE_DC_UP
Systematic name | M9699
Organism | Homo sapiens
PMID | 23527130
Authors | Chen Q,Swaminathan S,Yang D,Dai L,Sui H,Yang J,Hornung RL,Wang Y,Huang W da,Hu X,Lempicki RA,Imamichi T
Category | C7
Sub-category |
Brief description | Genes up-regulated in immature dendritic cells: untreated versus IL27 [GeneID=246778].
Full description | IL-27 treated DCs were shown to be highly potent inhibitors of cis HIV-1, particularly of CCR5 tropic strains. Microarray studies of IL-27 treated DCs showed no up-regulation of Type I (IFN) gene expression. Neutralization of the Type-I IFN receptor had no impact on the HIV inhibition. Lastly, IL-27 mediated inhibition was shown to act post-viral entry and prior to completion of reverse transcription. These results show for the first time that IL-27 is a potent inhibitor of cis HIV-1 infection in DCs by a Type I IFN independent mechanism.

Standard name | GSE44732_UNSTIM_VS_IL27_STIM_IMATURE_DC_DN
Systematic name | M9700
Organism | Homo sapiens
PMID | 23527130
Authors | Chen Q,Swaminathan S,Yang D,Dai L,Sui H,Yang J,Hornung RL,Wang Y,Huang W da,Hu X,Lempicki RA,Imamichi T
Category | C7
Sub-category |
Brief description | Genes down-regulated in immature dendritic cells: untreated versus IL27 [GeneID=246778].
Full description | IL-27 treated DCs were shown to be highly potent inhibitors of cis HIV-1, particularly of CCR5 tropic strains. Microarray studies of IL-27 treated DCs showed no up-regulation of Type I (IFN) gene expression. Neutralization of the Type-I IFN receptor had no impact on the HIV inhibition. Lastly, IL-27 mediated inhibition was shown to act post-viral entry and prior to completion of reverse transcription. These results show for the first time that IL-27 is a potent inhibitor of cis HIV-1 infection in DCs by a Type I IFN independent mechanism.

Standard name | GSE44955_MCSF_VS_MCSF_AND_IL27_STIM_MACROPHAGE_DN
Systematic name | M9701
Organism | Homo sapiens
PMID | 23535375
Authors | Swaminathan S,Hu X,Zheng X,Kriga Y,Shetty J,Zhao Y,Stephens R,Tran B,Baseler MW,Yang J,Lempicki RA,Huang D,Lane HC,Imamichi T
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophage differentiated by: CSF1 [GeneID=1435] versus CSF1 [GeneID=1435] and IL27 [GeneID=246778].
Full description | In this study, we hypothesized that IL-27 could induce the expression of novel miRNAs in macrophages which may have functional relevance in terms of anti-viral activity. In this study, primary monocytes were differentiated into macrophages using M-CSF (M-Mac) or with a combination of M-CSF and IL-27 (I-Mac) for seven days. Following this, total RNA was extracted from these cells and deep sequencing was performed, in parallel with gene expression microarrays. Using the novel miRNA discovery software, miRDeep, seven novel miRNAs were discovered in the macrophages, four of which were expressed higher in I-Mac (miRNAs 2.1, 8.1, 9.1 and 14.2) whilst three were detected in both M-Mac and I-Mac (miRNAs 9.3, 13.6 and 15.8). The expression of six of the seven novel miRNAs was highly correlated with qRT-PCR using specific primer/probes designed for the novel miRNAs. Gene expression microarray further demonstrated that a number of genes were potentially targeted by these differentially expressed novel miRNAs.

Standard name | GSE44955_MCSF_VS_MCSF_AND_IL27_STIM_MACROPHAGE_UP
Systematic name | M9704
Organism | Homo sapiens
PMID | 23535375
Authors | Swaminathan S,Hu X,Zheng X,Kriga Y,Shetty J,Zhao Y,Stephens R,Tran B,Baseler MW,Yang J,Lempicki RA,Huang D,Lane HC,Imamichi T
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophage differentiated by: CSF1 [GeneID=1435] versus CSF1 [GeneID=1435] and IL27 [GeneID=246778].
Full description | In this study, we hypothesized that IL-27 could induce the expression of novel miRNAs in macrophages which may have functional relevance in terms of anti-viral activity. In this study, primary monocytes were differentiated into macrophages using M-CSF (M-Mac) or with a combination of M-CSF and IL-27 (I-Mac) for seven days. Following this, total RNA was extracted from these cells and deep sequencing was performed, in parallel with gene expression microarrays. Using the novel miRNA discovery software, miRDeep, seven novel miRNAs were discovered in the macrophages, four of which were expressed higher in I-Mac (miRNAs 2.1, 8.1, 9.1 and 14.2) whilst three were detected in both M-Mac and I-Mac (miRNAs 9.3, 13.6 and 15.8). The expression of six of the seven novel miRNAs was highly correlated with qRT-PCR using specific primer/probes designed for the novel miRNAs. Gene expression microarray further demonstrated that a number of genes were potentially targeted by these differentially expressed novel miRNAs.

Standard name | GSE46242_CTRL_VS_EGR2_DELETED_TH1_CD4_TCELL_UP
Systematic name | M9705
Organism | Mus musculus
PMID | 23548837
Authors | Zheng Y,Zha Y,Spaapen RM,Mathew R,Barr K,Bendelac A,Gajewski TF
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] Th1 cells: wildtype versus EGR2 [GeneID=1959] knockout.
Full description | T cell anergy is one of the mechanisms contributing to peripheral tolerance, particularly in the context of progressively growing tumors and in tolerogenic treatments promoting allograft acceptance. We recently reported that early growth response gene 2 (Egr2) is a critical transcription factor for the induction of anergy in vitro and in vivo, which was identified based on its ability to regulate the expression of inhibitory signaling molecules diacylglycerol kinase (DGK)-a and -z. We reasoned that other transcriptional targets of Egr2 might encode additional factors important for T cell anergy and immune regulation. Thus, we conducted two sets of genome-wide screens: gene expression profiling of wild type versus Egr2-deleted T cells treated under anergizing conditions, and a ChIP-Seq analysis to identify genes that bind Egr2 in anergic cells. Merging of these data sets revealed 49 targets that are directly regulated by Egr2. Among these are inhibitory signaling molecules previously reported to contribute to T cell anergy, but unexpectedly, also cell surface molecules and secreted factors, including lymphocyte-activation gene 3 (Lag3), Class-I-MHC-restricted T cell associated molecule (Crtam), Semaphorin 7A (Sema7A), and chemokine CCL1. These observations suggest that anergic T cells might not simply be functionally inert, and may have additional functional properties oriented towards other cellular components of the immune system.

Standard name | GSE46242_CTRL_VS_EGR2_DELETED_TH1_CD4_TCELL_DN
Systematic name | M9706
Organism | Mus musculus
PMID | 23548837
Authors | Zheng Y,Zha Y,Spaapen RM,Mathew R,Barr K,Bendelac A,Gajewski TF
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] Th1 cells: wildtype versus EGR2 [GeneID=1959] knockout.
Full description | T cell anergy is one of the mechanisms contributing to peripheral tolerance, particularly in the context of progressively growing tumors and in tolerogenic treatments promoting allograft acceptance. We recently reported that early growth response gene 2 (Egr2) is a critical transcription factor for the induction of anergy in vitro and in vivo, which was identified based on its ability to regulate the expression of inhibitory signaling molecules diacylglycerol kinase (DGK)-a and -z. We reasoned that other transcriptional targets of Egr2 might encode additional factors important for T cell anergy and immune regulation. Thus, we conducted two sets of genome-wide screens: gene expression profiling of wild type versus Egr2-deleted T cells treated under anergizing conditions, and a ChIP-Seq analysis to identify genes that bind Egr2 in anergic cells. Merging of these data sets revealed 49 targets that are directly regulated by Egr2. Among these are inhibitory signaling molecules previously reported to contribute to T cell anergy, but unexpectedly, also cell surface molecules and secreted factors, including lymphocyte-activation gene 3 (Lag3), Class-I-MHC-restricted T cell associated molecule (Crtam), Semaphorin 7A (Sema7A), and chemokine CCL1. These observations suggest that anergic T cells might not simply be functionally inert, and may have additional functional properties oriented towards other cellular components of the immune system.

Standard name | GSE46242_CTRL_VS_EGR2_DELETED_ANERGIC_TH1_CD4_TCELL_UP
Systematic name | M9707
Organism | Mus musculus
PMID | 23548837
Authors | Zheng Y,Zha Y,Spaapen RM,Mathew R,Barr K,Bendelac A,Gajewski TF
Category | C7
Sub-category |
Brief description | Genes up-regulated in anergic CD4 [GeneID=920] Th1 cells: wildtype versus EGR2 [GeneID=1959] knockout.
Full description | T cell anergy is one of the mechanisms contributing to peripheral tolerance, particularly in the context of progressively growing tumors and in tolerogenic treatments promoting allograft acceptance. We recently reported that early growth response gene 2 (Egr2) is a critical transcription factor for the induction of anergy in vitro and in vivo, which was identified based on its ability to regulate the expression of inhibitory signaling molecules diacylglycerol kinase (DGK)-a and -z. We reasoned that other transcriptional targets of Egr2 might encode additional factors important for T cell anergy and immune regulation. Thus, we conducted two sets of genome-wide screens: gene expression profiling of wild type versus Egr2-deleted T cells treated under anergizing conditions, and a ChIP-Seq analysis to identify genes that bind Egr2 in anergic cells. Merging of these data sets revealed 49 targets that are directly regulated by Egr2. Among these are inhibitory signaling molecules previously reported to contribute to T cell anergy, but unexpectedly, also cell surface molecules and secreted factors, including lymphocyte-activation gene 3 (Lag3), Class-I-MHC-restricted T cell associated molecule (Crtam), Semaphorin 7A (Sema7A), and chemokine CCL1. These observations suggest that anergic T cells might not simply be functionally inert, and may have additional functional properties oriented towards other cellular components of the immune system.

Standard name | GSE46242_CTRL_VS_EGR2_DELETED_ANERGIC_TH1_CD4_TCELL_DN
Systematic name | M9708
Organism | Mus musculus
PMID | 23548837
Authors | Zheng Y,Zha Y,Spaapen RM,Mathew R,Barr K,Bendelac A,Gajewski TF
Category | C7
Sub-category |
Brief description | Genes down-regulated in anergic CD4 [GeneID=920] Th1 cells: wildtype versus EGR2 [GeneID=1959] knockout.
Full description | T cell anergy is one of the mechanisms contributing to peripheral tolerance, particularly in the context of progressively growing tumors and in tolerogenic treatments promoting allograft acceptance. We recently reported that early growth response gene 2 (Egr2) is a critical transcription factor for the induction of anergy in vitro and in vivo, which was identified based on its ability to regulate the expression of inhibitory signaling molecules diacylglycerol kinase (DGK)-a and -z. We reasoned that other transcriptional targets of Egr2 might encode additional factors important for T cell anergy and immune regulation. Thus, we conducted two sets of genome-wide screens: gene expression profiling of wild type versus Egr2-deleted T cells treated under anergizing conditions, and a ChIP-Seq analysis to identify genes that bind Egr2 in anergic cells. Merging of these data sets revealed 49 targets that are directly regulated by Egr2. Among these are inhibitory signaling molecules previously reported to contribute to T cell anergy, but unexpectedly, also cell surface molecules and secreted factors, including lymphocyte-activation gene 3 (Lag3), Class-I-MHC-restricted T cell associated molecule (Crtam), Semaphorin 7A (Sema7A), and chemokine CCL1. These observations suggest that anergic T cells might not simply be functionally inert, and may have additional functional properties oriented towards other cellular components of the immune system.

Standard name | GSE46242_TH1_VS_ANERGIC_TH1_CD4_TCELL_UP
Systematic name | M9710
Organism | Mus musculus
PMID | 23548837
Authors | Zheng Y,Zha Y,Spaapen RM,Mathew R,Barr K,Bendelac A,Gajewski TF
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] Th1 cells: control versus anergic.
Full description | T cell anergy is one of the mechanisms contributing to peripheral tolerance, particularly in the context of progressively growing tumors and in tolerogenic treatments promoting allograft acceptance. We recently reported that early growth response gene 2 (Egr2) is a critical transcription factor for the induction of anergy in vitro and in vivo, which was identified based on its ability to regulate the expression of inhibitory signaling molecules diacylglycerol kinase (DGK)-a and -z. We reasoned that other transcriptional targets of Egr2 might encode additional factors important for T cell anergy and immune regulation. Thus, we conducted two sets of genome-wide screens: gene expression profiling of wild type versus Egr2-deleted T cells treated under anergizing conditions, and a ChIP-Seq analysis to identify genes that bind Egr2 in anergic cells. Merging of these data sets revealed 49 targets that are directly regulated by Egr2. Among these are inhibitory signaling molecules previously reported to contribute to T cell anergy, but unexpectedly, also cell surface molecules and secreted factors, including lymphocyte-activation gene 3 (Lag3), Class-I-MHC-restricted T cell associated molecule (Crtam), Semaphorin 7A (Sema7A), and chemokine CCL1. These observations suggest that anergic T cells might not simply be functionally inert, and may have additional functional properties oriented towards other cellular components of the immune system.

Standard name | GSE46242_TH1_VS_ANERGIC_TH1_CD4_TCELL_DN
Systematic name | M9712
Organism | Mus musculus
PMID | 23548837
Authors | Zheng Y,Zha Y,Spaapen RM,Mathew R,Barr K,Bendelac A,Gajewski TF
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] Th1 cells: control versus anergic.
Full description | T cell anergy is one of the mechanisms contributing to peripheral tolerance, particularly in the context of progressively growing tumors and in tolerogenic treatments promoting allograft acceptance. We recently reported that early growth response gene 2 (Egr2) is a critical transcription factor for the induction of anergy in vitro and in vivo, which was identified based on its ability to regulate the expression of inhibitory signaling molecules diacylglycerol kinase (DGK)-a and -z. We reasoned that other transcriptional targets of Egr2 might encode additional factors important for T cell anergy and immune regulation. Thus, we conducted two sets of genome-wide screens: gene expression profiling of wild type versus Egr2-deleted T cells treated under anergizing conditions, and a ChIP-Seq analysis to identify genes that bind Egr2 in anergic cells. Merging of these data sets revealed 49 targets that are directly regulated by Egr2. Among these are inhibitory signaling molecules previously reported to contribute to T cell anergy, but unexpectedly, also cell surface molecules and secreted factors, including lymphocyte-activation gene 3 (Lag3), Class-I-MHC-restricted T cell associated molecule (Crtam), Semaphorin 7A (Sema7A), and chemokine CCL1. These observations suggest that anergic T cells might not simply be functionally inert, and may have additional functional properties oriented towards other cellular components of the immune system.

Standard name | GSE46242_TH1_VS_ANERGIC_TH1_CD4_TCELL_WITH_EGR2_DELETED_UP
Systematic name | M9716
Organism | Mus musculus
PMID | 23548837
Authors | Zheng Y,Zha Y,Spaapen RM,Mathew R,Barr K,Bendelac A,Gajewski TF
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] Th1 cells with EGR2 [GeneID=1959] knockout: control versus anergic.
Full description | T cell anergy is one of the mechanisms contributing to peripheral tolerance, particularly in the context of progressively growing tumors and in tolerogenic treatments promoting allograft acceptance. We recently reported that early growth response gene 2 (Egr2) is a critical transcription factor for the induction of anergy in vitro and in vivo, which was identified based on its ability to regulate the expression of inhibitory signaling molecules diacylglycerol kinase (DGK)-a and -z. We reasoned that other transcriptional targets of Egr2 might encode additional factors important for T cell anergy and immune regulation. Thus, we conducted two sets of genome-wide screens: gene expression profiling of wild type versus Egr2-deleted T cells treated under anergizing conditions, and a ChIP-Seq analysis to identify genes that bind Egr2 in anergic cells. Merging of these data sets revealed 49 targets that are directly regulated by Egr2. Among these are inhibitory signaling molecules previously reported to contribute to T cell anergy, but unexpectedly, also cell surface molecules and secreted factors, including lymphocyte-activation gene 3 (Lag3), Class-I-MHC-restricted T cell associated molecule (Crtam), Semaphorin 7A (Sema7A), and chemokine CCL1. These observations suggest that anergic T cells might not simply be functionally inert, and may have additional functional properties oriented towards other cellular components of the immune system.

Standard name | GSE46242_TH1_VS_ANERGIC_TH1_CD4_TCELL_WITH_EGR2_DELETED_DN
Systematic name | M9717
Organism | Mus musculus
PMID | 23548837
Authors | Zheng Y,Zha Y,Spaapen RM,Mathew R,Barr K,Bendelac A,Gajewski TF
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] Th1 cells with EGR2 [GeneID=1959] knockout: control versus anergic.
Full description | T cell anergy is one of the mechanisms contributing to peripheral tolerance, particularly in the context of progressively growing tumors and in tolerogenic treatments promoting allograft acceptance. We recently reported that early growth response gene 2 (Egr2) is a critical transcription factor for the induction of anergy in vitro and in vivo, which was identified based on its ability to regulate the expression of inhibitory signaling molecules diacylglycerol kinase (DGK)-a and -z. We reasoned that other transcriptional targets of Egr2 might encode additional factors important for T cell anergy and immune regulation. Thus, we conducted two sets of genome-wide screens: gene expression profiling of wild type versus Egr2-deleted T cells treated under anergizing conditions, and a ChIP-Seq analysis to identify genes that bind Egr2 in anergic cells. Merging of these data sets revealed 49 targets that are directly regulated by Egr2. Among these are inhibitory signaling molecules previously reported to contribute to T cell anergy, but unexpectedly, also cell surface molecules and secreted factors, including lymphocyte-activation gene 3 (Lag3), Class-I-MHC-restricted T cell associated molecule (Crtam), Semaphorin 7A (Sema7A), and chemokine CCL1. These observations suggest that anergic T cells might not simply be functionally inert, and may have additional functional properties oriented towards other cellular components of the immune system.

Standard name | GSE43863_NAIVE_VS_MEMORY_TH1_CD4_TCELL_D150_LCMV_DN
Systematic name | M9718
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus Th1 memory.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_LY6C_LOW_CXCR5NEG_CD4_EFF_TCELL_D6_LCMV_UP
Systematic name | M9720
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus Ly6c low CXCR5- effector during acute infection of LCMV.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_LY6C_LOW_CXCR5NEG_CD4_EFF_TCELL_D6_LCMV_DN
Systematic name | M9721
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus Ly6c low CXCR5- effector during acute infection of LCMV.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_MEMORY_TH1_CD4_TCELL_D150_LCMV_UP
Systematic name | M9722
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus Th1 memory.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_TH1_EFF_CD4_TCELL_D6_LCMV_UP
Systematic name | M9723
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA cells: naïve versus during acute infection of LCMV.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_TH1_EFF_CD4_TCELL_D6_LCMV_DN
Systematic name | M9724
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA cells: naïve versus during acute infection of LCMV.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_TFH_CD4_EFF_TCELL_D6_LCMV_UP
Systematic name | M9725
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus effector during acute infection of LCMV.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_TFH_CD4_EFF_TCELL_D6_LCMV_DN
Systematic name | M9727
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus effector during acute infection of LCMV.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_LY6C_INT_CXCR5POS_CD4_EFF_TCELL_D6_LCMV_UP
Systematic name | M9730
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus Ly6c+ CXCR5+ [GeneID=643] effector during acute infection of LCMV.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_LY6C_INT_CXCR5POS_CD4_EFF_TCELL_D6_LCMV_DN
Systematic name | M9732
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus Ly6c+ CXCR5+ [GeneID=643] effector during acute infection of LCMV.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_DAY6_EFF_VS_DAY150_MEM_LY6C_INT_CXCR5POS_CD4_TCELL_DN
Systematic name | M9733
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in Ly6c int CXCR5+ CD4 [GeneID=643;920] T cells: effector during acute infection of LCMV versus memory.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TH1_VS_TFH_MEMORY_CD4_TCELL_UP
Systematic name | M9734
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA memory T cells: Th1 versus follicular helper (Tfh).
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TH1_VS_TFH_MEMORY_CD4_TCELL_DN
Systematic name | M9735
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA memory T cells: Th1 versus follicular helper (Tfh).
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TH1_VS_LY6C_INT_CXCR5POS_MEMORY_CD4_TCELL_UP
Systematic name | M9736
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA memory T cells: Th1 versus Ly6c int CXCR5+ [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_MEMORY_TFH_CD4_TCELL_D150_LCMV_UP
Systematic name | M9737
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus memory follicular helper (Tfh).
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_MEMORY_TFH_CD4_TCELL_D150_LCMV_DN
Systematic name | M9738
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus memory follicular helper (Tfh).
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_MEMORY_LY6C_INT_CXCR5POS_CD4_TCELL_D150_LCMV_UP
Systematic name | M9739
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus Ly6c int CXCR5+ [GeneID=643] memory.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_NAIVE_VS_MEMORY_LY6C_INT_CXCR5POS_CD4_TCELL_D150_LCMV_DN
Systematic name | M9741
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA T cells: naïve versus Ly6c int CXCR5+ [GeneID=643] memory.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_DAY6_EFF_VS_DAY150_MEM_TH1_CD4_TCELL_UP
Systematic name | M9742
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in Th1 CD4 [GeneID=920] SMARTA T cells: effector during acute infection of LCMV versus memory.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_DAY6_EFF_VS_DAY150_MEM_TH1_CD4_TCELL_DN
Systematic name | M9744
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in Th1 CD4 [GeneID=920] SMARTA T cells: effector during acute infection of LCMV versus memory.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_DAY6_EFF_VS_DAY150_MEM_TFH_CD4_TCELL_UP
Systematic name | M9745
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in follicular helper CD4 [GeneID=920] SMARTA T cells (Tfh): effector during acute infection of LCMV versus memory.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_DAY6_EFF_VS_DAY150_MEM_TFH_CD4_TCELL_DN
Systematic name | M9747
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in follicular helper CD4 [GeneID=920] SMARTA T cells (Tfh): effector during acute infection of LCMV versus memory.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_DAY6_EFF_VS_DAY150_MEM_LY6C_INT_CXCR5POS_CD4_TCELL_UP
Systematic name | M9748
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in Ly6c int CXCR5+ CD4 [GeneID=643;920] T cells: effector during acute infection of LCMV versus memory.
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TFH_VS_LY6C_INT_CXCR5POS_EFFECTOR_CD4_TCELL_DN
Systematic name | M9749
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: follicular helper (Tfh) versus Ly6c int CXCR5+ [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TFH_VS_LY6C_LOW_CXCR5NEG_EFFECTOR_CD4_TCELL_UP
Systematic name | M9750
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: follicular helper (Tfh) versus Ly6c low CXCR5- [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TFH_VS_LY6C_LOW_CXCR5NEG_EFFECTOR_CD4_TCELL_DN
Systematic name | M9751
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: follicular helper (Tfh) versus Ly6c low CXCR5- [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_LY6C_INT_CXCR5POS_VS_LY6C_LOW_CXCR5NEG_EFFECTOR_CD4_TCELL_UP
Systematic name | M9754
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: Ly6c int CXCR5+ [GeneID=643] versus Ly6c low CXCR5- [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_LY6C_INT_CXCR5POS_VS_LY6C_LOW_CXCR5NEG_EFFECTOR_CD4_TCELL_DN
Systematic name | M9755
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: Ly6c int CXCR5+ [GeneID=643] versus Ly6c low CXCR5- [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TH1_VS_LY6C_INT_CXCR5POS_MEMORY_CD4_TCELL_DN
Systematic name | M9757
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA memory T cells: Th1 versus Ly6c int CXCR5+ [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TFH_VS_LY6C_INT_CXCR5POS_MEMORY_CD4_TCELL_UP
Systematic name | M9759
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA memory T cells: follicular helper (Tfh) versus Ly6c int CXCR5+ [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TFH_VS_LY6C_INT_CXCR5POS_MEMORY_CD4_TCELL_DN
Systematic name | M9761
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA memory T cells: follicular helper (Tfh) versus Ly6c int CXCR5+ [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TH1_VS_TFH_EFFECTOR_CD4_TCELL_UP
Systematic name | M9762
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: Th1 versus follicular helper (Tfh).
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TH1_VS_TFH_EFFECTOR_CD4_TCELL_DN
Systematic name | M9763
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: Th1 versus follicular helper (Tfh).
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TH1_VS_LY6C_INT_CXCR5POS_EFFECTOR_CD4_TCELL_UP
Systematic name | M9764
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: Th1 versus Ly6c int CXCR5+ [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TH1_VS_LY6C_INT_CXCR5POS_EFFECTOR_CD4_TCELL_DN
Systematic name | M9765
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: Th1 versus Ly6c int CXCR5+ [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TH1_VS_LY6C_LOW_CXCR5NEG_EFFECTOR_CD4_TCELL_UP
Systematic name | M9767
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: Th1 versus Ly6c low CXCR5- [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TH1_VS_LY6C_LOW_CXCR5NEG_EFFECTOR_CD4_TCELL_DN
Systematic name | M9768
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: Th1 versus Ly6c low CXCR5- [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE43863_TFH_VS_LY6C_INT_CXCR5POS_EFFECTOR_CD4_TCELL_UP
Systematic name | M9770
Organism | Mus musculus
PMID | 23583644
Authors | Hale JS,Youngblood B,Latner DR,Mohammed AU,Ye L,Akondy RS,Wu T,Iyer SS,Ahmed R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] SMARTA effector T cells during acute infection of LCMV: follicular helper (Tfh) versus Ly6c int CXCR5+ [GeneID=643].
Full description | CD4 T follicular helper (Tfh) cells provide the required signals to B cells for germinal center reactions that are necessary for longlived antibody responses. However, it remains unclear whether there are CD4+ memory T cells committed to the Tfh lineage after antigen clearance. Using adoptive transfer of antigen-specific memory CD4+ subpopulations (based on CXCR5 and Ly6c expression)in the LCMV infection model, we found that there are distinct memory CD4+ T cell populations with commitment to the Tfh and Th1 lineages. Our conclusions are based on gene expression profiles, epigenetic studies and phenotypic and functional analysis. The gene expression profiles of virus-specific CD4 T cell subets at effector and memory stages is presented here.

Standard name | GSE46143_CTRL_VS_LMP2A_TRANSDUCED_CD10_POS_GC_BCELL_UP
Systematic name | M9771
Organism | Homo sapiens
PMID | 23592216
Authors | Vockerodt M,Wei W,Nagy E,Prouzova Z,Schrader A,Kube D,Rowe M,Woodman CB,Murray PG
Category | C7
Sub-category |
Brief description | Genes up-regulated in MME+ [GeneID=4311] germinal center B lymphocytes: control versus over-expressing viral (EBV) gene LMP2A.
Full description | In this study, we have investigated the effect of LMP2A on gene expression in normal human GC B cells using a non-viral vector based system

Standard name | GSE46143_CTRL_VS_LMP2A_TRANSDUCED_CD10_POS_GC_BCELL_DN
Systematic name | M9773
Organism | Homo sapiens
PMID | 23592216
Authors | Vockerodt M,Wei W,Nagy E,Prouzova Z,Schrader A,Kube D,Rowe M,Woodman CB,Murray PG
Category | C7
Sub-category |
Brief description | Genes down-regulated in MME+ [GeneID=4311] germinal center B lymphocytes: control versus over-expressing viral (EBV) gene LMP2A.
Full description | In this study, we have investigated the effect of LMP2A on gene expression in normal human GC B cells using a non-viral vector based system

Standard name | GSE44649_NAIVE_VS_ACTIVATED_CD8_TCELL_UP
Systematic name | M9774
Organism | Mus musculus
PMID | 23603793
Authors | Gracias DT,Stelekati E,Hope JL,Boesteanu AC,Doering TA,Norton J,Mueller YM,Fraietta JA,Wherry EJ,Turner M,Katsikis PD
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: resting versus activated.
Full description | MicroRNA-155 (miR-155) is upregulated in primary effector CD8 T cells but is expressed at low amounts in naïve cells. Anti-viral CD8 T cell responses and viral clearance were impaired in miR-155 deficient (bic-/-) mice, and this defect was intrinsic to CD8 T cells, as adoptively transferred bic-/- CD8 T cells generated greatly reduced primary and memory responses during infection. To understand the mechanism by which miR-155 regulates CD8 T cell activation, we analyzed the gene expression profiles of naive and in vitro activated wild-type and bic-/- CD8 T cells.

Standard name | GSE44649_NAIVE_VS_ACTIVATED_CD8_TCELL_MIR155_KO_UP
Systematic name | M9776
Organism | Mus musculus
PMID | 23603793
Authors | Gracias DT,Stelekati E,Hope JL,Boesteanu AC,Doering TA,Norton J,Mueller YM,Fraietta JA,Wherry EJ,Turner M,Katsikis PD
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells with MIR155 [GeneID=406947] knockout: resting versus activated.
Full description | MicroRNA-155 (miR-155) is upregulated in primary effector CD8 T cells but is expressed at low amounts in naïve cells. Anti-viral CD8 T cell responses and viral clearance were impaired in miR-155 deficient (bic-/-) mice, and this defect was intrinsic to CD8 T cells, as adoptively transferred bic-/- CD8 T cells generated greatly reduced primary and memory responses during infection. To understand the mechanism by which miR-155 regulates CD8 T cell activation, we analyzed the gene expression profiles of naive and in vitro activated wild-type and bic-/- CD8 T cells.

Standard name | GSE44649_NAIVE_VS_ACTIVATED_CD8_TCELL_MIR155_KO_DN
Systematic name | M9777
Organism | Mus musculus
PMID | 23603793
Authors | Gracias DT,Stelekati E,Hope JL,Boesteanu AC,Doering TA,Norton J,Mueller YM,Fraietta JA,Wherry EJ,Turner M,Katsikis PD
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells with MIR155 [GeneID=406947] knockout: resting versus activated.
Full description | MicroRNA-155 (miR-155) is upregulated in primary effector CD8 T cells but is expressed at low amounts in naïve cells. Anti-viral CD8 T cell responses and viral clearance were impaired in miR-155 deficient (bic-/-) mice, and this defect was intrinsic to CD8 T cells, as adoptively transferred bic-/- CD8 T cells generated greatly reduced primary and memory responses during infection. To understand the mechanism by which miR-155 regulates CD8 T cell activation, we analyzed the gene expression profiles of naive and in vitro activated wild-type and bic-/- CD8 T cells.

Standard name | GSE44649_WT_VS_MIR155_KO_NAIVE_CD8_TCELL_UP
Systematic name | M9778
Organism | Mus musculus
PMID | 23603793
Authors | Gracias DT,Stelekati E,Hope JL,Boesteanu AC,Doering TA,Norton J,Mueller YM,Fraietta JA,Wherry EJ,Turner M,Katsikis PD
Category | C7
Sub-category |
Brief description | Genes up-regulated in resting CD8 T cells: wildtype versus MIR155 [GeneID=406947] knockout.
Full description | MicroRNA-155 (miR-155) is upregulated in primary effector CD8 T cells but is expressed at low amounts in naïve cells. Anti-viral CD8 T cell responses and viral clearance were impaired in miR-155 deficient (bic-/-) mice, and this defect was intrinsic to CD8 T cells, as adoptively transferred bic-/- CD8 T cells generated greatly reduced primary and memory responses during infection. To understand the mechanism by which miR-155 regulates CD8 T cell activation, we analyzed the gene expression profiles of naive and in vitro activated wild-type and bic-/- CD8 T cells.

Standard name | GSE44649_NAIVE_VS_ACTIVATED_CD8_TCELL_DN
Systematic name | M9779
Organism | Mus musculus
PMID | 23603793
Authors | Gracias DT,Stelekati E,Hope JL,Boesteanu AC,Doering TA,Norton J,Mueller YM,Fraietta JA,Wherry EJ,Turner M,Katsikis PD
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: resting versus activated.
Full description | MicroRNA-155 (miR-155) is upregulated in primary effector CD8 T cells but is expressed at low amounts in naïve cells. Anti-viral CD8 T cell responses and viral clearance were impaired in miR-155 deficient (bic-/-) mice, and this defect was intrinsic to CD8 T cells, as adoptively transferred bic-/- CD8 T cells generated greatly reduced primary and memory responses during infection. To understand the mechanism by which miR-155 regulates CD8 T cell activation, we analyzed the gene expression profiles of naive and in vitro activated wild-type and bic-/- CD8 T cells.

Standard name | GSE44649_WT_VS_MIR155_KO_ACTIVATED_CD8_TCELL_UP
Systematic name | M9782
Organism | Mus musculus
PMID | 23603793
Authors | Gracias DT,Stelekati E,Hope JL,Boesteanu AC,Doering TA,Norton J,Mueller YM,Fraietta JA,Wherry EJ,Turner M,Katsikis PD
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated CD8 T cells: wildtype versus MIR155 [GeneID=406947] knockout.
Full description | MicroRNA-155 (miR-155) is upregulated in primary effector CD8 T cells but is expressed at low amounts in naïve cells. Anti-viral CD8 T cell responses and viral clearance were impaired in miR-155 deficient (bic-/-) mice, and this defect was intrinsic to CD8 T cells, as adoptively transferred bic-/- CD8 T cells generated greatly reduced primary and memory responses during infection. To understand the mechanism by which miR-155 regulates CD8 T cell activation, we analyzed the gene expression profiles of naive and in vitro activated wild-type and bic-/- CD8 T cells.

Standard name | GSE44649_WT_VS_MIR155_KO_ACTIVATED_CD8_TCELL_DN
Systematic name | M9784
Organism | Mus musculus
PMID | 23603793
Authors | Gracias DT,Stelekati E,Hope JL,Boesteanu AC,Doering TA,Norton J,Mueller YM,Fraietta JA,Wherry EJ,Turner M,Katsikis PD
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated CD8 T cells: wildtype versus MIR155 [GeneID=406947] knockout.
Full description | MicroRNA-155 (miR-155) is upregulated in primary effector CD8 T cells but is expressed at low amounts in naïve cells. Anti-viral CD8 T cell responses and viral clearance were impaired in miR-155 deficient (bic-/-) mice, and this defect was intrinsic to CD8 T cells, as adoptively transferred bic-/- CD8 T cells generated greatly reduced primary and memory responses during infection. To understand the mechanism by which miR-155 regulates CD8 T cell activation, we analyzed the gene expression profiles of naive and in vitro activated wild-type and bic-/- CD8 T cells.

Standard name | GSE44649_WT_VS_MIR155_KO_NAIVE_CD8_TCELL_DN
Systematic name | M9785
Organism | Mus musculus
PMID | 23603793
Authors | Gracias DT,Stelekati E,Hope JL,Boesteanu AC,Doering TA,Norton J,Mueller YM,Fraietta JA,Wherry EJ,Turner M,Katsikis PD
Category | C7
Sub-category |
Brief description | Genes down-regulated in resting CD8 T cells: wildtype versus MIR155 [GeneID=406947] knockout.
Full description | MicroRNA-155 (miR-155) is upregulated in primary effector CD8 T cells but is expressed at low amounts in naïve cells. Anti-viral CD8 T cell responses and viral clearance were impaired in miR-155 deficient (bic-/-) mice, and this defect was intrinsic to CD8 T cells, as adoptively transferred bic-/- CD8 T cells generated greatly reduced primary and memory responses during infection. To understand the mechanism by which miR-155 regulates CD8 T cell activation, we analyzed the gene expression profiles of naive and in vitro activated wild-type and bic-/- CD8 T cells.

Standard name | GSE42724_MEMORY_BCELL_VS_PLASMABLAST_UP
Systematic name | M9786
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: memory versus plasmablasts.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_B1_BCELL_VS_PLASMABLAST_UP
Systematic name | M9787
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: B1 versus plasmablasts.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_B1_BCELL_VS_PLASMABLAST_DN
Systematic name | M9789
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: B1 versus plasmablasts.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_NAIVE_VS_B1_BCELL_UP
Systematic name | M9790
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: naïve versus B1.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_MEMORY_BCELL_VS_PLASMABLAST_DN
Systematic name | M9791
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: memory versus plasmablasts.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_NAIVE_VS_MEMORY_BCELL_UP
Systematic name | M9792
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: naïve versus memory.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_NAIVE_VS_MEMORY_BCELL_DN
Systematic name | M9793
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: naïve versus memory.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_MEMORY_VS_B1_BCELL_UP
Systematic name | M9794
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: memory versus B1.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_NAIVE_VS_B1_BCELL_DN
Systematic name | M9796
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: naïve versus B1.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_NAIVE_BCELL_VS_PLASMABLAST_UP
Systematic name | M9797
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: naïve versus plasmablasts.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_NAIVE_BCELL_VS_PLASMABLAST_DN
Systematic name | M9800
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: naïve versus plasmablasts.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE42724_MEMORY_VS_B1_BCELL_DN
Systematic name | M9801
Organism | Homo sapiens
PMID | 23613519
Authors | Covens K,Verbinnen B,Geukens N,Meyts I,Schuit F,Lommel Van L,Jacquemin M,Bossuyt X
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: memory versus B1.
Full description | The recent discovery of the human B1 cells, identified by the expression of CD20, CD27 and CD43 in absence of expression of CD70 and CD69 has been subject of debate. Some studies have raised the possibility that these cells are B cells differentiating towards the plasmablast and plasma cell stage rather than being the human counterpart of murine B1 cells. No further in depth studies have been performed. Therefore, a functional comparison was made between, the proposed B1 cells and plasmablasts. We observed that for several functional characteristics (distribution of isotypes of spontaneously producted antibodies, production of antigen-specific antibodies after vaccination with both T-cell dependent as well as T-cell independent antigen, the proposed B1 cells behaved similar to plasmablasts. In addition, we were able to differentiate the proposed B1 cells in vitro, indicating that they are not from a distinct lineage as the murine B1 cells. Gene expression analysis revealed that these cells cluster between memory B cells and plasmablasts, contradicting them being the genuine human counterpart of murine B1 cells, rather revealing a preplasmablast phenotype.

Standard name | GSE45382_UNTREATED_VS_TGFB_TREATED_MACROPHAGES_UP
Systematic name | M9803
Organism | Mus musculus
PMID | 23643295
Authors | Gu Z,Chhabra AY,Alard P,Warner DR,Kosiewicz MM
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: untreated versus TGFB2 [GeneID=7042].
Full description | F4/80+ macrophages treated with TGFb2 are potently tolerogenic. Our understanding of the molecular mechanisms mediating the development of these tolerogenic properties is incomplete. We used microarray analysis to identify molecules that are involved in the tolerogenic mechanisms in murine TGFb-treated macrophages.

Standard name | GSE45382_UNTREATED_VS_TGFB_TREATED_MACROPHAGES_DN
Systematic name | M9804
Organism | Mus musculus
PMID | 23643295
Authors | Gu Z,Chhabra AY,Alard P,Warner DR,Kosiewicz MM
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: untreated versus TGFB2 [GeneID=7042].
Full description | F4/80+ macrophages treated with TGFb2 are potently tolerogenic. Our understanding of the molecular mechanisms mediating the development of these tolerogenic properties is incomplete. We used microarray analysis to identify molecules that are involved in the tolerogenic mechanisms in murine TGFb-treated macrophages.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_1DAY_STIMULATED_IRF4_KO_BCELL_UP
Systematic name | M9807
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4-KO.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_1DAY_STIMULATED_IRF4_KO_BCELL_DN
Systematic name | M9808
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4-KO.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_3DAY_STIMULATED_IRF4_KO_BCELL_UP
Systematic name | M9812
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4-KO.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_3DAY_STIMULATED_IRF4_KO_BCELL_DN
Systematic name | M9813
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4-KO.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4_KO_VS_WT_CD40L_IL2_IL5_1DAY_STIMULATED_BCELL_UP
Systematic name | M9817
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4_KO_VS_WT_CD40L_IL2_IL5_1DAY_STIMULATED_BCELL_DN
Systematic name | M9819
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4_KO_VS_WT_CD40L_IL2_IL5_3DAY_STIMULATED_BCELL_UP
Systematic name | M9821
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4_KO_VS_WT_CD40L_IL2_IL5_3DAY_STIMULATED_BCELL_DN
Systematic name | M9824
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_DAY1_VS_DAY3_CD40L_IL2_IL5_STIMULATED_IRF4_KO_BCELL_UP
Systematic name | M9825
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4-KO.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_DAY1_VS_DAY3_CD40L_IL2_IL5_STIMULATED_IRF4_KO_BCELL_DN
Systematic name | M9827
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4-KO.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_1DAY_STIMULATED_IRF4HIGH_SORTED_BCELL_UP
Systematic name | M9829
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4high.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_1DAY_STIMULATED_IRF4HIGH_SORTED_BCELL_DN
Systematic name | M9830
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4high.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_3DAY_STIMULATED_IRF4HIGH_SORTED_BCELL_UP
Systematic name | M9831
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4high.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_3DAY_STIMULATED_IRF4HIGH_SORTED_BCELL_DN
Systematic name | M9832
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4high.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_1DAY_STIMULATED_IRF4MID_SORTED_BCELL_UP
Systematic name | M9833
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4intermediate.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_1DAY_STIMULATED_IRF4MID_SORTED_BCELL_DN
Systematic name | M9835
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4intermediate.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_3DAY_STIMULATED_IRF4MID_SORTED_BCELL_UP
Systematic name | M9836
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4intermediate.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_3DAY_STIMULATED_IRF4MID_SORTED_BCELL_DN
Systematic name | M9837
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in at day 0 B cell IRF4-KO versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4intermediate.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_DAY1_VS_DAY3_CD40L_IL2_IL5_STIMULATED_IRF4HIGH_BCELL_UP
Systematic name | M9838
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4high versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4high.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_DAY1_VS_DAY3_CD40L_IL2_IL5_STIMULATED_IRF4HIGH_BCELL_DN
Systematic name | M9839
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4high versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4high.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_DAY1_VS_DAY3_CD40L_IL2_IL5_STIMULATED_IRF4MID_BCELL_UP
Systematic name | M9840
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4intermediate versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4intermediate.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_DAY1_VS_DAY3_CD40L_IL2_IL5_STIMULATED_IRF4MID_BCELL_DN
Systematic name | M9842
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4intermediate versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4intermediate.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4HIGH_VS_IRF4MID_CD40L_IL2_IL5_DAY1_STIMULATED_BCELL_UP
Systematic name | M9843
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4high versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4intermediate.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4HIGH_VS_IRF4MID_CD40L_IL2_IL5_DAY1_STIMULATED_BCELL_DN
Systematic name | M9844
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4high versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4intermediate.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4HIGH_VS_IRF4MID_CD40L_IL2_IL5_DAY3_STIMULATED_BCELL_UP
Systematic name | M9845
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4high versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4intermediate.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4HIGH_VS_IRF4MID_CD40L_IL2_IL5_DAY3_STIMULATED_BCELL_DN
Systematic name | M9846
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4high versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4intermediate.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4HIGH_VS_WT_CD40L_IL2_IL5_DAY1_STIMULATED_BCELL_UP
Systematic name | M9847
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4high versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4HIGH_VS_WT_CD40L_IL2_IL5_DAY1_STIMULATED_BCELL_DN
Systematic name | M9848
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4high versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4MID_VS_WT_CD40L_IL2_IL5_DAY1_STIMULATED_BCELL_UP
Systematic name | M9850
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4intermediate versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4MID_VS_WT_CD40L_IL2_IL5_DAY1_STIMULATED_BCELL_DN
Systematic name | M9851
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell IRF4intermediate versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4HIGH_VS_WT_CD40L_IL2_IL5_DAY3_STIMULATED_BCELL_UP
Systematic name | M9853
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4high versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4HIGH_VS_WT_CD40L_IL2_IL5_DAY3_STIMULATED_BCELL_DN
Systematic name | M9854
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4high versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4MID_VS_WT_CD40L_IL2_IL5_DAY3_STIMULATED_BCELL_UP
Systematic name | M9856
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4intermediate versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4MID_VS_WT_CD40L_IL2_IL5_DAY3_STIMULATED_BCELL_DN
Systematic name | M9859
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell IRF4intermediate versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4_KO_VS_WT_UNSTIM_BCELL_UP
Systematic name | M9860
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in at day 0 B cell IRF4-KO versus at day 0 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_IRF4_KO_VS_WT_UNSTIM_BCELL_DN
Systematic name | M9861
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in at day 0 B cell IRF4-KO versus at day 0 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_DAY1_STIMULATED_BCELL_UP
Systematic name | M9862
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in at day 0 B cell wildtype versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_DAY1_STIMULATED_BCELL_DN
Systematic name | M9864
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in at day 0 B cell wildtype versus CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_DAY3_STIMULATED_BCELL_UP
Systematic name | M9867
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in at day 0 B cell wildtype versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_UNSTIM_VS_CD40L_IL2_IL5_DAY3_STIMULATED_BCELL_DN
Systematic name | M9870
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in at day 0 B cell wildtype versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_DAY1_VS_DAY3_CD40L_IL2_IL5_STIMULATED_BCELL_UP
Systematic name | M9871
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell wildtype versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46606_DAY1_VS_DAY3_CD40L_IL2_IL5_STIMULATED_BCELL_DN
Systematic name | M9872
Organism | Mus musculus
PMID | 23684984
Authors | Ochiai K,Maienschein-Cline M,Simonetti G,Chen J,Rosenthal R,Brink R,Chong AS,Klein U,Dinner AR,Singh H,Sciammas R
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD40L and IL-2 IL-4 IL-5 stimulated at day 1 B cell wildtype versus CD40L and IL-2 IL-4 IL-5 stimulated at day 3 B cell wildtype.
Full description | Temporal analysis of B cell activation in vitro using CD40L and IL-2/4/5 cytokines in wild type Irf4+/+ B cells or in mutant Irf4-/- B cells harboring a tet-inducible allele of Irf4. IRF4 expression was restored, or not, in the Irf4-/- background by culturing in the presence of low or high concentrations of doxycycline. The results provide insight in the role of IRF4 expression levels in coordinating different programs of B cell differentiation.

Standard name | GSE46025_WT_VS_FOXO1_KO_KLRG1_LOW_CD8_EFFECTOR_TCELL_UP
Systematic name | M9873
Organism | Mus musculus
PMID | 23712431
Authors | Michelini Hess R,Doedens AL,Goldrath AW,Hedrick SM
Category | C7
Sub-category |
Brief description | Genes up-regulated during acute viral infection in KLRG1 low [GeneID=10219] CD8 T cells: wildtype versus FOXO1 [GeneID=2308] knockout.
Full description | The forkhead O transcription factors (FOXO) integrate a range of extracellular signals including growth factor signaling, inflammation, oxidative stress and nutrient availability, to substantially alter the program of gene expression and modulate cell survival, cell cycle progression, and many cell-type specific responses yet to be unraveled. Naive antigen-specific CD8+ T cells undergo a rapid expansion and arming of effector function within days of pathogen exposure, but in addition, by the peak of expansion, they form precursors to memory T cells capable of self-renewal and indefinite survival. We used microarrays to determine whether FOXO1 broadly affects effector and memory differentiation, and to what extent FOXO1 determines the program of memory T cell gene expression.

Standard name | GSE46025_WT_VS_FOXO1_KO_KLRG1_LOW_CD8_EFFECTOR_TCELL_DN
Systematic name | M9876
Organism | Mus musculus
PMID | 23712431
Authors | Michelini Hess R,Doedens AL,Goldrath AW,Hedrick SM
Category | C7
Sub-category |
Brief description | Genes down-regulated during acute viral infection in KLRG1 low [GeneID=10219] CD8 T cells: wildtype versus FOXO1 [GeneID=2308] knockout.
Full description | The forkhead O transcription factors (FOXO) integrate a range of extracellular signals including growth factor signaling, inflammation, oxidative stress and nutrient availability, to substantially alter the program of gene expression and modulate cell survival, cell cycle progression, and many cell-type specific responses yet to be unraveled. Naive antigen-specific CD8+ T cells undergo a rapid expansion and arming of effector function within days of pathogen exposure, but in addition, by the peak of expansion, they form precursors to memory T cells capable of self-renewal and indefinite survival. We used microarrays to determine whether FOXO1 broadly affects effector and memory differentiation, and to what extent FOXO1 determines the program of memory T cell gene expression.

Standard name | GSE45739_NRAS_KO_VS_WT_UNSTIM_CD4_TCELL_UP
Systematic name | M9877
Organism | Mus musculus
PMID | 23755101
Authors | Lynch SJ,Zavadil J,Pellicer A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: NRAS [GeneID=4893] knockout versus wildtype.
Full description | It has been recently shown that N-ras plays a preferential role in immune cell development and function; specifically: N-ras, but not H-ras or K-ras, could be activated at and signal from the Golgi membrane of immune cells following a low level TCR stimulus. The goal of our studies was to test the hypothesis that N-ras and H-ras played distinct roles in immune cells at the level of the transcriptome. First, we showed via mRNA expression profiling that there were over four hundred genes that were uniquely differentially regulated either by N-ras or H-ras, which provided strong evidence in favor of the hypothesis that N-ras and H-ras have distinct functions in immune cells. We next characterized the genes that were differentially regulated by N-ras in T cells following a low-level TCR stimulus. Of the large pool of candidate genes that were differentially regulated by N-ras downstream of TCR ligation, four genes were verified in qRT-PCR-based validation experiments as being differentially regulated by N-ras (Dntt, Slc9a6, Chst1, and Lars2). Finally, although there was little overlap between individual genes that were regulated by N-ras in unstimulated thymocytes and stimulated CD4+ T-cells, there was a nearly complete correspondence between the signaling pathways that were regulated by N-ras in these two immune cell types. Since we were interested primarily in genes that were differentially regulated by N-ras following a low-level TCR stimulus, our microarray data comparison was between data from TCR-stimulated, WT CD4+ T-cells and from TCR-stimulated, N-ras KO CD4+ T-cells. Genes that were differentially regulated in the comparison between stimulated N-ras KO CD4+ T-cells and unstimulated N-ras KO CD4+ T-cells, as well as those genes that were differentially regulated in the comparison between stimulated WT CD4+ T-cells and unstimulated WT CD4+ T-cells were excluded from this analysis. To determine if N-ras and H-ras regulate different sets of genes in thymocytes, a comparison was made between the set of genes that were differentially regulated by N-ras in the [WT] vs. [N-ras KO] comparison and the set of genes that were differentially regulated by H-ras in the [WT] vs. [H-ras KO] comparison.

Standard name | GSE45739_NRAS_KO_VS_WT_UNSTIM_CD4_TCELL_DN
Systematic name | M9879
Organism | Mus musculus
PMID | 23755101
Authors | Lynch SJ,Zavadil J,Pellicer A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: NRAS [GeneID=4893] knockout versus wildtype.
Full description | It has been recently shown that N-ras plays a preferential role in immune cell development and function; specifically: N-ras, but not H-ras or K-ras, could be activated at and signal from the Golgi membrane of immune cells following a low level TCR stimulus. The goal of our studies was to test the hypothesis that N-ras and H-ras played distinct roles in immune cells at the level of the transcriptome. First, we showed via mRNA expression profiling that there were over four hundred genes that were uniquely differentially regulated either by N-ras or H-ras, which provided strong evidence in favor of the hypothesis that N-ras and H-ras have distinct functions in immune cells. We next characterized the genes that were differentially regulated by N-ras in T cells following a low-level TCR stimulus. Of the large pool of candidate genes that were differentially regulated by N-ras downstream of TCR ligation, four genes were verified in qRT-PCR-based validation experiments as being differentially regulated by N-ras (Dntt, Slc9a6, Chst1, and Lars2). Finally, although there was little overlap between individual genes that were regulated by N-ras in unstimulated thymocytes and stimulated CD4+ T-cells, there was a nearly complete correspondence between the signaling pathways that were regulated by N-ras in these two immune cell types. Since we were interested primarily in genes that were differentially regulated by N-ras following a low-level TCR stimulus, our microarray data comparison was between data from TCR-stimulated, WT CD4+ T-cells and from TCR-stimulated, N-ras KO CD4+ T-cells. Genes that were differentially regulated in the comparison between stimulated N-ras KO CD4+ T-cells and unstimulated N-ras KO CD4+ T-cells, as well as those genes that were differentially regulated in the comparison between stimulated WT CD4+ T-cells and unstimulated WT CD4+ T-cells were excluded from this analysis. To determine if N-ras and H-ras regulate different sets of genes in thymocytes, a comparison was made between the set of genes that were differentially regulated by N-ras in the [WT] vs. [N-ras KO] comparison and the set of genes that were differentially regulated by H-ras in the [WT] vs. [H-ras KO] comparison.

Standard name | GSE45739_NRAS_KO_VS_WT_ACD3_ACD28_STIM_CD4_TCELL_UP
Systematic name | M9881
Organism | Mus musculus
PMID | 23755101
Authors | Lynch SJ,Zavadil J,Pellicer A
Category | C7
Sub-category |
Brief description | Genes up-regulated in activated CD4 [GeneID=920] T cells: NRAS [GeneID=4893] knockout versus wildtype.
Full description | It has been recently shown that N-ras plays a preferential role in immune cell development and function; specifically: N-ras, but not H-ras or K-ras, could be activated at and signal from the Golgi membrane of immune cells following a low level TCR stimulus. The goal of our studies was to test the hypothesis that N-ras and H-ras played distinct roles in immune cells at the level of the transcriptome. First, we showed via mRNA expression profiling that there were over four hundred genes that were uniquely differentially regulated either by N-ras or H-ras, which provided strong evidence in favor of the hypothesis that N-ras and H-ras have distinct functions in immune cells. We next characterized the genes that were differentially regulated by N-ras in T cells following a low-level TCR stimulus. Of the large pool of candidate genes that were differentially regulated by N-ras downstream of TCR ligation, four genes were verified in qRT-PCR-based validation experiments as being differentially regulated by N-ras (Dntt, Slc9a6, Chst1, and Lars2). Finally, although there was little overlap between individual genes that were regulated by N-ras in unstimulated thymocytes and stimulated CD4+ T-cells, there was a nearly complete correspondence between the signaling pathways that were regulated by N-ras in these two immune cell types. Since we were interested primarily in genes that were differentially regulated by N-ras following a low-level TCR stimulus, our microarray data comparison was between data from TCR-stimulated, WT CD4+ T-cells and from TCR-stimulated, N-ras KO CD4+ T-cells. Genes that were differentially regulated in the comparison between stimulated N-ras KO CD4+ T-cells and unstimulated N-ras KO CD4+ T-cells, as well as those genes that were differentially regulated in the comparison between stimulated WT CD4+ T-cells and unstimulated WT CD4+ T-cells were excluded from this analysis. To determine if N-ras and H-ras regulate different sets of genes in thymocytes, a comparison was made between the set of genes that were differentially regulated by N-ras in the [WT] vs. [N-ras KO] comparison and the set of genes that were differentially regulated by H-ras in the [WT] vs. [H-ras KO] comparison.

Standard name | GSE45739_NRAS_KO_VS_WT_ACD3_ACD28_STIM_CD4_TCELL_DN
Systematic name | M9882
Organism | Mus musculus
PMID | 23755101
Authors | Lynch SJ,Zavadil J,Pellicer A
Category | C7
Sub-category |
Brief description | Genes down-regulated in activated CD4 [GeneID=920] T cells: NRAS [GeneID=4893] knockout versus wildtype.
Full description | It has been recently shown that N-ras plays a preferential role in immune cell development and function; specifically: N-ras, but not H-ras or K-ras, could be activated at and signal from the Golgi membrane of immune cells following a low level TCR stimulus. The goal of our studies was to test the hypothesis that N-ras and H-ras played distinct roles in immune cells at the level of the transcriptome. First, we showed via mRNA expression profiling that there were over four hundred genes that were uniquely differentially regulated either by N-ras or H-ras, which provided strong evidence in favor of the hypothesis that N-ras and H-ras have distinct functions in immune cells. We next characterized the genes that were differentially regulated by N-ras in T cells following a low-level TCR stimulus. Of the large pool of candidate genes that were differentially regulated by N-ras downstream of TCR ligation, four genes were verified in qRT-PCR-based validation experiments as being differentially regulated by N-ras (Dntt, Slc9a6, Chst1, and Lars2). Finally, although there was little overlap between individual genes that were regulated by N-ras in unstimulated thymocytes and stimulated CD4+ T-cells, there was a nearly complete correspondence between the signaling pathways that were regulated by N-ras in these two immune cell types. Since we were interested primarily in genes that were differentially regulated by N-ras following a low-level TCR stimulus, our microarray data comparison was between data from TCR-stimulated, WT CD4+ T-cells and from TCR-stimulated, N-ras KO CD4+ T-cells. Genes that were differentially regulated in the comparison between stimulated N-ras KO CD4+ T-cells and unstimulated N-ras KO CD4+ T-cells, as well as those genes that were differentially regulated in the comparison between stimulated WT CD4+ T-cells and unstimulated WT CD4+ T-cells were excluded from this analysis. To determine if N-ras and H-ras regulate different sets of genes in thymocytes, a comparison was made between the set of genes that were differentially regulated by N-ras in the [WT] vs. [N-ras KO] comparison and the set of genes that were differentially regulated by H-ras in the [WT] vs. [H-ras KO] comparison.

Standard name | GSE45739_UNSTIM_VS_ACD3_ACD28_STIM_NRAS_KO_CD4_TCELL_UP
Systematic name | M9883
Organism | Mus musculus
PMID | 23755101
Authors | Lynch SJ,Zavadil J,Pellicer A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells with NRAS [GeneID=4893] knockout: unstimulated versus activated.
Full description | It has been recently shown that N-ras plays a preferential role in immune cell development and function; specifically: N-ras, but not H-ras or K-ras, could be activated at and signal from the Golgi membrane of immune cells following a low level TCR stimulus. The goal of our studies was to test the hypothesis that N-ras and H-ras played distinct roles in immune cells at the level of the transcriptome. First, we showed via mRNA expression profiling that there were over four hundred genes that were uniquely differentially regulated either by N-ras or H-ras, which provided strong evidence in favor of the hypothesis that N-ras and H-ras have distinct functions in immune cells. We next characterized the genes that were differentially regulated by N-ras in T cells following a low-level TCR stimulus. Of the large pool of candidate genes that were differentially regulated by N-ras downstream of TCR ligation, four genes were verified in qRT-PCR-based validation experiments as being differentially regulated by N-ras (Dntt, Slc9a6, Chst1, and Lars2). Finally, although there was little overlap between individual genes that were regulated by N-ras in unstimulated thymocytes and stimulated CD4+ T-cells, there was a nearly complete correspondence between the signaling pathways that were regulated by N-ras in these two immune cell types. Since we were interested primarily in genes that were differentially regulated by N-ras following a low-level TCR stimulus, our microarray data comparison was between data from TCR-stimulated, WT CD4+ T-cells and from TCR-stimulated, N-ras KO CD4+ T-cells. Genes that were differentially regulated in the comparison between stimulated N-ras KO CD4+ T-cells and unstimulated N-ras KO CD4+ T-cells, as well as those genes that were differentially regulated in the comparison between stimulated WT CD4+ T-cells and unstimulated WT CD4+ T-cells were excluded from this analysis. To determine if N-ras and H-ras regulate different sets of genes in thymocytes, a comparison was made between the set of genes that were differentially regulated by N-ras in the [WT] vs. [N-ras KO] comparison and the set of genes that were differentially regulated by H-ras in the [WT] vs. [H-ras KO] comparison.

Standard name | GSE45739_UNSTIM_VS_ACD3_ACD28_STIM_NRAS_KO_CD4_TCELL_DN
Systematic name | M9885
Organism | Mus musculus
PMID | 23755101
Authors | Lynch SJ,Zavadil J,Pellicer A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells with NRAS [GeneID=4893] knockout: unstimulated versus activated.
Full description | It has been recently shown that N-ras plays a preferential role in immune cell development and function; specifically: N-ras, but not H-ras or K-ras, could be activated at and signal from the Golgi membrane of immune cells following a low level TCR stimulus. The goal of our studies was to test the hypothesis that N-ras and H-ras played distinct roles in immune cells at the level of the transcriptome. First, we showed via mRNA expression profiling that there were over four hundred genes that were uniquely differentially regulated either by N-ras or H-ras, which provided strong evidence in favor of the hypothesis that N-ras and H-ras have distinct functions in immune cells. We next characterized the genes that were differentially regulated by N-ras in T cells following a low-level TCR stimulus. Of the large pool of candidate genes that were differentially regulated by N-ras downstream of TCR ligation, four genes were verified in qRT-PCR-based validation experiments as being differentially regulated by N-ras (Dntt, Slc9a6, Chst1, and Lars2). Finally, although there was little overlap between individual genes that were regulated by N-ras in unstimulated thymocytes and stimulated CD4+ T-cells, there was a nearly complete correspondence between the signaling pathways that were regulated by N-ras in these two immune cell types. Since we were interested primarily in genes that were differentially regulated by N-ras following a low-level TCR stimulus, our microarray data comparison was between data from TCR-stimulated, WT CD4+ T-cells and from TCR-stimulated, N-ras KO CD4+ T-cells. Genes that were differentially regulated in the comparison between stimulated N-ras KO CD4+ T-cells and unstimulated N-ras KO CD4+ T-cells, as well as those genes that were differentially regulated in the comparison between stimulated WT CD4+ T-cells and unstimulated WT CD4+ T-cells were excluded from this analysis. To determine if N-ras and H-ras regulate different sets of genes in thymocytes, a comparison was made between the set of genes that were differentially regulated by N-ras in the [WT] vs. [N-ras KO] comparison and the set of genes that were differentially regulated by H-ras in the [WT] vs. [H-ras KO] comparison.

Standard name | GSE45739_UNSTIM_VS_ACD3_ACD28_STIM_WT_CD4_TCELL_UP
Systematic name | M9886
Organism | Mus musculus
PMID | 23755101
Authors | Lynch SJ,Zavadil J,Pellicer A
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD4 [GeneID=920] T cells: unstimulated versus activated.
Full description | It has been recently shown that N-ras plays a preferential role in immune cell development and function; specifically: N-ras, but not H-ras or K-ras, could be activated at and signal from the Golgi membrane of immune cells following a low level TCR stimulus. The goal of our studies was to test the hypothesis that N-ras and H-ras played distinct roles in immune cells at the level of the transcriptome. First, we showed via mRNA expression profiling that there were over four hundred genes that were uniquely differentially regulated either by N-ras or H-ras, which provided strong evidence in favor of the hypothesis that N-ras and H-ras have distinct functions in immune cells. We next characterized the genes that were differentially regulated by N-ras in T cells following a low-level TCR stimulus. Of the large pool of candidate genes that were differentially regulated by N-ras downstream of TCR ligation, four genes were verified in qRT-PCR-based validation experiments as being differentially regulated by N-ras (Dntt, Slc9a6, Chst1, and Lars2). Finally, although there was little overlap between individual genes that were regulated by N-ras in unstimulated thymocytes and stimulated CD4+ T-cells, there was a nearly complete correspondence between the signaling pathways that were regulated by N-ras in these two immune cell types. Since we were interested primarily in genes that were differentially regulated by N-ras following a low-level TCR stimulus, our microarray data comparison was between data from TCR-stimulated, WT CD4+ T-cells and from TCR-stimulated, N-ras KO CD4+ T-cells. Genes that were differentially regulated in the comparison between stimulated N-ras KO CD4+ T-cells and unstimulated N-ras KO CD4+ T-cells, as well as those genes that were differentially regulated in the comparison between stimulated WT CD4+ T-cells and unstimulated WT CD4+ T-cells were excluded from this analysis. To determine if N-ras and H-ras regulate different sets of genes in thymocytes, a comparison was made between the set of genes that were differentially regulated by N-ras in the [WT] vs. [N-ras KO] comparison and the set of genes that were differentially regulated by H-ras in the [WT] vs. [H-ras KO] comparison.

Standard name | GSE45739_UNSTIM_VS_ACD3_ACD28_STIM_WT_CD4_TCELL_DN
Systematic name | M9887
Organism | Mus musculus
PMID | 23755101
Authors | Lynch SJ,Zavadil J,Pellicer A
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD4 [GeneID=920] T cells: unstimulated versus activated.
Full description | It has been recently shown that N-ras plays a preferential role in immune cell development and function; specifically: N-ras, but not H-ras or K-ras, could be activated at and signal from the Golgi membrane of immune cells following a low level TCR stimulus. The goal of our studies was to test the hypothesis that N-ras and H-ras played distinct roles in immune cells at the level of the transcriptome. First, we showed via mRNA expression profiling that there were over four hundred genes that were uniquely differentially regulated either by N-ras or H-ras, which provided strong evidence in favor of the hypothesis that N-ras and H-ras have distinct functions in immune cells. We next characterized the genes that were differentially regulated by N-ras in T cells following a low-level TCR stimulus. Of the large pool of candidate genes that were differentially regulated by N-ras downstream of TCR ligation, four genes were verified in qRT-PCR-based validation experiments as being differentially regulated by N-ras (Dntt, Slc9a6, Chst1, and Lars2). Finally, although there was little overlap between individual genes that were regulated by N-ras in unstimulated thymocytes and stimulated CD4+ T-cells, there was a nearly complete correspondence between the signaling pathways that were regulated by N-ras in these two immune cell types. Since we were interested primarily in genes that were differentially regulated by N-ras following a low-level TCR stimulus, our microarray data comparison was between data from TCR-stimulated, WT CD4+ T-cells and from TCR-stimulated, N-ras KO CD4+ T-cells. Genes that were differentially regulated in the comparison between stimulated N-ras KO CD4+ T-cells and unstimulated N-ras KO CD4+ T-cells, as well as those genes that were differentially regulated in the comparison between stimulated WT CD4+ T-cells and unstimulated WT CD4+ T-cells were excluded from this analysis. To determine if N-ras and H-ras regulate different sets of genes in thymocytes, a comparison was made between the set of genes that were differentially regulated by N-ras in the [WT] vs. [N-ras KO] comparison and the set of genes that were differentially regulated by H-ras in the [WT] vs. [H-ras KO] comparison.

Standard name | GSE45881_CXCR6HI_VS_CXCR1LO_COLONIC_LAMINA_PROPRIA_UP
Systematic name | M9889
Organism | Mus musculus
PMID | 23840334
Authors | Mandai Y,Takahashi D,Hase K,Obata Y,Furusawa Y,Ebisawa M,Nakagawa T,Sato T,Katsuno T,Saito Y,Shimaoka T,Yokosuka O,Yokote K,Ohno H
Category | C7
Sub-category |
Brief description | Genes up-regulated in colonic lamina propria cells sorted by CXCR6 [GeneID=10663]: high versus low.
Full description | To identify the role of chemokine receptor in inflammation of colon, we isolated CD3+CD4+ helper T cells harboring CXCR6 from colonic lamina propria of mice We used microarrays to identify the differentially expressed genes between CXCR6Hi Tcells and CXCR6Lo Tcells

Standard name | GSE45881_CXCR6HI_VS_CXCR1LO_COLONIC_LAMINA_PROPRIA_DN
Systematic name | M9890
Organism | Mus musculus
PMID | 23840334
Authors | Mandai Y,Takahashi D,Hase K,Obata Y,Furusawa Y,Ebisawa M,Nakagawa T,Sato T,Katsuno T,Saito Y,Shimaoka T,Yokosuka O,Yokote K,Ohno H
Category | C7
Sub-category |
Brief description | Genes down-regulated in colonic lamina propria cells sorted by CXCR6 [GeneID=10663]: high versus low.
Full description | To identify the role of chemokine receptor in inflammation of colon, we isolated CD3+CD4+ helper T cells harboring CXCR6 from colonic lamina propria of mice We used microarrays to identify the differentially expressed genes between CXCR6Hi Tcells and CXCR6Lo Tcells

Standard name | GSE45837_WT_VS_GFI1_KO_PDC_UP
Systematic name | M9892
Organism | Mus musculus
PMID | 24086657
Authors | Chow KT,Schulz D,McWhirter SM,Schlissel MS
Category | C7
Sub-category |
Brief description | Genes up-regulated in plasmacytoid dendritic cells: wildtype versus GFI1 [GeneID=2672] knockout.
Full description | Growth factor independence genes (Gfi1 and Gfi1b) repress recombination activating genes (Rag) transcription in developing B lymphocytes. Because all blood lineages originate from hematopoietic stem cells (HSCs) and different lineage progenitors have been shown to share transcription factor networks prior to cell fate commitment, we hypothesized that GFI family proteins may also play a role in repressing Rag transcription or a global lymphoid transcriptional program in other blood lineages. We tested the level of Rag transcription in various blood cells when Gfi1 and Gfi1b were deleted, and observed an upregulation of Rag expression in plasmacytoid dendritic cells (pDCs). Using microarray analysis, we observed that Gfi1 and Gfi1b regulate a broad spectrum of cellular processes in pDCs, but not a lymphoid specific transcriptional program. This study establishes a role for Gfi1 and Gfi1b in Rag regulation in a non-B lineage cell type

Standard name | GSE45837_WT_VS_GFI1_KO_PDC_DN
Systematic name | M9894
Organism | Mus musculus
PMID | 24086657
Authors | Chow KT,Schulz D,McWhirter SM,Schlissel MS
Category | C7
Sub-category |
Brief description | Genes down-regulated in plasmacytoid dendritic cells: wildtype versus GFI1 [GeneID=2672] knockout.
Full description | Growth factor independence genes (Gfi1 and Gfi1b) repress recombination activating genes (Rag) transcription in developing B lymphocytes. Because all blood lineages originate from hematopoietic stem cells (HSCs) and different lineage progenitors have been shown to share transcription factor networks prior to cell fate commitment, we hypothesized that GFI family proteins may also play a role in repressing Rag transcription or a global lymphoid transcriptional program in other blood lineages. We tested the level of Rag transcription in various blood cells when Gfi1 and Gfi1b were deleted, and observed an upregulation of Rag expression in plasmacytoid dendritic cells (pDCs). Using microarray analysis, we observed that Gfi1 and Gfi1b regulate a broad spectrum of cellular processes in pDCs, but not a lymphoid specific transcriptional program. This study establishes a role for Gfi1 and Gfi1b in Rag regulation in a non-B lineage cell type

Standard name | GSE42088_UNINF_VS_LEISHMANIA_INF_DC_24H_UP
Systematic name | M9895
Organism | Homo sapiens
PMID | 24808365
Authors | Favila MA,Geraci NS,Zeng E,Harker B,Condon D,Cotton RN,Jayakumar A,Tripathi V,McDowell MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: untreated versus 24h after infection of Leishmania major.
Full description | Leishmania major infected human dendritic cells (DCs) exhibit a marked induction of IL-12 ultimately promoting a robust Th1-mediated response associated with parasite killing and protective immunity. In this study, we utilized Affymetrix Genechips to globally assess the host cell genes and pathways associated with L. major infection during early infection (2, 4, 8, and 24 hrs) in human myeloid-derived DCs. Bioinformatic analyses of the hybridized microarray chips identified 728 genes, represented by 848 unique probe sets, which, when compared to uninfected samples were observed to be significantly differentially expressed by one-way ANOVA. Altogether, the data provide a genome-wide perspective on the transcriptional influences Leishmania species exert within human DCs during early infection, and provides a platform for further investigations toward functionally characterizing candidate genes of importance to the IL-12 based immune response to infections. In the current study, we further investigate the L. major infected DC transcriptional during early time points after infection via microarray analysis.

Standard name | GSE42088_UNINF_VS_LEISHMANIA_INF_DC_24H_DN
Systematic name | M9897
Organism | Homo sapiens
PMID | 24808365
Authors | Favila MA,Geraci NS,Zeng E,Harker B,Condon D,Cotton RN,Jayakumar A,Tripathi V,McDowell MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: untreated versus 24h after infection of Leishmania major.
Full description | Leishmania major infected human dendritic cells (DCs) exhibit a marked induction of IL-12 ultimately promoting a robust Th1-mediated response associated with parasite killing and protective immunity. In this study, we utilized Affymetrix Genechips to globally assess the host cell genes and pathways associated with L. major infection during early infection (2, 4, 8, and 24 hrs) in human myeloid-derived DCs. Bioinformatic analyses of the hybridized microarray chips identified 728 genes, represented by 848 unique probe sets, which, when compared to uninfected samples were observed to be significantly differentially expressed by one-way ANOVA. Altogether, the data provide a genome-wide perspective on the transcriptional influences Leishmania species exert within human DCs during early infection, and provides a platform for further investigations toward functionally characterizing candidate genes of importance to the IL-12 based immune response to infections. In the current study, we further investigate the L. major infected DC transcriptional during early time points after infection via microarray analysis.

Standard name | GSE42088_2H_VS_24H_LEISHMANIA_INF_DC_UP
Systematic name | M9899
Organism | Homo sapiens
PMID | 24808365
Authors | Favila MA,Geraci NS,Zeng E,Harker B,Condon D,Cotton RN,Jayakumar A,Tripathi V,McDowell MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells infected by Leishmania major: 2h versus 24h.
Full description | Leishmania major infected human dendritic cells (DCs) exhibit a marked induction of IL-12 ultimately promoting a robust Th1-mediated response associated with parasite killing and protective immunity. In this study, we utilized Affymetrix Genechips to globally assess the host cell genes and pathways associated with L. major infection during early infection (2, 4, 8, and 24 hrs) in human myeloid-derived DCs. Bioinformatic analyses of the hybridized microarray chips identified 728 genes, represented by 848 unique probe sets, which, when compared to uninfected samples were observed to be significantly differentially expressed by one-way ANOVA. Altogether, the data provide a genome-wide perspective on the transcriptional influences Leishmania species exert within human DCs during early infection, and provides a platform for further investigations toward functionally characterizing candidate genes of importance to the IL-12 based immune response to infections. In the current study, we further investigate the L. major infected DC transcriptional during early time points after infection via microarray analysis.

Standard name | GSE42088_UNINF_VS_LEISHMANIA_INF_DC_2H_UP
Systematic name | M9900
Organism | Homo sapiens
PMID | 24808365
Authors | Favila MA,Geraci NS,Zeng E,Harker B,Condon D,Cotton RN,Jayakumar A,Tripathi V,McDowell MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: untreated versus 2h after infection of Leishmania major.
Full description | Leishmania major infected human dendritic cells (DCs) exhibit a marked induction of IL-12 ultimately promoting a robust Th1-mediated response associated with parasite killing and protective immunity. In this study, we utilized Affymetrix Genechips to globally assess the host cell genes and pathways associated with L. major infection during early infection (2, 4, 8, and 24 hrs) in human myeloid-derived DCs. Bioinformatic analyses of the hybridized microarray chips identified 728 genes, represented by 848 unique probe sets, which, when compared to uninfected samples were observed to be significantly differentially expressed by one-way ANOVA. Altogether, the data provide a genome-wide perspective on the transcriptional influences Leishmania species exert within human DCs during early infection, and provides a platform for further investigations toward functionally characterizing candidate genes of importance to the IL-12 based immune response to infections. In the current study, we further investigate the L. major infected DC transcriptional during early time points after infection via microarray analysis.

Standard name | GSE42088_UNINF_VS_LEISHMANIA_INF_DC_2H_DN
Systematic name | M9901
Organism | Homo sapiens
PMID | 24808365
Authors | Favila MA,Geraci NS,Zeng E,Harker B,Condon D,Cotton RN,Jayakumar A,Tripathi V,McDowell MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: untreated versus 2h after infection of Leishmania major.
Full description | Leishmania major infected human dendritic cells (DCs) exhibit a marked induction of IL-12 ultimately promoting a robust Th1-mediated response associated with parasite killing and protective immunity. In this study, we utilized Affymetrix Genechips to globally assess the host cell genes and pathways associated with L. major infection during early infection (2, 4, 8, and 24 hrs) in human myeloid-derived DCs. Bioinformatic analyses of the hybridized microarray chips identified 728 genes, represented by 848 unique probe sets, which, when compared to uninfected samples were observed to be significantly differentially expressed by one-way ANOVA. Altogether, the data provide a genome-wide perspective on the transcriptional influences Leishmania species exert within human DCs during early infection, and provides a platform for further investigations toward functionally characterizing candidate genes of importance to the IL-12 based immune response to infections. In the current study, we further investigate the L. major infected DC transcriptional during early time points after infection via microarray analysis.

Standard name | GSE42088_UNINF_VS_LEISHMANIA_INF_DC_4H_UP
Systematic name | M9903
Organism | Homo sapiens
PMID | 24808365
Authors | Favila MA,Geraci NS,Zeng E,Harker B,Condon D,Cotton RN,Jayakumar A,Tripathi V,McDowell MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: untreated versus 4h after infection of Leishmania major.
Full description | Leishmania major infected human dendritic cells (DCs) exhibit a marked induction of IL-12 ultimately promoting a robust Th1-mediated response associated with parasite killing and protective immunity. In this study, we utilized Affymetrix Genechips to globally assess the host cell genes and pathways associated with L. major infection during early infection (2, 4, 8, and 24 hrs) in human myeloid-derived DCs. Bioinformatic analyses of the hybridized microarray chips identified 728 genes, represented by 848 unique probe sets, which, when compared to uninfected samples were observed to be significantly differentially expressed by one-way ANOVA. Altogether, the data provide a genome-wide perspective on the transcriptional influences Leishmania species exert within human DCs during early infection, and provides a platform for further investigations toward functionally characterizing candidate genes of importance to the IL-12 based immune response to infections. In the current study, we further investigate the L. major infected DC transcriptional during early time points after infection via microarray analysis.

Standard name | GSE42088_UNINF_VS_LEISHMANIA_INF_DC_4H_DN
Systematic name | M9907
Organism | Homo sapiens
PMID | 24808365
Authors | Favila MA,Geraci NS,Zeng E,Harker B,Condon D,Cotton RN,Jayakumar A,Tripathi V,McDowell MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: untreated versus 4h after infection of Leishmania major.
Full description | Leishmania major infected human dendritic cells (DCs) exhibit a marked induction of IL-12 ultimately promoting a robust Th1-mediated response associated with parasite killing and protective immunity. In this study, we utilized Affymetrix Genechips to globally assess the host cell genes and pathways associated with L. major infection during early infection (2, 4, 8, and 24 hrs) in human myeloid-derived DCs. Bioinformatic analyses of the hybridized microarray chips identified 728 genes, represented by 848 unique probe sets, which, when compared to uninfected samples were observed to be significantly differentially expressed by one-way ANOVA. Altogether, the data provide a genome-wide perspective on the transcriptional influences Leishmania species exert within human DCs during early infection, and provides a platform for further investigations toward functionally characterizing candidate genes of importance to the IL-12 based immune response to infections. In the current study, we further investigate the L. major infected DC transcriptional during early time points after infection via microarray analysis.

Standard name | GSE42088_UNINF_VS_LEISHMANIA_INF_DC_8H_UP
Systematic name | M9909
Organism | Homo sapiens
PMID | 24808365
Authors | Favila MA,Geraci NS,Zeng E,Harker B,Condon D,Cotton RN,Jayakumar A,Tripathi V,McDowell MA
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: untreated versus 8h after infection of Leishmania major.
Full description | Leishmania major infected human dendritic cells (DCs) exhibit a marked induction of IL-12 ultimately promoting a robust Th1-mediated response associated with parasite killing and protective immunity. In this study, we utilized Affymetrix Genechips to globally assess the host cell genes and pathways associated with L. major infection during early infection (2, 4, 8, and 24 hrs) in human myeloid-derived DCs. Bioinformatic analyses of the hybridized microarray chips identified 728 genes, represented by 848 unique probe sets, which, when compared to uninfected samples were observed to be significantly differentially expressed by one-way ANOVA. Altogether, the data provide a genome-wide perspective on the transcriptional influences Leishmania species exert within human DCs during early infection, and provides a platform for further investigations toward functionally characterizing candidate genes of importance to the IL-12 based immune response to infections. In the current study, we further investigate the L. major infected DC transcriptional during early time points after infection via microarray analysis.

Standard name | GSE42088_UNINF_VS_LEISHMANIA_INF_DC_8H_DN
Systematic name | M9910
Organism | Homo sapiens
PMID | 24808365
Authors | Favila MA,Geraci NS,Zeng E,Harker B,Condon D,Cotton RN,Jayakumar A,Tripathi V,McDowell MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: untreated versus 8h after infection of Leishmania major.
Full description | Leishmania major infected human dendritic cells (DCs) exhibit a marked induction of IL-12 ultimately promoting a robust Th1-mediated response associated with parasite killing and protective immunity. In this study, we utilized Affymetrix Genechips to globally assess the host cell genes and pathways associated with L. major infection during early infection (2, 4, 8, and 24 hrs) in human myeloid-derived DCs. Bioinformatic analyses of the hybridized microarray chips identified 728 genes, represented by 848 unique probe sets, which, when compared to uninfected samples were observed to be significantly differentially expressed by one-way ANOVA. Altogether, the data provide a genome-wide perspective on the transcriptional influences Leishmania species exert within human DCs during early infection, and provides a platform for further investigations toward functionally characterizing candidate genes of importance to the IL-12 based immune response to infections. In the current study, we further investigate the L. major infected DC transcriptional during early time points after infection via microarray analysis.

Standard name | GSE42088_2H_VS_24H_LEISHMANIA_INF_DC_DN
Systematic name | M9912
Organism | Homo sapiens
PMID | 24808365
Authors | Favila MA,Geraci NS,Zeng E,Harker B,Condon D,Cotton RN,Jayakumar A,Tripathi V,McDowell MA
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells infected by Leishmania major: 2h versus 24h.
Full description | Leishmania major infected human dendritic cells (DCs) exhibit a marked induction of IL-12 ultimately promoting a robust Th1-mediated response associated with parasite killing and protective immunity. In this study, we utilized Affymetrix Genechips to globally assess the host cell genes and pathways associated with L. major infection during early infection (2, 4, 8, and 24 hrs) in human myeloid-derived DCs. Bioinformatic analyses of the hybridized microarray chips identified 728 genes, represented by 848 unique probe sets, which, when compared to uninfected samples were observed to be significantly differentially expressed by one-way ANOVA. Altogether, the data provide a genome-wide perspective on the transcriptional influences Leishmania species exert within human DCs during early infection, and provides a platform for further investigations toward functionally characterizing candidate genes of importance to the IL-12 based immune response to infections. In the current study, we further investigate the L. major infected DC transcriptional during early time points after infection via microarray analysis.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_BCELL_1H_DN
Systematic name | M9913
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: untreated versus anti-IgM for 1h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_BCELL_3H_UP
Systematic name | M9915
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: untreated versus anti-IgM for 3h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_BCELL_3H_DN
Systematic name | M9916
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: untreated versus anti-IgM for 3h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_BCELL_1H_UP
Systematic name | M9917
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: untreated versus anti-IgM for 1h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_TAK1_KO_BCELL_24H_UP
Systematic name | M9918
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes with MAP3K7 [GeneID=6885] knockout: untreated versus anti IgM for 24h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_TAK1_KO_BCELL_24H_DN
Systematic name | M9920
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes with MAP3K7 [GeneID=6885] knockout: untreated versus anti IgM for 24h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_WT_VS_TAK1_KO_UNSTIM_BCELL_UP
Systematic name | M9921
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: wildtype versus MAP3K7 [GeneID=6885].
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_BCELL_6H_UP
Systematic name | M9922
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: untreated versus anti-IgM for 6h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_BCELL_6H_DN
Systematic name | M9923
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: untreated versus anti-IgM for 6h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_BCELL_24H_UP
Systematic name | M9924
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: untreated versus anti-IgM for 24h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_BCELL_24H_DN
Systematic name | M9925
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: untreated versus anti-IgM for 24h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_TAK1_KO_BCELL_1H_UP
Systematic name | M9926
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes with MAP3K7 [GeneID=6885] knockout: untreated versus anti IgM for 1h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_TAK1_KO_BCELL_1H_DN
Systematic name | M9928
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes with MAP3K7 [GeneID=6885] knockout: untreated versus anti IgM for 1h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_TAK1_KO_BCELL_3H_UP
Systematic name | M9929
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes with MAP3K7 [GeneID=6885] knockout: untreated versus anti IgM for 3h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_TAK1_KO_BCELL_3H_DN
Systematic name | M9930
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes with MAP3K7 [GeneID=6885] knockout: untreated versus anti IgM for 3h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_TAK1_KO_BCELL_6H_UP
Systematic name | M9931
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes with MAP3K7 [GeneID=6885] knockout: untreated versus anti IgM for 6h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_UNSTIM_VS_ANTI_IGM_STIM_TAK1_KO_BCELL_6H_DN
Systematic name | M9933
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes with MAP3K7 [GeneID=6885] knockout: untreated versus anti IgM for 6h.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_WT_VS_TAK1_KO_ANTI_IGM_STIM_BCELL_1H_UP
Systematic name | M9934
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes treated by anti IgM for 1h: wildtype versus MAP3K7 [GeneID=6885] knockout.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_WT_VS_TAK1_KO_ANTI_IGM_STIM_BCELL_1H_DN
Systematic name | M9935
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes treated by anti IgM for 1h: wildtype versus MAP3K7 [GeneID=6885] knockout.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_WT_VS_TAK1_KO_ANTI_IGM_STIM_BCELL_3H_UP
Systematic name | M9938
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes treated by anti IgM for 3h: wildtype versus MAP3K7 [GeneID=6885] knockout.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_WT_VS_TAK1_KO_UNSTIM_BCELL_DN
Systematic name | M9941
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: wildtype versus MAP3K7 [GeneID=6885].
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_WT_VS_TAK1_KO_ANTI_IGM_STIM_BCELL_6H_UP
Systematic name | M9942
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes treated by anti IgM for 6h: wildtype versus MAP3K7 [GeneID=6885] knockout.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_WT_VS_TAK1_KO_ANTI_IGM_STIM_BCELL_6H_DN
Systematic name | M9943
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes treated by anti IgM for 6h: wildtype versus MAP3K7 [GeneID=6885] knockout.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_WT_VS_TAK1_KO_ANTI_IGM_STIM_BCELL_24H_UP
Systematic name | M9944
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes treated by anti IgM for 24h: wildtype versus MAP3K7 [GeneID=6885] knockout.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_WT_VS_TAK1_KO_ANTI_IGM_STIM_BCELL_3H_DN
Systematic name | M9950
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes treated by anti IgM for 3h: wildtype versus MAP3K7 [GeneID=6885] knockout.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE41176_WT_VS_TAK1_KO_ANTI_IGM_STIM_BCELL_24H_DN
Systematic name | M9952
Organism | Mus musculus
PMID | 24833394
Authors | Shinohara H,Behar M,Inoue K,Hiroshima M,Yasuda T,Nagashima T,Kimura S,Sanjo H,Maeda S,Yumoto N,Ki S,Akira S,Sako Y,Hoffmann A,Kurosaki T,Okada-Hatakeyama M
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes treated by anti IgM for 24h: wildtype versus MAP3K7 [GeneID=6885] knockout.
Full description | The activation signaling of transcription factor nuclear factor-kB (NF-kB) plays central role for immune system. One of key kinase mediating this pathway is TAK1 in adaptive and innate immunity. However, role of TAK1 in B cell receptor signaling is still unclear. To know effects of TAK1-deletion on the gene expression induced by anti-IgM, we performed the time course analysis in comparison of wild type with TAK1-deleted splenic B cells.

Standard name | GSE43260_BTLA_POS_VS_NEG_INTRATUMORAL_CD8_TCELL_UP
Systematic name | M9953
Organism | Homo sapiens
PMID | 26405566
Authors | Haymaker CL,Wu RC,Ritthipichai K,Bernatchez C,Forget MA,Chen JQ,Liu H,Wang E,Marincola F,Hwu P,Radvanyi LG
Category | C7
Sub-category |
Brief description | Genes up-regulated in tumor-infiltrating CD8 T cells: BTLA+ [GeneID=151888] versus BTLA- [GeneID=151888].
Full description | Adoptive T-cell Therapy (ACT) involves using tumor-infiltrating lymphocytes (TIL) isolated from metastatic melanoma and expanding them ex vivo prior to infusion into lympho-depleted patients. This is one of the most promising approaches to treat metastatic melanoma, with the rates of clinical response between 48-50% based on studies done at NCI, M.D. Anderson Cancer Center (Houston, TX), and Sheba Medical Center (Tel Aviv, Israel). In the Phase II ACT Trial at M.D. Anderson Cancer Center , our group has uncovered an association between positive clinical response and the amount of CD8+ tumor-infiltrating lymphocytes expressing B and T Lymphocyte Attenuator (BTLA), a reported inhibitory receptor on T-cells. We used microarrays to detail the differences in the global programme of gene expression between CD8+BTLA+ vs CD8+BTLA- TILs in order to understand the molecular basis of the clinical association.

Standard name | GSE43260_BTLA_POS_VS_NEG_INTRATUMORAL_CD8_TCELL_DN
Systematic name | M9954
Organism | Homo sapiens
PMID | 26405566
Authors | Haymaker CL,Wu RC,Ritthipichai K,Bernatchez C,Forget MA,Chen JQ,Liu H,Wang E,Marincola F,Hwu P,Radvanyi LG
Category | C7
Sub-category |
Brief description | Genes down-regulated in tumor-infiltrating CD8 T cells: BTLA+ [GeneID=151888] versus BTLA- [GeneID=151888].
Full description | Adoptive T-cell Therapy (ACT) involves using tumor-infiltrating lymphocytes (TIL) isolated from metastatic melanoma and expanding them ex vivo prior to infusion into lympho-depleted patients. This is one of the most promising approaches to treat metastatic melanoma, with the rates of clinical response between 48-50% based on studies done at NCI, M.D. Anderson Cancer Center (Houston, TX), and Sheba Medical Center (Tel Aviv, Israel). In the Phase II ACT Trial at M.D. Anderson Cancer Center , our group has uncovered an association between positive clinical response and the amount of CD8+ tumor-infiltrating lymphocytes expressing B and T Lymphocyte Attenuator (BTLA), a reported inhibitory receptor on T-cells. We used microarrays to detail the differences in the global programme of gene expression between CD8+BTLA+ vs CD8+BTLA- TILs in order to understand the molecular basis of the clinical association.

Standard name | GSE45365_NK_CELL_VS_CD11B_DC_MCMV_INFECTION_UP
Systematic name | M9956
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated during primary acute viral infection: NK cells versus ITGAM+ [GeneID=3684] dendritic cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD11B_DC_MCMV_INFECTION_DN
Systematic name | M9957
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated during primary acute viral infection: NK cells versus ITGAM+ [GeneID=3684] dendritic cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_BCELL_MCMV_INFECTION_UP
Systematic name | M9958
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated during primary acute viral infection: NK cells versus B lymphocytes.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_BCELL_MCMV_INFECTION_DN
Systematic name | M9959
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated during primary acute viral infection: NK cells versus B lymphocytes.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD8_TCELL_MCMV_INFECTION_UP
Systematic name | M9960
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated during primary acute viral infection: NK vells versus CD8 T cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD8_TCELL_MCMV_INFECTION_DN
Systematic name | M9961
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated during primary acute viral infection: NK vells versus CD8 T cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_CD8A_DC_UP
Systematic name | M9962
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A [GeneID=925] dendritic cells: wildtype versus IFNAR1 [GeneID=3454] knockout.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_CD8A_DC_DN
Systematic name | M9963
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A [GeneID=925] dendritic cells: wildtype versus IFNAR1 [GeneID=3454] knockout.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_CD8A_DC_MCMV_INFECTION_UP
Systematic name | M9964
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated during primary acute viral infection in CD8A [GeneID=925] dendritic cells: wildtype versus IFNAR1 [GeneID=3454] knockout.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_CD8A_DC_MCMV_INFECTION_DN
Systematic name | M9966
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated during primary acute viral infection in CD8A [GeneID=925] dendritic cells: wildtype versus IFNAR1 [GeneID=3454] knockout.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_CD8A_DC_UP
Systematic name | M9967
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A [GeneID=925] dendritic cells: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_CD8A_DC_DN
Systematic name | M9968
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A [GeneID=925] dendritic cells: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_CD8A_DC_IFNAR_KO_UP
Systematic name | M9969
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8A [GeneID=925] dendritic cells with IFNAR1 [GeneID=3454] knockout: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_CD8A_DC_IFNAR_KO_DN
Systematic name | M9970
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8A [GeneID=925] dendritic cells with IFNAR1 [GeneID=3454] knockout: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_CD11B_DC_UP
Systematic name | M9971
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in ITGAM+ [GeneID=3684] dendritic cells: wildtype versus IFNAR1 [GeneID=3454].
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_CD11B_DC_DN
Systematic name | M9973
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in ITGAM+ [GeneID=3684] dendritic cells: wildtype versus IFNAR1 [GeneID=3454].
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_CD11B_DC_MCMV_INFECTION_UP
Systematic name | M9975
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated during primary acute viral infection in ITGAM+ [GeneID=3684] dendritic cells: wildtype versus IFNAR1 [GeneID=3454] knockout.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_CD11B_DC_MCMV_INFECTION_DN
Systematic name | M9977
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated during primary acute viral infection in ITGAM+ [GeneID=3684] dendritic cells: wildtype versus IFNAR1 [GeneID=3454] knockout.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_CD11B_DC_UP
Systematic name | M9978
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in ITGAM+ [GeneID=3684] dendritic cells: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_CD11B_DC_DN
Systematic name | M9979
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in ITGAM+ [GeneID=3684] dendritic cells: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_CD11B_DC_IFNAR_KO_UP
Systematic name | M9980
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in ITGAM+ [GeneID=3684] dendritic cells with IFNAR1 [GeneID=3454] knockout: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_CD11B_DC_IFNAR_KO_DN
Systematic name | M9983
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in ITGAM+ [GeneID=3684] dendritic cells with IFNAR1 [GeneID=3454] knockout: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_BCELL_UP
Systematic name | M9984
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_BCELL_DN
Systematic name | M9987
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_BCELL_MCMV_INFECTION_UP
Systematic name | M9988
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in CD8 T cells: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_WT_VS_IFNAR_KO_BCELL_MCMV_INFECTION_DN
Systematic name | M9989
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in CD8 T cells: control versus primary acute viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_BCELL_VS_CD8_TCELL_UP
Systematic name | M9991
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in B lymphocytes versus CD8 T cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_BCELL_VS_CD8_TCELL_DN
Systematic name | M9992
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in B lymphocytes versus CD8 T cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_BCELL_IFNAR_KO_UP
Systematic name | M9994
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated during primary acute viral infection: B lymphocytes versus CD8 T cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_BCELL_IFNAR_KO_DN
Systematic name | M9996
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated during primary acute viral infection: B lymphocytes versus CD8 T cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_CD8A_DC_VS_CD11B_DC_UP
Systematic name | M9997
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells: CD8A [GeneID=925] versus ITGAM+ [GeneID=3684].
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_CD8A_DC_VS_CD11B_DC_DN
Systematic name | M9998
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells: CD8A [GeneID=925] versus ITGAM+ [GeneID=3684].
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_CD8A_DC_VS_CD11B_DC_IFNAR_KO_UP
Systematic name | M10001
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in dendritic cells with IFNAR1 [GeneID=3454] knockout: CD8A [GeneID=925] versus ITGAM+ [GeneID=3684].
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_CD8A_DC_VS_CD11B_DC_IFNAR_KO_DN
Systematic name | M10002
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in dendritic cells with IFNAR1 [GeneID=3454] knockout: CD8A [GeneID=925] versus ITGAM+ [GeneID=3684].
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_CD8A_DC_VS_CD11B_DC_IFNAR_KO_MCMV_INFECTION_UP
Systematic name | M10003
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated during primary acute viral infection in dendritic cells: CD8A [GeneID=925] versus ITGAM+ [GeneID=3684].
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_CD8A_DC_VS_CD11B_DC_IFNAR_KO_MCMV_INFECTION_DN
Systematic name | M10004
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated during primary acute viral infection in dendritic cells: CD8A [GeneID=925] versus ITGAM+ [GeneID=3684].
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_CD8_TCELL_IFNAR_KO_UP
Systematic name | M10006
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated during primary acute viral infection in dendritic cells with IFNAR1 [GeneID=3454] knockout: CD8A [GeneID=925] versus ITGAM+ [GeneID=3684].
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_HEALTHY_VS_MCMV_INFECTION_CD8_TCELL_IFNAR_KO_DN
Systematic name | M10007
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated during primary acute viral infection in dendritic cells with IFNAR1 [GeneID=3454] knockout: CD8A [GeneID=925] versus ITGAM+ [GeneID=3684].
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD8_TCELL_DN
Systematic name | M10008
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells versus CD8 T cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD8A_DC_MCMV_INFECTION_UP
Systematic name | M10011
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated during primary acute viral infection: NK cells versus CD8A [GeneID=625] dendritic cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD8A_DC_MCMV_INFECTION_DN
Systematic name | M10012
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated during primary acute viral infection: NK cells versus CD8A [GeneID=625] dendritic cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE37336_LY6C_POS_VS_NEG_NAIVE_CD4_TCELL_DN
Systematic name | M10013
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated naïve CD4 [GeneID=920] T cells: Ly6c+ versus Ly6c-.
Full description | The naive CD4 T cell compartment is heterogeneous. Ly-6C- and Ly-6C+ Naive CD4 T cells were compare by microarrays.

Standard name | GSE18804_SPLEEN_MACROPHAGE_VS_BRAIN_TUMORAL_MACROPHAGE_UP
Systematic name | M10014
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: control versus glioblastoma conditioned.
Full description | Active immunotherapy is a promising strategy for anti-angiogenic cancer therapy. Recently, we have reported that a vaccine using human umbilical vein endothelial cells (HUVECs) induced specific anti-endothelial immune responses in the most of immunized patients, and resulted in tumor regression in some patients with recurrent malignant brain tumors, whereas not in colorectal cancer patients. In this study, we hypothesized that non-hypoxic perivascular tumor associated macrophages (TAMs) in colorectal cancer, but not in glioblastoma, might negatively alter the therapeutic efficacy of anti-angiogenic active immunotherapy. To test this hypothesis, we examined global gene expression profiles of non-hypoxic macrophages stimulated in vitro by soluble factors released from tumor cells of human glioblastoma U-87MG (‘brain TAMs’) or colorectal adenocarcinoma HT-29 (‘colon TAMs’).

Standard name | GSE18804_SPLEEN_MACROPHAGE_VS_BRAIN_TUMORAL_MACROPHAGE_DN
Systematic name | M10015
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: control versus glioblastoma conditioned.
Full description | Active immunotherapy is a promising strategy for anti-angiogenic cancer therapy. Recently, we have reported that a vaccine using human umbilical vein endothelial cells (HUVECs) induced specific anti-endothelial immune responses in the most of immunized patients, and resulted in tumor regression in some patients with recurrent malignant brain tumors, whereas not in colorectal cancer patients. In this study, we hypothesized that non-hypoxic perivascular tumor associated macrophages (TAMs) in colorectal cancer, but not in glioblastoma, might negatively alter the therapeutic efficacy of anti-angiogenic active immunotherapy. To test this hypothesis, we examined global gene expression profiles of non-hypoxic macrophages stimulated in vitro by soluble factors released from tumor cells of human glioblastoma U-87MG (‘brain TAMs’) or colorectal adenocarcinoma HT-29 (‘colon TAMs’).

Standard name | GSE37336_LY6C_POS_VS_NEG_NAIVE_CD4_TCELL_UP
Systematic name | M10016
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated naïve CD4 [GeneID=920] T cells: Ly6c+ versus Ly6c-.
Full description | The naive CD4 T cell compartment is heterogeneous. Ly-6C- and Ly-6C+ Naive CD4 T cells were compare by microarrays.

Standard name | GSE18804_BRAIN_VS_COLON_TUMORAL_MACROPHAGE_DN
Systematic name | M10017
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in tumor associated macrophages conditioned by: glioblastoma versus colorectal adenocarcinoma.
Full description | Active immunotherapy is a promising strategy for anti-angiogenic cancer therapy. Recently, we have reported that a vaccine using human umbilical vein endothelial cells (HUVECs) induced specific anti-endothelial immune responses in the most of immunized patients, and resulted in tumor regression in some patients with recurrent malignant brain tumors, whereas not in colorectal cancer patients. In this study, we hypothesized that non-hypoxic perivascular tumor associated macrophages (TAMs) in colorectal cancer, but not in glioblastoma, might negatively alter the therapeutic efficacy of anti-angiogenic active immunotherapy. To test this hypothesis, we examined global gene expression profiles of non-hypoxic macrophages stimulated in vitro by soluble factors released from tumor cells of human glioblastoma U-87MG (‘brain TAMs’) or colorectal adenocarcinoma HT-29 (‘colon TAMs’).

Standard name | GSE18804_SPLEEN_MACROPHAGE_VS_TUMORAL_MACROPHAGE_UP
Systematic name | M10018
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: control versus tumor associated.
Full description | Active immunotherapy is a promising strategy for anti-angiogenic cancer therapy. Recently, we have reported that a vaccine using human umbilical vein endothelial cells (HUVECs) induced specific anti-endothelial immune responses in the most of immunized patients, and resulted in tumor regression in some patients with recurrent malignant brain tumors, whereas not in colorectal cancer patients. In this study, we hypothesized that non-hypoxic perivascular tumor associated macrophages (TAMs) in colorectal cancer, but not in glioblastoma, might negatively alter the therapeutic efficacy of anti-angiogenic active immunotherapy. To test this hypothesis, we examined global gene expression profiles of non-hypoxic macrophages stimulated in vitro by soluble factors released from tumor cells of human glioblastoma U-87MG (‘brain TAMs’) or colorectal adenocarcinoma HT-29 (‘colon TAMs’).

Standard name | GSE18804_SPLEEN_MACROPHAGE_VS_TUMORAL_MACROPHAGE_DN
Systematic name | M10020
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: control versus tumor associated.
Full description | Active immunotherapy is a promising strategy for anti-angiogenic cancer therapy. Recently, we have reported that a vaccine using human umbilical vein endothelial cells (HUVECs) induced specific anti-endothelial immune responses in the most of immunized patients, and resulted in tumor regression in some patients with recurrent malignant brain tumors, whereas not in colorectal cancer patients. In this study, we hypothesized that non-hypoxic perivascular tumor associated macrophages (TAMs) in colorectal cancer, but not in glioblastoma, might negatively alter the therapeutic efficacy of anti-angiogenic active immunotherapy. To test this hypothesis, we examined global gene expression profiles of non-hypoxic macrophages stimulated in vitro by soluble factors released from tumor cells of human glioblastoma U-87MG (‘brain TAMs’) or colorectal adenocarcinoma HT-29 (‘colon TAMs’).

Standard name | GSE18804_BRAIN_VS_COLON_TUMORAL_MACROPHAGE_UP
Systematic name | M10021
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in tumor associated macrophages conditioned by: glioblastoma versus colorectal adenocarcinoma.
Full description | Active immunotherapy is a promising strategy for anti-angiogenic cancer therapy. Recently, we have reported that a vaccine using human umbilical vein endothelial cells (HUVECs) induced specific anti-endothelial immune responses in the most of immunized patients, and resulted in tumor regression in some patients with recurrent malignant brain tumors, whereas not in colorectal cancer patients. In this study, we hypothesized that non-hypoxic perivascular tumor associated macrophages (TAMs) in colorectal cancer, but not in glioblastoma, might negatively alter the therapeutic efficacy of anti-angiogenic active immunotherapy. To test this hypothesis, we examined global gene expression profiles of non-hypoxic macrophages stimulated in vitro by soluble factors released from tumor cells of human glioblastoma U-87MG (‘brain TAMs’) or colorectal adenocarcinoma HT-29 (‘colon TAMs’).

Standard name | GSE45365_CTRL_VS_MCMV_INFECTION_NK_CELL_DN
Systematic name | M10022
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells: control versus acute primary viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_BCELL_DN
Systematic name | M10023
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells versus B lymphocytes.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD8_TCELL_UP
Systematic name | M10025
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells versus CD8 T cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_CTRL_VS_MCMV_INFECTION_NK_CELL_UP
Systematic name | M10026
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells: control versus acute primary viral infection.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD11B_DC_DN
Systematic name | M10027
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells versus ITGAM+ [GeneID=3684] dendritic cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD8A_DC_UP
Systematic name | M10028
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells versus CD8A [GeneID=925] T cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD8A_DC_DN
Systematic name | M10029
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in NK cells versus CD8A [GeneID=925] T cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_CD11B_DC_UP
Systematic name | M10030
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells versus ITGAM+ [GeneID=3684] dendritic cells.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE45365_NK_CELL_VS_BCELL_UP
Systematic name | M10031
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in NK cells versus B lymphocytes.
Full description | Murine Cytomegalovirus (MCMV) infection leads to early activation of various immune cells, including B and T lymphocytes, before the actual initiation of antigen-specific adaptive immunity. This activation is partly driven by innate cytokines, including type I interferon (IFN), which are induced early after infection. The objective of this study was to address the role of type I IFN in shaping early/innate B and T cell responses to a primary acute viral infection. In order to decipher the specific impact of IFN-I on cell subsets, we performed a genome-wide expression analysis on WT splenic B and CD8 T lymphocytes isolated from C57BL/6 [CD45.1 WT / CD45.2 IFNAR-KO] mixed bone marrow chimera mice. This study complements series GSE39555, which focused on early responses of NK cells and of the two subsets of conventional dendritic cells.

Standard name | GSE18804_SPLEEN_MACROPHAGE_VS_COLON_TUMORAL_MACROPHAGE_UP
Systematic name | M10032
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes up-regulated in macrophages: control versus colorectal adenocarcinoma conditioned.
Full description | Active immunotherapy is a promising strategy for anti-angiogenic cancer therapy. Recently, we have reported that a vaccine using human umbilical vein endothelial cells (HUVECs) induced specific anti-endothelial immune responses in the most of immunized patients, and resulted in tumor regression in some patients with recurrent malignant brain tumors, whereas not in colorectal cancer patients. In this study, we hypothesized that non-hypoxic perivascular tumor associated macrophages (TAMs) in colorectal cancer, but not in glioblastoma, might negatively alter the therapeutic efficacy of anti-angiogenic active immunotherapy. To test this hypothesis, we examined global gene expression profiles of non-hypoxic macrophages stimulated in vitro by soluble factors released from tumor cells of human glioblastoma U-87MG (‘brain TAMs’) or colorectal adenocarcinoma HT-29 (‘colon TAMs’).

Standard name | GSE18804_SPLEEN_MACROPHAGE_VS_COLON_TUMORAL_MACROPHAGE_DN
Systematic name | M10033
Organism | Mus musculus
PMID |
Authors |
Category | C7
Sub-category |
Brief description | Genes down-regulated in macrophages: control versus colorectal adenocarcinoma conditioned.
Full description | Active immunotherapy is a promising strategy for anti-angiogenic cancer therapy. Recently, we have reported that a vaccine using human umbilical vein endothelial cells (HUVECs) induced specific anti-endothelial immune responses in the most of immunized patients, and resulted in tumor regression in some patients with recurrent malignant brain tumors, whereas not in colorectal cancer patients. In this study, we hypothesized that non-hypoxic perivascular tumor associated macrophages (TAMs) in colorectal cancer, but not in glioblastoma, might negatively alter the therapeutic efficacy of anti-angiogenic active immunotherapy. To test this hypothesis, we examined global gene expression profiles of non-hypoxic macrophages stimulated in vitro by soluble factors released from tumor cells of human glioblastoma U-87MG (‘brain TAMs’) or colorectal adenocarcinoma HT-29 (‘colon TAMs’).

Standard name | DESERT_PERIPORTAL_HEPATOCELLULAR_CARCINOMA_SUBCLASS_UP
Systematic name | M34031
Organism | Homo sapiens
PMID | 28498607
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the periportal-type subclass of hepatocellular carcinomas. Sets created as part of a metaanalysis of nine public transcriptomic datasets merged into a metadataset including 1133 human hepatocellular carcinomas obtained after curative resection. For platform descriptions of each one of the 9 datasets, see Figure 1B in Désert et al., Hepatology (2017), 66: 1502-1518.
Full description | Hepatocellular carcinomas (HCCs) exhibit a diversity of molecular phenotypes, raising major challenges in clinical management. HCCs detected by surveillance programs at an early stage are candidates for potentially curative therapies (local ablation, resection or transplantation). In the long term, transplantation provides the lowest recurrence rates. Treatment allocation is based on tumor number, size, vascular invasion, performance status, functional liver reserve and on the prediction of early (< 2 years) recurrence, which reflects the intrinsic aggressiveness of the tumor. Well-differentiated, potentially low-aggressiveness tumors form the heterogeneous molecular class of non-proliferative HCCs, characterized by an approximate 50% beta-catenin (CTNNB1) mutation rate. To define the clinical, pathological, molecular features and the outcome of non-proliferative HCCs, we constructed an 1133-HCC transcriptomic metadata set and validated findings in a publically available 210-HCC RNAseq set. We show that non-proliferative HCCs preserve the zonation program that distributes metabolic functions along the porto-central axis in normal liver. More precisely, we identified two well-differentiated, non-proliferation subclasses, namely Periportal-type (wild-type CTNNB1) and Perivenous-type (mutant CTNNB1), which expressed negatively correlated gene networks. The new Periportal-type subclass represented 29% of all HCCs; expressed an HNF4A-driven gene network, which was down-regulated in mouse Hnf4a-KO mice; were early-stage tumors by BCLC, CLIP and TNM staging systems; had no macrovascular invasion and showed the lowest metastasis-specific gene expression levels and TP53 mutation rates. Also, we identified an 8-gene Periportal-type HCC signature, which was independently associated with the highest 2-year recurrence-free survival by multivariate analyses in two independent cohorts of 247 and 210 patients. Conclusion: Well-differentiated HCCs display mutually exclusive periportal or perivenous zonation programs. Among all HCCs, Periportal-type tumors have the lowest intrinsic potential for early recurrence after curative resection.

Standard name | DESERT_PERIVENOUS_HEPATOCELLULAR_CARCINOMA_SUBCLASS_UP
Systematic name | M34032
Organism | Homo sapiens
PMID | 28498607
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the perivenous-type subclass of hepatocellular carcinomas. Sets created as part of a metaanalysis of nine public transcriptomic datasets merged into a metadataset including 1133 human hepatocellular carcinomas obtained after curative resection. For platform descriptions of each one of the 9 datasets, see Figure 1B in Désert et al., Hepatology (2017), 66: 1502-1518.
Full description | Hepatocellular carcinomas (HCCs) exhibit a diversity of molecular phenotypes, raising major challenges in clinical management. HCCs detected by surveillance programs at an early stage are candidates for potentially curative therapies (local ablation, resection or transplantation). In the long term, transplantation provides the lowest recurrence rates. Treatment allocation is based on tumor number, size, vascular invasion, performance status, functional liver reserve and on the prediction of early (< 2 years) recurrence, which reflects the intrinsic aggressiveness of the tumor. Well-differentiated, potentially low-aggressiveness tumors form the heterogeneous molecular class of non-proliferative HCCs, characterized by an approximate 50% beta-catenin (CTNNB1) mutation rate. To define the clinical, pathological, molecular features and the outcome of non-proliferative HCCs, we constructed an 1133-HCC transcriptomic metadata set and validated findings in a publically available 210-HCC RNAseq set. We show that non-proliferative HCCs preserve the zonation program that distributes metabolic functions along the porto-central axis in normal liver. More precisely, we identified two well-differentiated, non-proliferation subclasses, namely Periportal-type (wild-type CTNNB1) and Perivenous-type (mutant CTNNB1), which expressed negatively correlated gene networks. The new Periportal-type subclass represented 29% of all HCCs; expressed an HNF4A-driven gene network, which was down-regulated in mouse Hnf4a-KO mice; were early-stage tumors by BCLC, CLIP and TNM staging systems; had no macrovascular invasion and showed the lowest metastasis-specific gene expression levels and TP53 mutation rates. Also, we identified an 8-gene Periportal-type HCC signature, which was independently associated with the highest 2-year recurrence-free survival by multivariate analyses in two independent cohorts of 247 and 210 patients. Conclusion: Well-differentiated HCCs display mutually exclusive periportal or perivenous zonation programs. Among all HCCs, Periportal-type tumors have the lowest intrinsic potential for early recurrence after curative resection.

Standard name | DESERT_EXTRACELLULAR_MATRIX_HEPATOCELLULAR_CARCINOMA_SUBCLASS_UP
Systematic name | M34033
Organism | Homo sapiens
PMID | 28498607
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the extracellular matrix-type subclass of hepatocellular carcinomas. Sets created as part of a metaanalysis of nine public transcriptomic datasets merged into a metadataset including 1133 human hepatocellular carcinomas obtained after curative resection. For platform descriptions of each one of the 9 datasets, see Figure 1B in Désert et al., Hepatology (2017), 66: 1502-1518.
Full description | Hepatocellular carcinomas (HCCs) exhibit a diversity of molecular phenotypes, raising major challenges in clinical management. HCCs detected by surveillance programs at an early stage are candidates for potentially curative therapies (local ablation, resection or transplantation). In the long term, transplantation provides the lowest recurrence rates. Treatment allocation is based on tumor number, size, vascular invasion, performance status, functional liver reserve and on the prediction of early (< 2 years) recurrence, which reflects the intrinsic aggressiveness of the tumor. Well-differentiated, potentially low-aggressiveness tumors form the heterogeneous molecular class of non-proliferative HCCs, characterized by an approximate 50% beta-catenin (CTNNB1) mutation rate. To define the clinical, pathological, molecular features and the outcome of non-proliferative HCCs, we constructed an 1133-HCC transcriptomic metadata set and validated findings in a publically available 210-HCC RNAseq set. We show that non-proliferative HCCs preserve the zonation program that distributes metabolic functions along the porto-central axis in normal liver. More precisely, we identified two well-differentiated, non-proliferation subclasses, namely Periportal-type (wild-type CTNNB1) and Perivenous-type (mutant CTNNB1), which expressed negatively correlated gene networks. The new Periportal-type subclass represented 29% of all HCCs; expressed an HNF4A-driven gene network, which was down-regulated in mouse Hnf4a-KO mice; were early-stage tumors by BCLC, CLIP and TNM staging systems; had no macrovascular invasion and showed the lowest metastasis-specific gene expression levels and TP53 mutation rates. Also, we identified an 8-gene Periportal-type HCC signature, which was independently associated with the highest 2-year recurrence-free survival by multivariate analyses in two independent cohorts of 247 and 210 patients. Conclusion: Well-differentiated HCCs display mutually exclusive periportal or perivenous zonation programs. Among all HCCs, Periportal-type tumors have the lowest intrinsic potential for early recurrence after curative resection.

Standard name | DESERT_STEM_CELL_HEPATOCELLULAR_CARCINOMA_SUBCLASS_UP
Systematic name | M34034
Organism | Homo sapiens
PMID | 28498607
Authors |
Category | C2
Sub-category | CGP
Brief description | Genes up-regulated in the stem cell-type subclass of hepatocellular carcinomas. Sets created as part of a metaanalysis of nine public transcriptomic datasets merged into a metadataset including 1133 human hepatocellular carcinomas obtained after curative resection. For platform descriptions of each one of the 9 datasets, see Figure 1B in Désert et al., Hepatology (2017), 66: 1502-1518.
Full description | Hepatocellular carcinomas (HCCs) exhibit a diversity of molecular phenotypes, raising major challenges in clinical management. HCCs detected by surveillance programs at an early stage are candidates for potentially curative therapies (local ablation, resection or transplantation). In the long term, transplantation provides the lowest recurrence rates. Treatment allocation is based on tumor number, size, vascular invasion, performance status, functional liver reserve and on the prediction of early (< 2 years) recurrence, which reflects the intrinsic aggressiveness of the tumor. Well-differentiated, potentially low-aggressiveness tumors form the heterogeneous molecular class of non-proliferative HCCs, characterized by an approximate 50% beta-catenin (CTNNB1) mutation rate. To define the clinical, pathological, molecular features and the outcome of non-proliferative HCCs, we constructed an 1133-HCC transcriptomic metadata set and validated findings in a publically available 210-HCC RNAseq set. We show that non-proliferative HCCs preserve the zonation program that distributes metabolic functions along the porto-central axis in normal liver. More precisely, we identified two well-differentiated, non-proliferation subclasses, namely Periportal-type (wild-type CTNNB1) and Perivenous-type (mutant CTNNB1), which expressed negatively correlated gene networks. The new Periportal-type subclass represented 29% of all HCCs; expressed an HNF4A-driven gene network, which was down-regulated in mouse Hnf4a-KO mice; were early-stage tumors by BCLC, CLIP and TNM staging systems; had no macrovascular invasion and showed the lowest metastasis-specific gene expression levels and TP53 mutation rates. Also, we identified an 8-gene Periportal-type HCC signature, which was independently associated with the highest 2-year recurrence-free survival by multivariate analyses in two independent cohorts of 247 and 210 patients. Conclusion: Well-differentiated HCCs display mutually exclusive periportal or perivenous zonation programs. Among all HCCs, Periportal-type tumors have the lowest intrinsic potential for early recurrence after curative resection.

Standard name | GO_MITOCHONDRIAL_GENOME_MAINTENANCE
Systematic name | M15237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The maintenance of the structure and integrity of the mitochondrial genome; includes replication and segregation of the mitochondrial chromosome. [GOC:ai, GOC:vw]
Full description |

Standard name | GO_REPRODUCTION
Systematic name | M15840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The production of new individuals that contain some portion of genetic material inherited from one or more parent organisms. [GOC:go_curators, GOC:isa_complete, GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_SINGLE_STRAND_BREAK_REPAIR
Systematic name | M22128
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The repair of single strand breaks in DNA. Repair of such breaks is mediated by the same enzyme systems as are used in base excision repair. [http://www.ultranet.com/~jkimball/BiologyPages/D/DNArepair.html]
Full description |

Standard name | GO_REGULATION_OF_DNA_RECOMBINATION
Systematic name | M10217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA recombination, a DNA metabolic process in which a new genotype is formed by reassortment of genes resulting in gene combinations different from those that were present in the parents. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_MITOTIC_RECOMBINATION
Systematic name | M22129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA recombination during mitosis. [GOC:go_curators]
Full description |

Standard name | GO_RIBOSOMAL_LARGE_SUBUNIT_ASSEMBLY
Systematic name | M12577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of constituent RNAs and proteins to form the large ribosomal subunit. [GOC:jl]
Full description |

Standard name | GO_RIBOSOMAL_SMALL_SUBUNIT_ASSEMBLY
Systematic name | M16295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of constituent RNAs and proteins to form the small ribosomal subunit. [GOC:jl]
Full description |

Standard name | GO_VERY_LONG_CHAIN_FATTY_ACID_METABOLIC_PROCESS
Systematic name | M13480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a fatty acid which has a chain length greater than C22. [GOC:hjd]
Full description |

Standard name | GO_TRANSITION_METAL_ION_TRANSPORT
Systematic name | M10755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of transition metal ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. A transition metal is an element whose atom has an incomplete d-subshell of extranuclear electrons, or which gives rise to a cation or cations with an incomplete d-subshell. Transition metals often have more than one valency state. Biologically relevant transition metals include vanadium, manganese, iron, copper, cobalt, nickel, molybdenum and silver. [ISBN:0198506732]
Full description |

Standard name | GO_UREA_CYCLE
Systematic name | M22130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The sequence of reactions by which arginine is synthesized from ornithine, then cleaved to yield urea and regenerate ornithine. The overall reaction equation is NH3 + CO2 + aspartate + 3 ATP + 2 H2O = urea + fumarate + 2 ADP + 2 phosphate + AMP + diphosphate. [GOC:pde, GOC:vw, ISBN:0198506732]
Full description |

Standard name | GO_CITRULLINE_METABOLIC_PROCESS
Systematic name | M29007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving citrulline, N5-carbamoyl-L-ornithine, an alpha amino acid not found in proteins. [ISBN:0198506732]
Full description |

Standard name | GO_RIBOSOMAL_LARGE_SUBUNIT_EXPORT_FROM_NUCLEUS
Systematic name | M22131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a ribosomal large subunit from the nucleus into the cytoplasm. [GOC:mah]
Full description |

Standard name | GO_RIBOSOMAL_SMALL_SUBUNIT_EXPORT_FROM_NUCLEUS
Systematic name | M22132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a ribosomal small subunit from the nucleus into the cytoplasm. [GOC:mah]
Full description |

Standard name | GO_MITOTIC_SISTER_CHROMATID_SEGREGATION
Systematic name | M5962
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which replicated homologous chromosomes are organized and then physically separated and apportioned to two sets during the mitotic cell cycle. Each replicated chromosome, composed of two sister chromatids, aligns at the cell equator, paired with its homologous partner. One homolog of each morphologic type goes into each of the resulting chromosome sets. [GOC:ai, GOC:jl]
Full description |

Standard name | GO_CELL_CYCLE_CHECKPOINT
Systematic name | M14894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle process that controls cell cycle progression by monitoring the integrity of specific cell cycle events. A cell cycle checkpoint begins with detection of deficiencies or defects and ends with signal transduction. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_DNA_REPLICATION_CHECKPOINT
Systematic name | M14250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle checkpoint that prevents the initiation of nuclear division until DNA replication is complete, thereby ensuring that progeny inherit a full complement of the genome. [GOC:curators, GOC:rn, PMID:11728327, PMID:12537518]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_INVOLVED_IN_G1_S_TRANSITION_OF_MITOTIC_CELL_CYCLE
Systematic name | M16327
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that regulates transcription such that the target genes are involved in the transition between G1 and S phase of the mitotic cell cycle. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_SULFUR_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M15580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving amino acids containing sulfur, comprising cysteine, homocysteine, methionine and selenocysteine. [GOC:ai]
Full description |

Standard name | GO_SULFUR_AMINO_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M29008
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of amino acids containing sulfur, comprising cysteine, methionine and selenocysteine. [GOC:ai]
Full description |

Standard name | GO_SULFUR_AMINO_ACID_CATABOLIC_PROCESS
Systematic name | M22133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of amino acids containing sulfur, comprising cysteine, methionine and selenocysteine. [GOC:ai]
Full description |

Standard name | GO_SULFUR_AMINO_ACID_TRANSPORT
Systematic name | M22134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of amino acids containing sulfur (cystine, methionine and their derivatives) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSCRIPTION_BY_RNA_POLYMERASE_II
Systematic name | M22135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of transcription mediated by RNA polymerase II. [GOC:go_curators, GOC:txnOH]
Full description |

Standard name | GO_RRNA_MODIFICATION
Systematic name | M15791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent alteration of one or more nucleotides within an rRNA molecule to produce an rRNA molecule with a sequence that differs from that coded genetically. [GOC:curators]
Full description |

Standard name | GO_RDNA_HETEROCHROMATIN_ASSEMBLY
Systematic name | M15982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The assembly of chromatin characterized by the modified histone H3K9me3, into heterochromatin, resulting in the repression of transcription of rDNA. [PMID:10219245]
Full description |

Standard name | GO_NUCLEAR_TRANSCRIBED_MRNA_CATABOLIC_PROCESS_NONSENSE_MEDIATED_DECAY
Systematic name | M15478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The nonsense-mediated decay pathway for nuclear-transcribed mRNAs degrades mRNAs in which an amino-acid codon has changed to a nonsense codon; this prevents the translation of such mRNAs into truncated, and potentially harmful, proteins. [GOC:krc, GOC:ma, PMID:10025395]
Full description |

Standard name | GO_ACTIVATION_OF_MAPKKK_ACTIVITY
Systematic name | M14705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of the inactive enzyme MAP kinase kinase kinase (MAPKKK). [PMID:9561267]
Full description |

Standard name | GO_ACTIVATION_OF_MAPKK_ACTIVITY
Systematic name | M16935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initiation of the activity of the inactive enzyme MAP kinase kinase (MAPKK). [PMID:9561267]
Full description |

Standard name | GO_ACTIVATION_OF_MAPK_ACTIVITY
Systematic name | M16162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initiation of the activity of the inactive enzyme MAP kinase (MAPK). [PMID:9561267]
Full description |

Standard name | GO_INACTIVATION_OF_MAPK_ACTIVITY
Systematic name | M16037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that terminates the activity of the active enzyme MAP kinase. [PMID:9561267]
Full description |

Standard name | GO_PROTEIN_POLYUBIQUITINATION
Systematic name | M13882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Addition of multiple ubiquitin groups to a protein, forming a ubiquitin chain. [ISBN:0815316194]
Full description |

Standard name | GO_MEIOTIC_SPINDLE_ORGANIZATION
Systematic name | M22136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the microtubule spindle during a meiotic cell cycle. [GOC:go_curators, GOC:mah]
Full description |

Standard name | GO_MICROTUBULE_CYTOSKELETON_ORGANIZATION
Systematic name | M2261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of cytoskeletal structures comprising microtubules and their associated proteins. [GOC:mah]
Full description |

Standard name | GO_SPLICEOSOMAL_TRI_SNRNP_COMPLEX_ASSEMBLY
Systematic name | M12504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a tri-snRNP complex containing U4 and U6 (or U4atac and U6atac) snRNAs and U5 snRNAs and associated proteins. This includes reannealing of U4 and U6 (or U4atac and U6atac) snRNAs released from previous rounds of splicing to reform the U4/U6 snRNP (or U4atac/U6atac snRNP) as well as the subsequent association of the U5 snRNP with the U4/U6 snRNP (or U4atac/U6atac snRNP) to form a tri-snRNP that is ready to reassemble into another spliceosome complex. [ISBN:0879695897, PMID:9452384]
Full description |

Standard name | GO_SPLICEOSOMAL_COMPLEX_ASSEMBLY
Systematic name | M9878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a spliceosomal complex, a ribonucleoprotein apparatus that catalyzes nuclear mRNA splicing via transesterification reactions. [PMID:9476892]
Full description |

Standard name | GO_MITOCHONDRIAL_FISSION
Systematic name | M12786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The division of a mitochondrion within a cell to form two or more separate mitochondrial compartments. [PMID:11038192]
Full description |

Standard name | GO_PEPTIDOGLYCAN_METABOLIC_PROCESS
Systematic name | M29009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving peptidoglycans, any of a class of glycoconjugates found only in bacterial cell walls and consisting of strands of glycosaminoglycan cross-linked by oligopeptides to form a huge and rigid network. [http://www.dsmz.de/species/murein.htm, ISBN:0198506732]
Full description |

Standard name | GO_POLYSACCHARIDE_BIOSYNTHETIC_PROCESS
Systematic name | M10417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a polysaccharide, a polymer of many (typically more than 10) monosaccharide residues linked glycosidically. [GOC:go_curators]
Full description |

Standard name | GO_POLYSACCHARIDE_CATABOLIC_PROCESS
Systematic name | M12148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a polysaccharide, a polymer of many (typically more than 10) monosaccharide residues linked glycosidically. [GOC:go_curators]
Full description |

Standard name | GO_MITOTIC_CELL_CYCLE
Systematic name | M1396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Progression through the phases of the mitotic cell cycle, the most common eukaryotic cell cycle, which canonically comprises four successive phases called G1, S, G2, and M and includes replication of the genome and the subsequent segregation of chromosomes into daughter cells. In some variant cell cycles nuclear replication or nuclear division may not be followed by cell division, or G1 and G2 phases may be absent. [GOC:mah, ISBN:0815316194, Reactome:69278]
Full description |

Standard name | GO_MITOTIC_CYTOKINESIS
Systematic name | M10078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle process that results in the division of the cytoplasm of a cell after mitosis, resulting in the separation of the original cell into two daughter cells. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_NUCLEAR_TRANSCRIBED_MRNA_CATABOLIC_PROCESS_DEADENYLATION_DEPENDENT_DECAY
Systematic name | M14218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A major pathway of degradation of nuclear-transcribed mRNAs that proceeds through a series of ordered steps that includes poly(A) tail shortening and that can regulate mRNA stability. [GOC:jp, GOC:krc]
Full description |

Standard name | GO_NUCLEAR_TRANSCRIBED_MRNA_POLY_A_TAIL_SHORTENING
Systematic name | M14619
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Shortening of the poly(A) tail of a nuclear-transcribed mRNA from full length to an oligo(A) length. [GOC:krc]
Full description |

Standard name | GO_DEADENYLATION_DEPENDENT_DECAPPING_OF_NUCLEAR_TRANSCRIBED_MRNA
Systematic name | M22137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cleavage of the 5'-cap of a nuclear mRNA triggered by shortening of the poly(A) tail to below a minimum functional length. [GOC:krc]
Full description |

Standard name | GO_NUCLEAR_TRANSCRIBED_MRNA_CATABOLIC_PROCESS_EXONUCLEOLYTIC
Systematic name | M16277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of the transcript body of a nuclear-transcribed mRNA that occurs when the ends are not protected by the 5'-cap or the 3'-poly(A) tail. [GOC:krc]
Full description |

Standard name | GO_RESPONSE_TO_REACTIVE_OXYGEN_SPECIES
Systematic name | M16953
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a reactive oxygen species stimulus. Reactive oxygen species include singlet oxygen, superoxide, and oxygen free radicals. [GOC:krc]
Full description |

Standard name | GO_RESPONSE_TO_OXYGEN_RADICAL
Systematic name | M15581
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an oxygen radical stimulus. An oxygen radical is any oxygen species that carries a free electron; examples include hydroxyl radicals and the superoxide anion. [GOC:krc, ISBN:0124325653]
Full description |

Standard name | GO_RE_ENTRY_INTO_MITOTIC_CELL_CYCLE
Systematic name | M22138
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The resumption of the mitotic cell division cycle by cells that were in a quiescent or other non-dividing state. [GOC:krc]
Full description |

Standard name | GO_PROTEIN_DENEDDYLATION
Systematic name | M22139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of a ubiquitin-like protein of the NEDD8 type from a protein. [GOC:krc]
Full description |

Standard name | GO_FORMATION_OF_QUADRUPLE_SL_U4_U5_U6_SNRNP
Systematic name | M34035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Formation of a quadruple snRNP complex composed of the spliced leader (SL) RNA along with the U4/U6-U5 tri-snRNP complex. Interactions that may facilitate this include a duplex between the SL and U6 RNAs and interactions between the U5 RNA and the exon sequence at the 5' splice site within the SL RNA. [GOC:krc, ISBN:0879695897]
Full description |

Standard name | GO_RNA_SPLICING_VIA_TRANSESTERIFICATION_REACTIONS
Systematic name | M8362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Splicing of RNA via a series of two transesterification reactions. [GOC:krc]
Full description |

Standard name | GO_ALTERNATIVE_MRNA_SPLICING_VIA_SPLICEOSOME
Systematic name | M10881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of generating multiple mRNA molecules from a given set of exons by differential use of exons from the primary transcript(s) to form multiple mature mRNAs that vary in their exon composition. [GOC:krc, PMID:12110900]
Full description |

Standard name | GO_SPLICEOSOMAL_SNRNP_ASSEMBLY
Systematic name | M16609
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of one or more snRNA and multiple protein components to form a ribonucleoprotein complex that is involved in formation of the spliceosome. [GOC:krc, GOC:mah, ISBN:0879695897]
Full description |

Standard name | GO_MRNA_3_SPLICE_SITE_RECOGNITION
Systematic name | M22142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Recognition of the intron 3'-splice site by components of the assembling U2- or U12-type spliceosome. [GOC:krc, ISBN:0879695897]
Full description |

Standard name | GO_SPLICEOSOMAL_CONFORMATIONAL_CHANGES_TO_GENERATE_CATALYTIC_CONFORMATION
Systematic name | M22143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Structural rearrangements of the spliceosome complex, containing RNA to be spliced, to generate a catalytic conformation. [GOC:krc]
Full description |

Standard name | GO_RNA_SPLICING_VIA_ENDONUCLEOLYTIC_CLEAVAGE_AND_LIGATION
Systematic name | M13106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Splicing of RNA via recognition of the folded RNA structure that brings the 5' and 3' splice sites into proximity and cleavage of the RNA at both the 3' and 5' splice sites by an endonucleolytic mechanism, followed by ligation of the exons. [GOC:krc, ISBN:0879695897]
Full description |

Standard name | GO_MRNA_5_SPLICE_SITE_RECOGNITION
Systematic name | M22144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Recognition of the intron 5'-splice site by components of the assembling spliceosome. [GOC:krc, ISBN:0879695897]
Full description |

Standard name | GO_PROTEIN_PEPTIDYL_PROLYL_ISOMERIZATION
Systematic name | M22145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of a protein by cis-trans isomerization of a proline residue. [GOC:krc, PMID:16959570]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_H3_K36_METHYLATION
Systematic name | M22146
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the covalent addition of a methyl group to the lysine at position 36 of histone H3. [GOC:krc]
Full description |

Standard name | GO_AUTOPHAGY_OF_MITOCHONDRION
Systematic name | M22147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The autophagic process in which mitochondria are delivered to a type of vacuole and degraded in response to changing cellular conditions. [GOC:autophagy, PMID:15798367, PMID:19289147, PMID:23065344]
Full description |

Standard name | GO_MITOPHAGY
Systematic name | M22148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The selective autophagy process in which a mitochondrion is degraded by macroautophagy. [PMID:15798367]
Full description |

Standard name | GO_ENDONUCLEOLYTIC_CLEAVAGE_IN_ITS1_TO_SEPARATE_SSU_RRNA_FROM_5_8S_RRNA_AND_LSU_RRNA_FROM_TRICISTRONIC_RRNA_TRANSCRIPT_SSU_RRNA_5_8S_RRNA_LSU_RRNA
Systematic name | M22149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Endonucleolytic cleavage between the SSU-rRNA and the 5.8S rRNA of an rRNA molecule originally produced as a tricistronic rRNA transcript that contained the Small SubUnit (SSU) rRNA, the 5.8S rRNA, and the Large SubUnit (LSU) rRNA, in that order, from 5' to 3' along the primary transcript. [GOC:curators, PMID:10690410]
Full description |

Standard name | GO_ENZYME_DIRECTED_RRNA_PSEUDOURIDINE_SYNTHESIS
Systematic name | M34036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The intramolecular conversion of uridine to pseudouridine during ribosome biogenesis where the enzyme specifies the site that becomes pseudouridylated without using a guide RNA. [GOC:curators, ISBN:1555811337]
Full description |

Standard name | GO_MATURATION_OF_5_8S_RRNA
Systematic name | M15661
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maturation of a precursor 5.8S ribosomal RNA (rRNA) molecule into a mature 5.8S rRNA molecule. [GOC:curators]
Full description |

Standard name | GO_MATURATION_OF_SSU_RRNA_FROM_TRICISTRONIC_RRNA_TRANSCRIPT_SSU_RRNA_5_8S_RRNA_LSU_RRNA
Systematic name | M13062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maturation of a precursor Small SubUnit (SSU) ribosomal RNA (rRNA) molecule into a mature SSU-rRNA molecule from the pre-rRNA molecule originally produced as a tricistronic rRNA transcript that contains the Small Subunit (SSU) rRNA, 5.8S rRNA, and the Large Subunit (LSU) in that order from 5' to 3' along the primary transcript. [GOC:curators]
Full description |

Standard name | GO_MATURATION_OF_LSU_RRNA_FROM_TRICISTRONIC_RRNA_TRANSCRIPT_SSU_RRNA_5_8S_RRNA_LSU_RRNA
Systematic name | M22151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maturation of a precursor Large SubUnit (LSU) ribosomal RNA (rRNA) molecule into a mature LSU-rRNA molecule from the pre-rRNA molecule originally produced as a tricistronic rRNA transcript that contains the Small Subunit (SSU) rRNA, 5.8S rRNA, and Large Subunit (LSU) in that order from 5' to 3' along the primary transcript. [GOC:curators]
Full description |

Standard name | GO_MATURATION_OF_5_8S_RRNA_FROM_TRICISTRONIC_RRNA_TRANSCRIPT_SSU_RRNA_5_8S_RRNA_LSU_RRNA
Systematic name | M12787
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maturation of an rRNA molecule originally produced as part of a tricistronic rRNA transcript that contained the Small SubUnit (SSU) rRNA, the 5.8S rRNA, and the Large SubUnit (LSU) rRNA, in that order, from 5' to 3' along the primary transcript. [GOC:curators, PMID:10690410]
Full description |

Standard name | GO_CLEAVAGE_INVOLVED_IN_RRNA_PROCESSING
Systematic name | M11466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any phosphodiester bond hydrolysis involved in the conversion of a primary ribosomal RNA (rRNA) transcript into a mature rRNA molecule. [GOC:curators]
Full description |

Standard name | GO_MATURATION_OF_LSU_RRNA
Systematic name | M13105
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maturation of a precursor Large SubUnit (LSU) ribosomal RNA (rRNA) molecule into a mature LSU-rRNA molecule. [GOC:curators]
Full description |

Standard name | GO_ENDONUCLEOLYTIC_CLEAVAGE_INVOLVED_IN_RRNA_PROCESSING
Systematic name | M22152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any endonucleolytic cleavage involved in the conversion of a primary ribosomal RNA (rRNA) transcript into a mature rRNA molecule. Some endonucleolytic cleavages produce the mature end, while others are a step in the process of generating the mature end from the pre-rRNA. [GOC:krc, PMID:10690410]
Full description |

Standard name | GO_ENDONUCLEOLYTIC_CLEAVAGE_IN_5_ETS_OF_TRICISTRONIC_RRNA_TRANSCRIPT_SSU_RRNA_5_8S_RRNA_LSU_RRNA
Systematic name | M22153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Endonucleolytic cleavage within the 5'-External Transcribed Spacer (ETS) of a tricistronic rRNA transcript that contains the Small Subunit (SSU) rRNA, the 5.8S rRNA, and the Large Subunit (LSU) rRNA in that order from 5' to 3' along the primary transcript. Endonucleolytic cleavage within the 5'-ETS of the pre-RNA is conserved as one of the early steps of rRNA processing in all eukaryotes, but the specific position of cleavage is variable. [GOC:curators, PMID:10690410, PMID:15282326]
Full description |

Standard name | GO_SMALL_NUCLEOLAR_RIBONUCLEOPROTEIN_COMPLEX_ASSEMBLY
Systematic name | M22154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins and a snoRNA to form a small nucleolar ribonucleoprotein (snoRNP) complex. [GOC:krc]
Full description |

Standard name | GO_BOX_C_D_SNORNP_ASSEMBLY
Systematic name | M22155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins and a box C/D snoRNA to form a box C/D small nucleolar ribonucleoprotein (snoRNP) complex. [GOC:krc]
Full description |

Standard name | GO_EMBRYONIC_AXIS_SPECIFICATION
Systematic name | M10648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment, maintenance and elaboration of a pattern along a line or a point in an embryo. [GOC:dph, GOC:go_curators, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_MEIOTIC_MISMATCH_REPAIR
Systematic name | M34037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A system for the identification and correction of base-base mismatches, small insertion-deletion loops, and regions of heterology that are present in duplex DNA formed with strands from two recombining molecules. Correction of the mismatch can result in non-Mendelian segregation of alleles following meiosis. [GOC:elh, PMID:10357855]
Full description |

Standard name | GO_RESOLUTION_OF_MEIOTIC_RECOMBINATION_INTERMEDIATES
Systematic name | M22157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cleavage and rejoining of intermediates, such as Holliday junctions, formed during meiotic recombination to produce two intact molecules in which genetic material has been exchanged. [GOC:elh, PMID:11733053]
Full description |

Standard name | GO_NUCLEOTIDE_EXCISION_REPAIR_DNA_DAMAGE_RECOGNITION
Systematic name | M12048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The identification of lesions in DNA, such as pyrimidine-dimers, intrastrand cross-links, and bulky adducts. The wide range of substrate specificity suggests the repair complex recognizes distortions in the DNA helix. [GOC:elh, PMID:10197977]
Full description |

Standard name | GO_NUCLEOTIDE_EXCISION_REPAIR_DNA_DUPLEX_UNWINDING
Systematic name | M15649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The unwinding, or local denaturation, of the DNA duplex to create a bubble around the site of the DNA damage. [GOC:elh, PMID:10197977]
Full description |

Standard name | GO_TELOMERE_MAINTENANCE_VIA_RECOMBINATION
Systematic name | M13353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any recombinational process that contributes to the maintenance of proper telomeric length. [GOC:elh, PMID:11850777]
Full description |

Standard name | GO_RECOMBINATIONAL_REPAIR
Systematic name | M15461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A DNA repair process that involves the exchange, reciprocal or nonreciprocal, of genetic material between the broken DNA molecule and a homologous region of DNA. [GOC:elh]
Full description |

Standard name | GO_NON_RECOMBINATIONAL_REPAIR
Systematic name | M14315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A DNA repair process in which that does not require the exchange of genetic material between the broken DNA molecule and a homologous region of DNA. [GOC:elh]
Full description |

Standard name | GO_DOUBLE_STRAND_BREAK_REPAIR_VIA_BREAK_INDUCED_REPLICATION
Systematic name | M22158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The error-free repair of a double-strand break in DNA in which the centromere-proximal end of a broken chromosome searches for a homologous region in an intact chromosome. DNA synthesis initiates from the 3' end of the invading DNA strand, using the intact chromosome as the template, and progresses to the end of the chromosome. [GOC:elh, PMID:10357855]
Full description |

Standard name | GO_DNA_DOUBLE_STRAND_BREAK_PROCESSING
Systematic name | M15933
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The 5' to 3' exonucleolytic resection of the DNA at the site of the break to form a 3' single-strand DNA overhang. [PMID:10357855]
Full description |

Standard name | GO_DNA_SYNTHESIS_INVOLVED_IN_DNA_REPAIR
Systematic name | M14184
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Synthesis of DNA that proceeds from the broken 3' single-strand DNA end and uses the homologous intact duplex as the template. [PMID:10357855]
Full description |

Standard name | GO_DNA_STRAND_RENATURATION
Systematic name | M22159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The identification and annealing of complementary base pairs in single-strand DNA. [GOC:elh]
Full description |

Standard name | GO_DNA_CATABOLIC_PROCESS_ENDONUCLEOLYTIC
Systematic name | M16882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of DNA, involving the hydrolysis of internal 3',5'-phosphodiester bonds in one or two strands of deoxyribonucleotides. [GOC:elh, GOC:mah]
Full description |

Standard name | GO_DNA_CATABOLIC_PROCESS_EXONUCLEOLYTIC
Systematic name | M22160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of DNA, involving the hydrolysis of terminal 3',5'-phosphodiester bonds in one or two strands of deoxyribonucleotides. [GOC:elh, GOC:mah]
Full description |

Standard name | GO_SISTER_CHROMATID_SEGREGATION
Systematic name | M536
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which sister chromatids are organized and then physically separated and apportioned to two or more sets. [GOC:ai, GOC:elh]
Full description |

Standard name | GO_REGULATION_OF_GLUTAMINE_FAMILY_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M22161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving amino acids of the glutamine family, comprising arginine, glutamate, glutamine and proline. [GOC:go_curators]
Full description |

Standard name | GO_CELL_MORPHOGENESIS
Systematic name | M34038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process in which the size or shape of a cell is generated and organized. [GOC:clt, GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_CELL_MORPHOGENESIS_INVOLVED_IN_DIFFERENTIATION
Systematic name | M2593
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in form (cell shape and size) that occurs when relatively unspecialized cells, e.g. embryonic or regenerative cells, acquire specialized structural and/or functional features that characterize the cells, tissues, or organs of the mature organism or some other relatively stable phase of the organism's life history. [GOC:go_curators]
Full description |

Standard name | GO_CYTOKINESIS
Systematic name | M12709
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The division of the cytoplasm and the plasma membrane of a cell and its partitioning into two daughter cells. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_NUCLEAR_TRANSCRIBED_MRNA_CATABOLIC_PROCESS
Systematic name | M22162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of nuclear-transcribed mRNAs in eukaryotic cells. [GOC:krc]
Full description |

Standard name | GO_MITOCHONDRIAL_RNA_CATABOLIC_PROCESS
Systematic name | M22163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of RNA transcribed from the mitochondrial genome and occurring in the mitochondrion. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_MITOCHONDRIAL_RNA_METABOLIC_PROCESS
Systematic name | M13702
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving RNA transcribed from the mitochondrial genome and occurring in the mitochondrion. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRIAL_RNA_CATABOLIC_PROCESS
Systematic name | M29010
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving catabolism in the mitochondrion of RNA transcribed from the mitochondrial genome. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_MITOCHONDRIAL_RNA_PROCESSING
Systematic name | M13360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The conversion of a primary RNA molecule transcribed from a mitochondrial genome into one or more mature RNA molecules; occurs in the mitochondrion. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_MITOCHONDRIAL_RNA_3_END_PROCESSING
Systematic name | M22164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in forming the mature 3' end of an RNA molecule transcribed from a mitochondrial genome; occurs in the mitochondrion. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_RNA_5_END_PROCESSING
Systematic name | M22165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in forming the mature 5' end of an RNA molecule. [GOC:krc]
Full description |

Standard name | GO_RRNA_5_END_PROCESSING
Systematic name | M34039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in forming the mature 5' end of an rRNA molecule. [GOC:krc]
Full description |

Standard name | GO_TRANSCRIPTION_DEPENDENT_TETHERING_OF_RNA_POLYMERASE_II_GENE_DNA_AT_NUCLEAR_PERIPHERY
Systematic name | M22166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chromosome organization process in which the DNA sequence containing a gene transcribed by RNA polymerase II is maintained in a specific location at the nuclear periphery. In S. cerevisiae, this process involves cis-acting DNA sequences such as the TATA box and upstream activating sequence (UAS) elements, trans-acting transcriptional activators, and also the 3'-UTR of the transcript. [GOC:krc, PMID:18614049]
Full description |

Standard name | GO_RESPONSE_TO_ACID_CHEMICAL
Systematic name | M10614
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus by the chemical structure of the anion portion of a dissociated acid (rather than the acid acting as a proton donor). The acid chemical may be in gaseous, liquid or solid form. [GOC:go_curators, GOC:rn]
Full description |

Standard name | GO_RNA_POLYMERASE_I_PREINITIATION_COMPLEX_ASSEMBLY
Systematic name | M22167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins on promoter DNA to form the transcriptional preinitiation complex (PIC), the formation of which is a prerequisite for transcription from an RNA polymerase I promoter. [GOC:txnOH, PMID:12381659, PMID:14969726, PMID:8057832]
Full description |

Standard name | GO_REPLICATIVE_CELL_AGING
Systematic name | M22168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process associated with progression of the cell from its inception to the end of its lifespan that occurs as the cell continues cycles of growth and division. [GOC:jh, PMID:12044934]
Full description |

Standard name | GO_FORMATION_OF_EXTRACHROMOSOMAL_CIRCULAR_DNA
Systematic name | M22169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Excision from the chromosome and circularization of a region of chromosomal DNA, generally, but not always, via homologous recombination between direct tandem repeats. [GOC:jh, PMID:12044938]
Full description |

Standard name | GO_SKELETAL_SYSTEM_DEVELOPMENT
Systematic name | M10584
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the skeleton over time, from its formation to the mature structure. The skeleton is the bony framework of the body in vertebrates (endoskeleton) or the hard outer envelope of insects (exoskeleton or dermoskeleton). [GOC:dph, GOC:jid, GOC:tb]
Full description |

Standard name | GO_OSSIFICATION
Systematic name | M14199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of bone or of a bony substance, or the conversion of fibrous tissue or of cartilage into bone or a bony substance. [GOC:mtg_mpo, PMID:17572649]
Full description |

Standard name | GO_NEUROTRANSMITTER_UPTAKE
Systematic name | M10602
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of neurotransmitters into neurons or glial cells. This process leads to inactivation and recycling of neurotransmitters. [ISBN:0123668387]
Full description |

Standard name | GO_REGULATION_OF_NEUROTRANSMITTER_LEVELS
Systematic name | M11723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates levels of neurotransmitter. [GOC:jl]
Full description |

Standard name | GO_ACTION_POTENTIAL
Systematic name | M8865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which membrane potential cycles through a depolarizing spike, triggered in response to depolarization above some threshold, followed by repolarization. This cycle is driven by the flow of ions through various voltage gated channels with different thresholds and ion specificities. [GOC:dph, GOC:go_curators, GOC:tb, ISBN:978-0-07-139011-8]
Full description |

Standard name | GO_RNA_METHYLATION
Systematic name | M11750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Posttranscriptional addition of a methyl group to either a nucleotide or 2'-O ribose in a polyribonucleotide. Usually uses S-adenosylmethionine as a cofactor. [GOC:hjd]
Full description |

Standard name | GO_PSEUDOURIDINE_SYNTHESIS
Systematic name | M11974
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The intramolecular conversion of uridine to pseudouridine within an RNA molecule. This posttranscriptional base modification occurs in tRNA, rRNA, and snRNAs. [GOC:hjd, GOC:mah]
Full description |

Standard name | GO_CILIUM_OR_FLAGELLUM_DEPENDENT_CELL_MOTILITY
Systematic name | M13478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell motility due to movement of eukaryotic cilia or bacterial-type flagella or archaeal-type flagella. [GOC:cilia, GOC:hjd, GOC:krc]
Full description |

Standard name | GO_OVARIAN_FOLLICLE_DEVELOPMENT
Systematic name | M12328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the ovarian follicle over time, from its formation to the mature structure. [GOC:go_curators]
Full description |

Standard name | GO_OVULATION_FROM_OVARIAN_FOLLICLE
Systematic name | M22170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process leading to the rupture of the follicle, releasing the centrally located oocyte into the oviduct. An example of this is found in Mus musculus. [GOC:mtg_sensu, http://ovary.stanford.edu]
Full description |

Standard name | GO_ANTRAL_OVARIAN_FOLLICLE_GROWTH
Systematic name | M22171
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Increase in size of antral follicles due to cell proliferation and/or growth of the antral cavity. [http://ovary.stanford.edu]
Full description |

Standard name | GO_LUTEINIZATION
Systematic name | M22172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The set of processes resulting in differentiation of theca and granulosa cells into luteal cells and in the formation of a corpus luteum after ovulation. [http://ovary.stanford.edu]
Full description |

Standard name | GO_LUTEOLYSIS
Systematic name | M22173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The lysis or structural demise of the corpus luteum. During normal luteolysis, two closely related events occur. First, there is loss of the capacity to synthesize and secrete progesterone (functional luteolysis) followed by loss of the cells that comprise the corpus luteum (structural luteolysis). Preventing luteolysis is crucial to maintain pregnancy. [PMID:10617764]
Full description |

Standard name | GO_OOCYTE_MATURATION
Systematic name | M13890
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for an oocyte to attain its fully functional state. Oocyte maturation commences after reinitiation of meiosis commonly starting with germinal vesicle breakdown, and continues up to the second meiotic arrest prior to fertilization. [GOC:devbiol, http://ovary.stanford.edu]
Full description |

Standard name | GO_FATTY_ACID_ALPHA_OXIDATION
Systematic name | M22174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A metabolic pathway by which 3-methyl branched fatty acids are degraded. These compounds are not degraded by the normal peroxisomal beta-oxidation pathway, because the 3-methyl blocks the dehydrogenation of the hydroxyl group by hydroxyacyl-CoA dehydrogenase. The 3-methyl branched fatty acid is converted in several steps to pristenic acid, which can then feed into the beta-oxidative pathway. [http://www.peroxisome.org/Scientist/Biochemistry/alpha-oxidation.html]
Full description |

Standard name | GO_RESPONSE_TO_PROTOZOAN
Systematic name | M13033
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a protozoan. [GOC:ai]
Full description |

Standard name | GO_BRANCHING_INVOLVED_IN_BLOOD_VESSEL_MORPHOGENESIS
Systematic name | M22175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of coordinated growth and sprouting of blood vessels giving rise to the organized vascular system. [GOC:dph]
Full description |

Standard name | GO_VASCULOGENESIS
Systematic name | M14322
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The differentiation of endothelial cells from progenitor cells during blood vessel development, and the de novo formation of blood vessels and tubes. [PMID:8999798]
Full description |

Standard name | GO_GANGLIOSIDE_METABOLIC_PROCESS
Systematic name | M29011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving ceramide oligosaccharides carrying in addition to other sugar residues, one or more sialic acid residues. [ISBN:0198506732]
Full description |

Standard name | GO_GANGLIOSIDE_BIOSYNTHETIC_PROCESS
Systematic name | M13958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of ceramide oligosaccharides carrying in addition to other sugar residues, one or more sialic acid residues. [ISBN:0198506732]
Full description |

Standard name | GO_MICROTUBULE_BUNDLE_FORMATION
Systematic name | M14007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that results in a parallel arrangement of microtubules. [GOC:dph]
Full description |

Standard name | GO_OSTEOBLAST_DIFFERENTIATION
Systematic name | M11227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whereby a relatively unspecialized cell acquires the specialized features of an osteoblast, a mesodermal or neural crest cell that gives rise to bone. [CL:0000062, GO_REF:0000034, GOC:jid]
Full description |

Standard name | GO_UROGENITAL_SYSTEM_DEVELOPMENT
Systematic name | M14876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the urogenital system over time, from its formation to the mature structure. [GOC:go_curators]
Full description |

Standard name | GO_METANEPHROS_DEVELOPMENT
Systematic name | M10490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the metanephros over time, from its formation to the mature structure. In mammals, the metanephros is the excretory organ of the fetus, which develops into the mature kidney and is formed from the rear portion of the nephrogenic cord. The metanephros is an endocrine and metabolic organ that filters the blood and excretes the end products of body metabolism in the form of urine. [GOC:bf, ISBN:0192800752]
Full description |

Standard name | GO_TEMPERATURE_HOMEOSTASIS
Systematic name | M16432
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A homeostatic process in which an organism modulates its internal body temperature. [GOC:jl]
Full description |

Standard name | GO_FEVER_GENERATION
Systematic name | M22176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The heat generation process that results in a rise in body temperature above the normal, often as a response to infection. [GOC:dph, GOC:jl]
Full description |

Standard name | GO_CONDITIONED_TASTE_AVERSION
Systematic name | M22177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A conditioned aversion to a specific chemical compound as a result of that compound being coupled with a noxious stimulus. [GOC:dph, PMID:9920659]
Full description |

Standard name | GO_AMEBOIDAL_TYPE_CELL_MIGRATION
Systematic name | M11839
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell migration that is accomplished by extension and retraction of a pseudopodium. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_CHROMATIN_ASSEMBLY_OR_DISASSEMBLY
Systematic name | M22178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of chromatin assembly or disassembly. [GOC:go_curators]
Full description |

Standard name | GO_ACROSOME_ASSEMBLY
Systematic name | M13681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of the acrosome from the spermatid Golgi. [GOC:dph, GOC:hjd, GOC:tb]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACID_METABOLIC_PROCESS
Systematic name | M11385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving long-chain fatty acids, A long-chain fatty acid is a fatty acid with a chain length between C13 and C22. [GOC:ajp]
Full description |

Standard name | GO_CELLULAR_GLUCOSE_HOMEOSTASIS
Systematic name | M14255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular homeostatic process involved in the maintenance of an internal steady state of glucose within a cell or between a cell and its external environment. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_TRNA_5_LEADER_REMOVAL
Systematic name | M22179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Generation of the mature 5'-end of the tRNA, usually via an endonucleolytic cleavage by RNase P. [PMID:11592395]
Full description |

Standard name | GO_HISTAMINE_METABOLIC_PROCESS
Systematic name | M34040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving histamine, a physiologically active amine, found in plant and animal tissue and released from mast cells as part of an allergic reaction in humans. [GOC:jl, ISBN:0395825172]
Full description |

Standard name | GO_GASTRIC_ACID_SECRETION
Systematic name | M22180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of gastric acid (hydrochloric acid) by parietal or oxyntic cells during digestion. [GOC:hjd]
Full description |

Standard name | GO_IN_UTERO_EMBRYONIC_DEVELOPMENT
Systematic name | M12544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the embryo in the uterus over time, from formation of the zygote in the oviduct, to birth. An example of this process is found in Mus musculus. [GOC:go_curators, GOC:mtg_sensu]
Full description |

Standard name | GO_GASTRULATION_WITH_MOUTH_FORMING_SECOND
Systematic name | M11702
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A gastrulation process in which the initial invagination becomes the anus and the mouth forms second. [GOC:go_curators, GOC:mtg_sensu]
Full description |

Standard name | GO_FORMATION_OF_PRIMARY_GERM_LAYER
Systematic name | M10670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of the ectoderm, mesoderm and endoderm during gastrulation. [GOC:go_curators]
Full description |

Standard name | GO_ENDODERM_FORMATION
Systematic name | M14962
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of the endoderm during gastrulation. [GOC:go_curators]
Full description |

Standard name | GO_CELL_FATE_SPECIFICATION
Systematic name | M15496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process involved in the specification of cell identity. Once specification has taken place, a cell will be committed to differentiate down a specific pathway if left in its normal environment. [GOC:go_curators]
Full description |

Standard name | GO_CELL_FATE_DETERMINATION
Systematic name | M14390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process involved in cell fate commitment. Once determination has taken place, a cell becomes committed to differentiate down a particular pathway regardless of its environment. [ISBN:0878932437]
Full description |

Standard name | GO_MESODERMAL_CELL_FATE_COMMITMENT
Systematic name | M16287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell differentiation process that results in commitment of a cell to become part of the mesoderm. [GOC:go_curators, ISBN:0878932437]
Full description |

Standard name | GO_ENDODERMAL_CELL_FATE_COMMITMENT
Systematic name | M16520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell differentiation process that results in commitment of a cell to become part of the endoderm. [GOC:go_curators, ISBN:0878932437]
Full description |

Standard name | GO_ENDODERMAL_CELL_FATE_SPECIFICATION
Systematic name | M22181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell fate determination process that results in a cell becoming capable of differentiating autonomously into an endoderm cell in an environment that is neutral with respect to the developmental pathway; upon specification, the cell fate can be reversed. [GOC:go_curators]
Full description |

Standard name | GO_FORMATION_OF_TRANSLATION_PREINITIATION_COMPLEX
Systematic name | M12715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The joining of the small ribosomal subunit, ternary complex, and mRNA. [GOC:hjd]
Full description |

Standard name | GO_FORMATION_OF_CYTOPLASMIC_TRANSLATION_INITIATION_COMPLEX
Systematic name | M22182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Joining of the large subunit, with release of IF2/eIF2 and IF3/eIF3. This leaves the functional ribosome at the AUG, with the methionyl/formyl-methionyl-tRNA positioned at the P site. [GOC:hjd]
Full description |

Standard name | GO_MORPHOGENESIS_OF_A_POLARIZED_EPITHELIUM
Systematic name | M14957
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphogenetic process in which the anatomical structures of a polarized epithelium are generated and organized. A polarized epithelium is an epithelium where the epithelial sheet is oriented with respect to the planar axis. [GOC:dph]
Full description |

Standard name | GO_EYE_PHOTORECEPTOR_CELL_DIFFERENTIATION
Systematic name | M12350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a photoreceptor cell, as found in the eye, the primary visual organ of most organisms. [GOC:go_curators]
Full description |

Standard name | GO_NEURAL_CREST_CELL_MIGRATION
Systematic name | M12364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The characteristic movement of cells from the dorsal ridge of the neural tube to a variety of locations in a vertebrate embryo. [GOC:ascb_2009, GOC:dph, GOC:tb, ISBN:0878932437]
Full description |

Standard name | GO_SOMITOGENESIS
Systematic name | M13075
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of mesodermal clusters that are arranged segmentally along the anterior posterior axis of an embryo. [ISBN:0721662544]
Full description |

Standard name | GO_SOMITE_SPECIFICATION
Systematic name | M22183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which individual somites establish identity during embryogenesis. [GOC:dph]
Full description |

Standard name | GO_ORGAN_INDUCTION
Systematic name | M13627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The interaction of two or more cells or tissues that causes them to change their fates and specify the development of an organ. [ISBN:0878932437]
Full description |

Standard name | GO_MORPHOGENESIS_OF_A_BRANCHING_STRUCTURE
Systematic name | M14729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of branches are generated and organized. A branch is a division or offshoot from a main stem. Examples in animals would include blood vessels, nerves, lymphatics and other endothelial or epithelial tubes. [ISBN:0721662544]
Full description |

Standard name | GO_NEURON_MIGRATION
Systematic name | M13864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The characteristic movement of an immature neuron from germinal zones to specific positions where they will reside as they mature. [CL:0000540, GOC:go_curators]
Full description |

Standard name | GO_MEMBRANE_RAFT_ASSEMBLY
Systematic name | M22184
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a membrane raft, a small (10-200 nm), heterogeneous, highly dynamic, sterol- and sphingolipid-enriched membrane domains that compartmentalizes cellular processes. [PMID:12648772, PMID:12803918, PMID:16645198]
Full description |

Standard name | GO_ESTABLISHMENT_OF_LYMPHOCYTE_POLARITY
Systematic name | M22185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed orientation of lymphocyte signaling molecules and associated membrane rafts towards a chemokine gradient or a contact point with an appropriate activating cell. [GOC:mgi_curators, PMID:11244041, PMID:12615889]
Full description |

Standard name | GO_IMMUNOLOGICAL_SYNAPSE_FORMATION
Systematic name | M16118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of an area of close contact between a lymphocyte (T-, B-, or natural killer cell) and a target cell through the clustering of particular signaling and adhesion molecules and their associated membrane rafts on both the lymphocyte and target cell, which facilitates activation of the lymphocyte, transfer of membrane from the target cell to the lymphocyte, and in some situations killing of the target cell through release of secretory granules and/or death-pathway ligand-receptor interaction. [GOC:mgi_curators, PMID:11244041, PMID:11376330]
Full description |

Standard name | GO_MYELOID_DENDRITIC_CELL_ACTIVATION
Systematic name | M16283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a dendritic cell resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. [GOC:mgi_curators, ISBN:0781735149]
Full description |

Standard name | GO_CELL_ACTIVATION
Systematic name | M6709
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in the morphology or behavior of a cell resulting from exposure to an activating factor such as a cellular or soluble ligand. [GOC:mgi_curators]
Full description |

Standard name | GO_LEUKOCYTE_HOMEOSTASIS
Systematic name | M16788
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of regulating the proliferation and elimination of cells of the immune system such that the total number of cells of a particular cell type within a whole or part of an organism is stable over time in the absence of an outside stimulus. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_PLASMA_MEMBRANE_REPAIR
Systematic name | M22186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The resealing of a cell plasma membrane after cellular wounding due to, for instance, mechanical stress. [GOC:add, PMID:12925704]
Full description |

Standard name | GO_NATURAL_KILLER_CELL_DIFFERENTIATION
Systematic name | M10359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a natural killer cell. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_NEUTROPHIL_HOMEOSTASIS
Systematic name | M22187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of regulating the proliferation and elimination of neutrophils such that the total number of neutrophils within a whole or part of an organism is stable over time in the absence of an outside stimulus. [GOC:add, GOC:pr, PMID:12752675, PMID:12960266]
Full description |

Standard name | GO_NEUTROPHIL_APOPTOTIC_PROCESS
Systematic name | M22188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a neutrophil, any of the immature or mature forms of a granular leukocyte that in its mature form has a nucleus with three to five lobes connected by slender threads of chromatin, and cytoplasm containing fine inconspicuous granules and stainable by neutral dyes. [CL:0000775, GOC:add, GOC:mtg_apoptosis, PMID:12752675, PMID:12960266]
Full description |

Standard name | GO_B_CELL_HOMEOSTASIS
Systematic name | M10425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of regulating the proliferation and elimination of B cells such that the total number of B cells within a whole or part of an organism is stable over time in the absence of an outside stimulus. [GOC:add, ISBN:0781735149, PMID:12956429]
Full description |

Standard name | GO_B_CELL_APOPTOTIC_PROCESS
Systematic name | M22189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a B cell, a lymphocyte of B lineage with the phenotype CD19-positive and capable of B cell mediated immunity. [CL:0000236, GOC:add, GOC:mtg_apoptosis, ISBN:0781735149]
Full description |

Standard name | GO_NATURAL_KILLER_CELL_PROLIFERATION
Systematic name | M22190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a natural killer cell population by cell division. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_CYTOKINE_PRODUCTION
Systematic name | M13156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of a cytokine due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYTOKINE_PRODUCTION
Systematic name | M16054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the rate of production of a cytokine. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOKINE_PRODUCTION
Systematic name | M11373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of production of a cytokine. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_SEROTONIN_SECRETION
Systematic name | M22191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of serotonin by a cell. Serotonin (5-hydroxytryptamine, or 5-HT) is a monoamine synthesised in serotonergic neurons in the central nervous system, enterochromaffin cells in the gastrointestinal tract and some immune system cells. [GOC:ef, ISBN:0198506732, ISBN:0781735149]
Full description |

Standard name | GO_HISTAMINE_SECRETION
Systematic name | M34041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of histamine by a cell or tissue. It is formed by decarboxylation of histidine and it acts through receptors in smooth muscle and in secretory systems. [GOC:mah, ISBN:0198506732, ISBN:0781735149]
Full description |

Standard name | GO_MESONEPHROS_DEVELOPMENT
Systematic name | M16285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the mesonephros over time, from its formation to the mature structure. In mammals, the mesonephros is the second of the three embryonic kidneys to be established and exists only transiently. In lower vertebrates such as fish and amphibia, the mesonephros will form the mature kidney. [GOC:dph, ISBN:0124020607, ISBN:0721662544, PMID:10535314]
Full description |

Standard name | GO_BLASTOCYST_DEVELOPMENT
Systematic name | M13548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the blastocyst over time, from its formation to the mature structure. The mammalian blastocyst is a hollow ball of cells containing two cell types, the inner cell mass and the trophectoderm. [GOC:dph, ISBN:0124020607, ISBN:0198542771]
Full description |

Standard name | GO_BLASTOCYST_FORMATION
Systematic name | M11531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial formation of a blastocyst from a solid ball of cells known as a morula. [GOC:dph, ISBN:0124020607, ISBN:0198542771]
Full description |

Standard name | GO_INNER_CELL_MASS_CELL_DIFFERENTIATION
Systematic name | M22192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of an inner cell mass cell. [GOC:dph, ISBN:0124020607, ISBN:0198542771]
Full description |

Standard name | GO_TROPHECTODERMAL_CELL_DIFFERENTIATION
Systematic name | M15352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a trophectoderm cell. [GOC:dph, ISBN:0124020607, ISBN:0198542771]
Full description |

Standard name | GO_BLASTOCYST_GROWTH
Systematic name | M15169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An increase in size of a blastocyst due to expansion of the blastocoelic cavity cell shape changes and cell proliferation. [GOC:dph, ISBN:0124020607, ISBN:0198542771]
Full description |

Standard name | GO_INNER_CELL_MASS_CELL_PROLIFERATION
Systematic name | M12152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The proliferation of cells in the inner cell mass. [GOC:dph, GOC:isa_complete, ISBN:0124020607, ISBN:0198542771]
Full description |

Standard name | GO_RELEASE_OF_CYTOCHROME_C_FROM_MITOCHONDRIA
Systematic name | M13434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in the movement of cytochrome c from the mitochondrial intermembrane space into the cytosol, which is part of the apoptotic signaling pathway and leads to caspase activation. [GOC:add, GOC:mah, GOC:mtg_apoptosis, ISBN:0721639976, PMID:12925707, PMID:9560217]
Full description |

Standard name | GO_EPITHELIAL_TO_MESENCHYMAL_TRANSITION
Systematic name | M817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A transition where an epithelial cell loses apical/basolateral polarity, severs intercellular adhesive junctions, degrades basement membrane components and becomes a migratory mesenchymal cell. [GOC:dph, PMID:14701881]
Full description |

Standard name | GO_NEURAL_PLATE_MORPHOGENESIS
Systematic name | M22193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the neural plate are generated and organized. The neural plate is a specialized region of columnar epithelial cells in the dorsal ectoderm that will give rise to nervous system tissue. [GOC:dph, ISBN:0878932437]
Full description |

Standard name | GO_NEURAL_PLATE_DEVELOPMENT
Systematic name | M22194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the neural plate over time, from its formation to the mature structure. The neural plate is a flat, thickened layer of ectodermal cells. The underlying dorsal mesoderm signals the ectodermal cells above it to elongate into columnar neural plate cells. The neural plate subsequently develops into the neural tube, which gives rise to the central nervous system. [GOC:dph, GOC:ef, ISBN:0878932437, ISBN:0878932585]
Full description |

Standard name | GO_NEURAL_TUBE_FORMATION
Systematic name | M15370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a tube from the flat layer of ectodermal cells known as the neural plate. This will give rise to the central nervous system. [GOC:dph, ISBN:0878932437]
Full description |

Standard name | GO_NEURAL_FOLD_FORMATION
Systematic name | M22195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the neural fold is formed. The edges of the neural plate thicken and move up to form a U-shaped structure called the neural groove. [GOC:dph, ISBN:0878932437]
Full description |

Standard name | GO_PROTEIN_INSERTION_INTO_MITOCHONDRIAL_MEMBRANE_INVOLVED_IN_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M22196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a protein is incorporated into a mitochondrial membrane as the initial phase of the mitochondrial membrane permeabilization that takes place in the apoptotic signaling pathway. [GOC:add, GOC:mtg_apoptosis, PMID:12952892]
Full description |

Standard name | GO_PHAGOLYSOSOME_ASSEMBLY
Systematic name | M11887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in the fusion of a phagosome, a vesicle formed by phagocytosis, with a lysosome. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_NK_T_CELL_DIFFERENTIATION
Systematic name | M22197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of a NK T cell. [GOC:add, ISBN:0781735149, PMID:10704459]
Full description |

Standard name | GO_NK_T_CELL_PROLIFERATION
Systematic name | M22198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a NK T cell population by cell division. [GOC:add, ISBN:0781735149, PMID:10704459]
Full description |

Standard name | GO_COMPLEMENT_ACTIVATION_LECTIN_PATHWAY
Systematic name | M22199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the activation of any of the steps of the lectin pathway of the complement cascade which allows for the direct killing of microbes and the regulation of other immune processes. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_RECEPTOR_RECYCLING
Systematic name | M22200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in the return of receptor molecules to an active state and an active cellular location after they have been stimulated by a ligand. An active state is when the receptor is ready to receive a signal. [GOC:dph]
Full description |

Standard name | GO_ENDOTHELIAL_CELL_DEVELOPMENT
Systematic name | M10104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of an endothelial cell over time, from its formation to the mature structure. [GOC:dph]
Full description |

Standard name | GO_ENDOTHELIAL_CELL_MORPHOGENESIS
Systematic name | M22201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in form (cell shape and size) that occurs during the differentiation of an endothelial cell. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_SELENIUM_COMPOUND_METABOLIC_PROCESS
Systematic name | M22202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving compounds that contain selenium, such as selenocysteine. [PMID:12730456]
Full description |

Standard name | GO_PLACENTA_DEVELOPMENT
Systematic name | M15526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the placenta over time, from its formation to the mature structure. The placenta is an organ of metabolic interchange between fetus and mother, partly of embryonic origin and partly of maternal origin. [GOC:add, ISBN:068340007X]
Full description |

Standard name | GO_EMBRYONIC_PLACENTA_DEVELOPMENT
Systematic name | M12216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The embryonically driven process whose specific outcome is the progression of the placenta over time, from its formation to the mature structure. The placenta is an organ of metabolic interchange between fetus and mother, partly of embryonic origin and partly of maternal origin. [GOC:add, ISBN:068340007X]
Full description |

Standard name | GO_MATERNAL_PLACENTA_DEVELOPMENT
Systematic name | M15972
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Maternally driven process whose specific outcome is the progression of the placenta over time, from its formation to the mature structure. The placenta is an organ of metabolic interchange between fetus and mother, partly of embryonic origin and partly of maternal origin. [GOC:add, ISBN:068340007X]
Full description |

Standard name | GO_TISSUE_HOMEOSTASIS
Systematic name | M11334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A homeostatic process involved in the maintenance of an internal steady state within a defined tissue of an organism, including control of cellular proliferation and death and control of metabolic function. [GOC:add, GOC:isa_complete]
Full description |

Standard name | GO_RETINA_HOMEOSTASIS
Systematic name | M15299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A tissue homeostatic process involved in the maintenance of an internal equilibrium within the retina of the eye, including control of cellular proliferation and death and control of metabolic function. [GOC:add, GOC:dph, GOC:tb, PMID:15365173, PMID:15365178]
Full description |

Standard name | GO_CELL_KILLING
Systematic name | M15770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in an organism that results in the killing of its own cells or those of another organism, including in some cases the death of the other organism. Killing here refers to the induction of death in one cell by another cell, not cell-autonomous death due to internal or other environmental conditions. [GOC:add]
Full description |

Standard name | GO_LEUKOCYTE_MEDIATED_CYTOTOXICITY
Systematic name | M11242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed killing of a target cell by a leukocyte. [GO_REF:0000022, GOC:add, ISBN:0781735149, PMID:11911826]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_MEDIATED_CYTOTOXICITY
Systematic name | M29012
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of leukocyte mediated cytotoxicity. [GOC:add, ISBN:0781735149, PMID:11911826]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LEUKOCYTE_MEDIATED_CYTOTOXICITY
Systematic name | M29013
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the rate of leukocyte mediated cytotoxicity. [GOC:add, ISBN:0781735149, PMID:11911826]
Full description |

Standard name | GO_T_CELL_MEDIATED_CYTOTOXICITY
Systematic name | M22203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed killing of a target cell by a T cell through the release of granules containing cytotoxic mediators or through the engagement of death receptors. [GOC:add, GOC:pr, ISBN:0781735149, PMID:11911826]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_MEDIATED_CYTOTOXICITY
Systematic name | M12991
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of T cell mediated cytotoxicity. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_CELL_MEDIATED_CYTOTOXICITY
Systematic name | M22204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the rate of T cell mediated cytotoxicity. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_CELL_MEDIATED_CYTOTOXICITY
Systematic name | M12145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of T cell mediated cytotoxicity. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_RECEPTOR_RECYCLING
Systematic name | M15712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of receptor recycling. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RECEPTOR_RECYCLING
Systematic name | M16264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of receptor recycling. [GOC:add]
Full description |

Standard name | GO_B_1_B_CELL_DIFFERENTIATION
Systematic name | M22205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a hemopoietic stem cell acquires the specialized features of a B-1 B cell. B-1 B cells are a distinct subset of B cells characterized as being CD5 positive, found predominantly in the peritoneum, pleural cavities, and spleen, and enriched for self-reactivity. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_ENDOTHELIAL_CELL_PROLIFERATION
Systematic name | M3696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of endothelial cells, resulting in the expansion of a cell population. Endothelial cells are thin flattened cells which line the inside surfaces of body cavities, blood vessels, and lymph vessels, making up the endothelium. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ENDOTHELIAL_CELL_PROLIFERATION
Systematic name | M15272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the rate or extent of endothelial cell proliferation. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOTHELIAL_CELL_PROLIFERATION
Systematic name | M15832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of endothelial cell proliferation. [GOC:add]
Full description |

Standard name | GO_POSTSYNAPTIC_MEMBRANE_ORGANIZATION
Systematic name | M13157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process which results in the assembly, arrangement of constituent parts, or disassembly of a postsynaptic membrane, the specialized area of membrane facing the presynaptic membrane on the tip of the nerve ending and separated from it by a minute cleft (the synaptic cleft). [GOC:dph, GOC:pr]
Full description |

Standard name | GO_VASCULATURE_DEVELOPMENT
Systematic name | M4002
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the vasculature over time, from its formation to the mature structure. The vasculature is an interconnected tubular multi-tissue structure that contains fluid that is actively transported around the organism. [GOC:dph, UBERON:0002409]
Full description |

Standard name | GO_LYMPH_VESSEL_DEVELOPMENT
Systematic name | M15779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a lymph vessel over time, from its formation to the mature structure. [GOC:dph, UBERON:0001473]
Full description |

Standard name | GO_LYMPHANGIOGENESIS
Systematic name | M12830
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Lymph vessel formation when new vessels emerge from the proliferation of pre-existing vessels. [GOC:dph, PMID:11596157]
Full description |

Standard name | GO_REGULATION_OF_CELL_MATRIX_ADHESION
Systematic name | M15173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of attachment of a cell to the extracellular matrix. [GOC:hjd]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_MATRIX_ADHESION
Systematic name | M12466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the rate or extent of cell adhesion to the extracellular matrix. [GOC:hjd]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_MATRIX_ADHESION
Systematic name | M12172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of cell adhesion to an extracellular matrix. [GOC:hjd]
Full description |

Standard name | GO_BLOOD_VESSEL_MATURATION
Systematic name | M22206
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for a blood vessel to attain its fully functional state. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEUROTRANSMITTER_SECRETION
Systematic name | M13827
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the regulated release of a neurotransmitter. [GOC:hjd]
Full description |

Standard name | GO_SYNAPTIC_TRANSMISSION_DOPAMINERGIC
Systematic name | M13418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The vesicular release of dopamine. from a presynapse, across a chemical synapse, the subsequent activation of dopamine receptors at the postsynapse of a target cell (neuron, muscle, or secretory cell) and the effects of this activation on the postsynaptic membrane potential and ionic composition of the postsynaptic cytosol. This process encompasses both spontaneous and evoked release of neurotransmitter and all parts of synaptic vesicle exocytosis. Evoked transmission starts with the arrival of an action potential at the presynapse. [GOC:dos, GOC:dph]
Full description |

Standard name | GO_STARTLE_RESPONSE
Systematic name | M12157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An action or movement due to the application of a sudden unexpected stimulus. [GOC:dph]
Full description |

Standard name | GO_SUCKLING_BEHAVIOR
Systematic name | M10981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Specific behavior of a newborn or infant mammal that results in the derivation of nourishment from the breast. [GOC:dph, GOC:pr]
Full description |

Standard name | GO_BLOOD_VESSEL_REMODELING
Systematic name | M14110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The reorganization or renovation of existing blood vessels. [GOC:hjd]
Full description |

Standard name | GO_RESPONSE_TO_AMPHETAMINE
Systematic name | M12946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an amphetamine stimulus. Amphetamines consist of a group of compounds related to alpha-methylphenethylamine. [GOC:dph, GOC:ef]
Full description |

Standard name | GO_NERVOUS_SYSTEM_PROCESS_INVOLVED_IN_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE
Systematic name | M14150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulation of blood pressure mediated by detection of stimuli and a neurological response. [GOC:mtg_cardio, ISBN:0721643949]
Full description |

Standard name | GO_RENAL_SYSTEM_PROCESS_INVOLVED_IN_REGULATION_OF_BLOOD_VOLUME
Systematic name | M10872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A slow mechanism of blood pressure regulation that responds to changes in pressure resulting from fluid and salt intake by modulating the quantity of blood in the circulatory system. [GOC:dph, GOC:tb, ISBN:0721643949]
Full description |

Standard name | GO_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE_BY_HORMONE
Systematic name | M16299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which hormones modulate the force with which blood passes through the circulatory system. A hormone is one of a group of substances formed in very small amounts in one specialized organ or group of cells and carried (sometimes in the bloodstream) to another organ or group of cells, in the same organism, upon which they have a specific regulatory action. [GOC:mtg_cardio, ISBN:0721643949]
Full description |

Standard name | GO_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE_BY_CIRCULATORY_RENIN_ANGIOTENSIN
Systematic name | M10423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which angiotensinogen metabolites in the bloodstream modulate the force with which blood passes through the circulatory system. The process begins when renin is released and cleaves angiotensinogen. [ISBN:0721643949]
Full description |

Standard name | GO_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE_BY_VASOPRESSIN
Systematic name | M22208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulation of blood pressure mediated by the signaling molecule vasopressin. Vasopressin is produced in the hypothalamus, and affects vasoconstriction, and renal water transport. [GOC:mtg_cardio, ISBN:0721643949]
Full description |

Standard name | GO_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE_BY_NOREPINEPHRINE_EPINEPHRINE
Systematic name | M22209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the secretion of norepinephrine or epinephrine into the bloodstream modulates the force with which blood passes through the circulatory system. [ISBN:0721643949]
Full description |

Standard name | GO_RENIN_SECRETION_INTO_BLOOD_STREAM
Systematic name | M34042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of renin into the blood stream by juxtoglomerular cells. [ISBN:0721643949]
Full description |

Standard name | GO_REGULATION_OF_ANGIOTENSIN_LEVELS_IN_BLOOD
Systematic name | M22211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that modulates the level of any of the various angiotensinogen proteolytic products in the blood. This occurs by the proteolytic cleavage of angiotensinogen, and its proteolytic products, to create a variety of active peptide hormones, such as angiotensin I and angiotensin II, as well as through the removal of these peptides from the circulation. [GOC:rl, PMID:21951628, Wikipedia:Angiotensin]
Full description |

Standard name | GO_MORPHOGENESIS_OF_AN_EPITHELIUM
Systematic name | M10083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of epithelia are generated and organized. An epithelium consists of closely packed cells arranged in one or more layers, that covers the outer surfaces of the body or lines any internal cavity or tube. [GOC:dph, GOC:jl, GOC:tb, ISBN:0198506732]
Full description |

Standard name | GO_MORPHOGENESIS_OF_AN_EPITHELIAL_SHEET
Systematic name | M13139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of an epithelial sheet are generated and organized. An epithelial sheet is a flat surface consisting of closely packed epithelial cells. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_BLOOD_VOLUME_BY_RENIN_ANGIOTENSIN
Systematic name | M15949
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the renin-angiotensin system controls the rate of fluid intake and output into the blood. [GOC:dph, GOC:mtg_cardio, GOC:tb, ISBN:0721643949]
Full description |

Standard name | GO_RESPONSE_TO_DIETARY_EXCESS
Systematic name | M10800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The physiological process in which dietary excess is sensed by the central nervous system, resulting in a reduction in food intake and increased energy expenditure. [GOC:pg, GOC:pr, PMID:12161655]
Full description |

Standard name | GO_REDUCTION_OF_FOOD_INTAKE_IN_RESPONSE_TO_DIETARY_EXCESS
Systematic name | M22212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An eating behavior process whereby detection of a dietary excess results in a decrease in intake of nutrients. [GOC:pg, GOC:pr, PMID:12161655, PMID:12840200]
Full description |

Standard name | GO_DIET_INDUCED_THERMOGENESIS
Systematic name | M22213
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in increased metabolic rate in tissues of an organism. It is triggered by the detection of dietary excess. This process is achieved via signalling in the sympathetic nervous system. [PMID:12161655]
Full description |

Standard name | GO_REGULATION_OF_THE_FORCE_OF_HEART_CONTRACTION
Systematic name | M13092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the extent of heart contraction, changing the force with which blood is propelled. [GOC:dph, GOC:tb, PMID:10358008]
Full description |

Standard name | GO_REGULATION_OF_HEART_RATE
Systematic name | M13192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency or rate of heart contraction. [GOC:dph, GOC:tb, PMID:10358008]
Full description |

Standard name | GO_REGULATION_OF_SODIUM_ION_TRANSPORT
Systematic name | M11902
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of sodium ions (Na+) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:dph]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_RECEPTOR_INTERNALIZATION
Systematic name | M10096
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in the uptake of a G protein-coupled receptor into an endocytic vesicle. [PMID:8396717]
Full description |

Standard name | GO_REGULATION_OF_L_GLUTAMATE_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M22214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of L-glutamate import into a cell. [GOC:TermGenie]
Full description |

Standard name | GO_SPROUTING_ANGIOGENESIS
Systematic name | M12499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The extension of new blood vessels from existing vessels into avascular tissues, this process includes the specialization of endothelial cells into leading tip and stalk cells, proliferation and migration of the endothelial cells and cell adhesion resulting in angiogenic sprout fusion or lumen formation. [PMID:16391003, PMID:23031691]
Full description |

Standard name | GO_CELL_MIGRATION_INVOLVED_IN_SPROUTING_ANGIOGENESIS
Systematic name | M11055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of endothelial cells into the extracellular matrix in order to form new blood vessels involved in sprouting angiogenesis. [PMID:16391003]
Full description |

Standard name | GO_BLOOD_VESSEL_ENDOTHELIAL_CELL_PROLIFERATION_INVOLVED_IN_SPROUTING_ANGIOGENESIS
Systematic name | M22215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of blood vessel endothelial cells, resulting in the expansion of a cell population contributing to sprouting angiogenesis. [GOC:dph, GOC:tb, PMID:16391003]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEUROBLAST_PROLIFERATION
Systematic name | M11631
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate of neuroblast proliferation. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MESENCHYMAL_CELL_PROLIFERATION
Systematic name | M15138
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of activating or increasing the rate or extent of mesenchymal cell proliferation. Mesenchymal cells are loosely organized embryonic cells. [GOC:dph]
Full description |

Standard name | GO_CHONDROCYTE_DIFFERENTIATION
Systematic name | M13053
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a chondroblast acquires specialized structural and/or functional features of a chondrocyte. A chondrocyte is a polymorphic cell that forms cartilage. [GOC:dph]
Full description |

Standard name | GO_CHONDROCYTE_DEVELOPMENT
Systematic name | M11483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a chondrocyte over time, from its commitment to its mature state. Chondrocyte development does not include the steps involved in committing a chondroblast to a chondrocyte fate. [GOC:dph]
Full description |

Standard name | GO_EPITHELIAL_CELL_DEVELOPMENT
Systematic name | M10678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an epithelial cell over time, from its formation to the mature structure. An epithelial cell is a cell usually found in a two-dimensional sheet with a free surface. [GOC:dph]
Full description |

Standard name | GO_COLUMNAR_CUBOIDAL_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M14185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a columnar/cuboidal epithelial cell. A columnar/cuboidal epithelial cell is a cell usually found in a two dimensional sheet with a free surface. Columnar/cuboidal epithelial cells take on the shape of a column or cube. [GOC:dph]
Full description |

Standard name | GO_COLUMNAR_CUBOIDAL_EPITHELIAL_CELL_DEVELOPMENT
Systematic name | M14021
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a columnar/cuboidal epithelial cell over time, from its formation to the mature structure. A columnar/cuboidal epithelial cell is a cell usually found in a two dimensional sheet with a free surface. Columnar/cuboidal epithelial cells take on the shape of a column or cube. [GOC:dph]
Full description |

Standard name | GO_GLANDULAR_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M16936
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a glandular epithelial cell. A glandular epithelial cell is a columnar/cuboidal epithelial cell found in a two dimensional sheet with a free surface exposed to the lumen of a gland. [GOC:dph]
Full description |

Standard name | GO_GLANDULAR_EPITHELIAL_CELL_DEVELOPMENT
Systematic name | M12098
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a glandular epithelial cell over time, from its formation to the mature structure. A glandular epithelial cell is a columnar/cuboidal epithelial cell is a cell found in a two dimensional sheet with a free surface exposed to the lumen of a gland. [GOC:dph]
Full description |

Standard name | GO_COLUMNAR_CUBOIDAL_EPITHELIAL_CELL_MATURATION
Systematic name | M22216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process, independent of morphogenetic (shape) change, that is required for a columna/cuboidal epithelial cell to attain its fully functional state. A columnar/cuboidal epithelial cell is a cell usually found in a two dimensional sheet with a free surface. Columnar/cuboidal epithelial cells take on the shape of a column or cube. [GOC:dph]
Full description |

Standard name | GO_EPITHELIAL_CELL_MATURATION
Systematic name | M16225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process, independent of morphogenetic (shape) change, that is required for an epithelial cell to attain its fully functional state. An epithelial cell is a cell usually found in a two-dimensional sheet with a free surface. [GOC:dph]
Full description |

Standard name | GO_OPTIC_CUP_MORPHOGENESIS_INVOLVED_IN_CAMERA_TYPE_EYE_DEVELOPMENT
Systematic name | M22217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The invagination of the optic vesicle to form two-walled indentations, the optic cups, that will go on to form the retina. This process begins with the optic vesicle becoming a two-walled structure and its subsequent shape changes. It does not include the fate commitment of cells to become the pigmented retina and the neural retina. An example of this process is found in Mus musculus. [GOC:dph, GOC:mtg_sensu, GOC:sdb_2009, GOC:tb, ISBN:0878932437]
Full description |

Standard name | GO_OSTEOBLAST_DEVELOPMENT
Systematic name | M15119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an osteoblast over time, from its formation to the mature structure. Osteoblast development does not include the steps involved in committing a cranial neural crest cell or an osteoprogenitor cell to an osteoblast fate. An osteoblast is a cell that gives rise to bone. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_OXIDATIVE_PHOSPHORYLATION
Systematic name | M12136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the phosphorylation of ADP to ATP that accompanies the oxidation of a metabolite through the operation of the respiratory chain. Oxidation of compounds establishes a proton gradient across the membrane, providing the energy for ATP synthesis. [GOC:dph]
Full description |

Standard name | GO_PROTEIN_DEPALMITOYLATION
Systematic name | M34043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of palymitoyl groups from a lipoprotein. [GOC:hjd]
Full description |

Standard name | GO_INHIBITION_OF_NEUROEPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M29016
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that prevents the activation of neuroepithelial cell differentiation. Neuroepithelial cell differentiation is the process in which epiblast cells acquire specialized features of neuroepithelial cells. [GOC:dph, PMID:16678814]
Full description |

Standard name | GO_REGULATION_OF_RESPIRATORY_GASEOUS_EXCHANGE_BY_NERVOUS_SYSTEM_PROCESS
Systematic name | M11118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process carried out by the nervous system that is required for the proper control of respiratory gaseous exchange. This process occurs in the respiratory center of the brain in vertebrates. [GOC:dph, GOC:tb, PMID:12458206]
Full description |

Standard name | GO_LENS_DEVELOPMENT_IN_CAMERA_TYPE_EYE
Systematic name | M16757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the lens over time, from its formation to the mature structure. The lens is a transparent structure in the eye through which light is focused onto the retina. An example of this process is found in Mus musculus. [GOC:dph, ISBN:0582064333]
Full description |

Standard name | GO_LENS_MORPHOGENESIS_IN_CAMERA_TYPE_EYE
Systematic name | M15529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the lens are generated and organized. The lens is a transparent structure in the eye through which light is focused onto the retina. An example of this process is found in Mus musculus. [GOC:dph, GOC:mtg_sensu]
Full description |

Standard name | GO_REGULATION_OF_RECEPTOR_INTERNALIZATION
Systematic name | M12639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of receptor internalization. [GOC:hjd]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RECEPTOR_INTERNALIZATION
Systematic name | M22218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of receptor internalization. [GOC:hjd]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RECEPTOR_INTERNALIZATION
Systematic name | M13693
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of receptor internalization. [GOC:hjd]
Full description |

Standard name | GO_AUDITORY_RECEPTOR_CELL_MORPHOGENESIS
Systematic name | M16661
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that alters the size or shape of an auditory receptor cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_TRNA_WOBBLE_BASE_MODIFICATION
Systematic name | M22219
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the nucleotide at position 34 in the anticodon of a tRNA is post-transcriptionally modified. [GOC:hjd, ISBN:155581073X]
Full description |

Standard name | GO_TRNA_WOBBLE_URIDINE_MODIFICATION
Systematic name | M22220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a uridine in position 34 of a tRNA is post-transcriptionally modified. [GOC:hjd, ISBN:155581073X]
Full description |

Standard name | GO_STORE_OPERATED_CALCIUM_ENTRY
Systematic name | M22221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A calcium ion entry mechanism in the plasma membrane activated by the depletion of calcium ion from the internal calcium ion store in the endoplasmic reticulum. [GOC:hjd, PMID:11120592, PMID:17956991]
Full description |

Standard name | GO_AGGRESSIVE_BEHAVIOR
Systematic name | M22222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A behavioral interaction between organisms in which one organism has the intention of inflicting physical damage on another individual. [GOC:hjd]
Full description |

Standard name | GO_THYROID_HORMONE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M22223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by the detection of a thyroid hormone. [GOC:hjd]
Full description |

Standard name | GO_REGULATION_OF_THYROID_HORMONE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M22224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a thyroid hormone mediated signaling pathway. [GOC:hjd]
Full description |

Standard name | GO_OSTEOCLAST_PROLIFERATION
Systematic name | M22225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of osteoclasts, resulting in the expansion of an osteoclast cell population. An osteoclast is a specialized phagocytic cell associated with the absorption and removal of the mineralized matrix of bone tissue, which typically differentiates from monocytes. [CL:0000092, GOC:hjd]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_PARANODE_REGION_OF_AXON
Systematic name | M22226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular protein localization process in which a protein is transported to, or maintained at, the paranode region of an axon. [PMID:18803321]
Full description |

Standard name | GO_CYTOPLASMIC_TRANSLATION
Systematic name | M10085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a protein in the cytoplasm. This is a ribosome-mediated process in which the information in messenger RNA (mRNA) is used to specify the sequence of amino acids in the protein. [GOC:hjd]
Full description |

Standard name | GO_CYTOPLASMIC_TRANSLATIONAL_ELONGATION
Systematic name | M22227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The successive addition of amino acid residues to a nascent polypeptide chain during protein biosynthesis in the cytoplasm. [GOC:hjd]
Full description |

Standard name | GO_CYTOPLASMIC_TRANSLATIONAL_INITIATION
Systematic name | M13161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process preceding formation of the peptide bond between the first two amino acids of a protein in the cytoplasm. This includes the formation of a complex of the ribosome, mRNA or circRNA, and an initiation complex that contains the first aminoacyl-tRNA. [GOC:hjd]
Full description |

Standard name | GO_CAP_INDEPENDENT_TRANSLATIONAL_INITIATION
Systematic name | M22228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process where translation initiation recruits the 40S ribosomal subunits in a Cap and 5' end independent fashion before an AUG codon is encountered in an appropriate sequence context to initiate mRNA or circRNA translation. [PMID:17284590]
Full description |

Standard name | GO_SOMATIC_DIVERSIFICATION_OF_IMMUNE_RECEPTORS
Systematic name | M13638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The somatic process allowing for the production of immune receptors whose specificity is not encoded in the germline genomic sequences. [GOC:add, ISBN:0781735149, PMID:16102575, PMID:16166509]
Full description |

Standard name | GO_ACTIVATION_OF_INNATE_IMMUNE_RESPONSE
Systematic name | M15340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates an innate immune response. Innate immune responses are defense responses mediated by germline encoded components that directly recognize components of potential pathogens. Examples of this process include activation of the hypersensitive response of Arabidopsis thaliana and activation of any NOD or TLR signaling pathway in vertebrate species. [GO_REF:0000022, GOC:add, GOC:mtg_sensu, ISBN:0781735149, PMID:15199967, PMID:16177805]
Full description |

Standard name | GO_PATTERN_RECOGNITION_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of a pattern recognition receptor (PRR) binding to one of its physiological ligands. PRRs bind pathogen-associated molecular pattern (PAMPs), structures conserved among microbial species, or damage-associated molecular pattern (DAMPs), endogenous molecules released from damaged cells. [GOC:add, GOC:ar, ISBN:0781735149, PMID:15199967]
Full description |

Standard name | GO_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11996
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of binding to a toll-like receptor. Toll-like receptors directly bind pattern motifs from a variety of microbial sources to initiate innate immune response. [GO_REF:0000022, GOC:add, ISBN:0781735149, PMID:12467241, PMID:12524386, PMID:12855817, PMID:15585605, PMID:15728447]
Full description |

Standard name | GO_INNATE_IMMUNE_RESPONSE_IN_MUCOSA
Systematic name | M12958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process of the innate immune response that takes place in the mucosal tissues. [GOC:add, PMID:10719665, PMID:15971105]
Full description |

Standard name | GO_NATURAL_KILLER_CELL_MEDIATED_IMMUNITY
Systematic name | M13937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The promotion of an immune response by natural killer cells through direct recognition of target cells or through the release of cytokines. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DEFENSE_RESPONSE_TO_VIRUS_BY_HOST
Systematic name | M22229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any host process that results in the promotion of antiviral immune response mechanisms, thereby limiting viral replication. [GOC:add, GOC:dph, GOC:tb, ISBN:0781735149]
Full description |

Standard name | GO_LEUKOCYTE_CHEMOTAXIS_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M29017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of an immune cell in response to an external stimulus contributing to an inflammatory response. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_RESPONSE_TO_MOLECULE_OF_BACTERIAL_ORIGIN
Systematic name | M16728
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus by molecules of bacterial origin such as peptides derived from bacterial flagellin. [GOC:rl, GOC:sm]
Full description |

Standard name | GO_HEMATOPOIETIC_PROGENITOR_CELL_DIFFERENTIATION
Systematic name | M10180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which precursor cell type acquires the specialized features of a hematopoietic progenitor cell, a class of cell types including myeloid progenitor cells and lymphoid progenitor cells. [GOC:add, GOC:rl, ISBN:0781735149, PMID:16551251]
Full description |

Standard name | GO_WOUND_HEALING_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M22230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events that restore integrity to damaged tissue that contribute to an inflammatory response. [GOC:jal, ISBN:0721601871]
Full description |

Standard name | GO_LYMPHOCYTE_ANERGY
Systematic name | M34044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process contributing to lymphocyte anergy, a state of functional inactivation. [GOC:add]
Full description |

Standard name | GO_ADAPTIVE_IMMUNE_RESPONSE
Systematic name | M13847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response mediated by cells expressing specific receptors for antigen produced through a somatic diversification process, and allowing for an enhanced secondary response to subsequent exposures to the same antigen (immunological memory). [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_ORGAN_OR_TISSUE_SPECIFIC_IMMUNE_RESPONSE
Systematic name | M11805
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response taking place in an organ or tissues such as the liver, brain, mucosa, or nervous system tissues. [GO_REF:0000022, GOC:jal]
Full description |

Standard name | GO_IMMUNE_EFFECTOR_PROCESS
Systematic name | M14818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process of the immune system that can potentially contribute to an immune response. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_ACTIVATION_OF_IMMUNE_RESPONSE
Systematic name | M19789
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates an immune response. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_LYMPHOCYTE_HOMEOSTASIS
Systematic name | M11008
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of regulating the proliferation and elimination of lymphocytes such that the total number of lymphocytes within a whole or part of an organism is stable over time in the absence of an outside stimulus. [GOC:add, PMID:15826826, PMID:16319493, PMID:16551252, PMID:16551262]
Full description |

Standard name | GO_MYELOID_CELL_HOMEOSTASIS
Systematic name | M10467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of regulating the proliferation and elimination of myeloid cells such that the total number of myeloid cells within a whole or part of an organism is stable over time in the absence of an outside stimulus. [CL:0000763, GOC:add]
Full description |

Standard name | GO_CELL_ACTIVATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M12069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in the morphology or behavior of a cell resulting from exposure to an activating factor such as a cellular or soluble ligand, leading to the initiation or perpetuation of an immune response. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_LEUKOCYTE_ACTIVATION_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M22232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in the morphology or behavior of a leukocyte resulting from exposure to an activating factor such as a cellular or soluble ligand, leading to the initiation or perpetuation of an inflammatory response. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_MYELOID_LEUKOCYTE_ACTIVATION
Systematic name | M12762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in the morphology or behavior of a myeloid leukocyte resulting from exposure to an activating factor such as a cellular or soluble ligand. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_MACROPHAGE_ACTIVATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M10789
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in morphology and behavior of a macrophage resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor, leading to the initiation or perpetuation of an immune response. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_LYMPHOCYTE_ACTIVATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M16140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in morphology and behavior of a lymphocyte resulting from exposure to a specific antigen, mitogen, cytokine, chemokine, cellular ligand, or soluble factor, leading to the initiation or perpetuation of an immune response. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_T_CELL_ACTIVATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M10714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a mature or immature T cell resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific, leading to the initiation or perpetuation of an immune response. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_ALPHA_BETA_T_CELL_ACTIVATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M34045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of an alpha-beta T cell resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific, leading to the initiation or perpetuation of an immune response. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_T_CELL_ACTIVATION_VIA_T_CELL_RECEPTOR_CONTACT_WITH_ANTIGEN_BOUND_TO_MHC_MOLECULE_ON_ANTIGEN_PRESENTING_CELL
Systematic name | M22233
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a mature or immature T cell resulting from exposure to an antigen for which its T cell receptor is specific bound to an MHC molecule on an antigen presenting cell, leading to the initiation or perpetuation of an immune response. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_T_CELL_DIFFERENTIATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M12607
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigenically naive T cell acquires the specialized features of an effector, regulatory, or memory T cell as part of an immune response. Effector T cells include cells which provide T cell help or exhibit cytotoxicity towards other cells. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_T_HELPER_CELL_LINEAGE_COMMITMENT
Systematic name | M34046
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a CD4-positive, alpha-beta T cell becomes committed to becoming a T-helper cell, a CD4-positive, alpha-beta T cell specialized to promote various immunological processes. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_B_CELL_ACTIVATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M16926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a mature or immature B cell during an immune response, resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific. [GOC:jal]
Full description |

Standard name | GO_MATURE_B_CELL_DIFFERENTIATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M15108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a naive B cell acquires the specialized features of a mature or memory B cell during an immune response. [GOC:jal]
Full description |

Standard name | GO_GERMINAL_CENTER_B_CELL_DIFFERENTIATION
Systematic name | M34047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a B cell in the spleen acquires the specialized features of a germinal center B cell. Germinal center B cells are rapidly cycling B cells which have downregulated IgD expression and exhibit high levels of binding by peanut agglutinin (PNA). [GOC:jal, ISBN:0781735149]
Full description |

Standard name | GO_MARGINAL_ZONE_B_CELL_DIFFERENTIATION
Systematic name | M22234
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a B cell in the spleen acquires the specialized features of a marginal zone B cell. Marginal zone B cells are localized in a distinct anatomical region of the spleen that represents the major antigen-filtering and scavenging area (by specialized macrophages resident there). It appears that they are preselected to express a BCR repertoire similar to B-1 B cells, biased toward bacterial cell wall constituents and senescent self-components (such as oxidized LDL). [GOC:jal, ISBN:0781735149]
Full description |

Standard name | GO_MYELOID_PROGENITOR_CELL_DIFFERENTIATION
Systematic name | M22235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of a myeloid progenitor cell. Myeloid progenitor cells include progenitor cells for any of the myeloid lineages. [GOC:add, PMID:16551264]
Full description |

Standard name | GO_LYMPHOID_PROGENITOR_CELL_DIFFERENTIATION
Systematic name | M15918
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of a lymphoid progenitor cell. Lymphoid progenitor cells include progenitor cells for any of the lymphoid lineages. [GOC:add, PMID:16551251, PMID:16551264]
Full description |

Standard name | GO_B_CELL_PROLIFERATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M22236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a B cell population by cell division following B cell activation during an immune response. [GOC:jal]
Full description |

Standard name | GO_NATURAL_KILLER_CELL_ACTIVATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M13717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a natural killer cell resulting from exposure a cytokine, chemokine, cellular ligand, or soluble factor, leading to the initiation or perpetuation of an immune response. [GOC:add, PMID:15032583]
Full description |

Standard name | GO_B_CELL_LINEAGE_COMMITMENT
Systematic name | M22237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a lymphoid progenitor cell becomes committed to become any type of B cell. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_IMMATURE_B_CELL_DIFFERENTIATION
Systematic name | M22238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of an immature B cell. [GOC:jal, ISBN:0781735149, PMID:16551251]
Full description |

Standard name | GO_PRO_B_CELL_DIFFERENTIATION
Systematic name | M22239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of a pro-B cell. Pro-B cells are the earliest stage of the B cell lineage and undergo heavy chain D and J gene rearrangements, although they are not fully committed. [GOC:jal, ISBN:0781735149]
Full description |

Standard name | GO_PRE_B_CELL_DIFFERENTIATION
Systematic name | M22240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of a pre-B cell. Pre-B cells follow the pro-B cell stage of immature B cell differentiation and undergo rearrangement of heavy chain V, D, and J gene segments. [GOC:jal, ISBN:0781735149]
Full description |

Standard name | GO_MATURE_B_CELL_DIFFERENTIATION
Systematic name | M15201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which transitional stage B cells acquire the specialized features of mature B cells in the spleen. [GOC:jal, ISBN:0781735149]
Full description |

Standard name | GO_RESPONSE_TO_TUMOR_CELL
Systematic name | M22241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a tumor cell. [GOC:add, ISBN:0781735149, PMID:16730260]
Full description |

Standard name | GO_HISTAMINE_PRODUCTION_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M22242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis or release of histamine following a stimulus as part of an inflammatory response, resulting in an increase in its intracellular or extracellular levels. [GOC:add, ISBN:0781735149, PMID:16730260]
Full description |

Standard name | GO_T_CELL_LINEAGE_COMMITMENT
Systematic name | M14950
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a lymphoid progenitor cell becomes committed to becoming any type of T cell. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_CD4_POSITIVE_CD25_POSITIVE_ALPHA_BETA_REGULATORY_T_CELL_DIFFERENTIATION
Systematic name | M22243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of a CD4-positive, CD25-positive, alpha-beta regulatory T cell. [GOC:add, PMID:15207821]
Full description |

Standard name | GO_CYTOKINE_PRODUCTION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M14635
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of a cytokine due to biosynthesis or secretion following a cellular stimulus contributing to an immune response, resulting in an increase in its intracellular or extracellular levels. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_T_CELL_CYTOKINE_PRODUCTION
Systematic name | M22245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that contributes to cytokine production by a T cell. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_NATURAL_KILLER_CELL_CYTOKINE_PRODUCTION
Systematic name | M22246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that contributes to cytokine production by a natural killer cell. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_DENDRITIC_CELL_CYTOKINE_PRODUCTION
Systematic name | M22247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that contributes to cytokine production by a dendritic cell. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_MYELOID_DENDRITIC_CELL_CYTOKINE_PRODUCTION
Systematic name | M29019
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that contributes to cytokine production by a myeloid dendritic cell. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_IMMUNOGLOBULIN_PRODUCTION
Systematic name | M12930
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of immunoglobulin due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_IMMUNOGLOBULIN_PRODUCTION_INVOLVED_IN_IMMUNOGLOBULIN_MEDIATED_IMMUNE_RESPONSE
Systematic name | M14208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of immunoglobulin due to biosynthesis or secretion following a cellular stimulus during an immune response, resulting in an increase in its intracellular or extracellular levels. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_MHC_PROTEIN_COMPLEX_ASSEMBLY
Systematic name | M22249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an MHC protein complex. [GOC:add, ISBN:0781735149, PMID:15771591, PMID:15928678]
Full description |

Standard name | GO_DENDRITIC_CELL_CHEMOTAXIS
Systematic name | M34048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a dendritic cell in response to an external stimulus. [CL:0000451, GOC:add, ISBN:0781735149, PMID:15814331, PMID:16056255]
Full description |

Standard name | GO_IMMUNE_RESPONSE_TO_TUMOR_CELL
Systematic name | M22250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune system process that functions in the response of an organism to a tumor cell. [GOC:add, ISBN:0781735149, PMID:16730260]
Full description |

Standard name | GO_NATURAL_KILLER_CELL_MEDIATED_IMMUNE_RESPONSE_TO_TUMOR_CELL
Systematic name | M22251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response mediated by a natural killer cell triggered in response to the presence of a tumor cell. [GOC:add, ISBN:0781735149, PMID:16730260]
Full description |

Standard name | GO_T_CELL_MEDIATED_IMMUNE_RESPONSE_TO_TUMOR_CELL
Systematic name | M34049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response mediated by a T cell triggered in response to the presence of a tumor cell. [GOC:add, ISBN:0781735149, PMID:16730260]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_PEPTIDE_ANTIGEN_VIA_MHC_CLASS_IB
Systematic name | M22252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses peptide antigen in association with an MHC class Ib protein complex on its cell surface. The peptide antigen may originate from an endogenous or exogenous protein. Class Ib here refers to non-classical class I molecules, such as those of the HLA-E family. [GOC:add, PMID:15928678]
Full description |

Standard name | GO_COMPLEMENT_RECEPTOR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M22253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals generated as a consequence of a component of the complement pathway binding to a complement receptor. Such components include both whole complement proteins and fragments of complement proteins generated through the activity of the complement pathway. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_FC_RECEPTOR_MEDIATED_STIMULATORY_SIGNALING_PATHWAY
Systematic name | M22254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals generated as a consequence of a the binding of the Fc portion of an immunoglobulin by an Fc receptor capable of activating or perpetuating an immune response. The Fc portion of an immunoglobulin is its C-terminal constant region. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_INFLAMMATORY_RESPONSE_TO_ANTIGENIC_STIMULUS
Systematic name | M13812
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An inflammatory response to an antigenic stimulus, which can be include any number of T cell or B cell epitopes. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_ACUTE_INFLAMMATORY_RESPONSE_TO_ANTIGENIC_STIMULUS
Systematic name | M22255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An acute inflammatory response to an antigenic stimulus. An acute inflammatory response occurs within a matter of minutes or hours, and either resolves within a few days or becomes a chronic inflammatory response. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_PRODUCTION_OF_MOLECULAR_MEDIATOR_OF_IMMUNE_RESPONSE
Systematic name | M16237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis or release of any molecular mediator of the immune response, resulting in an increase in its intracellular or extracellular levels. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_LEUKOCYTE_MEDIATED_IMMUNITY
Systematic name | M11678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the carrying out of an immune response by a leukocyte. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_MYELOID_LEUKOCYTE_MEDIATED_IMMUNITY
Systematic name | M14205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the carrying out of an immune response by a myeloid leukocyte. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_MAST_CELL_MEDIATED_IMMUNITY
Systematic name | M14868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the carrying out of an immune response by a mast cell. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_LYMPHOCYTE_MEDIATED_IMMUNITY
Systematic name | M12663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the carrying out of an immune response by a lymphocyte. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_HUMORAL_IMMUNE_RESPONSE_MEDIATED_BY_CIRCULATING_IMMUNOGLOBULIN
Systematic name | M14749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response dependent upon secreted immunoglobulin. An example of this process is found in Mus musculus. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_T_CELL_MEDIATED_IMMUNITY
Systematic name | M15651
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the carrying out of an immune response by a T cell. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_T_CELL_ANTIGEN_PROCESSING_AND_PRESENTATION
Systematic name | M22256
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a T cell expresses antigen (peptide or lipid) on its cell surface in association with an MHC protein complex. [GOC:add, PMID:11417857, PMID:15120183]
Full description |

Standard name | GO_ADAPTIVE_IMMUNE_RESPONSE_BASED_ON_SOMATIC_RECOMBINATION_OF_IMMUNE_RECEPTORS_BUILT_FROM_IMMUNOGLOBULIN_SUPERFAMILY_DOMAINS
Systematic name | M16548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response mediated by lymphocytes expressing specific receptors for antigen produced through a somatic diversification process that includes somatic recombination of germline gene segments encoding immunoglobulin superfamily domains. Recombined receptors for antigen encoded by immunoglobulin superfamily domains include T cell receptors and immunoglobulins (antibodies) produced by B cells. The first encounter with antigen elicits a primary immune response that is slow and not of great magnitude. T and B cells selected by antigen become activated and undergo clonal expansion. A fraction of antigen-reactive T and B cells become memory cells, whereas others differentiate into effector cells. The memory cells generated during the primary response enable a much faster and stronger secondary immune response upon subsequent exposures to the same antigen (immunological memory). An example of this is the adaptive immune response found in Mus musculus. [GOC:add, GOC:mtg_sensu, ISBN:0781735149, ISBN:1405196831]
Full description |

Standard name | GO_TOLERANCE_INDUCTION_DEPENDENT_UPON_IMMUNE_RESPONSE
Systematic name | M22257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Tolerance induction dependent upon an immune response, typically a response by a mature T or B cell in the periphery resulting tolerance towards an antigen via induction of anergy, cellular deletion, or regulatory T cell activation. [GO_REF:0000022, GOC:jal, ISBN:0781735149]
Full description |

Standard name | GO_GERMINAL_CENTER_FORMATION
Systematic name | M22258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which germinal centers form. A germinal center is a specialized microenvironment formed when activated B cells enter lymphoid follicles. Germinal centers are the foci for B cell proliferation and somatic hypermutation. [GO_REF:0000022, GOC:jal, ISBN:081533642X]
Full description |

Standard name | GO_DENDRITIC_CELL_ANTIGEN_PROCESSING_AND_PRESENTATION
Systematic name | M22259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a dendritic cell expresses antigen (peptide or lipid) on its cell surface in association with an MHC protein complex. [GOC:add, ISBN:0781735149, PMID:15771591]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_PEPTIDE_ANTIGEN_VIA_MHC_CLASS_I
Systematic name | M13091
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses a peptide antigen on its cell surface in association with an MHC class I protein complex. Class I here refers to classical class I molecules. [GOC:add, ISBN:0781735149, PMID:15224092, PMID:15771591]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_VIA_MHC_CLASS_IB
Systematic name | M11335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses antigen (peptide or lipid) on its cell surface in association with an MHC class Ib protein complex. Class Ib here refers to non-classical class I molecules, such as those of the CD1 or HLA-E gene families. [GOC:add, PMID:15928678, PMID:15928680]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_EXOGENOUS_PEPTIDE_ANTIGEN_VIA_MHC_CLASS_I_TAP_INDEPENDENT
Systematic name | M22260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses a peptide antigen of exogenous origin on its cell surface in association with an MHC class I protein complex following intracellular transport via a pathway not requiring TAP (transporter associated with antigen processing). The peptide is typically a fragment of a larger exogenous protein which has been degraded within the cell. Class I here refers to classical class I molecules. [GOC:add, PMID:15224093, PMID:15771591, PMID:16181335]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_ENDOGENOUS_PEPTIDE_ANTIGEN
Systematic name | M16750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses a peptide antigen of endogenous origin on its cell surface in association with an MHC protein complex. The peptide is typically a fragment of a larger endogenous protein which has been degraded within the cell. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_ENDOGENOUS_PEPTIDE_ANTIGEN_VIA_MHC_CLASS_I_VIA_ER_PATHWAY
Systematic name | M34050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses a peptide antigen of endogenous origin on its cell surface in association with an MHC class I protein complex following intracellular transport via an ER pathway. The peptide is typically a fragment of a larger endogenous protein which has been degraded within the cell and becomes associated with the MHC class I molecule in the ER. Class I here refers to classical class I molecules. [GOC:add, ISBN:0781735149, PMID:14647477, PMID:15771591]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_PEPTIDE_OR_POLYSACCHARIDE_ANTIGEN_VIA_MHC_CLASS_II
Systematic name | M10260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses antigen (peptide or polysaccharide) on its cell surface in association with an MHC class II protein complex. [GOC:add, ISBN:0781735149, PMID:15531770, PMID:15771591, PMID:16153240]
Full description |

Standard name | GO_TOLERANCE_INDUCTION
Systematic name | M10485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that directly activates any of the steps required for tolerance, a physiologic state in which the immune system does not react destructively against the components of an organism that harbors it or against antigens that are introduced to it. [GO_REF:0000022, GOC:jal, ISBN:0781735149]
Full description |

Standard name | GO_TOLERANCE_INDUCTION_TO_SELF_ANTIGEN
Systematic name | M34051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Tolerance induction directed at self antigens. [GO_REF:0000022, GOC:jal, ISBN:0781735149]
Full description |

Standard name | GO_T_CELL_TOLERANCE_INDUCTION
Systematic name | M22263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process involving any mechanism for tolerance induction in T cells. [GOC:jal, ISBN:0781735149, PMID:16551263]
Full description |

Standard name | GO_IMMUNE_SYSTEM_DEVELOPMENT
Systematic name | M3457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an organismal system whose objective is to provide calibrated responses by an organism to a potential internal or invasive threat, over time, from its formation to the mature structure. A system is a regularly interacting or interdependent group of organs or tissues that work together to carry out a given biological process. [GOC:add, GOC:dph]
Full description |

Standard name | GO_LEUKOCYTE_DIFFERENTIATION
Systematic name | M803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized hemopoietic precursor cell acquires the specialized features of a leukocyte. A leukocyte is an achromatic cell of the myeloid or lymphoid lineages capable of ameboid movement, found in blood or other tissue. [CL:0000738, GOC:add, PMID:16551264]
Full description |

Standard name | GO_LEUKOCYTE_MIGRATION_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M16132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a leukocyte within or between different tissues and organs of the body contributing to an inflammatory response. [GOC:add, ISBN:0781735149, PMID:14680625, PMID:14708592, PMID:7507411, PMID:8600538]
Full description |

Standard name | GO_HYPERSENSITIVITY
Systematic name | M22264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An inflammatory response to an exogenous environmental antigen or an endogenous antigen initiated by the adaptive immune system. [GOC:jal, ISBN:0781735149]
Full description |

Standard name | GO_ACUTE_INFLAMMATORY_RESPONSE
Systematic name | M6557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Inflammation which comprises a rapid, short-lived, relatively uniform response to acute injury or antigenic challenge and is characterized by accumulations of fluid, plasma proteins, and granulocytic leukocytes. An acute inflammatory response occurs within a matter of minutes or hours, and either resolves within a few days or becomes a chronic inflammatory response. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_PRODUCTION_OF_MOLECULAR_MEDIATOR_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M13063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis or release of any molecular mediator of the inflammatory response following an inflammatory stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:add, GOC:dph, GOC:tb, ISBN:0781735149]
Full description |

Standard name | GO_CYTOKINE_PRODUCTION_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M22265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis or release of a cytokine following a inflammatory stimulus as part of an inflammatory response, resulting in an increase in its intracellular or extracellular levels. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_RESPIRATORY_BURST_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M22266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A phase of elevated metabolic activity, during which oxygen consumption increases following a stimulus as part of an inflammatory response; this leads to the production, by an NADH dependent system, of hydrogen peroxide (H2O2), superoxide anions and hydroxyl radicals, resulting in an increase in their intracellular or extracellular levels. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_CHRONIC_INFLAMMATORY_RESPONSE
Systematic name | M15140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Inflammation of prolonged duration (weeks or months) in which active inflammation, tissue destruction, and attempts at repair are proceeding simultaneously. Although it may follow acute inflammation, chronic inflammation frequently begins insidiously, as a low-grade, smoldering, often asymptomatic response. [GO_REF:0000022, GOC:jal, ISBN:0781735149]
Full description |

Standard name | GO_MONOCYTE_CHEMOTAXIS
Systematic name | M15503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a monocyte in response to an external stimulus. [GOC:add, PMID:11696603, PMID:15173832]
Full description |

Standard name | GO_SOMATIC_DIVERSIFICATION_OF_IMMUNE_RECEPTORS_VIA_SOMATIC_MUTATION
Systematic name | M15163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which immune receptor genes are diversified through somatic mutation. [ISBN:0781735149, PMID:16102575]
Full description |

Standard name | GO_SOMATIC_DIVERSIFICATION_OF_T_CELL_RECEPTOR_GENES
Systematic name | M22268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The somatic process that results in the generation of sequence diversity of T cell receptor genes. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_MYELOID_LEUKOCYTE_DIFFERENTIATION
Systematic name | M11427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized myeloid precursor cell acquires the specialized features of any cell of the myeloid leukocyte lineage. [GOC:add, PMID:16551251]
Full description |

Standard name | GO_PLATELET_DEGRANULATION
Systematic name | M15876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated exocytosis of secretory granules containing preformed mediators such as histamine and serotonin by a platelet. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_ANTIGEN_PROCESSING_AND_PRESENTATION
Systematic name | M12648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of antigen processing and presentation. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ANTIGEN_PROCESSING_AND_PRESENTATION
Systematic name | M22269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of antigen processing and presentation. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ANTIGEN_PROCESSING_AND_PRESENTATION
Systematic name | M13310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of antigen processing and presentation. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_PEPTIDE_OR_POLYSACCHARIDE_ANTIGEN_VIA_MHC_CLASS_II
Systematic name | M22270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of antigen processing and presentation of antigen (peptide or polysaccharide) via MHC class II. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_PEPTIDE_ANTIGEN
Systematic name | M10719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of antigen processing and presentation of peptide antigen. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DENDRITIC_CELL_ANTIGEN_PROCESSING_AND_PRESENTATION
Systematic name | M22271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of dendritic cell antigen processing and presentation. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_GERMINAL_CENTER_FORMATION
Systematic name | M22272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of germinal center formation. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_IMMUNOGLOBULIN_PRODUCTION
Systematic name | M12231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of immunoglobulin production. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_IMMUNOGLOBULIN_PRODUCTION
Systematic name | M22273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of immunoglobulin production. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_IMMUNOGLOBULIN_PRODUCTION
Systematic name | M13791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of immunoglobulin production. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_TOLERANCE_INDUCTION
Systematic name | M11555
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of tolerance induction. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TOLERANCE_INDUCTION
Systematic name | M22274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of tolerance induction. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_TOLERANCE_INDUCTION
Systematic name | M12505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of T cell tolerance induction. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_CELL_TOLERANCE_INDUCTION
Systematic name | M22275
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of T cell tolerance induction. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_ACUTE_INFLAMMATORY_RESPONSE
Systematic name | M11994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of an acute inflammatory response. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ACUTE_INFLAMMATORY_RESPONSE
Systematic name | M11491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of an acute inflammatory response. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACUTE_INFLAMMATORY_RESPONSE
Systematic name | M11700
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of an acute inflammatory response. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_CHRONIC_INFLAMMATORY_RESPONSE
Systematic name | M13843
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a chronic inflammatory response. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHRONIC_INFLAMMATORY_RESPONSE
Systematic name | M34052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of a chronic inflammatory response. [GOC:add]
Full description |

Standard name | GO_RESPIRATORY_BURST_INVOLVED_IN_DEFENSE_RESPONSE
Systematic name | M22276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A phase of elevated metabolic activity, during which oxygen consumption increases made as part of a defense response ; this leads to the production, by an NADH dependent system, of hydrogen peroxide (H2O2), superoxide anions and hydroxyl radicals. [GOC:add, ISBN:0781735149, PMID:12789499]
Full description |

Standard name | GO_REGULATION_OF_IMMUNE_SYSTEM_PROCESS
Systematic name | M5017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of an immune system process. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_IMMUNE_SYSTEM_PROCESS
Systematic name | M3748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of an immune system process. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_IMMUNE_SYSTEM_PROCESS
Systematic name | M4046
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of an immune system process. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_MIGRATION
Systematic name | M11696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of leukocyte migration. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LEUKOCYTE_MIGRATION
Systematic name | M12721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of leukocyte migration. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LEUKOCYTE_MIGRATION
Systematic name | M12651
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of leukocyte migration. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_CHEMOTAXIS
Systematic name | M14612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of leukocyte chemotaxis. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LEUKOCYTE_CHEMOTAXIS
Systematic name | M15323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of leukocyte chemotaxis. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LEUKOCYTE_CHEMOTAXIS
Systematic name | M16142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of leukocyte chemotaxis. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_EXTRAVASATION
Systematic name | M13375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of cellular extravasation. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_EXTRAVASATION
Systematic name | M22277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of cellular extravasation. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_EXTRAVASATION
Systematic name | M10997
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of cellular extravasation. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_IMMUNE_EFFECTOR_PROCESS
Systematic name | M4850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of an immune effector process. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_IMMUNE_EFFECTOR_PROCESS
Systematic name | M16089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of an immune effector process. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_IMMUNE_EFFECTOR_PROCESS
Systematic name | M14875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of an immune effector process. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_PRODUCTION_OF_MOLECULAR_MEDIATOR_OF_IMMUNE_RESPONSE
Systematic name | M16947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of the production of molecular mediator of immune response. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PRODUCTION_OF_MOLECULAR_MEDIATOR_OF_IMMUNE_RESPONSE
Systematic name | M10849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of the production of molecular mediator of immune response. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PRODUCTION_OF_MOLECULAR_MEDIATOR_OF_IMMUNE_RESPONSE
Systematic name | M14743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of the production of molecular mediator of immune response. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_MEDIATED_IMMUNITY
Systematic name | M14544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of leukocyte mediated immunity. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LEUKOCYTE_MEDIATED_IMMUNITY
Systematic name | M10874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of leukocyte mediated immunity. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LEUKOCYTE_MEDIATED_IMMUNITY
Systematic name | M16943
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of leukocyte mediated immunity. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_LYMPHOCYTE_MEDIATED_IMMUNITY
Systematic name | M13637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of lymphocyte mediated immunity. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LYMPHOCYTE_MEDIATED_IMMUNITY
Systematic name | M14417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of lymphocyte mediated immunity. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LYMPHOCYTE_MEDIATED_IMMUNITY
Systematic name | M12910
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of lymphocyte mediated immunity. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_MEDIATED_IMMUNITY
Systematic name | M14330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of T cell mediated immunity. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_CELL_MEDIATED_IMMUNITY
Systematic name | M14715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of T cell mediated immunity. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_CELL_MEDIATED_IMMUNITY
Systematic name | M15686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of T cell mediated immunity. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_B_CELL_MEDIATED_IMMUNITY
Systematic name | M13261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of B cell mediated immunity. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_B_CELL_MEDIATED_IMMUNITY
Systematic name | M22278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of B cell mediated immunity. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_B_CELL_MEDIATED_IMMUNITY
Systematic name | M11570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of B cell mediated immunity. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_NATURAL_KILLER_CELL_MEDIATED_IMMUNITY
Systematic name | M15915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of natural killer cell mediated immunity. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NATURAL_KILLER_CELL_MEDIATED_IMMUNITY
Systematic name | M11357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of natural killer cell mediated immunity. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NATURAL_KILLER_CELL_MEDIATED_IMMUNITY
Systematic name | M16164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of natural killer cell mediated immunity. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_CYTOKINE_PRODUCTION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M11972
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of cytokine production that contributes to an immune response. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYTOKINE_PRODUCTION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M11083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of cytokine production contributing to an immune response. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOKINE_PRODUCTION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M10842
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of cytokine production that contributes to an immune response. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_CYTOKINE_PRODUCTION
Systematic name | M13970
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of T cell cytokine production. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_CELL_CYTOKINE_PRODUCTION
Systematic name | M22279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of T cell cytokine production. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_CELL_CYTOKINE_PRODUCTION
Systematic name | M13565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of T cell cytokine production. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DENDRITIC_CELL_CYTOKINE_PRODUCTION
Systematic name | M22280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of dendritic cell cytokine production. [GOC:add]
Full description |

Standard name | GO_CYTOPLASMIC_PATTERN_RECOGNITION_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15016
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of a cytoplasmic pattern recognition receptor (PRR) binding to one of its physiological ligands. PRRs bind pathogen-associated molecular pattern (PAMPs), structures conserved among microbial species. [GOC:add, GOC:ar, ISBN:0781735149, PMID:15199967]
Full description |

Standard name | GO_MYD88_DEPENDENT_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of binding to a toll-like receptor where the MyD88 adaptor molecule mediates transduction of the signal. Toll-like receptors directly bind pattern motifs from a variety of microbial sources to initiate innate immune response. [GOC:add, ISBN:0781735149, PMID:12467241, PMID:12524386, PMID:12855817, PMID:15585605, PMID:15728447]
Full description |

Standard name | GO_MYD88_INDEPENDENT_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15121
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of binding to a toll-like receptor not relying on the MyD88 adaptor molecule. Toll-like receptors directly bind pattern motifs from a variety of microbial sources to initiate innate immune response. [GOC:add, ISBN:0781735149, PMID:12467241, PMID:12524386, PMID:12855817, PMID:15585605, PMID:15728447]
Full description |

Standard name | GO_INNATE_IMMUNE_RESPONSE_ACTIVATING_SIGNAL_TRANSDUCTION
Systematic name | M34053
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cascade of processes by which a signal interacts with a receptor, causing a change in the level or activity of a second messenger or other downstream target, and ultimately leading to activation or perpetuation of an innate immune response. [GO_REF:0000022, GOC:add]
Full description |

Standard name | GO_REGULATION_OF_ANTIMICROBIAL_HUMORAL_RESPONSE
Systematic name | M22283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of an antimicrobial humoral response. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_MYELOID_LEUKOCYTE_DIFFERENTIATION
Systematic name | M15189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of myeloid leukocyte differentiation. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MYELOID_LEUKOCYTE_DIFFERENTIATION
Systematic name | M13329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of myeloid leukocyte differentiation. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MYELOID_LEUKOCYTE_DIFFERENTIATION
Systematic name | M16705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of myeloid leukocyte differentiation. [GOC:add]
Full description |

Standard name | GO_IMMUNE_RESPONSE_REGULATING_SIGNALING_PATHWAY
Systematic name | M22284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cascade of processes by which a signal interacts with a receptor, causing a change in the level or activity of a second messenger or other downstream target, and ultimately leading to the activation, perpetuation, or inhibition of an immune response. [GOC:add, ISBN:0781735149, PMID:15771571]
Full description |

Standard name | GO_IMMUNE_RESPONSE_INHIBITING_SIGNAL_TRANSDUCTION
Systematic name | M22285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cascade of processes by which a signal interacts with a receptor, causing a change in the level or activity of a second messenger or other downstream target, and ultimately leading to inhibition of an immune response. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_IMMUNE_RESPONSE_INHIBITING_CELL_SURFACE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of an extracellular ligand to a receptor on the surface of the target cell capable of inhibiting an immune response. [GOC:add, ISBN:0781735149, PMID:15771571]
Full description |

Standard name | GO_ANTIMICROBIAL_PEPTIDE_PRODUCTION
Systematic name | M22287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis or release of an antimicrobial peptide during an immune response, resulting in an increase in intracellular or extracellular levels. Such peptides may have protective properties against bacteria, fungi, viruses, or protozoa. [GOC:add, ISBN:0781735149, PMID:11807545, PMID:15638771]
Full description |

Standard name | GO_PEPTIDE_SECRETION
Systematic name | M11633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled release of a peptide from a cell or a tissue. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDE_SECRETION
Systematic name | M15388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of peptide secretion. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PEPTIDE_SECRETION
Systematic name | M11194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of peptide secretion. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PEPTIDE_SECRETION
Systematic name | M15157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of peptide secretion. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_ADAPTIVE_IMMUNE_RESPONSE
Systematic name | M10757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of an adaptive immune response. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ADAPTIVE_IMMUNE_RESPONSE
Systematic name | M10422
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of an adaptive immune response. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ADAPTIVE_IMMUNE_RESPONSE
Systematic name | M10368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of an adaptive immune response. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_T_HELPER_1_TYPE_IMMUNE_RESPONSE
Systematic name | M15803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a T-helper 1 type immune response. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_HELPER_1_TYPE_IMMUNE_RESPONSE
Systematic name | M22288
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of a T-helper 1 type immune response. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_HELPER_1_TYPE_IMMUNE_RESPONSE
Systematic name | M12978
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of a T-helper 1 type immune response. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_TYPE_2_IMMUNE_RESPONSE
Systematic name | M11058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a type 2 immune response. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TYPE_2_IMMUNE_RESPONSE
Systematic name | M12199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of a type 2 immune response. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TYPE_2_IMMUNE_RESPONSE
Systematic name | M12590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of a type 2 immune response. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_BIOTIC_STIMULUS
Systematic name | M14774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a response to biotic stimulus. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_BIOTIC_STIMULUS
Systematic name | M12015
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of a response to biotic stimulus. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_BIOTIC_STIMULUS
Systematic name | M14494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of a response to biotic stimulus. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_TUMOR_CELL
Systematic name | M16192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a response to tumor cell. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_TUMOR_CELL
Systematic name | M13866
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of a response to tumor cell. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_MEDIATED_IMMUNE_RESPONSE_TO_TUMOR_CELL
Systematic name | M34054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a T cell mediated immune response to tumor cell. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NATURAL_KILLER_CELL_MEDIATED_IMMUNE_RESPONSE_TO_TUMOR_CELL
Systematic name | M22289
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of natural killer cell mediated immune response to a tumor cell. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_INFLAMMATORY_RESPONSE_TO_ANTIGENIC_STIMULUS
Systematic name | M10361
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of an inflammatory response to an antigenic stimulus. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INFLAMMATORY_RESPONSE_TO_ANTIGENIC_STIMULUS
Systematic name | M22290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of an inflammatory response to an antigenic stimulus. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INFLAMMATORY_RESPONSE_TO_ANTIGENIC_STIMULUS
Systematic name | M22291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of an inflammatory response to an antigenic stimulus. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_ACUTE_INFLAMMATORY_RESPONSE_TO_ANTIGENIC_STIMULUS
Systematic name | M22292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of an acute inflammatory response to an antigenic stimulus. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ACUTE_INFLAMMATORY_RESPONSE_TO_ANTIGENIC_STIMULUS
Systematic name | M22293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of an acute inflammatory response to an antigenic stimulus. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACUTE_INFLAMMATORY_RESPONSE_TO_ANTIGENIC_STIMULUS
Systematic name | M22294
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of an acute inflammatory response to an antigenic stimulus. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HYPERSENSITIVITY
Systematic name | M22295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of hypersensitivity. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_MYELOID_LEUKOCYTE_MEDIATED_IMMUNITY
Systematic name | M22296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of myeloid leukocyte mediated immunity. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MYELOID_LEUKOCYTE_MEDIATED_IMMUNITY
Systematic name | M22297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of myeloid leukocyte mediated immunity. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MYELOID_LEUKOCYTE_MEDIATED_IMMUNITY
Systematic name | M16316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of myeloid leukocyte mediated immunity. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_B_CELL_APOPTOTIC_PROCESS
Systematic name | M13701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of B cell apoptotic process. [GOC:add, GOC:mtg_apoptosis]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_B_CELL_APOPTOTIC_PROCESS
Systematic name | M16499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of B cell apoptotic process. [GOC:add, GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_HUMORAL_IMMUNE_RESPONSE
Systematic name | M14968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a humoral immune response. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HUMORAL_IMMUNE_RESPONSE
Systematic name | M13912
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of a humoral immune response. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HUMORAL_IMMUNE_RESPONSE
Systematic name | M15300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of a humoral immune response. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_HUMORAL_IMMUNE_RESPONSE_MEDIATED_BY_CIRCULATING_IMMUNOGLOBULIN
Systematic name | M22298
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a humoral immune response mediated by circulating immunoglobulin. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HUMORAL_IMMUNE_RESPONSE_MEDIATED_BY_CIRCULATING_IMMUNOGLOBULIN
Systematic name | M22299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of a humoral immune response mediated by circulating immunoglobulin. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HUMORAL_IMMUNE_RESPONSE_MEDIATED_BY_CIRCULATING_IMMUNOGLOBULIN
Systematic name | M22300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of a humoral immune response mediated by circulating immunoglobulin. [GOC:add]
Full description |

Standard name | GO_RESPONSE_TO_ISCHEMIA
Systematic name | M12936
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a inadequate blood supply. [GOC:hjd]
Full description |

Standard name | GO_LIPID_HYDROXYLATION
Systematic name | M22301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment of a hydroxyl group to one or more fatty acids in a lipid. [GOC:hjd, PMID:15658937]
Full description |

Standard name | GO_DESMOSOME_ORGANIZATION
Systematic name | M22302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a desmosome. A desmosome is a patch-like intercellular junction found in vertebrate tissues, consisting of parallel zones of two cell membranes, separated by an space of 25-35 nm, and having dense fibrillar plaques in the subjacent cytoplasm. [GOC:hjd]
Full description |

Standard name | GO_REGIONALIZATION
Systematic name | M578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The pattern specification process that results in the subdivision of an axis or axes in space to define an area or volume in which specific patterns of cell differentiation will take place or in which cells interpret a specific environment. [GOC:dph, GOC:isa_complete]
Full description |

Standard name | GO_DEVELOPMENTAL_PROCESS_INVOLVED_IN_REPRODUCTION
Systematic name | M14904
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process in which a progressive change in the state of some part of an organism specifically contributes to its ability to form offspring. [GOC:dph, GOC:isa_complete]
Full description |

Standard name | GO_HEART_MORPHOGENESIS
Systematic name | M12997
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process in which the heart is generated and organized. The heart is a hollow, muscular organ, which, by contracting rhythmically, keeps up the circulation of the blood. [GOC:dph, GOC:isa_complete]
Full description |

Standard name | GO_SKELETAL_MUSCLE_CONTRACTION
Systematic name | M11647
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within skeletal muscle tissue, resulting in a change in muscle geometry. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. In the skeletal muscle, the muscle contraction takes advantage of an ordered sarcomeric structure and in most cases it is under voluntary control. [GOC:mtg_cardio, GOC:mtg_muscle]
Full description |

Standard name | GO_VOLUNTARY_SKELETAL_MUSCLE_CONTRACTION
Systematic name | M22303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within voluntary skeletal muscle tissue, resulting in a change in muscle geometry. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. In the voluntary skeletal muscle, the muscle contraction takes advantage of an ordered sarcomeric structure and it is under voluntary control. Voluntary skeletal muscle is skeletal muscle that is under conscious control. [GOC:mtg_cardio, GOC:mtg_muscle]
Full description |

Standard name | GO_MUSCLE_SYSTEM_PROCESS
Systematic name | M14930
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A organ system process carried out at the level of a muscle. Muscle tissue is composed of contractile cells or fibers. [GOC:mtg_cardio]
Full description |

Standard name | GO_CIRCULATORY_SYSTEM_PROCESS
Systematic name | M10531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A organ system process carried out by any of the organs or tissues of the circulatory system. The circulatory system is an organ system that moves extracellular fluids to and from tissue within a multicellular organism. [GOC:mtg_cardio]
Full description |

Standard name | GO_RENAL_SYSTEM_PROCESS
Systematic name | M16787
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A organ system process carried out by any of the organs or tissues of the renal system. The renal system maintains fluid balance, and contributes to electrolyte balance, acid/base balance, and disposal of nitrogenous waste products. In humans, the renal system comprises a pair of kidneys, a pair of ureters, urinary bladder, urethra, sphincter muscle and associated blood vessels; in other species, the renal system may comprise related structures (e.g., nephrocytes and malpighian tubules in Drosophila). [GOC:cjm, GOC:mtg_cardio, GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_HEART_PROCESS
Systematic name | M14929
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A circulatory system process carried out by the heart. The heart is a hollow, muscular organ, which, by contracting rhythmically, keeps up the circulation of the blood. The heart is a hollow, muscular organ, which, by contracting rhythmically, keeps up the circulation of the blood. [GOC:mtg_cardio]
Full description |

Standard name | GO_RESPIRATORY_SYSTEM_PROCESS
Systematic name | M11273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process carried out by the organs or tissues of the respiratory system. The respiratory system is an organ system responsible for respiratory gaseous exchange. [GOC:dph, GOC:mtg_cardio, GOC:tb]
Full description |

Standard name | GO_VASCULAR_PROCESS_IN_CIRCULATORY_SYSTEM
Systematic name | M16767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A circulatory process that occurs at the level of the vasculature. [GOC:mtg_cardio]
Full description |

Standard name | GO_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE_MEDIATED_BY_A_CHEMICAL_SIGNAL
Systematic name | M16735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulation of blood pressure mediated by biochemical signaling: hormonal, autocrine or paracrine. [GOC:mtg_cardio]
Full description |

Standard name | GO_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M22304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of vascular smooth muscle contraction. [GOC:mtg_cardio, GOC:mtg_sensu, GOC:rl]
Full description |

Standard name | GO_REGULATION_OF_THE_FORCE_OF_HEART_CONTRACTION_BY_CHEMICAL_SIGNAL
Systematic name | M22305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulation of the force of heart muscle contraction mediated by chemical signaling, hormonal, autocrine or paracrine. [GOC:mtg_cardio, GOC:rl]
Full description |

Standard name | GO_REGULATION_OF_HEART_RATE_BY_CHEMICAL_SIGNAL
Systematic name | M22306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulation of the rate of heart contraction mediated by chemical signaling, hormonal, autocrine or paracrine. [GOC:dph, GOC:mtg_cardio, GOC:rl, GOC:tb]
Full description |

Standard name | GO_RENAL_SYSTEM_PROCESS_INVOLVED_IN_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE
Systematic name | M16494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Renal process that modulates the force with which blood travels through the circulatory system. The process is controlled by a balance of processes that increase pressure and decrease pressure. [GOC:dph, GOC:mtg_cardio, GOC:tb]
Full description |

Standard name | GO_RENAL_CONTROL_OF_PERIPHERAL_VASCULAR_RESISTANCE_INVOLVED_IN_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE
Systematic name | M22307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The renal process that modulates the force with which blood travels through the circulatory system, by impeding blood flow through the peripheral vasculature. [GOC:mtg_cardio]
Full description |

Standard name | GO_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE
Systematic name | M11135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that modulates the force with which blood travels through the systemic arterial circulatory system. The process is controlled by a balance of processes that increase pressure and decrease pressure. [GOC:mtg_cardio]
Full description |

Standard name | GO_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE_BY_RENIN_ANGIOTENSIN
Systematic name | M15490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which renin-angiotensin modulates the force with which blood passes through the circulatory system. [GOC:mtg_cardio]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE
Systematic name | M22308
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that increases the force with which blood travels through the systemic arterial circulatory system. [GOC:mtg_cardio]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE
Systematic name | M12626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that reduces the force with which blood travels through the systemic arterial circulatory system. [GOC:mtg_cardio]
Full description |

Standard name | GO_RENAL_WATER_HOMEOSTASIS
Systematic name | M13320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Renal process involved in the maintenance of an internal steady state of water in the body. [GOC:mtg_cardio]
Full description |

Standard name | GO_REGULATION_OF_GLOMERULAR_FILTRATION
Systematic name | M11935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glomerular filtration. Glomerular filtration is the process in which blood is filtered by the glomerulus into the renal tubule. [GOC:mtg_cardio]
Full description |

Standard name | GO_RENAL_SODIUM_ION_TRANSPORT
Systematic name | M22309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of sodium ions (Na+) by the renal system. [GOC:mtg_cardio]
Full description |

Standard name | GO_RENAL_WATER_TRANSPORT
Systematic name | M22310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of water (H2O) by the renal system. [GOC:mtg_cardio]
Full description |

Standard name | GO_REGULATION_OF_SYSTEMIC_ARTERIAL_BLOOD_PRESSURE_BY_ENDOTHELIN
Systematic name | M22311
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which endothelin modulates the force with which blood passes through the circulatory system. Endothelin is a hormone that is released by the endothelium, and it is a vasoconstrictor. [GOC:mtg_cardio]
Full description |

Standard name | GO_HEART_FIELD_SPECIFICATION
Systematic name | M22312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in the delineation of a specific region of the lateral mesoderm into the area in which the heart will develop. [GOC:mtg_heart]
Full description |

Standard name | GO_HEART_INDUCTION
Systematic name | M22313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The close range interaction between mesoderm and endoderm or ectoderm that causes cells to change their fates and specify the development of the heart. [GOC:mtg_heart]
Full description |

Standard name | GO_SECONDARY_HEART_FIELD_SPECIFICATION
Systematic name | M22314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in the delineation of a specific region of the lateral mesoderm into the area which will form the majority of the mesodermal component of the right ventricle, arterial pole (outflow tract) and venous pole (inflow tract). [GOC:mtg_heart, GOC:rl, PMID:17276708]
Full description |

Standard name | GO_DETERMINATION_OF_LEFT_RIGHT_ASYMMETRY_IN_LATERAL_MESODERM
Systematic name | M22315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment of the lateral mesoderm with respect to the left and right halves. [GOC:mtg_heart]
Full description |

Standard name | GO_EMBRYONIC_HEART_TUBE_MORPHOGENESIS
Systematic name | M34055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the embryonic heart tube are generated and organized. The embryonic heart tube is an epithelial tube that will give rise to the mature heart. [GOC:mtg_heart]
Full description |

Standard name | GO_OUTFLOW_TRACT_SEPTUM_MORPHOGENESIS
Systematic name | M10461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the outflow tract septum are generated and organized. The outflow tract septum is a partition in the outflow tract. [GOC:mtg_heart]
Full description |

Standard name | GO_MEMBRANOUS_SEPTUM_MORPHOGENESIS
Systematic name | M22316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the membranous septum is generated and organized. The membranous septum is the upper part of ventricular septum. [GOC:mtg_heart]
Full description |

Standard name | GO_MUSCULAR_SEPTUM_MORPHOGENESIS
Systematic name | M22317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the muscular septum is generated and organized. The muscular septum is the lower part of the ventricular septum. [GOC:mtg_heart]
Full description |

Standard name | GO_OUTFLOW_TRACT_MORPHOGENESIS
Systematic name | M15408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the outflow tract are generated and organized. The outflow tract is the portion of the heart through which blood flows into the arteries. [GOC:mtg_heart, UBERON:0004145]
Full description |

Standard name | GO_REGULATION_OF_ANIMAL_ORGAN_FORMATION
Systematic name | M22318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of animal organ formation. Organ formation is the process pertaining to the initial formation of an organ from unspecified parts. The process begins with the specific processes that contribute to the appearance of the discrete structure, such as inductive events, and ends when the structural rudiment of the organ is recognizable, such as a condensation of mesenchymal cells into the organ rudiment. [GOC:dph, GOC:mtg_heart, GOC:tb]
Full description |

Standard name | GO_ENDOCARDIUM_DEVELOPMENT
Systematic name | M11703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the endocardium over time, from its formation to the mature structure. The endocardium is an anatomical structure comprised of an endothelium and an extracellular matrix that forms the innermost layer of tissue of the heart, and lines the heart chambers. [GOC:mtg_heart]
Full description |

Standard name | GO_ENDOTHELIUM_DEVELOPMENT
Systematic name | M13427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an endothelium over time, from its formation to the mature structure. Endothelium refers to the layer of cells lining blood vessels, lymphatics, the heart, and serous cavities, and is derived from bone marrow or mesoderm. Corneal endothelium is a special case, derived from neural crest cells. [GOC:mtg_heart]
Full description |

Standard name | GO_MORPHOGENESIS_OF_AN_ENDOTHELIUM
Systematic name | M12089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of an endothelium is generated and organized. Endothelium refers to the layer of cells lining blood vessels, lymphatics, the heart, and serous cavities, and is derived from bone marrow or mesoderm. Corneal endothelium is a special case, derived from neural crest cells. [GOC:mtg_heart]
Full description |

Standard name | GO_ENDOCARDIUM_MORPHOGENESIS
Systematic name | M22319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the endocardium is generated and organized. The endocardium is an anatomical structure comprised of an endothelium and an extracellular matrix that forms the innermost layer of tissue of the heart, and lines the heart chambers. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_CONDUCTION_SYSTEM_DEVELOPMENT
Systematic name | M11933
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the cardiac conduction system over time, from its formation to the mature structure. The cardiac conduction system consists of specialized cardiomyocytes that regulate the frequency of heart beat. [GOC:mtg_heart]
Full description |

Standard name | GO_HIS_PURKINJE_SYSTEM_DEVELOPMENT
Systematic name | M22320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the His-Purkinje system over time, from its formation to the mature structure. The His-Purkinje system receives signals from the AV node and is composed of the fibers that regulate cardiac muscle contraction in the ventricles. [GOC:mtg_heart]
Full description |

Standard name | GO_HEART_VALVE_DEVELOPMENT
Systematic name | M14639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a heart valve over time, from its formation to the mature structure. A heart valve is a structure that restricts the flow of blood to different regions of the heart and forms from an endocardial cushion. [GOC:mtg_heart]
Full description |

Standard name | GO_ATRIOVENTRICULAR_VALVE_DEVELOPMENT
Systematic name | M15790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the atrioventricular valve over time, from its formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_MITRAL_VALVE_DEVELOPMENT
Systematic name | M22321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the mitral valve over time, from its formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_TRICUSPID_VALVE_DEVELOPMENT
Systematic name | M22322
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the tricuspid valve over time, from its formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_AORTIC_VALVE_DEVELOPMENT
Systematic name | M22323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the aortic valve over time, from its formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_PULMONARY_VALVE_DEVELOPMENT
Systematic name | M22324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the pulmonary valve over time, from its formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_PULMONARY_VALVE_MORPHOGENESIS
Systematic name | M22325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the structure of the pulmonary valve is generated and organized. [GOC:mtg_heart]
Full description |

Standard name | GO_TRICUSPID_VALVE_MORPHOGENESIS
Systematic name | M22326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the structure of the tricuspid valve is generated and organized. [GOC:mtg_heart]
Full description |

Standard name | GO_HEART_VALVE_FORMATION
Systematic name | M13323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of a heart valve from unspecified parts. This process begins with the specific processes that contribute to the appearance of the discrete structure and ends when the structural rudiment is recognizable. [GOC:mtg_heart]
Full description |

Standard name | GO_ATRIOVENTRICULAR_VALVE_FORMATION
Systematic name | M22327
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of the atrioventricular valve from unspecified parts. This process begins with the specific processes that contribute to the appearance of the discrete structure and ends when the structural rudiment is recognizable. [GOC:mtg_heart]
Full description |

Standard name | GO_ENDOCARDIAL_CUSHION_DEVELOPMENT
Systematic name | M10798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a cardiac cushion over time, from its initial formation to the mature structure. The endocardial cushion is a specialized region of mesenchymal cells that will give rise to the heart septa and valves. [GOC:mtg_heart]
Full description |

Standard name | GO_EPITHELIAL_TO_MESENCHYMAL_TRANSITION_INVOLVED_IN_ENDOCARDIAL_CUSHION_FORMATION
Systematic name | M15098
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A transition where a cardiac epithelial cell loses apical/basolateral polarity, severs intercellular adhesive junctions, degrades basement membrane components and becomes a migratory mesenchymal cell that will contribute to the formation of the endocardial cushion. [GOC:mtg_heart]
Full description |

Standard name | GO_ENDOCARDIAL_CUSHION_MORPHOGENESIS
Systematic name | M11666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the endocardial cushion is generated and organized. The endocardial cushion is a specialized region of mesenchymal cells that will give rise to the heart septa and valves. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_CHAMBER_DEVELOPMENT
Systematic name | M10039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a cardiac chamber over time, from its formation to the mature structure. A cardiac chamber is an enclosed cavity within the heart. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_CHAMBER_MORPHOGENESIS
Systematic name | M10631
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a cardiac chamber is generated and organized. A cardiac chamber is an enclosed cavity within the heart. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_CHAMBER_FORMATION
Systematic name | M15525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of a cardiac chamber from unspecified parts. A cardiac chamber is an enclosed cavity within the heart. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_VENTRICLE_MORPHOGENESIS
Systematic name | M13090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the cardiac ventricle is generated and organized. A cardiac ventricle receives blood from a cardiac atrium and pumps it out of the heart. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_ATRIUM_MORPHOGENESIS
Systematic name | M34056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the cardiac atrium is generated and organized. A cardiac atrium receives blood from a vein and pumps it to a cardiac ventricle. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_VENTRICLE_FORMATION
Systematic name | M22328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of a cardiac ventricle from unspecified parts. A cardiac ventricle receives blood from a cardiac atrium and pumps it out of the heart. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_LEFT_VENTRICLE_MORPHOGENESIS
Systematic name | M10565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the left cardiac ventricle is generated and organized. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_RIGHT_VENTRICLE_MORPHOGENESIS
Systematic name | M13214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the right cardiac ventricle is generated and organized. [GOC:mtg_heart]
Full description |

Standard name | GO_VENTRICULAR_TRABECULA_MYOCARDIUM_MORPHOGENESIS
Systematic name | M15939
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the trabecular cardiac ventricle muscle are generated and organized. [GOC:mtg_heart]
Full description |

Standard name | GO_VENTRICULAR_COMPACT_MYOCARDIUM_MORPHOGENESIS
Systematic name | M22329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the compact cardiac ventricle muscle are generated and organized. [GOC:mtg_heart]
Full description |

Standard name | GO_ATRIAL_CARDIAC_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M22330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of cardiac muscle of the atrium over time, from its formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_VENTRICULAR_CARDIAC_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M12538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of ventricular cardiac muscle over time, from its formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_ATRIUM_DEVELOPMENT
Systematic name | M12332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a cardiac atrium over time, from its formation to the mature structure. A cardiac atrium receives blood from a vein and pumps it to a cardiac ventricle. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_VENTRICLE_DEVELOPMENT
Systematic name | M13718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a cardiac ventricle over time, from its formation to the mature structure. A cardiac ventricle receives blood from a cardiac atrium and pumps it out of the heart. [GOC:mtg_heart]
Full description |

Standard name | GO_GROWTH_INVOLVED_IN_HEART_MORPHOGENESIS
Systematic name | M22331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Developmental growth that contributes to the shaping of the heart. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_NEURAL_CREST_CELL_MIGRATION_INVOLVED_IN_OUTFLOW_TRACT_MORPHOGENESIS
Systematic name | M22332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a neural crest cell from one site to another that will contribute to the morphogenesis of the outflow tract. [GOC:mtg_heart]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_DEPOLARIZATION
Systematic name | M11448
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of membrane depolarization. Membrane depolarization is the process in which membrane potential changes in the depolarizing direction from the resting potential, usually from negative to positive. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CARDIOBLAST_PROLIFERATION
Systematic name | M22334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of cardioblasts, resulting in the expansion of the population in the heart field. A cardioblast is a cardiac precursor cell. It is a cell that has been committed to a cardiac fate, but will undergo more cell division rather than terminally differentiating. [GOC:mtg_heart]
Full description |

Standard name | GO_REGULATION_OF_SECONDARY_HEART_FIELD_CARDIOBLAST_PROLIFERATION
Systematic name | M22335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardioblast proliferation in the second heart field. A cardioblast is a cardiac precursor cell. It is a cell that has been committed to a cardiac fate, but will undergo more cell division rather than terminally differentiating. The secondary heart field is the region of the heart that will form the majority of the mesodermal component of the right ventricle, the arterial pole (outflow tract) and the venous pole (inflow tract). [GOC:mtg_heart, GOC:rl, PMID:17276708]
Full description |

Standard name | GO_ENDOCARDIAL_CUSHION_FORMATION
Systematic name | M11945
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of an endocardial cushion. The endocardial cushion is a specialized region of mesenchymal cells that will give rise to the heart septa and valves. [GOC:mtg_heart, PMID:15797462]
Full description |

Standard name | GO_APOPTOTIC_PROCESS_INVOLVED_IN_HEART_MORPHOGENESIS
Systematic name | M22336
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process that contributes to the shaping of the heart. [GOC:mtg_apoptosis, GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_SEPTUM_DEVELOPMENT
Systematic name | M10373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a cardiac septum over time, from its initial formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_VENTRICULAR_SEPTUM_DEVELOPMENT
Systematic name | M14093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the ventricular septum over time from its formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_ATRIAL_SEPTUM_DEVELOPMENT
Systematic name | M12355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the atrial septum over time, from its initial formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_SEPTUM_PRIMUM_DEVELOPMENT
Systematic name | M22337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the septum primum over time, from its formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_ATRIAL_SEPTUM_PRIMUM_MORPHOGENESIS
Systematic name | M22338
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which anatomical structure of an atrial septum primum is generated and organized. [GOC:mtg_heart]
Full description |

Standard name | GO_MUSCLE_HYPERTROPHY_IN_RESPONSE_TO_STRESS
Systematic name | M22339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The enlargement or overgrowth of all or part of a muscle organ or tissue due to an increase in the size of its muscle cells as a result of a disturbance in organismal or cellular homeostasis. [GOC:mtg_heart]
Full description |

Standard name | GO_PHYSIOLOGICAL_CARDIAC_MUSCLE_HYPERTROPHY
Systematic name | M22340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The enlargement or overgrowth of all or part of the heart muscle due to an increase in size of cardiac muscle cells without cell division. This process contributes to the developmental growth of the heart. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:mtg_heart]
Full description |

Standard name | GO_WNT_SIGNALING_PATHWAY_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M22341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of Wnt protein to a receptor on the surface of the target cell, resulting a change in cell state that contributes to the progression of the heart over time. [GOC:mtg_heart]
Full description |

Standard name | GO_REGULATION_OF_WNT_SIGNALING_PATHWAY_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M22342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the series of molecular signals initiated by binding of Wnt protein to a frizzled family receptor on the surface of the target cell, resulting a change in cell state that contributes to the progression of the heart over time. [GOC:mtg_heart]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_WNT_SIGNALING_PATHWAY_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M29022
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of the series of molecular signals initiated by binding of Wnt protein to a frizzled family receptor on the surface of the target cell, resulting a change in cell state that contributes to the progression of the heart over time. [GOC:mtg_heart]
Full description |

Standard name | GO_PANCREATIC_A_CELL_DIFFERENTIATION
Systematic name | M22343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and functional features of a pancreatic A cell. A pancreatic A cell is a cell in the pancreas that secretes glucagon. [GOC:dph, PMID:11076772]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BLOOD_PRESSURE_BY_EPINEPHRINE_NOREPINEPHRINE
Systematic name | M22344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which the force of blood traveling through the circulatory system is increased by the chemicals epinephrine and norepinephrine. [GOC:dph]
Full description |

Standard name | GO_TYPE_B_PANCREATIC_CELL_DEVELOPMENT
Systematic name | M11045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a type B pancreatic cell over time, from its formation to the mature structure. A type B pancreatic cell is a cell located towards center of the islets of Langerhans that secretes insulin. [CL:0000169, GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_EXTRACELLULAR_MATRIX_CONSTITUENT_SECRETION
Systematic name | M22345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the controlled release of molecules that form the extracellular matrix, including carbohydrates and glycoproteins by a cell or a group of cells. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_AMINO_ACID_TRANSMEMBRANE_TRANSPORT
Systematic name | M11551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an amino acid is transported across a membrane. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_KERATINOCYTE_DEVELOPMENT
Systematic name | M22346
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a keratinocyte over time, from its formation to the mature structure. [GOC:dph]
Full description |

Standard name | GO_MESENCHYMAL_TO_EPITHELIAL_TRANSITION_INVOLVED_IN_METANEPHROS_MORPHOGENESIS
Systematic name | M22347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A transition where a mesenchymal cell establishes apical/basolateral polarity,forms intercellular adhesive junctions, synthesizes basement membrane components and becomes an epithelial cell that will contribute to the shaping of the metanephros. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_METANEPHROS_MORPHOGENESIS
Systematic name | M16739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the metanephros are generated and organized. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_MESENCHYMAL_TO_EPITHELIAL_TRANSITION_INVOLVED_IN_METANEPHROS_MORPHOGENESIS
Systematic name | M22348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of the transition where a mesenchymal cell establishes apical/basolateral polarity,forms intercellular adhesive junctions, synthesizes basement membrane components and becomes an epithelial cell that will contribute to the shaping of the metanephros. [GOC:dph]
Full description |

Standard name | GO_CILIUM_MOVEMENT
Systematic name | M13169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed, self-propelled movement of a cilium. [GOC:dph, GOC:jl]
Full description |

Standard name | GO_PERICARDIUM_MORPHOGENESIS
Systematic name | M22349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the pericardium is generated and organized. [GOC:dph, PMID:18722343]
Full description |

Standard name | GO_REGULATION_OF_CILIUM_MOVEMENT
Systematic name | M15153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of cilium movement, the directed, self-propelled movement of a cilium. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CILIUM_MOVEMENT
Systematic name | M34057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of cilium movement, the directed, self-propelled movement of a cilium. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_CILIUM_BEAT_FREQUENCY
Systematic name | M22350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency of cilium movement, the directed, self-propelled movement of a cilium. [GOC:dph]
Full description |

Standard name | GO_NORADRENERGIC_NEURON_DIFFERENTIATION
Systematic name | M22351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of an noradrenergic neuron, a neuron that secretes noradrenaline. [GOC:dph]
Full description |

Standard name | GO_BRAINSTEM_DEVELOPMENT
Systematic name | M22352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the brainstem from its formation to the mature structure. The brainstem is the part of the brain that connects the brain with the spinal cord. [GOC:dph]
Full description |

Standard name | GO_DYNAMIN_FAMILY_PROTEIN_POLYMERIZATION_INVOLVED_IN_MEMBRANE_FISSION
Systematic name | M34058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of creating dynamin family protein polymers, compounds composed of a large number of dynamin family protein monomers. Dynamin family protein polymers form around lipid tubes and contribute to membrane fission. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_SPHINGOSINE_1_PHOSPHATE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the sphingolipid sphingosine-1-phosphate (S1P) binding to a receptor on the surface of the cell, and which proceeds with the activated receptor transmitting the signal by promoting the exchange of GDP for GTP on the alpha-subunit of an associated heterotrimeric G-protein complex. The pathway ends with regulation of a downstream cellular process, e.g. transcription. [GOC:ascb_2009, GOC:signaling, PMID:14592418, PMID:22001186, Reactome:R-HSA-419428]
Full description |

Standard name | GO_EPITHELIAL_CELL_MORPHOGENESIS
Systematic name | M15117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in form that occurs when an epithelial cell progresses from its initial formation to its mature state. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_AXIS_ELONGATION
Systematic name | M16254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental growth that results in the elongation of a line that defines polarity or symmetry in an anatomical structure. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_PLANAR_CELL_POLARITY_PATHWAY_INVOLVED_IN_AXIS_ELONGATION
Systematic name | M22355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of a Wnt protein to a receptor on the surface of the target cell where activated receptors signal to modulate cytoskeletal elements and control cell polarity that contributes to axis elongation. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_RETINAL_PIGMENT_EPITHELIUM_DEVELOPMENT
Systematic name | M34059
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the retinal pigment epithelium over time, from its initial formation to the mature structure. The retinal pigment epithelium is the melanin-containing layer of cells between the retina and the choroid that absorbs scattered and reflected light and removes waste products produced by the photoreceptor cells. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEURAL_RETINA_DEVELOPMENT
Systematic name | M11465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the neural retina over time from its initial formation to the mature structure. The neural retina is the part of the retina that contains neurons and photoreceptor cells. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_CHONDROCYTE_DIFFERENTIATION_INVOLVED_IN_ENDOCHONDRAL_BONE_MORPHOGENESIS
Systematic name | M22356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a chondroblast acquires specialized structural and/or functional features of a chondrocyte that will contribute to the development of a bone. A chondrocyte is a polymorphic cell that forms cartilage. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_CHONDROCYTE_HYPERTROPHY
Systematic name | M34060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The growth of a chondrocyte, where growth contributes to the progression of the chondrocyte over time. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_GROWTH_PLATE_CARTILAGE_DEVELOPMENT
Systematic name | M15986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the cartilage that will provide a scaffold for mineralization of endochondral bones as they elongate or grow. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_GROWTH_PLATE_CARTILAGE_CHONDROCYTE_DIFFERENTIATION
Systematic name | M22357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a chondroblast acquires specialized structural and/or functional features of a chondrocyte that will contribute to the growth of a bone. A chondrocyte is a polymorphic cell that forms cartilage. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_GROWTH_PLATE_CARTILAGE_CHONDROCYTE_DEVELOPMENT
Systematic name | M34061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a growth plate cartilage chondrocyte over time from after its fate commitment to the mature cell. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_CHONDROCYTE_DEVELOPMENT_INVOLVED_IN_ENDOCHONDRAL_BONE_MORPHOGENESIS
Systematic name | M22359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a chondrocyte over time from after its commitment to its mature state where the chondrocyte will contribute to the shaping of an endochondral bone. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_DETECTION_OF_CALCIUM_ION
Systematic name | M16957
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a calcium ion stimulus is received by a cell and converted into a molecular signal. [GOC:pg]
Full description |

Standard name | GO_CARBOHYDRATE_METABOLIC_PROCESS
Systematic name | M13504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving carbohydrates, any of a group of organic compounds based of the general formula Cx(H2O)y. Includes the formation of carbohydrate derivatives by the addition of a carbohydrate residue to another molecule. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_POLYSACCHARIDE_METABOLIC_PROCESS
Systematic name | M2986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a polysaccharide, a polymer of many (typically more than 10) monosaccharide residues linked glycosidically. [ISBN:0198547684]
Full description |

Standard name | GO_GLYCOGEN_BIOSYNTHETIC_PROCESS
Systematic name | M22360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of glycogen, a polydisperse, highly branched glucan composed of chains of D-glucose residues. [ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_GLYCOGEN_CATABOLIC_PROCESS
Systematic name | M22361
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of glycogen. [GOC:go_curators]
Full description |

Standard name | GO_DISACCHARIDE_METABOLIC_PROCESS
Systematic name | M22362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any disaccharide, sugars composed of two monosaccharide units. [GOC:jl, ISBN:0192800981]
Full description |

Standard name | GO_MONOSACCHARIDE_METABOLIC_PROCESS
Systematic name | M15452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving monosaccharides, the simplest carbohydrates. They are polyhydric alcohols containing either an aldehyde or a keto group and between three to ten or more carbon atoms. They form the constitutional repeating units of oligo- and polysaccharides. [ISBN:0198506732]
Full description |

Standard name | GO_FRUCTOSE_METABOLIC_PROCESS
Systematic name | M16959
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving fructose, the ketohexose arabino-2-hexulose. Fructose exists in a open chain form or as a ring compound. D-fructose is the sweetest of the sugars and is found free in a large number of fruits and honey. [ISBN:0198506732]
Full description |

Standard name | GO_FRUCTOSE_6_PHOSPHATE_METABOLIC_PROCESS
Systematic name | M22364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving fructose 6-phosphate, also known as F6P. The D-enantiomer is an important intermediate in glycolysis, gluconeogenesis, and fructose metabolism. [ISBN:0198506732]
Full description |

Standard name | GO_FRUCTOSE_2_6_BISPHOSPHATE_METABOLIC_PROCESS
Systematic name | M22365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving fructose 2,6-bisphosphate. The D enantiomer is an important regulator of the glycolytic and gluconeogenic pathways. It inhibits fructose 1,6-bisphosphatase and activates phosphofructokinase. [ISBN:0198506732]
Full description |

Standard name | GO_FUCOSE_METABOLIC_PROCESS
Systematic name | M14604
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving fucose, or 6-deoxygalactose, which has two enantiomers, D-fucose and L-fucose. [ISBN:0198506732]
Full description |

Standard name | GO_GLUCOSE_METABOLIC_PROCESS
Systematic name | M13870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glucose, the aldohexose gluco-hexose. D-glucose is dextrorotatory and is sometimes known as dextrose; it is an important source of energy for living organisms and is found free as well as combined in homo- and hetero-oligosaccharides and polysaccharides. [ISBN:0198506732]
Full description |

Standard name | GO_GLUCOSE_CATABOLIC_PROCESS
Systematic name | M15777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glucose, the aldohexose gluco-hexose. [GOC:ai]
Full description |

Standard name | GO_UDP_GLUCOSE_METABOLIC_PROCESS
Systematic name | M29023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving UDP-glucose, uridinediphosphoglucose, a substance composed of glucose in glycosidic linkage with uridine diphosphate. [GOC:ai]
Full description |

Standard name | GO_GALACTOSE_METABOLIC_PROCESS
Systematic name | M13218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving galactose, the aldohexose galacto-hexose. D-galactose is widely distributed in combined form in plants, animals and microorganisms as a constituent of oligo- and polysaccharides; it also occurs in galactolipids and as its glucoside in lactose and melibiose. [ISBN:0198506732]
Full description |

Standard name | GO_MANNOSE_METABOLIC_PROCESS
Systematic name | M22366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving mannose, the aldohexose manno-hexose, the C-2 epimer of glucose. The D-(+)-form is widely distributed in mannans and hemicelluloses and is of major importance in the core oligosaccharide of N-linked oligosaccharides of glycoproteins. [ISBN:0198506732]
Full description |

Standard name | GO_INOSITOL_METABOLIC_PROCESS
Systematic name | M13490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving inositol, 1,2,3,4,5,6-cyclohexanehexol, a growth factor for animals and microorganisms. [ISBN:0198547684]
Full description |

Standard name | GO_AMINOGLYCAN_METABOLIC_PROCESS
Systematic name | M13402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving aminoglycans, any polymer containing amino groups that consists of more than about 10 monosaccharide residues joined to each other by glycosidic linkages. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_AMINOGLYCAN_BIOSYNTHETIC_PROCESS
Systematic name | M11847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of aminoglycans, any polymer containing amino groups that consists of more than about 10 monosaccharide residues joined to each other by glycosidic linkages. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_AMINOGLYCAN_CATABOLIC_PROCESS
Systematic name | M16015
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of aminoglycans, any polymer containing amino groups that consists of more than about 10 monosaccharide residues joined to each other by glycosidic linkages. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_PROTEOGLYCAN_METABOLIC_PROCESS
Systematic name | M880
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving proteoglycans, any glycoprotein in which the carbohydrate units are glycosaminoglycans. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_CHITIN_METABOLIC_PROCESS
Systematic name | M34062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving chitin, a linear polysaccharide consisting of beta-(1->4)-linked N-acetyl-D-glucosamine residues. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_AMINO_SUGAR_METABOLIC_PROCESS
Systematic name | M13955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any amino sugar, sugars containing an amino group in place of a hydroxyl group. [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_N_ACETYLGLUCOSAMINE_METABOLIC_PROCESS
Systematic name | M18664
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving N-acetylglucosamine. The D isomer is a common structural unit of glycoproteins in plants, bacteria and animals; it is often the terminal sugar of an oligosaccharide group of a glycoprotein. [ISBN:0198506732]
Full description |

Standard name | GO_UDP_N_ACETYLGLUCOSAMINE_METABOLIC_PROCESS
Systematic name | M15333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving UDP-N-acetylglucosamine, a substance composed of N-acetylglucosamine, a common structural unit of oligosaccharides, in glycosidic linkage with uridine diphosphate. [GOC:ai]
Full description |

Standard name | GO_UDP_N_ACETYLGLUCOSAMINE_BIOSYNTHETIC_PROCESS
Systematic name | M22368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of UDP-N-acetylglucosamine, a substance composed of N-acetylglucosamine, a common structural unit of oligosaccharides, in glycosidic linkage with uridine diphosphate. [GOC:ai]
Full description |

Standard name | GO_N_ACETYLNEURAMINATE_METABOLIC_PROCESS
Systematic name | M29024
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving N-acetylneuraminate, the anion of 5-(acetylamino)-3,5-dideoxy-D-glycero-D-galacto-non-3-ulosonic acid. [ISBN:0198506732]
Full description |

Standard name | GO_URONIC_ACID_METABOLIC_PROCESS
Systematic name | M14675
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving uronic acid, any monocarboxylic acid formally derived by oxidizing to a carboxyl group the terminal hydroxymethylene group of either an aldose with four or more carbon atoms in the molecule, or of any glycoside derived from such an aldose. [ISBN:0198506732]
Full description |

Standard name | GO_ALCOHOL_METABOLIC_PROCESS
Systematic name | M17063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving alcohols, any of a class of compounds containing one or more hydroxyl groups attached to a saturated carbon atom. [ISBN:0198506732]
Full description |

Standard name | GO_ETHANOL_METABOLIC_PROCESS
Systematic name | M29025
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving ethanol, CH3-CH2-OH, a colorless, water-miscible, flammable liquid produced by alcoholic fermentation. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_ETHANOL_CATABOLIC_PROCESS
Systematic name | M29026
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of ethanol, CH3-CH2-OH, a colorless, water-miscible, flammable liquid produced by alcoholic fermentation. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_ETHANOL_OXIDATION
Systematic name | M22369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An ethanol metabolic process in which ethanol is converted to acetyl-CoA via acetaldehyde and acetate. [GOC:mah, MetaCyc:PWY66-161, MetaCyc:PWY66-162, MetaCyc:PWY66-21]
Full description |

Standard name | GO_GLYCEROL_3_PHOSPHATE_METABOLIC_PROCESS
Systematic name | M29027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycerol-3-phosphate, a phosphoric monoester of glycerol. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_CELLULAR_GLUCAN_METABOLIC_PROCESS
Systematic name | M16733
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glucans, polysaccharides consisting only of glucose residues, occurring at the level of an individual cell. [ISBN:0198547684]
Full description |

Standard name | GO_CELLULAR_ALDEHYDE_METABOLIC_PROCESS
Systematic name | M14307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving aldehydes, any organic compound with the formula R-CH=O, as carried out by individual cells. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_ORGANIC_ACID_METABOLIC_PROCESS
Systematic name | M14117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving organic acids, any acidic compound containing carbon in covalent linkage. [ISBN:0198506732]
Full description |

Standard name | GO_ACETYL_COA_METABOLIC_PROCESS
Systematic name | M11586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving acetyl-CoA, a derivative of coenzyme A in which the sulfhydryl group is acetylated; it is a metabolite derived from several pathways (e.g. glycolysis, fatty acid oxidation, amino-acid catabolism) and is further metabolized by the tricarboxylic acid cycle. It is a key intermediate in lipid and terpenoid biosynthesis. [ISBN:0198547684]
Full description |

Standard name | GO_ACETYL_COA_BIOSYNTHETIC_PROCESS
Systematic name | M14802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of acetyl-CoA, a derivative of coenzyme A in which the sulfhydryl group is acetylated. [GOC:go_curators]
Full description |

Standard name | GO_ACETYL_COA_BIOSYNTHETIC_PROCESS_FROM_PYRUVATE
Systematic name | M22370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of acetyl-CoA from pyruvate. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_LACTATE_METABOLIC_PROCESS
Systematic name | M22371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving lactate, the anion of lactic acid. [ISBN:0198547684]
Full description |

Standard name | GO_PYRUVATE_METABOLIC_PROCESS
Systematic name | M15816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving pyruvate, 2-oxopropanoate. [GOC:go_curators]
Full description |

Standard name | GO_GENERATION_OF_PRECURSOR_METABOLITES_AND_ENERGY
Systematic name | M1210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of precursor metabolites, substances from which energy is derived, and any process involved in the liberation of energy from these substances. [GOC:jl]
Full description |

Standard name | GO_TRICARBOXYLIC_ACID_CYCLE
Systematic name | M22373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A nearly universal metabolic pathway in which the acetyl group of acetyl coenzyme A is effectively oxidized to two CO2 and four pairs of electrons are transferred to coenzymes. The acetyl group combines with oxaloacetate to form citrate, which undergoes successive transformations to isocitrate, 2-oxoglutarate, succinyl-CoA, succinate, fumarate, malate, and oxaloacetate again, thus completing the cycle. In eukaryotes the tricarboxylic acid is confined to the mitochondria. See also glyoxylate cycle. [ISBN:0198506732]
Full description |

Standard name | GO_CITRATE_METABOLIC_PROCESS
Systematic name | M29029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving citrate, 2-hydroxy-1,2,3-propanetricarboyxlate. Citrate is widely distributed in nature and is an important intermediate in the TCA cycle and the glyoxylate cycle. [ISBN:0198506732]
Full description |

Standard name | GO_ISOCITRATE_METABOLIC_PROCESS
Systematic name | M22374
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving isocitrate, the anion of isocitric acid, 1-hydroxy-1,2,3-propanetricarboxylic acid. Isocitrate is an important intermediate in the TCA cycle and the glycoxylate cycle. [ISBN:0198506732]
Full description |

Standard name | GO_2_OXOGLUTARATE_METABOLIC_PROCESS
Systematic name | M15857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving oxoglutarate, the dianion of 2-oxoglutaric acid. It is a key constituent of the TCA cycle and a key intermediate in amino-acid metabolism. [ISBN:0198506732]
Full description |

Standard name | GO_SUCCINYL_COA_METABOLIC_PROCESS
Systematic name | M22375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving succinyl-CoA, a compound composed of the monovalent acyl group 3-carboxypropanoyl, derived from succinic acid by loss of one OH group, linked to coenzyme A. [GOC:ai]
Full description |

Standard name | GO_SUCCINATE_METABOLIC_PROCESS
Systematic name | M22376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving succinate, also known as butanedioate or ethane dicarboxylate, the dianion of succinic acid. Succinate is an important intermediate in metabolism and a component of the TCA cycle. [ISBN:0198506732]
Full description |

Standard name | GO_OXALOACETATE_METABOLIC_PROCESS
Systematic name | M11435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving oxaloacetate, the anion of oxobutanedioic acid, an important intermediate in metabolism, especially as a component of the TCA cycle. [ISBN:0198506732]
Full description |

Standard name | GO_MALATE_METABOLIC_PROCESS
Systematic name | M22377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving malate, the anion of hydroxybutanedioic acid, a chiral hydroxydicarboxylic acid. The (+) enantiomer is an important intermediate in metabolism as a component of both the TCA cycle and the glyoxylate cycle. [ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_CARBOHYDRATE_METABOLIC_PROCESS
Systematic name | M12731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving carbohydrates. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_GLUCONEOGENESIS
Systematic name | M16528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gluconeogenesis, the formation of glucose from noncarbohydrate precursors, such as pyruvate, amino acids and glycerol. [GOC:go_curators]
Full description |

Standard name | GO_ENERGY_RESERVE_METABOLIC_PROCESS
Systematic name | M18828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways by which a cell derives energy from stored compounds such as fats or glycogen. [GOC:mah]
Full description |

Standard name | GO_FERMENTATION
Systematic name | M29030
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The anaerobic enzymatic conversion of organic compounds, especially carbohydrates, coupling the oxidation and reduction of NAD/H and the generation of adenosine triphosphate (ATP). [GOC:curators, ISBN:0201090910, MetaCyc:Fermentation]
Full description |

Standard name | GO_OXIDATIVE_PHOSPHORYLATION
Systematic name | M12919
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The phosphorylation of ADP to ATP that accompanies the oxidation of a metabolite through the operation of the respiratory chain. Oxidation of compounds establishes a proton gradient across the membrane, providing the energy for ATP synthesis. [ISBN:0198506732, ISBN:0471331309]
Full description |

Standard name | GO_MITOCHONDRIAL_ELECTRON_TRANSPORT_NADH_TO_UBIQUINONE
Systematic name | M22379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of electrons from NADH to ubiquinone that occurs during oxidative phosphorylation. [ISBN:0716731363]
Full description |

Standard name | GO_MITOCHONDRIAL_ELECTRON_TRANSPORT_UBIQUINOL_TO_CYTOCHROME_C
Systematic name | M12278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of electrons from ubiquinol to cytochrome c that occurs during oxidative phosphorylation, mediated by the multisubunit enzyme known as complex III. [ISBN:0716731363]
Full description |

Standard name | GO_REGULATION_OF_NUCLEOTIDE_METABOLIC_PROCESS
Systematic name | M15679
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving nucleotides. [GOC:go_curators]
Full description |

Standard name | GO_PURINE_NUCLEOBASE_METABOLIC_PROCESS
Systematic name | M14439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving purine nucleobases, one of the two classes of nitrogen-containing ring compounds found in DNA and RNA, which include adenine and guanine. [GOC:go_curators]
Full description |

Standard name | GO_PURINE_NUCLEOSIDE_CATABOLIC_PROCESS
Systematic name | M14480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of purine nucleoside, one of a family of organic molecules consisting of a purine base covalently bonded to a sugar ribose (a ribonucleoside) or deoxyribose (a deoxyribonucleoside). [GOC:go_curators]
Full description |

Standard name | GO_PURINE_RIBONUCLEOSIDE_SALVAGE
Systematic name | M22380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which produces a purine nucleoside from derivatives of it, without de novo synthesis. [GOC:jl]
Full description |

Standard name | GO_AMP_BIOSYNTHETIC_PROCESS
Systematic name | M22381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of AMP, adenosine monophosphate. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_CAMP_BIOSYNTHETIC_PROCESS
Systematic name | M11264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of the nucleotide cAMP (cyclic AMP, adenosine 3',5'-cyclophosphate). [ISBN:0198506732]
Full description |

Standard name | GO_ADP_BIOSYNTHETIC_PROCESS
Systematic name | M22382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of ADP, adenosine 5'-diphosphate. [GOC:ai]
Full description |

Standard name | GO_CGMP_BIOSYNTHETIC_PROCESS
Systematic name | M10878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of cyclic GMP, guanosine 3',5'-phosphate. [ISBN:0198506732]
Full description |

Standard name | GO_GTP_BIOSYNTHETIC_PROCESS
Systematic name | M22383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of GTP, guanosine triphosphate. [ISBN:0198506732]
Full description |

Standard name | GO_IMP_BIOSYNTHETIC_PROCESS
Systematic name | M16175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of IMP, inosine monophosphate. [ISBN:0198506732]
Full description |

Standard name | GO_DE_NOVO_IMP_BIOSYNTHETIC_PROCESS
Systematic name | M22384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of IMP, inosine monophosphate, by the stepwise assembly of a purine ring on ribose 5-phosphate. [GOC:mah, ISBN:0716720094]
Full description |

Standard name | GO_CAMP_CATABOLIC_PROCESS
Systematic name | M22385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of the nucleotide cAMP (cyclic AMP, adenosine 3',5'-cyclophosphate). [ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOBASE_METABOLIC_PROCESS
Systematic name | M11748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving pyrimidine nucleobases, 1,3-diazine, organic nitrogenous bases. [GOC:go_curators]
Full description |

Standard name | GO_DE_NOVO_PYRIMIDINE_NUCLEOBASE_BIOSYNTHETIC_PROCESS
Systematic name | M22386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of pyrimidine nucleobases, 1,3-diazine, organic nitrogenous bases, beginning with the synthesis of a pyrimidine ring from simpler precursors. [GOC:mah, ISBN:0716720094]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOSIDE_METABOLIC_PROCESS
Systematic name | M15692
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any pyrimidine nucleoside, one of a family of organic molecules consisting of a pyrimidine base covalently bonded to ribose (a ribonucleoside) or deoxyribose (a deoxyribonucleoside). [GOC:jl, ISBN:0140512713]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOTIDE_METABOLIC_PROCESS
Systematic name | M12372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a pyrimidine nucleotide, a compound consisting of nucleoside (a pyrimidine base linked to a deoxyribose or ribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOTIDE_BIOSYNTHETIC_PROCESS
Systematic name | M10521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a pyrimidine nucleotide, a compound consisting of nucleoside (a pyrimidine base linked to a deoxyribose or ribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOTIDE_CATABOLIC_PROCESS
Systematic name | M12633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a pyrimidine nucleotide, a compound consisting of nucleoside (a pyrimidine base linked to a deoxyribose or ribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_DNA_METABOLIC_PROCESS
Systematic name | M17815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular metabolic process involving deoxyribonucleic acid. This is one of the two main types of nucleic acid, consisting of a long, unbranched macromolecule formed from one, or more commonly, two, strands of linked deoxyribonucleotides. [ISBN:0198506732]
Full description |

Standard name | GO_DNA_REPLICATION
Systematic name | M16148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular metabolic process in which a cell duplicates one or more molecules of DNA. DNA replication begins when specific sequences, known as origins of replication, are recognized and bound by initiation proteins, and ends when the original DNA molecule has been completely duplicated and the copies topologically separated. The unit of replication usually corresponds to the genome of the cell, an organelle, or a virus. The template for replication can either be an existing DNA molecule or RNA. [GOC:mah]
Full description |

Standard name | GO_DNA_DEPENDENT_DNA_REPLICATION
Systematic name | M18074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A DNA replication process that uses parental DNA as a template for the DNA-dependent DNA polymerases that synthesize the new strands. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_MITOCHONDRIAL_DNA_REPLICATION
Systematic name | M22390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which new strands of DNA are synthesized in the mitochondrion. [GOC:ai]
Full description |

Standard name | GO_DNA_TOPOLOGICAL_CHANGE
Systematic name | M22391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a transformation is induced in the topological structure of a double-stranded DNA helix, resulting in a change in linking number. [ISBN:071673706X, ISBN:0935702490]
Full description |

Standard name | GO_DNA_LIGATION
Systematic name | M15868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The re-formation of a broken phosphodiester bond in the DNA backbone, carried out by DNA ligase. [ISBN:0815316194]
Full description |

Standard name | GO_DNA_UNWINDING_INVOLVED_IN_DNA_REPLICATION
Systematic name | M22392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which interchain hydrogen bonds between two strands of DNA are broken or 'melted', generating unpaired template strands for DNA replication. [ISBN:071673706X, ISBN:0815316194]
Full description |

Standard name | GO_DNA_REPLICATION_SYNTHESIS_OF_RNA_PRIMER
Systematic name | M22393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of a short RNA polymer, usually 4-15 nucleotides long, using one strand of unwound DNA as a template; the RNA then serves as a primer from which DNA polymerases extend synthesis. [PMID:11395402]
Full description |

Standard name | GO_DNA_REPLICATION_INITIATION
Systematic name | M3528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which DNA-dependent DNA replication is started; this begins with the ATP dependent loading of an initiator complex onto the DNA, this is followed by DNA melting and helicase activity. In bacteria, the gene products that enable the helicase activity are loaded after the initial melting and in archaea and eukaryotes, the gene products that enable the helicase activity are inactive when they are loaded and subsequently activate. [ISBN:071673706X, ISBN:0815316194, PMID:28209641]
Full description |

Standard name | GO_DNA_STRAND_ELONGATION_INVOLVED_IN_DNA_REPLICATION
Systematic name | M11000
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an existing DNA strand is extended by activities including the addition of nucleotides to the 3' end of the strand, complementary to an existing template, as part of DNA replication. [GOC:mah, ISBN:071673706X, ISBN:0815316194]
Full description |

Standard name | GO_REGULATION_OF_DNA_REPLICATION
Systematic name | M8566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA replication. [GOC:go_curators]
Full description |

Standard name | GO_RNA_DEPENDENT_DNA_BIOSYNTHETIC_PROCESS
Systematic name | M10089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A DNA biosynthetic process that uses RNA as a template for RNA-dependent DNA polymerases (e.g. reverse transcriptase) that synthesize the new strand. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_DNA_REPAIR
Systematic name | M18229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of restoring DNA after damage. Genomes are subject to damage by chemical and physical agents in the environment (e.g. UV and ionizing radiations, chemical mutagens, fungal and bacterial toxins, etc.) and by free radicals or alkylating agents endogenously generated in metabolism. DNA is also damaged because of errors during its replication. A variety of different DNA repair pathways have been reported that include direct reversal, base excision repair, nucleotide excision repair, photoreactivation, bypass, double-strand break repair pathway, and mismatch repair pathway. [PMID:11563486]
Full description |

Standard name | GO_REGULATION_OF_DNA_REPAIR
Systematic name | M11674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA repair. [GOC:go_curators]
Full description |

Standard name | GO_TRANSCRIPTION_COUPLED_NUCLEOTIDE_EXCISION_REPAIR
Systematic name | M10862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The nucleotide-excision repair process that carries out preferential repair of DNA lesions on the actively transcribed strand of the DNA duplex. In addition, the transcription-coupled nucleotide-excision repair pathway is required for the recognition and repair of a small subset of lesions that are not recognized by the global genome nucleotide excision repair pathway. [PMID:10197977, PMID:11900249]
Full description |

Standard name | GO_BASE_EXCISION_REPAIR
Systematic name | M2350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | In base excision repair, an altered base is removed by a DNA glycosylase enzyme, followed by excision of the resulting sugar phosphate. The small gap left in the DNA helix is filled in by the sequential action of DNA polymerase and DNA ligase. [ISBN:0815316194]
Full description |

Standard name | GO_BASE_EXCISION_REPAIR_AP_SITE_FORMATION
Systematic name | M22394
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of an AP site, a deoxyribose sugar with a missing base, by DNA glycosylase which recognizes an altered base in DNA and catalyzes its hydrolytic removal. This sugar phosphate is the substrate recognized by the AP endonuclease, which cuts the DNA phosphodiester backbone at the 5' side of the altered site to leave a gap which is subsequently repaired. [ISBN:0815316194]
Full description |

Standard name | GO_BASE_EXCISION_REPAIR_GAP_FILLING
Systematic name | M22395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Repair of the damaged strand by the combined action of an apurinic endouclease that degrades a few bases on the damaged strand and a polymerase that synthesizes a 'patch' in the 5' to 3' direction, using the undamaged strand as a template. [ISBN:1550091131]
Full description |

Standard name | GO_NUCLEOTIDE_EXCISION_REPAIR
Systematic name | M12281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A DNA repair process in which a small region of the strand surrounding the damage is removed from the DNA helix as an oligonucleotide. The small gap left in the DNA helix is filled in by the sequential action of DNA polymerase and DNA ligase. Nucleotide excision repair recognizes a wide range of substrates, including damage caused by UV irradiation (pyrimidine dimers and 6-4 photoproducts) and chemicals (intrastrand cross-links and bulky adducts). [PMID:10197977]
Full description |

Standard name | GO_PYRIMIDINE_DIMER_REPAIR
Systematic name | M22396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The repair of UV-induced T-T, C-T and C-C dimers. [ISBN:0815316194]
Full description |

Standard name | GO_NUCLEOTIDE_EXCISION_REPAIR_PREINCISION_COMPLEX_STABILIZATION
Systematic name | M34063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The stabilization of the multiprotein complex involved in damage recognition, DNA helix unwinding, and endonucleolytic cleavage at the site of DNA damage as well as the unwound DNA. The stabilization of the protein-DNA complex ensures proper positioning of the preincision complex before the phosphodiester backbone of the damaged strand is cleaved 3' and 5' of the site of DNA damage. [GOC:elh, PMID:10197977]
Full description |

Standard name | GO_NUCLEOTIDE_EXCISION_REPAIR_PREINCISION_COMPLEX_ASSEMBLY
Systematic name | M13046
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins on DNA to form the multiprotein complex involved in damage recognition, DNA helix unwinding, and endonucleolytic cleavage at the site of DNA damage. This assembly occurs before the phosphodiester backbone of the damaged strand is cleaved 3' and 5' of the site of DNA damage. [GOC:elh, PMID:10197977]
Full description |

Standard name | GO_NUCLEOTIDE_EXCISION_REPAIR_DNA_GAP_FILLING
Systematic name | M13298
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Repair of the gap in the DNA helix by DNA polymerase and DNA ligase after the portion of the strand containing the lesion has been removed by pyrimidine-dimer repair enzymes. [ISBN:0815316194]
Full description |

Standard name | GO_MISMATCH_REPAIR
Systematic name | M14852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A system for the correction of errors in which an incorrect base, which cannot form hydrogen bonds with the corresponding base in the parent strand, is incorporated into the daughter strand. The mismatch repair system promotes genomic fidelity by repairing base-base mismatches, insertion-deletion loops and heterologies generated during DNA replication and recombination. [ISBN:0198506732, PMID:11687886]
Full description |

Standard name | GO_POSTREPLICATION_REPAIR
Systematic name | M11368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The conversion of DNA-damage induced single-stranded gaps into large molecular weight DNA after replication. Includes pathways that remove replication-blocking lesions in conjunction with DNA replication. [GOC:elh]
Full description |

Standard name | GO_DOUBLE_STRAND_BREAK_REPAIR
Systematic name | M3162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The repair of double-strand breaks in DNA via homologous and nonhomologous mechanisms to reform a continuous DNA helix. [GOC:elh]
Full description |

Standard name | GO_DNA_MODIFICATION
Systematic name | M12430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent alteration of one or more nucleotide sites in DNA, resulting in a change in its properties. [GOC:jl, GOC:ma]
Full description |

Standard name | GO_DNA_METHYLATION
Systematic name | M22397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent transfer of a methyl group to either N-6 of adenine or C-5 or N-4 of cytosine. [GOC:ems, ISBN:0198506732]
Full description |

Standard name | GO_DNA_DEALKYLATION_INVOLVED_IN_DNA_REPAIR
Systematic name | M22398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The repair of alkylation damage, e.g. the removal of the alkyl group at the O6-position of guanine by O6-alkylguanine-DNA alkyltransferase (AGT). [PMID:10946226]
Full description |

Standard name | GO_DNA_CATABOLIC_PROCESS
Systematic name | M1174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular DNA metabolic process resulting in the breakdown of DNA, deoxyribonucleic acid, one of the two main types of nucleic acid, consisting of a long unbranched macromolecule formed from one or two strands of linked deoxyribonucleotides, the 3'-phosphate group of each constituent deoxyribonucleotide being joined in 3',5'-phosphodiester linkage to the 5'-hydroxyl group of the deoxyribose moiety of the next one. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_APOPTOTIC_DNA_FRAGMENTATION
Systematic name | M15701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cleavage of DNA during apoptosis, which usually occurs in two stages: cleavage into fragments of about 50 kbp followed by cleavage between nucleosomes to yield 200 bp fragments. [GOC:dph, GOC:mah, GOC:mtg_apoptosis, GOC:tb, ISBN:0721639976, PMID:15723341, PMID:23379520]
Full description |

Standard name | GO_DNA_RECOMBINATION
Systematic name | M18489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a new genotype is formed by reassortment of genes resulting in gene combinations different from those that were present in the parents. In eukaryotes genetic recombination can occur by chromosome assortment, intrachromosomal recombination, or nonreciprocal interchromosomal recombination. Interchromosomal recombination occurs by crossing over. In bacteria it may occur by genetic transformation, conjugation, transduction, or F-duction. [ISBN:0198506732]
Full description |

Standard name | GO_MITOTIC_RECOMBINATION
Systematic name | M14528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The exchange, reciprocal or nonreciprocal, of genetic material between one DNA molecule and a homologous region of DNA that occurs during mitotic cell cycles. [GOC:elh]
Full description |

Standard name | GO_DNA_PACKAGING
Systematic name | M16215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which DNA and associated proteins are formed into a compact, orderly structure. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_CHROMATIN_ORGANIZATION
Systematic name | M13550
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in the specification, formation or maintenance of the physical structure of eukaryotic chromatin. [GOC:mah, GOC:vw, PMID:20404130]
Full description |

Standard name | GO_CHROMATIN_ASSEMBLY_OR_DISASSEMBLY
Systematic name | M12115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation or destruction of chromatin structures. [GOC:mah]
Full description |

Standard name | GO_NUCLEOSOME_ASSEMBLY
Systematic name | M34064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a nucleosome, the beadlike structural units of eukaryotic chromatin composed of histones and DNA. [GOC:mah]
Full description |

Standard name | GO_CHROMATIN_REMODELING
Systematic name | M15726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Dynamic structural changes to eukaryotic chromatin occurring throughout the cell division cycle. These changes range from the local changes necessary for transcriptional regulation to global changes necessary for chromosome segregation. [GOC:jid, GOC:vw, PMID:12697820]
Full description |

Standard name | GO_CHROMATIN_SILENCING
Systematic name | M34065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Repression of transcription by altering the structure of chromatin, e.g. by conversion of large regions of DNA into an inaccessible state often called heterochromatin. [GOC:mah, PMID:10219245]
Full description |

Standard name | GO_DNA_METHYLATION_DEPENDENT_HETEROCHROMATIN_ASSEMBLY
Systematic name | M12288
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Repression of transcription by methylation of DNA, leading to the formation of heterochromatin. [GOC:mah]
Full description |

Standard name | GO_CHROMATIN_SILENCING_AT_TELOMERE
Systematic name | M22399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Repression of transcription of telomeric DNA by altering the structure of chromatin. [PMID:10219245]
Full description |

Standard name | GO_REGULATION_OF_GENE_EXPRESSION_BY_GENETIC_IMPRINTING
Systematic name | M12528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Heritable alterations in the activity of a gene that depend on whether it passed through the paternal or the maternal germline, but that are not encoded by DNA itself. [GOC:ems, ISBN:0198506732, PMID:11498578]
Full description |

Standard name | GO_DNA_TEMPLATED_TRANSCRIPTION_INITIATION
Systematic name | M13823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the assembly of the RNA polymerase preinitiation complex (PIC) at the core promoter region of a DNA template, resulting in the subsequent synthesis of RNA from that promoter. The initiation phase includes PIC assembly and the formation of the first few bonds in the RNA chain, including abortive initiation, which occurs when the first few nucleotides are repeatedly synthesized and then released. The initiation phase ends just before and does not include promoter clearance, or release, which is the transition between the initiation and elongation phases of transcription. [GOC:jid, GOC:txnOH, PMID:18280161]
Full description |

Standard name | GO_DNA_TEMPLATED_TRANSCRIPTION_TERMINATION
Systematic name | M10551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular process that completes DNA-templated transcription; the formation of phosphodiester bonds ceases, the RNA-DNA hybrid dissociates, and RNA polymerase releases the DNA. [GOC:txnOH, ISBN:0716720094, PMID:15020047, PMID:18280161]
Full description |

Standard name | GO_DNA_TEMPLATED_TRANSCRIPTION_ELONGATION
Systematic name | M19211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The extension of an RNA molecule after transcription initiation and promoter clearance at a DNA-dependent RNA polymerase promoter by the addition of ribonucleotides catalyzed by an RNA polymerase. [GOC:mah, GOC:txnOH, PMID:15020047, PMID:18280161]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_BY_RNA_POLYMERASE_I
Systematic name | M22400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transcription mediated by RNA polymerase I. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_BY_RNA_POLYMERASE_III
Systematic name | M22401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transcription mediated by RNA ploymerase III. [GOC:go_curators]
Full description |

Standard name | GO_TRANSCRIPTION_BY_RNA_POLYMERASE_I
Systematic name | M22402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of RNA from a DNA template by RNA polymerase I (RNAP I), originating at an RNAP I promoter. [GOC:jl, GOC:txnOH]
Full description |

Standard name | GO_TRANSCRIPTION_INITIATION_FROM_RNA_POLYMERASE_I_PROMOTER
Systematic name | M22403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the assembly of the RNA polymerase I preinitiation complex (PIC) at an RNA polymerase I promoter region of a DNA template, resulting in the subsequent synthesis of RNA from that promoter. The initiation phase includes PIC assembly and the formation of the first few bonds in the RNA chain, including abortive initiation, which occurs when the first few nucleotides are repeatedly synthesized and then released. Promoter clearance, or release, is the transition between the initiation and elongation phases of transcription. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_TRANSCRIPTION_ELONGATION_FROM_RNA_POLYMERASE_I_PROMOTER
Systematic name | M22404
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The extension of an RNA molecule after transcription initiation and promoter clearance at an RNA polymerase I specific promoter by the addition of ribonucleotides catalyzed by RNA polymerase I. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_TERMINATION_OF_RNA_POLYMERASE_I_TRANSCRIPTION
Systematic name | M22405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the synthesis of an RNA molecule by RNA polymerase I using a DNA template is completed. RNAP I termination requires binding of a terminator protein so specific sequences downstream of the transcription unit. [GOC:mah, GOC:txnOH, PMID:10684922]
Full description |

Standard name | GO_TRANSCRIPTION_INITIATION_FROM_RNA_POLYMERASE_II_PROMOTER
Systematic name | M13899
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the assembly of the RNA polymerase II preinitiation complex (PIC) at an RNA polymerase II promoter region of a DNA template, resulting in the subsequent synthesis of RNA from that promoter. The initiation phase includes PIC assembly and the formation of the first few bonds in the RNA chain, including abortive initiation, which occurs when the first few nucleotides are repeatedly synthesized and then released. Promoter clearance, or release, is the transition between the initiation and elongation phases of transcription. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_TRANSCRIPTION_ELONGATION_FROM_RNA_POLYMERASE_II_PROMOTER
Systematic name | M12918
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The extension of an RNA molecule after transcription initiation and promoter clearance at an RNA polymerase II promoter by the addition of ribonucleotides catalyzed by RNA polymerase II. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_TERMINATION_OF_RNA_POLYMERASE_II_TRANSCRIPTION
Systematic name | M14029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the synthesis of an RNA molecule by RNA polymerase II using a DNA template is completed. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_MRNA_SPLICE_SITE_SELECTION
Systematic name | M1426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Selection of a splice site by components of the assembling spliceosome. [GOC:krc, ISBN:0879695897]
Full description |

Standard name | GO_MRNA_CLEAVAGE
Systematic name | M13747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a pre-mRNA or mRNA molecule is cleaved at specific sites or in a regulated manner. [GOC:mah]
Full description |

Standard name | GO_ADENOSINE_TO_INOSINE_EDITING
Systematic name | M22406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The conversion of an adenosine residue to inosine in an RNA molecule by deamination. [PMID:11092837]
Full description |

Standard name | GO_TRANSCRIPTION_BY_RNA_POLYMERASE_III
Systematic name | M11167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of RNA from a DNA template by RNA polymerase III, originating at an RNAP III promoter. [GOC:jl, GOC:txnOH, PMID:12381659]
Full description |

Standard name | GO_TRANSCRIPTION_INITIATION_FROM_RNA_POLYMERASE_III_PROMOTER
Systematic name | M22408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the assembly of the RNA polymerase III preinitiation complex (PIC) at an RNA polymerase III promoter region of a DNA template, resulting in the subsequent synthesis of RNA from that promoter. The initiation phase includes PIC assembly and the formation of the first few bonds in the RNA chain, including abortive initiation, which occurs when the first few nucleotides are repeatedly synthesized and then released. Promoter clearance, or release, is the transition between the initiation and elongation phases of transcription. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_MITOCHONDRIAL_TRANSCRIPTION
Systematic name | M22409
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of RNA from a mitochondrial DNA template, usually by a specific mitochondrial RNA polymerase. [GOC:jl]
Full description |

Standard name | GO_RNA_PROCESSING
Systematic name | M9529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the conversion of one or more primary RNA transcripts into one or more mature RNA molecules. [GOC:mah]
Full description |

Standard name | GO_MRNA_PROCESSING
Systematic name | M2472
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the conversion of a primary mRNA transcript into one or more mature mRNA(s) prior to translation into polypeptide. [GOC:mah]
Full description |

Standard name | GO_MRNA_3_END_PROCESSING_BY_STEM_LOOP_BINDING_AND_CLEAVAGE
Systematic name | M22410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any mRNA 3'-end processing that involves the binding to and cleavage of a stem-loop structure. For example, histone mRNAs contain a highly conserved stem-loop sequence at the 3' end of the mRNA with a 6 base pairs (bp) stem and a 4-nt loop. The mRNA is cleaved between these two elements, after the fourth or fifth nucleotide, which is typically an adenosine. [GOC:mah, GOC:tb, PMID:17998288]
Full description |

Standard name | GO_TRNA_METABOLIC_PROCESS
Systematic name | M10958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving tRNA, transfer RNA, a class of relatively small RNA molecules responsible for mediating the insertion of amino acids into the sequence of nascent polypeptide chains during protein synthesis. Transfer RNA is characterized by the presence of many unusual minor bases, the function of which has not been completely established. [ISBN:0198506732]
Full description |

Standard name | GO_TRNA_MODIFICATION
Systematic name | M16875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent alteration of one or more nucleotides within a tRNA molecule to produce a tRNA molecule with a sequence that differs from that coded genetically. [GOC:curators]
Full description |

Standard name | GO_RNA_CATABOLIC_PROCESS
Systematic name | M12276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of RNA, ribonucleic acid, one of the two main type of nucleic acid, consisting of a long, unbranched macromolecule formed from ribonucleotides joined in 3',5'-phosphodiester linkage. [ISBN:0198506732]
Full description |

Standard name | GO_RNA_LOCALIZATION
Systematic name | M16023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which RNA is transported to, or maintained in, a specific location. [GOC:ai]
Full description |

Standard name | GO_RNA_EXPORT_FROM_NUCLEUS
Systematic name | M22411
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of RNA from the nucleus to the cytoplasm. [GOC:ma]
Full description |

Standard name | GO_MRNA_EXPORT_FROM_NUCLEUS
Systematic name | M22412
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of mRNA from the nucleus to the cytoplasm. [GOC:ma]
Full description |

Standard name | GO_TRANSLATIONAL_INITIATION
Systematic name | M11328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process preceding formation of the peptide bond between the first two amino acids of a protein. This includes the formation of a complex of the ribosome, mRNA or circRNA, and an initiation complex that contains the first aminoacyl-tRNA. [ISBN:019879276X]
Full description |

Standard name | GO_TRANSLATIONAL_ELONGATION
Systematic name | M14270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The successive addition of amino acid residues to a nascent polypeptide chain during protein biosynthesis. [GOC:ems]
Full description |

Standard name | GO_TRANSLATIONAL_TERMINATION
Systematic name | M11662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process resulting in the release of a polypeptide chain from the ribosome, usually in response to a termination codon (UAA, UAG, or UGA in the universal genetic code). [GOC:hjd, ISBN:019879276X]
Full description |

Standard name | GO_REGULATION_OF_TRANSLATIONAL_INITIATION
Systematic name | M17238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of translational initiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_TRANSLATIONAL_ELONGATION
Systematic name | M11322
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, extent or accuracy of translational elongation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_TRANSLATIONAL_TERMINATION
Systematic name | M22413
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of translational termination. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_TRANSLATIONAL_FIDELITY
Systematic name | M15006
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the ability of the translational apparatus to interpret the genetic code. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_TRANSLATIONAL_READTHROUGH
Systematic name | M22414
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The continuation of translation beyond a stop codon by the use of a special tRNA that recognizes the UAG and UGA codons as modified amino acids, rather than as termination codons. [GOC:jsg, PMID:11179232]
Full description |

Standard name | GO_PROTEIN_FOLDING
Systematic name | M13856
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of assisting in the covalent and noncovalent assembly of single chain polypeptides or multisubunit complexes into the correct tertiary structure. [GOC:go_curators, GOC:rb]
Full description |

Standard name | GO_DE_NOVO_PROTEIN_FOLDING
Systematic name | M15208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of assisting in the folding of a nascent peptide chain into its correct tertiary structure. [GOC:mb]
Full description |

Standard name | GO_SIGNAL_PEPTIDE_PROCESSING
Systematic name | M16386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The proteolytic removal of a signal peptide from a protein during or after transport to a specific location in the cell. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_PROTEIN_DEPHOSPHORYLATION
Systematic name | M14907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of removing one or more phosphoric residues from a protein. [GOC:hb]
Full description |

Standard name | GO_PROTEIN_ADP_RIBOSYLATION
Systematic name | M13497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer, from NAD, of ADP-ribose to protein amino acids. [GOC:pr, RESID:AA0040, RESID:AA0168, RESID:AA0169, RESID:AA0231, RESID:AA0237, RESID:AA0295]
Full description |

Standard name | GO_PROTEIN_ACETYLATION
Systematic name | M12694
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of an acetyl group to a protein amino acid. An acetyl group is CH3CO-, derived from acetic [ethanoic] acid. [GOC:ai]
Full description |

Standard name | GO_N_TERMINAL_PROTEIN_AMINO_ACID_ACETYLATION
Systematic name | M10151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The acetylation of the N-terminal amino acid of proteins. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_SULFATION
Systematic name | M22415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a sulfate group as an ester to a protein amino acid. [GOC:curators]
Full description |

Standard name | GO_PROTEIN_METHYLATION
Systematic name | M22416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a methyl group to a protein amino acid. A methyl group is derived from methane by the removal of a hydrogen atom. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_DEMETHYLATION
Systematic name | M22417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of a methyl group, from a protein amino acid. A methyl group is derived from methane by the removal of a hydrogen atom. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_N_LINKED_GLYCOSYLATION
Systematic name | M10780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein glycosylation process in which a carbohydrate or carbohydrate derivative unit is added to a protein via the N4 atom of peptidyl-asparagine, the omega-N of arginine, or the N1' atom peptidyl-tryptophan. [GOC:pr, RESID:AA0151, RESID:AA0156, RESID:AA0327]
Full description |

Standard name | GO_DOLICHYL_DIPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M22418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of dolichyl diphosphate, a diphosphorylated dolichol derivative. [ISBN:0198506732]
Full description |

Standard name | GO_OLIGOSACCHARIDE_LIPID_INTERMEDIATE_BIOSYNTHETIC_PROCESS
Systematic name | M16610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of an oligosaccharide-lipid intermediate, such as a molecule of dolichol-P-man or dolicol-P-Glc used in N-linked glycosylation. [GOC:dph, GOC:hjd, GOC:isa_complete, GOC:pr, GOC:rb]
Full description |

Standard name | GO_N_GLYCAN_PROCESSING
Systematic name | M10200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The conversion of N-linked glycan (N = nitrogen) structures from the initially transferred oligosaccharide to a mature form, by the actions of glycosidases and glycosyltransferases. The early processing steps are conserved and play roles in glycoprotein folding and trafficking. [ISBN:0879695595, PMID:12736198]
Full description |

Standard name | GO_PROTEIN_O_LINKED_GLYCOSYLATION
Systematic name | M16434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein glycosylation process in which a carbohydrate or carbohydrate derivative unit is added to a protein via the hydroxyl group of peptidyl-serine, peptidyl-threonine, peptidyl-hydroxylysine, or peptidyl-hydroxyproline, or via the phenol group of peptidyl-tyrosine, forming an O-glycan. [GOC:pr, ISBN:0879695595, RESID:AA0153, RESID:AA0154, RESID:AA0155, RESID:AA0157, RESID:AA0212]
Full description |

Standard name | GO_N_TERMINAL_PROTEIN_LIPIDATION
Systematic name | M22419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment of a lipid group to the amino terminus of a protein. [GOC:jl]
Full description |

Standard name | GO_C_TERMINAL_PROTEIN_LIPIDATION
Systematic name | M22420
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment of a lipid group to the carboxy-terminus of a protein. [GOC:jl]
Full description |

Standard name | GO_GPI_ANCHOR_METABOLIC_PROCESS
Systematic name | M29034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycosylphosphatidylinositol anchors, molecular mechanisms for attaching membrane proteins to the lipid bilayer of cell membranes. Structurally they consist of a molecule of phosphatidylinositol to which is linked, via the C-6 hydroxyl of the inositol, a carbohydrate chain. This chain is in turn linked to the protein through an ethanolamine phosphate group, the amino group of which is in amide linkage with the C-terminal carboxyl of the protein chain, the phosphate group being esterified to the C-6 hydroxyl of the terminal mannose of the core carbohydrate chain. [ISBN:0198506732]
Full description |

Standard name | GO_PROTEOLYSIS
Systematic name | M17569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The hydrolysis of proteins into smaller polypeptides and/or amino acids by cleavage of their peptide bonds. [GOC:bf, GOC:mah]
Full description |

Standard name | GO_MEMBRANE_PROTEIN_ECTODOMAIN_PROTEOLYSIS
Systematic name | M14570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The proteolytic cleavage of transmembrane proteins and release of their ectodomain (extracellular domain). [GOC:jl, http://www.copewithcytokines.de/]
Full description |

Standard name | GO_PROTEIN_MONOUBIQUITINATION
Systematic name | M13470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Addition of a single ubiquitin group to a protein. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_QUALITY_CONTROL_FOR_MISFOLDED_OR_INCOMPLETELY_SYNTHESIZED_PROTEINS
Systematic name | M22422
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of misfolded or attenuated proteins. [GOC:jl]
Full description |

Standard name | GO_GLYCOPROTEIN_CATABOLIC_PROCESS
Systematic name | M408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glycoproteins, any protein that contains covalently bound glycose (i.e. monosaccharide) residues; the glycose occurs most commonly as oligosaccharide or fairly small polysaccharide but occasionally as monosaccharide. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PROTEIN_DEGLYCOSYLATION
Systematic name | M14264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of sugar residues from a glycosylated protein. [GOC:mah]
Full description |

Standard name | GO_PEPTIDE_METABOLIC_PROCESS
Systematic name | M12056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving peptides, compounds of two or more amino acids where the alpha carboxyl group of one is bound to the alpha amino group of another. [GOC:go_curators]
Full description |

Standard name | GO_CELLULAR_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M9857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving amino acids, carboxylic acids containing one or more amino groups, as carried out by individual cells. [ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M16483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving amino acids. [GOC:go_curators]
Full description |

Standard name | GO_ARGININE_METABOLIC_PROCESS
Systematic name | M29035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving arginine, 2-amino-5-(carbamimidamido)pentanoic acid. [GOC:go_curators]
Full description |

Standard name | GO_ARGININE_BIOSYNTHETIC_PROCESS
Systematic name | M34066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of arginine, 2-amino-5-(carbamimidamido)pentanoic acid. [ISBN:0198506732]
Full description |

Standard name | GO_ARGININE_CATABOLIC_PROCESS
Systematic name | M22424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of arginine, 2-amino-5-(carbamimidamido)pentanoic acid. [GOC:go_curators]
Full description |

Standard name | GO_ASPARAGINE_METABOLIC_PROCESS
Systematic name | M34067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving asparagine, 2-amino-3-carbamoylpropanoic acid. [GOC:go_curators]
Full description |

Standard name | GO_ASPARTATE_METABOLIC_PROCESS
Systematic name | M15665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving aspartate, the anion derived from aspartic acid, 2-aminobutanedioic acid. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_CYSTEINE_METABOLIC_PROCESS
Systematic name | M22425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving cysteine, 2-amino-3-mercaptopropanoic acid. [GOC:go_curators]
Full description |

Standard name | GO_GLUTAMATE_METABOLIC_PROCESS
Systematic name | M10955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glutamate, the anion of 2-aminopentanedioic acid. [GOC:go_curators]
Full description |

Standard name | GO_GLUTAMATE_BIOSYNTHETIC_PROCESS
Systematic name | M22426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of glutamate, the anion of 2-aminopentanedioic acid. [GOC:go_curators]
Full description |

Standard name | GO_GLUTAMATE_CATABOLIC_PROCESS
Systematic name | M22427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glutamate, the anion of 2-aminopentanedioic acid. [GOC:go_curators]
Full description |

Standard name | GO_GLUTAMINE_METABOLIC_PROCESS
Systematic name | M11960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glutamine, 2-amino-4-carbamoylbutanoic acid. [GOC:ai]
Full description |

Standard name | GO_GLYCINE_METABOLIC_PROCESS
Systematic name | M13750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycine, aminoethanoic acid. [GOC:go_curators]
Full description |

Standard name | GO_HISTIDINE_METABOLIC_PROCESS
Systematic name | M29036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving histidine, 2-amino-3-(1H-imidazol-4-yl)propanoic acid. [GOC:go_curators]
Full description |

Standard name | GO_ISOLEUCINE_METABOLIC_PROCESS
Systematic name | M34068
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving isoleucine, (2R*,3R*)-2-amino-3-methylpentanoic acid. [GOC:ai]
Full description |

Standard name | GO_LEUCINE_METABOLIC_PROCESS
Systematic name | M29037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving leucine, 2-amino-4-methylpentanoic acid. [GOC:ai]
Full description |

Standard name | GO_LEUCINE_CATABOLIC_PROCESS
Systematic name | M22429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of leucine, 2-amino-4-methylpentanoic acid. [GOC:ai]
Full description |

Standard name | GO_LYSINE_METABOLIC_PROCESS
Systematic name | M29038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving lysine, 2,6-diaminohexanoic acid. [GOC:go_curators]
Full description |

Standard name | GO_METHIONINE_METABOLIC_PROCESS
Systematic name | M13851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving methionine (2-amino-4-(methylthio)butanoic acid), a sulfur-containing, essential amino acid found in peptide linkage in proteins. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_L_PHENYLALANINE_METABOLIC_PROCESS
Systematic name | M29039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving L-phenylalanine, the L-enantiomer of 2-amino-3-phenylpropanoic acid, i.e. (2S)-2-amino-3-phenylpropanoic acid. [GOC:jsg, GOC:mah]
Full description |

Standard name | GO_PROLINE_METABOLIC_PROCESS
Systematic name | M29040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving proline (pyrrolidine-2-carboxylic acid), a chiral, cyclic, nonessential alpha-amino acid found in peptide linkage in proteins. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_PROLINE_BIOSYNTHETIC_PROCESS
Systematic name | M34069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of proline (pyrrolidine-2-carboxylic acid), a chiral, cyclic, nonessential alpha-amino acid found in peptide linkage in proteins. [ISBN:0198506732]
Full description |

Standard name | GO_L_SERINE_METABOLIC_PROCESS
Systematic name | M22433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving L-serine, the L-enantiomer of serine, i.e. (2S)-2-amino-3-hydroxypropanoic acid. [GOC:ai, GOC:jsg]
Full description |

Standard name | GO_L_SERINE_BIOSYNTHETIC_PROCESS
Systematic name | M22434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of L-serine, the L-enantiomer of serine, i.e. (2S)-2-amino-3-hydroxypropanoic acid. [GOC:ai, GOC:jsg]
Full description |

Standard name | GO_THREONINE_METABOLIC_PROCESS
Systematic name | M29041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving threonine (2-amino-3-hydroxybutyric acid), a polar, uncharged, essential amino acid found in peptide linkage in proteins. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_THREONINE_CATABOLIC_PROCESS
Systematic name | M34070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of threonine (2-amino-3-hydroxybutyric acid), a polar, uncharged, essential amino acid found in peptide linkage in proteins. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_TRYPTOPHAN_METABOLIC_PROCESS
Systematic name | M15858
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving tryptophan, the chiral amino acid 2-amino-3-(1H-indol-3-yl)propanoic acid. [ISBN:0198547684]
Full description |

Standard name | GO_TYROSINE_METABOLIC_PROCESS
Systematic name | M29042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving tyrosine, an aromatic amino acid, 2-amino-3-(4-hydroxyphenyl)propanoic acid. [GOC:go_curators]
Full description |

Standard name | GO_TYROSINE_CATABOLIC_PROCESS
Systematic name | M22436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of tyrosine, an aromatic amino acid, 2-amino-3-(4-hydroxyphenyl)propanoic acid. [GOC:go_curators]
Full description |

Standard name | GO_VALINE_METABOLIC_PROCESS
Systematic name | M29043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving valine, 2-amino-3-methylbutanoic acid. [GOC:ai]
Full description |

Standard name | GO_CELLULAR_MODIFIED_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M1635
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving compounds derived from amino acids, organic acids containing one or more amino substituents. [GOC:ai]
Full description |

Standard name | GO_CELLULAR_BIOGENIC_AMINE_METABOLIC_PROCESS
Systematic name | M7597
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways occurring at the level of individual cells involving any of a group of naturally occurring, biologically active amines, such as norepinephrine, histamine, and serotonin, many of which act as neurotransmitters. [GOC:jl, ISBN:0395825172]
Full description |

Standard name | GO_AMINO_ACID_BETAINE_METABOLIC_PROCESS
Systematic name | M14299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any betaine, the N-trimethyl derivative of an amino acid. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_AMINO_ACID_BETAINE_BIOSYNTHETIC_PROCESS
Systematic name | M22438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any betaine, the N-trimethyl derivative of an amino acid. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_CATECHOLAMINE_METABOLIC_PROCESS
Systematic name | M11529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any of a group of physiologically important biogenic amines that possess a catechol (3,4-dihydroxyphenyl) nucleus and are derivatives of 3,4-dihydroxyphenylethylamine. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_INDOLALKYLAMINE_METABOLIC_PROCESS
Systematic name | M29045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving indolalkylamines, indole or indole derivatives containing a primary, secondary, or tertiary amine group. [GOC:curators]
Full description |

Standard name | GO_ORNITHINE_METABOLIC_PROCESS
Systematic name | M29046
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving ornithine, an amino acid only rarely found in proteins, but which is important in living organisms as an intermediate in the reactions of the urea cycle and in arginine biosynthesis. [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_POLYAMINE_METABOLIC_PROCESS
Systematic name | M12251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving polyamines, any organic compound containing two or more amino groups. [ISBN:0198506732]
Full description |

Standard name | GO_POLYAMINE_BIOSYNTHETIC_PROCESS
Systematic name | M22439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of polyamines, any organic compound containing two or more amino groups. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHAGEN_METABOLIC_PROCESS
Systematic name | M29047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving phosphagen, any of a group of guanidine phosphates that occur in muscle and can be used to regenerate ATP from ADP during muscular contraction. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_CREATINE_METABOLIC_PROCESS
Systematic name | M11588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving creatine (N-(aminoiminomethyl)-N-methylglycine), a compound synthesized from the amino acids arginine, glycine, and methionine that occurs in muscle. [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_PROTEIN_TARGETING
Systematic name | M11119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of targeting specific proteins to particular regions of the cell, typically membrane-bounded subcellular organelles. Usually requires an organelle specific protein sequence motif. [GOC:ma]
Full description |

Standard name | GO_NLS_BEARING_PROTEIN_IMPORT_INTO_NUCLEUS
Systematic name | M14979
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein bearing a nuclear localization signal (NLS) from the cytoplasm into the nucleus, across the nuclear envelope. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_TARGETING_TO_MEMBRANE
Systematic name | M12388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of directing proteins towards a membrane, usually using signals contained within the protein. [GOC:curators]
Full description |

Standard name | GO_COTRANSLATIONAL_PROTEIN_TARGETING_TO_MEMBRANE
Systematic name | M22441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The targeting of proteins to a membrane that occurs during translation. The transport of most secretory proteins, particularly those with more than 100 amino acids, into the endoplasmic reticulum lumen occurs in this manner, as does the import of some proteins into mitochondria. [ISBN:0716731363, PMID:10512867, PMID:16896215]
Full description |

Standard name | GO_SRP_DEPENDENT_COTRANSLATIONAL_PROTEIN_TARGETING_TO_MEMBRANE_TRANSLOCATION
Systematic name | M22442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process during cotranslational membrane targeting wherein proteins move across a membrane. SRP and its receptor initiate the transfer of the nascent chain across the endoplasmic reticulum (ER) membrane; they then dissociate from the chain, which is transferred to a set of transmembrane proteins, collectively called the translocon. Once the nascent chain translocon complex is assembled, the elongating chain passes directly from the large ribosomal subunit into the centers of the translocon, a protein-lined channel within the membrane. The growing chain is never exposed to the cytosol and does not fold until it reaches the ER lumen. [ISBN:0716731363]
Full description |

Standard name | GO_SRP_DEPENDENT_COTRANSLATIONAL_PROTEIN_TARGETING_TO_MEMBRANE_SIGNAL_SEQUENCE_RECOGNITION
Systematic name | M34071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which SRP binds to the signal peptide in a nascent protein, causing protein elongation to pause, during cotranslational membrane targeting. [ISBN:0815316194]
Full description |

Standard name | GO_POSTTRANSLATIONAL_PROTEIN_TARGETING_TO_ENDOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M22444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The targeting of proteins to a membrane that occurs after their translation. Some secretory proteins exhibit posttranslational transport into the endoplasmic reticulum (ER) lumen: they are synthesized in their entirety on free cytosolic ribosomes and then released into the cytosol, where they are bound by chaperones which keep them in an unfolded state, and subsequently are translocated across the ER membrane. [ISBN:0716731363]
Full description |

Standard name | GO_PROTEIN_RETENTION_IN_ER_LUMEN
Systematic name | M22445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The retention in the endoplasmic reticulum (ER) lumen of soluble resident proteins. Sorting receptors retrieve proteins with ER localization signals, such as KDEL and HDEL sequences or some transmembrane domains, that have escaped to the cis-Golgi network and return them to the ER. Abnormally folded proteins and unassembled subunits are also selectively retained in the ER. [ISBN:0716731363, PMID:12972550]
Full description |

Standard name | GO_PROTEIN_TARGETING_TO_LYSOSOME
Systematic name | M16491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of directing proteins towards the lysosome using signals contained within the protein. [GOC:curators]
Full description |

Standard name | GO_PROTEIN_TARGETING_TO_VACUOLE
Systematic name | M22446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of directing proteins towards the vacuole, usually using signals contained within the protein. [GOC:curators]
Full description |

Standard name | GO_PROTEIN_TARGETING_TO_MITOCHONDRION
Systematic name | M15596
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of directing proteins towards and into the mitochondrion, usually mediated by mitochondrial proteins that recognize signals contained within the imported protein. [GOC:mcc, ISBN:0716731363]
Full description |

Standard name | GO_PROTEIN_PROCESSING_INVOLVED_IN_PROTEIN_TARGETING_TO_MITOCHONDRION
Systematic name | M22447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cleavage of peptide bonds in proteins, usually near the N terminus, contributing to the process of import into the mitochondrion. Several different peptidases mediate cleavage of proteins destined for different mitochondrial compartments. [GOC:mcc, PMID:12191769]
Full description |

Standard name | GO_LIPID_METABOLIC_PROCESS
Systematic name | M14099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving lipids, compounds soluble in an organic solvent but not, or sparingly, in an aqueous solvent. Includes fatty acids; neutral fats, other fatty-acid esters, and soaps; long-chain (fatty) alcohols and waxes; sphingoids and other long-chain bases; glycolipids, phospholipids and sphingolipids; and carotenes, polyprenols, sterols, terpenes and other isoprenoids. [GOC:ma]
Full description |

Standard name | GO_FATTY_ACID_METABOLIC_PROCESS
Systematic name | M17829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving fatty acids, aliphatic monocarboxylic acids liberated from naturally occurring fats and oils by hydrolysis. [ISBN:0198547684]
Full description |

Standard name | GO_FATTY_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M13591
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a fatty acid, any of the aliphatic monocarboxylic acids that can be liberated by hydrolysis from naturally occurring fats and oils. Fatty acids are predominantly straight-chain acids of 4 to 24 carbon atoms, which may be saturated or unsaturated; branched fatty acids and hydroxy fatty acids also occur, and very long chain acids of over 30 carbons are found in waxes. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_FATTY_ACID_BETA_OXIDATION
Systematic name | M6999
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A fatty acid oxidation process that results in the complete oxidation of a long-chain fatty acid. Fatty acid beta-oxidation begins with the addition of coenzyme A to a fatty acid, and occurs by successive cycles of reactions during each of which the fatty acid is shortened by a two-carbon fragment removed as acetyl coenzyme A; the cycle continues until only two or three carbons remain (as acetyl-CoA or propionyl-CoA respectively). [GOC:mah, ISBN:0198506732, MetaCyc:FAO-PWY]
Full description |

Standard name | GO_UNSATURATED_FATTY_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M16551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of an unsaturated fatty acid, any fatty acid containing one or more double bonds between carbon atoms. [GOC:mah, MetaCyc:PWY-762, MetaCyc:PWY-782]
Full description |

Standard name | GO_NEUTRAL_LIPID_METABOLIC_PROCESS
Systematic name | M14292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving neutral lipids, lipids only soluble in solvents of very low polarity. [ISBN:0198547684]
Full description |

Standard name | GO_MONOACYLGLYCEROL_BIOSYNTHETIC_PROCESS
Systematic name | M34072
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of monoacylglycerol, any ester of glycerol in which any one of its hydroxyl groups has been acylated with a fatty acid, the other being non-esterified. [ISBN:0198506732]
Full description |

Standard name | GO_TRIGLYCERIDE_METABOLIC_PROCESS
Systematic name | M22449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving triglyceride, any triester of glycerol. The three fatty acid residues may all be the same or differ in any permutation. Triglycerides are important components of plant oils, animal fats and animal plasma lipoproteins. [ISBN:0198506732]
Full description |

Standard name | GO_MEMBRANE_LIPID_METABOLIC_PROCESS
Systematic name | M15543
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving membrane lipids, any lipid found in or associated with a biological membrane. [GOC:ai]
Full description |

Standard name | GO_PHOSPHOLIPID_METABOLIC_PROCESS
Systematic name | M10283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving phospholipids, any lipid containing phosphoric acid as a mono- or diester. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHATIDYLETHANOLAMINE_BIOSYNTHETIC_PROCESS
Systematic name | M14655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of phosphatidylethanolamine, any of a class of glycerophospholipids in which a phosphatidyl group is esterified to the hydroxyl group of ethanolamine. [ISBN:0198506732]
Full description |

Standard name | GO_GLYCEROPHOSPHOLIPID_METABOLIC_PROCESS
Systematic name | M13919
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycerophospholipids, any derivative of glycerophosphate that contains at least one O-acyl, O-alkyl, or O-alkenyl group attached to the glycerol residue. [ISBN:0198506732]
Full description |

Standard name | GO_DIACYLGLYCEROL_BIOSYNTHETIC_PROCESS
Systematic name | M34073
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of diacylglycerol, a glyceride in which any two of the R groups (positions not specified) are acyl groups while the remaining R group can be either H or an alkyl group. [GOC:curators]
Full description |

Standard name | GO_PHOSPHATIDYLGLYCEROL_BIOSYNTHETIC_PROCESS
Systematic name | M22451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of phosphatidylglycerols, any of a class of phospholipids in which the phosphatidyl group is esterified to the hydroxyl group of glycerol. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHATIDYLCHOLINE_BIOSYNTHETIC_PROCESS
Systematic name | M10663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of phosphatidylcholines, any of a class of glycerophospholipids in which the phosphatidyl group is esterified to the hydroxyl group of choline. [ISBN:0198506732]
Full description |

Standard name | GO_CDP_CHOLINE_PATHWAY
Systematic name | M22452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The phosphatidylcholine biosynthetic process that begins with the phosphorylation of choline and ends with the combination of CDP-choline with diacylglycerol to form phosphatidylcholine. [ISBN:0471331309, MetaCyc:PWY3O-450]
Full description |

Standard name | GO_PHOSPHATIDYLSERINE_METABOLIC_PROCESS
Systematic name | M15367
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving phosphatidylserines, any of a class of glycerophospholipids in which the phosphatidyl group is esterified to the hydroxyl group of L-serine. They are important constituents of cell membranes. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_BIOSYNTHETIC_PROCESS
Systematic name | M10758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of phosphatidylinositol, any glycophospholipid in which the sn-glycerol 3-phosphate residue is esterified to the 1-hydroxyl group of 1D-myo-inositol. [ISBN:0198506732]
Full description |

Standard name | GO_GLYCEROL_ETHER_METABOLIC_PROCESS
Systematic name | M22453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycerol ethers, any anhydride formed between two organic hydroxy compounds, one of which is glycerol. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_PLATELET_ACTIVATING_FACTOR_BIOSYNTHETIC_PROCESS
Systematic name | M34074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of platelet activating factor, 1-O-alkyl-2-acetyl-sn-glycerol 3-phosphocholine, where alkyl = hexadecyl or octadecyl. Platelet activating factor is an inflammatory mediator released from a variety of cells in response to various stimuli. [ISBN:0198547684]
Full description |

Standard name | GO_SPHINGOLIPID_METABOLIC_PROCESS
Systematic name | M12691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving sphingolipids, any of a class of lipids containing the long-chain amine diol sphingosine or a closely related base (a sphingoid). [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_CERAMIDE_METABOLIC_PROCESS
Systematic name | M14627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving ceramides, any N-acylated sphingoid. [ISBN:0198547684]
Full description |

Standard name | GO_GLYCOSYLCERAMIDE_METABOLIC_PROCESS
Systematic name | M29049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycosylceramides, any compound formed by the replacement of the glycosidic hydroxyl group of a cyclic form of a monosaccharide (or derivative) by a ceramide group. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_GLUCOSYLCERAMIDE_METABOLIC_PROCESS
Systematic name | M29050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glucosylceramides, any compound formed by the replacement of the glycosidic hydroxyl group of a cyclic form of glucose by a ceramide group. They are neutral glycolipids containing equimolar amounts of fatty acid, glucose, and sphingosine or a sphingosine derivative. [ISBN:0198506732]
Full description |

Standard name | GO_SPHINGOMYELIN_METABOLIC_PROCESS
Systematic name | M10957
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving sphingomyelin, N-acyl-4-sphingenyl-1-O-phosphorylcholine, any of a class of phospholipids in which the amino group of sphingosine is in amide linkage with one of several fatty acids, while the terminal hydroxyl group of sphingosine is esterified to phosphorylcholine. [ISBN:0198506732]
Full description |

Standard name | GO_SPHINGOMYELIN_CATABOLIC_PROCESS
Systematic name | M22454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of sphingomyelin, N-acyl-4-sphingenyl-1-O-phosphorylcholine. [ISBN:0198506732]
Full description |

Standard name | GO_SPHINGOMYELIN_BIOSYNTHETIC_PROCESS
Systematic name | M22455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of sphingomyelin, N-acyl-4-sphingenyl-1-O-phosphorylcholine. [ISBN:0198506732]
Full description |

Standard name | GO_GLYCOSPHINGOLIPID_METABOLIC_PROCESS
Systematic name | M29051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycosphingolipids, any compound with residues of sphingoid and at least one monosaccharide. [ISBN:0198547684]
Full description |

Standard name | GO_GLYCOSPHINGOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M13299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of glycosphingolipid, a compound with residues of sphingoid and at least one monosaccharide. [GOC:go_curators]
Full description |

Standard name | GO_GANGLIOSIDE_CATABOLIC_PROCESS
Systematic name | M22456
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of ganglioside, a ceramide oligosaccharide carrying, in addition to other sugar residues, one or more sialic residues. [ISBN:0198547684]
Full description |

Standard name | GO_ICOSANOID_METABOLIC_PROCESS
Systematic name | M22457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving icosanoids, any of a group of C20 polyunsaturated fatty acids. [GOC:ma]
Full description |

Standard name | GO_LEUKOTRIENE_METABOLIC_PROCESS
Systematic name | M16416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving leukotriene, a pharmacologically active substance derived from a polyunsaturated fatty acid, such as arachidonic acid. [GOC:ma]
Full description |

Standard name | GO_PROSTANOID_METABOLIC_PROCESS
Systematic name | M15959
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving prostanoids, any compound based on or derived from the prostanoate structure. [ISBN:0198506732]
Full description |

Standard name | GO_STEROID_BIOSYNTHETIC_PROCESS
Systematic name | M13381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of steroids, compounds with a 1,2,cyclopentanoperhydrophenanthrene nucleus; includes de novo formation and steroid interconversion by modification. [GOC:go_curators]
Full description |

Standard name | GO_BILE_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M12041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of bile acids, any of a group of steroid carboxylic acids occurring in bile. [GOC:go_curators]
Full description |

Standard name | GO_C21_STEROID_HORMONE_BIOSYNTHETIC_PROCESS
Systematic name | M15204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of C21-steroid hormones, steroid compounds containing 21 carbons which function as hormones. [GOC:ai]
Full description |

Standard name | GO_PROGESTERONE_BIOSYNTHETIC_PROCESS
Systematic name | M22458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of progesterone, a steroid hormone produced in the ovary which prepares and maintains the uterus for pregnancy. Also found in plants. [GOC:jl, http://www.cogsci.princeton.edu/]
Full description |

Standard name | GO_ANDROGEN_BIOSYNTHETIC_PROCESS
Systematic name | M12293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of androgens, C19 steroid hormones that can stimulate the development of male sexual characteristics. [ISBN:0198506732]
Full description |

Standard name | GO_ESTROGEN_BIOSYNTHETIC_PROCESS
Systematic name | M15172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of estrogens, C18 steroid hormones that can stimulate the development of female sexual characteristics. Also found in plants. [ISBN:0198506732]
Full description |

Standard name | GO_GLUCOCORTICOID_BIOSYNTHETIC_PROCESS
Systematic name | M13523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of glucocorticoids, hormonal C21 corticosteroids synthesized from cholesterol. [ISBN:0198506732]
Full description |

Standard name | GO_STEROID_CATABOLIC_PROCESS
Systematic name | M16855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of steroids, compounds with a 1,2,cyclopentanoperhydrophenanthrene nucleus. [GOC:go_curators]
Full description |

Standard name | GO_CHOLESTEROL_CATABOLIC_PROCESS
Systematic name | M22460
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of cholesterol, cholest-5-en-3 beta-ol, the principal sterol of vertebrates and the precursor of many steroids, including bile acids and steroid hormones. [GOC:ai]
Full description |

Standard name | GO_ANDROGEN_CATABOLIC_PROCESS
Systematic name | M22461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of androgens, C19 steroid hormones that can stimulate the development of male sexual characteristics. [ISBN:0198506732]
Full description |

Standard name | GO_ISOPRENOID_METABOLIC_PROCESS
Systematic name | M16492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving isoprenoid compounds, isoprene (2-methylbuta-1,3-diene) or compounds containing or derived from linked isoprene (3-methyl-2-butenylene) residues. [ISBN:0198547684]
Full description |

Standard name | GO_TERPENOID_METABOLIC_PROCESS
Systematic name | M29052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving terpenoids, any member of a class of compounds characterized by an isoprenoid chemical structure and including derivatives with various functional groups. [ISBN:0198506732]
Full description |

Standard name | GO_ONE_CARBON_METABOLIC_PROCESS
Systematic name | M13302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving the transfer of one-carbon units in various oxidation states. [GOC:hjd, GOC:mah, GOC:pde]
Full description |

Standard name | GO_NADH_METABOLIC_PROCESS
Systematic name | M13933
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving reduced nicotinamide adenine dinucleotide (NADH), a coenzyme present in most living cells and derived from the B vitamin nicotinic acid. [GOC:jl, ISBN:0618254153]
Full description |

Standard name | GO_NADP_METABOLIC_PROCESS
Systematic name | M10730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving nicotinamide-adenine dinucleotide phosphate, a coenzyme involved in many redox and biosynthetic reactions; metabolism may be of either the oxidized form, NADP, or the reduced form, NADPH. [GOC:mah]
Full description |

Standard name | GO_NADPH_REGENERATION
Systematic name | M29054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A metabolic process that generates a pool of NADPH by the reduction of NADP+. [GOC:mah]
Full description |

Standard name | GO_UBIQUINONE_METABOLIC_PROCESS
Systematic name | M29055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving ubiquinone, a lipid-soluble electron-transporting coenzyme. [GOC:mah]
Full description |

Standard name | GO_GLUTATHIONE_METABOLIC_PROCESS
Systematic name | M14708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glutathione, the tripeptide glutamylcysteinylglycine, which acts as a coenzyme for some enzymes and as an antioxidant in the protection of sulfhydryl groups in enzymes and other proteins; it has a specific role in the reduction of hydrogen peroxide (H2O2) and oxidized ascorbate, and it participates in the gamma-glutamyl cycle. [ISBN:0198506732]
Full description |

Standard name | GO_GLUTATHIONE_CATABOLIC_PROCESS
Systematic name | M22463
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glutathione, the tripeptide glutamylcysteinylglycine, which acts as a coenzyme for some enzymes and as an antioxidant in the protection of sulfhydryl groups in enzymes and other proteins. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_ATP_BIOSYNTHETIC_PROCESS
Systematic name | M12750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of ATP, adenosine 5'-triphosphate, a universally important coenzyme and enzyme regulator. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_FOLIC_ACID_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M29056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a folic acid-containing compound, i.e. any of a group of heterocyclic compounds based on the pteroic acid skeleton conjugated with one or more L-glutamic acid or L-glutamate units. [GOC:ai, GOC:mah]
Full description |

Standard name | GO_VITAMIN_METABOLIC_PROCESS
Systematic name | M16119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving vitamins. Vitamin is a general term for a number of unrelated organic substances that occur in many foods in small amounts and that are necessary in trace amounts for the normal metabolic functioning of the body. Vitamins may be water-soluble or fat-soluble and usually serve as components of coenzyme systems. [GOC:ai]
Full description |

Standard name | GO_WATER_SOLUBLE_VITAMIN_METABOLIC_PROCESS
Systematic name | M13439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any of a diverse group of vitamins that are soluble in water. [GOC:jl]
Full description |

Standard name | GO_BIOTIN_METABOLIC_PROCESS
Systematic name | M12182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving biotin, cis-tetrahydro-2-oxothieno(3,4-d)imidazoline-4-valeric acid; the (+) enantiomer is very widely distributed in cells and serves as a carrier in a number of enzymatic beta-carboxylation reactions. [ISBN:0198506732]
Full description |

Standard name | GO_FAT_SOLUBLE_VITAMIN_METABOLIC_PROCESS
Systematic name | M13330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving of any of a diverse group of vitamins that are soluble in organic solvents and relatively insoluble in water. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_VITAMIN_A_METABOLIC_PROCESS
Systematic name | M22466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any of the vitamin A compounds, retinol, retinal (retinaldehyde) and retinoic acid, all of which are derivatives of beta-carotene. [GOC:jl, http://www.dentistry.leeds.ac.uk/biochem/thcme/vitamins.html#k]
Full description |

Standard name | GO_PORPHYRIN_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M11983
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any member of a large group of derivatives or analogs of porphyrin. Porphyrins consists of a ring of four pyrrole nuclei linked each to the next at their alpha positions through a methine group. [GOC:jl, ISBN:0198506732, Wikipedia:Porphyrin#Natural_formation]
Full description |

Standard name | GO_PROTOPORPHYRINOGEN_IX_BIOSYNTHETIC_PROCESS
Systematic name | M22467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of protoporphyrinogen IX. [GOC:go_curators]
Full description |

Standard name | GO_SULFUR_COMPOUND_METABOLIC_PROCESS
Systematic name | M9906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving the nonmetallic element sulfur or compounds that contain sulfur, such as the amino acids methionine and cysteine or the tripeptide glutathione. [GOC:ai]
Full description |

Standard name | GO_POLYPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a polyphosphate, the anion or salt of polyphosphoric acid. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_POLYPHOSPHATE_CATABOLIC_PROCESS
Systematic name | M22468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a polyphosphate, the anion or salt of polyphosphoric acid. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_SUPEROXIDE_METABOLIC_PROCESS
Systematic name | M11249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving superoxide, the superoxide anion O2- (superoxide free radical), or any compound containing this species. [GOC:jl]
Full description |

Standard name | GO_ION_TRANSPORT
Systematic name | M10111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of charged atoms or small charged molecules into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_CATION_TRANSPORT
Systematic name | M11869
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of cations, atoms or small molecules with a net positive charge, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_POTASSIUM_ION_TRANSPORT
Systematic name | M10060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of potassium ions (K+) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_SODIUM_ION_TRANSPORT
Systematic name | M16391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of sodium ions (Na+) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_PHOSPHATE_ION_TRANSPORT
Systematic name | M13372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of phosphate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_ANION_TRANSPORT
Systematic name | M12081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of anions, atoms or small molecules with a net negative charge, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_CHLORIDE_TRANSPORT
Systematic name | M12615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of chloride into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_COBALT_ION_TRANSPORT
Systematic name | M22471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of cobalt (Co) ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_COPPER_ION_TRANSPORT
Systematic name | M11794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of copper (Cu) ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_IRON_ION_TRANSPORT
Systematic name | M11591
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of iron (Fe) ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_MANGANESE_ION_TRANSPORT
Systematic name | M11471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of manganese (Mn) ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_ZINC_ION_TRANSPORT
Systematic name | M22472
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of zinc (Zn II) ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_WATER_TRANSPORT
Systematic name | M12180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of water (H2O) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_DICARBOXYLIC_ACID_TRANSPORT
Systematic name | M13852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of dicarboxylic acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_NEUROTRANSMITTER_TRANSPORT
Systematic name | M11274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a neurotransmitter into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Neurotransmitters are any chemical substance that is capable of transmitting (or inhibiting the transmission of) a nerve impulse from a neuron to another cell. [GOC:ai]
Full description |

Standard name | GO_SEROTONIN_TRANSPORT
Systematic name | M22473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of serotonin into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Serotonin (5-hydroxytryptamine) is a monoamine neurotransmitter occurring in the peripheral and central nervous systems. [GOC:ai]
Full description |

Standard name | GO_MITOCHONDRIAL_TRANSPORT
Systematic name | M11760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Transport of substances into, out of or within a mitochondrion. [GOC:ai]
Full description |

Standard name | GO_ACYL_CARNITINE_TRANSPORT
Systematic name | M22474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of acyl carnitine into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Acyl carnitine is the condensation product of a carboxylic acid and carnitine and is the transport form for a fatty acid crossing the mitochondrial membrane. [GOC:ai]
Full description |

Standard name | GO_MITOCHONDRIAL_CALCIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M22475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a calcium ion (Ca2+) is transported across a mitochondrial membrane, into or out of the mitochondrion. [GOC:ai]
Full description |

Standard name | GO_CARNITINE_SHUTTLE
Systematic name | M22476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of acyl groups to and from acyl-CoA molecules to form O-acylcarnitine, which can exchange across the mitochondrial inner membrane with unacylated carnitine. [ISBN:0198547684]
Full description |

Standard name | GO_DRUG_TRANSMEMBRANE_TRANSPORT
Systematic name | M11498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a drug is transported across a membrane. [GOC:ai, GOC:bf]
Full description |

Standard name | GO_OLIGOPEPTIDE_TRANSPORT
Systematic name | M22477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of oligopeptides into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Oligopeptides are molecules that contain a small number (2 to 20) of amino-acid residues connected by peptide linkages. [ISBN:0198506732]
Full description |

Standard name | GO_EXTRACELLULAR_TRANSPORT
Systematic name | M29059
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transport of substances that occurs outside cells. [GOC:go_curators]
Full description |

Standard name | GO_NUCLEOTIDE_TRANSPORT
Systematic name | M11774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a nucleotide, any compound consisting of a nucleoside that is esterified with (ortho)phosphate, into, out of or within a cell. [ISBN:0198506732]
Full description |

Standard name | GO_PURINE_NUCLEOBASE_TRANSPORT
Systematic name | M22478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of purine bases, one of the two classes of nitrogen-containing ring compounds found in DNA and RNA, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [ISBN:0198506732]
Full description |

Standard name | GO_AMINO_ACID_TRANSPORT
Systematic name | M13394
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of amino acids, organic acids containing one or more amino substituents, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_GLUTAMINE_TRANSPORT
Systematic name | M22479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of glutamine, 2-amino-4-carbamoylbutanoic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_CELLULAR_ION_HOMEOSTASIS
Systematic name | M22480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of ions at the level of a cell. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_COPPER_ION_HOMEOSTASIS
Systematic name | M15519
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of copper ions at the level of a cell. [GOC:ai, GOC:mah]
Full description |

Standard name | GO_CELLULAR_IRON_ION_HOMEOSTASIS
Systematic name | M11074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of iron ions at the level of a cell. [GOC:ai, GOC:mah]
Full description |

Standard name | GO_CELLULAR_SODIUM_ION_HOMEOSTASIS
Systematic name | M13498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of sodium ions at the level of a cell. [GOC:ai, GOC:mah]
Full description |

Standard name | GO_CELL_VOLUME_HOMEOSTASIS
Systematic name | M15548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in maintaining the steady state of a cell's volume. The cell's volume refers to the three-dimensional space occupied by a cell. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PH
Systematic name | M14452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal equilibrium of hydrogen ions, thereby modulating the internal pH, within an organism or cell. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_INTRACELLULAR_PROTEIN_TRANSPORT
Systematic name | M10598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of proteins in a cell, including the movement of proteins between specific compartments or structures within a cell, such as organelles of a eukaryotic cell. [GOC:mah]
Full description |

Standard name | GO_EXOCYTOSIS
Systematic name | M1231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process of secretion by a cell that results in the release of intracellular molecules (e.g. hormones, matrix proteins) contained within a membrane-bounded vesicle. Exocytosis can occur either by full fusion, when the vesicle collapses into the plasma membrane, or by a kiss-and-run mechanism that involves the formation of a transient contact, a pore, between a granule (for exemple of chromaffin cells) and the plasma membrane. The latter process most of the time leads to only partial secretion of the granule content. Exocytosis begins with steps that prepare vesicles for fusion with the membrane (tethering and docking) and ends when molecules are secreted from the cell. [GOC:mah, ISBN:0716731363, PMID:22323285]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_TO_GOLGI_VESICLE_MEDIATED_TRANSPORT
Systematic name | M12529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from the endoplasmic reticulum (ER) to the Golgi, mediated by COP II vesicles. Small COP II coated vesicles form from the ER and then fuse directly with the cis-Golgi. Larger structures are transported along microtubules to the cis-Golgi. [GOC:ascb_2009, GOC:dph, GOC:jp, GOC:tb, ISBN:0716731363]
Full description |

Standard name | GO_RETROGRADE_VESICLE_MEDIATED_TRANSPORT_GOLGI_TO_ENDOPLASMIC_RETICULUM
Systematic name | M22482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from the Golgi back to the endoplasmic reticulum, mediated by vesicles bearing specific protein coats such as COPI or COG. [ISBN:0716731363, PMID:16510524]
Full description |

Standard name | GO_INTRA_GOLGI_VESICLE_MEDIATED_TRANSPORT
Systematic name | M11795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances within the Golgi, mediated by small transport vesicles. These either fuse with the cis-Golgi or with each other to form the membrane stacks known as the cis-Golgi reticulum (network). [ISBN:0716731363]
Full description |

Standard name | GO_POST_GOLGI_VESICLE_MEDIATED_TRANSPORT
Systematic name | M19178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from the Golgi to other parts of the cell, including organelles and the plasma membrane, mediated by small transport vesicles. [GOC:ai, GOC:mah]
Full description |

Standard name | GO_GOLGI_TO_PLASMA_MEMBRANE_TRANSPORT
Systematic name | M12387
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from the Golgi to the plasma membrane in transport vesicles that move from the trans-Golgi network to the plasma membrane, where they fuse and release their contents by exocytosis. [ISBN:0716731363]
Full description |

Standard name | GO_GOLGI_TO_ENDOSOME_TRANSPORT
Systematic name | M13587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from the Golgi to early sorting endosomes. Clathrin vesicles transport substances from the trans-Golgi to endosomes. [GOC:jl, ISBN:0716731363, PMID:10873832]
Full description |

Standard name | GO_GOLGI_TO_VACUOLE_TRANSPORT
Systematic name | M14207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from the Golgi to the vacuole. [GOC:ai]
Full description |

Standard name | GO_ENDOCYTOSIS
Systematic name | M16060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A vesicle-mediated transport process in which cells take up external materials or membrane constituents by the invagination of a small region of the plasma membrane to form a new membrane-bounded vesicle. [GOC:mah, ISBN:0198506732, ISBN:0716731363]
Full description |

Standard name | GO_RECEPTOR_MEDIATED_ENDOCYTOSIS
Systematic name | M18488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An endocytosis process in which cell surface receptors ensure specificity of transport. A specific receptor on the cell surface binds tightly to the extracellular macromolecule (the ligand) that it recognizes; the plasma-membrane region containing the receptor-ligand complex then undergoes endocytosis, forming a transport vesicle containing the receptor-ligand complex and excluding most other plasma-membrane proteins. Receptor-mediated endocytosis generally occurs via clathrin-coated pits and vesicles. [GOC:mah, ISBN:0716731363]
Full description |

Standard name | GO_VESICLE_BUDDING_FROM_MEMBRANE
Systematic name | M22483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The evagination of a membrane, resulting in formation of a vesicle. [GOC:jid, GOC:tb]
Full description |

Standard name | GO_VESICLE_TARGETING
Systematic name | M11195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which vesicles are directed to specific destination membranes. Targeting involves coordinated interactions among cytoskeletal elements (microtubules or actin filaments), motor proteins, molecules at the vesicle membrane and target membrane surfaces, and vesicle cargo. [GOC:mah, PMID:17335816]
Full description |

Standard name | GO_VESICLE_DOCKING_INVOLVED_IN_EXOCYTOSIS
Systematic name | M12489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial attachment of a vesicle membrane to a target membrane, mediated by proteins protruding from the membrane of the vesicle and the target membrane, that contributes to exocytosis. [GOC:aruk, GOC:bc, GOC:jid, PMID:22438915]
Full description |

Standard name | GO_PINOCYTOSIS
Systematic name | M10341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An endocytosis process that results in the uptake of liquid material by cells from their external environment; literally 'cell drinking'. Liquid is enclosed in vesicles, called pinosomes, formed by invagination of the plasma membrane. [ISBN:0198506732]
Full description |

Standard name | GO_PHAGOCYTOSIS
Systematic name | M16307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A vesicle-mediated transport process that results in the engulfment of external particulate material by phagocytes and their delivery to the lysosome. The particles are initially contained within phagocytic vacuoles (phagosomes), which then fuse with primary lysosomes to effect digestion of the particles. [ISBN:0198506732]
Full description |

Standard name | GO_PHAGOCYTOSIS_RECOGNITION
Systematic name | M16726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial step in phagocytosis involving adhesion to bacteria, immune complexes and other particulate matter, or an apoptotic cell and based on recognition of factors such as bacterial cell wall components, opsonins like complement and antibody or protein receptors and lipids like phosphatidyl serine, and leading to intracellular signaling in the phagocytosing cell. [GOC:curators, ISBN:0781735149]
Full description |

Standard name | GO_APOPTOTIC_PROCESS
Systematic name | M34075
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A programmed cell death process which begins when a cell receives an internal (e.g. DNA damage) or external signal (e.g. an extracellular death ligand), and proceeds through a series of biochemical events (signaling pathway phase) which trigger an execution phase. The execution phase is the last step of an apoptotic process, and is typically characterized by rounding-up of the cell, retraction of pseudopodes, reduction of cellular volume (pyknosis), chromatin condensation, nuclear fragmentation (karyorrhexis), plasma membrane blebbing and fragmentation of the cell into apoptotic bodies. When the execution phase is completed, the cell has died. [GOC:cjm, GOC:dhl, GOC:ecd, GOC:go_curators, GOC:mtg_apoptosis, GOC:tb, ISBN:0198506732, PMID:18846107, PMID:21494263]
Full description |

Standard name | GO_ACTIVATION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_APOPTOTIC_PROCESS
Systematic name | M6665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of the inactive enzyme cysteine-type endopeptidase in the context of an apoptotic process. [GOC:al, GOC:dph, GOC:jl, GOC:mtg_apoptosis, GOC:tb, PMID:14744432, PMID:18328827, Wikipedia:Caspase]
Full description |

Standard name | GO_CELLULAR_COMPONENT_DISASSEMBLY_INVOLVED_IN_EXECUTION_PHASE_OF_APOPTOSIS
Systematic name | M18530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The breakdown of structures such as organelles, proteins, or other macromolecular structures during apoptosis. [GOC:dph, GOC:mah, GOC:mtg_apoptosis, GOC:tb]
Full description |

Standard name | GO_ACTIVATION_INDUCED_CELL_DEATH_OF_T_CELLS
Systematic name | M22486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A T cell apoptotic process that occurs towards the end of the expansion phase following the initial activation of mature T cells by antigen and is triggered by T cell receptor stimulation and signals transmitted via various surface-expressed members of the TNF receptor family such as Fas ligand, Fas, and TNF and the p55 and p75 TNF receptors. [GOC:add, GOC:mtg_apoptosis, ISBN:0781765196, PMID:12414721, PMID:12752672]
Full description |

Standard name | GO_INFLAMMATORY_CELL_APOPTOTIC_PROCESS
Systematic name | M22487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in an inflammatory cell, any cell participating in the inflammatory response to a foreign substance e.g. neutrophil, macrophage. [GOC:jl, GOC:mtg_apoptosis]
Full description |

Standard name | GO_SUBSTRATE_DEPENDENT_CELL_MIGRATION
Systematic name | M15295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a cell from one site to another along a substrate such as the extracellular matrix; the migrating cell forms a protrusion that attaches to the substrate. [ISBN:0815316194, PMID:11944043, PMID:14657486]
Full description |

Standard name | GO_SUBSTRATE_DEPENDENT_CELL_MIGRATION_CELL_EXTENSION
Systematic name | M22488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a cell surface protrusion, such as a lamellipodium or filopodium, at the leading edge of a migrating cell. [ISBN:0815316194, PMID:11944043, PMID:14657486]
Full description |

Standard name | GO_MUSCLE_CONTRACTION
Systematic name | M12628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within muscle tissue, resulting in a change in muscle geometry. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. [GOC:ef, GOC:mtg_muscle, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_MUSCLE_CONTRACTION
Systematic name | M12506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of muscle contraction. [GOC:go_curators]
Full description |

Standard name | GO_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M13593
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within smooth muscle tissue, resulting in a change in muscle geometry. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. Smooth muscle differs from striated muscle in the much higher actin/myosin ratio, the absence of conspicuous sarcomeres and the ability to contract to a much smaller fraction of its resting length. [GOC:ef, GOC:jl, GOC:mtg_muscle, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M11136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of smooth muscle contraction. [GOC:go_curators]
Full description |

Standard name | GO_STRIATED_MUSCLE_CONTRACTION
Systematic name | M19924
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within striated muscle tissue, resulting in the shortening of the muscle. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. Striated muscle is a type of muscle in which the repeating units (sarcomeres) of the contractile myofibrils are arranged in registry throughout the cell, resulting in transverse or oblique striations observable at the level of the light microscope. [GOC:jl, GOC:mtg_muscle, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_STRIATED_MUSCLE_CONTRACTION
Systematic name | M12174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of striated muscle contraction. [GOC:go_curators]
Full description |

Standard name | GO_SYNCYTIUM_FORMATION
Systematic name | M16681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a syncytium, a mass of cytoplasm containing several nuclei enclosed within a single plasma membrane. Syncytia are normally derived from single cells that fuse or fail to complete cell division. [ISBN:0198506732]
Full description |

Standard name | GO_DEFENSE_RESPONSE
Systematic name | M3458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Reactions, triggered in response to the presence of a foreign body or the occurrence of an injury, which result in restriction of damage to the organism attacked or prevention/recovery from the infection caused by the attack. [GOC:go_curators]
Full description |

Standard name | GO_ACUTE_PHASE_RESPONSE
Systematic name | M16862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An acute inflammatory response that involves non-antibody proteins whose concentrations in the plasma increase in response to infection or injury of homeothermic animals. [ISBN:0198506732]
Full description |

Standard name | GO_INFLAMMATORY_RESPONSE
Systematic name | M10617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The immediate defensive reaction (by vertebrate tissue) to infection or injury caused by chemical or physical agents. The process is characterized by local vasodilation, extravasation of plasma into intercellular spaces and accumulation of white blood cells and macrophages. [GO_REF:0000022, ISBN:0198506732]
Full description |

Standard name | GO_COMPLEMENT_ACTIVATION
Systematic name | M12406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the activation of any of the steps of the complement cascade, which allows for the direct killing of microbes, the disposal of immune complexes, and the regulation of other immune processes; the initial steps of complement activation involve one of three pathways, the classical pathway, the alternative pathway, and the lectin pathway, all of which lead to the terminal complement pathway. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_COMPLEMENT_ACTIVATION_ALTERNATIVE_PATHWAY
Systematic name | M13163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the activation of any of the steps of the alternative pathway of the complement cascade which allows for the direct killing of microbes and the regulation of other immune processes. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_HUMORAL_IMMUNE_RESPONSE
Systematic name | M13774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response mediated through a body fluid. [GOC:hb, ISBN:0198506732]
Full description |

Standard name | GO_CELLULAR_DEFENSE_RESPONSE
Systematic name | M15168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A defense response that is mediated by cells. [GOC:ebc]
Full description |

Standard name | GO_RESPONSE_TO_OSMOTIC_STRESS
Systematic name | M16208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating an increase or decrease in the concentration of solutes outside the organism or cell. [GOC:jl]
Full description |

Standard name | GO_HYPOTONIC_RESPONSE
Systematic name | M22489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of detection of, or exposure to, a hypotonic environment, i.e. an environment with a lower concentration of solutes than the organism or cell. [GOC:jl, PMID:12598593]
Full description |

Standard name | GO_HYPEROSMOTIC_RESPONSE
Systematic name | M11354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of detection of, or exposure to, a hyperosmotic environment, i.e. an environment with a higher concentration of solutes than the organism or cell. [GOC:jl, PMID:12142009]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_DNA_DAMAGE_STIMULUS
Systematic name | M13636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating damage to its DNA from environmental insults or errors during metabolism. [GOC:go_curators]
Full description |

Standard name | GO_DNA_DAMAGE_INDUCED_PROTEIN_PHOSPHORYLATION
Systematic name | M22490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The widespread phosphorylation of various molecules, triggering many downstream processes, that occurs in response to the detection of DNA damage. [GOC:go_curators]
Full description |

Standard name | GO_RESPONSE_TO_OXIDATIVE_STRESS
Systematic name | M3223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of oxidative stress, a state often resulting from exposure to high levels of reactive oxygen species, e.g. superoxide anions, hydrogen peroxide (H2O2), and hydroxyl radicals. [GOC:jl, PMID:12115731]
Full description |

Standard name | GO_ER_OVERLOAD_RESPONSE
Systematic name | M22491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated by the accumulation of normal or misfolded proteins in the endoplasmic reticulum and leading to activation of transcription by NF-kappaB. [PMID:10390516]
Full description |

Standard name | GO_ER_NUCLEUS_SIGNALING_PATHWAY
Systematic name | M12546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals that conveys information from the endoplasmic reticulum to the nucleus, usually resulting in a change in transcriptional regulation. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_STEROL_DEPLETION
Systematic name | M22492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating deprivation of sterols. Sterols are a group of steroids characterized by the presence of one or more hydroxyl groups and a hydrocarbon side-chain in the molecule. [GOC:bf, ISBN:0198506732]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_NITROGEN_STARVATION
Systematic name | M22493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of deprivation of nitrogen. [GOC:jl]
Full description |

Standard name | GO_NUCLEUS_ORGANIZATION
Systematic name | M13020
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the nucleus. [GOC:dph, GOC:ems, GOC:jl, GOC:mah]
Full description |

Standard name | GO_NUCLEAR_ENVELOPE_ORGANIZATION
Systematic name | M15019
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the nuclear envelope. [GOC:dph, GOC:ems, GOC:jl, GOC:mah]
Full description |

Standard name | GO_NUCLEAR_PORE_ORGANIZATION
Systematic name | M11924
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the nuclear pore. [GOC:dph, GOC:jid, GOC:jl, GOC:mah]
Full description |

Standard name | GO_NUCLEOLUS_ORGANIZATION
Systematic name | M22494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the nucleolus. [GOC:dph, GOC:jid, GOC:jl, GOC:mah]
Full description |

Standard name | GO_MITOCHONDRION_ORGANIZATION
Systematic name | M3040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a mitochondrion; includes mitochondrial morphogenesis and distribution, and replication of the mitochondrial genome as well as synthesis of new mitochondrial components. [GOC:dph, GOC:jl, GOC:mah, GOC:sgd_curators, PMID:9786946]
Full description |

Standard name | GO_MITOCHONDRIAL_MEMBRANE_ORGANIZATION
Systematic name | M5628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a mitochondrial membrane, either of the lipid bilayer surrounding a mitochondrion. [GOC:ai, GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_INNER_MITOCHONDRIAL_MEMBRANE_ORGANIZATION
Systematic name | M12841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the mitochondrial inner membrane. [GOC:ai, GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_OUTER_MITOCHONDRIAL_MEMBRANE_ORGANIZATION
Systematic name | M22495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the mitochondrial outer membrane. [GOC:ai, GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_PLASMA_MEMBRANE_ORGANIZATION
Systematic name | M11086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the plasma membrane. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_CYTOSKELETON_ORGANIZATION
Systematic name | M6657
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of cytoskeletal structures. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_ACTIN_FILAMENT_ORGANIZATION
Systematic name | M13068
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of cytoskeletal structures comprising actin filaments. Includes processes that control the spatial distribution of actin filaments, such as organizing filaments into meshworks, bundles, or other structures, as by cross-linking. [GOC:mah]
Full description |

Standard name | GO_MICROTUBULE_BASED_PROCESS
Systematic name | M4758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that depends upon or alters the microtubule cytoskeleton, that part of the cytoskeleton comprising microtubules and their associated proteins. [GOC:mah]
Full description |

Standard name | GO_MICROTUBULE_BASED_MOVEMENT
Systematic name | M3616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A microtubule-based process that results in the movement of organelles, other microtubules, or other cellular components. Examples include motor-driven movement along microtubules and movement driven by polymerization or depolymerization of microtubules. [GOC:cjm, ISBN:0815316194]
Full description |

Standard name | GO_MICROTUBULE_DEPOLYMERIZATION
Systematic name | M12616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of tubulin heterodimers from one or both ends of a microtubule. [ISBN:0815316194]
Full description |

Standard name | GO_MICROTUBULE_NUCLEATION
Systematic name | M11488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which tubulin alpha-beta heterodimers begin aggregation to form an oligomeric tubulin structure (a microtubule seed). Microtubule nucleation is the initiating step in the formation of a microtubule in the absence of any existing microtubules ('de novo' microtubule formation). [GOC:go_curators, ISBN:0815316194, PMID:12517712]
Full description |

Standard name | GO_TUBULIN_COMPLEX_ASSEMBLY
Systematic name | M22497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation and bonding together of alpha- and beta-tubulin to form a tubulin heterodimer. [GOC:mah]
Full description |

Standard name | GO_POST_CHAPERONIN_TUBULIN_FOLDING_PATHWAY
Systematic name | M29060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Completion of folding of alpha- and beta-tubulin; takes place subsequent to chaperonin-mediated partial folding; mediated by a complex of folding cofactors. [PMID:10542094]
Full description |

Standard name | GO_CYTOPLASM_ORGANIZATION
Systematic name | M22499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the cytoplasm. The cytoplasm is all of the contents of a cell excluding the plasma membrane and nucleus, but including other subcellular structures. [GOC:curators, GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_ORGANIZATION
Systematic name | M15310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the endoplasmic reticulum. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_GOLGI_ORGANIZATION
Systematic name | M16920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the Golgi apparatus. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_PEROXISOME_ORGANIZATION
Systematic name | M3524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a peroxisome. A peroxisome is a small, membrane-bounded organelle that uses dioxygen (O2) to oxidize organic molecules. [GOC:mah]
Full description |

Standard name | GO_ENDOSOME_ORGANIZATION
Systematic name | M10494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of endosomes. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_VACUOLE_ORGANIZATION
Systematic name | M1054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a vacuole. [GOC:mah]
Full description |

Standard name | GO_VACUOLAR_TRANSPORT
Systematic name | M11237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances into, out of or within a vacuole. [GOC:ai]
Full description |

Standard name | GO_VACUOLAR_ACIDIFICATION
Systematic name | M13305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that reduces the pH of the vacuole, measured by the concentration of the hydrogen ion. [GOC:jid]
Full description |

Standard name | GO_PROTEIN_CATABOLIC_PROCESS_IN_THE_VACUOLE
Systematic name | M22500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a protein in the vacuole, usually by the action of vacuolar proteases. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_LYSOSOMAL_TRANSPORT
Systematic name | M10443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances into, out of or within a lysosome. [GOC:ai]
Full description |

Standard name | GO_LYSOSOMAL_LUMEN_ACIDIFICATION
Systematic name | M22501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that reduces the pH of the lysosomal lumen, measured by the concentration of the hydrogen ion. [GOC:jid]
Full description |

Standard name | GO_CELL_CELL_JUNCTION_ASSEMBLY
Systematic name | M15540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a junction between cells. [GOC:ai]
Full description |

Standard name | GO_CELL_CYCLE
Systematic name | M9669
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of biochemical and morphological phases and events that occur in a cell during successive cell replication or nuclear replication events. Canonically, the cell cycle comprises the replication and segregation of genetic material followed by the division of the cell, but in endocycles or syncytial cells nuclear replication or nuclear division may not be followed by cell division. [GOC:go_curators, GOC:mtg_cell_cycle]
Full description |

Standard name | GO_CELL_CYCLE_ARREST
Systematic name | M14297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A regulatory process that halts progression through the cell cycle during one of the normal phases (G1, S, G2, M). [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_SPINDLE_ORGANIZATION
Systematic name | M18881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the spindle, the array of microtubules and associated molecules that forms between opposite poles of a eukaryotic cell during DNA segregation and serves to move the duplicated chromosomes apart. [GOC:go_curators, GOC:mah]
Full description |

Standard name | GO_MITOTIC_SPINDLE_ORGANIZATION
Systematic name | M2825
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the microtubule spindle during a mitotic cell cycle. [GOC:go_curators, GOC:mah]
Full description |

Standard name | GO_CHROMOSOME_SEGREGATION
Systematic name | M19628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which genetic material, in the form of chromosomes, is organized into specific structures and then physically separated and apportioned to two or more sets. In eukaryotes, chromosome segregation begins with the condensation of chromosomes, includes chromosome separation, and ends when chromosomes have completed movement to the spindle poles. [GOC:jl, GOC:mah, GOC:mtg_cell_cycle, GOC:vw]
Full description |

Standard name | GO_SISTER_CHROMATID_COHESION
Systematic name | M13145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which the sister chromatids of a replicated chromosome become tethered to each other. [GOC:jh, GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_REGULATION_OF_SISTER_CHROMATID_COHESION
Systematic name | M15695
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of sister chromatid cohesion. [GOC:go_curators]
Full description |

Standard name | GO_MITOTIC_SISTER_CHROMATID_COHESION
Systematic name | M16318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which the sister chromatids of a replicated chromosome are joined along the entire length of the chromosome, from their formation in S phase through metaphase during a mitotic cell cycle. This cohesion cycle is critical for high fidelity chromosome transmission. [GOC:ai, GOC:rn, PMID:10827941, PMID:11389843, PMID:14623866]
Full description |

Standard name | GO_MITOTIC_CHROMOSOME_CONDENSATION
Systematic name | M16780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which chromatin structure is compacted prior to and during mitosis in eukaryotic cells. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_MITOTIC_NUCLEAR_ENVELOPE_DISASSEMBLY
Systematic name | M22503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which the controlled breakdown of the nuclear envelope during mitotic cell division occurs. [GOC:bf]
Full description |

Standard name | GO_MITOTIC_METAPHASE_PLATE_CONGRESSION
Systematic name | M22504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which chromosomes are aligned at the metaphase plate, a plane halfway between the poles of the mitotic spindle, during mitosis. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_MITOTIC_NUCLEAR_ENVELOPE_REASSEMBLY
Systematic name | M22505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process that results in reformation of the nuclear envelope during mitotic cell division. [GOC:ai]
Full description |

Standard name | GO_MITOTIC_CELL_CYCLE_CHECKPOINT
Systematic name | M8627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle checkpoint that ensures accurate chromosome replication and segregation by preventing progression through a mitotic cell cycle until conditions are suitable for the cell to proceed to the next stage. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_MITOTIC_G2_DNA_DAMAGE_CHECKPOINT
Systematic name | M13382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A mitotic cell cycle checkpoint that detects and negatively regulates progression through the G2/M transition of the cell cycle in response to DNA damage. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_REGULATION_OF_EXIT_FROM_MITOSIS
Systematic name | M11467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the progression from anaphase/telophase to G1 that is associated with a conversion from high to low mitotic CDK activity. [GOC:rn]
Full description |

Standard name | GO_NUCLEAR_MIGRATION
Systematic name | M34076
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of the nucleus to a specific location within a cell. [GOC:ai]
Full description |

Standard name | GO_HOMOLOGOUS_CHROMOSOME_PAIRING_AT_MEIOSIS
Systematic name | M16642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The meiotic cell cycle process where side by side pairing and physical juxtaposition of homologous chromosomes is created during meiotic prophase. Homologous chromosome pairing begins when the chromosome arms begin to pair from the clustered telomeres and ends when synaptonemal complex or linear element assembly is complete. [GOC:mtg_cell_cycle, PMID:22582262, PMID:23117617, PMID:31811152]
Full description |

Standard name | GO_MALE_MEIOTIC_NUCLEAR_DIVISION
Systematic name | M22507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle process by which the cell nucleus divides as part of a meiotic cell cycle in the male germline. [GOC:dph, GOC:mah, GOC:vw]
Full description |

Standard name | GO_MALE_MEIOSIS_I
Systematic name | M13719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle process comprising the steps by which a cell progresses through male meiosis I, the first meiotic division in the male germline. [GOC:dph, GOC:mah]
Full description |

Standard name | GO_FEMALE_MEIOTIC_NUCLEAR_DIVISION
Systematic name | M22508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle process by which the cell nucleus divides as part of a meiotic cell cycle in the female germline. [GOC:dph, GOC:ems, GOC:mah, GOC:vw]
Full description |

Standard name | GO_FEMALE_MEIOSIS_I
Systematic name | M22509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which the first meiotic division occurs in the female germline. [GOC:mah]
Full description |

Standard name | GO_HOMOPHILIC_CELL_ADHESION_VIA_PLASMA_MEMBRANE_ADHESION_MOLECULES
Systematic name | M7823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a plasma membrane adhesion molecule in one cell to an identical molecule in an adjacent cell. [ISBN:0198506732]
Full description |

Standard name | GO_HETEROPHILIC_CELL_CELL_ADHESION_VIA_PLASMA_MEMBRANE_CELL_ADHESION_MOLECULES
Systematic name | M10391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of an adhesion molecule in one cell to a nonidentical adhesion molecule in an adjacent cell. [ISBN:0198506732]
Full description |

Standard name | GO_NEURON_CELL_CELL_ADHESION
Systematic name | M14028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a neuron to another cell via adhesion molecules. [GOC:go_curators]
Full description |

Standard name | GO_LEUKOCYTE_CELL_CELL_ADHESION
Systematic name | M14645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a leukocyte to another cell via adhesion molecules. [GOC:go_curators]
Full description |

Standard name | GO_CELL_MATRIX_ADHESION
Systematic name | M15809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The binding of a cell to the extracellular matrix via adhesion molecules. [GOC:hb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_ADHESION
Systematic name | M17747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cell adhesion. [GOC:go_curators]
Full description |

Standard name | GO_ESTABLISHMENT_OR_MAINTENANCE_OF_CELL_POLARITY
Systematic name | M1049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that results in the specification, formation or maintenance of anisotropic intracellular organization or cell growth patterns. [GOC:mah]
Full description |

Standard name | GO_ESTABLISHMENT_OF_TISSUE_POLARITY
Systematic name | M34077
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Coordinated organization of groups of cells in a tissue, such that they all orient to similar coordinates. [GOC:jid]
Full description |

Standard name | GO_ENZYME_LINKED_RECEPTOR_PROTEIN_SIGNALING_PATHWAY
Systematic name | M284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals initiated by the binding of an extracellular ligand to a receptor on the surface of the target cell, where the receptor possesses catalytic activity or is closely associated with an enzyme such as a protein kinase, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, GOC:signaling, ISBN:0815316194]
Full description |

Standard name | GO_RECEPTOR_GUANYLYL_CYCLASE_SIGNALING_PATHWAY
Systematic name | M22510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of an extracellular ligand to a receptor on the surface of the target cell where the receptor possesses guanylyl cyclase activity, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, GOC:signaling, PMID:16815030]
Full description |

Standard name | GO_TRANSMEMBRANE_RECEPTOR_PROTEIN_TYROSINE_KINASE_SIGNALING_PATHWAY
Systematic name | M17660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of an extracellular ligand to a receptor on the surface of the target cell where the receptor possesses tyrosine kinase activity, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:ceb, GOC:signaling]
Full description |

Standard name | GO_ACTIVATION_OF_TRANSMEMBRANE_RECEPTOR_PROTEIN_TYROSINE_KINASE_ACTIVITY
Systematic name | M16019
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of the inactive transmembrane receptor protein tyrosine kinase activity. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_SIGNAL_COMPLEX_ASSEMBLY
Systematic name | M22511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a complex capable of relaying a signal within a cell. [GOC:bf, GOC:signaling, PMID:9646862]
Full description |

Standard name | GO_EPIDERMAL_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M10399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by binding of a ligand to the tyrosine kinase receptor EGFR (ERBB1) on the surface of a cell. The pathway ends with regulation of a downstream cellular process, e.g. transcription. [GOC:ceb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EPIDERMAL_GROWTH_FACTOR_ACTIVATED_RECEPTOR_ACTIVITY
Systematic name | M22512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of EGF-activated receptor activity. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_EPIDERMAL_GROWTH_FACTOR_ACTIVATED_RECEPTOR_ACTIVITY
Systematic name | M11285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of EGF-activated receptor activity. [GOC:dph, GOC:go_curators]
Full description |

Standard name | GO_TRANSMEMBRANE_RECEPTOR_PROTEIN_SERINE_THREONINE_KINASE_SIGNALING_PATHWAY
Systematic name | M7385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of an extracellular ligand to a receptor on the surface of the target cell where the receptor possesses serine/threonine kinase activity, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of an extracellular ligand to a transforming growth factor beta receptor on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:BHF, GOC:mah, GOC:signaling]
Full description |

Standard name | GO_COMMON_PARTNER_SMAD_PROTEIN_PHOSPHORYLATION
Systematic name | M22513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing a phosphate group on to a common-partner SMAD protein. A common partner SMAD protein binds to pathway-restricted SMAD proteins forming a complex that translocates to the nucleus. [GOC:dph, ISBN:3527303782]
Full description |

Standard name | GO_SMAD_PROTEIN_COMPLEX_ASSEMBLY
Systematic name | M22514
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a protein complex that contains SMAD proteins. [GOC:isa_complete]
Full description |

Standard name | GO_TRANSMEMBRANE_RECEPTOR_PROTEIN_TYROSINE_PHOSPHATASE_SIGNALING_PATHWAY
Systematic name | M22515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of an extracellular ligand to a receptor on the surface of the target cell where the receptor possesses protein tyrosine phosphatase activity, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M2280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals that proceeds with an activated receptor promoting the exchange of GDP for GTP on the alpha-subunit of an associated heterotrimeric G-protein complex. The GTP-bound activated alpha-G-protein then dissociates from the beta- and gamma-subunits to further transmit the signal within the cell. The pathway begins with receptor-ligand interaction, or for basal GPCR signaling the pathway begins with the receptor activating its G protein in the absence of an agonist, and ends with regulation of a downstream cellular process, e.g. transcription. The pathway can start from the plasma membrane, Golgi or nuclear membrane. [GOC:bf, GOC:mah, PMID:16902576, PMID:24568158, Wikipedia:G_protein-coupled_receptor]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY_COUPLED_TO_CYCLIC_NUCLEOTIDE_SECOND_MESSENGER
Systematic name | M6402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a G protein-coupled receptor binding to its physiological ligand, where the pathway proceeds with activation or inhibition of a nucleotide cyclase activity and a subsequent change in the concentration of a cyclic nucleotide. [GOC:mah, GOC:signaling, ISBN:0815316194]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_ACTIVATING_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M1768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a G protein-coupled receptor binding to its physiological ligand, where the pathway proceeds through activation of adenylyl cyclase activity and a subsequent increase in the concentration of cyclic AMP (cAMP). [GOC:dph, GOC:mah, GOC:signaling, GOC:tb, ISBN:0815316194]
Full description |

Standard name | GO_ACTIVATION_OF_ADENYLATE_CYCLASE_ACTIVITY
Systematic name | M2198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of the inactive enzyme adenylate cyclase. [GOC:ai]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_ACTIVATING_DOPAMINE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M14081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a dopamine receptor binding to its physiological ligand, where the pathway proceeds with activation of adenylyl cyclase and a subsequent increase in the concentration of cyclic AMP (cAMP). [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_INHIBITING_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M14835
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a G protein-coupled receptor binding to its physiological ligand, where the pathway proceeds through inhibition of adenylyl cyclase activity and a subsequent decrease in the concentration of cyclic AMP (cAMP). [GOC:dph, GOC:mah, GOC:signaling, GOC:tb, ISBN:0815316194]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ADENYLATE_CYCLASE_ACTIVITY
Systematic name | M22516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of adenylate cyclase activity. [GOC:go_curators]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_INHIBITING_DOPAMINE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a dopamine receptor binding to its physiological ligand, where the pathway proceeds with inhibition of adenylyl cyclase and a subsequent decrease in the concentration of cyclic AMP (cAMP). [GOC:dph, GOC:mah, GOC:signaling, GOC:tb]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_INHIBITING_G_PROTEIN_COUPLED_GLUTAMATE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a G protein-coupled glutamate receptor binding to its physiological ligand, where the pathway proceeds with inhibition of adenylyl cyclase and a subsequent decrease in the concentration of cyclic AMP (cAMP). [GOC:dph, GOC:mah, GOC:signaling, GOC:tb]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_INHIBITING_G_PROTEIN_COUPLED_ACETYLCHOLINE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22519
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a G protein-coupled acetylcholine receptor binding to its physiological ligand, where the pathway proceeds with inhibition of adenylyl cyclase and a subsequent decrease in the concentration of cyclic AMP (cAMP). [GOC:dph, GOC:mah, GOC:signaling, GOC:tb]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_INHIBITING_SEROTONIN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M29061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a serotonin receptor binding to its physiological ligand, where the pathway proceeds with inhibition of adenylyl cyclase and a subsequent decrease in the concentration of cyclic AMP (cAMP). [GOC:dph, GOC:mah, GOC:signaling, GOC:tb]
Full description |

Standard name | GO_PHOSPHOLIPASE_C_ACTIVATING_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a G protein-coupled receptor binding to its physiological ligand, where the pathway proceeds with activation of phospholipase C (PLC) and a subsequent increase in the concentration of inositol trisphosphate (IP3) and diacylglycerol (DAG). [GOC:dph, GOC:mah, GOC:signaling, GOC:tb, ISBN:0815316194]
Full description |

Standard name | GO_ACTIVATION_OF_PHOSPHOLIPASE_C_ACTIVITY
Systematic name | M419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initiation of the activity of the inactive enzyme phospolipase C as the result of a series of molecular signals generated as a consequence of a G protein-coupled receptor binding to its physiological ligand. [GOC:dph, GOC:mah, GOC:tb, PMID:8280098]
Full description |

Standard name | GO_PROTEIN_KINASE_C_ACTIVATING_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a G protein-coupled receptor binding to its physiological ligand, where the pathway proceeds with activation of protein kinase C (PKC). PKC is activated by second messengers including diacylglycerol (DAG). [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_SEROTONIN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a serotonin receptor binding to one of its physiological ligands. [GOC:mah]
Full description |

Standard name | GO_DOPAMINE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M16457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a dopamine receptor binding to one of its physiological ligands. [GOC:mah, PMID:21711983]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_ACETYLCHOLINE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals initiated by an acetylcholine receptor on the surface of the target cell binding to one of its physiological ligands, and proceeding with the activated receptor promoting the exchange of GDP for GTP on the alpha-subunit of an associated heterotrimeric G-protein complex. The GTP-bound activated alpha-G-protein then dissociates from the beta- and gamma-subunits to further transmit the signal within the cell. The pathway begins with receptor-ligand interaction and ends with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_GAMMA_AMINOBUTYRIC_ACID_SIGNALING_PATHWAY
Systematic name | M11337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated by the binding of gamma-aminobutyric acid (GABA, 4-aminobutyrate), an amino acid which acts as a neurotransmitter in some organisms, to a cell surface receptor. [GOC:mah]
Full description |

Standard name | GO_GLUTAMATE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M17444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of glutamate to a glutamate receptor on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, GOC:signaling, PMID:9131252]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_GLUTAMATE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11464
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by glutamate binding to a glutamate receptor on the surface of the target cell, and proceeding with the activated receptor promoting the exchange of GDP for GTP on the alpha-subunit of an associated heterotrimeric G-protein complex. Ends with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, GOC:signaling, PMID:9131252]
Full description |

Standard name | GO_TACHYKININ_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a tachykinin, i.e. a short peptide with the terminal sequence (Phe-X-Gly-Leu-Met-NH2), binding to a cell surface receptor. [GOC:mah, PMID:14723970]
Full description |

Standard name | GO_NEUROPEPTIDE_SIGNALING_PATHWAY
Systematic name | M7277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a peptide neurotransmitter binding to a cell surface receptor. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_NOTCH_SIGNALING_PATHWAY
Systematic name | M3744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of an extracellular ligand to the receptor Notch on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:go_curators, GOC:signaling]
Full description |

Standard name | GO_NOTCH_RECEPTOR_PROCESSING
Systematic name | M10979
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of successive proteolytic cleavages of the Notch protein, which result in an active form of the receptor. [PMID:12651094, PMID:14986688]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_OF_NOTCH_RECEPTOR_TARGET
Systematic name | M22523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The activation of transcription of specific genes as a result of Notch signaling, mediated by the Notch intracellular domain. [PMID:12651094]
Full description |

Standard name | GO_WNT_SIGNALING_PATHWAY_CALCIUM_MODULATING_PATHWAY
Systematic name | M11621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of a Wnt protein to a receptor on the surface of the target cell where activated receptors leads to an increase in intracellular calcium and activation of protein kinase C (PKC). [GOC:bf, GOC:dph, GOC:go_curators, PMID:11532397]
Full description |

Standard name | GO_SMOOTHENED_SIGNALING_PATHWAY
Systematic name | M14890
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals generated as a consequence of activation of the transmembrane protein Smoothened. [GOC:mah, PMID:15205520]
Full description |

Standard name | GO_INTEGRIN_MEDIATED_SIGNALING_PATHWAY
Systematic name | M15881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of extracellular ligand to an integrin on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_I_KAPPAB_KINASE_NF_KAPPAB_SIGNALING
Systematic name | M10984
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a signal is passed on to downstream components within the cell through the I-kappaB-kinase (IKK)-dependent activation of NF-kappaB. The cascade begins with activation of a trimeric IKK complex (consisting of catalytic kinase subunits IKKalpha and/or IKKbeta, and the regulatory scaffold protein NEMO) and ends with the regulation of transcription of target genes by NF-kappaB. In a resting state, NF-kappaB dimers are bound to I-kappaB proteins, sequestering NF-kappaB in the cytoplasm. Phosphorylation of I-kappaB targets I-kappaB for ubiquitination and proteasomal degradation, thus releasing the NF-kappaB dimers, which can translocate to the nucleus to bind DNA and regulate transcription. [GOC:bf, GOC:jl, PMID:12773372, Reactome:R-HSA-209560]
Full description |

Standard name | GO_ACTIVATION_OF_NF_KAPPAB_INDUCING_KINASE_ACTIVITY
Systematic name | M11081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The stimulation of the activity of NF-kappaB-inducing kinase through phosphorylation at specific residues. [GOC:jl, PMID:12773372]
Full description |

Standard name | GO_I_KAPPAB_PHOSPHORYLATION
Systematic name | M14423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing a phosphate group into an inhibitor of kappa B (I-kappaB) protein. Phosphorylation of I-kappaB targets I-kappaB for ubiquitination and proteasomal degradation, thus releasing bound NF-kappaB dimers, which can translocate to the nucleus to bind DNA and regulate transcription. [GOC:bf, GOC:jl, PMID:21772278, PMID:7594468]
Full description |

Standard name | GO_CYTOPLASMIC_SEQUESTERING_OF_NF_KAPPAB
Systematic name | M22524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The selective interaction of the transcription factor NF-kappaB with specific molecules in the cytoplasm, thereby inhibiting its translocation into the nucleus. [GOC:jl]
Full description |

Standard name | GO_JNK_CASCADE
Systematic name | M13069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An intracellular protein kinase cascade containing at least a JNK (a MAPK), a JNKK (a MAPKK) and a JUN3K (a MAP3K). The cascade can also contain an additional tier: the upstream MAP4K. The kinases in each tier phosphorylate and activate the kinases in the downstream tier to transmit a signal within a cell. [GOC:bf, GOC:signaling, PMID:11790549, PMID:20811974]
Full description |

Standard name | GO_ACTIVATION_OF_JNKK_ACTIVITY
Systematic name | M22525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initiation of the activity of the inactive enzyme JUN kinase kinase (JNKK) activity. JNKKs are involved in a signaling pathway that is primarily activated by cytokines and exposure to environmental stress. [GOC:bf, PMID:11790549]
Full description |

Standard name | GO_ACTIVATION_OF_JUN_KINASE_ACTIVITY
Systematic name | M11379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initiation of the activity of the inactive enzyme JUN kinase (JNK). [GOC:bf]
Full description |

Standard name | GO_TYROSINE_PHOSPHORYLATION_OF_STAT_PROTEIN
Systematic name | M5562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing a phosphate group to a tyrosine residue of a STAT (Signal Transducer and Activator of Transcription) protein. [GOC:jl, PMID:10918594]
Full description |

Standard name | GO_NITRIC_OXIDE_MEDIATED_SIGNAL_TRANSDUCTION
Systematic name | M15820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any intracellular signal transduction in which the signal is passed on within the cell via nitric oxide (NO). Includes synthesis of nitric oxide, receptors/sensors for nitric oxide (such as soluble guanylyl cyclase/sGC) and downstream effectors that further transmit the signal within the cell. Nitric oxide transmits its downstream effects through either cyclic GMP (cGMP)-dependent or independent mechanisms. [GOC:jl, PMID:21549190]
Full description |

Standard name | GO_SMALL_GTPASE_MEDIATED_SIGNAL_TRANSDUCTION
Systematic name | M15802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals in which a small monomeric GTPase relays one or more of the signals. [GOC:mah]
Full description |

Standard name | GO_RAS_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M13487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals within the cell that are mediated by a member of the Ras superfamily of proteins switching to a GTP-bound active state. [GOC:bf]
Full description |

Standard name | GO_RHO_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M7069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals within the cell that are mediated by a member of the Rho family of proteins switching to a GTP-bound active state. [GOC:bf]
Full description |

Standard name | GO_CELL_CELL_SIGNALING
Systematic name | M11874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that mediates the transfer of information from one cell to another. This process includes signal transduction in the receiving cell and, where applicable, release of a ligand and any processes that actively facilitate its transport and presentation to the receiving cell. Examples include signaling via soluble ligands, via cell adhesion molecules and via gap junctions. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_NEUROTRANSMITTER_SECRETION
Systematic name | M29062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of neurotransmitter from the presynapse into the synaptic cleft via calcium-regulated exocytosis during synaptic transmission. [GOC:dph]
Full description |

Standard name | GO_NEURON_NEURON_SYNAPTIC_TRANSMISSION
Systematic name | M12840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of synaptic transmission from a neuron to another neuron across a synapse. [GOC:add, GOC:dos, GOC:jl, MeSH:D009435]
Full description |

Standard name | GO_SYNAPTIC_TRANSMISSION_CHOLINERGIC
Systematic name | M11082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The vesicular release of acetylcholine from a presynapse, across a chemical synapse, the subsequent activation of dopamine receptors at the postsynapse of a target cell (neuron, muscle, or secretory cell) and the effects of this activation on the postsynaptic membrane potential and ionic composition of the postsynaptic cytosol. This process encompasses both spontaneous and evoked release of neurotransmitter and all parts of synaptic vesicle exocytosis. Evoked transmission starts with the arrival of an action potential at the presynapse. [GOC:dos, Wikipedia:Cholinergic]
Full description |

Standard name | GO_ENSHEATHMENT_OF_NEURONS
Systematic name | M12937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which glial cells envelop neuronal cell bodies and/or axons to form an insulating layer. This can take the form of myelinating or non-myelinating ensheathment. [GOC:dgh, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEUROMUSCULAR_SYNAPTIC_TRANSMISSION
Systematic name | M15769
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of synaptic transmission from a neuron to a muscle, across a synapse. [GOC:dos, GOC:jl, MeSH:D009435]
Full description |

Standard name | GO_GAMETE_GENERATION
Systematic name | M14681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The generation and maintenance of gametes in a multicellular organism. A gamete is a haploid reproductive cell. [GOC:ems, GOC:mtg_sensu]
Full description |

Standard name | GO_GERM_CELL_DEVELOPMENT
Systematic name | M15865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an immature germ cell over time, from its formation to the mature structure (gamete). A germ cell is any reproductive cell in a multicellular organism. [GOC:go_curators]
Full description |

Standard name | GO_SPERM_AXONEME_ASSEMBLY
Systematic name | M22526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The assembly and organization of the sperm flagellar axoneme, the bundle of microtubules and associated proteins that forms the core of the eukaryotic sperm flagellum, and is responsible for movement. [GOC:bf, GOC:cilia, ISBN:0198547684]
Full description |

Standard name | GO_SPERMATID_NUCLEUS_DIFFERENTIATION
Systematic name | M13895
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specialization of the spermatid nucleus during the development of a spermatid into a mature male gamete competent for fertilization. [GOC:bf, GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_FEMALE_GAMETE_GENERATION
Systematic name | M14814
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Generation of the female gamete; specialised haploid cells produced by meiosis and along with a male gamete takes part in sexual reproduction. [GOC:dph, ISBN:0198506732]
Full description |

Standard name | GO_INSEMINATION
Systematic name | M11707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The introduction of semen or sperm into the genital tract of a female. [ISBN:0582227089]
Full description |

Standard name | GO_SINGLE_FERTILIZATION
Systematic name | M10123
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The union of male and female gametes to form a zygote. [GOC:ems, GOC:mtg_sensu]
Full description |

Standard name | GO_BINDING_OF_SPERM_TO_ZONA_PELLUCIDA
Systematic name | M16221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the sperm binds to the zona pellucida glycoprotein layer of the egg. The process begins with the attachment of the sperm plasma membrane to the zona pellucida and includes attachment of the acrosome inner membrane to the zona pellucida after the acrosomal reaction takes place. [GOC:dph, ISBN:0878932437]
Full description |

Standard name | GO_ACROSOME_REACTION
Systematic name | M14797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The discharge, by sperm, of a single, anterior secretory granule following the sperm's attachment to the zona pellucida of the oocyte. The process begins with the fusion of the outer acrosomal membrane with the sperm plasma membrane and ends with the exocytosis of the acrosomal contents into the zona pellucida. [GOC:dph, PMID:11175768, PMID:21042299, PMID:3886029]
Full description |

Standard name | GO_PENETRATION_OF_ZONA_PELLUCIDA
Systematic name | M22527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The infiltration by sperm of the zona pellucida to reach the oocyte. The process involves digestive enzymes from a modified lysosome called the acrosome, situated at the head of the sperm. [GOC:jl, http://arbl.cvmbs.colostate.edu/hbooks/pathphys/reprod/fert/fert.html]
Full description |

Standard name | GO_FUSION_OF_SPERM_TO_EGG_PLASMA_MEMBRANE_INVOLVED_IN_SINGLE_FERTILIZATION
Systematic name | M22528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The binding and fusion of a sperm, with the plasma membrane of the oocyte as part of the process of single fertilization. In sperm with flagella, binding occurs at the posterior (post-acrosomal) region of the sperm head. [GOC:dph, GOC:jl, http://arbl.cvmbs.colostate.edu/hbooks/pathphys/reprod/fert/fert.html]
Full description |

Standard name | GO_EGG_ACTIVATION
Systematic name | M22529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the egg becomes metabolically active, initiates protein and DNA synthesis and undergoes structural changes to its cortex and/or cytoplasm. [GOC:bf, PMID:9630751]
Full description |

Standard name | GO_REGULATION_OF_MITOTIC_CELL_CYCLE
Systematic name | M19030
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or extent of progress through the mitotic cell cycle. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_BLASTODERM_SEGMENTATION
Systematic name | M14056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The hierarchical steps resulting in the progressive subdivision of the anterior/posterior axis of the embryo. [http://fly.ebi.ac.uk/allied-data/lk/interactive-fly/aimain/1aahome.htm, ISBN:0879694238]
Full description |

Standard name | GO_TRIPARTITE_REGIONAL_SUBDIVISION
Systematic name | M14898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Subdivision of the embryo along the anterior/posterior axis into anterior, posterior and terminal regions. [GOC:dph, GOC:isa_complete, http://fly.ebi.ac.uk/allied-data/lk/interactive-fly/aimain/1aahome.htm, ISBN:0879694238]
Full description |

Standard name | GO_ZYGOTIC_DETERMINATION_OF_ANTERIOR_POSTERIOR_AXIS_EMBRYO
Systematic name | M22530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specification of the anterior/posterior axis of the embryo by products of genes expressed in the zygote; exemplified in insects by the gap genes, pair rule genes and segment polarity gene cascade. [http://fly.ebi.ac.uk/allied-data/lk/interactive-fly/aimain/1aahome.htm, ISBN:0879694238]
Full description |

Standard name | GO_THORAX_AND_ANTERIOR_ABDOMEN_DETERMINATION
Systematic name | M22531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Specification of the central (trunk) regions of the embryo by the gap genes; exemplified in insects by the actions of the Kruppel gene product. [http://fly.ebi.ac.uk/allied-data/lk/interactive-fly/aimain/1aahome.htm, ISBN:0879694238]
Full description |

Standard name | GO_GASTRULATION
Systematic name | M13572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A complex and coordinated series of cellular movements that occurs at the end of cleavage during embryonic development of most animals. The details of gastrulation vary from species to species, but usually result in the formation of the three primary germ layers, ectoderm, mesoderm and endoderm. [GOC:curators, ISBN:9780878933846]
Full description |

Standard name | GO_SEGMENT_SPECIFICATION
Systematic name | M14196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which segments assume individual identities; exemplified in insects by the actions of the products of the homeotic genes. [http://fly.ebi.ac.uk/allied-data/lk/interactive-fly/aimain/1aahome.htm, ISBN:0879694238]
Full description |

Standard name | GO_COMPARTMENT_PATTERN_SPECIFICATION
Systematic name | M22532
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process in which embryonic segments are divided into compartments that will result in differences in cell differentiation. [http://fly.ebi.ac.uk/allied-data/lk/interactive-fly/aimain/1aahome.htm, ISBN:0879694238]
Full description |

Standard name | GO_PATTERN_SPECIFICATION_PROCESS
Systematic name | M5927
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any developmental process that results in the creation of defined areas or spaces within an organism to which cells respond and eventually are instructed to differentiate. [GOC:go_curators, GOC:isa_complete, ISBN:0521436125]
Full description |

Standard name | GO_ECTODERM_DEVELOPMENT
Systematic name | M12267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the ectoderm over time, from its formation to the mature structure. In animal embryos, the ectoderm is the outer germ layer of the embryo, formed during gastrulation. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEUROBLAST_PROLIFERATION
Systematic name | M16110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a neuroblast population by cell division. A neuroblast is any cell that will divide and give rise to a neuron. [GOC:ai, GOC:mtg_sensu, GOC:sart]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEUROBLAST_PROLIFERATION
Systematic name | M22533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the proliferation of neuroblasts. [GOC:ai]
Full description |

Standard name | GO_AXONAL_FASCICULATION
Systematic name | M16337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The collection of axons into a bundle of rods, known as a fascicle. [GOC:dgh]
Full description |

Standard name | GO_SYNAPSE_ASSEMBLY
Systematic name | M10639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a synapse. This process ends when the synapse is mature (functional). [GOC:mah]
Full description |

Standard name | GO_CENTRAL_NERVOUS_SYSTEM_DEVELOPMENT
Systematic name | M974
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the central nervous system over time, from its formation to the mature structure. The central nervous system is the core nervous system that serves an integrating and coordinating function. In vertebrates it consists of the brain and spinal cord. In those invertebrates with a central nervous system it typically consists of a brain, cerebral ganglia and a nerve cord. [GOC:bf, GOC:jid, ISBN:0582227089]
Full description |

Standard name | GO_PERIPHERAL_NERVOUS_SYSTEM_DEVELOPMENT
Systematic name | M15524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the peripheral nervous system over time, from its formation to the mature structure. The peripheral nervous system is one of the two major divisions of the nervous system. Nerves in the PNS connect the central nervous system (CNS) with sensory organs, other organs, muscles, blood vessels and glands. [GOC:go_curators, UBERON:0000010]
Full description |

Standard name | GO_SENSORY_ORGAN_DEVELOPMENT
Systematic name | M15223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of sensory organs over time, from its formation to the mature structure. [GOC:go_curators]
Full description |

Standard name | GO_SALIVARY_GLAND_DEVELOPMENT
Systematic name | M10696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the salivary gland over time, from its formation to the mature structure. Salivary glands include any of the saliva-secreting exocrine glands of the oral cavity. [GOC:jid, UBERON:0001044]
Full description |

Standard name | GO_FOREGUT_MORPHOGENESIS
Systematic name | M22534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the foregut are generated and organized. [GOC:jid]
Full description |

Standard name | GO_ENDODERM_DEVELOPMENT
Systematic name | M13755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the endoderm over time, from its formation to the mature structure. The endoderm is the innermost germ layer that develops into the gastrointestinal tract, the lungs and associated tissues. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_MIDGUT_DEVELOPMENT
Systematic name | M16113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the midgut over time, from its formation to the mature structure. The midgut is the middle part of the alimentary canal from the stomach, or entrance of the bile duct, to, or including, the large intestine. [GOC:jid, UBERON:0001045]
Full description |

Standard name | GO_MESODERM_DEVELOPMENT
Systematic name | M15421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the mesoderm over time, from its formation to the mature structure. The mesoderm is the middle germ layer that develops into muscle, bone, cartilage, blood and connective tissue. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_MESODERMAL_CELL_FATE_SPECIFICATION
Systematic name | M22535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell fate determination process in which a cell becomes capable of differentiating autonomously into a mesoderm cell in an environment that is neutral with respect to the developmental pathway; upon specification, the cell fate can be reversed. [GOC:go_curators]
Full description |

Standard name | GO_GONADAL_MESODERM_DEVELOPMENT
Systematic name | M22536
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the gonadal mesoderm over time, from its formation to the mature structure. The gonadal mesoderm is the middle layer of the three primary germ layers of the embryo which will go on to form the gonads of the organism. [GOC:ai]
Full description |

Standard name | GO_HEART_DEVELOPMENT
Systematic name | M8348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the heart over time, from its formation to the mature structure. The heart is a hollow, muscular organ, which, by contracting rhythmically, keeps up the circulation of the blood. [GOC:jid, UBERON:0000948]
Full description |

Standard name | GO_ADULT_HEART_DEVELOPMENT
Systematic name | M15404
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the adult heart over time, from its formation to the mature structure. [GOC:bf]
Full description |

Standard name | GO_MUSCLE_ORGAN_DEVELOPMENT
Systematic name | M774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the muscle over time, from its formation to the mature structure. The muscle is an organ consisting of a tissue made up of various elongated cells that are specialized to contract and thus to produce movement and mechanical work. [GOC:jid, ISBN:0198506732]
Full description |

Standard name | GO_MYOBLAST_FUSION
Systematic name | M16873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which non-proliferating myoblasts fuse to existing fibers or to myotubes to form new fibers. A myoblast is a mononucleate cell type that, by fusion with other myoblasts, gives rise to the myotubes that eventually develop into skeletal muscle fibers. [CL:0000056, GOC:mtg_muscle]
Full description |

Standard name | GO_NEUROMUSCULAR_JUNCTION_DEVELOPMENT
Systematic name | M10077
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a neuromuscular junction. [GOC:mtg_OBO2OWL_2013]
Full description |

Standard name | GO_SEX_DETERMINATION
Systematic name | M11201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that establishes and transmits the specification of sexual status of an individual organism. [ISBN:0198506732]
Full description |

Standard name | GO_SEX_DIFFERENTIATION
Systematic name | M14458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment of the sex of an organism by physical differentiation. [GOC:ai]
Full description |

Standard name | GO_DOSAGE_COMPENSATION
Systematic name | M22537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Compensating for the variation in the unpaired sex chromosome:autosome chromosome ratios between sexes by activation or inactivation of genes on one or both of the sex chromosomes. [GOC:ems, ISBN:0140512888, PMID:11498577]
Full description |

Standard name | GO_EMBRYO_IMPLANTATION
Systematic name | M7793
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Attachment of the blastocyst to the uterine lining. [GOC:isa_complete, http://www.medterms.com]
Full description |

Standard name | GO_PARTURITION
Systematic name | M13603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The reproductive process in which the parent is separated from its offspring either by giving birth to live young or by laying eggs. [ISBN:0198506732]
Full description |

Standard name | GO_AGING
Systematic name | M12132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process that is a deterioration and loss of function over time. Aging includes loss of functions such as resistance to disease, homeostasis, and fertility, as well as wear and tear. Aging includes cellular senescence, but is more inclusive. May precede death and may succeed developmental maturation (GO:0021700). [GOC:PO_curators]
Full description |

Standard name | GO_CELL_AGING
Systematic name | M14701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An aging process that has as participant a cell after a cell has stopped dividing. Cell aging may occur when a cell has temporarily stopped dividing through cell cycle arrest (GO:0007050) or when a cell has permanently stopped dividing, in which case it is undergoing cellular senescence (GO:0090398). May precede cell death (GO:0008219) and succeed cell maturation (GO:0048469). [GOC:PO_curators]
Full description |

Standard name | GO_RESPONSE_TO_NUTRIENT
Systematic name | M15950
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nutrient stimulus. [GOC:go_curators]
Full description |

Standard name | GO_RESPIRATORY_GASEOUS_EXCHANGE_BY_RESPIRATORY_SYSTEM
Systematic name | M10354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of gaseous exchange between an organism and its environment. In plants, microorganisms, and many small animals, air or water makes direct contact with the organism's cells or tissue fluids, and the processes of diffusion supply the organism with dioxygen (O2) and remove carbon dioxide (CO2). In larger animals the efficiency of gaseous exchange is improved by specialized respiratory organs, such as lungs and gills, which are ventilated by breathing mechanisms. [ISBN:0198506732]
Full description |

Standard name | GO_DIGESTION
Systematic name | M10163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The whole of the physical, chemical, and biochemical processes carried out by multicellular organisms to break down ingested nutrients into components that may be easily absorbed and directed into metabolism. [GOC:isa_complete, ISBN:0198506732]
Full description |

Standard name | GO_EXCRETION
Systematic name | M10162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The elimination by an organism of the waste products that arise as a result of metabolic activity. These products include water, carbon dioxide (CO2), and nitrogenous compounds. [ISBN:0192801023]
Full description |

Standard name | GO_BODY_FLUID_SECRETION
Systematic name | M14825
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled release of a fluid by a cell or tissue in an animal. [GOC:ai, GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_LACTATION
Systematic name | M16885
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of milk from the mammary glands and the period of time that a mother lactates to feed her young. [ISBN:0198506732]
Full description |

Standard name | GO_BLOOD_COAGULATION_INTRINSIC_PATHWAY
Systematic name | M13351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein activation cascade that contributes to blood coagulation and consists of the interactions among high molecular weight kininogen, prekallikrein, and factor XII that lead to the activation of clotting factor X. [GOC:add, GOC:mah, GOC:pde]
Full description |

Standard name | GO_SENSORY_PERCEPTION
Systematic name | M14699
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive a sensory stimulus, convert it to a molecular signal, and recognize and characterize the signal. This is a neurological process. [GOC:ai, GOC:dph]
Full description |

Standard name | GO_PHOTOTRANSDUCTION
Systematic name | M11253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The sequence of reactions within a cell required to convert absorbed photons into a molecular signal. [GOC:go_curators]
Full description |

Standard name | GO_PHOTOTRANSDUCTION_VISIBLE_LIGHT
Systematic name | M12905
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The sequence of reactions within a cell required to convert absorbed photons from visible light into a molecular signal. A visible light stimulus is electromagnetic radiation that can be perceived visually by an organism; for organisms lacking a visual system, this can be defined as light with a wavelength within the range 380 to 780 nm. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_CHEMICAL_STIMULUS
Systematic name | M11231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive a sensory chemical stimulus, convert it to a molecular signal, and recognize and characterize the signal. This is a neurological process. [GOC:ai]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_SMELL
Systematic name | M22538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive an olfactory stimulus, convert it to a molecular signal, and recognize and characterize the signal. Olfaction involves the detection of chemical composition of an organism's ambient medium by chemoreceptors. This is a neurological process. [GOC:ai]
Full description |

Standard name | GO_BEHAVIOR
Systematic name | M10444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The internally coordinated responses (actions or inactions) of animals (individuals or groups) to internal or external stimuli, via a mechanism that involves nervous system activity. [GOC:ems, GOC:jl, ISBN:0395448956, PMID:20160973]
Full description |

Standard name | GO_LEARNING
Systematic name | M13048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in an organism in which a relatively long-lasting adaptive behavioral change occurs as the result of experience. [ISBN:0582227089, ISBN:0721662544]
Full description |

Standard name | GO_MEMORY
Systematic name | M10099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The activities involved in the mental information processing system that receives (registers), modifies, stores, and retrieves informational stimuli. The main stages involved in the formation and retrieval of memory are encoding (processing of received information by acquisition), storage (building a permanent record of received information as a result of consolidation) and retrieval (calling back the stored information and use it in a suitable way to execute a given task). [GOC:curators, ISBN:0582227089]
Full description |

Standard name | GO_SHORT_TERM_MEMORY
Systematic name | M22539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The memory process that deals with the storage, retrieval and modification of information received a short time (up to about 30 minutes) ago. This type of memory is typically dependent on direct, transient effects of second messenger activation. [http://hebb.mit.edu/courses/9.03/lecture4.html, ISBN:0582227089]
Full description |

Standard name | GO_LONG_TERM_MEMORY
Systematic name | M13777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The memory process that deals with the storage, retrieval and modification of information a long time (typically weeks, months or years) after receiving that information. This type of memory is typically dependent on gene transcription regulated by second messenger activation. [http://hebb.mit.edu/courses/9.03/lecture4.html, ISBN:0582227089]
Full description |

Standard name | GO_MATING_BEHAVIOR
Systematic name | M16030
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The behavioral interactions between organisms for the purpose of mating, or sexual reproduction resulting in the formation of zygotes. [GOC:ai, GOC:dph]
Full description |

Standard name | GO_MATING
Systematic name | M11325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The pairwise union of individuals for the purpose of sexual reproduction, ultimately resulting in the formation of zygotes. [GOC:jl, ISBN:0387520546]
Full description |

Standard name | GO_COPULATION
Systematic name | M16623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The act of sexual union between male and female, involving the transfer of sperm. [ISBN:0721662544]
Full description |

Standard name | GO_RHYTHMIC_BEHAVIOR
Systematic name | M14310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific behavior of an organism that recur with measured regularity. [GOC:jl, GOC:pr]
Full description |

Standard name | GO_CIRCADIAN_RHYTHM
Systematic name | M10045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process in an organism that recurs with a regularity of approximately 24 hours. [GOC:bf, GOC:go_curators]
Full description |

Standard name | GO_GROOMING_BEHAVIOR
Systematic name | M14426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific behavior of an organism relating to grooming, cleaning and brushing to remove dirt and parasites. [GOC:jl, GOC:pr]
Full description |

Standard name | GO_LOCOMOTORY_BEHAVIOR
Systematic name | M7204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific movement from place to place of an organism in response to external or internal stimuli. Locomotion of a whole organism in a manner dependent upon some combination of that organism's internal state and external conditions. [GOC:dph]
Full description |

Standard name | GO_FEEDING_BEHAVIOR
Systematic name | M17480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Behavior associated with the intake of food. [GOC:mah]
Full description |

Standard name | GO_VISUAL_BEHAVIOR
Systematic name | M15174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The behavior of an organism in response to a visual stimulus. [GOC:jid, GOC:pr]
Full description |

Standard name | GO_CHEMOSENSORY_BEHAVIOR
Systematic name | M13140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Behavior that is dependent upon the sensation of chemicals. [GOC:go_curators]
Full description |

Standard name | GO_MECHANOSENSORY_BEHAVIOR
Systematic name | M15667
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Behavior that is dependent upon the sensation of a mechanical stimulus. [GOC:go_curators]
Full description |

Standard name | GO_TRNA_PROCESSING
Systematic name | M16373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a pre-tRNA molecule is converted to a mature tRNA, ready for addition of an aminoacyl group. [GOC:jl, PMID:12533506]
Full description |

Standard name | GO_CELL_RECOGNITION
Systematic name | M5969
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a cell in an organism interprets its surroundings. [GOC:go_curators]
Full description |

Standard name | GO_NEURON_RECOGNITION
Systematic name | M10326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a neuronal cell in a multicellular organism interprets its surroundings. [GOC:go_curators]
Full description |

Standard name | GO_MOTOR_NEURON_AXON_GUIDANCE
Systematic name | M12159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the migration of an axon growth cone of a motor neuron is directed to a specific target site in response to a combination of attractive and repulsive cues. [CL:0000100, GOC:pr, ISBN:0878932437]
Full description |

Standard name | GO_MITOCHONDRIAL_FUSION
Systematic name | M14442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Merging of two or more mitochondria within a cell to form a single compartment. [PMID:11038192]
Full description |

Standard name | GO_TOLL_SIGNALING_PATHWAY
Systematic name | M22540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of an extracellular ligand to the receptor Toll on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:go_curators, PMID:11135568, PMID:19126860]
Full description |

Standard name | GO_MESODERMAL_CELL_MIGRATION
Systematic name | M22541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of mesodermal cells from one site to another. [GOC:ascb_2009, GOC:dph, GOC:mah, GOC:sat, GOC:tb, PMID:25119047]
Full description |

Standard name | GO_AXO_DENDRITIC_TRANSPORT
Systematic name | M10408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of organelles or molecules along microtubules in neuron projections. [ISBN:0815316194]
Full description |

Standard name | GO_ANTEROGRADE_AXONAL_TRANSPORT
Systematic name | M29064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of organelles or molecules along microtubules from the cell body toward the cell periphery in nerve cell axons. [ISBN:0815316194]
Full description |

Standard name | GO_RETROGRADE_AXONAL_TRANSPORT
Systematic name | M22542
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of organelles or molecules along microtubules from the cell periphery toward the cell body in nerve cell axons. [ISBN:0815316194]
Full description |

Standard name | GO_ACTIN_POLYMERIZATION_OR_DEPOLYMERIZATION
Systematic name | M2403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Assembly or disassembly of actin filaments by the addition or removal of actin monomers from a filament. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_REPLICATION
Systematic name | M17293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of DNA replication. [GOC:go_curators]
Full description |

Standard name | GO_STEROID_METABOLIC_PROCESS
Systematic name | M16758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving steroids, compounds with a 1,2,cyclopentanoperhydrophenanthrene nucleus. [ISBN:0198547684]
Full description |

Standard name | GO_BILE_ACID_METABOLIC_PROCESS
Systematic name | M17975
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving bile acids, any of a group of steroid carboxylic acids occurring in bile, where they are present as the sodium salts of their amides with glycine or taurine. [GOC:go_curators]
Full description |

Standard name | GO_C21_STEROID_HORMONE_METABOLIC_PROCESS
Systematic name | M11034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving C21-steroid hormones, steroid compounds containing 21 carbons which function as hormones. [GOC:ai]
Full description |

Standard name | GO_ANDROGEN_METABOLIC_PROCESS
Systematic name | M13960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving androgens, C19 steroid hormones that can stimulate the development of male sexual characteristics. [ISBN:0198506732]
Full description |

Standard name | GO_ESTROGEN_METABOLIC_PROCESS
Systematic name | M16636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving estrogens, C18 steroid hormones that can stimulate the development of female sexual characteristics. Also found in plants. [ISBN:0198506732]
Full description |

Standard name | GO_GLUCOCORTICOID_METABOLIC_PROCESS
Systematic name | M10776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glucocorticoids, hormonal C21 corticosteroids synthesized from cholesterol. Glucocorticoids act primarily on carbohydrate and protein metabolism, and have anti-inflammatory effects. [ISBN:0198506732]
Full description |

Standard name | GO_MINERALOCORTICOID_METABOLIC_PROCESS
Systematic name | M29066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving mineralocorticoids, hormonal C21 corticosteroids synthesized from cholesterol. Mineralocorticoids act primarily on water and electrolyte balance. [ISBN:0198506732]
Full description |

Standard name | GO_SPERMINE_METABOLIC_PROCESS
Systematic name | M29067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving spermine, a polybasic amine found in human sperm, in ribosomes and in some viruses, which is involved in nucleic acid packaging. Synthesis is regulated by ornithine decarboxylase which plays a key role in control of DNA replication. [GOC:curators]
Full description |

Standard name | GO_SPERMIDINE_METABOLIC_PROCESS
Systematic name | M22543
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving spermidine, N-(3-aminopropyl)-1,4-diaminobutane. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_BLOOD_PRESSURE
Systematic name | M10469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the force with which blood travels through the circulatory system. The process is controlled by a balance of processes that increase pressure and decrease pressure. [GOC:dph, GOC:mtg_cardio, ISBN:0721643949]
Full description |

Standard name | GO_OPSONIZATION
Systematic name | M22544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a microorganism (or other particulate material) is rendered more susceptible to phagocytosis by coating with an opsonin, a blood serum protein such as a complement component or antibody. [GOC:add, GOC:mah, ISBN:0198506732, ISBN:068340007X, ISBN:0781735149]
Full description |

Standard name | GO_SULFATE_TRANSPORT
Systematic name | M11256
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of sulfate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_REGULATION_OF_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of G protein-coupled receptor signaling pathway. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_POPULATION_PROLIFERATION
Systematic name | M2227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of cell proliferation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_POPULATION_PROLIFERATION
Systematic name | M6566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of cell proliferation. [GOC:go_curators]
Full description |

Standard name | GO_INSULIN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M18583
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of the insulin receptor binding to insulin. [GOC:ceb]
Full description |

Standard name | GO_ACETYLCHOLINE_METABOLIC_PROCESS
Systematic name | M29068
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving acetylcholine, the acetic acid ester of the organic base choline. Acetylcholine is a major neurotransmitter and neuromodulator both in the central and peripheral nervous systems. It also acts as a paracrine signal in various non-neural tissues. [GOC:jl, GOC:nln, ISBN:0192800752]
Full description |

Standard name | GO_INTRACELLULAR_MRNA_LOCALIZATION
Systematic name | M22548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which mRNA is transported to, or maintained in, a specific location within the cell. [GOC:ai]
Full description |

Standard name | GO_ISOPRENOID_BIOSYNTHETIC_PROCESS
Systematic name | M15231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any isoprenoid compound, isoprene (2-methylbuta-1,3-diene) or compounds containing or derived from linked isoprene (3-methyl-2-butenylene) residues. [ISBN:0198506732]
Full description |

Standard name | GO_ISOPRENOID_CATABOLIC_PROCESS
Systematic name | M22549
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of any isoprenoid compound, isoprene (2-methylbuta-1,3-diene) or compounds containing or derived from linked isoprene (3-methyl-2-butenylene) residues. [ISBN:0198506732]
Full description |

Standard name | GO_ASSOCIATIVE_LEARNING
Systematic name | M10883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Learning by associating a stimulus (the cause) with a particular outcome (the effect). [ISBN:0582227089]
Full description |

Standard name | GO_ENDOSOME_TO_LYSOSOME_TRANSPORT
Systematic name | M11014
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from endosomes to lysosomes. [GOC:ai, ISBN:0716731363]
Full description |

Standard name | GO_HISTONE_MRNA_METABOLIC_PROCESS
Systematic name | M14732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving an mRNA encoding a histone. [GOC:krc, GOC:mah, PMID:17855393]
Full description |

Standard name | GO_DETERMINATION_OF_ADULT_LIFESPAN
Systematic name | M14847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The control of viability and duration in the adult phase of the life-cycle. [GOC:ems]
Full description |

Standard name | GO_ADULT_FEEDING_BEHAVIOR
Systematic name | M22550
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Feeding behavior in a fully developed and mature organism. [GOC:mah]
Full description |

Standard name | GO_ADULT_LOCOMOTORY_BEHAVIOR
Systematic name | M11578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Locomotory behavior in a fully developed and mature organism. [GOC:ai]
Full description |

Standard name | GO_GLIAL_CELL_MIGRATION
Systematic name | M14116
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a glial cell, non-neuronal cells that provide support and nutrition, maintain homeostasis, form myelin, and participate in signal transmission in the nervous system. [GOC:jl, GOC:mtg_sensu]
Full description |

Standard name | GO_GERM_CELL_MIGRATION
Systematic name | M22551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a cell specialized to produce haploid gametes through the embryo from its site of production to the place where the gonads will form. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_ASYMMETRIC_CELL_DIVISION
Systematic name | M12036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The asymmetric division of cells to produce two daughter cells with different developmental potentials. It is of fundamental significance for the generation of cell diversity. [PMID:11672519]
Full description |

Standard name | GO_REGULATION_OF_CELL_SHAPE
Systematic name | M16874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the surface configuration of a cell. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CELL_SIZE
Systematic name | M13531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the size of a cell. [GOC:go_curators]
Full description |

Standard name | GO_RNA_SPLICING
Systematic name | M13559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of removing sections of the primary RNA transcript to remove sequences not present in the mature form of the RNA and joining the remaining sections to form the mature form of the RNA. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_RESPIRATORY_CHAIN_COMPLEX_IV_ASSEMBLY
Systematic name | M10577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form respiratory chain complex IV (also known as cytochrome c oxidase), the terminal member of the respiratory chain of the mitochondrion and some aerobic bacteria. Cytochrome c oxidases are multi-subunit enzymes containing from 13 subunits in the mammalian mitochondrial form to 3-4 subunits in the bacterial forms. [GOC:jl, http://www.med.wright.edu/bmb/lp/lplab.htm]
Full description |

Standard name | GO_FIBROBLAST_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M14806
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a fibroblast growth factor receptor binding to one of its physiological ligands. [GOC:ceb]
Full description |

Standard name | GO_EPIDERMIS_DEVELOPMENT
Systematic name | M14065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the epidermis over time, from its formation to the mature structure. The epidermis is the outer epithelial layer of an animal, it may be a single layer that produces an extracellular material (e.g. the cuticle of arthropods) or a complex stratified squamous epithelium, as in the case of many vertebrate species. [GOC:go_curators, UBERON:0001003]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_GROWTH_AT_NEUROMUSCULAR_JUNCTION
Systematic name | M22552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of synaptic growth at neuromuscular junctions. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_SMOOTHENED_SIGNALING_PATHWAY
Systematic name | M14063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of smoothened signaling. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_NOTCH_SIGNALING_PATHWAY
Systematic name | M14001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the Notch signaling pathway. [GOC:go_curators]
Full description |

Standard name | GO_ATTACHMENT_OF_SPINDLE_MICROTUBULES_TO_KINETOCHORE
Systematic name | M10211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which spindle microtubules become physically associated with the proteins making up the kinetochore complex. [GOC:vw, PMID:10322137]
Full description |

Standard name | GO_LIPID_BIOSYNTHETIC_PROCESS
Systematic name | M14504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of lipids, compounds soluble in an organic solvent but not, or sparingly, in an aqueous solvent. [GOC:go_curators]
Full description |

Standard name | GO_EXTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_VIA_DEATH_DOMAIN_RECEPTORS
Systematic name | M13726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which a signal is conveyed from the cell surface to trigger the apoptotic death of a cell. The pathway starts with a ligand binding to a death domain receptor on the cell surface, and ends when the execution phase of apoptosis is triggered. [GOC:mah, GOC:mtg_apoptosis]
Full description |

Standard name | GO_GRANZYME_MEDIATED_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M22553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals induced by granzymes which triggers the apoptotic death of a cell. The pathway starts with reception of a granzyme signal, and ends when the execution phase of apoptosis is triggered. Granzymes are serine proteases that are secreted by cytotoxic T cells and natural killer cells to induce apoptosis in target cells. [GOC:mtg_apoptosis, PMID:17158907]
Full description |

Standard name | GO_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_OSMOTIC_STRESS
Systematic name | M22554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway is induced in response to changes in intracellular ion homeostasis, and ends when the execution phase of apoptosis is triggered. [GOC:mtg_apoptosis, PMID:11454444, PMID:16483738]
Full description |

Standard name | GO_HORMONE_MEDIATED_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M22555
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by the detection of a hormone, and which triggers the apoptotic signaling pathway in a cell. The pathway starts with reception of a hormone signal, and ends when the execution phase of apoptosis is triggered. [GOC:bf, GOC:mtg_apoptosis]
Full description |

Standard name | GO_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_DNA_DAMAGE
Systematic name | M13458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway is induced by the detection of DNA damage, and ends when the execution phase of apoptosis is triggered. [GOC:go_curators, GOC:mtg_apoptosis]
Full description |

Standard name | GO_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_OXIDATIVE_STRESS
Systematic name | M22556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway is induced in response to oxidative stress, a state often resulting from exposure to high levels of reactive oxygen species, and ends when the execution phase of apoptosis is triggered. [GOC:ai, GOC:mtg_apoptosis]
Full description |

Standard name | GO_ACTIVATION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_APOPTOTIC_PROCESS_BY_CYTOCHROME_C
Systematic name | M22557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of the inactive enzyme cysteine-type endopeptidase in the context of an apoptotic process and is mediated by cytochrome c. [GOC:dph, GOC:jl, GOC:mtg_apoptosis, GOC:tb, PMID:14744432, Wikipedia:Caspase]
Full description |

Standard name | GO_APOPTOTIC_MITOCHONDRIAL_CHANGES
Systematic name | M7482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphological and physiological alterations undergone by mitochondria during apoptosis. [GOC:mah, GOC:mtg_apoptosis]
Full description |

Standard name | GO_CARBOHYDRATE_TRANSPORT
Systematic name | M10256
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of carbohydrate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Carbohydrates are any of a group of organic compounds based of the general formula Cx(H2O)y. [GOC:ai]
Full description |

Standard name | GO_CELLULAR_AMINO_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M11377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of amino acids, organic acids containing one or more amino substituents. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M11978
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of phospholipids, any lipid containing phosphoric acid as a mono- or diester. [ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_CONTAINING_COMPOUND_SALVAGE
Systematic name | M13567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that generates a pyrimidine-containing compound, any nucleobase, nucleoside, nucleotide or nucleic acid that contains a pyrimidine base, from derivatives of them without de novo synthesis. [GOC:jl]
Full description |

Standard name | GO_PENTOSE_PHOSPHATE_SHUNT_NON_OXIDATIVE_BRANCH
Systematic name | M22558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The branch of the pentose-phosphate shunt which does not involve oxidation reactions. It comprises a series of sugar phosphate interconversions, starting with ribulose 5-P and producing fructose 6-P and glyceraldehyde 3-P. [ISBN:0198506732, MetaCyc:NONOXIPENT-PWY]
Full description |

Standard name | GO_MACROMOLECULE_CATABOLIC_PROCESS
Systematic name | M1112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a macromolecule, any molecule of high relative molecular mass, the structure of which essentially comprises the multiple repetition of units derived, actually or conceptually, from molecules of low relative molecular mass. [GOC:mah]
Full description |

Standard name | GO_AEROBIC_RESPIRATION
Systematic name | M11785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The enzymatic release of energy from inorganic and organic compounds (especially carbohydrates and fats) which requires oxygen as the terminal electron acceptor. [GOC:das, GOC:jl, ISBN:0140513590]
Full description |

Standard name | GO_FATTY_ACID_CATABOLIC_PROCESS
Systematic name | M10250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a fatty acid, any of the aliphatic monocarboxylic acids that can be liberated by hydrolysis from naturally occurring fats and oils. Fatty acids are predominantly straight-chain acids of 4 to 24 carbon atoms, which may be saturated or unsaturated; branched fatty acids and hydroxy fatty acids also occur, and very long chain acids of over 30 carbons are found in waxes. [GOC:go_curators]
Full description |

Standard name | GO_CELLULAR_AMINO_ACID_CATABOLIC_PROCESS
Systematic name | M15063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of amino acids, organic acids containing one or more amino substituents. [GOC:ai]
Full description |

Standard name | GO_GLUTAMINE_FAMILY_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M11431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving amino acids of the glutamine family, comprising arginine, glutamate, glutamine and proline. [GOC:ai]
Full description |

Standard name | GO_GLUTAMINE_FAMILY_AMINO_ACID_CATABOLIC_PROCESS
Systematic name | M10807
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of amino acids of the glutamine family, comprising arginine, glutamate, glutamine and proline. [GOC:ai]
Full description |

Standard name | GO_ASPARTATE_FAMILY_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M15039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving amino acids of the aspartate family, comprising asparagine, aspartate, lysine, methionine and threonine. [GOC:ai]
Full description |

Standard name | GO_ASPARTATE_FAMILY_AMINO_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M11470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of amino acids of the aspartate family, comprising asparagine, aspartate, lysine, methionine and threonine. [GOC:ai]
Full description |

Standard name | GO_ASPARTATE_FAMILY_AMINO_ACID_CATABOLIC_PROCESS
Systematic name | M13099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of amino acids of the aspartate family, comprising asparagine, aspartate, lysine, methionine and threonine. [GOC:ai]
Full description |

Standard name | GO_SERINE_FAMILY_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M16092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving amino acids of the serine family, comprising cysteine, glycine, homoserine, selenocysteine and serine. [GOC:ai]
Full description |

Standard name | GO_SERINE_FAMILY_AMINO_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M11026
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of amino acids of the serine family, comprising cysteine, glycine, homoserine, selenocysteine and serine. [GOC:ai]
Full description |

Standard name | GO_SERINE_FAMILY_AMINO_ACID_CATABOLIC_PROCESS
Systematic name | M22559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of amino acids of the serine family, comprising cysteine, glycine, homoserine, selenocysteine and serine. [GOC:ai]
Full description |

Standard name | GO_AROMATIC_AMINO_ACID_FAMILY_METABOLIC_PROCESS
Systematic name | M12883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving aromatic amino acid family, amino acids with aromatic ring (phenylalanine, tyrosine, tryptophan). [GOC:go_curators]
Full description |

Standard name | GO_AROMATIC_AMINO_ACID_FAMILY_CATABOLIC_PROCESS
Systematic name | M15416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of aromatic amino acid family, amino acids with aromatic ring (phenylalanine, tyrosine, tryptophan). [GOC:go_curators]
Full description |

Standard name | GO_PYRUVATE_FAMILY_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M22560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any amino acid that requires pyruvate for its synthesis, e.g. alanine. [GOC:jl]
Full description |

Standard name | GO_BRANCHED_CHAIN_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M29069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving amino acids containing a branched carbon skeleton, comprising isoleucine, leucine and valine. [GOC:ai]
Full description |

Standard name | GO_BRANCHED_CHAIN_AMINO_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M34078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of amino acids containing a branched carbon skeleton, comprising isoleucine, leucine and valine. [GOC:ai]
Full description |

Standard name | GO_GLUTAMINE_FAMILY_AMINO_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M10295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of amino acids of the glutamine family, comprising arginine, glutamate, glutamine and proline. [GOC:ai]
Full description |

Standard name | GO_METHIONINE_BIOSYNTHETIC_PROCESS
Systematic name | M13431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of methionine (2-amino-4-(methylthio)butanoic acid), a sulfur-containing, essential amino acid found in peptide linkage in proteins. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_HOMOSERINE_METABOLIC_PROCESS
Systematic name | M22562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving homoserine, alpha-amino-gamma-hydroxybutyric acid, an intermediate in the biosynthesis of cystathionine, threonine and methionine. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_GLYCOPROTEIN_METABOLIC_PROCESS
Systematic name | M16741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycoproteins, any protein that contains covalently bound glycose (i.e. monosaccharide) residues; the glycose occurs most commonly as oligosaccharide or fairly small polysaccharide but occasionally as monosaccharide. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_GLYCOPROTEIN_BIOSYNTHETIC_PROCESS
Systematic name | M22563
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of glycoproteins, any protein that contains covalently bound glycose (i.e. monosaccharide) residues; the glycose occurs most commonly as oligosaccharide or fairly small polysaccharide but occasionally as monosaccharide. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_VITAMIN_BIOSYNTHETIC_PROCESS
Systematic name | M13391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a vitamin, one of a number of unrelated organic substances that occur in many foods in small amounts and that are necessary in trace amounts for the normal metabolic functioning of the body. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_VITAMIN_CATABOLIC_PROCESS
Systematic name | M22564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a vitamin, one of a number of unrelated organic substances that occur in many foods in small amounts and that are necessary in trace amounts for the normal metabolic functioning of the body. [GOC:ai]
Full description |

Standard name | GO_NUCLEOBASE_METABOLIC_PROCESS
Systematic name | M12754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a nucleobase, a nitrogenous base that is a constituent of a nucleic acid, e.g. the purines: adenine, guanine, hypoxanthine, xanthine and the pyrimidines: cytosine, uracil, thymine. [GOC:ma]
Full description |

Standard name | GO_PURINE_NUCLEOBASE_BIOSYNTHETIC_PROCESS
Systematic name | M13379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of purine nucleobases, one of the two classes of nitrogen-containing ring compounds found in DNA and RNA, which include adenine and guanine. [ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_METABOLIC_PROCESS
Systematic name | M22565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a nucleoside, a nucleobase linked to either beta-D-ribofuranose (a ribonucleoside) or 2-deoxy-beta-D-ribofuranose, (a deoxyribonucleoside), e.g. adenosine, guanosine, inosine, cytidine, uridine and deoxyadenosine, deoxyguanosine, deoxycytidine and thymidine (= deoxythymidine). [GOC:ma]
Full description |

Standard name | GO_RIBONUCLEOSIDE_METABOLIC_PROCESS
Systematic name | M29070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any ribonucleoside, a nucleoside in which purine or pyrimidine base is linked to a ribose (beta-D-ribofuranose) molecule. [GOC:jl]
Full description |

Standard name | GO_DEOXYRIBONUCLEOSIDE_METABOLIC_PROCESS
Systematic name | M29071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any one of a family of organic molecules consisting of a purine or pyrimidine base covalently bonded to a sugar deoxyribose (a deoxyribonucleoside). [GOC:jl, ISBN:0140512713]
Full description |

Standard name | GO_NUCLEOSIDE_MONOPHOSPHATE_METABOLIC_PROCESS
Systematic name | M15105
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a nucleoside monophosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_MONOPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M14180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a nucleoside monophosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_MONOPHOSPHATE_CATABOLIC_PROCESS
Systematic name | M22566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a nucleoside monophosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PURINE_NUCLEOSIDE_MONOPHOSPHATE_METABOLIC_PROCESS
Systematic name | M22567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving purine nucleoside monophosphate, a compound consisting of a purine base linked to a ribose or deoxyribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PURINE_NUCLEOSIDE_MONOPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M15156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of purine nucleoside monophosphate, a compound consisting of a purine base linked to a ribose or deoxyribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOSIDE_MONOPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29072
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving pyrimidine nucleoside monophosphate, a compound consisting of a pyrimidine base linked to a ribose or deoxyribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_DIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M10329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a nucleoside diphosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with diphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_DIPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M22569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a nucleoside diphosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with diphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_DIPHOSPHATE_CATABOLIC_PROCESS
Systematic name | M22570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a nucleoside diphosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with diphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_TRIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M13168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a nucleoside triphosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_TRIPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M13233
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a nucleoside triphosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_TRIPHOSPHATE_CATABOLIC_PROCESS
Systematic name | M15102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a nucleoside triphosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PURINE_NUCLEOSIDE_TRIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29073
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving purine nucleoside triphosphate, a compound consisting of a purine base linked to a ribose or deoxyribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PURINE_NUCLEOSIDE_TRIPHOSPHATE_CATABOLIC_PROCESS
Systematic name | M22573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of purine nucleoside triphosphate, a compound consisting of a purine base linked to a ribose or deoxyribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOSIDE_TRIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving pyrimidine nucleoside triphosphate, a compound consisting of a pyrimidine base linked to a ribose or deoxyribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOSIDE_TRIPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M11210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of pyrimidine nucleoside triphosphate, a compound consisting of a pyrimidine base linked to a ribose or deoxyribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PURINE_DEOXYRIBONUCLEOTIDE_METABOLIC_PROCESS
Systematic name | M29075
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving purine deoxyribonucleotide, a compound consisting of deoxyribonucleoside (a purine base linked to a deoxyribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PURINE_DEOXYRIBONUCLEOTIDE_BIOSYNTHETIC_PROCESS
Systematic name | M34079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of purine deoxyribonucleotide, a compound consisting of deoxyribonucleoside (a purine base linked to a deoxyribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PURINE_DEOXYRIBONUCLEOTIDE_CATABOLIC_PROCESS
Systematic name | M22574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of purine deoxyribonucleotide, a compound consisting of deoxyribonucleoside (a purine base linked to a deoxyribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_RIBONUCLEOSIDE_MONOPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M22575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a ribonucleoside monophosphate, a compound consisting of a nucleobase linked to a ribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_DEOXYRIBONUCLEOSIDE_MONOPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M22576
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a deoxyribonucleoside monophosphate, a compound consisting of a nucleobase linked to a deoxyribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_RIBONUCLEOSIDE_MONOPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29076
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a ribonucleoside monophosphate, a compound consisting of a nucleobase linked to a ribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_DEOXYRIBONUCLEOSIDE_MONOPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29077
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a deoxyribonucleoside monophosphate, a compound consisting of a nucleobase linked to a deoxyribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_CATABOLIC_PROCESS
Systematic name | M22577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of any one of a family of organic molecules consisting of a purine or pyrimidine base covalently bonded to a sugar ribose (a ribonucleoside) or deoxyribose (a deoxyribonucleoside). [GOC:jl]
Full description |

Standard name | GO_PYRIMIDINE_RIBONUCLEOSIDE_MONOPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving pyrimidine ribonucleoside monophosphate, a compound consisting of a pyrimidine base linked to a ribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_DEOXYRIBONUCLEOSIDE_MONOPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving pyrimidine deoxynucleoside monophosphate, a compound consisting of a pyrimidine base linked to a deoxyribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_DEOXYRIBONUCLEOSIDE_MONOPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M22578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of pyrimidine deoxynucleoside monophosphate, a compound consisting of a pyrimidine base linked to a deoxyribose sugar esterified with phosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_DEOXYRIBONUCLEOSIDE_DIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a deoxyribonucleoside diphosphate, a compound consisting of a nucleobase linked to a deoxyribose sugar esterified with diphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_CYCLIC_NUCLEOTIDE_METABOLIC_PROCESS
Systematic name | M11397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a cyclic nucleotide, a nucleotide in which the phosphate group is in diester linkage to two positions on the sugar residue. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_RIBONUCLEOSIDE_DIPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M34080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a ribonucleoside diphosphate, a compound consisting of a nucleobase linked to a ribose sugar esterified with diphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_CYCLIC_NUCLEOTIDE_BIOSYNTHETIC_PROCESS
Systematic name | M14261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a cyclic nucleotide, a nucleotide in which the phosphate group is in diester linkage to two positions on the sugar residue. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_RIBONUCLEOSIDE_TRIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a ribonucleoside triphosphate, a compound consisting of a nucleobase linked to a ribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_DEOXYRIBONUCLEOSIDE_TRIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a deoxyribonucleoside triphosphate, a compound consisting of a nucleobase linked to a deoxyribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_RIBONUCLEOSIDE_TRIPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M12677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a ribonucleoside triphosphate, a compound consisting of a nucleobase linked to a ribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_DEOXYRIBONUCLEOSIDE_TRIPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M22579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a deoxyribonucleoside triphosphate, a compound consisting of a nucleobase linked to a deoxyribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_DEOXYRIBONUCLEOSIDE_TRIPHOSPHATE_CATABOLIC_PROCESS
Systematic name | M22580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a deoxyribonucleoside triphosphate, a compound consisting of a nucleobase linked to a deoxyribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_RIBONUCLEOSIDE_TRIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving pyrimidine ribonucleoside triphosphate, a compound consisting of a pyrimidine base linked to a ribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_DEOXYRIBONUCLEOSIDE_TRIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving pyrimidine deoxyribonucleoside triphosphate, a compound consisting of a pyrimidine base linked to a deoxyribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_CYCLIC_NUCLEOTIDE_CATABOLIC_PROCESS
Systematic name | M11711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a cyclic nucleotide, a nucleotide in which the phosphate group is in diester linkage to two positions on the sugar residue. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PURINE_DEOXYRIBONUCLEOSIDE_TRIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving purine deoxyribonucleoside triphosphate, a compound consisting of a purine base linked to a deoxyribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PURINE_DEOXYRIBONUCLEOSIDE_TRIPHOSPHATE_CATABOLIC_PROCESS
Systematic name | M22582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of purine deoxyribonucleoside triphosphate, a compound consisting of a purine base linked to a deoxyribose sugar esterified with triphosphate on the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_RIBONUCLEOTIDE_METABOLIC_PROCESS
Systematic name | M29086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a pyrimidine ribonucleotide, a compound consisting of nucleoside (a pyrimidine base linked to a ribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_DEOXYRIBONUCLEOTIDE_METABOLIC_PROCESS
Systematic name | M29087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a pyrimidine deoxynucleotide, a compound consisting of nucleoside (a pyrimidine base linked to a deoxyribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_DEOXYRIBONUCLEOTIDE_BIOSYNTHETIC_PROCESS
Systematic name | M22584
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a pyrimidine deoxyribonucleotide, a compound consisting of nucleoside (a pyrimidine base linked to a deoxyribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOTIDE_SUGAR_METABOLIC_PROCESS
Systematic name | M17914
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular chemical reactions and pathways involving nucleotide-sugars, any nucleotide-carbohydrate in which the distal phosphoric residue of a nucleoside 5'-diphosphate is in glycosidic linkage with a monosaccharide or monosaccharide derivative. [ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOTIDE_SUGAR_BIOSYNTHETIC_PROCESS
Systematic name | M16127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of nucleotide-sugars, any nucleotide-carbohydrate in which the distal phosphoric residue of a nucleoside 5'-diphosphate is in glycosidic linkage with a monosaccharide or monosaccharide derivative. [ISBN:0198506732]
Full description |

Standard name | GO_MENAQUINONE_METABOLIC_PROCESS
Systematic name | M34081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any of the menaquinones, quinone-derived compounds synthesized by intestinal bacteria. Structurally, menaquinones consist of a methylated naphthoquinone ring structure and side chains composed of a variable number of unsaturated isoprenoid residues. Menaquinones have vitamin K activity and are known as vitamin K2. [GOC:jl, http://www.dentistry.leeds.ac.uk/biochem/thcme/vitamins.html#k]
Full description |

Standard name | GO_COBALAMIN_METABOLIC_PROCESS
Systematic name | M12625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving cobalamin (vitamin B12), a water-soluble vitamin characterized by possession of a corrin nucleus containing a cobalt atom. [GOC:go_curators]
Full description |

Standard name | GO_ISOPENTENYL_DIPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M22585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of isopentenyl diphosphate, an isomer of dimethylallyl diphosphate and the key precursor of all isoprenoids. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_GLYCOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M10674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of glycolipid, a class of 1,2-di-O-acylglycerols joined at oxygen 3 by a glycosidic linkage to a carbohydrate part (usually a mono-, di- or tri-saccharide). [GOC:go_curators]
Full description |

Standard name | GO_PROTEIN_LIPOYLATION
Systematic name | M22586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The lipoylation of peptidyl-lysine to form peptidyl-N6-lipoyl-L-lysine. [RESID:AA0118]
Full description |

Standard name | GO_10_FORMYLTETRAHYDROFOLATE_METABOLIC_PROCESS
Systematic name | M29088
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving 10-formyltetrahydrofolate, the formylated derivative of tetrahydrofolate. [GOC:ai]
Full description |

Standard name | GO_RIBONUCLEOTIDE_CATABOLIC_PROCESS
Systematic name | M10548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a ribonucleotide, a compound consisting of ribonucleoside (a base linked to a ribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_DEOXYRIBONUCLEOTIDE_METABOLIC_PROCESS
Systematic name | M29089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a deoxyribonucleotide, a compound consisting of deoxyribonucleoside (a base linked to a deoxyribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_DEOXYRIBONUCLEOTIDE_BIOSYNTHETIC_PROCESS
Systematic name | M14364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a deoxyribonucleotide, a compound consisting of deoxyribonucleoside (a base linked to a deoxyribose sugar) esterified with a phosphate group at either the 3' or 5'-hydroxyl group of the sugar. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_RESPONSE_TO_TEMPERATURE_STIMULUS
Systematic name | M7660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a temperature stimulus. [GOC:hb]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_STARVATION
Systematic name | M14501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of deprivation of nourishment. [GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_PH
Systematic name | M14244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a pH stimulus. pH is a measure of the acidity or basicity of an aqueous solution. [GOC:jl, Wikipedia:PH]
Full description |

Standard name | GO_MRNA_TRANSCRIPTION
Systematic name | M14396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular synthesis of messenger RNA (mRNA) from a DNA template. [GOC:jl]
Full description |

Standard name | GO_SNRNA_TRANSCRIPTION
Systematic name | M22589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of small nuclear RNA (snRNA) from a DNA template. [GOC:jl, ISBN:0321000382]
Full description |

Standard name | GO_RRNA_TRANSCRIPTION
Systematic name | M11730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of ribosomal RNA (rRNA), any RNA that forms part of the ribosomal structure, from a DNA template. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_TRNA_TRANSCRIPTION
Systematic name | M22590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of transfer RNA (tRNA) from a DNA template. [GOC:jl]
Full description |

Standard name | GO_AMINE_METABOLIC_PROCESS
Systematic name | M7216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any organic compound that is weakly basic in character and contains an amino or a substituted amino group. Amines are called primary, secondary, or tertiary according to whether one, two, or three carbon atoms are attached to the nitrogen atom. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_AMINE_BIOSYNTHETIC_PROCESS
Systematic name | M3353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any organic compound that is weakly basic in character and contains an amino or a substituted amino group. Amines are called primary, secondary, or tertiary according to whether one, two, or three carbon atoms are attached to the nitrogen atom. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_AMINE_CATABOLIC_PROCESS
Systematic name | M7838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of any organic compound that is weakly basic in character and contains an amino or a substituted amino group. Amines are called primary, secondary, or tertiary according to whether one, two, or three carbon atoms are attached to the nitrogen atom. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_OLIGOSACCHARIDE_METABOLIC_PROCESS
Systematic name | M10171
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving oligosaccharides, molecules with between two and (about) 20 monosaccharide residues connected by glycosidic linkages. [ISBN:0198506732]
Full description |

Standard name | GO_OLIGOSACCHARIDE_BIOSYNTHETIC_PROCESS
Systematic name | M14475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of oligosaccharides, molecules with between two and (about) 20 monosaccharide residues connected by glycosidic linkages. [ISBN:0198506732]
Full description |

Standard name | GO_OLIGOSACCHARIDE_CATABOLIC_PROCESS
Systematic name | M11203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of oligosaccharides, molecules with between two and (about) 20 monosaccharide residues connected by glycosidic linkages. [ISBN:0198506732]
Full description |

Standard name | GO_RESPONSE_TO_RADIATION
Systematic name | M13646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an electromagnetic radiation stimulus. Electromagnetic radiation is a propagating wave in space with electric and magnetic components. These components oscillate at right angles to each other and to the direction of propagation. [GOC:jl, Wikipedia:Electromagnetic_radiation]
Full description |

Standard name | GO_PHOSPHOLIPID_CATABOLIC_PROCESS
Systematic name | M15731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of phospholipids, any lipid containing phosphoric acid as a mono- or diester. [ISBN:0198506732]
Full description |

Standard name | GO_FOLIC_ACID_CONTAINING_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M12451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of folic acid and its derivatives. [GOC:ai]
Full description |

Standard name | GO_TOXIN_METABOLIC_PROCESS
Systematic name | M13243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a toxin, a poisonous compound (typically a protein) that is produced by cells or organisms and that can cause disease when introduced into the body or tissues of an organism. [GOC:cab2]
Full description |

Standard name | GO_RESPONSE_TO_HEAT
Systematic name | M17735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a heat stimulus, a temperature stimulus above the optimal temperature for that organism. [GOC:lr]
Full description |

Standard name | GO_RESPONSE_TO_COLD
Systematic name | M10527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cold stimulus, a temperature stimulus below the optimal temperature for that organism. [GOC:lr]
Full description |

Standard name | GO_RESPONSE_TO_XENOBIOTIC_STIMULUS
Systematic name | M9008
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a xenobiotic compound stimulus. Xenobiotic compounds are compounds foreign to living organisms. [GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_UV
Systematic name | M13573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ultraviolet radiation (UV light) stimulus. Ultraviolet radiation is electromagnetic radiation with a wavelength in the range of 10 to 380 nanometers. [GOC:hb]
Full description |

Standard name | GO_RESPONSE_TO_WATER_DEPRIVATION
Systematic name | M16777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a water deprivation stimulus, prolonged deprivation of water. [GOC:lr]
Full description |

Standard name | GO_RESPONSE_TO_WATER
Systematic name | M16350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting the presence, absence, or concentration of water. [GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_LIGHT_STIMULUS
Systematic name | M16292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a light stimulus, electromagnetic radiation of wavelengths classified as infrared, visible or ultraviolet light. [GOC:go_curators, ISBN:0582227089]
Full description |

Standard name | GO_NAD_BIOSYNTHETIC_PROCESS
Systematic name | M34082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of nicotinamide adenine dinucleotide, a coenzyme present in most living cells and derived from the B vitamin nicotinic acid; biosynthesis may be of either the oxidized form, NAD, or the reduced form, NADH. [GOC:jl, ISBN:0618254153]
Full description |

Standard name | GO_CARNITINE_METABOLIC_PROCESS
Systematic name | M29090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving carnitine (hydroxy-trimethyl aminobutyric acid), a compound that participates in the transfer of acyl groups across the inner mitochondrial membrane. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_METHYLGLYOXAL_METABOLIC_PROCESS
Systematic name | M29091
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving methylglyoxal, CH3-CO-CHO, the aldehyde of pyruvic acid. [GOC:ai]
Full description |

Standard name | GO_PUTRESCINE_METABOLIC_PROCESS
Systematic name | M29092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving putrescine, 1,4-diaminobutane; putrescine can be formed by decarboxylation of ornithine and is the metabolic precursor of spermidine and spermine. [GOC:ai]
Full description |

Standard name | GO_PUTRESCINE_BIOSYNTHETIC_PROCESS
Systematic name | M22592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of putrescine, 1,4-diaminobutane; putrescine can be synthesized from arginine or ornithine and is the metabolic precursor of spermidine and spermine. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_GAMMA_AMINOBUTYRIC_ACID_METABOLIC_PROCESS
Systematic name | M29093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving gamma-aminobutyric acid (GABA, 4-aminobutyrate), an amino acid which acts as a neurotransmitter in some organisms. [ISBN:0198506732]
Full description |

Standard name | GO_RNA_MODIFICATION
Systematic name | M12563
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent alteration of one or more nucleotides within an RNA molecule to produce an RNA molecule with a sequence that differs from that coded genetically. [GOC:go_curators, ISBN:1555811337]
Full description |

Standard name | GO_FERTILIZATION
Systematic name | M15335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The union of gametes of opposite sexes during the process of sexual reproduction to form a zygote. It involves the fusion of the gametic nuclei (karyogamy) and cytoplasm (plasmogamy). [GOC:tb, ISBN:0198506732]
Full description |

Standard name | GO_DETECTION_OF_ABIOTIC_STIMULUS
Systematic name | M14474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which an (non-living) abiotic stimulus is received by a cell and converted into a molecular signal. [GOC:hb]
Full description |

Standard name | GO_DETECTION_OF_LIGHT_STIMULUS
Systematic name | M14135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a light stimulus (in the form of photons) is received and converted into a molecular signal. [GOC:go_curators]
Full description |

Standard name | GO_DETECTION_OF_VISIBLE_LIGHT
Systematic name | M14216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a visible light stimulus is received by a cell and converted into a molecular signal. A visible light stimulus is electromagnetic radiation that can be perceived visually by an organism; for organisms lacking a visual system, this can be defined as light with a wavelength within the range 380 to 780 nm. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_DETECTION_OF_BIOTIC_STIMULUS
Systematic name | M18259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a biotic stimulus, one caused or produced by a living organism, is received and converted into a molecular signal. [GOC:hb]
Full description |

Standard name | GO_DETECTION_OF_VIRUS
Systematic name | M22593
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a stimulus from a virus is received and converted into a molecular signal. [GOC:hb]
Full description |

Standard name | GO_RESPONSE_TO_BIOTIC_STIMULUS
Systematic name | M4746
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a biotic stimulus, a stimulus caused or produced by a living organism. [GOC:hb]
Full description |

Standard name | GO_RESPONSE_TO_SYMBIONT
Systematic name | M34083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a symbiont, an organism living with an organism of a different species in close physical association. The symbiont is defined as the smaller of the organisms involved in a symbiotic interaction. [GOC:hb, ISBN:0198506732]
Full description |

Standard name | GO_RESPONSE_TO_WOUNDING
Systematic name | M5634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating damage to the organism. [GOC:go_curators]
Full description |

Standard name | GO_RESPONSE_TO_MECHANICAL_STIMULUS
Systematic name | M16378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mechanical stimulus. [GOC:hb]
Full description |

Standard name | GO_RESPONSE_TO_VIRUS
Systematic name | M16779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a virus. [GOC:hb]
Full description |

Standard name | GO_RESPONSE_TO_BACTERIUM
Systematic name | M18818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a bacterium. [GOC:hb]
Full description |

Standard name | GO_RESPONSE_TO_FUNGUS
Systematic name | M15573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a fungus. [GOC:hb]
Full description |

Standard name | GO_RESPONSE_TO_ABIOTIC_STIMULUS
Systematic name | M14159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an abiotic (not derived from living organisms) stimulus. [GOC:hb]
Full description |

Standard name | GO_RESPONSE_TO_GRAVITY
Systematic name | M11582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a gravitational stimulus. [GOC:hb]
Full description |

Standard name | GO_RESPONSE_TO_HERBICIDE
Systematic name | M22594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a herbicide stimulus. Herbicides are chemicals used to kill or control the growth of plants. [GOC:curators]
Full description |

Standard name | GO_RESPONSE_TO_TOXIC_SUBSTANCE
Systematic name | M15317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a toxic stimulus. [GOC:lr]
Full description |

Standard name | GO_RESPONSE_TO_LIGHT_INTENSITY
Systematic name | M22595
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a light intensity stimulus. [GOC:go_curators]
Full description |

Standard name | GO_PHOTOPERIODISM
Systematic name | M10689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of detection of, or exposure to, a period of light or dark of a given length, measured relative to a particular duration known as the 'critical day length'. The critical day length varies between species. [GOC:jid, GOC:pj, ISBN:0582015952, ISBN:0697037754, ISBN:0709408862]
Full description |

Standard name | GO_ENTRAINMENT_OF_CIRCADIAN_CLOCK
Systematic name | M13785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synchronization of a circadian rhythm to environmental time cues such as light. [GOC:jid]
Full description |

Standard name | GO_UV_PROTECTION
Systematic name | M11655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organism or cell protects itself from ultraviolet radiation (UV), which may also result in resistance to repeated exposure to UV. [GOC:jl, GOC:ml]
Full description |

Standard name | GO_RESPONSE_TO_SALT_STRESS
Systematic name | M13071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating an increase or decrease in the concentration of salt (particularly but not exclusively sodium and chloride ions) in the environment. [GOC:jl]
Full description |

Standard name | GO_PHENYLPROPANOID_METABOLIC_PROCESS
Systematic name | M22596
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving aromatic derivatives of trans-cinnamic acid. [GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_ENDOGENOUS_STIMULUS
Systematic name | M6658
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus arising within the organism. [GOC:sm]
Full description |

Standard name | GO_RESPONSE_TO_HORMONE
Systematic name | M13987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hormone stimulus. [GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_CARBOHYDRATE
Systematic name | M9582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a carbohydrate stimulus. [GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_FRUCTOSE
Systematic name | M22597
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fructose stimulus. [GOC:jl]
Full description |

Standard name | GO_HORMONE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M12291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by the detection of a hormone. [GOC:sm]
Full description |

Standard name | GO_CARBOHYDRATE_MEDIATED_SIGNALING
Systematic name | M22598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by the detection of carbohydrate. [GOC:sm]
Full description |

Standard name | GO_REGULATION_OF_ASYMMETRIC_CELL_DIVISION
Systematic name | M34084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of asymmetric cell division. [GOC:lr]
Full description |

Standard name | GO_EMBRYO_DEVELOPMENT
Systematic name | M15134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an embryo from its formation until the end of its embryonic life stage. The end of the embryonic stage is organism-specific. For example, for mammals, the process would begin with zygote formation and end with birth. For insects, the process would begin at zygote formation and end with larval hatching. For plant zygotic embryos, this would be from zygote formation to the end of seed dormancy. For plant vegetative embryos, this would be from the initial determination of the cell or group of cells to form an embryo until the point when the embryo becomes independent of the parent plant. [GOC:go_curators, GOC:isa_complete, GOC:mtg_sensu]
Full description |

Standard name | GO_POST_EMBRYONIC_DEVELOPMENT
Systematic name | M16529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the organism over time, from the completion of embryonic development to the mature structure. See embryonic development. [GOC:go_curators]
Full description |

Standard name | GO_EMBRYO_DEVELOPMENT_ENDING_IN_BIRTH_OR_EGG_HATCHING
Systematic name | M10259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an embryo over time, from zygote formation until the end of the embryonic life stage. The end of the embryonic life stage is organism-specific and may be somewhat arbitrary; for mammals it is usually considered to be birth, for insects the hatching of the first instar larva from the eggshell. [GOC:go_curators, GOC:isa_complete, GOC:mtg_sensu]
Full description |

Standard name | GO_AXIS_SPECIFICATION
Systematic name | M10396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment, maintenance and elaboration of a pattern along a line or around a point. [GOC:dph, GOC:go_curators, GOC:isa_complete]
Full description |

Standard name | GO_SPECIFICATION_OF_SYMMETRY
Systematic name | M12038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment of an organism's body plan or part of an organism such that a similar arrangement in form and relationship of parts around a common axis, or around each side of a plane is created. [GOC:go_curators]
Full description |

Standard name | GO_FLAVONOID_METABOLIC_PROCESS
Systematic name | M15331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving flavonoids, a group of water-soluble phenolic derivatives containing a flavan skeleton including flavones, flavonols and flavanoids, and anthocyanins. [GOC:tair_curators, ISBN:0198547684]
Full description |

Standard name | GO_ALKALOID_METABOLIC_PROCESS
Systematic name | M16310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving alkaloids, nitrogen containing natural products which are not otherwise classified as peptides, nonprotein amino acids, amines, cyanogenic glycosides, glucosinolates, cofactors, phytohormones or primary metabolites (such as purine or pyrimidine bases). [GOC:lr, ISBN:0122146743]
Full description |

Standard name | GO_ABSCISSION
Systematic name | M22599
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled shedding of a body part. [ISBN:0140514031]
Full description |

Standard name | GO_EMBRYONIC_PATTERN_SPECIFICATION
Systematic name | M13032
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in the patterns of cell differentiation that will arise in an embryo. [GOC:go_curators, ISBN:0521436125]
Full description |

Standard name | GO_POST_EMBRYONIC_ANIMAL_MORPHOGENESIS
Systematic name | M22600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process, occurring after animal embryonic development, by which anatomical structures are generated and organized. [GOC:go_curators]
Full description |

Standard name | GO_ANIMAL_ORGAN_MORPHOGENESIS
Systematic name | M12326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Morphogenesis of an animal organ. An organ is defined as a tissue or set of tissues that work together to perform a specific function or functions. Morphogenesis is the process in which anatomical structures are generated and organized. Organs are commonly observed as visibly distinct structures, but may also exist as loosely associated clusters of cells that work together to perform a specific function or functions. [GOC:dgh, GOC:go_curators, ISBN:0471245208, ISBN:0721662544]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BIOSYNTHETIC_PROCESS
Systematic name | M9602
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the rate of the chemical reactions and pathways resulting in the formation of substances. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_CATABOLIC_PROCESS
Systematic name | M12729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of the chemical reactions and pathways resulting in the breakdown of substances. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CATABOLIC_PROCESS
Systematic name | M16760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of substances. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CATABOLIC_PROCESS
Systematic name | M12781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of substances. [GOC:go_curators]
Full description |

Standard name | GO_AUDITORY_RECEPTOR_CELL_FATE_COMMITMENT
Systematic name | M22603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the cellular identity of auditory hair cells is acquired and determined. [GOC:lr]
Full description |

Standard name | GO_EPIDERMAL_CELL_DIFFERENTIATION
Systematic name | M12194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of an epidermal cell, any of the cells making up the epidermis. [GOC:dph, GOC:go_curators, GOC:mtg_sensu, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_HORMONE_TRANSPORT
Systematic name | M11292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of hormones into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:tb]
Full description |

Standard name | GO_ANTERIOR_POSTERIOR_AXIS_SPECIFICATION
Systematic name | M14941
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment, maintenance and elaboration of the anterior/posterior axis. The anterior-posterior axis is defined by a line that runs from the head or mouth of an organism to the tail or opposite end of the organism. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_DORSAL_VENTRAL_AXIS_SPECIFICATION
Systematic name | M15618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment, maintenance and elaboration of the dorsal/ventral axis. The dorsal/ventral axis is defined by a line that runs orthogonal to both the anterior/posterior and left/right axes. The dorsal end is defined by the upper or back side of an organism. The ventral end is defined by the lower or front side of an organism. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_ANTERIOR_POSTERIOR_PATTERN_SPECIFICATION
Systematic name | M12766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process in which specific areas of cell differentiation are determined along the anterior-posterior axis. The anterior-posterior axis is defined by a line that runs from the head or mouth of an organism to the tail or opposite end of the organism. [GOC:dph, GOC:go_curators, GOC:isa_complete, GOC:tb]
Full description |

Standard name | GO_DORSAL_VENTRAL_PATTERN_FORMATION
Systematic name | M11780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process in which the areas along the dorsal/ventral axis are established that will lead to differences in cell differentiation. The dorsal/ventral axis is defined by a line that runs orthogonal to both the anterior/posterior and left/right axes. The dorsal end is defined by the upper or back side of an organism. The ventral end is defined by the lower or front side of an organism. [GOC:dph, GOC:go_curators, GOC:isa_complete, GOC:tb]
Full description |

Standard name | GO_PROXIMAL_DISTAL_PATTERN_FORMATION
Systematic name | M12263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process in which specific areas of cell differentiation are determined along a proximal/distal axis. The proximal/distal axis is defined by a line that runs from main body (proximal end) of an organism outward (distal end). [GOC:dph, GOC:go_curators, GOC:isa_complete]
Full description |

Standard name | GO_CELL_CELL_RECOGNITION
Systematic name | M15483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell recognition between cells. May involve the formation of specialized cell junctions. [ISBN:0824072820]
Full description |

Standard name | GO_RESPONSE_TO_EXTRACELLULAR_STIMULUS
Systematic name | M13687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an extracellular stimulus. [GOC:go_curators]
Full description |

Standard name | GO_CELLULAR_WATER_HOMEOSTASIS
Systematic name | M34085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of water within a cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_OOCYTE_DIFFERENTIATION
Systematic name | M13948
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized immature germ cell acquires the specialized features of a mature female gamete. [GOC:go_curators, GOC:mtg_sensu]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_FATE_SPECIFICATION
Systematic name | M22604
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that restricts, stops or prevents a cell from adopting a specific cell fate. [GOC:go_curators]
Full description |

Standard name | GO_GLIAL_CELL_DIFFERENTIATION
Systematic name | M15366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a glial cell. [GOC:go_curators, GOC:mtg_sensu]
Full description |

Standard name | GO_CARDIOBLAST_DIFFERENTIATION
Systematic name | M13412
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized mesodermal cell acquires the specialized structural and/or functional features of a cardioblast. A cardioblast is a cardiac precursor cell. It is a cell that has been committed to a cardiac fate, but will undergo more cell division rather than terminally differentiating. [GOC:go_curators]
Full description |

Standard name | GO_MEIOTIC_CHROMOSOME_CONDENSATION
Systematic name | M22605
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Compaction of chromatin structure prior to meiosis in eukaryotic cells. [PMID:10072401]
Full description |

Standard name | GO_RESPONSE_TO_INORGANIC_SUBSTANCE
Systematic name | M11882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an inorganic substance stimulus. [GOC:sm]
Full description |

Standard name | GO_RESPONSE_TO_METAL_ION
Systematic name | M11938
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a metal ion stimulus. [GOC:sm]
Full description |

Standard name | GO_RESPONSE_TO_IRON_ION
Systematic name | M16655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an iron ion stimulus. [GOC:sm]
Full description |

Standard name | GO_RESPONSE_TO_IRON_III_ION
Systematic name | M34086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an iron(III) ion stimulus. [GOC:sm]
Full description |

Standard name | GO_RESPONSE_TO_MANGANESE_ION
Systematic name | M16546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a manganese ion stimulus. [GOC:sm]
Full description |

Standard name | GO_RESPONSE_TO_ZINC_ION
Systematic name | M10390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a zinc ion stimulus. [GOC:sm]
Full description |

Standard name | GO_SPECIFICATION_OF_ANIMAL_ORGAN_IDENTITY
Systematic name | M22610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process in which the identity of an animal organ primordium is specified. Identity is considered to be the aggregate of characteristics by which a structure is recognized. [GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PROTON_TRANSPORT
Systematic name | M14164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of proton transport into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:sm]
Full description |

Standard name | GO_RESPONSE_TO_X_RAY
Systematic name | M15358
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of X-ray radiation. An X-ray is a form of electromagnetic radiation with a wavelength in the range of 10 nanometers to 100 picometers (corresponding to frequencies in the range 30 PHz to 3 EHz). [GOC:sm, Wikipedia:X-ray]
Full description |

Standard name | GO_BODY_MORPHOGENESIS
Systematic name | M10308
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the soma are generated and organized. [GOC:ems, ISBN:0140512888]
Full description |

Standard name | GO_EMBRYONIC_BODY_MORPHOGENESIS
Systematic name | M22612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the embryonic soma are generated and organized. [GOC:ems]
Full description |

Standard name | GO_SUGAR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M22613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a change in the level of a mono- or disaccharide such as glucose, fructose or sucrose triggers the expression of genes controlling metabolic and developmental processes. [PMID:9014361]
Full description |

Standard name | GO_RESPONSE_TO_IONIZING_RADIATION
Systematic name | M10262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a ionizing radiation stimulus. Ionizing radiation is radiation with sufficient energy to remove electrons from atoms and may arise from spontaneous decay of unstable isotopes, resulting in alpha and beta particles and gamma rays. Ionizing radiation also includes X-rays. [PMID:12509526]
Full description |

Standard name | GO_MAINTENANCE_OF_DNA_METHYLATION
Systematic name | M22614
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in maintaining the methylation state of a nucleotide sequence. [PMID:11898023]
Full description |

Standard name | GO_RESPONSE_TO_UV_B
Systematic name | M16501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a UV-B radiation stimulus. UV-B radiation (UV-B light) spans the wavelengths 280 to 315 nm. [GOC:tb]
Full description |

Standard name | GO_RESPONSE_TO_UV_C
Systematic name | M10139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a UV-C radiation stimulus. UV-C radiation (UV-C light) spans the wavelengths 100 to 280 nm. [GOC:tb]
Full description |

Standard name | GO_RESPONSE_TO_LITHIUM_ION
Systematic name | M14953
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lithium (Li+) ion stimulus. [GOC:tb]
Full description |

Standard name | GO_VASCULAR_TRANSPORT
Systematic name | M34087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances, into, out of or within a cell, either in a vascular tissue or in the vascular membrane. [GOC:sm]
Full description |

Standard name | GO_ESTABLISHMENT_OR_MAINTENANCE_OF_TRANSMEMBRANE_ELECTROCHEMICAL_GRADIENT
Systematic name | M10147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of ions to establish or maintain an electrochemical gradient across a membrane by means of some agent such as a transporter or pore. [GOC:mah, GOC:sm]
Full description |

Standard name | GO_ENDOMEMBRANE_SYSTEM_ORGANIZATION
Systematic name | M13914
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the endomembrane system. [GOC:mah, GOC:sm]
Full description |

Standard name | GO_NADH_DEHYDROGENASE_COMPLEX_ASSEMBLY
Systematic name | M22615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an NADH dehydrogenase complex. [GOC:sm]
Full description |

Standard name | GO_MULTICELLULAR_ORGANISM_AGING
Systematic name | M10108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An aging process that has as participant a whole multicellular organism. Multicellular organism aging includes loss of functions such as resistance to disease, homeostasis, and fertility, as well as wear and tear. Multicellular organisms aging includes processes like cellular senescence and organ senescence, but is more inclusive. May precede death (GO:0016265) of an organism and may succeed developmental maturation (GO:0021700). [GOC:PO_curators]
Full description |

Standard name | GO_SCF_COMPLEX_ASSEMBLY
Systematic name | M22616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form the SKP1-Cullin/Cdc53-F-box protein ubiquitin ligase (SCF) complex. [GOC:pz]
Full description |

Standard name | GO_RESPONSE_TO_SELENIUM_ION
Systematic name | M22617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from selenium ion. [GOC:mg]
Full description |

Standard name | GO_HEAT_ACCLIMATION
Systematic name | M22618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases heat tolerance of an organism in response to high temperatures. [GOC:tair_curators]
Full description |

Standard name | GO_RESPONSE_TO_LEAD_ION
Systematic name | M16615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lead ion stimulus. [GOC:tair_curators, PMID:16461380]
Full description |

Standard name | GO_REGULATION_OF_HYDROGEN_PEROXIDE_METABOLIC_PROCESS
Systematic name | M15219
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving hydrogen peroxide. [PMID:14765119]
Full description |

Standard name | GO_MEMBRANE_INVAGINATION
Systematic name | M15414
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The infolding of a membrane. [GOC:tb]
Full description |

Standard name | GO_RESPONSE_TO_GAMMA_RADIATION
Systematic name | M14914
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a gamma radiation stimulus. Gamma radiation is a form of electromagnetic radiation (EMR) or light emission of a specific frequency produced from sub-atomic particle interaction, such as electron-positron annihilation and radioactive decay. Gamma rays are generally characterized as EMR having the highest frequency and energy, and also the shortest wavelength, within the electromagnetic radiation spectrum. [GOC:tair_curators]
Full description |

Standard name | GO_REGULATION_OF_ANION_CHANNEL_ACTIVITY
Systematic name | M22619
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of anion channel activity. [PMID:17319842]
Full description |

Standard name | GO_COP9_SIGNALOSOME_ASSEMBLY
Systematic name | M22620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a COP9 signalosome. [PMID:17307927]
Full description |

Standard name | GO_HISTONE_MONOUBIQUITINATION
Systematic name | M12020
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histones by addition of a single ubiquitin group. [PMID:17329563]
Full description |

Standard name | GO_FATTY_ACID_OMEGA_OXIDATION
Systematic name | M34088
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A fatty acid oxidation process in which the methyl group at the end of the fatty acid molecule (the omega carbon) is first oxidized to a hydroxyl group, then to an oxo group, and finally to a carboxyl group. The long chain dicarboxylates derived from omega-oxidation then enter the beta-oxidation pathway for further degradation. [MetaCyc:PWY-2724, PMID:16404574]
Full description |

Standard name | GO_RESPONSE_TO_ACIDIC_PH
Systematic name | M15520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a pH stimulus with pH < 7. pH is a measure of the acidity or basicity of an aqueous solution. [GOC:go_curators, GOC:tb, Wikipedia:PH]
Full description |

Standard name | GO_HISTONE_H3_K36_METHYLATION
Systematic name | M22621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of one or more methyl groups to lysine at position 36 of the histone. [GOC:pr, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CELL_FATE_COMMITMENT
Systematic name | M16856
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell fate commitment. Cell fate commitment is the commitment of cells to specific cell fates and their capacity to differentiate into particular kinds of cells. Positional information is established through protein signals that emanate from a localized source within a cell (the initial one-cell zygote) or within a developmental field. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_FATE_COMMITMENT
Systematic name | M22622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency or rate of cell fate commitment. Cell fate commitment is the commitment of cells to specific cell fates and their capacity to differentiate into particular kinds of cells. Positional information is established through protein signals that emanate from a localized source within a cell (the initial one-cell zygote) or within a developmental field. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_FATE_COMMITMENT
Systematic name | M10583
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency or rate of cell fate commitment. Cell fate commitment is the commitment of cells to specific cell fates and their capacity to differentiate into particular kinds of cells. Positional information is established through protein signals that emanate from a localized source within a cell (the initial one-cell zygote) or within a developmental field. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CENTRIOLE_CENTRIOLE_COHESION
Systematic name | M22623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which the two centrioles within a centrosome remain tightly paired. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_EXIT_FROM_MITOSIS
Systematic name | M12894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle transition where a cell leaves M phase and enters a new G1 phase. M phase is the part of the mitotic cell cycle during which mitosis and cytokinesis take place. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HEART_RATE
Systematic name | M22624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency or rate of heart contraction. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HEART_RATE
Systematic name | M12377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency or rate of heart contraction. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_MESENCHYMAL_CELL_PROLIFERATION
Systematic name | M15086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of cells, resulting in the expansion of a mesenchymal cell population. A mesenchymal cell is a cell that normally gives rise to other cells that are organized as three-dimensional masses, rather than sheets. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MESENCHYMAL_CELL_PROLIFERATION
Systematic name | M12439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mesenchymal cell proliferation. A mesenchymal cell is a cell that normally gives rise to other cells that are organized as three-dimensional masses, rather than sheets. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PEPTIDASE_ACTIVITY
Systematic name | M16870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate of peptidase activity, the hydrolysis of peptide bonds within proteins. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SIGNALING_RECEPTOR_ACTIVITY
Systematic name | M22625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a signaling receptor activity. Receptor activity is when a molecule combines with an extracellular or intracellular messenger to initiate a change in cell activity. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_GASTRULATION
Systematic name | M14070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or extent of gastrulation. Gastrulation is the complex and coordinated series of cellular movements that occurs at the end of cleavage during embryonic development of most animals. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_INTERCELLULAR_TRANSPORT
Systematic name | M29094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of substances between cells. [GOC:dhl]
Full description |

Standard name | GO_PROTEASOMAL_PROTEIN_CATABOLIC_PROCESS
Systematic name | M15332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a protein or peptide by hydrolysis of its peptide bonds that is mediated by the proteasome. [GOC:tb]
Full description |

Standard name | GO_PROTEASOMAL_UBIQUITIN_INDEPENDENT_PROTEIN_CATABOLIC_PROCESS
Systematic name | M22626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a protein or peptide by hydrolysis of its peptide bonds that is mediated by the proteasome but do not involve ubiquitin. [GOC:tb]
Full description |

Standard name | GO_RNA_SECONDARY_STRUCTURE_UNWINDING
Systematic name | M14123
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a secondary structure of RNA are broken or 'melted'. [PMID:17169986]
Full description |

Standard name | GO_REGULATION_OF_AUTOPHAGY
Systematic name | M10281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of autophagy. Autophagy is the process in which cells digest parts of their own cytoplasm. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AUTOPHAGY
Systematic name | M12149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of autophagy. Autophagy is the process in which cells digest parts of their own cytoplasm. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AUTOPHAGY
Systematic name | M15852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the rate of autophagy. Autophagy is the process in which cells digest parts of their own cytoplasm. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHATIDYLINOSITOL_BIOSYNTHETIC_PROCESS
Systematic name | M22627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of phosphatidylinositol. [GOC:dph, GOC:tb, GOC:vw]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHOSPHATIDYLINOSITOL_BIOSYNTHETIC_PROCESS
Systematic name | M22628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of phosphatidylinositol. [GOC:dph, GOC:tb, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHOLIPASE_ACTIVITY
Systematic name | M13050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of phospholipase activity, the hydrolysis of a phospholipid. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHOSPHOLIPASE_ACTIVITY
Systematic name | M10316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of phospholipase activity, the hydrolysis of a phospholipid. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PHOSPHOLIPASE_ACTIVITY
Systematic name | M22629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of phospholipase activity, the hydrolysis of a phospholipid. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CALCIUM_ION_TRANSPORT_INTO_CYTOSOL
Systematic name | M13541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate of the directed movement of calcium ions into the cytosol of a cell. The cytosol is that part of the cytoplasm that does not contain membranous or particulate subcellular components. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CALCIUM_ION_TRANSPORT_INTO_CYTOSOL
Systematic name | M12209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate of the directed movement of calcium ions into the cytosol of a cell. The cytosol is that part of the cytoplasm that does not contain membranous or particulate subcellular components. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CALCIUM_ION_TRANSPORT_INTO_CYTOSOL
Systematic name | M14062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate of the directed movement of calcium ions into the cytosol of a cell. The cytosol is that part of the cytoplasm that does not contain membranous or particulate subcellular components. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TRANSPOSITION
Systematic name | M22630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transposition. Transposition results in the movement of discrete segments of DNA between nonhomologous sites. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_ACTIVATION_OF_JANUS_KINASE_ACTIVITY
Systematic name | M22631
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency or rate of activation of JAK (Janus Activated Kinase) protein. The activation of JAK protein is the process of introducing a phosphate group to a tyrosine residue of a JAK (Janus Activated Kinase) protein, thereby activating it. [GOC:dph, GOC:tb, PMID:17190829, PMID:9135582]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACTIVATION_OF_JANUS_KINASE_ACTIVITY
Systematic name | M22632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency or rate of activation of JAK (Janus Activated Kinase) protein. The activation of JAK protein is the process of introducing a phosphate group to a tyrosine residue of a JAK (Janus Activated Kinase) protein, thereby activating it. [GOC:dph, GOC:tb, PMID:9135582]
Full description |

Standard name | GO_REGULATION_OF_PLATELET_ACTIVATION
Systematic name | M14994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or frequency of platelet activation. Platelet activation is a series of progressive, overlapping events triggered by exposure of the platelets to subendothelial tissue. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PLATELET_ACTIVATION
Systematic name | M10805
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate or frequency of platelet activation. Platelet activation is a series of progressive, overlapping events triggered by exposure of the platelets to subendothelial tissue. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLYCOPROTEIN_BIOSYNTHETIC_PROCESS
Systematic name | M22634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the chemical reactions and pathways resulting in the formation of glycoproteins, any protein that contains covalently bound glycose (i.e. monosaccharide) residues; the glycose occurs most commonly as oligosaccharide or fairly small polysaccharide but occasionally as monosaccharide. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHOSPHORUS_METABOLIC_PROCESS
Systematic name | M12940
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the chemical reactions and pathways involving phosphorus or compounds containing phosphorus. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PHOSPHORUS_METABOLIC_PROCESS
Systematic name | M13280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the chemical reactions and pathways involving phosphorus or compounds containing phosphorus. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CELL_CYCLE_PROCESS
Systematic name | M15760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates a cellular process that is involved in the progression of biochemical and morphological phases and events that occur in a cell during successive cell replication or nuclear replication events. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_KETONE_METABOLIC_PROCESS
Systematic name | M13102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the chemical reactions and pathways involving any of a class of organic compounds that contain the carbonyl group, CO, and in which the carbonyl group is bonded only to carbon atoms. The general formula for a ketone is RCOR, where R and R are alkyl or aryl groups. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_KETONE_BIOSYNTHETIC_PROCESS
Systematic name | M22635
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of a ketone, carried out by individual cells. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_DOUBLE_STRAND_BREAK_REPAIR_VIA_HOMOLOGOUS_RECOMBINATION
Systematic name | M11429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the error-free repair of a double-strand break in DNA in which the broken DNA molecule is repaired using homologous sequences. [GOC:dph, GOC:jp, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NUCLEAR_CELL_CYCLE_DNA_REPLICATION
Systematic name | M22636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of The DNA-dependent DNA replication that occurs in the nucleus of eukaryotic organisms as part of the cell cycle. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PLATELET_ACTIVATION
Systematic name | M22637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate or frequency of platelet activation. Platelet activation is a series of progressive, overlapping events triggered by exposure of the platelets to subendothelial tissue. [GOC:dph, GOC:sl, GOC:tb]
Full description |

Standard name | GO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_PRODUCTION
Systematic name | M22638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of vascular endothelial growth factor production due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:rl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_PRODUCTION
Systematic name | M16809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases or activates the frequency, rate, or extent of production of vascular endothelial growth factor. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_MIRNA_METABOLIC_PROCESS
Systematic name | M22639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving miRNA, microRNA, a class of single-stranded RNA molecules of about 21-23 nucleotides in length, which regulates gene expression. [PMID:17993620]
Full description |

Standard name | GO_MIRNA_CATABOLIC_PROCESS
Systematic name | M22640
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of miRNA, microRNA, a class of single-stranded RNA molecules of about 21-23 nucleotides in length, which regulates gene expression. [PMID:17993620]
Full description |

Standard name | GO_REGULATION_OF_LAMELLIPODIUM_ASSEMBLY
Systematic name | M11612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of the formation of a lamellipodium, a thin sheetlike extension of the surface of a migrating cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LAMELLIPODIUM_ASSEMBLY
Systematic name | M13928
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of the formation of a lamellipodium, a thin sheetlike extension of the surface of a migrating cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LAMELLIPODIUM_ASSEMBLY
Systematic name | M22641
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of the formation of a lamellipodium, a thin sheetlike extension of the surface of a migrating cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_ENDOTHELIAL_CELL_MIGRATION
Systematic name | M12838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the orderly movement of an endothelial cell into the extracellular matrix to form an endothelium. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOTHELIAL_CELL_MIGRATION
Systematic name | M12005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the orderly movement of an endothelial cell into the extracellular matrix to form an endothelium. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CYTOPLASMIC_MRNA_PROCESSING_BODY_ASSEMBLY
Systematic name | M22642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the aggregation, arrangement and bonding together of proteins and RNA molecules to form a cytoplasmic mRNA processing body. [GOC:dph, GOC:krc, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOPLASMIC_MRNA_PROCESSING_BODY_ASSEMBLY
Systematic name | M22643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the aggregation, arrangement and bonding together of proteins and RNA molecules to form a cytoplasmic mRNA processing body. [GOC:dph, GOC:krc, GOC:tb]
Full description |

Standard name | GO_POSTTRANSCRIPTIONAL_REGULATION_OF_GENE_EXPRESSION
Systematic name | M12155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gene expression after the production of an RNA transcript. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_ADAPTATION
Systematic name | M22644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, extent or frequency of the process in which cardiac muscle adapts, with consequent modifications to structural and/or functional phenotypes, in response to a stimulus. Stimuli include contractile activity, loading conditions, substrate supply, and environmental factors. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CARDIAC_MUSCLE_ADAPTATION
Systematic name | M22645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, extent or frequency of the process in which cardiac muscle adapts, with consequent modifications to structural and/or functional phenotypes, in response to a stimulus. Stimuli include contractile activity, loading conditions, substrate supply, and environmental factors. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CARDIAC_MUSCLE_ADAPTATION
Systematic name | M22646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, extent or frequency of the process in which cardiac muscle adapts, with consequent modifications to structural and/or functional phenotypes, in response to a stimulus. Stimuli include contractile activity, loading conditions, substrate supply, and environmental factors. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_PROGRAMMED_CELL_DEATH_INVOLVED_IN_CELL_DEVELOPMENT
Systematic name | M22647
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The activation of endogenous cellular processes that result in the death of a cell as part of its development. [GOC:dph, GOC:mtg_apoptosis, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SCHWANN_CELL_PROLIFERATION
Systematic name | M22648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency or extent of the multiplication or reproduction of Schwann cells, resulting in the expansion of their population. Schwann cells are a type of glial cell in the peripheral nervous system. [GOC:dph, GOC:sl, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_EPITHELIAL_CELL_MIGRATION
Systematic name | M11069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of epithelial cell migration. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EPITHELIAL_CELL_MIGRATION
Systematic name | M12808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of epithelial cell migration. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPITHELIAL_CELL_MIGRATION
Systematic name | M14851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of epithelial cell migration. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRIAL_FUSION
Systematic name | M22649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of merging of two or more mitochondria within a cell to form a single compartment. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MITOCHONDRIAL_FUSION
Systematic name | M22650
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of merging of two or more mitochondria within a cell to form a single compartment. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ORGANELLE_ORGANIZATION
Systematic name | M11547
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of an organelle. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ORGANELLE_ORGANIZATION
Systematic name | M16234
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of an organelle. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PLATELET_DERIVED_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15978
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the platelet-derived growth factor receptor signaling pathway. [GOC:dph, GOC:hjd, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PLATELET_DERIVED_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22651
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the platelet-derived growth factor receptor signaling pathway. [GOC:dph, GOC:hjd, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PLATELET_DERIVED_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the platelet-derived growth factor receptor signaling pathway. [GOC:dph, GOC:hjd, GOC:tb]
Full description |

Standard name | GO_CELL_COMMUNICATION_BY_ELECTRICAL_COUPLING
Systematic name | M13301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that mediates signaling interactions between one cell and another cell by transfer of current between their adjacent cytoplasms via intercellular protein channels. [GOC:dph, GOC:kmv, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CELL_COMMUNICATION_BY_ELECTRICAL_COUPLING
Systematic name | M14633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell communication via electrical coupling. Cell communication via electrical coupling is the process that mediates signaling interactions between one cell and another cell by transfer of current between their adjacent cytoplasms via intercellular protein channels. [GOC:dph, GOC:kmv, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M12233
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate or frequency of muscle cell apoptotic process, a form of programmed cell death induced by external or internal signals that trigger the activity of proteolytic caspases whose actions dismantle a muscle cell and result in its death. [GOC:dph, GOC:mtg_apoptosis, GOC:tb]
Full description |

Standard name | GO_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M22653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A form of programmed cell death induced by external or internal signals that trigger the activity of proteolytic caspases, whose actions dismantle a muscle cell and result in its death. A muscle cell is a mature contractile cell, commonly known as a myocyte, that forms one of three kinds of muscle. [CL:0000187, GOC:dph, GOC:mtg_apoptosis, GOC:tb]
Full description |

Standard name | GO_STRIATED_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M22654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A form of programmed cell death induced by external or internal signals that trigger the activity of proteolytic caspases, whose actions dismantle a striated muscle cell and result in its death. Striated muscle cells make up striated muscle fibers which are divided by transverse bands into striations. [CL:0000737, GOC:dph, GOC:mtg_apoptosis, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M16552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate or frequency of muscle cell apoptotic process, a form of programmed cell death induced by external or internal signals that trigger the activity of proteolytic caspases whose actions dismantle a muscle cell and result in its death. [GOC:dph, GOC:mtg_apoptosis, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STRIATED_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M22655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate or extent of striated muscle cell apoptotic process, a form of programmed cell death induced by external or internal signals that trigger the activity of proteolytic caspases whose actions dismantle a striated muscle cell and result in its death. [GOC:dph, GOC:mtg_apoptosis, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_STRIATED_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M16715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate or extent of striated muscle cell apoptotic process, a form of programmed cell death induced by external or internal signals that trigger the activity of proteolytic caspases whose actions dismantle a striated muscle cell and result in its death. [GOC:BHF, GOC:dph, GOC:mtg_apoptosis, GOC:rl, GOC:tb]
Full description |

Standard name | GO_ECTODERMAL_CELL_DIFFERENTIATION
Systematic name | M22656
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features of an ectodermal cell. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_EPITHELIAL_STRUCTURE_MAINTENANCE
Systematic name | M15560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A tissue homeostatic process required for the maintenance of epithelial structure. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_CARBOHYDRATE_METABOLIC_PROCESS
Systematic name | M22657
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, extent or frequency of the chemical reactions and pathways involving carbohydrates, any of a group of organic compounds based of the general formula Cx(H2O)y, as carried out by individual cells. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_CARBOHYDRATE_METABOLIC_PROCESS
Systematic name | M22658
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, extent or frequency of the chemical reactions and pathways involving carbohydrates, any of a group of organic compounds based of the general formula Cx(H2O)y, as carried out by individual cells. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_ALKALINE_PHOSPHATASE_ACTIVITY
Systematic name | M22659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of alkaline phosphatase activity, the catalysis of the reaction: an orthophosphoric monoester + H2O = an alcohol + phosphate, with an alkaline pH optimum. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ALKALINE_PHOSPHATASE_ACTIVITY
Systematic name | M22660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of alkaline phosphatase activity, the catalysis of the reaction: an orthophosphoric monoester + H2O = an alcohol + phosphate, with an alkaline pH optimum. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NOREPINEPHRINE_SECRETION
Systematic name | M22661
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the regulated release of norepinephrine. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_COLLAGEN_METABOLIC_PROCESS
Systematic name | M29095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the metabolism of collagen, any of a group of fibrous proteins of very high tensile strength that form the main component of connective tissue in animals. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_COLLAGEN_METABOLIC_PROCESS
Systematic name | M29096
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the chemical reactions and pathways resulting in the metabolism of collagen, any of a group of fibrous proteins of very high tensile strength that form the main component of connective tissue in animals. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_COLLAGEN_METABOLIC_PROCESS
Systematic name | M29097
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the chemical reactions and pathways resulting in the metabolism of collagen, any of a group of fibrous proteins of very high tensile strength that form the main component of connective tissue in animals. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_EXTRACELLULAR_MATRIX_DISASSEMBLY
Systematic name | M15732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of extracellular matrix disassembly. Extracellular matrix disassembly is a process that results in the breakdown of the extracellular matrix. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EXTRACELLULAR_MATRIX_DISASSEMBLY
Systematic name | M22662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of extracellular matrix disassembly. Extracellular matrix disassembly is a process that results in the breakdown of the extracellular matrix. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_EPITHELIAL_TO_MESENCHYMAL_TRANSITION
Systematic name | M16783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of epithelial to mesenchymal transition. Epithelial to mesenchymal transition where an epithelial cell loses apical/basolateral polarity, severs intercellular adhesive junctions, degrades basement membrane components and becomes a migratory mesenchymal cell. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPITHELIAL_TO_MESENCHYMAL_TRANSITION
Systematic name | M10621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of epithelial to mesenchymal transition. Epithelial to mesenchymal transition is where an epithelial cell loses apical/basolateral polarity, severs intercellular adhesive junctions, degrades basement membrane components and becomes a migratory mesenchymal cell. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EPITHELIAL_TO_MESENCHYMAL_TRANSITION
Systematic name | M11446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of epithelial to mesenchymal transition. Epithelial to mesenchymal transition where an epithelial cell loses apical/basolateral polarity, severs intercellular adhesive junctions, degrades basement membrane components and becomes a migratory mesenchymal cell. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_DEVELOPMENT
Systematic name | M15451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of the progression of the cell over time, from its formation to the mature structure. Cell development does not include the steps involved in committing a cell to a specific fate. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_DEVELOPMENT
Systematic name | M10301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of the progression of the cell over time, from its formation to the mature structure. Cell development does not include the steps involved in committing a cell to a specific fate. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HYDROGEN_PEROXIDE_METABOLIC_PROCESS
Systematic name | M34089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the chemical reactions and pathways involving hydrogen peroxide. [GOC:dph, GOC:hjd, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HYDROGEN_PEROXIDE_METABOLIC_PROCESS
Systematic name | M34090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the chemical reactions and pathways involving hydrogen peroxide. [GOC:dph, GOC:hjd, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_HYDROGEN_PEROXIDE_BIOSYNTHETIC_PROCESS
Systematic name | M22663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of hydrogen peroxide biosynthesis. The chemical reactions and pathways resulting in the formation of hydrogen peroxide (H2O2), a potentially harmful byproduct of aerobic cellular respiration which can cause damage to DNA. [GOC:dph, GOC:hjd, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HYDROGEN_PEROXIDE_BIOSYNTHETIC_PROCESS
Systematic name | M22664
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of hydrogen peroxide biosynthesis. The chemical reactions and pathways resulting in the formation of hydrogen peroxide (H2O2), a potentially harmful byproduct of aerobic cellular respiration which can cause damage to DNA. [GOC:dph, GOC:hjd, GOC:tb]
Full description |

Standard name | GO_PROTEIN_KINASE_A_SIGNALING
Systematic name | M22665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of reactions, mediated by the intracellular serine/threonine kinase protein kinase A, which occurs as a result of a single trigger reaction or compound. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_KINASE_A_SIGNALING
Systematic name | M13147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of protein kinase A signaling. PKA signaling is the series of reactions, mediated by the intracellular serine/threonine kinase protein kinase A, which occurs as a result of a single trigger reaction or compound. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_KINASE_A_SIGNALING
Systematic name | M22666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of protein kinase A signaling. PKA signaling is the series of reactions, mediated by the intracellular serine/threonine kinase protein kinase A, which occurs as a result of a single trigger reaction or compound. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MACROPHAGE_DERIVED_FOAM_CELL_DIFFERENTIATION
Systematic name | M12121
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of macrophage derived foam cell differentiation. Macrophage derived foam cell differentiation is the process in which a macrophage acquires the specialized features of a foam cell. A foam cell is a type of cell containing lipids in small vacuoles and typically seen in atherosclerotic lesions, as well as other conditions. [GOC:add, GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MACROPHAGE_DERIVED_FOAM_CELL_DIFFERENTIATION
Systematic name | M11590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of macrophage derived foam cell differentiation. Macrophage derived foam cell differentiation is the process in which a macrophage acquires the specialized features of a foam cell. A foam cell is a type of cell containing lipids in small vacuoles and typically seen in atherosclerotic lesions, as well as other conditions. [GOC:add, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MACROPHAGE_DERIVED_FOAM_CELL_DIFFERENTIATION
Systematic name | M14235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of macrophage derived foam cell differentiation. Macrophage derived foam cell differentiation is the process in which a macrophage acquires the specialized features of a foam cell. A foam cell is a type of cell containing lipids in small vacuoles and typically seen in atherosclerotic lesions, as well as other conditions. [GOC:add, GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_LONG_CHAIN_FATTY_ACID_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M34091
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of plasma membrane long-chain fatty acid transport. Plasma membrane long-chain fatty acid transport is the directed movement of long-chain fatty acids across the plasma membrane. A long-chain fatty acid is a fatty acid with a chain length between C13 and C22. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_NITRIC_OXIDE_MEDIATED_SIGNAL_TRANSDUCTION
Systematic name | M22667
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of nitric oxide mediated signal transduction. Nitric oxide mediated signal transduction is a series of molecular signals mediated by the detection of nitric oxide (NO). [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NITRIC_OXIDE_MEDIATED_SIGNAL_TRANSDUCTION
Systematic name | M22668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of nitric oxide mediated signal transduction. Nitric oxide mediated signal transduction is a series of molecular signals mediated by the detection of nitric oxide (NO). [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CGMP_MEDIATED_SIGNALING
Systematic name | M22669
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of cGMP-mediated signaling. cGMP-mediated signaling is a series of molecular signals in which a cell uses cyclic GMP to convert an extracellular signal into a response. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CGMP_MEDIATED_SIGNALING
Systematic name | M22670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of cGMP-mediated signaling. cGMP-mediated signaling is a series of molecular signals in which a cell uses cyclic GMP to convert an extracellular signal into a response. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CGMP_MEDIATED_SIGNALING
Systematic name | M22671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of cGMP-mediated signaling. cGMP-mediated signaling is a series of molecular signals in which a cell uses cyclic GMP to convert an extracellular signal into a response. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PLASMINOGEN_ACTIVATION
Systematic name | M22672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of plasminogen activation. Plasminogen activation is the process in which plasminogen is processed to plasmin. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PLASMINOGEN_ACTIVATION
Systematic name | M22673
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of plasminogen activation. Plasminogen activation is the process in which plasminogen is processed to plasmin. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PLASMINOGEN_ACTIVATION
Systematic name | M22674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of plasminogen activation. Plasminogen activation is the process in which plasminogen is processed to plasmin. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MACROPHAGE_CHEMOTAXIS
Systematic name | M12468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of macrophage chemotaxis. Macrophage chemotaxis is the movement of a macrophage in response to an external stimulus. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MACROPHAGE_CHEMOTAXIS
Systematic name | M13699
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of macrophage chemotaxis. Macrophage chemotaxis is the movement of a macrophage in response to an external stimulus. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MACROPHAGE_CHEMOTAXIS
Systematic name | M22675
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of macrophage chemotaxis. Macrophage chemotaxis is the movement of a macrophage in response to an external stimulus. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_FIBROBLAST_MIGRATION
Systematic name | M22676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell migration that is accomplished by extension and retraction of a fibroblast pseudopodium. A fibroblast is a connective tissue cell which secretes an extracellular matrix rich in collagen and other macromolecules. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_FIBROBLAST_MIGRATION
Systematic name | M11312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of fibroblast cell migration. Fibroblast cell migration is accomplished by extension and retraction of a pseudopodium. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FIBROBLAST_MIGRATION
Systematic name | M11477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of fibroblast cell migration. Fibroblast cell migration is accomplished by extension and retraction of a pseudopodium. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FIBROBLAST_MIGRATION
Systematic name | M22677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of fibroblast cell migration. Fibroblast cell migration is accomplished by extension and retraction of a pseudopodium. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SODIUM_ION_TRANSPORT
Systematic name | M11460
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the directed movement of sodium ions (Na+) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SODIUM_ION_TRANSPORT
Systematic name | M10528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the directed movement of sodium ions (Na+) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CELL_MORPHOGENESIS_INVOLVED_IN_DIFFERENTIATION
Systematic name | M10820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell morphogenesis contributing to cell differentiation. Cell morphogenesis involved in differentiation is the change in form (cell shape and size) that occurs when relatively unspecialized cells acquire specialized structural and/or functional features that characterize the cells, tissues, or organs of the mature organism or some other relatively stable phase of the organism's life history. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_MORPHOGENESIS_INVOLVED_IN_DIFFERENTIATION
Systematic name | M16913
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of cell morphogenesis contributing to cell differentiation. Cell morphogenesis involved in differentiation is the change in form (cell shape and size) that occurs when relatively unspecialized cells acquire specialized structural and/or functional features that characterize the cells, tissues, or organs of the mature organism or some other relatively stable phase of the organism's life history. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_MORPHOGENESIS_INVOLVED_IN_DIFFERENTIATION
Systematic name | M13312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of cell morphogenesis contributing to cell differentiation. Cell morphogenesis involved in differentiation is the change in form (cell shape and size) that occurs when relatively unspecialized cells acquire specialized structural and/or functional features that characterize the cells, tissues, or organs of the mature organism or some other relatively stable phase of the organism's life history. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDYL_THREONINE_PHOSPHORYLATION
Systematic name | M14821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of peptidyl-threonine phosphorylation. Peptidyl-threonine phosphorylation is the phosphorylation of peptidyl-threonine to form peptidyl-O-phospho-L-threonine. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PEPTIDYL_THREONINE_PHOSPHORYLATION
Systematic name | M13887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of peptidyl-threonine phosphorylation. Peptidyl-threonine phosphorylation is the phosphorylation of peptidyl-threonine to form peptidyl-O-phospho-L-threonine. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PEPTIDYL_THREONINE_PHOSPHORYLATION
Systematic name | M13269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of peptidyl-threonine phosphorylation. Peptidyl-threonine phosphorylation is the phosphorylation of peptidyl-threonine to form peptidyl-O-phospho-L-threonine. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TUMOR_NECROSIS_FACTOR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M14642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or extent of the tumor necrosis factor-mediated signaling pathway. The tumor necrosis factor-mediated signaling pathway is the series of molecular signals generated as a consequence of tumor necrosis factor binding to a cell surface receptor. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TUMOR_NECROSIS_FACTOR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M11436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate or extent of the tumor necrosis factor-mediated signaling pathway. The tumor necrosis factor-mediated signaling pathway is the series of molecular signals generated as a consequence of tumor necrosis factor binding to a cell surface receptor. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_VESICLE_PRIMING
Systematic name | M22680
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of synaptic vesicle priming. Synaptic vesicle priming is the formation of SNARE-containing complexes, bringing synaptic vesicle membrane and plasma membranes into close proximity and thereby facilitating membrane fusion. [GOC:dph, GOC:kmv, GOC:tb, PMID:15489511]
Full description |

Standard name | GO_REGULATION_OF_CELL_SUBSTRATE_ADHESION
Systematic name | M14273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell-substrate adhesion. Cell-substrate adhesion is the attachment of a cell to the underlying substrate via adhesion molecules. [GOC:dph, GOC:pf, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_SUBSTRATE_ADHESION
Systematic name | M16144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of cell-substrate adhesion. Cell-substrate adhesion is the attachment of a cell to the underlying substrate via adhesion molecules. [GOC:dph, GOC:pf, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_SUBSTRATE_ADHESION
Systematic name | M12057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of cell-substrate adhesion. Cell-substrate adhesion is the attachment of a cell to the underlying substrate via adhesion molecules. [GOC:dph, GOC:pf, GOC:tb]
Full description |

Standard name | GO_BRADYKININ_CATABOLIC_PROCESS
Systematic name | M22681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of the peptide bradykinin. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_REGULATION_OF_HORMONE_LEVELS
Systematic name | M11178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the levels of hormone within an organism or a tissue. A hormone is any substance formed in very small amounts in one specialized organ or group of cells and carried (sometimes in the bloodstream) to another organ or group of cells in the same organism, upon which it has a specific regulatory action. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_T_CELL_CHEMOTAXIS
Systematic name | M22682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a T cell in response to an external stimulus. A T cell is a type of lymphocyte whose defining characteristic is the expression of a T cell receptor complex. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_CHEMOTAXIS
Systematic name | M10473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of T cell chemotaxis. T cell chemotaxis is the directed movement of a T cell in response to an external stimulus. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRION_ORGANIZATION
Systematic name | M12250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of a mitochondrion. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOCHONDRION_ORGANIZATION
Systematic name | M12282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of a mitochondrion. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MITOCHONDRION_ORGANIZATION
Systematic name | M16819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of a mitochondrion. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CENTROSOME_DUPLICATION
Systematic name | M13533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of centrosome duplication. Centrosome duplication is the replication of a centrosome, a structure comprised of a pair of centrioles and peri-centriolar material from which a microtubule spindle apparatus is organized. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CENTROSOME_DUPLICATION
Systematic name | M22683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of centrosome duplication. Centrosome duplication is the replication of a centrosome, a structure comprised of a pair of centrioles and peri-centriolar material from which a microtubule spindle apparatus is organized. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_GLUCOSE_TRANSMEMBRANE_TRANSPORT
Systematic name | M22684
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glucose transport across a membrane. Glucose transport is the directed movement of the hexose monosaccharide glucose into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLUCOSE_TRANSMEMBRANE_TRANSPORT
Systematic name | M22685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of glucose transport across a membrane. Glucose transport is the directed movement of the hexose monosaccharide glucose into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLUCOSE_TRANSMEMBRANE_TRANSPORT
Systematic name | M22686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of glucose transport across a membrane. Glucose transport is the directed movement of the hexose monosaccharide glucose into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MYOTUBE_DIFFERENTIATION
Systematic name | M14489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of myotube differentiation. Myotube differentiation is the process in which a relatively unspecialized cell acquires specialized features of a myotube cell. Myotubes are multinucleated cells that are formed when proliferating myoblasts exit the cell cycle, differentiate and fuse. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MYOTUBE_DIFFERENTIATION
Systematic name | M10106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of myotube differentiation. Myotube differentiation is the process in which a relatively unspecialized cell acquires specialized features of a myotube cell. Myotubes are multinucleated cells that are formed when proliferating myoblasts exit the cell cycle, differentiate and fuse. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MYOTUBE_DIFFERENTIATION
Systematic name | M11295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of myotube differentiation. Myotube differentiation is the process in which a relatively unspecialized cell acquires specialized features of a myotube cell. Myotubes are multinucleated cells that are formed when proliferating myoblasts exit the cell cycle, differentiate and fuse. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_TELOMERE_MAINTENANCE_VIA_TELOMERE_LENGTHENING
Systematic name | M11252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that contributes to the maintenance of proper telomeric length and structure by affecting and monitoring the activity of telomeric proteins and lengthening the telomeric DNA. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_ADP_RIBOSYLATION
Systematic name | M22687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein ADP-ribosylation. Protein ADP-ribosylation is the transfer, from NAD, of ADP-ribose to protein amino acids. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_KERATINOCYTE_PROLIFERATION
Systematic name | M13117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of keratinocyte proliferation. Keratinocyte proliferation is the multiplication or reproduction of keratinocytes, resulting in the expansion of a cell population. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_KERATINOCYTE_PROLIFERATION
Systematic name | M22688
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of keratinocyte proliferation. Keratinocyte proliferation is the multiplication or reproduction of keratinocytes, resulting in the expansion of a cell population. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_KERATINOCYTE_PROLIFERATION
Systematic name | M16775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of keratinocyte proliferation. Keratinocyte proliferation is the multiplication or reproduction of keratinocytes, resulting in the expansion of a cell population. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_RETINA_LAYER_FORMATION
Systematic name | M14064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the vertebrate retina is organized into three laminae: the outer nuclear layer (ONL), which contains photoreceptor nuclei; the inner nuclear layer (INL), which contains amacrine, bipolar and horizontal cells; and the retinal ganglion cell (RGC) layer. Between the inner and outer nuclear layers, the outer plexiform layer (OPL) contains connections between the photoreceptors and bipolar and horizontal cells. The inner plexiform layer (IPL) is positioned between the INL and the ganglion cell layer and contains the dendrites of RGCs and processes of bipolar and amacrine cells. Spanning all layers of the retina are the radially oriented Mueller glia. [GOC:ascb_2009, GOC:dph, GOC:tb, PMID:1270266]
Full description |

Standard name | GO_REGULATION_OF_CHROMATIN_ASSEMBLY
Systematic name | M34092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process the modulates the frequency, rate or extent of chromatin assembly. Chromatin assembly is the assembly of DNA, histone proteins, and other associated proteins into chromatin structure, beginning with the formation of the basic unit, the nucleosome, followed by organization of the nucleosomes into higher order structures, ultimately giving rise to a complex organization of specific domains within the nucleus. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PATHWAY_RESTRICTED_SMAD_PROTEIN_PHOSPHORYLATION
Systematic name | M16343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of pathway-restricted SMAD protein phosphorylation. Pathway-restricted SMAD proteins and common-partner SMAD proteins are involved in the transforming growth factor beta receptor signaling pathways. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TRIGLYCERIDE_BIOSYNTHETIC_PROCESS
Systematic name | M15739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of triglyceride biosynthesis. Triglyceride biosynthesis is the collection of chemical reactions and pathways resulting in the formation of triglyceride, any triester of glycerol. [GOC:BHF, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRIGLYCERIDE_BIOSYNTHETIC_PROCESS
Systematic name | M13622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of triglyceride biosynthesis. Triglyceride biosynthesis is the collection of chemical reactions and pathways resulting in the formation of triglyceride, any triester of glycerol. [GOC:BHF, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRIGLYCERIDE_BIOSYNTHETIC_PROCESS
Systematic name | M22689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of triglyceride biosynthesis. Triglyceride biosynthesis is the collection of chemical reactions and pathways resulting in the formation of triglyceride, any triester of glycerol. [GOC:BHF, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RECEPTOR_BIOSYNTHETIC_PROCESS
Systematic name | M13184
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency or rate of receptor biosynthesis. Receptor biosynthesis is the collection of chemical reactions and pathways resulting in the formation of a receptor molecule, a macromolecule that undergoes combination with a hormone, neurotransmitter, drug or intracellular messenger to initiate a change in cell function. [GOC:BHF, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RECEPTOR_BIOSYNTHETIC_PROCESS
Systematic name | M22690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency or rate of receptor biosynthesis. Receptor biosynthesis is the collection of chemical reactions and pathways resulting in the formation of a receptor molecule, a macromolecule that undergoes combination with a hormone, neurotransmitter, drug or intracellular messenger to initiate a change in cell function. [GOC:BHF, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CHOLESTEROL_ESTERIFICATION
Systematic name | M22691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cholesterol esterification. Cholesterol esterification is the lipid modification process in which a sterol ester is formed by the combination of a carboxylic acid (often a fatty acid) and cholesterol. In the blood this process is associated with the conversion of free cholesterol into cholesteryl ester, which is then sequestered into the core of a lipoprotein particle. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHOLESTEROL_ESTERIFICATION
Systematic name | M22692
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of cholesterol esterification. Cholesterol esterification is the lipid modification process in which a sterol ester is formed by the combination of a carboxylic acid (often a fatty acid) and cholesterol. In the blood this process is associated with the conversion of free cholesterol into cholesteryl ester, which is then sequestered into the core of a lipoprotein particle. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CHOLESTEROL_EFFLUX
Systematic name | M11164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cholesterol efflux. Cholesterol efflux is the directed movement of cholesterol, cholest-5-en-3-beta-ol, out of a cell or organelle. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHOLESTEROL_EFFLUX
Systematic name | M11122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of cholesterol efflux. Cholesterol efflux is the directed movement of cholesterol, cholest-5-en-3-beta-ol, out of a cell or organelle. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_LIPID_LOCALIZATION
Systematic name | M15749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a lipid is transported to, or maintained in, a specific location. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_CHOLESTEROL_STORAGE
Systematic name | M22693
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The accumulation and maintenance in cells or tissues of cholesterol, cholest-5-en-3 beta-ol, the principal sterol of vertebrates and the precursor of many steroids, including bile acids and steroid hormones. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_CONTRACTION_BY_REGULATION_OF_THE_RELEASE_OF_SEQUESTERED_CALCIUM_ION
Systematic name | M11807
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardiac muscle contraction via the regulation of the release of sequestered calcium ion by sarcoplasmic reticulum into cytosol. The sarcoplasmic reticulum is the endoplasmic reticulum of striated muscle, specialised for the sequestration of calcium ions that are released upon receipt of a signal relayed by the T tubules from the neuromuscular junction. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_CONTRACTION_BY_CALCIUM_ION_SIGNALING
Systematic name | M12792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardiac muscle contraction by changing the calcium ion signals that trigger contraction. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_LIPID_STORAGE
Systematic name | M10255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of lipid storage. Lipid storage is the accumulation and maintenance in cells or tissues of lipids, compounds soluble in organic solvents but insoluble or sparingly soluble in aqueous solvents. Lipid reserves can be accumulated during early developmental stages for mobilization and utilization at later stages of development. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPID_STORAGE
Systematic name | M15691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of lipid storage. Lipid storage is the accumulation and maintenance in cells or tissues of lipids, compounds soluble in organic solvents but insoluble or sparingly soluble in aqueous solvents. Lipid reserves can be accumulated during early developmental stages for mobilization and utilization at later stages of development. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHOLESTEROL_STORAGE
Systematic name | M22694
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate or extent of cholesterol storage. Cholesterol storage is the accumulation and maintenance in cells or tissues of cholesterol, cholest-5-en-3 beta-ol, the principal sterol of vertebrates and the precursor of many steroids, including bile acids and steroid hormones. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHOLESTEROL_STORAGE
Systematic name | M22695
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate or extent of cholesterol storage. Cholesterol storage is the accumulation and maintenance in cells or tissues of cholesterol, cholest-5-en-3 beta-ol, the principal sterol of vertebrates and the precursor of many steroids, including bile acids and steroid hormones. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPID_STORAGE
Systematic name | M14609
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of lipid storage. Lipid storage is the accumulation and maintenance in cells or tissues of lipids, compounds soluble in organic solvents but insoluble or sparingly soluble in aqueous solvents. Lipid reserves can be accumulated during early developmental stages for mobilization and utilization at later stages of development. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SEQUESTERING_OF_TRIGLYCERIDE
Systematic name | M12066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of sequestering of triglyceride. Triglyceride sequestration is the process of binding or confining any triester of glycerol such that it is separated from other components of a biological system. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SEQUESTERING_OF_TRIGLYCERIDE
Systematic name | M22696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of sequestering of triglyceride. Triglyceride sequestration is the process of binding or confining any triester of glycerol such that it is separated from other components of a biological system. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SEQUESTERING_OF_TRIGLYCERIDE
Systematic name | M22697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of sequestering of triglyceride. Triglyceride sequestration is the process of binding or confining any triester of glycerol such that it is separated from other components of a biological system. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STEROID_BIOSYNTHETIC_PROCESS
Systematic name | M12188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of steroids, compounds with a 1,2,cyclopentanoperhydrophenanthrene nucleus. [GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TRIGLYCERIDE_CATABOLIC_PROCESS
Systematic name | M13082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of the chemical reactions and pathways resulting in the breakdown of triglyceride. [GOC:rn, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRIGLYCERIDE_CATABOLIC_PROCESS
Systematic name | M29098
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate, or extent of the chemical reactions and pathways resulting in the breakdown of triglyceride. [GOC:rn, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRIGLYCERIDE_CATABOLIC_PROCESS
Systematic name | M22698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate, or extent of the chemical reactions and pathways resulting in the breakdown of triglyceride. [GOC:rn, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_VERY_LOW_DENSITY_LIPOPROTEIN_PARTICLE_REMODELING
Systematic name | M22699
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of very-low-density lipoprotein particle remodeling. Very-low-density lipoprotein particle remodeling is the acquisition, loss or modification of a protein or lipid within a very-low-density lipoprotein particle, including the hydrolysis of triglyceride by hepatic lipase or lipoprotein lipase and the subsequent loss of free fatty acid. [GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_GLUCOSE_METABOLIC_PROCESS
Systematic name | M13722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of glucose metabolism. Glucose metabolic processes are the chemical reactions and pathways involving glucose, the aldohexose gluco-hexose. [GOC:BHF, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLUCOSE_METABOLIC_PROCESS
Systematic name | M16946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of glucose metabolism. Glucose metabolic processes are the chemical reactions and pathways involving glucose, the aldohexose gluco-hexose. [GOC:BHF, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_ISOMERASE_ACTIVITY
Systematic name | M22700
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the activity of an isomerase. An isomerase catalyzes the geometric or structural changes within one molecule. Isomerase is the systematic name for any enzyme of EC class 5. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_VERY_LOW_DENSITY_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M22701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of very-low-density lipoprotein particle clearance. Very-low-density lipoprotein particle clearance is the process in which a very-low-density lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOCHONDRIAL_MEMBRANE_POTENTIAL
Systematic name | M22702
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of establishment or extent of a mitochondrial membrane potential, the electric potential existing across any mitochondrial membrane arising from charges in the membrane itself and from the charges present in the media on either side of the membrane. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_INOSITOL_PHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M13682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of inositol phosphate biosynthesis. Inositol phosphate biosynthetic processes are the chemical reactions and pathways resulting in the formation of an inositol phosphate, 1,2,3,4,5,6-cyclohexanehexol, with one or more phosphate groups attached. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHATASE_ACTIVITY
Systematic name | M10601
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or frequency of phosphatase activity. Phosphatases catalyze the hydrolysis of phosphoric monoesters, releasing inorganic phosphate. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHOSPHATASE_ACTIVITY
Systematic name | M16598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate or frequency of phosphatase activity. Phosphatases catalyze the hydrolysis of phosphoric monoesters, releasing inorganic phosphate. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_CELLULAR_COMPONENT_ASSEMBLY_INVOLVED_IN_MORPHOGENESIS
Systematic name | M12564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular component assembly that is part of the initial shaping of the component during its developmental progression. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_MACROPHAGE_CYTOKINE_PRODUCTION
Systematic name | M22703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of a macrophage cytokine due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:BHF, GOC:dph, GOC:rl, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MACROPHAGE_CYTOKINE_PRODUCTION
Systematic name | M22704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of macrophage cytokine production. Macrophage cytokine production is the appearance of a chemokine due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_REGULATION_OF_NECROTIC_CELL_DEATH
Systematic name | M13153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of necrotic cell death. Necrotic cell death is a cell death process that is morphologically characterized by a gain in cell volume (oncosis), swelling of organelles, plasma membrane rupture and subsequent loss of intracellular contents. [PMID:16507998]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NECROTIC_CELL_DEATH
Systematic name | M22705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of necrotic cell death. Necrotic cell death is a cell death process that is morphologically characterized by a gain in cell volume (oncosis), swelling of organelles, plasma membrane rupture and subsequent loss of intracellular contents. [PMID:16507998]
Full description |

Standard name | GO_REGULATION_OF_CELL_DEATH
Systematic name | M14917
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or frequency of cell death. Cell death is the specific activation or halting of processes within a cell so that its vital functions markedly cease, rather than simply deteriorating gradually over time, which culminates in cell death. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_DEATH
Systematic name | M13833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate or frequency of cell death. Cell death is the specific activation or halting of processes within a cell so that its vital functions markedly cease, rather than simply deteriorating gradually over time, which culminates in cell death. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSCRIPTION_BY_COMPETITIVE_PROMOTER_BINDING
Systematic name | M22706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of DNA-dependent transcription using a mechanism that involves direct competition for interaction with a promoter binding site. [GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_CYCLE_PROCESS
Systematic name | M12573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of a cellular process that is involved in the progression of biochemical and morphological phases and events that occur in a cell during successive cell replication or nuclear replication events. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PEPTIDASE_ACTIVITY
Systematic name | M13564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of peptidase activity, the hydrolysis of peptide bonds within proteins. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VITAMIN_D_BIOSYNTHETIC_PROCESS
Systematic name | M22707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of a vitamin D biosynthetic process. Vitamin D biosynthesis is the chemical reactions and pathways resulting in the formation of vitamin D, any of a group of related, fat-soluble compounds that are derived from delta-5,7 steroids and play a central role in calcium metabolism. Specific forms of vitamin D include calciferol (ergocalciferol; vitamin D2) and cholecalciferol (calciol; vitamin D3). [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_AMINO_ACID_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M34093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of amino acid import into a cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_METAL_ION_TRANSPORT
Systematic name | M12976
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of metal ion transport. Metal ion transport is the directed movement of metal ions, any metal ion with an electric charge, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_MAGNESIUM_ION_HOMEOSTASIS
Systematic name | M22709
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of magnesium ions within an organism or cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CELLULAR_MAGNESIUM_ION_HOMEOSTASIS
Systematic name | M22710
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of magnesium ions at the level of a cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_GLUCAN_BIOSYNTHETIC_PROCESS
Systematic name | M29099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of glucan biosynthesis. Glucan biosynthetic processes are the chemical reactions and pathways resulting in the formation of glucans, polysaccharides consisting only of glucose residues. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHATE_TRANSPORT
Systematic name | M22711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of phosphate transport. Phosphate transport is the directed movement of phosphate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MICROTUBULE_NUCLEATION
Systematic name | M22712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of microtubule nucleation. Microtubule nucleation is the 'de novo' formation of a microtubule, in which tubulin heterodimers form metastable oligomeric aggregates, some of which go on to support formation of a complete microtubule. Microtubule nucleation usually occurs from a specific site within a cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_TRANSPORT_ALONG_MICROTUBULE
Systematic name | M34094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of organelles or other particles from one location in the cell to another along microtubules, driven by motor activity. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_NEURON_PROJECTION_DEVELOPMENT
Systematic name | M14533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of neuron projection development. Neuron projection development is the process whose specific outcome is the progression of a neuron projection over time, from its formation to the mature structure. A neuron projection is any process extending from a neural cell, such as axons or dendrites (collectively called neurites). [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEURON_PROJECTION_DEVELOPMENT
Systematic name | M16634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of neuron projection development. Neuron projection development is the process whose specific outcome is the progression of a neuron projection over time, from its formation to the mature structure. A neuron projection is any process extending from a neural cell, such as axons or dendrites (collectively called neurites). [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEURON_PROJECTION_DEVELOPMENT
Systematic name | M22713
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of neuron projection development. Neuron projection development is the process whose specific outcome is the progression of a neuron projection over time, from its formation to the mature structure. A neuron projection is any process extending from a neural cell, such as axons or dendrites (collectively called neurites). [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_HIGH_DENSITY_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M22714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of high-density lipoprotein particle clearance. High-density lipoprotein particle clearance is the process in which a high-density lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M15875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of lipoprotein particle clearance. Lipoprotein particle clearance is the process in which a lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M22715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of lipoprotein particle clearance. Lipoprotein particle clearance is the process in which a lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M22716
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of lipoprotein particle clearance. Lipoprotein particle clearance is the process in which a lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_LOW_DENSITY_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M22717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of low-density lipoprotein particle clearance. Low-density lipoprotein particle clearance is the process in which a low-density lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LOW_DENSITY_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M22718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of low-density lipoprotein particle clearance. Low-density lipoprotein particle clearance is the process in which a low-density lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SMAD_PROTEIN_COMPLEX_ASSEMBLY
Systematic name | M22719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of SMAD protein complex assembly. SMAD protein complex assembly is the aggregation, arrangement and bonding together of a set of components to form a protein complex that contains SMAD proteins. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMAD_PROTEIN_COMPLEX_ASSEMBLY
Systematic name | M22720
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of SMAD protein complex assembly. SMAD protein complex assembly is the aggregation, arrangement and bonding together of a set of components to form a protein complex that contains SMAD proteins. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_UBIQUITIN_RECYCLING
Systematic name | M22721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of ubiquitin monomers and free ubiquitin chains at the level of the cell by recycling ubiquitin from proteasome-bound ubiquitinated intermediates. [GOC:BHF, GOC:dph, GOC:PG, GOC:tb, PMID:19410548]
Full description |

Standard name | GO_FREE_UBIQUITIN_CHAIN_POLYMERIZATION
Systematic name | M22722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of creating free ubiquitin chains, compounds composed of a large number of ubiquitin monomers. These chains are not conjugated to a protein. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_RESPONSE_TO_AUDITORY_STIMULUS
Systematic name | M13797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an auditory stimulus. [GOC:BHF, GOC:dph, GOC:sl, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TRANSLATIONAL_INITIATION_BY_EIF2_ALPHA_PHOSPHORYLATION
Systematic name | M22723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of translation initiation in response to stress by the phosphorylation of eIF2 alpha. [GOC:BHF, GOC:dph, GOC:hjd, GOC:tb]
Full description |

Standard name | GO_ASTROCYTE_DEVELOPMENT
Systematic name | M16698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process aimed at the progression of an astrocyte over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. An astrocyte is the most abundant type of glial cell. Astrocytes provide support for neurons and regulate the environment in which they function. [GOC:dgh, GOC:ef]
Full description |

Standard name | GO_OLIGODENDROCYTE_DEVELOPMENT
Systematic name | M15263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process aimed at the progression of an oligodendrocyte over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. An oligodendrocyte is a type of glial cell involved in myelinating the axons in the central nervous system. [GOC:dgh, GOC:ef]
Full description |

Standard name | GO_MICROGLIA_DIFFERENTIATION
Systematic name | M22724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a microglial cell. Microglia are glial cells that act as the immune cells of the central nervous system. They form part of the supporting structure of this system. [GOC:ef]
Full description |

Standard name | GO_GLIAL_CELL_PROLIFERATION
Systematic name | M22725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of glial cells by cell division, resulting in the expansion of their population. Glial cells exist throughout the nervous system, and include Schwann cells, astrocytes, and oligodendrocytes among others. [GOC:ef, ISBN:0878932585]
Full description |

Standard name | GO_SCHWANN_CELL_PROLIFERATION
Systematic name | M22726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of Schwann cells, resulting in the expansion of their population. Schwann cells are a type of glial cell in the peripheral nervous system. [GOC:ef, ISBN:0878932585]
Full description |

Standard name | GO_PERIPHERAL_NERVOUS_SYSTEM_AXON_REGENERATION
Systematic name | M22727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regrowth of axons outside the central nervous system (outside the brain and spinal cord) following an axonal injury. [GOC:ef]
Full description |

Standard name | GO_REGULATION_OF_GLIOGENESIS
Systematic name | M16014
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gliogenesis, the formation of mature glia. [GOC:ef]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLIOGENESIS
Systematic name | M10717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of gliogenesis, the formation of mature glia. [GOC:ef]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLIOGENESIS
Systematic name | M16883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of gliogenesis, the formation of mature glia. [GOC:ef]
Full description |

Standard name | GO_NEUROBLAST_DIFFERENTIATION
Systematic name | M34095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a neuroblast. There are at least four stages through which the pluripotent cells of epiblast or blastula become neuroblasts. [GOC:ef, ISBN:0878932585]
Full description |

Standard name | GO_NEURAL_CREST_FORMATION
Systematic name | M22728
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of the specialized region of ectoderm between the neural ectoderm (neural plate) and non-neural ectoderm. The neural crest gives rise to the neural crest cells that migrate away from this region as neural tube formation procedes. [GOC:dh, GOC:ef]
Full description |

Standard name | GO_NEURAL_CREST_CELL_DIFFERENTIATION
Systematic name | M16602
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a neural crest cell. [GOC:dh, GOC:ef]
Full description |

Standard name | GO_SCHWANN_CELL_DIFFERENTIATION
Systematic name | M15313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a Schwann cell. Schwann cells are found in the peripheral nervous system, where they insulate neurons and axons, and regulate the environment in which neurons function. [GOC:ef]
Full description |

Standard name | GO_REGULATION_OF_NEURON_MATURATION
Systematic name | M22729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neuron maturation, the process leading to the attainment of the full functional capacity of a neuron. This process is independent of morphogenetic change. [GOC:ef]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEURON_MATURATION
Systematic name | M22730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of neuron maturation. [GOC:ef]
Full description |

Standard name | GO_SCHWANN_CELL_DEVELOPMENT
Systematic name | M15027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process aimed at the progression of a Schwann cell over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. Schwann cells are found in the peripheral nervous system, where they insulate neurons and axons, and regulate the environment in which neurons function. [GOC:dgh, GOC:ef]
Full description |

Standard name | GO_ESTABLISHMENT_OF_ENDOTHELIAL_BLOOD_BRAIN_BARRIER
Systematic name | M29100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Establishment of the endothelial barrier between the blood and the brain. The endothelial cells in the brain capillaries are packed tightly together preventing the passage of most molecules from the blood into the brain. Only lipid soluble molecules or those that are actively transported can pass through the blood-brain barrier. [GOC:aruk, GOC:dgh, GOC:dph, GOC:sart, PMID:20080302, PMID:30280653]
Full description |

Standard name | GO_GLUTAMATE_SECRETION
Systematic name | M10238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled release of glutamate by a cell. The glutamate is the most abundant excitatory neurotransmitter in the nervous system. [GOC:ef]
Full description |

Standard name | GO_REGULATION_OF_GLUTAMATE_SECRETION
Systematic name | M14978
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the controlled release of glutamate. [GOC:ef]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLUTAMATE_SECRETION
Systematic name | M22732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the controlled release of glutamate. [GOC:ef]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLUTAMATE_SECRETION
Systematic name | M22733
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the controlled release of glutamate. [GOC:ef]
Full description |

Standard name | GO_GAMMA_AMINOBUTYRIC_ACID_SECRETION
Systematic name | M22734
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of gamma-aminobutyric acid by a cell or a tissue. The gamma-aminobutyric acid is the principal inhibitory neurotransmitter in the brain but is also found in several extraneural tissues. [GOC:ef]
Full description |

Standard name | GO_REGULATION_OF_GAMMA_AMINOBUTYRIC_ACID_SECRETION
Systematic name | M22735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of gamma-aminobutyric acid. [GOC:ef]
Full description |

Standard name | GO_REGULATION_OF_DOPAMINE_SECRETION
Systematic name | M29101
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of dopamine. [GOC:ef]
Full description |

Standard name | GO_REGULATION_OF_EPINEPHRINE_SECRETION
Systematic name | M34096
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of epinephrine. [GOC:ef]
Full description |

Standard name | GO_REGULATION_OF_SEROTONIN_SECRETION
Systematic name | M22736
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of serotonin. [GOC:ef]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SEROTONIN_SECRETION
Systematic name | M34097
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the regulated release of serotonin. [GOC:ef]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_KINASE_SIGNALING
Systematic name | M16656
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of reactions within the signal-receiving cell, mediated by the intracellular phosphatidylinositol 3-kinase (PI3K). Many cell surface receptor linked signaling pathways signal through PI3K to regulate numerous cellular functions. [GOC:ef, http://www.biocarta.com, PMID:22525052, Wikipedia:PI3K]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHATIDYLINOSITOL_3_KINASE_SIGNALING
Systematic name | M10525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of signal transduction mediated by the phosphatidylinositol 3-kinase cascade. [GOC:ef]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PHOSPHATIDYLINOSITOL_3_KINASE_SIGNALING
Systematic name | M22737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of signal transduction mediated by the phosphatidylinositol 3-kinase cascade. [GOC:ef]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHOSPHATIDYLINOSITOL_3_KINASE_SIGNALING
Systematic name | M16273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signal transduction mediated by the phosphatidylinositol 3-kinase cascade. [GOC:ef]
Full description |

Standard name | GO_RESPONSE_TO_ORGANIC_CYCLIC_COMPOUND
Systematic name | M13300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic cyclic compound stimulus. [GOC:ef]
Full description |

Standard name | GO_RESPONSE_TO_ISOQUINOLINE_ALKALOID
Systematic name | M34098
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an isoquinoline alkaloid stimulus. An isoquinoline alkaloid is any member of a group of compounds with the heterocyclic ring structure of benzo(c)pyridine which is a structure characteristic of the group of opium alkaloids. [GOC:ef]
Full description |

Standard name | GO_RESPONSE_TO_PURINE_CONTAINING_COMPOUND
Systematic name | M16537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a purine-containing compound stimulus. [GOC:ef]
Full description |

Standard name | GO_RESPONSE_TO_AMINE
Systematic name | M10567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an amine stimulus. An amine is a compound formally derived from ammonia by replacing one, two or three hydrogen atoms by hydrocarbyl groups. [GOC:ef]
Full description |

Standard name | GO_SKELETAL_MUSCLE_SATELLITE_CELL_ACTIVATION
Systematic name | M22738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change of a skeletal muscle satellite cell from a mitotically quiescent to a mitotically active state following exposure to some activating factor such as a cellular or soluble ligand. In adult muscle, satellite cells become activated to divide and differentiate in response to muscle damage. [GOC:mtg_muscle, PMID:23303905]
Full description |

Standard name | GO_REGULATION_OF_SKELETAL_MUSCLE_CONTRACTION_BY_CALCIUM_ION_SIGNALING
Systematic name | M22739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of skeletal muscle contraction by changing the calcium ion signals that trigger contraction. [GOC:mtg_muscle]
Full description |

Standard name | GO_REGULATION_OF_SKELETAL_MUSCLE_ADAPTATION
Systematic name | M14115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which skeletal muscle adapts, with consequent modifications to structural and/or functional phenotypes, in response to a stimulus. Stimuli include contractile activity, loading conditions, substrate supply, and environmental factors. These adaptive events occur in both muscle fibers and associated structures (motoneurons and capillaries), and they involve alterations in regulatory mechanisms, contractile properties and metabolic capacities. [GOC:mtg_muscle]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MUSCLE_HYPERTROPHY
Systematic name | M15459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of muscle hypertrophy. [GOC:mtg_muscle]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MUSCLE_HYPERTROPHY
Systematic name | M13031
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of muscle hypertrophy. [GOC:mtg_muscle]
Full description |

Standard name | GO_REGULATION_OF_MUSCLE_HYPERTROPHY
Systematic name | M13588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of muscle hypertrophy. [GOC:mtg_muscle]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MUSCLE_ADAPTATION
Systematic name | M22740
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of muscle adaptation. [GOC:mtg_muscle]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MUSCLE_ADAPTATION
Systematic name | M22741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of muscle adaptation. [GOC:mtg_muscle]
Full description |

Standard name | GO_SMOOTH_MUSCLE_ADAPTATION
Systematic name | M22742
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which smooth muscle adapts, with consequent modifications to structural and/or functional phenotypes, in response to a stimulus. Stimuli include contractile activity, loading conditions, substrate supply, and environmental factors. These adaptive events occur in both muscle fibers and associated structures (motoneurons and capillaries), and they involve alterations in regulatory mechanisms, contractile properties and metabolic capacities. [GOC:mtg_muscle]
Full description |

Standard name | GO_REGULATION_OF_SOMITOGENESIS
Systematic name | M22743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of somitogenesis. [GOC:mtg_muscle]
Full description |

Standard name | GO_MUSCLE_CELL_MIGRATION
Systematic name | M16216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a muscle cell from one site to another, often during the development of a multicellular organism. [CL:0000187, GOC:mtg_muscle]
Full description |

Standard name | GO_SKELETAL_MUSCLE_SATELLITE_CELL_DIFFERENTIATION
Systematic name | M22745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a satellite cell. [GOC:ef, GOC:mtg_muscle, PMID:16607119]
Full description |

Standard name | GO_REGULATION_OF_SKELETAL_MUSCLE_CONTRACTION
Systematic name | M15469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of skeletal muscle contraction. [GOC:ef, GOC:mtg_muscle]
Full description |

Standard name | GO_TONIC_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M22746
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within tonic smooth muscle tissue, resulting in a change in muscle geometry. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. In the tonic smooth muscle, the muscle contraction occurs without an ordered sarcomeric structure. Tonic smooth muscle contraction occurs as a sustained continuous contraction. [GOC:mtg_muscle]
Full description |

Standard name | GO_PHASIC_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M12983
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within phasic smooth muscle tissue, resulting in a change in muscle geometry. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. In the phasic smooth muscle, the muscle contraction occurs without an ordered sarcomeric structure. Phasic smooth muscle contraction occurs in a series of discrete contractions and relaxations. [GOC:mtg_muscle]
Full description |

Standard name | GO_RESPONSE_TO_ACTIVITY
Systematic name | M16849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an activity stimulus. [GOC:mtg_muscle]
Full description |

Standard name | GO_ARTERY_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M22747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within smooth muscle tissue, resulting in a change in muscle geometry. This process occurs in the artery. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. The artery is a vessel carrying blood away from the heart. [GOC:mtg_muscle, MA:0000708, MSH:D001158]
Full description |

Standard name | GO_INTESTINE_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M22748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within smooth muscle tissue, resulting in a change in muscle geometry. This process occurs in the intestine. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. The intestine is the section of the alimentary canal from the stomach to the anal canal. It includes the large intestine and small intestine. [GOC:mtg_muscle, MA:0001539, MSH:D007422]
Full description |

Standard name | GO_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M13177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process, occurring in the vascular tissue, whereby actin/myosin complex activity generates force through ATP hydrolysis resulting in a change in smooth muscle geometry. This process is always coupled to chemo-mechanical energy conversion. [GOC:mtg_muscle, MA:0002718]
Full description |

Standard name | GO_GASTRO_INTESTINAL_SYSTEM_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M22749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within smooth muscle tissue, resulting in a change in muscle geometry. This process occurs in the gastro-intestinal system. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. The gastro-intestinal system generally refers to the digestive structures stretching from the mouth to anus, but does not include the accessory glandular organs (liver, pancreas and biliary tract). [GOC:mtg_muscle, MA:0001523, MSH:D041981]
Full description |

Standard name | GO_URINARY_TRACT_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M22750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within smooth muscle tissue, resulting in a change in muscle geometry. This process occurs in the urinary tract. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. The urinary tract consists of organs of the body that produce and discharge urine. These include the kidneys, ureters, bladder, and urethra. [GOC:ef, GOC:mtg_muscle, MA:0000325, MSH:D014551]
Full description |

Standard name | GO_RESPONSE_TO_MUSCLE_ACTIVITY
Systematic name | M14486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a muscle activity stimulus. [GOC:mtg_muscle]
Full description |

Standard name | GO_RESPONSE_TO_INACTIVITY
Systematic name | M12689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an inactivity stimulus. [GOC:mtg_muscle]
Full description |

Standard name | GO_STRIATED_MUSCLE_CELL_PROLIFERATION
Systematic name | M14840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of striated muscle cells, resulting in the expansion of a cell population. Striated muscles contain fibers that are divided by transverse bands into striations, and cardiac and skeletal muscle are types of striated muscle. [CL:0000737, GOC:ef, GOC:mtg_muscle]
Full description |

Standard name | GO_SKELETAL_MUSCLE_CELL_PROLIFERATION
Systematic name | M22751
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of skeletal muscle cells, resulting in the expansion of a cell population. [CL:0000188, GOC:ef, GOC:mtg_muscle]
Full description |

Standard name | GO_SKELETAL_MYOFIBRIL_ASSEMBLY
Systematic name | M22752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the skeletal myofibril over time, from its formation to the mature structure. A skeletal myofibril is a myofibril specific to skeletal muscle cells. [GOC:ef, GOC:mtg_muscle]
Full description |

Standard name | GO_RESPONSE_TO_MUSCLE_INACTIVITY
Systematic name | M22753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a muscle inactivity stimulus. [GOC:mtg_muscle]
Full description |

Standard name | GO_RESPONSE_TO_STIMULUS_INVOLVED_IN_REGULATION_OF_MUSCLE_ADAPTATION
Systematic name | M14388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus. This occurs as part of the regulation of muscle adaptation. [GOC:ef, GOC:mtg_muscle]
Full description |

Standard name | GO_TRANSITION_BETWEEN_FAST_AND_SLOW_FIBER
Systematic name | M22754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of conversion of fast-contracting muscle fibers to a slower character. This may involve slowing of contractile rate, slow myosin gene induction, increase in oxidative metabolic properties, altered electrophysiology and altered innervation. This process also regulates skeletal muscle adapatation. [GOC:ef, GOC:mtg_muscle]
Full description |

Standard name | GO_STRIATED_MUSCLE_ADAPTATION
Systematic name | M16049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which striated muscle adapts, with consequent modifications to structural and/or functional phenotypes, in response to a stimulus. Stimuli include contractile activity, loading conditions, substrate supply, and environmental factors. These adaptive events occur in both muscle fibers and associated structures (motoneurons and capillaries), and they involve alterations in regulatory mechanisms, contractile properties and metabolic capacities. [GOC:mtg_muscle]
Full description |

Standard name | GO_MUSCLE_ATROPHY
Systematic name | M13975
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process, occurring in the muscle, that is characterized by a decrease in protein content, fiber diameter, force production and fatigue resistance in response to different conditions such as starvation, aging and disuse. [GOC:mtg_muscle]
Full description |

Standard name | GO_STRIATED_MUSCLE_ATROPHY
Systematic name | M22755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process, occurring in striated muscle, that is characterized by a decrease in protein content, fiber diameter, force production and fatigue resistance in response to different conditions such as starvation, aging and disuse. [GOC:mtg_muscle]
Full description |

Standard name | GO_MUSCLE_HYPERTROPHY
Systematic name | M14748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The muscle system process that results in enlargement or overgrowth of all or part of a muscle organ due to an increase in the size of its muscle cells. Physiological hypertrophy is a normal process during development (it stops in cardiac muscle after adolescence) and can also be brought on in response to demand. In athletes cardiac and skeletal muscles undergo hypertrophy stimulated by increasing muscle activity on exercise. Smooth muscle cells in the uterus undergo hypertrophy during pregnancy. [GOC:mtg_muscle]
Full description |

Standard name | GO_MUSCLE_HYPERPLASIA
Systematic name | M22756
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A muscle system process that results in an increase in cell number by cell division, often leading to an increase in the size of an organ. [GOC:mtg_muscle]
Full description |

Standard name | GO_MYOTUBE_DIFFERENTIATION
Systematic name | M14770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a myotube cell. Myotube differentiation starts with myoblast fusion and the appearance of specific cell markers (this is the cell development step). Then individual myotubes can fuse to form bigger myotubes and start to contract. Myotubes are multinucleated cells that are formed when proliferating myoblasts exit the cell cycle, differentiate and fuse. [GOC:mtg_muscle]
Full description |

Standard name | GO_MYOTUBE_CELL_DEVELOPMENT
Systematic name | M15444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process aimed at the progression of a myotube cell over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. Myotubes are multinucleated cells that are formed when proliferating myoblasts exit the cell cycle, differentiate and fuse. [GOC:mtg_muscle]
Full description |

Standard name | GO_MYOBLAST_FUSION_INVOLVED_IN_SKELETAL_MUSCLE_REGENERATION
Systematic name | M29104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which non-proliferating myoblasts, after migrating to the site of injury, fuse into existing damaged fibers or fuse to myotubes to form new fibers, as part of the process of skeletal muscle regeneration. A myoblast is a mononucleate cell type that, by fusion with other myoblasts, gives rise to the myotubes that eventually develop into skeletal muscle fibers. [CL:0000056, GOC:mtg_muscle]
Full description |

Standard name | GO_MYOTUBE_DIFFERENTIATION_INVOLVED_IN_SKELETAL_MUSCLE_REGENERATION
Systematic name | M29105
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a myotube cell. Myotube differentiation starts with myoblast fusion and the appearance of specific cell markers (this is the cell development step). Then individual myotubes can fuse to form bigger myotubes and start to contract. This process occurs as part of the process of skeletal muscle regeneration. Myotubes are multinucleated cells that are formed when proliferating myoblasts exit the cell cycle, differentiate and fuse. [GOC:mtg_muscle]
Full description |

Standard name | GO_SMOOTH_MUSCLE_CELL_MIGRATION
Systematic name | M22757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a smooth muscle cell from one site to another, often during the development of a multicellular organism. [CL:0000192, GOC:mtg_muscle]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SMOOTH_MUSCLE_CELL_MIGRATION
Systematic name | M14175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of smooth muscle cell migration. [CL:0000192, GOC:mtg_muscle]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMOOTH_MUSCLE_CELL_MIGRATION
Systematic name | M12483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of smooth muscle cell migration. [CL:0000192, GOC:mtg_muscle]
Full description |

Standard name | GO_REGULATION_OF_LUNG_BLOOD_PRESSURE
Systematic name | M22758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that modulates the force with which blood travels through the lungs. The process is controlled by a balance of processes that increase pressure and decrease pressure. [GOC:mtg_cardio]
Full description |

Standard name | GO_HEPARAN_SULFATE_PROTEOGLYCAN_BIOSYNTHETIC_PROCESS
Systematic name | M29106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of the heparan sulfate proteoglycan, a glycosaminoglycan with repeat unit consisting of alternating alpha-(1->4)-linked hexuronic acid and glucosamine residues; the former are a mixture of sulfated and nonsulfated D-glucuronic acid and L-iduronic acid; the L-iduronic acid is either sulfated or acetylated on its amino group as well as being sulfated on one of its hydroxyl groups; heparan sulfate chains are covalently linked to peptidyl-serine by a glycosidic attachment through the trisaccharide galactosyl-galactosyl-xylosyl to serine residues. [GOC:mah, ISBN:0198506732, ISBN:0198547684, RESID:AA0210]
Full description |

Standard name | GO_HEPARAN_SULFATE_PROTEOGLYCAN_BIOSYNTHETIC_PROCESS_POLYSACCHARIDE_CHAIN_BIOSYNTHETIC_PROCESS
Systematic name | M22759
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of polysaccharide chain component of heparan sulfate proteoglycan. [GOC:ai]
Full description |

Standard name | GO_HEPARAN_SULFATE_PROTEOGLYCAN_BIOSYNTHETIC_PROCESS_ENZYMATIC_MODIFICATION
Systematic name | M22760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification, often by sulfation, of sugars incorporated into heparan sulfate after polymerization. [ISBN:0815316194]
Full description |

Standard name | GO_DNA_INTEGRATION
Systematic name | M11414
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a segment of DNA is incorporated into another, usually larger, DNA molecule such as a chromosome. [GOC:mah]
Full description |

Standard name | GO_GAS_TRANSPORT
Systematic name | M13119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances that are gaseous in normal living conditions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_CARBON_DIOXIDE_TRANSPORT
Systematic name | M34099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of carbon dioxide (CO2) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_OXYGEN_TRANSPORT
Systematic name | M13619
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of oxygen (O2) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_MONOVALENT_INORGANIC_CATION_TRANSPORT
Systematic name | M11388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of inorganic cations with a valency of one into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Inorganic cations are atoms or small molecules with a positive charge which do not contain carbon in covalent linkage. [GOC:ai]
Full description |

Standard name | GO_COPPER_ION_IMPORT
Systematic name | M22761
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of copper ions into a cell or organelle. [GOC:ai]
Full description |

Standard name | GO_MAGNESIUM_ION_TRANSPORT
Systematic name | M11541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of magnesium (Mg) ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_ORGANIC_CATION_TRANSPORT
Systematic name | M14902
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of organic cations into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Organic cations are atoms or small molecules with a positive charge which contain carbon in covalent linkage. [GOC:ai]
Full description |

Standard name | GO_AMMONIUM_TRANSPORT
Systematic name | M14506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of ammonium into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Ammonium is the cation NH4+ which is formed from N2 by root-nodule bacteria in leguminous plants and is an excretory product in ammonotelic animals. [ISBN:0198506732]
Full description |

Standard name | GO_QUATERNARY_AMMONIUM_GROUP_TRANSPORT
Systematic name | M12893
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore of quaternary ammonium compounds, any compound that can be regarded as derived from ammonium hydroxide or an ammonium salt by replacement of all four hydrogen atoms of the NH4+ ion by organic groups. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_INORGANIC_ANION_TRANSPORT
Systematic name | M11296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of inorganic anions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Inorganic anions are atoms or small molecules with a negative charge which do not contain carbon in covalent linkage. [GOC:krc]
Full description |

Standard name | GO_BICARBONATE_TRANSPORT
Systematic name | M13560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of bicarbonate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_IODIDE_TRANSPORT
Systematic name | M22762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of iodide into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_ORGANIC_ANION_TRANSPORT
Systematic name | M13556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of organic anions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Organic anions are atoms or small molecules with a negative charge which contain carbon in covalent linkage. [GOC:ai, GOC:krc]
Full description |

Standard name | GO_HEXOSE_PHOSPHATE_TRANSPORT
Systematic name | M22763
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of hexose phosphate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_MONOCARBOXYLIC_ACID_TRANSPORT
Systematic name | M14456
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of monocarboxylic acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_BILE_ACID_AND_BILE_SALT_TRANSPORT
Systematic name | M13647
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of bile acid and bile salts into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:dph, GOC:krc, PMID:12663868, PMID:14699511]
Full description |

Standard name | GO_PROSTAGLANDIN_TRANSPORT
Systematic name | M22765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of prostaglandins into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_TAURINE_TRANSPORT
Systematic name | M29107
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of taurine into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_SIALIC_ACID_TRANSPORT
Systematic name | M34100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of sialic acid into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_C4_DICARBOXYLATE_TRANSPORT
Systematic name | M22767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a C4-dicarboxylate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. A C4-dicarboxylate is the anion of a dicarboxylic acid that contains four carbon atoms. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_URATE_TRANSPORT
Systematic name | M22770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of urate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc]
Full description |

Standard name | GO_ORGANOPHOSPHATE_ESTER_TRANSPORT
Systematic name | M12017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of organophosphate esters into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Organophosphate esters are small organic molecules containing phosphate ester bonds. [GOC:mcc]
Full description |

Standard name | GO_FRUCTOSE_TRANSMEMBRANE_TRANSPORT
Systematic name | M29108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of fructose into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Fructose exists in a open chain form or as a ring compound. D-fructose is the sweetest of the sugars and is found free in a large number of fruits and honey. [GOC:ai]
Full description |

Standard name | GO_NUCLEOTIDE_SUGAR_TRANSMEMBRANE_TRANSPORT
Systematic name | M22771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of nucleotide-sugars into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Nucleotide-sugars are any nucleotide in which the distal phosphoric residue of a nucleoside 5'-diphosphate is in glycosidic linkage with a monosaccharide or monosaccharide derivative. [ISBN:0198506732]
Full description |

Standard name | GO_POLYOL_TRANSPORT
Systematic name | M12791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of polyols, any polyhydric alcohol, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_GLYCEROL_TRANSPORT
Systematic name | M22772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of glycerol into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Glycerol is 1,2,3-propanetriol, a sweet, hygroscopic, viscous liquid, widely distributed in nature as a constituent of many lipids. [GOC:ai]
Full description |

Standard name | GO_MYO_INOSITOL_TRANSPORT
Systematic name | M34101
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of myo-inositol into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Myo-inositol is 1,2,3,4,5/4,6-cyclohexanehexol, a growth factor for animals and microorganisms. [GOC:ai]
Full description |

Standard name | GO_ACIDIC_AMINO_ACID_TRANSPORT
Systematic name | M14313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of acidic amino acids, amino acids with a pH below 7, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_AROMATIC_AMINO_ACID_TRANSPORT
Systematic name | M22773
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of aromatic amino acids, amino acids with aromatic ring, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_BASIC_AMINO_ACID_TRANSPORT
Systematic name | M13466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of basic amino acids, amino acids with a pH above 7, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_BRANCHED_CHAIN_AMINO_ACID_TRANSPORT
Systematic name | M22774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of branched-chain amino acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Branched-chain amino acids are amino acids with a branched carbon skeleton without rings. [GOC:ai, GOC:bf]
Full description |

Standard name | GO_NEUTRAL_AMINO_ACID_TRANSPORT
Systematic name | M15992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of neutral amino acids, amino acids with no net charge, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_L_AMINO_ACID_TRANSPORT
Systematic name | M11158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-enantiomer amino acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai, GOC:jsg, GOC:mah]
Full description |

Standard name | GO_L_ALANINE_TRANSPORT
Systematic name | M22775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-alanine, the L-enantiomer of 2-aminopropanoic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai, GOC:jsg, GOC:mah]
Full description |

Standard name | GO_ARGININE_TRANSPORT
Systematic name | M22776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of arginine, 2-amino-5-guanidinopentanoic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_ASPARTATE_TRANSMEMBRANE_TRANSPORT
Systematic name | M22777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which aspartate is transported across a lipid bilayer, from one side of a membrane to the other. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_GAMMA_AMINOBUTYRIC_ACID_TRANSPORT
Systematic name | M22778
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of gamma-aminobutyric acid (GABA, 4-aminobutyrate), an amino acid which acts as a neurotransmitter in some organisms, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_L_GLUTAMATE_TRANSMEMBRANE_TRANSPORT
Systematic name | M22779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-glutamate across a membrane. [PMID:21307582]
Full description |

Standard name | GO_GLYCINE_TRANSPORT
Systematic name | M22780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of glycine, aminoethanoic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_LEUCINE_TRANSPORT
Systematic name | M34102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of leucine, 2-amino-4-methylpentanoic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_ORNITHINE_TRANSPORT
Systematic name | M22781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of ornithine, 2,5-diaminopentanoic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_PROLINE_TRANSPORT
Systematic name | M22782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of proline, pyrrolidine-2-carboxylic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_TRYPTOPHAN_TRANSPORT
Systematic name | M34103
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of tryptophan, 2-amino-3-(1H-indol-3-yl)propanoic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_AMINE_TRANSPORT
Systematic name | M22784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of amines, including polyamines, organic compounds containing one or more amino groups, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_AMINO_ACID_BETAINE_TRANSPORT
Systematic name | M11866
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of betaine, the N-trimethyl derivative of an amino acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_UREA_TRANSPORT
Systematic name | M22785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of urea into, out of or within the cell. Urea is the water-soluble compound H2N-CO-NH2. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_MONOAMINE_TRANSPORT
Systematic name | M16521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of monoamines, organic compounds that contain one amino group that is connected to an aromatic ring by an ethylene group (-CH2-CH2-), into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_POLYAMINE_TRANSPORT
Systematic name | M22786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of polyamines, organic compounds containing two or more amino groups, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:krc, ISBN:0198506732]
Full description |

Standard name | GO_ORGANIC_ACID_TRANSPORT
Systematic name | M11909
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of organic acids, any acidic compound containing carbon in covalent linkage, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [ISBN:0198506732]
Full description |

Standard name | GO_ORGANIC_HYDROXY_COMPOUND_TRANSPORT
Systematic name | M11947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of an organic hydroxy compound (organic alcohol) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. An organic hydroxy compound is an organic compound having at least one hydroxy group attached to a carbon atom. [GOC:ai]
Full description |

Standard name | GO_NUCLEOBASE_TRANSPORT
Systematic name | M22787
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a nucleobase, any nitrogenous base that is a constituent of a nucleoside, nucleotide, or nucleic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOBASE_TRANSPORT
Systematic name | M34104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of pyrimidine nucleobases, one of the two classes of nitrogen-containing ring compounds found in DNA and RNA, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_NUCLEOSIDE_TRANSPORT
Systematic name | M15329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a nucleoside, a nucleobase linked to either beta-D-ribofuranose (ribonucleoside) or 2-deoxy-beta-D-ribofuranose, (a deoxyribonucleotide), into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOSIDE_TRANSPORT
Systematic name | M34105
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a pyrimidine nucleoside, a pyrimidine base covalently bonded to a ribose or deoxyribose sugar, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_PURINE_NUCLEOTIDE_TRANSPORT
Systematic name | M13929
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a purine nucleotide, any compound consisting of a purine nucleoside esterified with (ortho)phosphate, into, out of or within a cell. [GOC:ai]
Full description |

Standard name | GO_ATP_TRANSPORT
Systematic name | M22789
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of ATP, adenosine triphosphate, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_CHOLINE_TRANSPORT
Systematic name | M22790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of choline into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Choline (2-hydroxyethyltrimethylammonium) is an amino alcohol that occurs widely in living organisms as a constituent of certain types of phospholipids and in the neurotransmitter acetylcholine. [GOC:ai]
Full description |

Standard name | GO_DOPAMINE_TRANSPORT
Systematic name | M16439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of dopamine into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Dopamine is a catecholamine neurotransmitter and a metabolic precursor of noradrenaline and adrenaline. [GOC:ai]
Full description |

Standard name | GO_NOREPINEPHRINE_TRANSPORT
Systematic name | M22791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of norepinephrine into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Norepinephrine (3,4-dihydroxyphenyl-2-aminoethanol) is a hormone secreted by the adrenal medulla and a neurotransmitter in the sympathetic peripheral nervous system and in some tracts of the CNS. It is also the biosynthetic precursor of epinephrine. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_FOLIC_ACID_TRANSPORT
Systematic name | M22792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of folic acid (pteroylglutamic acid) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Folic acid is widely distributed as a member of the vitamin B complex and is essential for the synthesis of purine and pyrimidines. [GOC:ai]
Full description |

Standard name | GO_HEME_TRANSPORT
Systematic name | M22793
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of heme, any compound of iron complexed in a porphyrin (tetrapyrrole) ring, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_COBALAMIN_TRANSPORT
Systematic name | M22794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of cobalamin (vitamin B12), a water-soluble vitamin characterized by possession of a corrin nucleus containing a cobalt atom, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_DRUG_TRANSPORT
Systematic name | M14189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a drug, a substance used in the diagnosis, treatment or prevention of a disease, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_FATTY_ACID_TRANSPORT
Systematic name | M15938
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of fatty acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Fatty acids are aliphatic monocarboxylic acids liberated from naturally occurring fats and oils by hydrolysis. [GOC:ai]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACID_TRANSPORT
Systematic name | M15724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of long-chain fatty acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. A long-chain fatty acid is a fatty acid with a chain length between C13 and C22. [GOC:ai]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACID_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M22795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of long-chain fatty acids from outside of a cell, across the plasma membrane and into the cytosol. A long-chain fatty acid is a fatty acid with a chain length between C13 and C22. [GOC:ai]
Full description |

Standard name | GO_PHOSPHOLIPID_TRANSPORT
Systematic name | M14795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of phospholipids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Phospholipids are any lipids containing phosphoric acid as a mono- or diester. [GOC:ai]
Full description |

Standard name | GO_STEROL_TRANSPORT
Systematic name | M15161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of sterols into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Sterols are steroids with one or more hydroxyl groups and a hydrocarbon side-chain in the molecule. [GOC:ai]
Full description |

Standard name | GO_PEROXISOMAL_MEMBRANE_TRANSPORT
Systematic name | M22797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances to, from or across the peroxisomal membrane. [GOC:ai]
Full description |

Standard name | GO_NUCLEOBASE_CONTAINING_COMPOUND_TRANSPORT
Systematic name | M13429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of nucleobases, nucleosides, nucleotides and nucleic acids, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_COENZYME_A_METABOLIC_PROCESS
Systematic name | M10813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving coenzyme A, 3'-phosphoadenosine-(5')diphospho(4')pantatheine, an acyl carrier in many acylation and acyl-transfer reactions in which the intermediate is a thiol ester. [ISBN:0198547684]
Full description |

Standard name | GO_COENZYME_A_BIOSYNTHETIC_PROCESS
Systematic name | M15325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of coenzyme A, 3'-phosphoadenosine-(5')diphospho(4')pantatheine, an acyl carrier in many acylation and acyl-transfer reactions in which the intermediate is a thiol ester. [ISBN:0198547684]
Full description |

Standard name | GO_PANTOTHENATE_METABOLIC_PROCESS
Systematic name | M22798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving pantothenate, the anion of pantothenic acid, the amide of beta-alanine and pantoic acid. It is a B complex vitamin that is a constituent of coenzyme A and is distributed ubiquitously in foods. [GOC:ai, ISBN:0721662544]
Full description |

Standard name | GO_FORMATE_METABOLIC_PROCESS
Systematic name | M29109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving formate, also known as methanoate, the anion HCOO- derived from methanoic (formic) acid. [ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOBASE_CONTAINING_SMALL_MOLECULE_INTERCONVERSION
Systematic name | M14441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways by which a nucleobase, nucleoside or nucleotide small molecule is synthesized from another nucleobase, nucleoside or nucleotide small molecule. [GOC:mah, ISBN:0306444747, ISBN:0471394831]
Full description |

Standard name | GO_DIADENOSINE_POLYPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving diadenosine polyphosphate, a derivative of the nucleoside adenosine with phosphate groups attached. [GOC:ai]
Full description |

Standard name | GO_DIADENOSINE_POLYPHOSPHATE_CATABOLIC_PROCESS
Systematic name | M34106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of diadenosine polyphosphate, a derivative of the nucleoside adenosine with phosphate groups attached. [GOC:ai]
Full description |

Standard name | GO_ENERGY_DERIVATION_BY_OXIDATION_OF_ORGANIC_COMPOUNDS
Systematic name | M16137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways by which a cell derives energy from organic compounds; results in the oxidation of the compounds from which energy is released. [GOC:mah]
Full description |

Standard name | GO_ATP_SYNTHESIS_COUPLED_PROTON_TRANSPORT
Systematic name | M29111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transport of protons across a membrane to generate an electrochemical gradient (proton-motive force) that powers ATP synthesis. [ISBN:0716731363]
Full description |

Standard name | GO_ENERGY_COUPLED_PROTON_TRANSMEMBRANE_TRANSPORT_AGAINST_ELECTROCHEMICAL_GRADIENT
Systematic name | M34107
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transport of protons across a membrane and against an electrochemical gradient, using energy from a source such as ATP hydrolysis, light, or electron transport. [GOC:mah]
Full description |

Standard name | GO_LIPID_CATABOLIC_PROCESS
Systematic name | M15533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of lipids, compounds soluble in an organic solvent but not, or sparingly, in an aqueous solvent. [GOC:go_curators]
Full description |

Standard name | GO_DETECTION_OF_TEMPERATURE_STIMULUS
Systematic name | M12357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a temperature stimulus (hot or cold) is received and converted into a molecular signal. [GOC:hb]
Full description |

Standard name | GO_CELL_GROWTH
Systematic name | M16570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a cell irreversibly increases in size over time by accretion and biosynthetic production of matter similar to that already present. [GOC:ai]
Full description |

Standard name | GO_VESICLE_ORGANIZATION
Systematic name | M10786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a vesicle. [GOC:mah]
Full description |

Standard name | GO_CARBOHYDRATE_BIOSYNTHETIC_PROCESS
Systematic name | M3786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of carbohydrates, any of a group of organic compounds based of the general formula Cx(H2O)y. [ISBN:0198506732]
Full description |

Standard name | GO_CARBOHYDRATE_CATABOLIC_PROCESS
Systematic name | M14508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of carbohydrates, any of a group of organic compounds based of the general formula Cx(H2O)y. [ISBN:0198506732]
Full description |

Standard name | GO_ORGANIC_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M11689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of organic acids, any acidic compound containing carbon in covalent linkage. [ISBN:0198506732]
Full description |

Standard name | GO_ORGANIC_ACID_CATABOLIC_PROCESS
Systematic name | M13128
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of organic acids, any acidic compound containing carbon in covalent linkage. [ISBN:0198506732]
Full description |

Standard name | GO_RHODOPSIN_MEDIATED_SIGNALING_PATHWAY
Systematic name | M29112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of excitation of rhodopsin by a photon and the events that convert the absorbed photons into a cellular response. [GOC:bf, GOC:dph, GOC:hb, GOC:signaling, GOC:tb]
Full description |

Standard name | GO_MRNA_METABOLIC_PROCESS
Systematic name | M5804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving mRNA, messenger RNA, which is responsible for carrying the coded genetic 'message', transcribed from DNA, to sites of protein assembly at the ribosomes. [ISBN:0198506732]
Full description |

Standard name | GO_RRNA_METABOLIC_PROCESS
Systematic name | M3080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving rRNA, ribosomal RNA, a structural constituent of ribosomes. [ISBN:0198506732]
Full description |

Standard name | GO_SNRNA_METABOLIC_PROCESS
Systematic name | M29113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving snRNA, small nuclear RNA, any of various low-molecular-mass RNA molecules found in the eukaryotic nucleus as components of the small nuclear ribonucleoprotein. [ISBN:0198506732]
Full description |

Standard name | GO_SNORNA_METABOLIC_PROCESS
Systematic name | M10884
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving snoRNA, small nucleolar RNA, any of a class of small RNAs that are associated with the eukaryotic nucleus as components of small nucleolar ribonucleoproteins. They participate in the processing or modifications of many RNAs, mostly ribosomal RNAs (rRNAs) though snoRNAs are also known to target other classes of RNA, including spliceosomal RNAs, tRNAs, and mRNAs via a stretch of sequence that is complementary to a sequence in the targeted RNA. [GOC:krc]
Full description |

Standard name | GO_RRNA_CATABOLIC_PROCESS
Systematic name | M15564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of rRNA, ribosomal RNA, a structural constituent of ribosomes. [GOC:ai]
Full description |

Standard name | GO_TRNA_CATABOLIC_PROCESS
Systematic name | M22802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of tRNA, transfer RNA, a class of relatively small RNA molecules responsible for mediating the insertion of amino acids into the sequence of nascent polypeptide chains during protein synthesis. [GOC:ai]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_EXOCYTOSIS
Systematic name | M22803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Fusion of intracellular membrane-bounded vesicles with the pre-synaptic membrane of the neuronal cell resulting in release of neurotransmitter into the synaptic cleft. [GOC:jid, GOC:lmg]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_DOCKING
Systematic name | M22804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial (indirect) attachment of a synaptic vesicle membrane to the presynaptic active zone membrane, mediated by proteins protruding from the membrane and proteins of the presynaptic active zone cytoplasmic component. Synaptic vesicle tethering is the first step in this process. [PMID:15217342]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_PRIMING
Systematic name | M22805
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that converts synaptic vesicles to a state of competence for calcium triggered fusion with the active zone membrane by bringing the two membranes into very close proximity. Priming typically (but not always) occurs after docking (Jahn and Fasshauer, 2012). Primed vesicles are also capable of spontaneously fusing with the active zone membrane. [GOC:mah, PMID:15217342, PMID:23060190]
Full description |

Standard name | GO_POLYPRENOL_METABOLIC_PROCESS
Systematic name | M29114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving polyprenols, prenols with more than 4 isoprenoid residues, which may be all-trans, or a mixture of cis and trans. [PMID:11108713]
Full description |

Standard name | GO_MONOTERPENOID_METABOLIC_PROCESS
Systematic name | M22806
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving monoterpenoid compounds, terpenoids having a C10 skeleton. [ISBN:0198547684]
Full description |

Standard name | GO_DITERPENOID_BIOSYNTHETIC_PROCESS
Systematic name | M22808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of diterpenoid compounds, terpenoids with four isoprene units. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_TERPENOID_BIOSYNTHETIC_PROCESS
Systematic name | M22809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of terpenoids, any member of a class of compounds characterized by an isoprenoid chemical structure. [GOC:ai]
Full description |

Standard name | GO_TERPENOID_CATABOLIC_PROCESS
Systematic name | M29115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of terpenoids, any member of a class of compounds characterized by an isoprenoid chemical structure. [GOC:ai]
Full description |

Standard name | GO_STEROL_METABOLIC_PROCESS
Systematic name | M15826
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving sterols, steroids with one or more hydroxyl groups and a hydrocarbon side-chain in the molecule. [ISBN:0198547684]
Full description |

Standard name | GO_STEROL_BIOSYNTHETIC_PROCESS
Systematic name | M15206
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of sterols, steroids with one or more hydroxyl groups and a hydrocarbon side-chain in the molecule. [GOC:go_curators]
Full description |

Standard name | GO_GLYCOSIDE_METABOLIC_PROCESS
Systematic name | M16685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycosides, compounds in which a glycosyl group is substituted into a hydroxyl, thiol or selenol group in another compound. [ISBN:0198547684]
Full description |

Standard name | GO_GLYCOSIDE_CATABOLIC_PROCESS
Systematic name | M22810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glycosides, compounds in which a glycosyl group is substituted into a hydroxyl, thiol or selenol group in another compound. [GOC:go_curators]
Full description |

Standard name | GO_SNRNA_PROCESSING
Systematic name | M15788
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the conversion of a primary small nuclear RNA (snRNA) transcript into a mature snRNA molecule. [GOC:jl]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_BUDDING_FROM_PRESYNAPTIC_ENDOCYTIC_ZONE_MEMBRANE
Systematic name | M22811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Evagination of the presynaptic membrane, resulting in the formation of a new synaptic vesicle. [GOC:curators, PMID:10099709, PMID:20448150]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_MATURATION
Systematic name | M22812
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Steps required to form an initiated synaptic vesicle into a fully formed and transmissible synaptic vesicle. [GOC:curators, PMID:10099709]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_UNCOATING
Systematic name | M22813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of the protein coat on a synaptic vesicle following the pinching step at the end of budding from the presynaptic membrane. [GOC:curators, PMID:10099709, PMID:24596248]
Full description |

Standard name | GO_ENDOSOMAL_TRANSPORT
Systematic name | M22814
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances mediated by an endosome, a membrane-bounded organelle that carries materials enclosed in the lumen or located in the endosomal membrane. [ISBN:0198506732]
Full description |

Standard name | GO_AXON_CHOICE_POINT_RECOGNITION
Systematic name | M22815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The recognition of molecules at a choice point by an axon growth cone; at a choice point the growth cone determines the direction of its future growth. [PMID:10218152]
Full description |

Standard name | GO_AXON_MIDLINE_CHOICE_POINT_RECOGNITION
Systematic name | M22816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The recognition of molecules at the central nervous system midline choice point by an axon growth cone; this choice point determines whether the growth cone will cross the midline. [PMID:11376484]
Full description |

Standard name | GO_IRON_SULFUR_CLUSTER_ASSEMBLY
Systematic name | M22817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The incorporation of iron and exogenous sulfur into a metallo-sulfur cluster. [GOC:jl, GOC:mah, GOC:pde, GOC:vw]
Full description |

Standard name | GO_TELOMERE_CAPPING
Systematic name | M10586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which telomeres are protected from degradation and fusion, thereby ensuring chromosome stability by protecting the ends from both degradation and from being recognized as damaged DNA. May be mediated by specific single- or double-stranded telomeric DNA binding proteins. [GOC:mah, GOC:rn, PMID:11349150, PMID:11352055]
Full description |

Standard name | GO_MACROAUTOPHAGY
Systematic name | M11871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The major inducible pathway for the general turnover of cytoplasmic constituents in eukaryotic cells, it is also responsible for the degradation of active cytoplasmic enzymes and organelles during nutrient starvation. Macroautophagy involves the formation of double-membrane-bounded autophagosomes which enclose the cytoplasmic constituent targeted for degradation in a membrane-bounded structure. Autophagosomes then fuse with a lysosome (or vacuole) releasing single-membrane-bounded autophagic bodies that are then degraded within the lysosome (or vacuole). Some types of macroautophagy, e.g. pexophagy, mitophagy, involve selective targeting of the targets to be degraded. [PMID:11099404, PMID:12914914, PMID:15798367, PMID:16973210, PMID:20159618, PMID:9412464]
Full description |

Standard name | GO_LYSOSOMAL_MICROAUTOPHAGY
Systematic name | M34108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of cytosolic components into the lysosomal compartment by direct invagination of the lysosomal membrane without prior sequestration into an autophagosome. The engulfing membranes fuse, resulting in the lysosomal delivery of the cargo wrapped in a single membrane derived from the invaginated lysosomal membrane. In S. cerevisiae, the vacuole is the lysosomal compartment. [PMID:14679207, PMID:15798367, PMID:16973210, PMID:9566964]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MACROAUTOPHAGY
Systematic name | M22818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process, such as recognition of nutrient depletion, that activates or increases the rate of macroautophagy to bring cytosolic macromolecules to the vacuole/lysosome for degradation. [GOC:go_curators, PMID:9412464]
Full description |

Standard name | GO_REGULATION_OF_MACROAUTOPHAGY
Systematic name | M22819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of macroautophagy. [GOC:krc]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MACROAUTOPHAGY
Systematic name | M14040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of macroautophagy. [GOC:go_curators]
Full description |

Standard name | GO_RNA_INTERFERENCE
Systematic name | M16564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which double-stranded RNAs silence cognate genes. Involves posttranscriptional gene inactivation ('silencing') both of transgenes or dsRNA introduced into a germline, and of the host gene(s) homologous to the transgenes or dsRNA. This silencing is triggered by the introduction of transgenes or double-stranded RNA (dsRNA), and can occur through a specific decrease in the level of mRNA, or by negative regulation of translation, of both host genes and transgenes. [GOC:ems, PMID:11201747, PMID:11713190, PMID:18771919]
Full description |

Standard name | GO_PREASSEMBLY_OF_GPI_ANCHOR_IN_ER_MEMBRANE
Systematic name | M10908
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The stepwise addition of the components of the GPI anchor on to phosphatidylinositol lipids in the endoplasmic reticulum membrane. [ISBN:0879695595]
Full description |

Standard name | GO_ATTACHMENT_OF_GPI_ANCHOR_TO_PROTEIN
Systematic name | M22820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A transamidation reaction that results in the cleavage of the polypeptide chain and the concomitant transfer of the GPI anchor to the newly formed carboxy-terminal amino acid of the anchored protein. The cleaved C-terminal contains the C-terminal GPI signal sequence of the newly synthesized polypeptide chain. [ISBN:0879695595]
Full description |

Standard name | GO_GAP_JUNCTION_ASSEMBLY
Systematic name | M22821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Assembly of gap junctions, which are found in most animal tissues, and serve as direct connections between the cytoplasms of adjacent cells. They provide open channels through the plasma membrane, allowing ions and small molecules (less than approximately a thousand daltons) to diffuse freely between neighboring cells, but preventing the passage of proteins and nucleic acids. [GOC:jid, ISBN:0716731363]
Full description |

Standard name | GO_O_GLYCAN_PROCESSING
Systematic name | M15987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The stepwise addition of carbohydrate or carbohydrate derivative residues to the initially added O-linked residue (usually GalNAc) to form a core O-glycan structure. [GOC:mah, GOC:pr, PMID:10580130]
Full description |

Standard name | GO_DEPHOSPHORYLATION
Systematic name | M14717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of removing one or more phosphoric (ester or anhydride) residues from a molecule. [ISBN:0198506732]
Full description |

Standard name | GO_FEMALE_MEIOSIS_CHROMOSOME_SEGREGATION
Systematic name | M22822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which genetic material, in the form of chromosomes, is organized and then physically separated and apportioned to two or more sets during the meiotic cell cycle in a female. [GOC:ai]
Full description |

Standard name | GO_NEURON_REMODELING
Systematic name | M22823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmentally regulated remodeling of neuronal projections such as pruning to eliminate the extra dendrites and axons projections set up in early stages of nervous system development. [GOC:hb]
Full description |

Standard name | GO_MORPHOGENESIS_OF_EMBRYONIC_EPITHELIUM
Systematic name | M11646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of embryonic epithelia are generated and organized. [GOC:jl]
Full description |

Standard name | GO_CALCIUM_INDEPENDENT_CELL_CELL_ADHESION_VIA_PLASMA_MEMBRANE_CELL_ADHESION_MOLECULES
Systematic name | M7966
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of one cell to another cell via adhesion molecules that do not require the presence of calcium for the interaction. [GOC:hb]
Full description |

Standard name | GO_CALCIUM_DEPENDENT_CELL_CELL_ADHESION_VIA_PLASMA_MEMBRANE_CELL_ADHESION_MOLECULES
Systematic name | M11914
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of one cell to another cell via adhesion molecules that require the presence of calcium for the interaction. [GOC:hb]
Full description |

Standard name | GO_DENDRITE_DEVELOPMENT
Systematic name | M10094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the dendrite over time, from its formation to the mature structure. [GOC:aruk, GOC:bc, GOC:jl, ISBN:0198506732, PMID:22683681]
Full description |

Standard name | GO_SOMATIC_DIVERSIFICATION_OF_IMMUNOGLOBULINS
Systematic name | M34109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The somatic process that results in the generation of sequence diversity of immunoglobulins. [GOC:add, GOC:ma, ISBN:0781735149]
Full description |

Standard name | GO_SOMATIC_RECOMBINATION_OF_IMMUNOGLOBULIN_GENE_SEGMENTS
Systematic name | M16380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which immunoglobulin genes are formed through recombination of the germline genetic elements, as known as immunoglobulin gene segments, within a single locus. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_GENE_SILENCING
Systematic name | M29117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process carried out at the cellular level that results in either long-term transcriptional repression via action on chromatin structure or RNA mediated, post-transcriptional repression of gene expression. [GOC:dos, GOC:dph, GOC:jid, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSCRIPTION_BY_RNA_POLYMERASE_I
Systematic name | M22824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of transcription mediated by RNA polymerase I. [GOC:go_curators]
Full description |

Standard name | GO_CYTOSOLIC_TRANSPORT
Systematic name | M16876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances or organelles within the cytosol. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_PROCESSING
Systematic name | M22825
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any protein maturation process achieved by the cleavage of a peptide bond or bonds within a protein. Protein maturation is the process leading to the attainment of the full functional capacity of a protein. [GOC:curators, GOC:jl, GOC:jsg]
Full description |

Standard name | GO_PROTEIN_AUTOPROCESSING
Systematic name | M16507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Processing which a protein carries out itself. This involves actions such as the autolytic removal of residues to generate the mature form of the protein. [GOC:ai, PMID:9335337]
Full description |

Standard name | GO_BASE_CONVERSION_OR_SUBSTITUTION_EDITING
Systematic name | M22826
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any base modification or substitution events that result in alterations in the coding potential or structural properties of RNAs as a result of changes in the base-pairing properties of the modified ribonucleoside(s). [PMID:11092837]
Full description |

Standard name | GO_CYTIDINE_TO_URIDINE_EDITING
Systematic name | M22827
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The conversion of a cytosine residue to uridine in an RNA molecule by deamination. [PMID:11092837]
Full description |

Standard name | GO_MRNA_MODIFICATION
Systematic name | M11831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent alteration of one or more nucleotides within an mRNA molecule to produce an mRNA molecule with a sequence that differs from that coded genetically. [GOC:curators]
Full description |

Standard name | GO_PROTEIN_IMPORT_INTO_PEROXISOME_MATRIX
Systematic name | M16241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The import of proteins into the peroxisomal matrix. A peroxisome targeting signal (PTS) binds to a soluble receptor protein in the cytosol, and the resulting complex then binds to a receptor protein in the peroxisome membrane and is imported. The cargo protein is then released into the peroxisome matrix. [ISBN:0716731363, PMID:11687502, PMID:11988772]
Full description |

Standard name | GO_PEROXISOME_FISSION
Systematic name | M22828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The division of a mature peroxisome within a cell to form two or more separate peroxisome compartments. [GOC:mah, PMID:11687502, PMID:14754507]
Full description |

Standard name | GO_COVALENT_CHROMATIN_MODIFICATION
Systematic name | M13244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The alteration of DNA or protein in chromatin by the covalent addition or removal of chemical groups. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_HISTONE_METHYLATION
Systematic name | M10934
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histones by addition of methyl groups. [GOC:ai]
Full description |

Standard name | GO_HISTONE_PHOSPHORYLATION
Systematic name | M16040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histones by addition of phosphate groups. [GOC:ai]
Full description |

Standard name | GO_HISTONE_UBIQUITINATION
Systematic name | M14333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histones by addition of ubiquitin groups. [GOC:ai]
Full description |

Standard name | GO_HISTONE_DEACETYLATION
Systematic name | M22829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histones by removal of acetyl groups. [GOC:ai]
Full description |

Standard name | GO_HISTONE_DEPHOSPHORYLATION
Systematic name | M22830
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histones by removal of phosphate groups. [GOC:ai]
Full description |

Standard name | GO_HISTONE_DEUBIQUITINATION
Systematic name | M11907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histones by removal of ubiquitin groups. [GOC:ai]
Full description |

Standard name | GO_NUCLEOSOME_POSITIONING
Systematic name | M22831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Ordering of successions of nucleosomes into regular arrays so that nucleosomes are positioned at defined distances from one another. [GOC:bf, PMID:11447119, PMID:8676389]
Full description |

Standard name | GO_RAC_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M16065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals within the cell that are mediated by a member of the Rac family of proteins switching to a GTP-bound active state. [GOC:bf]
Full description |

Standard name | GO_PROTEIN_SUMOYLATION
Systematic name | M13502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a SUMO protein (small ubiquitin-related modifier) is conjugated to a target protein via an isopeptide bond between the carboxy-terminus of SUMO with an epsilon-amino group of a lysine residue of the target protein. [GOC:jl, PMID:11265250]
Full description |

Standard name | GO_PROTEIN_DESUMOYLATION
Systematic name | M22832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a SUMO protein (small ubiquitin-related modifier) is cleaved from its target protein. [GOC:jl, PMID:11265250]
Full description |

Standard name | GO_POLY_A_PLUS_MRNA_EXPORT_FROM_NUCLEUS
Systematic name | M22833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of poly(A)+ mRNA out of the nucleus into the cytoplasm. [GOC:ai]
Full description |

Standard name | GO_CYTOCHROME_COMPLEX_ASSEMBLY
Systematic name | M11937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a cytochrome complex. A cytochrome complex is a protein complex in which at least one of the proteins is a cytochrome, i.e. a heme-containing protein involved in catalysis of redox reactions. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_PROTEIN_NITROSYLATION
Systematic name | M22837
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent addition of a nitric oxide group to an amino acid within a protein. [GOC:ai, PMID:20972426]
Full description |

Standard name | GO_PROTEIN_IMPORT
Systematic name | M11299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The targeting and directed movement of proteins into a cell or organelle. Not all import involves an initial targeting event. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_INSECTICIDE
Systematic name | M12887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an insecticide stimulus. Insecticides are chemicals used to kill insects. [GOC:curators]
Full description |

Standard name | GO_PLASMA_MEMBRANE_PHOSPHOLIPID_SCRAMBLING
Systematic name | M22838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a population of phospholipid molecules from one leaflet of the plasma membrane bilayer to the opposite leaflet, resulting in loss of lipid asymmetry and surface exposure of phosphatidylserine (PS) and phosphatidylethanolamine (PE). [GOC:cjm, PMID:20043909, PMID:20302864]
Full description |

Standard name | GO_DRUG_METABOLIC_PROCESS
Systematic name | M14156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a drug, a substance used in the diagnosis, treatment or prevention of a disease; as used here antibiotic substances (see antibiotic metabolism) are considered to be drugs, even if not used in medical or veterinary practice. [GOC:cab2]
Full description |

Standard name | GO_STEM_CELL_DIVISION
Systematic name | M12183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The self-renewing division of a stem cell. A stem cell is an undifferentiated cell, in the embryo or adult, that can undergo unlimited division and give rise to one or several different cell types. [GOC:jid, ISBN:0582227089]
Full description |

Standard name | GO_CALCIUM_ION_REGULATED_EXOCYTOSIS
Systematic name | M13877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The release of intracellular molecules (e.g. hormones, matrix proteins) contained within a membrane-bounded vesicle by fusion of the vesicle with the plasma membrane of a cell, induced by a rise in cytosolic calcium-ion levels. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_EXOCYTOSIS
Systematic name | M11165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of exocytosis. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_CALCIUM_ION_DEPENDENT_EXOCYTOSIS
Systematic name | M13808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of calcium ion-dependent exocytosis. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_DIPHTHAMIDE_BIOSYNTHETIC_PROCESS_FROM_PEPTIDYL_HISTIDINE
Systematic name | M22839
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-histidine to 2'-(3-carboxamido-3-(trimethylammonio)propyl)-L-histidine, known as diphthamide, found in translation elongation factor EF-2. The process occurs in eukaryotes and archaea but not eubacteria. [GOC:pde, PMID:20559380, RESID:AA0040]
Full description |

Standard name | GO_PEPTIDYL_LYSINE_HYDROXYLATION
Systematic name | M22840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The hydroxylation of peptidyl-lysine to form peptidyl-hydroxylysine. [GOC:ai]
Full description |

Standard name | GO_N_TERMINAL_PEPTIDYL_METHIONINE_ACETYLATION
Systematic name | M22841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The acetylation of the N-terminal methionine of proteins to form the derivative N-acetyl-L-methionine. [RESID:AA0049]
Full description |

Standard name | GO_PEPTIDYL_LYSINE_METHYLATION
Systematic name | M16191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The methylation of peptidyl-lysine to form either the mono-, di- or trimethylated derivative. [GOC:ai]
Full description |

Standard name | GO_PEPTIDYL_LYSINE_TRIMETHYLATION
Systematic name | M15561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The methylation of peptidyl-lysine to form peptidyl-N6,N6,N6-trimethyl-L-lysine. [RESID:AA0074]
Full description |

Standard name | GO_PEPTIDYL_LYSINE_MONOMETHYLATION
Systematic name | M22842
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The methylation of peptidyl-lysine to form peptidyl-N6-methyl-L-lysine. [RESID:AA0076]
Full description |

Standard name | GO_PEPTIDYL_LYSINE_DIMETHYLATION
Systematic name | M16240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The methylation of peptidyl-lysine to form peptidyl-N6,N6-dimethyl-L-lysine. [RESID:AA0075]
Full description |

Standard name | GO_PEPTIDYL_LYSINE_OXIDATION
Systematic name | M22843
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The oxidation of the terminal amino-methylene groups of peptidyl-L-lysine or peptidyl-5-hydroxy-L-lysine to aldehyde groups to form allysine or hydroxyallysine residues, respectively; these are intermediates in the formation of covalent cross-links between adjacent polypeptide chains in proteins such as collagens. [ISBN:0198547684, RESID:AA0121]
Full description |

Standard name | GO_PROTEIN_POLYGLUTAMYLATION
Systematic name | M22845
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of one or more alpha-linked glutamyl units to the gamma carboxyl group of peptidyl-glutamic acid. [RESID:AA0202]
Full description |

Standard name | GO_PROTEIN_C_LINKED_GLYCOSYLATION
Systematic name | M22846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein glycosylation process in which a carbohydrate or carbohydrate derivative unit is added to a protein via a C atom. [GOC:pr, PMID:7947762, RESID:AA0217]
Full description |

Standard name | GO_PROTEIN_HYDROXYLATION
Systematic name | M16190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a hydroxy group to a protein amino acid. [GOC:ai]
Full description |

Standard name | GO_KERATAN_SULFATE_BIOSYNTHETIC_PROCESS
Systematic name | M34110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of keratan sulfate, a glycosaminoglycan with repeat units consisting of beta-1,4-linked D-galactopyranosyl-beta-(1,4)-N-acetyl-D-glucosamine 6-sulfate and with variable amounts of fucose, sialic acid and mannose units; keratan sulfate chains are covalently linked by a glycosidic attachment through the trisaccharide galactosyl-galactosyl-xylose to peptidyl-threonine or serine residues. [ISBN:0198547684, RESID:AA0247]
Full description |

Standard name | GO_PEPTIDE_CROSS_LINKING
Systematic name | M10944
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a covalent cross-link between or within protein chains. [GOC:jsg]
Full description |

Standard name | GO_PROTEIN_OXIDATION
Systematic name | M22847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of a protein amino acid by oxidation. [GOC:ai]
Full description |

Standard name | GO_PEPTIDYL_AMINO_ACID_MODIFICATION
Systematic name | M3477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The alteration of an amino acid residue in a peptide. [GOC:mah]
Full description |

Standard name | GO_PEPTIDYL_ARGININE_MODIFICATION
Systematic name | M11726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-arginine. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_ASPARAGINE_MODIFICATION
Systematic name | M15831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-asparagine. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_CYSTEINE_MODIFICATION
Systematic name | M11643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-cysteine. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_GLUTAMIC_ACID_MODIFICATION
Systematic name | M13999
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-glutamic acid. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_HISTIDINE_MODIFICATION
Systematic name | M22849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-histidine. [GOC:ma]
Full description |

Standard name | GO_PEPTIDYL_LYSINE_MODIFICATION
Systematic name | M12286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-lysine. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_METHIONINE_MODIFICATION
Systematic name | M16116
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-methionine. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_PROLINE_MODIFICATION
Systematic name | M14790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-proline. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_SERINE_MODIFICATION
Systematic name | M10946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-serine. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_THREONINE_MODIFICATION
Systematic name | M12785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-threonine. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_TYROSINE_MODIFICATION
Systematic name | M19329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-tyrosine. [GOC:go_curators]
Full description |

Standard name | GO_PEPTIDYL_ARGININE_METHYLATION
Systematic name | M16038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a methyl group to an arginine residue in a protein. [GOC:mah]
Full description |

Standard name | GO_PEPTIDYL_L_CYSTEINE_S_PALMITOYLATION
Systematic name | M22850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment of a palmitoyl group to a sulfur (S) atom within a cysteine residue to form peptidyl-S-palmitoyl-L-cysteine. [RESID:AA0106]
Full description |

Standard name | GO_PROTEIN_O_LINKED_GLYCOSYLATION_VIA_SERINE
Systematic name | M22851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The glycosylation of protein via the O3 atom of peptidyl-serine, forming O3-glycosyl-L-serine; the most common forms are N-acetylgalactosaminyl, mannosyl, galactosyl, and xylosyl serine. [RESID:AA0154]
Full description |

Standard name | GO_PROTEIN_O_LINKED_GLYCOSYLATION_VIA_THREONINE
Systematic name | M22852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The glycosylation of protein via the O3 atom of peptidyl-threonine, forming O3-glycosyl-L-threonine; the most common forms are N-acetylgalactosaminyl, mannosyl, and galactosyl threonine. [RESID:AA0155]
Full description |

Standard name | GO_PROTEIN_CHROMOPHORE_LINKAGE
Systematic name | M15620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent or noncovalent attachment of a chromophore to a protein. [GOC:ma]
Full description |

Standard name | GO_PROTEIN_GERANYLGERANYLATION
Systematic name | M22853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment of a geranylgeranyl group to a protein. [GOC:jl]
Full description |

Standard name | GO_PROTEIN_PALMITOYLATION
Systematic name | M15614
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment of a palmitoyl group to a protein. [GOC:jl, PMID:15520806]
Full description |

Standard name | GO_PEPTIDYL_GLUTAMINE_METHYLATION
Systematic name | M34111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a methyl group to a glutamine residue in a protein. [GOC:mah]
Full description |

Standard name | GO_PEPTIDYL_LYSINE_ACETYLATION
Systematic name | M22854
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The acetylation of peptidyl-lysine. [GOC:mah]
Full description |

Standard name | GO_PEPTIDYL_PROLINE_HYDROXYLATION_TO_4_HYDROXY_L_PROLINE
Systematic name | M22855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of peptidyl-proline to form 4-hydroxy-L-proline; catalyzed by procollagen-proline,2-oxoglutarate-4-dioxygenase. [RESID:AA0030]
Full description |

Standard name | GO_C_TERMINAL_PROTEIN_AMINO_ACID_MODIFICATION
Systematic name | M15475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The alteration of the C-terminal amino acid residue in a protein. [GOC:mah]
Full description |

Standard name | GO_ETHER_METABOLIC_PROCESS
Systematic name | M10178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving organic ethers, any anhydride of the general formula R1-O-R2, formed between two identical or nonidentical organic hydroxy compounds. [GOC:pr, ISBN:0198506732]
Full description |

Standard name | GO_PHENOL_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M10130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a phenol, any compound containing one or more hydroxyl groups directly attached to an aromatic carbon ring. [ISBN:0198506732]
Full description |

Standard name | GO_VIRAL_LATENCY
Systematic name | M15253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process by which, after initial infection, a virus lies dormant within a cell and viral production ceases. The process ends when the virus switches from latency and starts to replicate. [GOC:jl]
Full description |

Standard name | GO_ESTABLISHMENT_OF_VIRAL_LATENCY
Systematic name | M22856
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process by which a virus establishes a latent state within its host, either as an integrated provirus within the host genome or as an episome, where viral genome remains in the cytoplasm or nucleus as distinct objects. [GOC:jl]
Full description |

Standard name | GO_MODULATION_BY_VIRUS_OF_HOST_PROCESS
Systematic name | M29118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a virus effects a change in the structure or processes of its host organism. [GOC:bf, GOC:jl, ISBN:0781718325, UniProtKB-KW:KW-0945]
Full description |

Standard name | GO_MODULATION_BY_VIRUS_OF_HOST_CELLULAR_PROCESS
Systematic name | M29119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a virus effects a change in the processes and activities of its host organism. [GOC:jl]
Full description |

Standard name | GO_VIRAL_LIFE_CYCLE
Systematic name | M13783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A set of processes which all viruses follow to ensure survival; includes attachment and entry of the virus particle, decoding of genome information, translation of viral mRNA by host ribosomes, genome replication, and assembly and release of viral particles containing the genome. [ISBN:1555811272]
Full description |

Standard name | GO_VIRION_ATTACHMENT_TO_HOST_CELL
Systematic name | M22857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process by which a virion protein binds to molecules on the host cellular surface or host cell surface projection. [GOC:bf, GOC:jl, UniProtKB-KW:KW-1161, VZ:956]
Full description |

Standard name | GO_VIRION_ASSEMBLY
Systematic name | M14097
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A late phase of the viral life cycle during which all the components necessary for the formation of a mature virion collect at a particular site in the cell and the basic structure of the virus particle is formed. [ISBN:0121585336]
Full description |

Standard name | GO_VIRAL_RELEASE_FROM_HOST_CELL
Systematic name | M34112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The dissemination of mature viral particles from the host cell, e.g. by cell lysis or the budding of virus particles from the cell membrane. [GOC:jl]
Full description |

Standard name | GO_VIRAL_GENOME_REPLICATION
Systematic name | M13578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved directly in viral genome replication, including viral nucleotide metabolism. [ISBN:0781702534]
Full description |

Standard name | GO_VIRAL_GENE_EXPRESSION
Systematic name | M22858
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process by which a viral gene is converted into a mature gene product or products (proteins or RNA). This includes viral transcription, processing to produce a mature RNA product, and viral translation. [GOC:bf, GOC:jl, ISBN:0121585336]
Full description |

Standard name | GO_VIRAL_TRANSLATION
Systematic name | M22859
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process by which viral mRNA is translated into viral protein, using the host cellular machinery. [GOC:bf, GOC:jl, ISBN:0781702534]
Full description |

Standard name | GO_REPRODUCTIVE_BEHAVIOR
Systematic name | M13129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific behavior of an organism that is associated with reproduction. [GOC:jl, GOC:pr]
Full description |

Standard name | GO_NONRIBOSOMAL_PEPTIDE_BIOSYNTHETIC_PROCESS
Systematic name | M12996
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biosynthetic process in which peptide bond formation occurs in the absence of the translational machinery. Examples include the synthesis of antibiotic peptides, and glutathione. [ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_LIPID_METABOLIC_PROCESS
Systematic name | M12303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving lipids. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_FATTY_ACID_METABOLIC_PROCESS
Systematic name | M11936
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving fatty acids. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_STEROID_METABOLIC_PROCESS
Systematic name | M15200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving steroids. [GOC:go_curators]
Full description |

Standard name | GO_CYTOKINE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a cytokine to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, GOC:signaling, PMID:19295629]
Full description |

Standard name | GO_TRANSMISSION_OF_NERVE_IMPULSE
Systematic name | M8461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The neurological system process in which a signal is transmitted through the nervous system by a combination of action potential propagation and synaptic transmission. [GOC:curators, ISBN:0815316194]
Full description |

Standard name | GO_NEURONAL_ACTION_POTENTIAL_PROPAGATION
Systematic name | M22861
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The propagation of an action potential along an axon, away from the soma. [GOC:isa_complete]
Full description |

Standard name | GO_NEURONAL_ACTION_POTENTIAL
Systematic name | M16080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An action potential that occurs in a neuron. [GOC:dph, GOC:isa_complete, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_VASOCONSTRICTION
Systematic name | M14342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of reductions in the diameter of blood vessels. [GOC:jl]
Full description |

Standard name | GO_PROPRIOCEPTION
Systematic name | M22862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events by which an organism senses the position, location, orientation, and movement of the body and its parts. Proprioception is mediated by proprioceptors, sensory nerve terminals found in muscles, tendons, and joint capsules, which give information concerning movements and position of the body. The receptors in the labyrinth are sometimes also considered proprioceptors. [ISBN:072168677X]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_PAIN
Systematic name | M12273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive a painful stimulus, convert it to a molecular signal, and recognize and characterize the signal. Pain is medically defined as the physical sensation of discomfort or distress caused by injury or illness, so can hence be described as a harmful stimulus which signals current (or impending) tissue damage. Pain may come from extremes of temperature, mechanical damage, electricity or from noxious chemical substances. This is a neurological process. [GOC:curators]
Full description |

Standard name | GO_RESPONSE_TO_PHEROMONE
Systematic name | M22863
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a pheromone stimulus. [GOC:jl]
Full description |

Standard name | GO_CITRULLINE_BIOSYNTHETIC_PROCESS
Systematic name | M22864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of citrulline, N5-carbamoyl-L-ornithine, an alpha amino acid not found in proteins. [ISBN:0198506732]
Full description |

Standard name | GO_N_ACETYLNEURAMINATE_CATABOLIC_PROCESS
Systematic name | M22865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of N-acetylneuraminate, the anion of 5-(acetylamino)-3,5-dideoxy-D-glycero-D-galacto-non-3-ulosonic acid. [ISBN:0198506732]
Full description |

Standard name | GO_FUCOSE_CATABOLIC_PROCESS
Systematic name | M22866
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of fucose (6-deoxygalactose). [GOC:jl]
Full description |

Standard name | GO_HEXOSE_CATABOLIC_PROCESS
Systematic name | M34113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of hexose, any monosaccharide with a chain of six carbon atoms in the molecule. [ISBN:0198506732]
Full description |

Standard name | GO_PENTOSE_METABOLIC_PROCESS
Systematic name | M16303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a pentose, any monosaccharide with a chain of five carbon atoms in the molecule. [ISBN:0198506732]
Full description |

Standard name | GO_PENTOSE_CATABOLIC_PROCESS
Systematic name | M22867
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a pentose, any monosaccharide with a chain of five carbon atoms in the molecule. [ISBN:0198506732]
Full description |

Standard name | GO_PHENOL_CONTAINING_COMPOUND_CATABOLIC_PROCESS
Systematic name | M22868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a phenol, any compound containing one or more hydroxyl groups directly attached to an aromatic carbon ring. [ISBN:0198506732]
Full description |

Standard name | GO_DOLICHOL_METABOLIC_PROCESS
Systematic name | M29120
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving dolichols, any 2,3-dihydropolyprenol derived from four or more linked isoprene units. [ISBN:0198506732]
Full description |

Standard name | GO_FATTY_ACID_ELONGATION_SATURATED_FATTY_ACID
Systematic name | M22870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Elongation of a saturated fatty acid chain. [GOC:mah]
Full description |

Standard name | GO_ARACHIDONIC_ACID_METABOLIC_PROCESS
Systematic name | M15944
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving arachidonic acid, a straight chain fatty acid with 20 carbon atoms and four double bonds per molecule. Arachidonic acid is the all-Z-(5,8,11,14)-isomer. [ISBN:0198506732]
Full description |

Standard name | GO_LEUKOTRIENE_BIOSYNTHETIC_PROCESS
Systematic name | M11524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of leukotriene, a pharmacologically active substance derived from a polyunsaturated fatty acid, such as arachidonic acid. [GOC:go_curators]
Full description |

Standard name | GO_CYCLOOXYGENASE_PATHWAY
Systematic name | M14352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways by which prostaglandins are formed from arachidonic acid, and in which prostaglandin-endoperoxide synthase (cyclooxygenase) catalyzes the committed step in the conversion of arachidonic acid to the prostaglandin-endoperoxides PGG2 and PGH2. [PMID:19854273]
Full description |

Standard name | GO_LIPOXYGENASE_PATHWAY
Systematic name | M12487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways by which an unsaturated fatty acid (such as arachidonic acid or linolenic acid) is converted to other compounds, and in which the first step is hydroperoxide formation catalyzed by lipoxygenase. [GOC:mah, PMID:17163881]
Full description |

Standard name | GO_EPOXYGENASE_P450_PATHWAY
Systematic name | M16166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways by which arachidonic acid is converted to other compounds including epoxyeicosatrienoic acids and dihydroxyeicosatrienoic acids. [GOC:mah, PMID:17979511]
Full description |

Standard name | GO_GALACTOLIPID_METABOLIC_PROCESS
Systematic name | M29122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving galactolipids, any glycolipid containing one of more residues of galactose and/or N-acetylgalactosamine. [ISBN:0198506732]
Full description |

Standard name | GO_GALACTOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M22871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of galactolipids, any glycolipid containing one of more residues of galactose and/or N-acetylgalactosamine. [ISBN:0198506732]
Full description |

Standard name | GO_GLYCOLIPID_CATABOLIC_PROCESS
Systematic name | M12373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glycolipid, a class of 1,2-di-O-acylglycerols joined at oxygen 3 by a glycosidic linkage to a carbohydrate part (usually a mono-, di- or tri-saccharide). [GOC:go_curators]
Full description |

Standard name | GO_GALACTOSE_CATABOLIC_PROCESS
Systematic name | M22872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of galactose, the aldohexose galacto-hexose. [ISBN:0198506732]
Full description |

Standard name | GO_ALDITOL_METABOLIC_PROCESS
Systematic name | M12277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving alditols, any polyhydric alcohol derived from the acyclic form of a monosaccharide by reduction of its aldehyde or keto group to an alcoholic group. [ISBN:0198506732]
Full description |

Standard name | GO_ALDITOL_BIOSYNTHETIC_PROCESS
Systematic name | M22873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of alditols, any polyhydric alcohol derived from the acyclic form of a monosaccharide by reduction of its aldehyde or keto group to an alcoholic group. [ISBN:0198506732]
Full description |

Standard name | GO_ALDITOL_CATABOLIC_PROCESS
Systematic name | M22874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of alditols, any polyhydric alcohol derived from the acyclic form of a monosaccharide by reduction of its aldehyde or keto group to an alcoholic group. [ISBN:0198506732]
Full description |

Standard name | GO_SULFIDE_OXIDATION
Systematic name | M22875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the conversion of sulfide to elemental sulfur in a higher oxidation state, or to sulfite or sulfate. [MetaCyc:P222-PWY, MetaCyc:P223-PWY, MetaCyc:PWY-5274, MetaCyc:PWY-5285]
Full description |

Standard name | GO_TRIGLYCERIDE_BIOSYNTHETIC_PROCESS
Systematic name | M34114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a triglyceride, any triester of glycerol. [ISBN:0198506732]
Full description |

Standard name | GO_TRIGLYCERIDE_CATABOLIC_PROCESS
Systematic name | M14112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a triglyceride, any triester of glycerol. [ISBN:0198506732]
Full description |

Standard name | GO_TRYPTOPHAN_CATABOLIC_PROCESS_TO_KYNURENINE
Systematic name | M22876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of tryptophan into other compounds, including kynurenine. [GOC:go_curators]
Full description |

Standard name | GO_L_METHIONINE_SALVAGE_FROM_METHYLTHIOADENOSINE
Systematic name | M22877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The generation of L-methionine (2-amino-4-(methylthio)butanoic acid) from methylthioadenosine. [GOC:jl, MetaCyc:PWY-4361]
Full description |

Standard name | GO_PEPTIDYL_PROLINE_HYDROXYLATION
Systematic name | M11860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The hydroxylation of peptidyl-proline to form peptidyl-hydroxyproline. [GOC:mah]
Full description |

Standard name | GO_TAURINE_METABOLIC_PROCESS
Systematic name | M22879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving taurine (2-aminoethanesulfonic acid), a sulphur-containing amino acid derivative important in the metabolism of fats. [GOC:jl, ISBN:0198600461]
Full description |

Standard name | GO_OXALATE_TRANSPORT
Systematic name | M14246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of oxalate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Oxalate, or ethanedioic acid, occurs in many plants and is highly toxic to animals. [ISBN:0198506732]
Full description |

Standard name | GO_SHORT_CHAIN_FATTY_ACID_CATABOLIC_PROCESS
Systematic name | M22880
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of fatty acids with a chain length of less than C6. [ISBN:0198506732]
Full description |

Standard name | GO_UREA_METABOLIC_PROCESS
Systematic name | M34115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving urea, the water soluble compound O=C-(NH2)2. [ISBN:0198506732]
Full description |

Standard name | GO_ORGANOPHOSPHATE_METABOLIC_PROCESS
Systematic name | M11372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving organophosphates, any phosphate-containing organic compound. [ISBN:0198506732]
Full description |

Standard name | GO_AEROBIC_ELECTRON_TRANSPORT_CHAIN
Systematic name | M22881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a series of electron carriers operate together to transfer electrons from donors such as NADH and FADH2 to oxygen to generate a transmembrane electrochemical gradient. [GOC:ai, GOC:mtg_electron_transport]
Full description |

Standard name | GO_GLYCOLYTIC_FERMENTATION
Systematic name | M29123
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Fermentation that includes the anaerobic conversion of glucose to pyruvate via the glycolytic pathway. [GOC:curators]
Full description |

Standard name | GO_GDP_MANNOSE_METABOLIC_PROCESS
Systematic name | M29124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving GDP-mannose, a substance composed of mannose in glycosidic linkage with guanosine diphosphate. [GOC:ai]
Full description |

Standard name | GO_NAD_METABOLIC_PROCESS
Systematic name | M11823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving nicotinamide adenine dinucleotide (NAD), a coenzyme present in most living cells and derived from the B vitamin nicotinic acid. [GOC:jl, ISBN:0618254153]
Full description |

Standard name | GO_GLYCERALDEHYDE_3_PHOSPHATE_METABOLIC_PROCESS
Systematic name | M29125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glyceraldehyde-3-phosphate, an important intermediate in glycolysis. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_RIBOSE_PHOSPHATE_METABOLIC_PROCESS
Systematic name | M29126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving ribose phosphate, any phosphorylated ribose sugar. [GOC:ai]
Full description |

Standard name | GO_CHOLINE_METABOLIC_PROCESS
Systematic name | M29127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving choline (2-hydroxyethyltrimethylammonium), an amino alcohol that occurs widely in living organisms as a constituent of certain types of phospholipids and in the neurotransmitter acetylcholine. [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_CALCIUM_MEDIATED_SIGNALING
Systematic name | M488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any intracellular signal transduction in which the signal is passed on within the cell via calcium ions. [GOC:signaling]
Full description |

Standard name | GO_B_CELL_MEDIATED_IMMUNITY
Systematic name | M12033
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved with the carrying out of an immune response by a B cell, through, for instance, the production of antibodies or cytokines, or antigen presentation to T cells. [GO_REF:0000022, GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_CELLULAR_HOMEOSTASIS
Systematic name | M5826
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state at the level of the cell. [GOC:isa_complete, GOC:jl, ISBN:0395825172]
Full description |

Standard name | GO_ANTIMICROBIAL_HUMORAL_RESPONSE
Systematic name | M10380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response against microbes mediated through a body fluid. Examples of this process are seen in the antimicrobial humoral response of Drosophila melanogaster and Mus musculus. [GOC:go_curators, GOC:mtg_sensu]
Full description |

Standard name | GO_ANTIBACTERIAL_HUMORAL_RESPONSE
Systematic name | M22882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response against bacteria mediated through a body fluid. Examples of this process are the antibacterial humoral responses in Mus musculus and Drosophila melanogaster. [GOC:go_curators, GOC:mtg_sensu]
Full description |

Standard name | GO_ANTIFUNGAL_HUMORAL_RESPONSE
Systematic name | M22883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response against a fungus mediated through a body fluid. An example of this process is the antifungal humoral response in Drosophila melanogaster. [GOC:go_curators, GOC:mtg_sensu]
Full description |

Standard name | GO_SECONDARY_METABOLIC_PROCESS
Systematic name | M3773
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in many of the chemical changes of compounds that are not necessarily required for growth and maintenance of cells, and are often unique to a taxon. In multicellular organisms secondary metabolism is generally carried out in specific cell types, and may be useful for the organism as a whole. In unicellular organisms, secondary metabolism is often used for the production of antibiotics or for the utilization and acquisition of unusual nutrients. [GOC:go_curators]
Full description |

Standard name | GO_POLYOL_METABOLIC_PROCESS
Systematic name | M11003
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a polyol, any alcohol containing three or more hydroxyl groups attached to saturated carbon atoms. [PMID:30240188]
Full description |

Standard name | GO_ONE_CARBON_COMPOUND_TRANSPORT
Systematic name | M12933
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of one-carbon compounds into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_PEPTIDE_CROSS_LINKING_VIA_CHONDROITIN_4_SULFATE_GLYCOSAMINOGLYCAN
Systematic name | M22885
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a cross-link between peptide chains mediated by a chondroitin 4-sulfate glycosaminoglycan that originates from a typical O-glycosidic link to serine of one chain; the other chain is esterified, via the alpha-carbon of its C-terminal Asp, to C-6 of an internal N-acetylgalactosamine of the glycosaminoglycan chain. [PMID:1898736, RESID:AA0219]
Full description |

Standard name | GO_CYTOLYSIS
Systematic name | M15834
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The rupture of cell membranes and the loss of cytoplasm. [UniProtKB-KW:KW-0204]
Full description |

Standard name | GO_L_ASCORBIC_ACID_METABOLIC_PROCESS
Systematic name | M12523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving L-ascorbic acid, (2R)-2-[(1S)-1,2-dihydroxyethyl]-4-hydroxy-5-oxo-2,5-dihydrofuran-3-olate; L-ascorbic acid is vitamin C and has co-factor and anti-oxidant activities in many species. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOBASE_BIOSYNTHETIC_PROCESS
Systematic name | M22886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of pyrimidine nucleobases, 1,3-diazine, organic nitrogenous bases. [GOC:go_curators]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION
Systematic name | M12794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses antigen (peptide or lipid) on its cell surface in association with an MHC protein complex. [GO_REF:0000022, GOC:add, ISBN:0781735149, PMID:15771591, PMID:15928678]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_ENDOGENOUS_ANTIGEN
Systematic name | M16324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses antigen (peptide or lipid) of endogenous origin on its cell surface in association with an MHC protein complex. [GOC:add, ISBN:0781735149, PMID:15771591, PMID:15928678]
Full description |

Standard name | GO_AXONAL_TRANSPORT_OF_MITOCHONDRION
Systematic name | M22887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of mitochondria along microtubules in nerve cell axons. [GOC:ai]
Full description |

Standard name | GO_LIPID_STORAGE
Systematic name | M15541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The accumulation and maintenance in cells or tissues of lipids, compounds soluble in organic solvents but insoluble or sparingly soluble in aqueous solvents. Lipid reserves can be accumulated during early developmental stages for mobilization and utilization at later stages of development. [GOC:dph, GOC:mah, GOC:tb, PMID:11102830]
Full description |

Standard name | GO_PEPTIDYL_ARGININE_METHYLATION_TO_ASYMMETRICAL_DIMETHYL_ARGININE
Systematic name | M34116
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of methylation of peptidyl-arginine to form peptidyl-N(omega),N(omega)-dimethyl-L-arginine. [RESID:AA0068, RESID:AA0069]
Full description |

Standard name | GO_SECOND_MESSENGER_MEDIATED_SIGNALING
Systematic name | M14872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any intracellular signal transduction in which the signal is passed on within the cell via a second messenger; a small molecule or ion that can be quickly generated or released from intracellular stores, and can diffuse within the cell. Second-messenger signaling includes production or release of the second messenger, and effectors downstream of the second messenger that further transmit the signal within the cell. [GOC:signaling, ISBN:0815316194, PMID:15221855, Wikipedia:Second_messenger_system]
Full description |

Standard name | GO_CGMP_MEDIATED_SIGNALING
Systematic name | M22889
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any intracellular signal transduction in which the signal is passed on within the cell via cyclic GMP (cGMP). Includes production of cGMP, and downstream effectors that further transmit the signal within the cell. [GOC:signaling]
Full description |

Standard name | GO_CYCLIC_NUCLEOTIDE_MEDIATED_SIGNALING
Systematic name | M19701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any intracellular signal transduction in which the signal is passed on within the cell via a cyclic nucleotide. Includes production or release of the cyclic nucleotide, and downstream effectors that further transmit the signal within the cell. [GOC:signaling]
Full description |

Standard name | GO_SEXUAL_REPRODUCTION
Systematic name | M12193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A reproduction process that creates a new organism by combining the genetic material of two gametes, which may come from two organisms or from a single organism, in the case of self-fertilizing hermaphrodites, e.g. C. elegans, or self-fertilization in plants. It occurs both in eukaryotes and prokaryotes: in multicellular eukaryotic organisms, an individual is created anew; in prokaryotes, the initial cell has additional or transformed genetic material. In a process called genetic recombination, genetic material (DNA) originating from two gametes join up so that homologous sequences are aligned with each other, and this is followed by exchange of genetic information. After the new recombinant chromosome is formed, it is passed on to progeny. [GOC:jl, GOC:kmv, GOC:krc, GOC:tb, ISBN:0387520546, Wikipedia:Sexual_reproduction]
Full description |

Standard name | GO_TRANSLESION_SYNTHESIS
Systematic name | M13848
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The replication of damaged DNA by synthesis across a lesion in the template strand; a specialized DNA polymerase or replication complex inserts a defined nucleotide across from the lesion which allows DNA synthesis to continue beyond the lesion. This process can be mutagenic depending on the damaged nucleotide and the inserted nucleotide. [GOC:elh, GOC:vw, PMID:10535901]
Full description |

Standard name | GO_HEMOGLOBIN_METABOLIC_PROCESS
Systematic name | M10121
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving hemoglobin, including its uptake and utilization. [GOC:go_curators, GOC:jl]
Full description |

Standard name | GO_SPINAL_CORD_DEVELOPMENT
Systematic name | M10048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the spinal cord over time, from its formation to the mature structure. The spinal cord primarily conducts sensory and motor nerve impulses between the brain and the peripheral nervous tissues. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_SPINAL_CORD_PATTERNING
Systematic name | M13455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process that regulates the coordinated growth and establishes the non-random spatial arrangement of the spinal cord. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_VENTRAL_SPINAL_CORD_INTERNEURON_DIFFERENTIATION
Systematic name | M13534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which neuroepithelial cells in the neural tube acquire specialized structural and/or functional features of ventral spinal cord interneurons. Ventral spinal cord interneurons are cells located in the ventral portion of the spinal cord that transmit signals between sensory and motor neurons and are required for reflexive responses. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:11262869]
Full description |

Standard name | GO_CELL_DIFFERENTIATION_IN_SPINAL_CORD
Systematic name | M11744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features that characterize the cells of the spinal cord. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:11262869]
Full description |

Standard name | GO_DORSAL_SPINAL_CORD_DEVELOPMENT
Systematic name | M15849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the dorsal region of the spinal cord over time, from its formation to the mature structure. The dorsal region of the mature spinal cord contains neurons that process and relay sensory input. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:11179871]
Full description |

Standard name | GO_VENTRAL_SPINAL_CORD_DEVELOPMENT
Systematic name | M12078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the ventral region of the spinal cord over time, from its formation to the mature structure. The neurons of the ventral region of the mature spinal cord participate in motor output. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_SPINAL_CORD_MOTOR_NEURON_CELL_FATE_SPECIFICATION
Systematic name | M12366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a cell becomes capable of differentiating autonomously into a motor neuron in an environment that is neutral with respect to the developmental pathway. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_SPINAL_CORD_MOTOR_NEURON_DIFFERENTIATION
Systematic name | M11842
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which neuroepithelial cells in the ventral neural tube acquire specialized structural and/or functional features of motor neurons. Motor neurons innervate an effector (muscle or glandular) tissue and are responsible for transmission of motor impulses from the brain to the periphery. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:11262869]
Full description |

Standard name | GO_SOMATIC_MOTOR_NEURON_DIFFERENTIATION
Systematic name | M22890
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which neuroepithelial cells in the neural tube acquire specialized structural and/or functional features of somatic motor neurons. Somatic motor neurons innervate skeletal muscle targets and are responsible for transmission of motor impulses from the brain to the periphery. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:11262869]
Full description |

Standard name | GO_SPINAL_CORD_ASSOCIATION_NEURON_DIFFERENTIATION
Systematic name | M14634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which neuroepithelial cells in the neural tube acquire specialized structural and/or functional features of association neurons. Association neurons are cells located in the dorsal portion of the spinal cord that integrate sensory input. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:11262869]
Full description |

Standard name | GO_SPINAL_CORD_OLIGODENDROCYTE_CELL_DIFFERENTIATION
Systematic name | M34117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which neuroepithelial cells in the neural tube acquire specialized structural and/or functional features of oligodendrocytes. Oligodendrocytes are non-neuronal cells. The primary function of oligodendrocytes is the myelination of nerve axons in the central nervous system. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_NEURAL_TUBE_PATTERNING
Systematic name | M16543
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process that regulates the coordinated growth that establishes the non-random spatial arrangement of the neural tube. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CELL_DIFFERENTIATION_IN_HINDBRAIN
Systematic name | M13307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features that characterize the mature cells of the hindbrain. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CELL_PROLIFERATION_IN_HINDBRAIN
Systematic name | M22891
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of cells, resulting in the expansion of a cell population in the hindbrain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CELL_MIGRATION_IN_HINDBRAIN
Systematic name | M14895
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a cell that will reside in the hindbrain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_DIENCEPHALON_DEVELOPMENT
Systematic name | M14556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the diencephalon over time, from its formation to the mature structure. The diencephalon is the paired caudal parts of the prosencephalon from which the thalamus, hypothalamus, epithalamus and subthalamus are derived; these regions regulate autonomic, visceral and endocrine function, and process information directed to the cerebral cortex. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_TELENCEPHALON_DEVELOPMENT
Systematic name | M15958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the telencephalon over time, from its formation to the mature structure. The telencephalon is the paired anteriolateral division of the prosencephalon plus the lamina terminalis from which the olfactory lobes, cerebral cortex, and subcortical nuclei are derived. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_CORPUS_CALLOSUM_MORPHOGENESIS
Systematic name | M22892
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the corpus callosum are generated and organized. The corpus callosum is a thick bundle of nerve fibers comprising a commissural plate connecting the two cerebral hemispheres. It consists of contralateral axon projections that provides communications between the right and left cerebral hemispheres. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_DENTATE_GYRUS_DEVELOPMENT
Systematic name | M10141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the dentate gyrus over time, from its formation to the mature structure. The dentate gyrus is one of two interlocking gyri of the hippocampus. It contains granule cells, which project to the pyramidal cells and interneurons of the CA3 region of the ammon gyrus. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_PALLIUM_DEVELOPMENT
Systematic name | M13343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the pallium over time, from its formation to the mature structure. The pallium is the roof region of the telencephalon. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_SUBPALLIUM_DEVELOPMENT
Systematic name | M16379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the subpallium over time, from its formation to the mature structure. The subpallium is the base region of the telencephalon. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_CRANIAL_NERVE_DEVELOPMENT
Systematic name | M11618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the cranial nerves over time, from its formation to the mature structure. The cranial nerves are composed of twelve pairs of nerves that emanate from the nervous tissue of the hindbrain. These nerves are sensory, motor, or mixed in nature, and provide the motor and general sensory innervation of the head, neck and viscera. They mediate vision, hearing, olfaction and taste and carry the parasympathetic innervation of the autonomic ganglia that control visceral functions. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_RHOMBOMERE_DEVELOPMENT
Systematic name | M22893
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the rhombomere over time, from its formation to the mature structure. Rhombomeres are transverse segments of the developing rhombencephalon. Rhombomeres are lineage restricted, express different genes from one another, and adopt different developmental fates. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_PONS_DEVELOPMENT
Systematic name | M12684
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the pons over time, from its formation to the mature structure. The pons lies above the medulla and next to the cerebellum. The pons conveys information about movement from the cerebral hemisphere to the cerebellum. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_OPTIC_NERVE_DEVELOPMENT
Systematic name | M13111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the optic nerve over time, from its formation to the mature structure. The sensory optic nerve originates from the bipolar cells of the retina and conducts visual information to the brainstem. The optic nerve exits the back of the eye in the orbit, enters the optic canal, and enters the central nervous system at the optic chiasm (crossing) where the nerve fibers become the optic tract just prior to entering the hindbrain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_TRIGEMINAL_NERVE_DEVELOPMENT
Systematic name | M22894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the trigeminal nerve over time, from its formation to the mature structure. The trigeminal nerve is composed of three large branches. They are the ophthalmic (V1, sensory), maxillary (V2, sensory) and mandibular (V3, motor and sensory) branches. The sensory ophthalmic branch travels through the superior orbital fissure and passes through the orbit to reach the skin of the forehead and top of the head. The maxillary nerve contains sensory branches that reach the pterygopalatine fossa via the inferior orbital fissure (face, cheek and upper teeth) and pterygopalatine canal (soft and hard palate, nasal cavity and pharynx). The motor part of the mandibular branch is distributed to the muscles of mastication, the mylohyoid muscle and the anterior belly of the digastric. The mandibular nerve also innervates the tensor veli palatini and tensor tympani muscles. The sensory part of the mandibular nerve is composed of branches that carry general sensory information from the mucous membranes of the mouth and cheek, anterior two-thirds of the tongue, lower teeth, skin of the lower jaw, side of the head and scalp and meninges of the anterior and middle cranial fossae. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_VESTIBULOCOCHLEAR_NERVE_DEVELOPMENT
Systematic name | M22895
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the vestibulocochlear nerve over time, from its formation to the mature structure. This sensory nerve innervates the membranous labyrinth of the inner ear. The vestibular branch innervates the vestibular apparatus that senses head position changes relative to gravity. The auditory branch innervates the cochlear duct, which is connected to the three bony ossicles which transduce sound waves into fluid movement in the cochlea. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_GLOSSOPHARYNGEAL_NERVE_DEVELOPMENT
Systematic name | M22896
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Various sensory and motor branches of the glossopharyngeal nerve supply nerve connections to the pharynx and back of the tongue. The branchial motor component contains motor fibers that innervate muscles that elevate the pharynx and larynx, and the tympanic branch supplies parasympathetic fibers to the otic ganglion. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_HINDBRAIN_MORPHOGENESIS
Systematic name | M14739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the hindbrain is generated and organized. The hindbrain is the region consisting of the medulla, pons and cerebellum. Areas of the hindbrain control motor and autonomic functions. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_VENTRICULAR_SYSTEM_DEVELOPMENT
Systematic name | M11577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the brain ventricular system over time, from its formation to the mature structure. The brain ventricular system consists of four communicating cavities within the brain that are continuous with the central canal of the spinal cord. These cavities include two lateral ventricles, the third ventricle and the fourth ventricle. Cerebrospinal fluid fills the ventricles and is produced by the choroid plexus. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CRANIAL_NERVE_MORPHOGENESIS
Systematic name | M11378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the cranial nerves are generated and organized. The cranial nerves are composed of twelve pairs of nerves that emanate from the nervous tissue of the hindbrain. These nerves are sensory, motor, or mixed in nature, and provide the motor and general sensory innervation of the head, neck and viscera. They mediate vision, hearing, olfaction and taste and carry the parasympathetic innervation of the autonomic ganglia that control visceral functions. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CRANIAL_NERVE_FORMATION
Systematic name | M22897
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that gives rise to the cranial nerves. This process pertains to the initial formation of a structure from unspecified parts. The cranial nerves are composed of twelve pairs of nerves that emanate from the nervous tissue of the hindbrain. These nerves are sensory, motor, or mixed in nature, and provide the motor and general sensory innervation of the head, neck and viscera. They mediate vision, hearing, olfaction and taste and carry the parasympathetic innervation of the autonomic ganglia that control visceral functions. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CRANIAL_NERVE_STRUCTURAL_ORGANIZATION
Systematic name | M22898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that contributes to the act of creating the structural organization of the cranial nerves. This process pertains to the physical shaping of a rudimentary structure. The cranial nerves are composed of twelve pairs of nerves that emanate from the nervous tissue of the hindbrain. These nerves are sensory, motor, or mixed in nature, and provide the motor and general sensory innervation of the head, neck and viscera. They mediate vision, hearing, olfaction and taste and carry the parasympathetic innervation of the autonomic ganglia that control visceral functions. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_FACIAL_NERVE_MORPHOGENESIS
Systematic name | M22899
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the facial nerve is generated and organized. This sensory and motor nerve supplies the muscles of facial expression and the expression and taste at the anterior two-thirds of the tongue. The principal branches are the superficial opthalmic, buccal, palatine and hyomandibular. The main trunk synapses within pterygopalatine ganglion in the parotid gland and this ganglion then gives of nerve branches which supply the lacrimal gland and the mucous secreting glands of the nasal and oral cavities. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_FACIAL_NERVE_STRUCTURAL_ORGANIZATION
Systematic name | M22900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that contributes to the act of creating the structural organization of the facial nerve. This process pertains to the physical shaping of a rudimentary structure. This sensory and motor nerve supplies the muscles of facial expression and the expression and taste at the anterior two-thirds of the tongue. The principal branches are the superficial opthalmic, buccal, palatine and hyomandibular. The main trunk synapses within pterygopalatine ganglion in the parotid gland and this ganglion then gives of nerve branches which supply the lacrimal gland and the mucous secreting glands of the nasal and oral cavities. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CENTRAL_NERVOUS_SYSTEM_MATURATION
Systematic name | M22901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for the central nervous system to attain its fully functional state. The central nervous system is the core nervous system that serves an integrating and coordinating function. In vertebrates it consists of the brain and spinal cord. In those invertebrates with a central nervous system it typically consists of a brain, cerebral ganglia and a nerve cord. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0582227089]
Full description |

Standard name | GO_OPTIC_NERVE_MORPHOGENESIS
Systematic name | M22902
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the optic nerve is generated and organized. The sensory optic nerve originates from the bipolar cells of the retina and conducts visual information to the brainstem. The optic nerve exits the back of the eye in the orbit, enters the optic canal, and enters the central nervous system at the optic chiasm (crossing) where the nerve fibers become the optic tract just prior to entering the hindbrain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_TRIGEMINAL_NERVE_MORPHOGENESIS
Systematic name | M22903
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the trigeminal nerve is generated and organized. The trigeminal nerve is composed of three large branches. They are the ophthalmic (V1, sensory), maxillary (V2, sensory) and mandibular (V3, motor and sensory) branches. The sensory ophthalmic branch travels through the superior orbital fissure and passes through the orbit to reach the skin of the forehead and top of the head. The maxillary nerve contains sensory branches that reach the pterygopalatine fossa via the inferior orbital fissure (face, cheek and upper teeth) and pterygopalatine canal (soft and hard palate, nasal cavity and pharynx). The motor part of the mandibular branch is distributed to the muscles of mastication, the mylohyoid muscle and the anterior belly of the digastric. The mandibular nerve also innervates the tensor veli palatini and tensor tympani muscles. The sensory part of the mandibular nerve is composed of branches that carry general sensory information from the mucous membranes of the mouth and cheek, anterior two-thirds of the tongue, lower teeth, skin of the lower jaw, side of the head and scalp and meninges of the anterior and middle cranial fossae. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_VESTIBULOCOCHLEAR_NERVE_MORPHOGENESIS
Systematic name | M22904
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the vestibulocochlear nerve is generated and organized. This sensory nerve innervates the membranous labyrinth of the inner ear. The vestibular branch innervates the vestibular apparatus that senses head position changes relative to gravity. The auditory branch innervates the cochlear duct, which is connected to the three bony ossicles which transduce sound waves into fluid movement in the cochlea. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_VESTIBULOCOCHLEAR_NERVE_FORMATION
Systematic name | M29128
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that gives rise to the vestibulocochlear nerve. This process pertains to the initial formation of a structure from unspecified parts. This sensory nerve innervates the membranous labyrinth of the inner ear. The vestibular branch innervates the vestibular apparatus that senses head position changes relative to gravity. The auditory branch innervates the cochlear duct, which is connected to the three bony ossicles which transduce sound waves into fluid movement in the cochlea. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_LATERAL_VENTRICLE_DEVELOPMENT
Systematic name | M14885
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the lateral ventricles over time, from the formation to the mature structure. The two lateral ventricles are a cavity in each of the cerebral hemispheres derived from the cavity of the embryonic neural tube. They are separated from each other by the septum pellucidum, and each communicates with the third ventricle by the foramen of Monro, through which also the choroid plexuses of the lateral ventricles become continuous with that of the third ventricle. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_NERVE_DEVELOPMENT
Systematic name | M13527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a nerve over time, from its formation to the mature structure. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_THIRD_VENTRICLE_DEVELOPMENT
Systematic name | M34118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the third ventricle over time, from its formation to the mature structure. The third ventricle is the narrow cleft inferior to the corpus callosum, within the diencephalon, between the paired thalami. Its floor is formed by the hypothalamus, its anterior wall by the lamina terminalis, and its roof by ependyma, and it communicates with the fourth ventricle by the cerebral aqueduct, and with the lateral ventricles by the interventricular foramina. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CEREBELLAR_PURKINJE_CELL_LAYER_DEVELOPMENT
Systematic name | M16365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the cerebellar Purkinje cell layer over time, from its formation to the mature structure. The Purkinje cell layer lies just underneath the molecular layer of the cerebellar cortex. It contains the neuronal cell bodies of the Purkinje cells that are arranged side by side in a single layer. Candelabrum interneurons are vertically oriented between the Purkinje cells. Purkinje neurons are inhibitory and provide the output of the cerebellar cortex through axons that project into the white matter. Extensive dendritic trees from the Purkinje cells extend upward in a single plane into the molecular layer where they synapse with parallel fibers of granule cells. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CEREBELLAR_GRANULAR_LAYER_DEVELOPMENT
Systematic name | M12526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the cerebellar granule layer over time, from its formation to the mature structure. The granular layer is the innermost layer of the cerebellar cortex. This layer contains densely packed small neurons, mostly granule cells. Some Golgi cells are found at the outer border. Granule neurons send parallel fibers to the upper molecular layer, where they synapse with Purkinje cell dendrites. Mossy fibers from the pontine nuclei in the white matter synapse with granule cell axons, Golgi cell axons and unipolar brush interneuron axons at cerebellar glomeruli in the granule cell layer. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CEREBELLAR_GRANULAR_LAYER_MORPHOGENESIS
Systematic name | M22905
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the cerebellar granular layer is generated and organized. The granular layer is the innermost layer of the cerebellar cortex. This layer contains densely packed small neurons, mostly granule cells. Some Golgi cells are found at the outer border. Granule neurons send parallel fibers to the upper molecular layer, where they synapse with Purkinje cell dendrites. Mossy fibers from the pontine nuclei in the white matter synapse with granule cell axons, Golgi cell axons and unipolar brush interneuron axons at cerebellar glomeruli in the granule cell layer. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CEREBELLAR_GRANULAR_LAYER_FORMATION
Systematic name | M22906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that gives rise to the cerebellar granule layer. This process pertains to the initial formation of a structure from unspecified parts. The granular layer is the innermost layer of the cerebellar cortex. This layer contains densely packed small neurons, mostly granule cells. Some Golgi cells are found at the outer border. Granule neurons send parallel fibers to the upper molecular layer, where they synapse with Purkinje cell dendrites. Mossy fibers from the pontine nuclei in the white matter synapse with granule cell axons, Golgi cell axons and unipolar brush interneuron axons at cerebellar glomeruli in the granule cell layer. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CEREBELLAR_PURKINJE_CELL_LAYER_MORPHOGENESIS
Systematic name | M15961
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the cerebellar Purkinje cell layer is generated and organized. The Purkinje cell layer lies just underneath the molecular layer of the cerebellar cortex. It contains the neuronal cell bodies of the Purkinje cells that are arranged side by side in a single layer. Candelabrum interneurons are vertically oriented between the Purkinje cells. Purkinje neurons are inhibitory and provide the output of the cerebellar cortex through axons that project into the white matter. Extensive dendritic trees from the Purkinje cells extend upward in a single plane into the molecular layer where they synapse with parallel fibers of granule cells. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CEREBELLAR_PURKINJE_CELL_LAYER_FORMATION
Systematic name | M11027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that gives rise to the cerebellar Purkinje cell layer. This process pertains to the initial formation of a structure from unspecified parts. The Purkinje cell layer lies just underneath the molecular layer of the cerebellar cortex. It contains the neuronal cell bodies of the Purkinje cells that are arranged side by side in a single layer. Candelabrum interneurons are vertically oriented between the Purkinje cells. Purkinje neurons are inhibitory and provide the output of the cerebellar cortex through axons that project into the white matter. Extensive dendritic trees from the Purkinje cells extend upward in a single plane into the molecular layer where they synapse with parallel fibers of granule cells. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CEREBELLAR_CORTEX_DEVELOPMENT
Systematic name | M12585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the cerebellar cortex over time, from its formation to the mature structure. The cerebellar cortex is a thin mantle of gray matter that covers the surface of each cerebral hemisphere. It has a characteristic morphology with convolutions (gyri) and crevices (sulci) that have specific functions. Six layers of nerve cells and the nerve pathways that connect them comprise the cerebellar cortex. Together, these regions are responsible for the processes of conscious thought, perception, emotion and memory as well as advanced motor function. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CEREBELLAR_CORTEX_MORPHOGENESIS
Systematic name | M11224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the cranial nerves are generated and organized. The cerebellar cortex is a thin mantle of gray matter that covers the surface of each cerebral hemisphere. It has a characteristic morphology with convolutions (gyri) and crevices (sulci) that have specific functions. Six layers of nerve cells and the nerve pathways that connect them comprise the cerebellar cortex. Together, these regions are responsible for the processes of conscious thought, perception, emotion and memory as well as advanced motor function. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_CEREBELLAR_CORTEX_FORMATION
Systematic name | M15386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that gives rise to the cerebellar cortex. This process pertains to the initial formation of a structure from unspecified parts. The cerebellar cortex is a thin mantle of gray matter that covers the surface of each cerebral hemisphere. It has a characteristic morphology with convolutions (gyri) and crevices (sulci) that have specific functions. Six layers of nerve cells and the nerve pathways that connect them comprise the cerebellar cortex. Together, these regions are responsible for the processes of conscious thought, perception, emotion and memory as well as advanced motor function. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343]
Full description |

Standard name | GO_DEVELOPMENTAL_MATURATION
Systematic name | M3318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for an anatomical structure, cell or cellular component to attain its fully functional state. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_STRIATUM_DEVELOPMENT
Systematic name | M15431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the striatum over time from its initial formation until its mature state. The striatum is a region of the forebrain consisting of the caudate nucleus, putamen and fundus striati. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0878937420]
Full description |

Standard name | GO_LIMBIC_SYSTEM_DEVELOPMENT
Systematic name | M16247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the limbic system over time from its initial formation until its mature state. The limbic system is a collection of structures in the brain involved in emotion, motivation and emotional aspects of memory. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0878937420]
Full description |

Standard name | GO_SUBSTANTIA_NIGRA_DEVELOPMENT
Systematic name | M13060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the substantia nigra over time from its initial formation until its mature state. The substantia nigra is the layer of gray substance that separates the posterior parts of the cerebral peduncles (tegmentum mesencephali) from the anterior parts; it normally includes a posterior compact part with many pigmented cells (pars compacta) and an anterior reticular part whose cells contain little pigment (pars reticularis). [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0838580343, ISBN:0878937420]
Full description |

Standard name | GO_AMYGDALA_DEVELOPMENT
Systematic name | M34119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the amygdala over time from its initial formation until its mature state. The amygdala is an almond-shaped set of neurons in the medial temporal lobe of the brain that play a key role in processing emotions such as fear and pleasure. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0878937420]
Full description |

Standard name | GO_HIPPOCAMPUS_DEVELOPMENT
Systematic name | M12672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the hippocampus over time from its initial formation until its mature state. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0878937420, UBERON:0002421]
Full description |

Standard name | GO_GLIAL_CELL_FATE_SPECIFICATION
Systematic name | M22907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a cell becomes capable of differentiating autonomously into a glial cell in an environment that is neutral with respect to the developmental pathway. Upon specification, the cell fate can be reversed. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_GLIAL_CELL_FATE_COMMITMENT
Systematic name | M14935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the developmental fate of a cell becomes restricted such that it will develop into a glial cell. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_GLIAL_CELL_DEVELOPMENT
Systematic name | M11130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process aimed at the progression of a glial cell over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_BRANCHIOMOTOR_NEURON_AXON_GUIDANCE
Systematic name | M22908
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a branchiomotor neuron growth cone is directed to a specific target site. Branchiomotor neurons are located in the hindbrain and innervate branchial arch-derived muscles that control jaw movements, facial expression, the larynx, and the pharynx. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:14699587]
Full description |

Standard name | GO_THALAMUS_DEVELOPMENT
Systematic name | M14842
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the thalamus changes over time, from its initial formation to its mature state. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CEREBRAL_CORTEX_CELL_MIGRATION
Systematic name | M15506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of cells from one site to another in the cerebral cortex. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CEREBRAL_CORTEX_REGIONALIZATION
Systematic name | M22909
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process that results in the creation of areas within the cerebral cortex that will direct the behavior of cell migration and differentiation as the cortex develops. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_FOREBRAIN_DORSAL_VENTRAL_PATTERN_FORMATION
Systematic name | M22910
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of specific regional progenitor domains along the dorsal-ventral axis in the developing forebrain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CEREBRAL_CORTEX_RADIALLY_ORIENTED_CELL_MIGRATION
Systematic name | M15776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The migration of cells in the developing cerebral cortex in which cells move from the ventricular and/or subventricular zone toward the surface of the brain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_CEREBRAL_CORTEX_TANGENTIAL_MIGRATION
Systematic name | M22911
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The migration of cells in the cerebral cortex in which cells move orthogonally to the direction of radial migration and do not use radial glial cell processes as substrates for migration. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_CELL_MOTILITY_INVOLVED_IN_CEREBRAL_CORTEX_RADIAL_GLIA_GUIDED_MIGRATION
Systematic name | M22912
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a cell along the process of a radial glial cell involved in cerebral cortex glial-mediated radial migration. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_MODULATION_OF_MICROTUBULE_CYTOSKELETON_INVOLVED_IN_CEREBRAL_CORTEX_RADIAL_GLIA_GUIDED_MIGRATION
Systematic name | M22913
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Rearrangements of the microtubule cytoskeleton that contribute to the movement of cells along radial glial cells as a component of the process of cerebral cortex glial-mediated radial migration. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_LAYER_FORMATION_IN_CEREBRAL_CORTEX
Systematic name | M11199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The detachment of cells from radial glial fibers at the appropriate time when they cease to migrate and form distinct layer in the cerebral cortex. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_SUBSTRATE_INDEPENDENT_TELENCEPHALIC_TANGENTIAL_MIGRATION
Systematic name | M12613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process where neuronal precursors migrate tangentially in the telencephalon, primarily guided by interactions that do not require cell-cell contact. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_CELL_PROLIFERATION_IN_FOREBRAIN
Systematic name | M11623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The creation of greater cell numbers in the forebrain due to cell division of progenitor cells. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_HYPOTHALAMUS_DEVELOPMENT
Systematic name | M12165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the hypothalamus region of the forebrain, from its initial formation to its mature state. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_PYRAMIDAL_NEURON_DIFFERENTIATION
Systematic name | M22915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a neuroblast or one of its progeny commits to a pyramidal neuron fate, migrates from the ventricular zone to the appropriate layer in the cortex and develops into a mature neuron. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_FOREBRAIN_RADIAL_GLIAL_CELL_DIFFERENTIATION
Systematic name | M22916
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which neuroepithelial cells of the neural tube give rise to radial glial cells, specialized bipotential progenitors cells of the forebrain. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:16226447]
Full description |

Standard name | GO_FOREBRAIN_VENTRICULAR_ZONE_PROGENITOR_CELL_DIVISION
Systematic name | M22917
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The mitotic division of a basal progenitor giving rise to two neurons. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:16226447]
Full description |

Standard name | GO_FOREBRAIN_REGIONALIZATION
Systematic name | M11910
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process resulting in the creation of areas within the forebrain that will direct the behavior of cell migration in differentiation as the forebrain develops. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:isa_complete, GOC:jid, PMID:16226447]
Full description |

Standard name | GO_FOREBRAIN_GENERATION_OF_NEURONS
Systematic name | M11912
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which nerve cells are generated in the forebrain. This includes the production of neuroblasts from and their differentiation into neurons. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_FOREBRAIN_NEUROBLAST_DIVISION
Systematic name | M22918
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The division of a neuroblast located in the forebrain. Neuroblast division gives rise to at least another neuroblast. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_FOREBRAIN_NEURON_FATE_COMMITMENT
Systematic name | M15633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the developmental fate of a cell becomes restricted such that it will develop into a neuron that resides in the forebrain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:16226447]
Full description |

Standard name | GO_FOREBRAIN_NEURON_DIFFERENTIATION
Systematic name | M22919
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a neuron that will reside in the forebrain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:16226447]
Full description |

Standard name | GO_FOREBRAIN_NEURON_DEVELOPMENT
Systematic name | M10074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a neuron that resides in the forebrain, from its initial commitment to its fate, to the fully functional differentiated cell. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_FOREBRAIN_CELL_MIGRATION
Systematic name | M11998
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a cell from one site to another at least one of which is located in the forebrain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_OLFACTORY_BULB_INTERNEURON_DIFFERENTIATION
Systematic name | M10208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a neuroblast acquires specialized features of an interneuron residing in the olfactory bulb. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_OLFACTORY_BULB_INTERNEURON_DEVELOPMENT
Systematic name | M16106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an interneuron residing in the olfactory bulb, from its initial commitment, to the fully functional differentiated cell. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_CEREBRAL_CORTEX_GABAERGIC_INTERNEURON_DIFFERENTIATION
Systematic name | M13737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a GABAergic interneuron residing in the cerebral cortex. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_CEREBRAL_CORTEX_GABAERGIC_INTERNEURON_DEVELOPMENT
Systematic name | M22920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a cerebral cortex GABAergic interneuron over time, from initial commitment to its fate, to the fully functional differentiated cell. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:12626695]
Full description |

Standard name | GO_CEREBRAL_CORTEX_NEURON_DIFFERENTIATION
Systematic name | M12325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a neuron residing in the cerebral cortex. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_COMMITMENT_OF_NEURONAL_CELL_TO_SPECIFIC_NEURON_TYPE_IN_FOREBRAIN
Systematic name | M22921
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The commitment of neuronal precursor cells to become specialized types of neurons in the forebrain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:16226447]
Full description |

Standard name | GO_ROSTROCAUDAL_NEURAL_TUBE_PATTERNING
Systematic name | M12735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the neural tube is divided into specific regions along the rostrocaudal axis. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:11262869]
Full description |

Standard name | GO_DORSAL_VENTRAL_NEURAL_TUBE_PATTERNING
Systematic name | M13873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the neural tube is regionalized in the dorsoventral axis. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:11262869]
Full description |

Standard name | GO_SMOOTHENED_SIGNALING_PATHWAY_INVOLVED_IN_VENTRAL_SPINAL_CORD_PATTERNING
Systematic name | M22922
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of activation of the transmembrane protein Smoothened that results in the spatial identity of regions along the dorsal-ventral axis of the spinal cord. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, GOC:tb, PMID:11262869]
Full description |

Standard name | GO_NEURAL_TUBE_DEVELOPMENT
Systematic name | M11393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the neural tube over time, from its formation to the mature structure. The mature structure of the neural tube exists when the tube has been segmented into the forebrain, midbrain, hindbrain and spinal cord regions. In addition neural crest has budded away from the epithelium. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_HINDBRAIN_RADIAL_GLIA_GUIDED_CELL_MIGRATION
Systematic name | M22923
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The radially directed movement of a cell along radial glial cells in the hindbrain. Radial migration refers to a directed movement from the internal ventricular area to the outer surface of the hindbrain. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:15157725]
Full description |

Standard name | GO_REGULATION_OF_CEREBELLAR_GRANULE_CELL_PRECURSOR_PROLIFERATION
Systematic name | M22924
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that modulates the frequency, rate or extent of granule cell precursor proliferation. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:15157725]
Full description |

Standard name | GO_CEREBELLAR_PURKINJE_CELL_GRANULE_CELL_PRECURSOR_CELL_SIGNALING_INVOLVED_IN_REGULATION_OF_GRANULE_CELL_PRECURSOR_CELL_PROLIFERATION
Systematic name | M22925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that mediates the transfer of information from Purkinje cells to granule cell precursors resulting in an increase in rate of granule cell precursor cell proliferation. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:15157725]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CEREBELLAR_GRANULE_CELL_PRECURSOR_PROLIFERATION
Systematic name | M22926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that activates or increases the rate or extent of granule cell precursor proliferation. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:15157725]
Full description |

Standard name | GO_CENTRAL_NERVOUS_SYSTEM_PROJECTION_NEURON_AXONOGENESIS
Systematic name | M13810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Generation of a long process of a CNS neuron, that carries efferent (outgoing) action potentials from the cell body towards target cells in a different central nervous system region. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CENTRAL_NERVOUS_SYSTEM_NEURON_DIFFERENTIATION
Systematic name | M13421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a neuron whose cell body resides in the central nervous system. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CENTRAL_NERVOUS_SYSTEM_NEURON_DEVELOPMENT
Systematic name | M15685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a neuron whose cell body is located in the central nervous system, from initial commitment of the cell to a neuronal fate, to the fully functional differentiated neuron. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CENTRAL_NERVOUS_SYSTEM_NEURON_AXONOGENESIS
Systematic name | M16736
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Generation of a long process from a neuron whose cell body resides in the central nervous system. The process carries efferent (outgoing) action potentials from the cell body towards target cells. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CORTICOSPINAL_TRACT_MORPHOGENESIS
Systematic name | M22928
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Generation of a long process of a pyramidal cell, that carries efferent (outgoing) action potentials from the cell body in cerebral cortex layer V towards target cells in the gray matter of the spinal cord. This axonal process is a member of those that make up the corticospinal tract. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, PMID:9878731]
Full description |

Standard name | GO_ANTERIOR_COMMISSURE_MORPHOGENESIS
Systematic name | M22929
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Generation of a long process of a CNS neuron, that carries efferent (outgoing) action potentials from the cell body in one half of the cerebral cortex towards target cells in the contralateral half. This axonal process is a member of those that make up the anterior commissure, a small midline fiber tract that lies at the anterior end of the corpus callosum. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, ISBN:0878937420]
Full description |

Standard name | GO_TELENCEPHALON_REGIONALIZATION
Systematic name | M15512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process that creates areas within the forebrain that will direct the behavior of cell migration in differentiation as the telencephalon develops. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, GOC:mgi_curators]
Full description |

Standard name | GO_HYPOTHALAMUS_CELL_DIFFERENTIATION
Systematic name | M22930
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The differentiation of cells that will contribute to the structure and function of the hypothalamus. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid, GOC:mgi_curators]
Full description |

Standard name | GO_PITUITARY_GLAND_DEVELOPMENT
Systematic name | M11324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the pituitary gland over time from its initial formation until its mature state. The pituitary gland is an endocrine gland that secretes hormones that regulate many other glands. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_ADENOHYPOPHYSIS_DEVELOPMENT
Systematic name | M15797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the adenohypophysis over time from its initial formation until its mature state. The adenohypophysis is the anterior part of the pituitary. It secretes a variety of hormones and its function is regulated by the hypothalamus. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CEREBRAL_CORTEX_DEVELOPMENT
Systematic name | M12873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the cerebral cortex over time from its initial formation until its mature state. The cerebral cortex is the outer layered region of the telencephalon. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_OLFACTORY_LOBE_DEVELOPMENT
Systematic name | M14319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the olfactory lobe over time from its initial formation until its mature state. The olfactory lobe is the area of the brain that process the neural inputs for the sense of smell. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_NEURAL_PLATE_ANTERIOR_POSTERIOR_REGIONALIZATION
Systematic name | M22931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that regulates the coordinated growth and differentiation that establishes the non-random anterior-posterior spatial arrangement of the neural plate. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_NEUROGENESIS
Systematic name | M11351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Generation of cells within the nervous system. [GO_REF:0000021, GOC:cls, GOC:curators, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_INTERKINETIC_NUCLEAR_MIGRATION
Systematic name | M22932
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of the nucleus of the ventricular zone cell between the apical and the basal zone surfaces. Mitosis occurs when the nucleus is near the apical surface, that is, the lumen of the ventricle. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_TANGENTIAL_MIGRATION_FROM_THE_SUBVENTRICULAR_ZONE_TO_THE_OLFACTORY_BULB
Systematic name | M22933
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The migration of cells in the telencephalon from the subventricular zone to the olfactory bulb in which cells move orthogonally to the direction of radial migration and do not use radial glial cell processes as substrates for migration. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_TELENCEPHALON_GLIAL_CELL_MIGRATION
Systematic name | M12797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of glial cells through the telencephalon. [GO_REF:0000021, GOC:cls, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_METENCEPHALON_DEVELOPMENT
Systematic name | M10347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the metencephalon over time, from its formation to the mature structure. [GO_REF:0000021, GOC:cls, GOC:curators, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CORPUS_CALLOSUM_DEVELOPMENT
Systematic name | M16907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the corpus callosum over time, from its formation to the mature structure. The corpus callosum is a thick bundle of nerve fibers comprising a commissural plate connecting the two cerebral hemispheres. It consists of contralateral axon projections that provide communication between the right and left cerebral hemispheres. [GO_REF:0000021, GOC:cls, GOC:curators, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_CELL_CYCLE_PROCESS
Systematic name | M17773
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular process that ensures successive accurate and complete genome replication and chromosome segregation. [GOC:isa_complete, GOC:mtg_cell_cycle]
Full description |

Standard name | GO_MEMBRANE_DOCKING
Systematic name | M11875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial attachment of a membrane or protein to a target membrane. Docking requires only that the proteins come close enough to interact and adhere. [GOC:isa_complete, PMID:27875684]
Full description |

Standard name | GO_REGULATION_OF_CELL_CELL_ADHESION
Systematic name | M6401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of attachment of a cell to another cell. [GOC:isa_complete]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_CELL_ADHESION
Systematic name | M11239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of cell adhesion to another cell. [GOC:isa_complete]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_CELL_ADHESION
Systematic name | M14725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of cell adhesion to another cell. [GOC:isa_complete]
Full description |

Standard name | GO_CELLULAR_COMPONENT_DISASSEMBLY
Systematic name | M4053
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the breakdown of a cellular component. [GOC:isa_complete]
Full description |

Standard name | GO_CELLULAR_PROCESS_INVOLVED_IN_REPRODUCTION_IN_MULTICELLULAR_ORGANISM
Systematic name | M13832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process, occurring at the cellular level, that is involved in the reproductive function of a multicellular organism. [GOC:isa_complete]
Full description |

Standard name | GO_PROTEIN_MATURATION_BY_PROTEIN_FOLDING
Systematic name | M22935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of assisting in the covalent and noncovalent assembly of single chain polypeptides or multisubunit complexes into the correct tertiary structure that results in the attainment of the full functional capacity of a protein. [GOC:isa_complete]
Full description |

Standard name | GO_DIGESTIVE_SYSTEM_PROCESS
Systematic name | M13988
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A physical, chemical, or biochemical process carried out by living organisms to break down ingested nutrients into components that may be easily absorbed and directed into metabolism. [GOC:isa_complete, GOC:jid, GOC:mtg_cardio]
Full description |

Standard name | GO_OVULATION_CYCLE_PROCESS
Systematic name | M12867
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process involved in the sexual cycle seen in females, often with physiologic changes in the endometrium that recur at regular intervals during the reproductive years. [GOC:isa_complete]
Full description |

Standard name | GO_REGULATION_OF_ANATOMICAL_STRUCTURE_MORPHOGENESIS
Systematic name | M7769
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of anatomical structure morphogenesis. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CELL_MORPHOGENESIS
Systematic name | M10484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell morphogenesis. Cell morphogenesis is the developmental process in which the shape of a cell is generated and organized. [GOC:isa_complete]
Full description |

Standard name | GO_MAMMALIAN_OOGENESIS_STAGE
Systematic name | M22936
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A reproductive process that is a step in the formation and maturation of an ovum or female gamete from a primordial female germ cell. [GOC:isa_complete, GOC:mtg_sensu]
Full description |

Standard name | GO_BIOLOGICAL_ADHESION
Systematic name | M16534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a cell or organism to a substrate, another cell, or other organism. Biological adhesion includes intracellular attachment between membrane regions. [GOC:isa_complete]
Full description |

Standard name | GO_GLAND_MORPHOGENESIS
Systematic name | M10421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a gland are generated and organized. [GOC:isa_complete]
Full description |

Standard name | GO_RIBONUCLEOPROTEIN_COMPLEX_BIOGENESIS
Systematic name | M16027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the biosynthesis of constituent macromolecules, assembly, and arrangement of constituent parts of a complex containing RNA and proteins. Includes the biosynthesis of the constituent RNA and protein molecules, and those macromolecular modifications that are involved in synthesis or assembly of the ribonucleoprotein complex. [GOC:isa_complete, GOC:mah]
Full description |

Standard name | GO_MEMBRANE_TO_MEMBRANE_DOCKING
Systematic name | M22937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial attachment of a membrane to a target membrane, mediated by proteins protruding from the two membranes. Docking requires only that the membranes come close enough for the proteins to interact and adhere. [GOC:isa_complete]
Full description |

Standard name | GO_DNA_STRAND_ELONGATION
Systematic name | M13628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The DNA metabolic process in which an existing DNA strand is extended by activities including the addition of nucleotides to the 3' end of the strand. [GOC:isa_complete, GOC:mah]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX_DISASSEMBLY
Systematic name | M14816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that results in the breakdown of the extracellular matrix. [GOC:jid]
Full description |

Standard name | GO_ELECTRON_TRANSPORT_CHAIN
Systematic name | M13293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a series of electron carriers operate together to transfer electrons from donors to any of several different terminal electron acceptors to generate a transmembrane electrochemical gradient. [GOC:mtg_electron_transport]
Full description |

Standard name | GO_RESPIRATORY_ELECTRON_TRANSPORT_CHAIN
Systematic name | M22938
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a series of electron carriers operate together to transfer electrons from donors such as NADH and FADH2 to any of several different terminal electron acceptors to generate a transmembrane electrochemical gradient. [GOC:mtg_electron_transport, ISBN:0716720094]
Full description |

Standard name | GO_SIGNAL_TRANSDUCTION_BY_PROTEIN_PHOSPHORYLATION
Systematic name | M15853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which the transfer of one or more phosphate groups to a substrate transmits a signal to the phosphorylated substrate. [GOC:mtg_signal, GOC:signaling]
Full description |

Standard name | GO_SIGNAL_TRANSDUCTION_INVOLVED_IN_REGULATION_OF_GENE_EXPRESSION
Systematic name | M16934
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gene expression as a consequence of a process in which a signal is released and/or conveyed from one location to another. [GOC:mtg_signal]
Full description |

Standard name | GO_CD40_SIGNALING_PATHWAY
Systematic name | M22939
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of the cell surface receptor CD40 to one of its physiological ligands, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:mtg_signal, GOC:signaling, PMID:11348017]
Full description |

Standard name | GO_NEURONAL_SIGNAL_TRANSDUCTION
Systematic name | M22940
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an activated neuronal cell receptor conveys information down a signaling pathway, resulting in a change in the function or state of a cell. This process may be intracellular or intercellular. [GOC:mtg_signal]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SIGNALING
Systematic name | M22941
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of a signaling process. [GOC:mtg_signal]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SIGNALING
Systematic name | M22942
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a signaling process. [GOC:mtg_signal]
Full description |

Standard name | GO_ADAPTATION_OF_SIGNALING_PATHWAY
Systematic name | M16223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulation of a signal transduction pathway in response to a stimulus upon prolonged exposure to that stimulus. [GOC:mtg_signal]
Full description |

Standard name | GO_SIGNAL_RELEASE
Systematic name | M13839
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a signal is secreted or discharged into the extracellular medium from a cellular source. [GOC:mtg_signal]
Full description |

Standard name | GO_METAL_ION_TRANSPORT
Systematic name | M10905
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of metal ions, any metal ion with an electric charge, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_CELLULAR_ANION_HOMEOSTASIS
Systematic name | M13241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of anions at the level of a cell. [GOC:ceb, GOC:mah]
Full description |

Standard name | GO_CELLULAR_MONOVALENT_INORGANIC_CATION_HOMEOSTASIS
Systematic name | M18588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of monovalent inorganic cations at the level of a cell. [GOC:ai, GOC:mah]
Full description |

Standard name | GO_CELLULAR_POTASSIUM_ION_HOMEOSTASIS
Systematic name | M13288
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of potassium ions at the level of a cell. [GOC:mah]
Full description |

Standard name | GO_ESTABLISHMENT_OF_CELL_POLARITY
Systematic name | M12181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specification and formation of anisotropic intracellular organization or cell growth patterns. [GOC:mah]
Full description |

Standard name | GO_MAINTENANCE_OF_CELL_POLARITY
Systematic name | M13745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The maintenance of established anisotropic intracellular organization or cell growth patterns. [GOC:mah]
Full description |

Standard name | GO_ACTIN_FILAMENT_BASED_PROCESS
Systematic name | M9082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that depends upon or alters the actin cytoskeleton, that part of the cytoskeleton comprising actin filaments and their associated proteins. [GOC:mah]
Full description |

Standard name | GO_CELL_PROJECTION_ORGANIZATION
Systematic name | M15229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a prolongation or process extending from a cell, e.g. a flagellum or axon. [GOC:jl, GOC:mah, http://www.cogsci.princeton.edu/~wn/]
Full description |

Standard name | GO_CELL_PROJECTION_ASSEMBLY
Systematic name | M3727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Formation of a prolongation or process extending from a cell, e.g. a flagellum or axon. [GOC:jl, GOC:mah, http://www.cogsci.princeton.edu/~wn/]
Full description |

Standard name | GO_LAMELLIPODIUM_ASSEMBLY
Systematic name | M16776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Formation of a lamellipodium, a thin sheetlike extension of the surface of a migrating cell. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_MICROVILLUS_ASSEMBLY
Systematic name | M22943
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Formation of a microvillus, a thin cylindrical membrane-covered projection on the surface of a cell. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_ACTIN_FILAMENT_DEPOLYMERIZATION
Systematic name | M22944
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Disassembly of actin filaments by the removal of actin monomers from a filament. [GOC:mah]
Full description |

Standard name | GO_PARALLEL_ACTIN_FILAMENT_BUNDLE_ASSEMBLY
Systematic name | M22945
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Assembly of actin filament bundles in which the filaments are tightly packed (approximately 10-20 nm apart) and oriented with the same polarity. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_ACTIN_MODIFICATION
Systematic name | M22946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Covalent modification of an actin molecule. [GOC:mah]
Full description |

Standard name | GO_ACTIN_FILAMENT_BASED_MOVEMENT
Systematic name | M17820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Movement of organelles or other particles along actin filaments, or sliding of actin filaments past each other, mediated by motor proteins. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_MUSCLE_FILAMENT_SLIDING
Systematic name | M22947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The sliding of actin thin filaments and myosin thick filaments past each other in muscle contraction. This involves a process of interaction of myosin located on a thick filament with actin located on a thin filament. During this process ATP is split and forces are generated. [GOC:mah, GOC:mtg_muscle, ISBN:0815316194]
Full description |

Standard name | GO_PEPTIDE_HORMONE_SECRETION
Systematic name | M22949
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of a peptide hormone from a cell. [GOC:mah]
Full description |

Standard name | GO_INSULIN_SECRETION
Systematic name | M10906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of proinsulin from secretory granules accompanied by cleavage of proinsulin to form mature insulin. In vertebrates, insulin is secreted from B granules in the B cells of the vertebrate pancreas and from insulin-producing cells in insects. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_PROTEIN_REPAIR
Systematic name | M22950
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of restoring a protein to its original state after damage by such things as oxidation or spontaneous decomposition of residues. [GOC:mlg]
Full description |

Standard name | GO_LYMPHOCYTE_DIFFERENTIATION
Systematic name | M18190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized precursor cell acquires specialized features of a lymphocyte. A lymphocyte is a leukocyte commonly found in the blood and lymph that has the characteristics of a large nucleus, a neutral staining cytoplasm, and prominent heterochromatin. [CL:0000542, GOC:go_curators]
Full description |

Standard name | GO_MYELOID_CELL_DIFFERENTIATION
Systematic name | M10009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized myeloid precursor cell acquires the specialized features of any cell of the myeloid leukocyte, megakaryocyte, thrombocyte, or erythrocyte lineages. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_ENDOCYTOSIS
Systematic name | M14202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endocytosis. [GOC:go_curators]
Full description |

Standard name | GO_NATURAL_KILLER_CELL_ACTIVATION
Systematic name | M14057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a natural killer cell in response to a cytokine, chemokine, cellular ligand, or soluble factor. [GOC:mgi_curators, ISBN:0781735149]
Full description |

Standard name | GO_WATER_HOMEOSTASIS
Systematic name | M13772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of water within an organism or cell. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_WNT_SIGNALING_PATHWAY
Systematic name | M11440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the activity of the Wnt signal transduction pathway. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_SPHINGOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M15003
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of sphingolipids, any of a class of lipids containing the long-chain amine diol sphingosine or a closely related base (a sphingoid). [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_PROTEIN_IMPORT_INTO_MITOCHONDRIAL_MATRIX
Systematic name | M15922
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The import of proteins across the outer and inner mitochondrial membranes into the matrix. Unfolded proteins enter the mitochondrial matrix with a chaperone protein; the information required to target the precursor protein from the cytosol to the mitochondrial matrix is contained within its N-terminal matrix-targeting sequence. Translocation of precursors to the matrix occurs at the rare sites where the outer and inner membranes are close together. [ISBN:0716731363]
Full description |

Standard name | GO_REGULATION_OF_CELL_ADHESION
Systematic name | M8154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of attachment of a cell to another cell or to the extracellular matrix. [GOC:mah]
Full description |

Standard name | GO_PANCREATIC_JUICE_SECRETION
Systematic name | M22951
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of pancreatic juice by the exocrine pancreas into the upper part of the intestine. Pancreatic juice is slightly alkaline and contains numerous enzymes and inactive enzyme precursors including alpha-amylase, chymotrypsinogen, lipase, procarboxypeptidase, proelastase, prophospholipase A2, ribonuclease, and trypsinogen. Its high concentration of bicarbonate ions helps to neutralize the acid from the stomach. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_PROTEOLYSIS
Systematic name | M16059
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the hydrolysis of a peptide bond or bonds within a protein. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_CATABOLIC_PROCESS
Systematic name | M16362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a protein by the destruction of the native, active configuration, with or without the hydrolysis of peptide bonds. [GOC:mah]
Full description |

Standard name | GO_PROTEOGLYCAN_BIOSYNTHETIC_PROCESS
Systematic name | M3215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of proteoglycans, any glycoprotein in which the carbohydrate units are glycosaminoglycans. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_PLATELET_ACTIVATION
Systematic name | M10857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of progressive, overlapping events triggered by exposure of the platelets to subendothelial tissue. These events include shape change, adhesiveness, aggregation, and release reactions. When carried through to completion, these events lead to the formation of a stable hemostatic plug. [http://www.graylab.ac.uk/omd/]
Full description |

Standard name | GO_REGULATION_OF_DNA_DEPENDENT_DNA_REPLICATION_INITIATION
Systematic name | M22952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of initiation of DNA-dependent DNA replication; the process in which DNA becomes competent to replicate. In eukaryotes, replication competence is established in early G1 and lost during the ensuing S phase. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_WNT_SIGNALING_PATHWAY
Systematic name | M15507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of Wnt signal transduction. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_WNT_SIGNALING_PATHWAY
Systematic name | M16074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the Wnt signaling pathway. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_NEURON_DIFFERENTIATION
Systematic name | M6898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a neuron. [GOC:mah]
Full description |

Standard name | GO_B_CELL_DIFFERENTIATION
Systematic name | M5982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of a B cell. A B cell is a lymphocyte of B lineage with the phenotype CD19-positive and capable of B cell mediated immunity. [GO_REF:0000022, GOC:mah]
Full description |

Standard name | GO_COLLAGEN_FIBRIL_ORGANIZATION
Systematic name | M10505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that determines the size and arrangement of collagen fibrils within an extracellular matrix. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_HEPARAN_SULFATE_PROTEOGLYCAN_METABOLIC_PROCESS
Systematic name | M12969
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any proteoglycan containing heparan sulfate, any member of a group of glycosaminoglycans that have repeat units consisting of alternating alpha-(1->4)-linked hexuronic acid and glucosamine residues, the former being a mixture of sulfated and nonsulfated D-glucuronic and L-iduronic acids, and the latter being either sulfated or acetylated on its amino group as well as sulfated on one of its hydroxyl groups. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_HEPARIN_METABOLIC_PROCESS
Systematic name | M29129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving heparin, any member of a group of glycosaminoglycans found mainly as an intracellular component of mast cells. They are similar to heparan sulfates but are of somewhat higher average Mr (6000-20000) and contain fewer N-acetyl groups and more N-sulfate and O-sulfate groups; they may be attached in the same manner to protein, forming proteoglycans. They consist predominantly of alternating alpha-(1->4)-linked D-galactose and N-acetyl-D-glucosamine-6-sulfate residues. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_DERMATAN_SULFATE_METABOLIC_PROCESS
Systematic name | M29130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving dermatan sulfate, any of a group of glycosaminoglycans with repeats consisting of beta-(1,4)-linked L-iduronyl-beta-(1,3)-N-acetyl-D-galactosamine 4-sulfate units. They are important components of ground substance or intercellular cement of skin and some connective tissues. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_CHONDROITIN_SULFATE_BIOSYNTHETIC_PROCESS
Systematic name | M13500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of chondroitin sulfate, any member of a group of 10-60 kDa glycosaminoglycans, widely distributed in cartilage and other mammalian connective tissues, the repeat units of which consist of beta-(1,4)-linked D-glucuronyl beta-(1,3)-N-acetyl-D-galactosamine sulfate. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_CHONDROITIN_SULFATE_CATABOLIC_PROCESS
Systematic name | M13795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of chondroitin sulfate, any member of a group of 10-60 kDa glycosaminoglycans, widely distributed in cartilage and other mammalian connective tissues, the repeat units of which consist of beta-(1,4)-linked D-glucuronyl beta-(1,3)-N-acetyl-D-galactosamine sulfate. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_HYALURONAN_METABOLIC_PROCESS
Systematic name | M12268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving hyaluronan, the naturally occurring anionic form of hyaluronic acid, any member of a group of glycosaminoglycans, the repeat units of which consist of beta-1,4 linked D-glucuronyl-beta-(1,3)-N-acetyl-D-glucosamine. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_HYALURONAN_BIOSYNTHETIC_PROCESS
Systematic name | M22956
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of hyaluronan, the naturally occurring anionic form of hyaluronic acid, any member of a group of glycosaminoglycans, the repeat units of which consist of beta-1,4 linked D-glucuronyl-beta-(1,3)-N-acetyl-D-glucosamine. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_HYALURONAN_CATABOLIC_PROCESS
Systematic name | M11100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of hyaluronan, the naturally occurring anionic form of hyaluronic acid, any member of a group of glycosaminoglycans, the repeat units of which consist of beta-1,4 linked D-glucuronyl-beta-(1,3)-N-acetyl-D-glucosamine. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_KERATINOCYTE_DIFFERENTIATION
Systematic name | M29131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a keratinocyte. [GOC:dph, GOC:mah, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_T_CELL_DIFFERENTIATION
Systematic name | M18127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires characteristics of a more mature T-cell. A T cell is a type of lymphocyte whose definin characteristic is the expression of a T cell receptor complex. [GO_REF:0000022, GOC:jid, GOC:mah]
Full description |

Standard name | GO_MEGAKARYOCYTE_DIFFERENTIATION
Systematic name | M14514
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a myeloid precursor cell acquires specializes features of a megakaryocyte. [GOC:mah]
Full description |

Standard name | GO_EOSINOPHIL_DIFFERENTIATION
Systematic name | M22957
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized myeloid precursor cell acquires the specializes features of an eosinophil. [GOC:add, GOC:mah]
Full description |

Standard name | GO_NEUTROPHIL_DIFFERENTIATION
Systematic name | M22958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a myeloid precursor cell acquires the specialized features of a neutrophil. [GOC:mah]
Full description |

Standard name | GO_MACROPHAGE_DIFFERENTIATION
Systematic name | M14853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized monocyte acquires the specialized features of a macrophage. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_MALE_SEX_DETERMINATION
Systematic name | M11044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specification of male sex of an individual organism. [GOC:mah]
Full description |

Standard name | GO_MYOFIBRIL_ASSEMBLY
Systematic name | M13349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Formation of myofibrils, the repeating units of striated muscle. [GOC:mah]
Full description |

Standard name | GO_SKELETAL_MUSCLE_THIN_FILAMENT_ASSEMBLY
Systematic name | M29132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins to form the actin-based thin filaments of myofibrils in skeletal muscle. [GOC:ef, GOC:mah, GOC:mtg_muscle]
Full description |

Standard name | GO_AUTOPHAGY_OF_PEROXISOME
Systematic name | M22959
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which peroxisomes are delivered to a type of vacuole and degraded in response to changing nutrient conditions. [GOC:autophagy, PMID:10547367, PMID:20083110]
Full description |

Standard name | GO_GROWTH_HORMONE_SECRETION
Systematic name | M22960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of growth hormone from secretory granules into the blood. [GOC:mah]
Full description |

Standard name | GO_LIPID_MODIFICATION
Systematic name | M10113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent alteration of one or more fatty acids in a lipid, resulting in a change in the properties of the lipid. [GOC:mah]
Full description |

Standard name | GO_LIPID_GLYCOSYLATION
Systematic name | M22961
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Covalent attachment of a glycosyl residue to a lipid molecule. [GOC:mah]
Full description |

Standard name | GO_CHROMOSOME_CONDENSATION
Systematic name | M11637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progressive compaction of dispersed interphase chromatin into threadlike chromosomes prior to mitotic or meiotic nuclear division, or during apoptosis, in eukaryotic cells. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_APOPTOTIC_CHROMOSOME_CONDENSATION
Systematic name | M22962
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The compaction of chromatin during apoptosis. [GOC:mah]
Full description |

Standard name | GO_MAINTENANCE_OF_GASTROINTESTINAL_EPITHELIUM
Systematic name | M13425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Protection of epithelial surfaces of the gastrointestinal tract from proteolytic and caustic digestive agents. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_OSSIFICATION
Systematic name | M16923
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ossification, the formation of bone or of a bony substance or the conversion of fibrous tissue or of cartilage into bone or a bony substance. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OSSIFICATION
Systematic name | M15467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of ossification, the formation of bone or of a bony substance or the conversion of fibrous tissue or of cartilage into bone or a bony substance. [GOC:go_curators]
Full description |

Standard name | GO_BONE_MINERALIZATION
Systematic name | M12864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The deposition of hydroxyapatite, a form of calcium phosphate with the formula Ca10(PO4)6(OH)2, in bone tissue. [GOC:mah, PMID:22936354]
Full description |

Standard name | GO_REGULATION_OF_INTESTINAL_CHOLESTEROL_ABSORPTION
Systematic name | M29133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of absorption of cholesterol into the blood, and the exclusion of other sterols from absorption. [GOC:mah, PMID:11099417]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_GROWTH
Systematic name | M12857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, extent or direction of cell growth. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_GROWTH
Systematic name | M10876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, extent or direction of cell growth. [GOC:go_curators]
Full description |

Standard name | GO_POLY_N_ACETYLLACTOSAMINE_METABOLIC_PROCESS
Systematic name | M29134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving poly-N-acetyllactosamine, a carbohydrate composed of N-acetyllactosamine repeats (Gal-beta-1,4-GlcNAc-beta-1,3)n. [GOC:mah, PMID:9405606]
Full description |

Standard name | GO_OSTEOCLAST_DIFFERENTIATION
Systematic name | M16135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized monocyte acquires the specialized features of an osteoclast. An osteoclast is a specialized phagocytic cell associated with the absorption and removal of the mineralized matrix of bone tissue. [CL:0000092, GOC:add, ISBN:0781735149, PMID:12161749]
Full description |

Standard name | GO_MELANOCYTE_DIFFERENTIATION
Systematic name | M15931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a melanocyte. [GOC:mah]
Full description |

Standard name | GO_TRANSEPITHELIAL_CHLORIDE_TRANSPORT
Systematic name | M22964
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of chloride ions from one side of an epithelium to the other. [GOC:mah]
Full description |

Standard name | GO_STABILIZATION_OF_MEMBRANE_POTENTIAL
Systematic name | M16676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The accomplishment of a non-fluctuating membrane potential, the electric potential existing across any membrane arising from charges in the membrane itself and from the charges present in the media on either side of the membrane. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_ADRENAL_GLAND_DEVELOPMENT
Systematic name | M13778
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the adrenal gland over time, from its formation to the mature structure. This gland can either be a discrete structure located bilaterally above each kidney, or a cluster of cells in the head kidney that perform the functions of the adrenal gland. In either case, this organ consists of two cells types, aminergic chromaffin cells and steroidogenic cortical cells. [GOC:dgh]
Full description |

Standard name | GO_DNA_DAMAGE_RESPONSE_SIGNAL_TRANSDUCTION_BY_P53_CLASS_MEDIATOR
Systematic name | M8378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cascade of processes induced by the cell cycle regulator phosphoprotein p53, or an equivalent protein, in response to the detection of DNA damage. [GOC:go_curators]
Full description |

Standard name | GO_FRUCTOSE_1_6_BISPHOSPHATE_METABOLIC_PROCESS
Systematic name | M22966
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving fructose 1,6-bisphosphate, also known as FBP. The D enantiomer is a metabolic intermediate in glycolysis and gluconeogenesis. [ISBN:0198506732]
Full description |

Standard name | GO_MEMBRANE_DISASSEMBLY
Systematic name | M10723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled breakdown of any cell membrane in the context of a normal process such as autophagy. [GOC:mah]
Full description |

Standard name | GO_PRODUCTION_OF_SIRNA_INVOLVED_IN_RNA_INTERFERENCE
Systematic name | M22967
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cleavage of double-stranded RNA to form small interfering RNA molecules (siRNAs) of 21-23 nucleotides, in the context of RNA interference. [GOC:mah, PMID:11524674]
Full description |

Standard name | GO_SLEEP
Systematic name | M14903
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organism enters and maintains a periodic, readily reversible state of reduced awareness and metabolic activity. Usually accompanied by physical relaxation, the onset of sleep in humans and other mammals is marked by a change in the electrical activity of the brain. [ISBN:0192800981]
Full description |

Standard name | GO_PERISTALSIS
Systematic name | M22968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A wavelike sequence of involuntary muscular contraction and relaxation that passes along a tubelike structure, such as the intestine, impelling the contents onwards. [ISBN:0198506732]
Full description |

Standard name | GO_UBIQUITIN_DEPENDENT_ERAD_PATHWAY
Systematic name | M22969
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of steps necessary to target endoplasmic reticulum (ER)-resident proteins for degradation by the cytoplasmic proteasome. Begins with recognition of the ER-resident protein, includes retrotranslocation (dislocation) of the protein from the ER to the cytosol, protein ubiquitination necessary for correct substrate transfer, transport of the protein to the proteasome, and ends with degradation of the protein by the cytoplasmic proteasome. [GOC:mah, GOC:rb, PMID:14607247, PMID:19520858]
Full description |

Standard name | GO_REGULATION_OF_COMPLEMENT_ACTIVATION_ALTERNATIVE_PATHWAY
Systematic name | M34120
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the alternative pathway of complement activation. [GOC:go_curators]
Full description |

Standard name | GO_NUCLEAR_MIGRATION_ALONG_MICROTUBULE
Systematic name | M22970
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of the nucleus along microtubules within the cell, mediated by motor proteins. [GOC:mah, GOC:sgd_curators]
Full description |

Standard name | GO_TRNA_METHYLATION
Systematic name | M13570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The posttranscriptional addition of methyl groups to specific residues in a tRNA molecule. [GOC:mah]
Full description |

Standard name | GO_MATURATION_OF_SSU_RRNA
Systematic name | M10864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maturation of a precursor Small SubUnit (SSU) ribosomal RNA (rRNA) molecule into a mature SSU-rRNA molecule. [GOC:curators]
Full description |

Standard name | GO_FATTY_ACID_ELONGATION
Systematic name | M16897
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The elongation of a fatty acid chain by the sequential addition of two-carbon units. [ISBN:0716720094]
Full description |

Standard name | GO_REGULATION_OF_BONE_MINERALIZATION
Systematic name | M22971
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of bone mineralization. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BONE_MINERALIZATION
Systematic name | M22972
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of bone mineralization. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BONE_MINERALIZATION
Systematic name | M22973
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of bone mineralization. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_BMP_SIGNALING_PATHWAY
Systematic name | M14928
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the activity of any BMP receptor signaling pathway. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BMP_SIGNALING_PATHWAY
Systematic name | M12261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of BMP signaling pathway activity. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BMP_SIGNALING_PATHWAY
Systematic name | M13373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the BMP signaling pathway. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AXON_EXTENSION
Systematic name | M10588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of axon outgrowth. [GOC:mah]
Full description |

Standard name | GO_INTRACELLULAR_STEROID_HORMONE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals generated as a consequence of a intracellular steroid hormone receptor binding to one of its physiological ligands. [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_INTRACELLULAR_ESTROGEN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M16829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of an intracellular estrogen receptor binding to one of its physiological ligands. The pathway begins with receptor-ligand binding, and ends with regulation of a downstream cellular process (e.g. transcription). [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_ANDROGEN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15861
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of an androgen binding to its receptor. [GOC:mah]
Full description |

Standard name | GO_INTRACELLULAR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M14730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals initiated by a ligand binding to an receptor located within a cell. [GOC:bf, GOC:mah]
Full description |

Standard name | GO_ADULT_BEHAVIOR
Systematic name | M10832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Behavior in a fully developed and mature organism. [GOC:mah, ISBN:0877797099]
Full description |

Standard name | GO_MALE_GENITALIA_DEVELOPMENT
Systematic name | M10795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the male genitalia over time, from its formation to the mature structure. [GOC:ems, ISBN:0140512888]
Full description |

Standard name | GO_FEMALE_GENITALIA_DEVELOPMENT
Systematic name | M16109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the female genitalia over time, from formation to the mature structure. [GOC:mah]
Full description |

Standard name | GO_COLLAGEN_CATABOLIC_PROCESS
Systematic name | M22974
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The proteolytic chemical reactions and pathways resulting in the breakdown of collagen in the extracellular matrix, usually carried out by proteases secreted by nearby cells. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_NUCLEAR_BODY_ORGANIZATION
Systematic name | M22975
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of any of the extra-nucleolar nuclear domains usually visualized by confocal microscopy and fluorescent antibodies to specific proteins. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_PML_BODY_ORGANIZATION
Systematic name | M22976
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of PML bodies, a class of nuclear body; they react against SP100 auto-antibodies (PML = promyelocytic leukemia). [GOC:mah, PMID:10806078]
Full description |

Standard name | GO_UBIQUITIN_DEPENDENT_SMAD_PROTEIN_CATABOLIC_PROCESS
Systematic name | M22977
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of SMAD signaling proteins by ubiquitination and targeting to the proteasome. [GOC:go_curators]
Full description |

Standard name | GO_NEUTROPHIL_CHEMOTAXIS
Systematic name | M34121
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a neutrophil cell, the most numerous polymorphonuclear leukocyte found in the blood, in response to an external stimulus, usually an infection or wounding. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_LEUKOCYTE_CHEMOTAXIS
Systematic name | M11916
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a leukocyte in response to an external stimulus. [GOC:add, GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_PH
Systematic name | M19698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal equilibrium of hydrogen ions (protons) within a cell or between a cell and its external environment. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_CELLULAR_CHLORIDE_ION_HOMEOSTASIS
Systematic name | M34122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of chloride ions at the level of a cell. [GOC:mah]
Full description |

Standard name | GO_AMINOGLYCOSIDE_ANTIBIOTIC_METABOLIC_PROCESS
Systematic name | M29135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving an aminoglycoside antibiotic, any member of a group of broad spectrum antibiotics, of similar toxicity and pharmacology, that contain an aminodeoxysugar, an amino- or guanidino-substituted inositol ring, and one or more residues of other sugars. The group includes streptomycin, neomycin, framycetin, kanamycin, paromomycin, and gentamicin. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_VITAMIN_METABOLIC_PROCESS
Systematic name | M11781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving a vitamin, one of a number of unrelated organic substances that occur in many foods in small amounts and that are necessary in trace amounts for the normal metabolic functioning of the body. [GOC:mah]
Full description |

Standard name | GO_CYTOSKELETON_DEPENDENT_INTRACELLULAR_TRANSPORT
Systematic name | M8785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances along cytoskeletal fibers such as microfilaments or microtubules within a cell. [GOC:mah]
Full description |

Standard name | GO_OVULATION
Systematic name | M13057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The release of a mature ovum/oocyte from an ovary. [GOC:bf, ISBN:0878932437]
Full description |

Standard name | GO_SEQUESTERING_OF_TRIGLYCERIDE
Systematic name | M22979
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of binding or confining any triester of glycerol such that it is separated from other components of a biological system. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_NUCLEOTIDE_BIOSYNTHETIC_PROCESS
Systematic name | M22980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of nucleotides. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NUCLEOTIDE_BIOSYNTHETIC_PROCESS
Systematic name | M22981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of nucleotides. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NUCLEOTIDE_BIOSYNTHETIC_PROCESS
Systematic name | M22982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of nucleotides. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ACTIN_FILAMENT_LENGTH
Systematic name | M16340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that controls the length of actin filaments in a cell. [GOC:dph, GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ACTIN_FILAMENT_DEPOLYMERIZATION
Systematic name | M11349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of actin depolymerization. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACTIN_FILAMENT_DEPOLYMERIZATION
Systematic name | M16880
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of actin depolymerization. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ACTIN_FILAMENT_POLYMERIZATION
Systematic name | M14995
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of actin polymerization. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACTIN_FILAMENT_POLYMERIZATION
Systematic name | M15198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of actin polymerization. [GOC:mah]
Full description |

Standard name | GO_PROSTATE_GLAND_DEVELOPMENT
Systematic name | M15794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the prostate gland over time, from its formation to the mature structure. The prostate gland is a partly muscular, partly glandular body that is situated near the base of the mammalian male urethra and secretes an alkaline viscid fluid which is a major constituent of the ejaculatory fluid. [PMID:11839751]
Full description |

Standard name | GO_GRANULOCYTE_DIFFERENTIATION
Systematic name | M14361
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a myeloid precursor cell acquires the specialized features of a granulocyte. Granulocytes are a class of leukocytes characterized by the presence of granules in their cytoplasm. These cells are active in allergic immune reactions such as arthritic inflammation and rashes. This class includes basophils, eosinophils and neutrophils. [GOC:ecd, http://life.nthu.edu.tw/~g864204/dict-search1.htm]
Full description |

Standard name | GO_REGULATION_OF_GRANULOCYTE_DIFFERENTIATION
Systematic name | M12437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of granulocyte differentiation. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GRANULOCYTE_DIFFERENTIATION
Systematic name | M22983
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of granulocyte differentiation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GRANULOCYTE_DIFFERENTIATION
Systematic name | M22984
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of granulocyte differentiation. [GOC:mah]
Full description |

Standard name | GO_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M3
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of an epithelial cell, any of the cells making up an epithelium. [GOC:ecd, PMID:11839751]
Full description |

Standard name | GO_REGULATION_OF_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M12058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of epithelial cell differentiation. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M14860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of epithelial cell differentiation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M10054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of epithelial cell differentiation. [GOC:mah]
Full description |

Standard name | GO_POLARIZED_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M13212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a polarized epithelial cell. The polarized epithelial cell can be any of the cells within an epithelium where the epithelial sheet is oriented with respect to the planar axis. [GOC:mah]
Full description |

Standard name | GO_CORTICAL_CYTOSKELETON_ORGANIZATION
Systematic name | M16535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of cytoskeletal structures in the cell cortex, i.e. just beneath the plasma membrane. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_CORTICAL_ACTIN_CYTOSKELETON_ORGANIZATION
Systematic name | M34123
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of actin-based cytoskeletal structures in the cell cortex, i.e. just beneath the plasma membrane. [GOC:dph, GOC:jl, GOC:mah, GOC:pf]
Full description |

Standard name | GO_THYROID_GLAND_DEVELOPMENT
Systematic name | M16540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the thyroid gland over time, from its formation to the mature structure. The thyroid gland is an endoderm-derived gland that produces thyroid hormone. [GOC:dgh]
Full description |

Standard name | GO_MAMMARY_GLAND_DEVELOPMENT
Systematic name | M13739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the mammary gland over time, from its formation to the mature structure. The mammary gland is a large compound sebaceous gland that in female mammals is modified to secrete milk. Its development starts with the formation of the mammary line and ends as the mature gland cycles between nursing and weaning stages. [PMID:9576833]
Full description |

Standard name | GO_REGULATION_OF_MYELOID_DENDRITIC_CELL_ACTIVATION
Systematic name | M22985
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency or rate of myeloid dendritic cell activation. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_B_CELL_PROLIFERATION
Systematic name | M14629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of B cell proliferation. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_B_CELL_PROLIFERATION
Systematic name | M14438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of B cell proliferation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_B_CELL_PROLIFERATION
Systematic name | M11546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of B cell proliferation. [GOC:mah]
Full description |

Standard name | GO_FOREBRAIN_DEVELOPMENT
Systematic name | M11811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the forebrain over time, from its formation to the mature structure. The forebrain is the anterior of the three primary divisions of the developing chordate brain or the corresponding part of the adult brain (in vertebrates, includes especially the cerebral hemispheres, the thalamus, and the hypothalamus and especially in higher vertebrates is the main control center for sensory and associative information processing, visceral functions, and voluntary motor functions). [http://www2.merriam-webster.com/cgi-bin/mwmednlm?book=Medical&va=forebrain]
Full description |

Standard name | GO_MIDBRAIN_DEVELOPMENT
Systematic name | M13125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the midbrain over time, from its formation to the mature structure. The midbrain is the middle division of the three primary divisions of the developing chordate brain or the corresponding part of the adult brain (in vertebrates, includes a ventral part containing the cerebral peduncles and a dorsal tectum containing the corpora quadrigemina and that surrounds the aqueduct of Sylvius connecting the third and fourth ventricles). [http://www2.merriam-webster.com/cgi-bin/mwmednlm?book=Medical&va=midbrain]
Full description |

Standard name | GO_HINDBRAIN_DEVELOPMENT
Systematic name | M10170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the hindbrain over time, from its formation to the mature structure. The hindbrain is the posterior of the three primary divisions of the developing chordate brain, or the corresponding part of the adult brain (in vertebrates, includes the cerebellum, pons, and medulla oblongata and controls the autonomic functions and equilibrium). [http://www2.merriam-webster.com/cgi-bin/mwmednlm?book=Medical&va=hindbrain]
Full description |

Standard name | GO_NOTOCHORD_DEVELOPMENT
Systematic name | M15882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the notochord over time, from its formation to the mature structure. The notochord is a mesoderm-derived structure located ventral of the developing nerve cord. In vertebrates, the notochord serves as a core around which other mesodermal cells form the vertebrae. In the most primitive chordates, which lack vertebrae, the notochord persists as a substitute for a vertebral column. [GOC:dgh]
Full description |

Standard name | GO_PARANODAL_JUNCTION_ASSEMBLY
Systematic name | M22986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Formation of the junction between an axon and the glial cell that forms the myelin sheath. Paranodal junctions form at each paranode, i.e. at the ends of the unmyelinated nodes of Ranvier. [PMID:14715942]
Full description |

Standard name | GO_OTIC_VESICLE_FORMATION
Systematic name | M22987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process resulting in the transition of the otic placode into the otic vesicle, a transient embryonic structure formed during development of the vertebrate inner ear. [GOC:dgh]
Full description |

Standard name | GO_MIDBRAIN_HINDBRAIN_BOUNDARY_DEVELOPMENT
Systematic name | M22988
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the midbrain-hindbrain boundary over time, from its formation to the mature structure. The midbrain-hindbrain domain of the embryonic brain is comprised of the mesencephalic vesicle and the first rhombencephalic vesicle at early somitogenesis stages. [GOC:dgh]
Full description |

Standard name | GO_REGULATION_OF_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M13223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of vascular endothelial growth factor receptor signaling pathway activity. [GOC:dgh]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M22989
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of vascular endothelial growth factor receptor signaling pathway activity. [GOC:dgh]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15928
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vascular endothelial growth factor receptor signaling pathway activity. [GOC:dgh]
Full description |

Standard name | GO_ESTABLISHMENT_OR_MAINTENANCE_OF_ACTIN_CYTOSKELETON_POLARITY
Systematic name | M22990
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that results in the specification, formation or maintenance of polarized actin-based cytoskeletal structures. [GOC:mah]
Full description |

Standard name | GO_ESTABLISHMENT_OR_MAINTENANCE_OF_CYTOSKELETON_POLARITY
Systematic name | M22991
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that results in the specification, formation or maintenance of polarized cytoskeletal structures. [GOC:mah]
Full description |

Standard name | GO_ASTRAL_MICROTUBULE_ORGANIZATION
Systematic name | M22992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of astral microtubules, any of the spindle microtubules that radiate in all directions from the spindle poles. [GOC:mah]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M22993
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of the presence of unfolded proteins in the endoplasmic reticulum (ER) or other ER-related stress; results in changes in the regulation of transcription and translation. [GOC:mah, PMID:12042763]
Full description |

Standard name | GO_RESPONSE_TO_CAFFEINE
Systematic name | M13820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a caffeine stimulus. Caffeine is an alkaloid found in numerous plant species, where it acts as a natural pesticide that paralyzes and kills certain insects feeding upon them. [GOC:ef, GOC:mah]
Full description |

Standard name | GO_PANCREAS_DEVELOPMENT
Systematic name | M11915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the pancreas over time, from its formation to the mature structure. The pancreas is an endoderm derived structure that produces precursors of digestive enzymes and blood glucose regulating enzymes. [GOC:cvs]
Full description |

Standard name | GO_EXOCRINE_PANCREAS_DEVELOPMENT
Systematic name | M22994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the exocrine pancreas over time, from its formation to the mature structure. The exocrine pancreas produces and store zymogens of digestive enzymes, such as chymotrypsinogen and trypsinogen in the acinar cells. [GOC:cvs]
Full description |

Standard name | GO_ENDOCRINE_PANCREAS_DEVELOPMENT
Systematic name | M12875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the endocrine pancreas over time, from its formation to the mature structure. The endocrine pancreas is made up of islet cells that produce insulin, glucagon and somatostatin. [GOC:cvs]
Full description |

Standard name | GO_MICROTUBULE_ORGANIZING_CENTER_ORGANIZATION
Systematic name | M2497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a microtubule organizing center, a structure from which microtubules grow. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_ACTOMYOSIN_STRUCTURE_ORGANIZATION
Systematic name | M13335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of cytoskeletal structures containing both actin and myosin or paramyosin. The myosin may be organized into filaments. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_MYOSIN_FILAMENT_ORGANIZATION
Systematic name | M22995
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a filament composed of myosin molecules. [GOC:mah]
Full description |

Standard name | GO_PRIMARY_MIRNA_PROCESSING
Systematic name | M22996
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the conversion of a primary microRNA transcript into a pre-microRNA molecule. [GOC:sl, PMID:15211354]
Full description |

Standard name | GO_PRE_MIRNA_PROCESSING
Systematic name | M14987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the conversion of a pre-microRNA transcript into a mature microRNA molecule. [GOC:sl, PMID:15211354]
Full description |

Standard name | GO_CHROMATIN_REMODELING_AT_CENTROMERE
Systematic name | M22997
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Dynamic structural changes in centromeric DNA. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_MODIFICATION
Systematic name | M22998
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the covalent alteration of a histone. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HISTONE_MODIFICATION
Systematic name | M12072
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the covalent alteration of a histone. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_METHYLATION
Systematic name | M10377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the covalent addition of methyl groups to histones. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HISTONE_METHYLATION
Systematic name | M12540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the covalent addition of methyl groups to histones. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HISTONE_METHYLATION
Systematic name | M15030
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the covalent addition of methyl groups to histones. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_DEACETYLATION
Systematic name | M10600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the removal of acetyl groups from histones. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HISTONE_DEACETYLATION
Systematic name | M22999
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the removal of acetyl groups from histones. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HISTONE_DEACETYLATION
Systematic name | M12235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the removal of acetyl groups from histones. [GOC:mah]
Full description |

Standard name | GO_EMBRYONIC_CAMERA_TYPE_EYE_DEVELOPMENT
Systematic name | M16446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process occurring during the embryonic phase whose specific outcome is the progression of the eye over time, from its formation to the mature structure. [GOC:mah, GOC:mtg_sensu]
Full description |

Standard name | GO_POST_EMBRYONIC_CAMERA_TYPE_EYE_DEVELOPMENT
Systematic name | M23000
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process occurring during the post-embryonic phase whose specific outcome is the progression of the camera-type eye over time, from its formation to the mature structure. [GOC:mah, GOC:mtg_sensu]
Full description |

Standard name | GO_NUCLEAR_TRANSCRIBED_MRNA_CATABOLIC_PROCESS_DEADENYLATION_INDEPENDENT_DECAY
Systematic name | M23001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A pathway of degradation of nuclear-transcribed mRNAs that proceeds through a series of steps that is independent of deadenylation, but requires decapping followed by transcript decay, and that can regulate mRNA stability. [GOC:krc, PMID:15225542, PMID:15225544]
Full description |

Standard name | GO_STRESS_ACTIVATED_PROTEIN_KINASE_SIGNALING_CASCADE
Systematic name | M15977
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which a stress-activated protein kinase (SAPK) cascade relays one or more of the signals. [GOC:mah]
Full description |

Standard name | GO_REGENERATION
Systematic name | M11315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regrowth of a lost or destroyed body part, such as an organ or tissue. This process may occur via renewal, repair, and/or growth alone (i.e. increase in size or mass). [GOC:mah, GOC:pr]
Full description |

Standard name | GO_ANIMAL_ORGAN_REGENERATION
Systematic name | M23002
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regrowth of a lost or destroyed animal organ. [GOC:mah]
Full description |

Standard name | GO_NEURON_PROJECTION_REGENERATION
Systematic name | M14446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regrowth of neuronal processes such as axons or dendrites in response to their loss or damage. [GOC:dgh, GOC:dph, GOC:tb]
Full description |

Standard name | GO_MICROTUBULE_POLYMERIZATION_OR_DEPOLYMERIZATION
Systematic name | M3855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Assembly or disassembly of microtubules by the addition or removal of tubulin heterodimers from a microtubule. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MICROTUBULE_POLYMERIZATION_OR_DEPOLYMERIZATION
Systematic name | M15466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of microtubule polymerization or depolymerization by the addition or removal of tubulin heterodimers from a microtubule. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MICROTUBULE_POLYMERIZATION_OR_DEPOLYMERIZATION
Systematic name | M23003
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of microtubule polymerization or depolymerization. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MICROTUBULE_POLYMERIZATION_OR_DEPOLYMERIZATION
Systematic name | M12519
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of microtubule polymerization or depolymerization. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MICROTUBULE_POLYMERIZATION
Systematic name | M12587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of microtubule polymerization. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MICROTUBULE_DEPOLYMERIZATION
Systematic name | M23004
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of microtubule depolymerization. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MICROTUBULE_POLYMERIZATION
Systematic name | M23005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of microtubule polymerization. [GOC:mah]
Full description |

Standard name | GO_RRNA_PSEUDOURIDINE_SYNTHESIS
Systematic name | M23006
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The intramolecular conversion of uridine to pseudouridine in an rRNA molecule. [GOC:mah]
Full description |

Standard name | GO_TRNA_PSEUDOURIDINE_SYNTHESIS
Systematic name | M23007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The intramolecular conversion of uridine to pseudouridine in a tRNA molecule. [GOC:mah]
Full description |

Standard name | GO_CYTOPLASMIC_MICROTUBULE_ORGANIZATION
Systematic name | M10313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of structures formed of microtubules and associated proteins in the cytoplasm of a cell. [GOC:mah]
Full description |

Standard name | GO_RNA_3_END_PROCESSING
Systematic name | M6392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in forming the mature 3' end of an RNA molecule. [GOC:mah]
Full description |

Standard name | GO_MRNA_3_END_PROCESSING
Systematic name | M13204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in forming the mature 3' end of an mRNA molecule. [GOC:mah]
Full description |

Standard name | GO_RRNA_3_END_PROCESSING
Systematic name | M14706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in forming the mature 3' end of an rRNA molecule. [GOC:mah]
Full description |

Standard name | GO_SNORNA_3_END_PROCESSING
Systematic name | M23008
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in forming the mature 3' end of a snoRNA molecule. [GOC:mah]
Full description |

Standard name | GO_DEVELOPMENTAL_INDUCTION
Systematic name | M11326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process involving two tissues in which one tissue (the inducer) produces a signal that directs cell fate commitment of cells in the second tissue (the responder). [GOC:cjm, GOC:dph, GOC:mah, PMID:24503535]
Full description |

Standard name | GO_REGULATION_OF_AXON_DIAMETER
Systematic name | M23009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, direction or extent of axon growth such that the correct diameter is attained and maintained. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_ANAPHASE_PROMOTING_COMPLEX_DEPENDENT_CATABOLIC_PROCESS
Systematic name | M10781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a protein or peptide by hydrolysis of its peptide bonds, initiated by the covalent attachment of ubiquitin, with ubiquitin-protein ligation catalyzed by the anaphase-promoting complex, and mediated by the proteasome. [GOC:mah, PMID:15380083, PMID:15840442]
Full description |

Standard name | GO_SCF_DEPENDENT_PROTEASOMAL_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS
Systematic name | M14611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a protein or peptide by hydrolysis of its peptide bonds, initiated by the covalent attachment of ubiquitin, with ubiquitin-protein ligation catalyzed by an SCF (Skp1/Cul1/F-box protein) complex, and mediated by the proteasome. [PMID:15380083]
Full description |

Standard name | GO_RRNA_METHYLATION
Systematic name | M16419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The posttranscriptional addition of methyl groups to specific residues in an rRNA molecule. [GOC:mah]
Full description |

Standard name | GO_PEPTIDE_MODIFICATION
Systematic name | M23010
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent alteration of one or more amino acid residues within a peptide, resulting in a change in the properties of that peptide. [GOC:mah]
Full description |

Standard name | GO_POSTTRANSLATIONAL_PROTEIN_TARGETING_TO_MEMBRANE_TRANSLOCATION
Systematic name | M23011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a protein translocates through the ER membrane posttranslationally. [PMID:12518317, PMID:8707814]
Full description |

Standard name | GO_PSEUDOPODIUM_ORGANIZATION
Systematic name | M23012
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a pseudopodium, a temporary protrusion or retractile process of a cell, associated with cellular movement. [GOC:pg]
Full description |

Standard name | GO_REGULATION_OF_PSEUDOPODIUM_ASSEMBLY
Systematic name | M13342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the assembly of pseudopodia. [GOC:pg]
Full description |

Standard name | GO_REGULATION_OF_CYCLASE_ACTIVITY
Systematic name | M23013
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cyclase activity. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYCLASE_ACTIVITY
Systematic name | M23014
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the activity of a cyclase. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_GUANYLATE_CYCLASE_ACTIVITY
Systematic name | M14622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of guanylate cyclase activity. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GUANYLATE_CYCLASE_ACTIVITY
Systematic name | M12125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of guanylate cyclase activity. [GOC:mah]
Full description |

Standard name | GO_RETINAL_GANGLION_CELL_AXON_GUIDANCE
Systematic name | M10833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the migration of an axon growth cone of a retinal ganglion cell (RGC) is directed to its target in the brain in response to a combination of attractive and repulsive cues. [GOC:ejs]
Full description |

Standard name | GO_MEMBRANE_PROTEIN_INTRACELLULAR_DOMAIN_PROTEOLYSIS
Systematic name | M13818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The proteolytic cleavage of a transmembrane protein leading to the release of an intracellular domain. [PMID:12808018]
Full description |

Standard name | GO_LYMPHOCYTE_COSTIMULATION
Systematic name | M11050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of providing, via surface-bound receptor-ligand pairs, a second, antigen-independent, signal in addition to that provided by the B- or T cell receptor to augment B- or T cell activation. [ISBN:0781735149]
Full description |

Standard name | GO_REPLICATION_FORK_PROCESSING
Systematic name | M23015
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a DNA replication fork that has stalled is restored to a functional state and replication is restarted. The stalling may be due to DNA damage, DNA secondary structure, bound proteins, dNTP shortage, or other causes. [GOC:vw, PMID:11459955, PMID:15367656, PMID:17660542]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_BIOSYNTHETIC_PROCESS
Systematic name | M29137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of substances, carried out by individual cells. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_CATABOLIC_PROCESS
Systematic name | M23016
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of substances, carried out by individual cells. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_CATABOLIC_PROCESS
Systematic name | M10886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of substances, carried out by individual cells. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_CONTAINING_COMPLEX_ASSEMBLY
Systematic name | M10120
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of protein complex assembly. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_CONTAINING_COMPLEX_ASSEMBLY
Systematic name | M14368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein complex assembly. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_VESICLE_FUSION
Systematic name | M10251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of vesicle fusion. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VESICLE_FUSION
Systematic name | M23017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of vesicle fusion. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VESICLE_FUSION
Systematic name | M23018
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vesicle fusion. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CELL_KILLING
Systematic name | M16351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell killing, the process in which a cell brings about the death of another cell, either in the same or a different organism. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_KILLING
Systematic name | M16248
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cell killing. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_KILLING
Systematic name | M15464
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell killing. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CELL_PROJECTION_ORGANIZATION
Systematic name | M12444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of cell projections. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_PROJECTION_ORGANIZATION
Systematic name | M14191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of cell projections. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_PROJECTION_ORGANIZATION
Systematic name | M16921
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the process involved in the formation, arrangement of constituent parts, or disassembly of cell projections. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_DEFENSE_RESPONSE
Systematic name | M15277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a defense response. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DEFENSE_RESPONSE
Systematic name | M13454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a defense response. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DEFENSE_RESPONSE
Systematic name | M9888
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of a defense response. [GOC:mah]
Full description |

Standard name | GO_N_TERMINAL_PROTEIN_AMINO_ACID_MODIFICATION
Systematic name | M16453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The alteration of the N-terminal amino acid residue in a protein. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROSTAGLANDIN_BIOSYNTHETIC_PROCESS
Systematic name | M29140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of prostaglandin. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_MODIFICATION_PROCESS
Systematic name | M17904
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the covalent alteration of one or more amino acid residues within a protein. [GOC:mah, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_MODIFICATION_PROCESS
Systematic name | M16497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the covalent alteration of one or more amino acid residues within a protein. [GOC:mah, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_MODIFICATION_PROCESS
Systematic name | M9604
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the covalent alteration of one or more amino acid residues within a protein. [GOC:mah, GOC:tb]
Full description |

Standard name | GO_KERATINIZATION
Systematic name | M15449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the cytoplasm of the outermost cells of the vertebrate epidermis is replaced by keratin. Keratinization occurs in the stratum corneum, feathers, hair, claws, nails, hooves, and horns. [GOC:dph, GOC:ebc, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_RESPONSE_TO_METHOTREXATE
Systematic name | M29141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a methotrexate stimulus. Methotrexate is 4-amino-10-methylformic acid, a folic acid analogue that is a potent competitive inhibitor of dihydrofolate reductase. [GOC:ef, GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_MRNA_3_END_PROCESSING
Systematic name | M12745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mRNA 3'-end processing, any process involved in forming the mature 3' end of an mRNA molecule. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MRNA_3_END_PROCESSING
Systematic name | M23020
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of mRNA 3'-end processing. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MRNA_3_END_PROCESSING
Systematic name | M14424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of mRNA 3'-end processing. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HETEROCHROMATIN_ASSEMBLY
Systematic name | M34124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of heterochromatin formation. [GOC:mah]
Full description |

Standard name | GO_NUCLEAR_ENVELOPE_REASSEMBLY
Systematic name | M10274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The reformation of the nuclear envelope following its breakdown in the context of a normal process. [GOC:mah]
Full description |

Standard name | GO_CHROMATIN_DISASSEMBLY
Systematic name | M12941
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled breakdown of chromatin from a higher order structure into its simpler subcomponents, DNA, histones, other proteins, and sometimes RNA. [http://www.infobiogen.fr/services/chromcancer/IntroItems/ChromatinEducEng.html, PMID:20404130]
Full description |

Standard name | GO_PROTEIN_CONTAINING_COMPLEX_LOCALIZATION
Systematic name | M23022
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A localization process that acts on a protein complex; the complex is transported to, or maintained in, a specific location. [GOC:mah]
Full description |

Standard name | GO_RUFFLE_ORGANIZATION
Systematic name | M16214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a ruffle, a projection at the leading edge of a crawling cell. [GOC:mah, PMID:10036235]
Full description |

Standard name | GO_ACTIN_CYTOSKELETON_REORGANIZATION
Systematic name | M15745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in dynamic structural changes to the arrangement of constituent parts of cytoskeletal structures comprising actin filaments and their associated proteins. [GOC:ecd, GOC:mah]
Full description |

Standard name | GO_BRAIN_DERIVED_NEUROTROPHIC_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23025
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a brain-derived neurotrophic factor receptor binding to one of its physiological ligands. [GOC:mah]
Full description |

Standard name | GO_DNA_INTEGRITY_CHECKPOINT
Systematic name | M16357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle process that controls cell cycle progression in response to changes in DNA structure by monitoring the integrity of the DNA. The DNA integrity checkpoint begins with detection of DNA damage, defects in DNA structure or DNA replication, and progresses through signal transduction and ends with cell cycle effector processes. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_G2_DNA_DAMAGE_CHECKPOINT
Systematic name | M15339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle checkpoint that detects and negatively regulates progression from G2 to M phase in the cell cycle in response to DNA damage. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_INTRA_S_DNA_DAMAGE_CHECKPOINT
Systematic name | M11926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A mitotic cell cycle checkpoint that slows DNA synthesis in response to DNA damage by the prevention of new origin firing and the stabilization of slow replication fork progression. [GOC:vw]
Full description |

Standard name | GO_MEMBRANE_RAFT_ORGANIZATION
Systematic name | M11484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of membrane rafts, small (10-200 nm), heterogeneous, highly dynamic, sterol- and sphingolipid-enriched membrane domains that compartmentalize cellular processes. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_HEMIDESMOSOME_ASSEMBLY
Systematic name | M12305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Assembly of hemidesmosomes, integrin-containing protein complexes that bind to laminin in the basal lamina. Hemidesmosomes form the contact between the basal surface of epithelial cells and the underlying basal lamina. [GOC:dgh, PMID:15983403]
Full description |

Standard name | GO_ACTIVATION_OF_PHOSPHOLIPASE_D_ACTIVITY
Systematic name | M23027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of inactive phospholipase D. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_INOSITOL_1_4_5_TRISPHOSPHATE_SENSITIVE_CALCIUM_RELEASE_CHANNEL_ACTIVITY
Systematic name | M23028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the activity of the inositol 1,4,5-trisphosphate-sensitive calcium-release channel. [GOC:dph, GOC:mah, GOC:signaling]
Full description |

Standard name | GO_CELL_SUBSTRATE_ADHESION
Systematic name | M15640
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a cell to the underlying substrate via adhesion molecules. [GOC:mah, GOC:pf]
Full description |

Standard name | GO_REGULATION_OF_FEVER_GENERATION
Systematic name | M13407
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or extent of fever generation. [GOC:add, GOC:dph, GOC:tb]
Full description |

Standard name | GO_RECEPTOR_INTERNALIZATION
Systematic name | M13598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A receptor-mediated endocytosis process that results in the movement of receptors from the plasma membrane to the inside of the cell. The process begins when cell surface receptors are monoubiquitinated following ligand-induced activation. Receptors are subsequently taken up into endocytic vesicles from where they are either targeted to the lysosome or vacuole for degradation or recycled back to the plasma membrane. [GOC:bf, GOC:mah, GOC:signaling, PMID:15006537, PMID:19643732]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_VESICLE_FUSION_TO_PRESYNAPTIC_ACTIVE_ZONE_MEMBRANE
Systematic name | M23029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of synaptic vesicle fusion to the presynaptic membrane. [GOC:mah]
Full description |

Standard name | GO_ZYMOGEN_ACTIVATION
Systematic name | M16589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The proteolytic processing of an inactive enzyme to an active form. [GOC:hjd]
Full description |

Standard name | GO_PLASMINOGEN_ACTIVATION
Systematic name | M23030
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which inactive plasminogen is processed to active plasmin. This process includes cleavage at an internal Arg-Val site to form an N-terminal A-chain and C-terminal B-chain held together by a disulfide bond, and can include further proteolytic cleavage events to remove the preactivation peptide. [PMID:9548733]
Full description |

Standard name | GO_KILLING_OF_CELLS_OF_OTHER_ORGANISM
Systematic name | M23031
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in an organism that results in the killing of cells of another organism, including in some cases the death of the other organism. Killing here refers to the induction of death in one cell by another cell, not cell-autonomous death due to internal or other environmental conditions. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_MYELINATION
Systematic name | M11417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the formation of a myelin sheath around nerve axons. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MYELINATION
Systematic name | M23032
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the formation of a myelin sheath around nerve axons. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MYELINATION
Systematic name | M16608
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the formation of a myelin sheath around nerve axons. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_NERVOUS_SYSTEM_PROCESS
Systematic name | M13921
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a neurophysiological process, an organ system process carried out by any of the organs or tissues of the nervous system. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NERVOUS_SYSTEM_PROCESS
Systematic name | M11186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a neurophysiological process. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NERVOUS_SYSTEM_PROCESS
Systematic name | M13905
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of a neurophysiological process. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_STABILITY
Systematic name | M13931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that affects the structure and integrity of a protein, altering the likelihood of its degradation or aggregation. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_PROTEIN_DESTABILIZATION
Systematic name | M12462
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the stability of a protein, making it more vulnerable to degradative processes or aggregation. [GOC:mah]
Full description |

Standard name | GO_HEAT_GENERATION
Systematic name | M23033
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any homeostatic process in which an organism produces heat, thereby raising its internal temperature. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_HEAT_GENERATION
Systematic name | M11308
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or extent of heat generation. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HEAT_GENERATION
Systematic name | M23034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of heat generation. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_LIPOPOLYSACCHARIDE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M14323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a lipopolysaccharide (LPS) to a receptor on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. Lipopolysaccharides are major components of the outer membrane of Gram-negative bacteria, making them prime targets for recognition by the immune system. [GOC:mah, GOC:signaling, PMID:15379975]
Full description |

Standard name | GO_REGULATION_OF_LIPOPOLYSACCHARIDE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M13762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of signaling in response to detection of lipopolysaccharide. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPOPOLYSACCHARIDE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M23035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of signaling in response to detection of lipopolysaccharide. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPOPOLYSACCHARIDE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M23036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signaling in response to detection of lipopolysaccharide. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_EXTRACELLULAR_STIMULUS
Systematic name | M10947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an extracellular stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_NUTRIENT
Systematic name | M14078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nutrient stimulus. [GOC:mah]
Full description |

Standard name | GO_PROTECTION_FROM_NON_HOMOLOGOUS_END_JOINING_AT_TELOMERE
Systematic name | M23037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that prevents non-homologous end joining at telomere, thereby ensuring that telomeres do not fuse. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SYNAPTIC_PLASTICITY
Systematic name | M23038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that decreases synaptic plasticity, the ability of synapses to change as circumstances require. They may alter function, such as increasing or decreasing their sensitivity, or they may increase or decrease in actual numbers. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPTIC_PLASTICITY
Systematic name | M23039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that increases synaptic plasticity, the ability of synapses to change as circumstances require. They may alter function, such as increasing or decreasing their sensitivity, or they may increase or decrease in actual numbers. [GOC:mah]
Full description |

Standard name | GO_TOR_SIGNALING
Systematic name | M14826
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by TOR (Target of rapamycin) proteins, members of the phosphoinositide (PI) 3-kinase related kinase (PIKK) family that act as serine/threonine kinases in response to nutrient availability or growth factors. [PMID:12372295]
Full description |

Standard name | GO_REGULATION_OF_CHROMATIN_SILENCING
Systematic name | M12575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that affects the rate, extent or location of chromatin silencing. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHROMATIN_SILENCING
Systematic name | M23040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of chromatin silencing. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_GLUCOCORTICOID_METABOLIC_PROCESS
Systematic name | M23042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving glucocorticoids. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLUCOCORTICOID_METABOLIC_PROCESS
Systematic name | M23043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving glucocorticoids. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_GLUCOCORTICOID_BIOSYNTHETIC_PROCESS
Systematic name | M23044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of glucocorticoids. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_AUTOPHOSPHORYLATION
Systematic name | M14909
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of addition of the phosphorylation by a protein of one or more of its own residues. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_AUTOPHOSPHORYLATION
Systematic name | M10366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or decreases the rate of the phosphorylation by a protein of one or more of its own residues. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_AUTOPHOSPHORYLATION
Systematic name | M13383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the phosphorylation by a protein of one or more of its own residues. [GOC:mah]
Full description |

Standard name | GO_CORTICOSTEROID_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of a corticosteroid binding to its receptor. [GOC:mah, PMID:11027914, PMID:12606724]
Full description |

Standard name | GO_RESPONSE_TO_CORTICOSTEROID
Systematic name | M10764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a corticosteroid hormone stimulus. A corticosteroid is a steroid hormone that is produced in the adrenal cortex. Corticosteroids are involved in a wide range of physiologic systems such as stress response, immune response and regulation of inflammation, carbohydrate metabolism, protein catabolism, blood electrolyte levels, and behavior. They include glucocorticoids and mineralocorticoids. [GOC:mah, PMID:11027914]
Full description |

Standard name | GO_LOCOMOTION_INVOLVED_IN_LOCOMOTORY_BEHAVIOR
Systematic name | M23046
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Self-propelled movement of a cell or organism from one location to another in a behavioral context; the aspect of locomotory behavior having to do with movement. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_FATTY_ACID_BETA_OXIDATION
Systematic name | M16969
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of fatty acid bbeta-oxidation. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FATTY_ACID_BETA_OXIDATION
Systematic name | M23047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of fatty acid beta-oxidation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FATTY_ACID_BETA_OXIDATION
Systematic name | M23048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of fatty acid beta-oxidation. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_TOR_SIGNALING
Systematic name | M29142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of TOR signaling. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TOR_SIGNALING
Systematic name | M13058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of TOR signaling. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TOR_SIGNALING
Systematic name | M11042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of TOR signaling. [GOC:mah]
Full description |

Standard name | GO_ARF_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M23049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals within the cell that are mediated by a member of the ARF family of proteins switching to a GTP-bound active state. [GOC:mah]
Full description |

Standard name | GO_ISG15_PROTEIN_CONJUGATION
Systematic name | M23050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent addition to a protein of ISG15, a ubiquitin-like protein. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INSULIN_SECRETION
Systematic name | M12237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the regulated release of insulin. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_COBALT_ION
Systematic name | M15970
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cobalt ion stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_MAGNESIUM_ION
Systematic name | M12099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a magnesium ion stimulus. [GOC:mah]
Full description |

Standard name | GO_MITOCHONDRIAL_DNA_METABOLIC_PROCESS
Systematic name | M10830
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving mitochondrial DNA. [GOC:mah]
Full description |

Standard name | GO_CARDIOLIPIN_METABOLIC_PROCESS
Systematic name | M14807
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving cardiolipin, 1,3-bis(3-phosphatidyl)glycerol. [GOC:mah]
Full description |

Standard name | GO_CARDIOLIPIN_BIOSYNTHETIC_PROCESS
Systematic name | M34125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of cardiolipin, 1,3-bis(3-phosphatidyl)glycerol. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSLATION_IN_RESPONSE_TO_STRESS
Systematic name | M23051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate of translation as a result of a stimulus indicating the organism is under stress. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSLATION_IN_RESPONSE_TO_STRESS
Systematic name | M23052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of translation as a result of a stimulus indicating the organism is under stress. [GOC:mah]
Full description |

Standard name | GO_BLEB_ASSEMBLY
Systematic name | M23053
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The assembly of a bleb, a cell extension caused by localized decoupling of the cytoskeleton from the plasma membrane and characterized by rapid formation, rounded shape, and scarcity of organelles within the protrusion. Plasma membrane blebbing occurs during apoptosis and other cellular processes, including cell locomotion, cell division, and as a result of physical or chemical stresses. [GOC:mah, GOC:mtg_apoptosis, PMID:12083798, PMID:16624291, Wikipedia:Bleb_(cell_biology)]
Full description |

Standard name | GO_REGULATION_OF_NUCLEASE_ACTIVITY
Systematic name | M11879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of nuclease activity, the hydrolysis of ester linkages within nucleic acids. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_DEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M23054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of deoxyribonuclease activity, the hydrolysis of ester linkages within deoxyribonucleic acid. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ENDODEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M23055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endodeoxyribonuclease activity, the hydrolysis of ester linkages within deoxyribonucleic acid by creating internal breaks. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NUCLEASE_ACTIVITY
Systematic name | M23056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate of nuclease activity, the hydrolysis of ester linkages within nucleic acids. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NUCLEASE_ACTIVITY
Systematic name | M15465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of nuclease activity, the hydrolysis of ester linkages within nucleic acids. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M23057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of deoxyribonuclease activity, the hydrolysis of ester linkages within deoxyribonucleic acid. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NF_KAPPAB_TRANSCRIPTION_FACTOR_ACTIVITY
Systematic name | M12742
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the activity of the transcription factor NF-kappaB. [GOC:dph, GOC:rl, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_BINDING
Systematic name | M12295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of protein binding. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_BINDING
Systematic name | M10240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein binding. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_FOOD
Systematic name | M11257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a food stimulus; food is anything which, when taken into the body, serves to nourish or build up the tissues or to supply body heat. [GOC:add, ISBN:0721601464]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_FOOD
Systematic name | M13051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a response to a food stimulus. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_APPETITE
Systematic name | M14263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which modulates appetite, the desire or physical craving for food. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_EXTERNAL_STIMULUS
Systematic name | M14548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a response to an external stimulus. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_EXTERNAL_STIMULUS
Systematic name | M16887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a response to an external stimulus. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_EXTERNAL_STIMULUS
Systematic name | M12127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the rate of a response to an external stimulus. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_EXTRACELLULAR_STIMULUS
Systematic name | M10887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a response to an extracellular stimulus. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_EXTRACELLULAR_STIMULUS
Systematic name | M13083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a response to an extracellular stimulus. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_EXTRACELLULAR_STIMULUS
Systematic name | M14061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the rate of a response to an extracellular stimulus. [GOC:mah]
Full description |

Standard name | GO_SEQUESTERING_OF_ZINC_ION
Systematic name | M23058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of binding or confining zinc ions such that they are separated from other components of a biological system. [GOC:mah]
Full description |

Standard name | GO_ACTIVATION_OF_PROTEIN_KINASE_ACTIVITY
Systematic name | M15758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of an inactive protein kinase. [GOC:mah]
Full description |

Standard name | GO_ACTIVATION_OF_PROTEIN_KINASE_B_ACTIVITY
Systematic name | M14938
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of the inactive enzyme protein kinase B. [GOC:pg]
Full description |

Standard name | GO_TRANSPOSITION
Systematic name | M23059
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in mediating the movement of discrete segments of DNA between nonhomologous sites. [GOC:jp, ISBN:1555812090]
Full description |

Standard name | GO_TRANSPOSITION_RNA_MEDIATED
Systematic name | M23060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in a type of transpositional recombination which occurs via an RNA intermediate. [GOC:jp, ISBN:1555812090]
Full description |

Standard name | GO_TELOMERE_ORGANIZATION
Systematic name | M11260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of telomeres, terminal regions of a linear chromosome that include the telomeric DNA repeats and associated proteins. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_TELOMERE_MAINTENANCE_VIA_SEMI_CONSERVATIVE_REPLICATION
Systematic name | M23061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which telomeric DNA is synthesized semi-conservatively by the conventional replication machinery and telomeric accessory factors as part of cell cycle DNA replication. [GOC:BHF, GOC:BHF_telomere, GOC:rl, GOC:vw, PMID:16598261]
Full description |

Standard name | GO_TELOMERE_ASSEMBLY
Systematic name | M34126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the aggregation, arrangement and bonding together of a set of components to form a telomere at a non-telomeric double-stranded DNA end. A telomere is a terminal region of a linear chromosome that includes telomeric DNA repeats and associated proteins. [GOC:mah, GOC:ns, PMID:11902675, PMID:8622671]
Full description |

Standard name | GO_REGULATION_OF_TELOMERE_MAINTENANCE
Systematic name | M12223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a process that affects and monitors the activity of telomeric proteins and the length of telomeric DNA. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TELOMERE_MAINTENANCE
Systematic name | M15180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a process that affects and monitors the activity of telomeric proteins and the length of telomeric DNA. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TELOMERE_MAINTENANCE
Systematic name | M14393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of a process that affects and monitors the activity of telomeric proteins and the length of telomeric DNA. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TELOMERE_MAINTENANCE_VIA_TELOMERASE
Systematic name | M10472
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the addition of telomeric repeats by telomerase. [GOC:mah]
Full description |

Standard name | GO_RIBOFLAVIN_TRANSPORT
Systematic name | M29143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of riboflavin into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Riboflavin (vitamin B2) is a water-soluble B-complex vitamin, converted in the cell to FMN and FAD, cofactors required for the function of flavoproteins. [GOC:rn, PMID:16204239]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_TRANSMISSION_CHOLINERGIC
Systematic name | M23062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cholinergic synaptic transmission, the process of communication from a neuron to another neuron across a synapse using the neurotransmitter acetylcholine. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_TRANSMISSION_DOPAMINERGIC
Systematic name | M16908
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of dopaminergic synaptic transmission, the process of communication from a neuron to another neuron across a synapse using the neurotransmitter dopamine. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPTIC_TRANSMISSION_DOPAMINERGIC
Systematic name | M23063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of dopaminergic synaptic transmission, the process of communication from a neuron to another neuron across a synapse using the neurotransmitter dopamine. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_TRANSMISSION_GABAERGIC
Systematic name | M15100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of GABAergic synaptic transmission, the process of communication from a neuron to another neuron across a synapse using the neurotransmitter gamma-aminobutyric acid (GABA). [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SYNAPTIC_TRANSMISSION_GABAERGIC
Systematic name | M23064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of GABAergic synaptic transmission, the process of communication from a neuron to another neuron across a synapse using the neurotransmitter gamma-aminobutyric acid (GABA). [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPTIC_TRANSMISSION_GABAERGIC
Systematic name | M16438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of GABAergic synaptic transmission, the process of communication from a neuron to another neuron across a synapse using the neurotransmitter gamma-aminobutyric acid (GABA). [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ACTIN_FILAMENT_BUNDLE_ASSEMBLY
Systematic name | M14318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the assembly of actin filament bundles. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ACTIN_FILAMENT_BUNDLE_ASSEMBLY
Systematic name | M12994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the assembly of actin filament bundles. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACTIN_FILAMENT_BUNDLE_ASSEMBLY
Systematic name | M15855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the assembly of actin filament bundles. [GOC:mah]
Full description |

Standard name | GO_ACTIVATION_OF_STORE_OPERATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M23065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that initiates the activity of an inactive store-operated calcium channel. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_NUCLEOBASE_CONTAINING_COMPOUND_TRANSPORT
Systematic name | M11708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of nucleobases, nucleosides, nucleotides and nucleic acids, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NUCLEOBASE_CONTAINING_COMPOUND_TRANSPORT
Systematic name | M23066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of nucleobases, nucleosides, nucleotides and nucleic acids, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_SECRETORY_GRANULE_LOCALIZATION
Systematic name | M23067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a secretory granule is transported to, and/or maintained in, a specific location within the cell. [GOC:mah]
Full description |

Standard name | GO_METHYLATION
Systematic name | M15919
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a methyl group is covalently attached to a molecule. [GOC:mah]
Full description |

Standard name | GO_PURINE_NUCLEOTIDE_SALVAGE
Systematic name | M23068
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which produces a purine nucleotide from derivatives of it, without de novo synthesis. [GOC:jp]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOTIDE_SALVAGE
Systematic name | M23069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which produces a pyrimidine nucleotide from derivatives of it, without de novo synthesis. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_POLYMERIZATION
Systematic name | M10309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the process of creating protein polymers. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_POLYMERIZATION
Systematic name | M10892
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the process of creating protein polymers. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_POLYMERIZATION
Systematic name | M16100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the process of creating protein polymers. [GOC:mah]
Full description |

Standard name | GO_GONADOTROPIN_SECRETION
Systematic name | M23070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of a gonadotropin, any hormone that stimulates the gonads, especially follicle-stimulating hormone and luteinizing hormone. [GOC:mah, ISBN:0721662544]
Full description |

Standard name | GO_LUTEINIZING_HORMONE_SECRETION
Systematic name | M23071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of luteinizing hormone, a gonadotropic glycoprotein hormone secreted by the anterior pituitary. [ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_GONADOTROPIN_SECRETION
Systematic name | M16612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of a gonadotropin. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GONADOTROPIN_SECRETION
Systematic name | M23072
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the regulated release of a gonadotropin. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GONADOTROPIN_SECRETION
Systematic name | M23073
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the regulated release of a gonadotropin. [GOC:mah]
Full description |

Standard name | GO_CENTRAL_NERVOUS_SYSTEM_MYELIN_MAINTENANCE
Systematic name | M29144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the structure and material content of mature central nervous system myelin is kept in a functional state. [GOC:dgh]
Full description |

Standard name | GO_PERIPHERAL_NERVOUS_SYSTEM_MYELIN_MAINTENANCE
Systematic name | M23074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the structure and material content of mature peripheral nervous system myelin is kept in a functional state. [GOC:dgh]
Full description |

Standard name | GO_MYELIN_ASSEMBLY
Systematic name | M14856
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the wraps of cell membrane that constitute myelin are laid down around an axon in the central or peripheral nervous system. [GOC:dgh, GOC:dph, GOC:tb]
Full description |

Standard name | GO_AXON_ENSHEATHMENT_IN_CENTRAL_NERVOUS_SYSTEM
Systematic name | M12986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a glial cell membrane closes around an axon in the central nervous system. This can be a myelinating or a non-myelinating neuron-glial interaction. [GOC:dgh]
Full description |

Standard name | GO_REGULATION_OF_ICOSANOID_SECRETION
Systematic name | M10374
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the controlled release of an icosanoid from a cell. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PROSTAGLANDIN_SECRETION
Systematic name | M10560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of a prostaglandin from a cell. [GOC:mah]
Full description |

Standard name | GO_PROSTAGLANDIN_SECRETION
Systematic name | M29145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of a prostaglandin, any of a group of biologically active metabolites which contain a cyclopentane ring, from a cell or a tissue. [GOC:mah]
Full description |

Standard name | GO_ALANINE_TRANSPORT
Systematic name | M23076
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of alanine, 2-aminopropanoic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_SERINE_TRANSPORT
Systematic name | M23077
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-serine, 2-amino-3-hydroxypropanoic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CHONDROCYTE_DIFFERENTIATION
Systematic name | M13341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of chondrocyte differentiation. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHONDROCYTE_DIFFERENTIATION
Systematic name | M16573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of chondrocyte differentiation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHONDROCYTE_DIFFERENTIATION
Systematic name | M16272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of chondrocyte differentiation. [GOC:mah]
Full description |

Standard name | GO_ALDOSTERONE_METABOLIC_PROCESS
Systematic name | M29146
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving aldosterone, a corticosteroid hormone that is produced by the zona glomerulosa of the adrenal cortex and regulates salt (sodium and potassium) and water balance. [PMID:16527843]
Full description |

Standard name | GO_REGULATION_OF_ALDOSTERONE_METABOLIC_PROCESS
Systematic name | M23078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving aldosterone. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_HORMONE_METABOLIC_PROCESS
Systematic name | M15585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving any hormone. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HORMONE_METABOLIC_PROCESS
Systematic name | M23079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving any hormone. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HORMONE_METABOLIC_PROCESS
Systematic name | M11648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving any hormone. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HORMONE_BIOSYNTHETIC_PROCESS
Systematic name | M34127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of hormones. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_FOLLICLE_STIMULATING_HORMONE
Systematic name | M13287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a follicle-stimulating hormone stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_ESTRADIOL
Systematic name | M10509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of stimulus by estradiol, a C18 steroid hormone hydroxylated at C3 and C17 that acts as a potent estrogen. [GOC:mah, ISBN:0911910123]
Full description |

Standard name | GO_OXYGEN_HOMEOSTASIS
Systematic name | M23080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A homeostatic process involved in the maintenance of an internal steady state of oxygen within an organism or cell. [GOC:rph]
Full description |

Standard name | GO_INTRACELLULAR_LIPID_TRANSPORT
Systematic name | M15177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of lipids within cells. [GOC:mah]
Full description |

Standard name | GO_INTRACELLULAR_STEROL_TRANSPORT
Systematic name | M23081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of sterols within cells. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_LIPID_TRANSPORT
Systematic name | M13620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of lipids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPID_TRANSPORT
Systematic name | M14419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of lipids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPID_TRANSPORT
Systematic name | M11731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of lipids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_STEROL_TRANSPORT
Systematic name | M14231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of sterols into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_STEROL_TRANSPORT
Systematic name | M15259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of sterols into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STEROL_TRANSPORT
Systematic name | M11339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of sterols into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_INTRACELLULAR_LIPID_TRANSPORT
Systematic name | M23082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of lipids within cells. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_INTRACELLULAR_TRANSPORT
Systematic name | M16149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of substances within cells. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTRACELLULAR_TRANSPORT
Systematic name | M16766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of substances within cells. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTRACELLULAR_TRANSPORT
Systematic name | M11997
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of substances within cells. [GOC:mah]
Full description |

Standard name | GO_DNA_GEOMETRIC_CHANGE
Systematic name | M14621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a transformation is induced in the geometry of a DNA double helix, resulting in a change in twist, writhe, or both, but with no change in linking number. Includes the unwinding of double-stranded DNA by helicases. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_TRANSPORTER_ACTIVITY
Systematic name | M12446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the activity of a transporter. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSPORTER_ACTIVITY
Systematic name | M10492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the activity of a transporter. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSPORTER_ACTIVITY
Systematic name | M10937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the activity of a transporter. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_SODIUM_PROTON_ANTIPORTER_ACTIVITY
Systematic name | M23084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the activity of a sodium:hydrogen antiporter, which catalyzes the reaction: Na+(out) + H+(in) = Na+(in) + H+(out). [GOC:mah, GOC:mtg_transport]
Full description |

Standard name | GO_LYSOSOME_LOCALIZATION
Systematic name | M13021
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a lysosome is transported to, and/or maintained in, a specific location. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHOLIPASE_A2_ACTIVITY
Systematic name | M14268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the activity of the enzyme phospholipase A2. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHOSPHOLIPASE_A2_ACTIVITY
Systematic name | M23085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the activity of the enzyme phospholipase A2. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PROTEASOMAL_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS
Systematic name | M10362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the breakdown of a protein or peptide by hydrolysis of its peptide bonds, initiated by the covalent attachment of ubiquitin, and mediated by the proteasome. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEASOMAL_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS
Systematic name | M23086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the breakdown of a protein or peptide by hydrolysis of its peptide bonds, initiated by the covalent attachment of ubiquitin, and mediated by the proteasome. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_MODIFICATION_BY_SMALL_PROTEIN_CONJUGATION
Systematic name | M3309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein modification process in which one or more groups of a small protein, such as ubiquitin or a ubiquitin-like protein, are covalently attached to a target protein. [GOC:mah]
Full description |

Standard name | GO_ENDOCYTIC_RECYCLING
Systematic name | M14656
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of membrane-bounded vesicles from recycling endosomes back to the plasma membrane where they are recycled for further rounds of transport. [GOC:ecd, PMID:16473635]
Full description |

Standard name | GO_REGULATION_OF_CYTOKINESIS
Systematic name | M13390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the division of the cytoplasm of a cell and its separation into two daughter cells. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYTOKINESIS
Systematic name | M23090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the division of the cytoplasm of a cell, and its separation into two daughter cells. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOKINESIS
Systematic name | M13553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the division of the cytoplasm of a cell, and its separation into two daughter cells. [GOC:mah]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_CALCIUM_ION_HOMEOSTASIS
Systematic name | M14124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of calcium ions within the endoplasmic reticulum of a cell or between the endoplasmic reticulum and its surroundings. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ENDOPLASMIC_RETICULUM_CALCIUM_ION_CONCENTRATION
Systematic name | M23091
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the concentration of calcium ions in the endoplasmic reticulum. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TYPE_I_INTERFERON_PRODUCTION
Systematic name | M11365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of type I interferon production. Type I interferons include the interferon-alpha, beta, delta, episilon, zeta, kappa, tau, and omega gene families. [GOC:add, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TYPE_I_INTERFERON_PRODUCTION
Systematic name | M10589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of type I interferon production. Type I interferons include the interferon-alpha, beta, delta, episilon, zeta, kappa, tau, and omega gene families. [GOC:add, GOC:mah]
Full description |

Standard name | GO_RAB_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M23092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals within the cell that are mediated by a member of the Rab family of proteins switching to a GTP-bound active state. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_RAB_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M34128
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of Rab protein signal transduction. [GOC:mah]
Full description |

Standard name | GO_RAP_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M23093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals within the cell that are mediated by a member of the Rap family of proteins switching to a GTP-bound active state. [GOC:mah]
Full description |

Standard name | GO_CDC42_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M8454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals within the cell that are mediated by the Cdc42 protein switching to a GTP-bound active state. [GOC:mah, PMID:18558478]
Full description |

Standard name | GO_REGULATION_OF_CDC42_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M23095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of Cdc42 protein signal transduction. [GOC:mah]
Full description |

Standard name | GO_DETECTION_OF_MOLECULE_OF_BACTERIAL_ORIGIN
Systematic name | M13529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a stimulus from a molecule of bacterial origin is received and converted into a molecular signal. [GOC:add, GOC:rl]
Full description |

Standard name | GO_RESPONSE_TO_BACTERIAL_LIPOPROTEIN
Systematic name | M23096
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a bacterial lipoprotein stimulus. [GOC:add, PMID:12077222]
Full description |

Standard name | GO_RESPONSE_TO_PEPTIDOGLYCAN
Systematic name | M23097
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptidoglycan stimulus. Peptidoglycan is a bacterial cell wall macromolecule. [GOC:add, ISBN:0721601464]
Full description |

Standard name | GO_RESPONSE_TO_MURAMYL_DIPEPTIDE
Systematic name | M11624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a muramyl dipeptide stimulus. Muramyl dipeptide is derived from peptidoglycan. [GOC:add]
Full description |

Standard name | GO_MULTICELLULAR_ORGANISM_REPRODUCTION
Systematic name | M16042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process in which new individuals are produced by one or two multicellular organisms. The new individuals inherit some proportion of their genetic material from the parent or parents. [GOC:isa_complete, GOC:jid]
Full description |

Standard name | GO_CYTOKINETIC_PROCESS
Systematic name | M11663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that is involved in cytokinesis (the division of the cytoplasm of a cell and its separation into two daughter cells). [GOC:bf, GOC:isa_complete, GOC:mah]
Full description |

Standard name | GO_MAINTENANCE_OF_PROTEIN_LOCATION_IN_CELL
Systematic name | M23098
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is maintained in a specific location within, or in the membrane of, a cell, and is prevented from moving elsewhere. [GOC:isa_complete, GOC:mah]
Full description |

Standard name | GO_ENDOSOME_TO_LYSOSOME_TRANSPORT_VIA_MULTIVESICULAR_BODY_SORTING_PATHWAY
Systematic name | M23100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from endosomes to lysosomes by a pathway in which molecules are sorted into multivesicular bodies, which then fuse with the lysosome. [GOC:mah, PMID:12461556, PMID:16689637]
Full description |

Standard name | GO_LATE_ENDOSOME_TO_VACUOLE_TRANSPORT_VIA_MULTIVESICULAR_BODY_SORTING_PATHWAY
Systematic name | M23101
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from endosomes to vacuoles by a pathway in which molecules are sorted into multivesicular bodies, which then fuse with the vacuole. [GOC:mah, PMID:12461556, PMID:16689637]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHOSPHOPROTEIN_PHOSPHATASE_ACTIVITY
Systematic name | M12844
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the activity of a phosphoprotein phosphatase. [GOC:mah]
Full description |

Standard name | GO_SOMITE_ROSTRAL_CAUDAL_AXIS_SPECIFICATION
Systematic name | M23102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment, maintenance and elaboration of the rostro-caudal axis of a somite, prior to the morphological formation of a somite boundary. [GOC:bf, PMID:16326386, PMID:17360776]
Full description |

Standard name | GO_RESPONSE_TO_RETINOIC_ACID
Systematic name | M15050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a retinoic acid stimulus. [GOC:sl]
Full description |

Standard name | GO_PROTEIN_EXIT_FROM_ENDOPLASMIC_RETICULUM
Systematic name | M16400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of proteins from the endoplasmic reticulum. [GOC:rb]
Full description |

Standard name | GO_MICROVILLUS_ORGANIZATION
Systematic name | M15796
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a microvillus, a thin cylindrical membrane-covered projection on the surface of a cell. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MICROVILLUS_ORGANIZATION
Systematic name | M14610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of a microvillus. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MICROVILLUS_LENGTH
Systematic name | M23103
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates the length of a microvillus. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MICROVILLUS_ASSEMBLY
Systematic name | M23104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates the formation of a microvillus. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_COMPONENT_SIZE
Systematic name | M577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates the size of a cellular component. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CELL_PROJECTION_SIZE
Systematic name | M16275
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates the size of a cell projection. [GOC:mah]
Full description |

Standard name | GO_MITOCHONDRIAL_TRANSLATION
Systematic name | M11131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a protein in a mitochondrion. This is a ribosome-mediated process in which the information in messenger RNA (mRNA) is used to specify the sequence of amino acids in the protein; the mitochondrion has its own ribosomes and transfer RNAs, and uses a genetic code that differs from the nuclear code. [GOC:go_curators]
Full description |

Standard name | GO_RESPONSE_TO_PROGESTERONE
Systematic name | M14163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a progesterone stimulus. [GOC:sl]
Full description |

Standard name | GO_PROTEIN_TRANSPORT_WITHIN_LIPID_BILAYER
Systematic name | M23105
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein from one location to another within a lipid bilayer. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_TRANSPORT_INTO_MEMBRANE_RAFT
Systematic name | M23106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein into a membrane raft. Membrane rafts are small (10-200 nm), heterogeneous, highly dynamic, sterol- and sphingolipid-enriched membrane domains that compartmentalize cellular processes. [GOC:mah]
Full description |

Standard name | GO_CHEMOKINE_PRODUCTION
Systematic name | M23107
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of a chemokine due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_GRANULOCYTE_MACROPHAGE_COLONY_STIMULATING_FACTOR_PRODUCTION
Systematic name | M23108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of granulocyte macrophage colony-stimulating factor due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_TYPE_I_INTERFERON_PRODUCTION
Systematic name | M23109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of type I interferon due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. Type I interferons include the interferon-alpha, beta, delta, episilon, zeta, kappa, tau, and omega gene families. [GOC:add, ISBN:0126896631, PMID:15546383, PMID:16681834]
Full description |

Standard name | GO_INTERFERON_ALPHA_PRODUCTION
Systematic name | M23110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interferon-alpha due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah, PMID:15546383]
Full description |

Standard name | GO_INTERFERON_BETA_PRODUCTION
Systematic name | M23111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interferon-beta due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah, PMID:15546383]
Full description |

Standard name | GO_INTERFERON_GAMMA_PRODUCTION
Systematic name | M6428
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interferon-gamma due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. Interferon-gamma is also known as type II interferon. [GOC:add, GOC:mah, PMID:15546383]
Full description |

Standard name | GO_INTERLEUKIN_1_ALPHA_PRODUCTION
Systematic name | M23112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-1 alpha due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_1_BETA_PRODUCTION
Systematic name | M23113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-1 beta due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_1_PRODUCTION
Systematic name | M11670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-1 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_10_PRODUCTION
Systematic name | M23114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-10 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_12_PRODUCTION
Systematic name | M23115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-12 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_13_PRODUCTION
Systematic name | M23116
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-13 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_17_PRODUCTION
Systematic name | M23117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of any member of the interleukin-17 family of cytokines due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah, GOC:rv, Wikipedia:Interleukin_17]
Full description |

Standard name | GO_INTERLEUKIN_18_PRODUCTION
Systematic name | M23118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-18 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_2_PRODUCTION
Systematic name | M6766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-2 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_21_PRODUCTION
Systematic name | M34129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-21 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_23_PRODUCTION
Systematic name | M23120
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-23 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_4_PRODUCTION
Systematic name | M23121
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-4 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_5_PRODUCTION
Systematic name | M23122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-5 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_6_PRODUCTION
Systematic name | M23123
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-6 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_8_PRODUCTION
Systematic name | M18749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of interleukin-8 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_INTERLEUKIN_18_PRODUCTION
Systematic name | M23125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of interleukin-18 production. [GOC:mah, PMID:23710316]
Full description |

Standard name | GO_REGULATION_OF_INTERLEUKIN_21_PRODUCTION
Systematic name | M34130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of interleukin-21 production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHEMOKINE_PRODUCTION
Systematic name | M14846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of chemokine production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERFERON_ALPHA_PRODUCTION
Systematic name | M23126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interferon-alpha production. [GOC:mah, PMID:15546383]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERFERON_BETA_PRODUCTION
Systematic name | M23127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interferon-beta production. [GOC:mah, PMID:15546383]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERFERON_GAMMA_PRODUCTION
Systematic name | M12740
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interferon-gamma production. Interferon-gamma is also known as type II interferon. [GOC:add, GOC:mah, PMID:15546383]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_1_ALPHA_PRODUCTION
Systematic name | M34131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-1 alpha production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_1_BETA_PRODUCTION
Systematic name | M34132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-1 beta production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_1_PRODUCTION
Systematic name | M10557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-1 production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_10_PRODUCTION
Systematic name | M12756
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-10 production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_12_PRODUCTION
Systematic name | M14223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-12 production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_13_PRODUCTION
Systematic name | M23128
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-13 production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_17_PRODUCTION
Systematic name | M16185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of production of any member of the interleukin-17 family of cytokines. [GOC:add, GOC:mah, PMID:16482511]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_2_PRODUCTION
Systematic name | M16961
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-2 production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_4_PRODUCTION
Systematic name | M23129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-4 production. [GOC:mah, PMID:29778524]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_5_PRODUCTION
Systematic name | M23130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-5 production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_6_PRODUCTION
Systematic name | M11987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-6 production. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_8_PRODUCTION
Systematic name | M14166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-8 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHEMOKINE_PRODUCTION
Systematic name | M13752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of chemokine production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GRANULOCYTE_MACROPHAGE_COLONY_STIMULATING_FACTOR_PRODUCTION
Systematic name | M23131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of granulocyte macrophage colony-stimulating factor production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERFERON_ALPHA_PRODUCTION
Systematic name | M15178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interferon-alpha production. [GOC:mah, PMID:15546383]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERFERON_BETA_PRODUCTION
Systematic name | M12719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interferon-beta production. [GOC:mah, PMID:15546383]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERFERON_GAMMA_PRODUCTION
Systematic name | M16043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interferon-gamma production. Interferon-gamma is also known as type II interferon. [GOC:add, GOC:mah, PMID:15546383]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_1_PRODUCTION
Systematic name | M13347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-1 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_10_PRODUCTION
Systematic name | M16084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-10 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_12_PRODUCTION
Systematic name | M12535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-12 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_13_PRODUCTION
Systematic name | M15396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-13 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_17_PRODUCTION
Systematic name | M14667
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of production of any member of the interleukin-17 family of cytokines. [GOC:add, GOC:mah, PMID:16482511]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_18_PRODUCTION
Systematic name | M34133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-18 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_2_PRODUCTION
Systematic name | M15337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-2 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_23_PRODUCTION
Systematic name | M23133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-23 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_4_PRODUCTION
Systematic name | M14293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-4 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_5_PRODUCTION
Systematic name | M23134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-5 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_6_PRODUCTION
Systematic name | M16211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-6 production. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTERLEUKIN_8_PRODUCTION
Systematic name | M10636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of interleukin-8 production. [GOC:mah]
Full description |

Standard name | GO_MAST_CELL_CYTOKINE_PRODUCTION
Systematic name | M23135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that contributes to cytokine production by a mast cell. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MAST_CELL_CYTOKINE_PRODUCTION
Systematic name | M23136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of mast cell cytokine production. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MONOOXYGENASE_ACTIVITY
Systematic name | M10701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the activity of a monooxygenase. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MONOOXYGENASE_ACTIVITY
Systematic name | M14880
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the activity of a monooxygenase. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MONOOXYGENASE_ACTIVITY
Systematic name | M15792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the activity of a monooxygenase. [GOC:mah]
Full description |

Standard name | GO_DNA_METHYLATION_ON_CYTOSINE
Systematic name | M23137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent transfer of a methyl group to C-5 or N-4 of cytosine in a DNA molecule. [GOC:pf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ATPASE_ACTIVITY
Systematic name | M10962
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate of ATP hydrolysis by an ATPase. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ATPASE_ACTIVITY
Systematic name | M16243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate of ATP hydrolysis by an ATPase. [GOC:mah]
Full description |

Standard name | GO_BILE_ACID_SECRETION
Systematic name | M23138
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of bile acid, composed of any of a group of steroid carboxylic acids occurring in bile, by a cell or a tissue. [GOC:ecd]
Full description |

Standard name | GO_REGULATION_OF_DNA_TEMPLATED_TRANSCRIPTION_ELONGATION
Systematic name | M16755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transcription elongation, the extension of an RNA molecule after transcription initiation and promoter clearance by the addition of ribonucleotides catalyzed by a DNA-dependent RNA polymerase. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_TEMPLATED_TRANSCRIPTION_ELONGATION
Systematic name | M15862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of transcription elongation, the extension of an RNA molecule after transcription initiation and promoter clearance by the addition of ribonucleotides catalyzed by a DNA-dependent RNA polymerase. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_TEMPLATED_TRANSCRIPTION_ELONGATION
Systematic name | M16451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of transcription elongation, the extension of an RNA molecule after transcription initiation and promoter clearance by the addition of ribonucleotides catalyzed by a DNA-dependent RNA polymerase. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_MONOCARBOXYLIC_ACID_METABOLIC_PROCESS
Systematic name | M11574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving monocarboxylic acids, any organic acid containing one carboxyl (COOH) group or anion (COO-). [GOC:vk]
Full description |

Standard name | GO_RIBOSOME_DISASSEMBLY
Systematic name | M23139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disaggregation of a ribosome into its constituent components; includes the dissociation of ribosomal subunits. [GOC:mah, GOC:vk]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CREB_TRANSCRIPTION_FACTOR_ACTIVITY
Systematic name | M23140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the activity of the transcription factor CREB. [GOC:dph, GOC:ecd, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CREB_TRANSCRIPTION_FACTOR_ACTIVITY
Systematic name | M10875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of activity of the transcription factor CREB. [GOC:dph, GOC:ecd, GOC:tb]
Full description |

Standard name | GO_LOW_DENSITY_LIPOPROTEIN_RECEPTOR_PARTICLE_METABOLIC_PROCESS
Systematic name | M23141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving low-density lipoprotein receptors. [GOC:vk]
Full description |

Standard name | GO_RECEPTOR_BIOSYNTHETIC_PROCESS
Systematic name | M23142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a receptor molecule, a macromolecule that undergoes combination with a hormone, neurotransmitter, drug or intracellular messenger to initiate a change in cell function. [GOC:mah]
Full description |

Standard name | GO_RECEPTOR_CATABOLIC_PROCESS
Systematic name | M16383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a receptor molecule, a macromolecule that undergoes combination with a hormone, neurotransmitter, drug or intracellular messenger to initiate a change in cell function. [GOC:mah]
Full description |

Standard name | GO_LOW_DENSITY_LIPOPROTEIN_PARTICLE_RECEPTOR_CATABOLIC_PROCESS
Systematic name | M23143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a low-density lipoprotein particle receptor molecule, a macromolecule that undergoes combination with a hormone, neurotransmitter, drug or intracellular messenger to initiate a change in cell function. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_LOW_DENSITY_LIPOPROTEIN_PARTICLE_RECEPTOR_CATABOLIC_PROCESS
Systematic name | M23144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of low-density lipoprotein particle receptors. [GOC:mah]
Full description |

Standard name | GO_LACRIMAL_GLAND_DEVELOPMENT
Systematic name | M23145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the lacrimal gland over time, from its formation to the mature structure. The lacrimal gland produces secretions that lubricate and protect the cornea of the eye. [GOC:ln]
Full description |

Standard name | GO_REGULATION_OF_NATURAL_KILLER_CELL_ACTIVATION
Systematic name | M12724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of natural killer cell activation. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NATURAL_KILLER_CELL_ACTIVATION
Systematic name | M23147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of natural killer cell activation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NATURAL_KILLER_CELL_ACTIVATION
Systematic name | M15133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of natural killer cell activation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NATURAL_KILLER_CELL_PROLIFERATION
Systematic name | M23148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of natural killer cell proliferation. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_NATURAL_KILLER_CELL_DIFFERENTIATION
Systematic name | M23149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of natural killer cell differentiation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NATURAL_KILLER_CELL_DIFFERENTIATION
Systematic name | M23150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of natural killer cell differentiation. [GOC:mah]
Full description |

Standard name | GO_GLOMERULUS_DEVELOPMENT
Systematic name | M13352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the glomerulus over time from its initial formation until its mature state. The glomerulus is a capillary tuft which forms a close network with the visceral epithelium (podocytes) and the mesangium to form the filtration barrier and is surrounded by Bowman's capsule in nephrons of the vertebrate kidney. The glomerulus is part of the nephron and is restricted to one body segment. [GOC:mah, GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_GLOMERULAR_BASEMENT_MEMBRANE_DEVELOPMENT
Systematic name | M23152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the glomerular basement membrane over time, from its formation to the mature structure. The glomerular basement membrane is the basal laminal portion of the glomerulus which performs the actual filtration. [GOC:sr]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_PH_REDUCTION
Systematic name | M23153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a process that reduces the internal pH of a cell. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_PH_REDUCTION
Systematic name | M34134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of a process that reduces the internal pH of a cell. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_INSULIN
Systematic name | M12725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an insulin stimulus. Insulin is a polypeptide hormone produced by the islets of Langerhans of the pancreas in mammals, and by the homologous organs of other organisms. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_INSULIN_STIMULUS
Systematic name | M11784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an insulin stimulus. Insulin is a polypeptide hormone produced by the islets of Langerhans of the pancreas in mammals, and by the homologous organs of other organisms. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_HORMONE_STIMULUS
Systematic name | M12601
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hormone stimulus. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ESTABLISHMENT_OR_MAINTENANCE_OF_CELL_POLARITY
Systematic name | M14855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the specification, formation or maintenance of anisotropic intracellular organization or cell growth patterns. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION
Systematic name | M14100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of any process in which a protein is transported to, or maintained in, a specific location. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_POLYSACCHARIDE_METABOLIC_PROCESS
Systematic name | M14888
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving polysaccharides. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MICROTUBULE_BASED_PROCESS
Systematic name | M10491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of any cellular process that depends upon or alters the microtubule cytoskeleton. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_VACUOLE_FUSION_NON_AUTOPHAGIC
Systematic name | M34135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the fusion of two vacuole membranes to form a single vacuole. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ORGANIC_ACID_TRANSPORT
Systematic name | M10568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of organic acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ORGANIC_ACID_TRANSPORT
Systematic name | M15391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of organic acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ORGANIC_ACID_TRANSPORT
Systematic name | M16017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of organic acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VIRAL_TRANSCRIPTION
Systematic name | M16672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of viral transcription. [GOC:mah]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA1_PRODUCTION
Systematic name | M23155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of transforming growth factor-beta1 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA2_PRODUCTION
Systematic name | M23156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of transforming growth factor-beta2 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA3_PRODUCTION
Systematic name | M29147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of transforming growth factor-beta3 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSFORMING_GROWTH_FACTOR_BETA1_PRODUCTION
Systematic name | M23157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of production of transforming growth factor-beta1. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSFORMING_GROWTH_FACTOR_BETA1_PRODUCTION
Systematic name | M23158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of production of transforming growth factor-beta1. [GOC:mah]
Full description |

Standard name | GO_CIRCADIAN_REGULATION_OF_GENE_EXPRESSION
Systematic name | M11433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gene expression such that an expression pattern recurs with a regularity of approximately 24 hours. [GOC:mah]
Full description |

Standard name | GO_ACTIVIN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M14587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of an extracellular ligand to an activin receptor on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:rl, GOC:signaling]
Full description |

Standard name | GO_REGULATION_OF_ACTIVIN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M16296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the activity of any activin receptor signaling pathway. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ACTIVIN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the activity of any activin receptor signaling pathway. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACTIVIN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the activity of any activin receptor signaling pathway. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_REGULATION_OF_SUPEROXIDE_ANION_GENERATION
Systematic name | M11046
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of enzymatic generation of superoxide by a cell. [GOC:mah]
Full description |

Standard name | GO_SECRETION_BY_TISSUE
Systematic name | M23163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled release of a substance by a tissue. [GOC:mah]
Full description |

Standard name | GO_INOSITOL_TRISPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving myo-inositol phosphate, 1,2,3,4,5,6-cyclohexanehexol, with three phosphate groups attached. [GOC:mah]
Full description |

Standard name | GO_INOSITOL_PHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M23164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of an inositol phosphate, 1,2,3,4,5,6-cyclohexanehexol, with one or more phosphate groups attached. [GOC:mah]
Full description |

Standard name | GO_INOSITOL_TRISPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M34136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of inositol trisphosphate, 1,2,3,4,5,6-cyclohexanehexol, with three phosphate groups attached. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_INOSITOL_TRISPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M23166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of inositol trisphosphate. [GOC:mah]
Full description |

Standard name | GO_COLLAGEN_METABOLIC_PROCESS
Systematic name | M23167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving collagen, any of a group of fibrous proteins of very high tensile strength that form the main component of connective tissue in animals. Collagen is highly enriched in glycine (some regions are 33% glycine) and proline, occurring predominantly as 3-hydroxyproline (about 20%). [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_COLLAGEN_BIOSYNTHETIC_PROCESS
Systematic name | M23168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of collagen, any of a group of fibrous proteins of very high tensile strength that form the main component of connective tissue in animals. Collagen is highly enriched in glycine (some regions are 33% glycine) and proline, occurring predominantly as 3-hydroxyproline (about 20%). [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_ELONGATION_FROM_RNA_POLYMERASE_II_PROMOTER
Systematic name | M12696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of transcription elongation, the extension of an RNA molecule after transcription initiation and promoter clearance by the addition of ribonucleotides, catalyzed by RNA polymerase II. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_REGULATION_OF_ACTIN_FILAMENT_BASED_PROCESS
Systematic name | M11956
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of any cellular process that depends upon or alters the actin cytoskeleton. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_CONTAINING_COMPLEX_DISASSEMBLY
Systematic name | M23172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disaggregation of a protein-containing macromolecular complex into its constituent components. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_DNA_COMPLEX_DISASSEMBLY
Systematic name | M23173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disaggregation of a protein-DNA complex into its constituent components. [GOC:mah]
Full description |

Standard name | GO_RIBONUCLEOPROTEIN_COMPLEX_DISASSEMBLY
Systematic name | M14303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disaggregation of a protein-RNA complex into its constituent components. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_COMPONENT_MORPHOGENESIS
Systematic name | M14697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which cellular structures, including whole cells or cell parts, are generated and organized. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_CELL_PART_MORPHOGENESIS
Systematic name | M10398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a cell part are generated and organized. [GOC:mah]
Full description |

Standard name | GO_MUSCLE_CELL_PROLIFERATION
Systematic name | M11549
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a muscle cell population by cell division. [CL:0000187, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MAST_CELL_ACTIVATION
Systematic name | M13124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of mast cell activation. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MAST_CELL_ACTIVATION
Systematic name | M14006
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of mast cell activation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MAST_CELL_ACTIVATION
Systematic name | M13599
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of mast cell activation. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MAST_CELL_ACTIVATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M10912
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of mast cell activation as part of an immune response. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MAST_CELL_ACTIVATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M23174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of mast cell activation as part of an immune response. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MAST_CELL_ACTIVATION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M12939
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of mast cell activation as part of an immune response. [GOC:mah]
Full description |

Standard name | GO_TETRAPYRROLE_METABOLIC_PROCESS
Systematic name | M13532
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving tetrapyrroles, natural pigments containing four pyrrole rings joined by one-carbon units linking position 2 of one pyrrole ring to position 5 of the next. [GOC:mah]
Full description |

Standard name | GO_TETRAPYRROLE_BIOSYNTHETIC_PROCESS
Systematic name | M11455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways leading to the formation of tetrapyrroles, natural pigments containing four pyrrole rings joined by one-carbon units linking position 2 of one pyrrole ring to position 5 of the next. [GOC:mah]
Full description |

Standard name | GO_MYELOID_CELL_APOPTOTIC_PROCESS
Systematic name | M23176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a myeloid cell, a cell of the monocyte, granulocyte, mast cell, megakaryocyte, or erythroid lineage. [CL:0000763, GOC:add, GOC:mtg_apoptosis, PMID:11292031, PMID:15330259, PMID:17133093]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MYELOID_CELL_APOPTOTIC_PROCESS
Systematic name | M15111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of a myeloid cell apoptotic process. [GOC:add, GOC:mtg_apoptosis]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MYELOID_CELL_APOPTOTIC_PROCESS
Systematic name | M23177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of myeloid cell apoptotic process. [GOC:add, GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_ORGANELLE_ORGANIZATION
Systematic name | M5517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of an organelle. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CHROMOSOME_ORGANIZATION
Systematic name | M15166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of a chromosome. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_SISTER_CHROMATID_SEGREGATION
Systematic name | M16547
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of sister chromatid segregation. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_PIGMENTATION
Systematic name | M11235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The deposition or aggregation of coloring matter in a cell. [GOC:mtg_MIT_16mar07]
Full description |

Standard name | GO_T_CELL_DIFFERENTIATION_IN_THYMUS
Systematic name | M23178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of a T cell via a differentiation pathway dependent upon transit through the thymus. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_IMMATURE_T_CELL_PROLIFERATION
Systematic name | M23179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of an immature T cell population by cell division. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_IMMATURE_T_CELL_PROLIFERATION_IN_THYMUS
Systematic name | M23180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of an immature T cell population by cell division in the thymus. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_DIFFERENTIATION_IN_THYMUS
Systematic name | M23181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T cell differentiation in the thymus. [GOC:add, GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_CELL_DIFFERENTIATION_IN_THYMUS
Systematic name | M23182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of T cell differentiation in the thymus. [GOC:add, GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_IMMATURE_T_CELL_PROLIFERATION
Systematic name | M23183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of immature T cell proliferation. [GOC:add, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_CELL_DIFFERENTIATION_IN_THYMUS
Systematic name | M23184
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of T cell differentiation in the thymus. [GOC:add, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_IMMATURE_T_CELL_PROLIFERATION
Systematic name | M34137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of immature T cell proliferation. [GOC:add, GOC:mah]
Full description |

Standard name | GO_MITOCHONDRIAL_RESPIRATORY_CHAIN_COMPLEX_ASSEMBLY
Systematic name | M11099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a mitochondrial respiratory chain complex. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RNA_SPLICING
Systematic name | M11010
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of RNA splicing. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RNA_SPLICING
Systematic name | M10625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of RNA splicing. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_PHOSPHORYLATION
Systematic name | M14138
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the addition of one or more phosphate groups to a histone protein. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HISTONE_PHOSPHORYLATION
Systematic name | M23185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the addition of one or more phosphate groups to a histone protein. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLUCOKINASE_ACTIVITY
Systematic name | M23186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of glucokinase activity, the catalysis of the transfer of a phosphate group, usually from ATP, to a glucose molecule. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDYL_SERINE_PHOSPHORYLATION
Systematic name | M12510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the phosphorylation of peptidyl-serine. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PEPTIDYL_SERINE_PHOSPHORYLATION
Systematic name | M15438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the phosphorylation of peptidyl-serine. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PEPTIDYL_SERINE_PHOSPHORYLATION
Systematic name | M16196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the phosphorylation of peptidyl-serine. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDYL_SERINE_PHOSPHORYLATION_OF_STAT_PROTEIN
Systematic name | M15129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the phosphorylation of a serine residue of a STAT (Signal Transducer and Activator of Transcription) protein. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_INTRACELLULAR_STEROID_HORMONE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the activity of any intracellular steroid hormone receptor signaling pathway. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTRACELLULAR_STEROID_HORMONE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12409
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the activity of any intracellular steroid hormone receptor signaling pathway. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTRACELLULAR_STEROID_HORMONE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11294
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the activity of any intracellular steroid hormone receptor signaling pathway. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_INTRACELLULAR_ESTROGEN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the activity of an intracellular estrogen receptor signaling pathway. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTRACELLULAR_ESTROGEN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the activity of an intracellular estrogen receptor signaling pathway. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTRACELLULAR_ESTROGEN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the activity of an intracellular estrogen receptor signaling pathway. [GOC:mah]
Full description |

Standard name | GO_V_D_J_RECOMBINATION
Systematic name | M16738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which immune receptor V, D, and J, or V and J gene segments, depending on the specific receptor, are recombined within a single locus utilizing the conserved heptamer and nonomer recombination signal sequences (RSS). [GOC:add, ISBN:0781700221, ISBN:0781735149]
Full description |

Standard name | GO_IMMUNOGLOBULIN_V_D_J_RECOMBINATION
Systematic name | M29149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which immunoglobulin gene segments are recombined within a single locus utilizing the conserved heptamer and nonomer recombination signal sequences (RSS). For immunoglobulin heavy chains V, D, and J gene segments are joined, and for immunoglobulin light chains V and J gene segments are joined. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_INTRACELLULAR_PROTEIN_TRANSPORT
Systematic name | M13668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of proteins within cells. [GOC:mah]
Full description |

Standard name | GO_HISTONE_H3_K9_DEMETHYLATION
Systematic name | M23188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the removal of a methyl group from lysine at position 9 of the histone. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_UBIQUITINATION
Systematic name | M23189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the addition of a ubiquitin group to a histone protein. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HISTONE_UBIQUITINATION
Systematic name | M23190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the addition of a ubiquitin group to a histone protein. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_VITAMIN_A
Systematic name | M14087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin A stimulus. [GOC:sl]
Full description |

Standard name | GO_RESPONSE_TO_HYDROPEROXIDE
Systematic name | M15279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydroperoxide stimulus. Hydroperoxides are monosubstitution products of hydrogen peroxide, HOOH. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_VITAMIN_E
Systematic name | M14468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin E stimulus. [GOC:sl]
Full description |

Standard name | GO_RESPONSE_TO_ATP
Systematic name | M13771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ATP (adenosine 5'-triphosphate) stimulus. [GOC:sl]
Full description |

Standard name | GO_MEIOTIC_CYTOKINESIS
Systematic name | M23191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle process that results in the division of the cytoplasm of a cell after meiosis, resulting in the separation of the original cell into two daughter cells. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_TUMOR_NECROSIS_FACTOR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M13837
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a tumor necrosis factor to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_LEPTIN_MEDIATED_SIGNALING_PATHWAY
Systematic name | M23192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of leptin to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. Leptin is a hormone manufactured primarily in the adipocytes of white adipose tissue, and the level of circulating leptin is directly proportional to the total amount of fat in the body. [GOC:mah, GOC:signaling, GOC:yaf]
Full description |

Standard name | GO_ADIPONECTIN_ACTIVATED_SIGNALING_PATHWAY
Systematic name | M23193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of adiponectin to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:mah, GOC:signaling, PMID:20536390]
Full description |

Standard name | GO_IRON_IMPORT_INTO_CELL
Systematic name | M23194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of iron ions from outside of a cell into the cytoplasmic compartment. This may occur via transport across the plasma membrane or via endocytosis. [PMID:18622392, PMID:23192658, Wikipedia:Human_iron_metabolism]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_SUMOYLATION
Systematic name | M10843
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the addition of SUMO groups to a protein. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_SUMOYLATION
Systematic name | M23196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the addition of SUMO groups to a protein. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_SUMOYLATION
Systematic name | M15403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the addition of SUMO groups to a protein. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_AMINE_METABOLIC_PROCESS
Systematic name | M11729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways by which individual cells transform amines. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_AMINE_METABOLIC_PROCESS
Systematic name | M23197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving amines. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_AMINE_METABOLIC_PROCESS
Systematic name | M10913
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving amines. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_NUCLEAR_CELL_CYCLE_DNA_REPLICATION
Systematic name | M11946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of The DNA-dependent DNA replication that occurs in the nucleus of eukaryotic organisms as part of the cell cycle. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_RESPONSE_TO_VITAMIN
Systematic name | M14836
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin stimulus. [GOC:sl]
Full description |

Standard name | GO_CELL_PROLIFERATION_IN_MIDBRAIN
Systematic name | M23199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of cells, resulting in the expansion of a cell population in the midbrain. [GO_REF:0000021, GOC:dgf]
Full description |

Standard name | GO_RESPONSE_TO_VITAMIN_D
Systematic name | M14269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin D stimulus. [GOC:sl]
Full description |

Standard name | GO_T_TUBULE_ORGANIZATION
Systematic name | M23200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level that results in the assembly, arrangement of constituent parts, or disassembly of the T-tubule. A T-tubule is an invagination of the plasma membrane of a muscle cell that extends inward from the cell surface around each myofibril. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_SECRETION_OF_LYSOSOMAL_ENZYMES
Systematic name | M23201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled release of lysosomal enzymes by a cell. [GOC:mah]
Full description |

Standard name | GO_MEIOTIC_CELL_CYCLE_CHECKPOINT
Systematic name | M23202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle checkpoint that ensures accurate chromosome replication and segregation by preventing progression through a meiotic cell cycle until conditions are suitable for the cell to proceed to the next stage. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_MITOTIC_DNA_REPLICATION_CHECKPOINT
Systematic name | M23203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle checkpoint that acts during a mitotic cell cycle and prevents the initiation of mitosis until DNA replication is complete, thereby ensuring that progeny inherit a full complement of the genome. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_LEYDIG_CELL_DIFFERENTIATION
Systematic name | M12427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized structural and/or functional features of a Leydig cell. A Leydig cell is a testosterone-secreting cell in the interstitial area, between the seminiferous tubules, in the testis. [GOC:ln, PMID:12050120]
Full description |

Standard name | GO_CHOLESTEROL_EFFLUX
Systematic name | M12103
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of cholesterol, cholest-5-en-3-beta-ol, out of a cell or organelle. [GOC:sart]
Full description |

Standard name | GO_S_ADENOSYLMETHIONINE_CYCLE
Systematic name | M23204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cyclic series of interconversions involving S-adenosylmethionine, S-adenosyl-L-homocysteine, L-cysteine, and L-methionine. Couples utilization of the methyl group of SAM with recycling of the homocysteinyl group and regeneration of methionine. [GOC:mah, MetaCyc:PWY-5041]
Full description |

Standard name | GO_SECRETORY_GRANULE_ORGANIZATION
Systematic name | M12532
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a secretory granule. A secretory granule is a small subcellular vesicle, surrounded by a membrane, that is formed from the Golgi apparatus and contains a highly concentrated protein destined for secretion. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_ORGANELLE
Systematic name | M14653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within an organelle. [GOC:mah]
Full description |

Standard name | GO_GAS_HOMEOSTASIS
Systematic name | M23205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A homeostatic process involved in the maintenance of an internal steady state of a gas within an organism or cell. [GOC:mah]
Full description |

Standard name | GO_CARBOHYDRATE_HOMEOSTASIS
Systematic name | M14445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A homeostatic process involved in the maintenance of an internal steady state of a carbohydrate within an organism or cell. [GOC:mah]
Full description |

Standard name | GO_FLOOR_PLATE_DEVELOPMENT
Systematic name | M23207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the floor plate over time from its initial formation until its mature state. [GOC:dh]
Full description |

Standard name | GO_HISTONE_H2A_UBIQUITINATION
Systematic name | M11505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H2A by addition of one or more ubiquitin groups. [GOC:bf, GOC:mah, PMID:15509584, PMID:16473935, PMID:18430235]
Full description |

Standard name | GO_HISTONE_H2B_UBIQUITINATION
Systematic name | M23208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H2B by addition of ubiquitin groups. [GOC:mah]
Full description |

Standard name | GO_FATTY_ACID_BETA_OXIDATION_USING_ACYL_COA_DEHYDROGENASE
Systematic name | M11873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A fatty acid beta-oxidation pathway in which the initial step of each oxidation cycle, which converts an acyl-CoA to a trans-2-enoyl-CoA, is catalyzed by acyl-CoA dehydrogenase; the electrons removed by oxidation pass through the respiratory chain to oxygen and leave H2O as the product. Fatty acid beta-oxidation begins with the addition of coenzyme A to a fatty acid, and ends when only two or three carbons remain (as acetyl-CoA or propionyl-CoA respectively). [GOC:mah, MetaCyc:FAO-PWY, MetaCyc:PWY-5136]
Full description |

Standard name | GO_FATTY_ACID_BETA_OXIDATION_USING_ACYL_COA_OXIDASE
Systematic name | M12385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A fatty acid beta-oxidation pathway in which the initial step, which converts an acyl-CoA to a trans-2-enoyl-CoA, is catalyzed by acyl-CoA oxidase; the electrons removed by oxidation pass directly to oxygen and produce hydrogen peroxide, which is cleaved by peroxisomal catalases. Fatty acid beta-oxidation begins with the addition of coenzyme A to a fatty acid, and ends when only two or three carbons remain (as acetyl-CoA or propionyl-CoA respectively). [GOC:mah, MetaCyc:PWY-5136]
Full description |

Standard name | GO_MULTICELLULAR_ORGANISMAL_RESPONSE_TO_STRESS
Systematic name | M11861
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a multicellular organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating the organism is under stress. The stress is usually, but not necessarily, exogenous (e.g. temperature, humidity, ionizing radiation). [GOC:mah]
Full description |

Standard name | GO_UNSATURATED_FATTY_ACID_METABOLIC_PROCESS
Systematic name | M15568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving an unsaturated fatty acid, any fatty acid containing one or more double bonds between carbon atoms. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_WATER_LOSS_VIA_SKIN
Systematic name | M11532
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates the rate or extent of water loss from an organism via the skin. [GOC:mah]
Full description |

Standard name | GO_ANTERIOR_POSTERIOR_AXON_GUIDANCE
Systematic name | M23209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the migration of an axon growth cone is directed to a specific target site along the anterior-posterior body axis in response to a combination of attractive and repulsive cues. The anterior-posterior axis is defined by a line that runs from the head or mouth of an organism to the tail or opposite end of the organism. [GOC:dph, GOC:kmv, GOC:tb]
Full description |

Standard name | GO_TRANSFERRIN_TRANSPORT
Systematic name | M23210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of transferrin into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mlg]
Full description |

Standard name | GO_RESPONSE_TO_TESTOSTERONE
Systematic name | M12351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a testosterone stimulus. [GOC:sl]
Full description |

Standard name | GO_PROTEIN_GLYCOSYLATION_IN_GOLGI
Systematic name | M23211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a carbohydrate or carbohydrate derivative unit to a protein amino acid in any compartment of the Golgi apparatus. [GOC:mah, GOC:pr, PMID:12042244]
Full description |

Standard name | GO_RESPONSE_TO_L_ASCORBIC_ACID
Systematic name | M23212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an L-ascorbic acid (vitamin C) stimulus. [GOC:sl]
Full description |

Standard name | GO_MAMMARY_GLAND_EPITHELIAL_CELL_PROLIFERATION
Systematic name | M15838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of mammary gland epithelial cells, resulting in the expansion of a cell population. Mammary gland epithelial cells make up the covering of surfaces of the mammary gland. The mammary gland is a large compound sebaceous gland that in female mammals is modified to secrete milk. [GOC:dph, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MAMMARY_GLAND_EPITHELIAL_CELL_PROLIFERATION
Systematic name | M10463
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mammary gland epithelial cell proliferation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MAMMARY_GLAND_EPITHELIAL_CELL_PROLIFERATION
Systematic name | M23213
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of mammary gland epithelial cell proliferation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DOPAMINE_SECRETION
Systematic name | M23214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the regulated release of dopamine. [GOC:sl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CATECHOLAMINE_SECRETION
Systematic name | M14465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the regulated release of a catecholamine. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CATECHOLAMINE_SECRETION
Systematic name | M13267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the regulated release of a catecholamine. [GOC:mah]
Full description |

Standard name | GO_MITOCHONDRIAL_CYTOCHROME_C_OXIDASE_ASSEMBLY
Systematic name | M23216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form respiratory chain complex IV (also known as cytochrome c oxidase) in the mitochondrial inner membrane. [GOC:mah]
Full description |

Standard name | GO_MEMBRANE_PROTEIN_PROTEOLYSIS
Systematic name | M15212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The proteolytic cleavage of a transmembrane protein leading to the release of its intracellular or ecto-domains. [GOC:pde]
Full description |

Standard name | GO_INTEGRIN_ACTIVATION
Systematic name | M23217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of an integrin, a heterodimeric adhesion receptor formed by the non-covalent association of particular alpha and beta subunits, that lead to the increased affinity of the integrin for its extracellular ligands. [GOC:add, PMID:12213832, PMID:14754902]
Full description |

Standard name | GO_REGULATION_OF_INTEGRIN_ACTIVATION
Systematic name | M23218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of integrin activation. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTEGRIN_ACTIVATION
Systematic name | M23219
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of integrin activation. [GOC:add]
Full description |

Standard name | GO_CELL_ADHESION_MEDIATED_BY_INTEGRIN
Systematic name | M15495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a cell, either to another cell or to an underlying substrate such as the extracellular matrix, via an integrin, a heterodimeric adhesion receptor formed by the non-covalent association of particular alpha and beta subunits. [GOC:add, PMID:12213832, PMID:14754902]
Full description |

Standard name | GO_REGULATION_OF_CELL_ADHESION_MEDIATED_BY_INTEGRIN
Systematic name | M13232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of cell adhesion mediated by integrin. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_ADHESION_MEDIATED_BY_INTEGRIN
Systematic name | M23220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of cell adhesion mediated by integrin. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_ADHESION_MEDIATED_BY_INTEGRIN
Systematic name | M13399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of cell adhesion mediated by integrin. [GOC:add]
Full description |

Standard name | GO_CELL_CELL_ADHESION_MEDIATED_BY_INTEGRIN
Systematic name | M23221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of one cell to another cell via an integrin, a heterodimeric adhesion receptor formed by the non-covalent association of particular alpha and beta subunits. [GOC:add, PMID:12213832, PMID:14754902]
Full description |

Standard name | GO_REGULATION_OF_CELL_CELL_ADHESION_MEDIATED_BY_INTEGRIN
Systematic name | M23222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of cell-cell adhesion mediated by integrin. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_CELL_ADHESION_MEDIATED_BY_INTEGRIN
Systematic name | M23223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of cell-cell adhesion mediated by integrin. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_KINASE_ACTIVITY
Systematic name | M10594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of kinase activity, the catalysis of the transfer of a phosphate group, usually from ATP, to a substrate molecule. [GOC:mah]
Full description |

Standard name | GO_NUCLEOTIDE_EXCISION_REPAIR_DNA_INCISION
Systematic name | M14625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that results in the endonucleolytic cleavage of the damaged strand of DNA. The incision occurs at the junction of single-stranded DNA and double-stranded DNA that is formed when the DNA duplex is unwound. [GOC:elh, PMID:8631896]
Full description |

Standard name | GO_REGULATION_OF_LUTEINIZING_HORMONE_SECRETION
Systematic name | M23224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of luteinizing hormone. [GOC:mah]
Full description |

Standard name | GO_OSTEOBLAST_PROLIFERATION
Systematic name | M23225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of osteoblasts, resulting in the expansion of an osteoblast cell population. An osteoblast is a bone-forming cell which secretes an extracellular matrix. Hydroxyapatite crystals are then deposited into the matrix to form bone. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OSTEOBLAST_PROLIFERATION
Systematic name | M23226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of osteoblast proliferation. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OSTEOBLAST_PROLIFERATION
Systematic name | M15213
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of osteoblast proliferation. [GOC:mah]
Full description |

Standard name | GO_PHOSPHOLIPID_EFFLUX
Systematic name | M16367
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a phospholipid out of a cell or organelle. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_GLUCAGON
Systematic name | M12213
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucagon stimulus. [GOC:sl]
Full description |

Standard name | GO_REGULATION_OF_NAD_P_H_OXIDASE_ACTIVITY
Systematic name | M23227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the activity of the enzyme NAD(P)H oxidase. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NAD_P_H_OXIDASE_ACTIVITY
Systematic name | M23228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the activity of the enzyme NAD(P)H oxidase. [GOC:mah]
Full description |

Standard name | GO_NUCLEOSIDE_BISPHOSPHATE_METABOLIC_PROCESS
Systematic name | M11301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a nucleoside bisphosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with one phosphate group attached to each of two different hydroxyl groups on the sugar. [GOC:mah, GOC:pde]
Full description |

Standard name | GO_NUCLEOSIDE_BISPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M14952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a nucleoside bisphosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with one phosphate group attached to each of two different hydroxyl groups on the sugar. [GOC:mah, GOC:pde]
Full description |

Standard name | GO_NUCLEOSIDE_BISPHOSPHATE_CATABOLIC_PROCESS
Systematic name | M23229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a nucleoside bisphosphate, a compound consisting of a nucleobase linked to a deoxyribose or ribose sugar esterified with one phosphate group attached to each of two different hydroxyl groups on the sugar. [GOC:mah, GOC:pde]
Full description |

Standard name | GO_P_BODY_ASSEMBLY
Systematic name | M10353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins and RNA molecules to form a cytoplasmic mRNA processing body. [GOC:mah, PMID:17429074]
Full description |

Standard name | GO_RESPONSE_TO_LIPID
Systematic name | M14037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipid stimulus. [GOC:sl]
Full description |

Standard name | GO_ENDOSOMAL_VESICLE_FUSION
Systematic name | M23230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The homotypic fusion of endocytic vesicles to form or add to an early endosome. [PMID:11964142, PMID:9422733]
Full description |

Standard name | GO_STRESS_GRANULE_ASSEMBLY
Systematic name | M23231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins and RNA molecules to form a stress granule. [GOC:mah, PMID:17392519]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_GOLGI_APPARATUS
Systematic name | M14366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within the Golgi apparatus. [GOC:mah]
Full description |

Standard name | GO_ESTABLISHMENT_OF_SISTER_CHROMATID_COHESION
Systematic name | M23232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the sister chromatids of a replicated chromosome become associated with each other during S phase. [GOC:jh, GOC:mah, PMID:14623866]
Full description |

Standard name | GO_MAINTENANCE_OF_SISTER_CHROMATID_COHESION
Systematic name | M23233
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the association between sister chromatids of a replicated chromosome is maintained as chromosomes condense, attach to the spindle in a bipolar orientation, and congress to the metaphase plate. [GOC:mah, PMID:14623866]
Full description |

Standard name | GO_REGULATION_OF_MAINTENANCE_OF_SISTER_CHROMATID_COHESION
Systematic name | M23234
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the extent to which the association between sister chromatids of a replicated chromosome is maintained. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MAINTENANCE_OF_SISTER_CHROMATID_COHESION
Systematic name | M23235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the extent to which the association between sister chromatids of a replicated chromosome is maintained. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_RESPONSE_TO_CYTOKINE
Systematic name | M15783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cytokine stimulus. [GOC:sl]
Full description |

Standard name | GO_ERYTHROCYTE_HOMEOSTASIS
Systematic name | M10976
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process of regulating the production and elimination of erythrocytes within an organism. [GOC:add, PMID:10694114, PMID:14754397]
Full description |

Standard name | GO_REGULATION_OF_TISSUE_REMODELING
Systematic name | M16194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of tissue remodeling. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TISSUE_REMODELING
Systematic name | M12214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of tissue remodeling. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TISSUE_REMODELING
Systematic name | M13871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of tissue remodeling. [GOC:add]
Full description |

Standard name | GO_HOMOTYPIC_CELL_CELL_ADHESION
Systematic name | M14858
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a cell to a second cell of the identical type via adhesion molecules. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_HOMOTYPIC_CELL_CELL_ADHESION
Systematic name | M14754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of homotypic cell-cell adhesion. [GOC:add]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HOMOTYPIC_CELL_CELL_ADHESION
Systematic name | M16688
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of homotypic cell-cell adhesion. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HOMOTYPIC_CELL_CELL_ADHESION
Systematic name | M23236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of homotypic cell-cell adhesion. [GOC:add]
Full description |

Standard name | GO_HETEROTYPIC_CELL_CELL_ADHESION
Systematic name | M16687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a cell to a cell of a different type via adhesion molecules. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_HETEROTYPIC_CELL_CELL_ADHESION
Systematic name | M10825
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of heterotypic cell-cell adhesion. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HETEROTYPIC_CELL_CELL_ADHESION
Systematic name | M23237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of heterotypic cell-cell adhesion. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of toll-like receptor signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of toll-like receptor signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of toll-like receptor signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_REGULATION_OF_MYD88_INDEPENDENT_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of MyD88-independent toll-like receptor signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_TOLL_LIKE_RECEPTOR_2_SIGNALING_PATHWAY
Systematic name | M23239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of binding to toll-like receptor 2. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_REGULATION_OF_TOLL_LIKE_RECEPTOR_2_SIGNALING_PATHWAY
Systematic name | M23240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of toll-like receptor 2 signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TOLL_LIKE_RECEPTOR_2_SIGNALING_PATHWAY
Systematic name | M23241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of toll-like receptor 2 signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TOLL_LIKE_RECEPTOR_2_SIGNALING_PATHWAY
Systematic name | M23242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of toll-like receptor 2 signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_TOLL_LIKE_RECEPTOR_3_SIGNALING_PATHWAY
Systematic name | M23243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of binding to toll-like receptor 3. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_REGULATION_OF_TOLL_LIKE_RECEPTOR_3_SIGNALING_PATHWAY
Systematic name | M23244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of toll-like receptor 3 signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TOLL_LIKE_RECEPTOR_3_SIGNALING_PATHWAY
Systematic name | M23245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of toll-like receptor 3 signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_TOLL_LIKE_RECEPTOR_4_SIGNALING_PATHWAY
Systematic name | M13874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of binding to toll-like receptor 4. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_REGULATION_OF_TOLL_LIKE_RECEPTOR_4_SIGNALING_PATHWAY
Systematic name | M11084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of toll-like receptor 4 signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TOLL_LIKE_RECEPTOR_4_SIGNALING_PATHWAY
Systematic name | M23246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of toll-like receptor 4 signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TOLL_LIKE_RECEPTOR_4_SIGNALING_PATHWAY
Systematic name | M23247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of toll-like receptor 4 signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_TOLL_LIKE_RECEPTOR_7_SIGNALING_PATHWAY
Systematic name | M23248
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of binding to toll-like receptor 7. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_REGULATION_OF_TOLL_LIKE_RECEPTOR_7_SIGNALING_PATHWAY
Systematic name | M34138
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of toll-like receptor 7 signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_TOLL_LIKE_RECEPTOR_9_SIGNALING_PATHWAY
Systematic name | M10707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of binding to toll-like receptor 9. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_REGULATION_OF_TOLL_LIKE_RECEPTOR_9_SIGNALING_PATHWAY
Systematic name | M23249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of toll-like receptor 9 signaling pathway. [GOC:add, PMID:16551253, PMID:17328678]
Full description |

Standard name | GO_ACYLGLYCEROL_TRANSPORT
Systematic name | M23250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of an acylglycerol into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. An acylglycerol is any mono-, di- or triester of glycerol with (one or more) fatty acids. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_ACTIVATION_OF_PROTEIN_KINASE_A_ACTIVITY
Systematic name | M16808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of the inactive enzyme protein kinase A. [GOC:pde]
Full description |

Standard name | GO_RESPONSE_TO_OLEIC_ACID
Systematic name | M23251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an oleic acid stimulus. [GOC:lp]
Full description |

Standard name | GO_LIPID_TRANSLOCATION
Systematic name | M29150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The translocation, or flipping, of lipid molecules from one monolayer of a membrane bilayer to the opposite monolayer. [GOC:mah]
Full description |

Standard name | GO_AMYLOID_BETA_FORMATION
Systematic name | M23252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The generation of amyloid-beta by cleavage of the amyloid precursor protein (APP). [GOC:mah]
Full description |

Standard name | GO_PROTEIN_HEXAMERIZATION
Systematic name | M23253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a protein hexamer, a macromolecular structure consisting of six noncovalently associated identical or nonidentical subunits. [GOC:ecd]
Full description |

Standard name | GO_CARBOHYDRATE_TRANSMEMBRANE_TRANSPORT
Systematic name | M13589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a carbohydrate is transported across a membrane. [GOC:mah]
Full description |

Standard name | GO_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M12359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which an ion is transported across a membrane. [GOC:mah]
Full description |

Standard name | GO_TRNA_THIO_MODIFICATION
Systematic name | M23254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition a sulfur atom to a nucleotide in a tRNA molecule. [GOC:mcc, PMID:12549933, PMID:14722066]
Full description |

Standard name | GO_MACROPHAGE_FUSION
Systematic name | M23255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The binding and fusion of a macrophage to one or more other cells to form a multinucleated cell. [GOC:sl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MACROPHAGE_FUSION
Systematic name | M29151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of macrophage fusion. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_ELONGATION_FROM_RNA_POLYMERASE_II_PROMOTER
Systematic name | M12178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transcription elongation, the extension of an RNA molecule after transcription initiation and promoter clearance by the addition of ribonucleotides, catalyzed by RNA polymerase II. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_AMIDE_METABOLIC_PROCESS
Systematic name | M14685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving amides. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_AMIDE_METABOLIC_PROCESS
Systematic name | M11639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving amides. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_AMIDE_METABOLIC_PROCESS
Systematic name | M10803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving amides. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GTPASE_ACTIVITY
Systematic name | M15318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate of GTP hydrolysis by a GTPase. [GO_REF:0000058, GOC:mah, GOC:rb, GOC:TermGenie, PMID:16143306, PMID:24335649]
Full description |

Standard name | GO_RESPONSE_TO_MONOSACCHARIDE
Systematic name | M34139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a monosaccharide stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_DISACCHARIDE
Systematic name | M23256
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a disaccharide stimulus. [GOC:sart]
Full description |

Standard name | GO_PRIMARY_ALCOHOL_METABOLIC_PROCESS
Systematic name | M16559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving primary alcohols. A primary alcohol is any alcohol in which a hydroxy group, -OH, is attached to a saturated carbon atom which has either three hydrogen atoms attached to it or only one other carbon atom and two hydrogen atoms attached to it. [GOC:mah]
Full description |

Standard name | GO_PRIMARY_ALCOHOL_BIOSYNTHETIC_PROCESS
Systematic name | M23257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of primary alcohols. A primary alcohol is any alcohol in which a hydroxy group, -OH, is attached to a saturated carbon atom which has either three hydrogen atoms attached to it or only one other carbon atom and two hydrogen atoms attached to it. [GOC:mah]
Full description |

Standard name | GO_PRIMARY_ALCOHOL_CATABOLIC_PROCESS
Systematic name | M23258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of primary alcohols. A primary alcohol is any alcohol in which a hydroxy group, -OH, is attached to a saturated carbon atom which has either three hydrogen atoms attached to it or only one other carbon atom and two hydrogen atoms attached to it. [GOC:mah]
Full description |

Standard name | GO_DIOL_METABOLIC_PROCESS
Systematic name | M13615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a diol, a compound that contains two hydroxy groups, generally assumed to be, but not necessarily, alcoholic. [GOC:curators]
Full description |

Standard name | GO_DIOL_BIOSYNTHETIC_PROCESS
Systematic name | M34140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a diol, any alcohol containing two hydroxyl groups attached to saturated carbon atoms. [GOC:mah]
Full description |

Standard name | GO_ARP2_3_COMPLEX_MEDIATED_ACTIN_NUCLEATION
Systematic name | M15218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The actin nucleation process in which actin monomers combine to form a new branch on the side of an existing actin filament; mediated by the Arp2/3 protein complex and its interaction with other proteins. [GOC:mah, PMID:16959963, PMID:18640983]
Full description |

Standard name | GO_REGULATION_OF_ARP2_3_COMPLEX_MEDIATED_ACTIN_NUCLEATION
Systematic name | M13607
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of actin nucleation mediated by the Arp2/3 complex and interacting proteins. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ARP2_3_COMPLEX_MEDIATED_ACTIN_NUCLEATION
Systematic name | M23260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of actin nucleation mediated by the Arp2/3 complex and interacting proteins. [GOC:mah, PMID:16959963]
Full description |

Standard name | GO_CELL_JUNCTION_ASSEMBLY
Systematic name | M14884
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the aggregation, arrangement and bonding together of a set of components to form a cell junction. [GOC:mah]
Full description |

Standard name | GO_CELL_JUNCTION_ORGANIZATION
Systematic name | M12450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a cell junction. A cell junction is a specialized region of connection between two cells or between a cell and the extracellular matrix. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_CELL_JUNCTION_MAINTENANCE
Systematic name | M23261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The organization process that preserves a cell junction in a stable functional or structural state. A cell junction is a specialized region of connection between two cells or between a cell and the extracellular matrix. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_ADHERENS_JUNCTION_ORGANIZATION
Systematic name | M15116
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of an adherens junction. An adherens junction is a cell-cell junction composed of the epithelial cadherin-catenin complex at which the cytoplasmic face of the plasma membrane is attached to actin filaments. [GOC:aruk, GOC:bc, GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_ADHERENS_JUNCTION_ASSEMBLY
Systematic name | M12531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an adherens junction. An adherens junction is a cell-cell junction composed of the epithelial cadherin-catenin complex at which the cytoplasmic face of the plasma membrane is attached to actin filaments. [GOC:aruk, GOC:bc, GOC:mah]
Full description |

Standard name | GO_ADHERENS_JUNCTION_MAINTENANCE
Systematic name | M23262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The maintenance of an adherens junction. An adherens junction is a cell-cell junction composed of the epithelial cadherin-catenin complex at which the cytoplasmic face of the plasma membrane is attached to actin filaments. [GOC:aruk, GOC:bc, GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_TYPE_I_INTERFERON
Systematic name | M11098
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a type I interferon stimulus. Type I interferons include the interferon-alpha, beta, delta, episilon, zeta, kappa, tau, and omega gene families. [GOC:add, ISBN:0126896631, PMID:15546383, PMID:16681834]
Full description |

Standard name | GO_RESPONSE_TO_INTERFERON_GAMMA
Systematic name | M15265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interferon-gamma stimulus. Interferon-gamma is also known as type II interferon. [GOC:add, ISBN:0126896631, PMID:15546383]
Full description |

Standard name | GO_TYPE_III_INTERFERON_PRODUCTION
Systematic name | M34141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of type III interferon due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. Interferon lambda is the only member of the type III interferon found so far. [GOC:add, ISBN:0126896631, PMID:15546383, PMID:16734557]
Full description |

Standard name | GO_GLIAL_CELL_APOPTOTIC_PROCESS
Systematic name | M23263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a glial cell, a non-neuronal cell of the nervous system. [CL:0000125, GOC:mtg_apoptosis, GOC:sart]
Full description |

Standard name | GO_REGULATION_OF_GLIAL_CELL_APOPTOTIC_PROCESS
Systematic name | M23264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of glial cell apoptotic process. [GOC:mah, GOC:mtg_apoptosis]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLIAL_CELL_APOPTOTIC_PROCESS
Systematic name | M29152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of glial cell apoptotic process. [GOC:mah, GOC:mtg_apoptosis]
Full description |

Standard name | GO_DE_NOVO_NAD_BIOSYNTHETIC_PROCESS_FROM_TRYPTOPHAN
Systematic name | M23265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of nicotinamide adenine dinucleotide (NAD), beginning with the synthesis of tryptophan from simpler precursors; biosynthesis may be of either the oxidized form, NAD, or the reduced form, NADH. [PMID:17161604]
Full description |

Standard name | GO_NAD_BIOSYNTHESIS_VIA_NICOTINAMIDE_RIBOSIDE_SALVAGE_PATHWAY
Systematic name | M23266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of nicotinamide adenine dinucleotide (NAD) from the vitamin precursor nicotinamide riboside. [PMID:17482543]
Full description |

Standard name | GO_PROTEIN_CONTAINING_COMPLEX_REMODELING
Systematic name | M23267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The acquisition, loss, or modification of macromolecules within a complex, resulting in the alteration of an existing complex. [GOC:BHF, GOC:mah, GOC:mtg_mpo, GOC:rl]
Full description |

Standard name | GO_TRIGLYCERIDE_RICH_LIPOPROTEIN_PARTICLE_REMODELING
Systematic name | M23268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The acquisition, loss or modification of a protein or lipid within a triglyceride-rich lipoprotein particle, including the hydrolysis of triglyceride by lipoprotein lipase, with the subsequent loss of free fatty acid, and the transfer of cholesterol esters to a triglyceride-rich lipoprotein particle by cholesteryl ester transfer protein (CETP), with the simultaneous transfer of triglyceride from a triglyceride-rich lipoprotein particle. [GOC:BHF, GOC:expert_pt, GOC:mah, GOC:rl]
Full description |

Standard name | GO_CHYLOMICRON_REMODELING
Systematic name | M23269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The acquisition, loss or modification of a protein or lipid within a chylomicron, including the hydrolysis of triglyceride by lipoprotein lipase and the subsequent loss of free fatty acid. [GOC:BHF, GOC:expert_pt, GOC:mah, GOC:rl]
Full description |

Standard name | GO_VERY_LOW_DENSITY_LIPOPROTEIN_PARTICLE_REMODELING
Systematic name | M23270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The acquisition, loss or modification of a protein or lipid within a very-low-density lipoprotein particle, including the hydrolysis of triglyceride by hepatic lipase or lipoprotein lipase and the subsequent loss of free fatty acid. [GOC:BHF, GOC:expert_pt, GOC:mah, GOC:rl]
Full description |

Standard name | GO_LOW_DENSITY_LIPOPROTEIN_PARTICLE_REMODELING
Systematic name | M15401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The acquisition, loss or modification of a protein or lipid within a low-density lipoprotein particle, including the hydrolysis of triglyceride by hepatic lipase, with the subsequent loss of free fatty acid, and the transfer of cholesterol esters from LDL to a triglyceride-rich lipoprotein particle by cholesteryl ester transfer protein (CETP), with the simultaneous transfer of triglyceride to LDL. [GOC:BHF, GOC:expert_pt, GOC:mah, GOC:rl]
Full description |

Standard name | GO_HIGH_DENSITY_LIPOPROTEIN_PARTICLE_REMODELING
Systematic name | M14745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The acquisition, loss or modification of a protein or lipid within a high-density lipoprotein particle, including the hydrolysis of triglyceride by hepatic lipase, with the subsequent loss of free fatty acid, and the transfer of cholesterol esters from LDL to a triglyceride-rich lipoprotein particle by cholesteryl ester transfer protein (CETP), with the simultaneous transfer of triglyceride to LDL. [GOC:BHF, GOC:expert_pt, GOC:mah, GOC:rl]
Full description |

Standard name | GO_CHYLOMICRON_ASSEMBLY
Systematic name | M23271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The non-covalent aggregation and arrangement of proteins and lipids in the intestine to form a chylomicron. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_VERY_LOW_DENSITY_LIPOPROTEIN_PARTICLE_ASSEMBLY
Systematic name | M23272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The non-covalent aggregation and arrangement of proteins and lipids in the liver to form a very-low-density lipoprotein particle. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_HIGH_DENSITY_LIPOPROTEIN_PARTICLE_ASSEMBLY
Systematic name | M23273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The non-covalent aggregation and arrangement of proteins and lipids to form a high-density lipoprotein particle. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_PLASMA_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M12592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:ascb_2009, GOC:BHF, GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_LOW_DENSITY_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M11765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a low-density lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_HIGH_DENSITY_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M23274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a high-density lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_LIPID_DROPLET_ORGANIZATION
Systematic name | M23275
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a lipid particle. [GOC:dph, GOC:jl, GOC:mah, PMID:18093937, PMID:18250201]
Full description |

Standard name | GO_SMOOTH_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M23276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a smooth muscle cell. Smooth muscle consists of non-striated, elongated, spindle-shaped cell found lining the digestive tract, uterus, and blood vessels. [CL:0000192, GOC:BHF, GOC:mah, GOC:mtg_apoptosis, GOC:rl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMOOTH_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M23277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of smooth muscle cell apoptotic process. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SMOOTH_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M23278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of smooth muscle cell apoptotic process. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CELL_SURFACE
Systematic name | M14783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within the external part of the cell wall and/or plasma membrane. [GOC:mah]
Full description |

Standard name | GO_CHROMATIN_ORGANIZATION_INVOLVED_IN_REGULATION_OF_TRANSCRIPTION
Systematic name | M23280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that results in the specification, formation or maintenance of the physical structure of eukaryotic chromatin that modulates the rate, frequency or extent of DNA-dependent transcription. [GOC:curators, PMID:21102443]
Full description |

Standard name | GO_NUCLEOBASE_CONTAINING_SMALL_MOLECULE_BIOSYNTHETIC_PROCESS
Systematic name | M23281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a nucleobase-containing small molecule: a nucleobase, a nucleoside, or a nucleotide. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_FLUID_SHEAR_STRESS
Systematic name | M10752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fluid shear stress stimulus. Fluid shear stress is the force acting on an object in a system where the fluid is moving across a solid surface. [GOC:sl]
Full description |

Standard name | GO_NUCLEAR_TRANSCRIBED_MRNA_CATABOLIC_PROCESS_EXONUCLEOLYTIC_3_5
Systematic name | M23282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of the mRNA transcript body that occurs when the 3' end is not protected by a 3'-poly(A) tail; degradation proceeds in the 3' to 5' direction. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_STEROID_ESTERIFICATION
Systematic name | M23283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A lipid modification process in which a steroid ester is formed by the combination of a carboxylic acid (often a fatty acid) and a steroid molecule (e.g. cholesterol). [GOC:BHF, GOC:mah, GOC:pde, GOC:rl]
Full description |

Standard name | GO_LIPID_OXIDATION
Systematic name | M15880
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of one or more electrons from a lipid, with or without the concomitant removal of a proton or protons, by reaction with an electron-accepting substance, by addition of oxygen or by removal of hydrogen. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_SUBSTRATE_ADHESION_DEPENDENT_CELL_SPREADING
Systematic name | M13894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphogenetic process that results in flattening of a cell as a consequence of its adhesion to a substrate. [GOC:mah, GOC:pf, PMID:17050732]
Full description |

Standard name | GO_VERY_LOW_DENSITY_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M23284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a very-low-density lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_MICROTUBULE_ANCHORING
Systematic name | M10603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a microtubule is maintained in a specific location in a cell. [GOC:mah]
Full description |

Standard name | GO_MICROTUBULE_ANCHORING_AT_CENTROSOME
Systematic name | M23285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a microtubule is maintained in a specific location in a cell by attachment to a centrosome. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_NCRNA_PROCESSING
Systematic name | M12423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in the conversion of one or more primary non-coding RNA (ncRNA) transcripts into one or more mature ncRNA molecules. [GOC:mah]
Full description |

Standard name | GO_U4_SNRNA_3_END_PROCESSING
Systematic name | M23287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in forming the mature 3' end of a U4 snRNA molecule. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_PHAGOPHORE_ASSEMBLY_SITE
Systematic name | M23288
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, or maintained at, the phagophore assembly site (PAS). [GOC:rb]
Full description |

Standard name | GO_EARLY_ENDOSOME_TO_GOLGI_TRANSPORT
Systematic name | M14726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from early endosomes to the Golgi. [GOC:rb]
Full description |

Standard name | GO_LATE_ENDOSOME_TO_GOLGI_TRANSPORT
Systematic name | M34142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from late endosomes to the Golgi. [GOC:rb]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_KINETOCHORE
Systematic name | M10686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, or maintained at, the kinetochore. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CHROMOSOME
Systematic name | M13155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, or maintained at, a specific location on a chromosome. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_NUCLEUS
Systematic name | M16062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein transports or maintains the localization of another protein to the nucleus. [GOC:ecd]
Full description |

Standard name | GO_TOOTH_MINERALIZATION
Systematic name | M11506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which calcium salts are deposited into calcareous tooth structures such as dental enamel, dentin and cementum. [GOC:mah, MP:0002817, MSH:D014074]
Full description |

Standard name | GO_CENTROMERE_COMPLEX_ASSEMBLY
Systematic name | M16315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins and centromeric DNA molecules to form a centromeric protein-DNA complex. Includes the formation of the chromatin structures which form a platform for the kinetochore, and assembly of the kinetochore onto this specialized chromatin. In fission yeast and higher eukaryotes this process also includes the formation of heterochromatin at the outer repeat (pericentric) regions of the centromere. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_MITOCHONDRIAL_RESPIRATORY_CHAIN_COMPLEX_III_ASSEMBLY
Systematic name | M23289
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form the cytochrome bc(1) complex (also known as ubiquinol-cytochrome c reductase), in the mitochondrial inner membrane. [GOC:dgf, GOC:mcc]
Full description |

Standard name | GO_PIRNA_METABOLIC_PROCESS
Systematic name | M14535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving piRNAs, Piwi-associated RNAs, a class of 24- to 30-nucleotide RNA derived from repeat or complex DNA sequence elements and processed by a Dicer-independent mechanism. [GOC:kmv]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_HEAT
Systematic name | M13924
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a heat stimulus, a temperature stimulus above the optimal temperature for that organism. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_TUMOR_NECROSIS_FACTOR
Systematic name | M16143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a tumor necrosis factor stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_REACTIVE_OXYGEN_SPECIES
Systematic name | M16581
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a reactive oxygen species stimulus. Reactive oxygen species include singlet oxygen, superoxide, and oxygen free radicals. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_LAMINAR_FLUID_SHEAR_STRESS
Systematic name | M16613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a laminar fluid shear stress stimulus. Laminar fluid flow is the force acting on an object in a system where the fluid is moving across a solid surface in parallel layers. As an example, laminar shear stress can be seen where blood flows against the luminal side of blood vessel walls. [GOC:ecd]
Full description |

Standard name | GO_CELLULAR_PROTEIN_CONTAINING_COMPLEX_ASSEMBLY
Systematic name | M23290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a protein complex, occurring at the level of an individual cell. [GOC:jl]
Full description |

Standard name | GO_CELLULAR_PROTEIN_CONTAINING_COMPLEX_LOCALIZATION
Systematic name | M23292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein complex localization process that takes place at the cellular level; as a result, a protein complex is transported to, or maintained in, a specific location within a cell. [GOC:mah]
Full description |

Standard name | GO_GLUTATHIONE_TRANSPORT
Systematic name | M34143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of glutathione, the tripeptide glutamylcysteinylglycine, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_CARBOHYDRATE_BIOSYNTHETIC_PROCESS
Systematic name | M15455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of carbohydrates, any of a group of organic compounds based of the general formula Cx(H2O)y, carried out by individual cells. [GOC:mah]
Full description |

Standard name | GO_PHOSPHATIDYLCHOLINE_CATABOLIC_PROCESS
Systematic name | M23293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of phosphatidylcholines, any of a class of glycerophospholipids in which the phosphatidyl group is esterified to the hydroxyl group of choline. [GOC:jp]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_UV
Systematic name | M10612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ultraviolet radiation (UV light) stimulus. Ultraviolet radiation is electromagnetic radiation with a wavelength in the range of 10 to 380 nanometers. [GOC:mah]
Full description |

Standard name | GO_CORTISOL_METABOLIC_PROCESS
Systematic name | M29153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving cortisol, the steroid hormone 11-beta-17,21-trihydroxypregn-4-ene-3,20-dione. Cortisol is synthesized from cholesterol in the adrenal gland and controls carbohydrate, fat and protein metabolism and has anti-inflammatory properties. [GOC:BHF, GOC:mah, GOC:rl]
Full description |

Standard name | GO_RETINOIC_ACID_CATABOLIC_PROCESS
Systematic name | M34144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of retinoic acid, one of the three components that makes up vitamin A. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_NUCLEOBASE_CONTAINING_SMALL_MOLECULE_CATABOLIC_PROCESS
Systematic name | M23295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a nucleobase-containing small molecule: a nucleobase, a nucleoside, or a nucleotide. [GOC:mah]
Full description |

Standard name | GO_NCRNA_METABOLIC_PROCESS
Systematic name | M13371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving non-coding RNA transcripts (ncRNAs). [GOC:mah]
Full description |

Standard name | GO_NCRNA_CATABOLIC_PROCESS
Systematic name | M10289
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of non-coding RNA transcripts (ncRNAs). Includes the breakdown of cryptic unstable transcripts (CUTs). [GOC:rb, PMID:18591258]
Full description |

Standard name | GO_RESPONSE_TO_PROSTAGLANDIN
Systematic name | M12603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a prostagladin stimulus. [GOC:BHF, GOC:vk]
Full description |

Standard name | GO_RESPONSE_TO_PROSTAGLANDIN_E
Systematic name | M10616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a prostagladin E stimulus. [GOC:BHF, GOC:vk]
Full description |

Standard name | GO_RESPONSE_TO_GONADOTROPIN
Systematic name | M15965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a gonadotropin stimulus. [GOC:BHF, GOC:vk]
Full description |

Standard name | GO_HISTONE_H3_K4_DEMETHYLATION
Systematic name | M23296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the removal of a methyl group from lysine at position 4 of the histone. [GOC:mah]
Full description |

Standard name | GO_HISTONE_H3_K4_DEMETHYLATION_TRIMETHYL_H3_K4_SPECIFIC
Systematic name | M23297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the removal of a methyl group from a trimetylated lysine at position 4 of the histone. [GOC:mah]
Full description |

Standard name | GO_DNA_REPLICATION_DEPENDENT_NUCLEOSOME_ORGANIZATION
Systematic name | M14696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation or destruction of chromatin structures on newly replicated DNA, coupled to strand elongation. [GOC:mah, PMID:17510629]
Full description |

Standard name | GO_DNA_REPLICATION_INDEPENDENT_NUCLEOSOME_ORGANIZATION
Systematic name | M16465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation or destruction of chromatin structures, occurring outside the context of DNA replication. [GOC:mah, PMID:17510629]
Full description |

Standard name | GO_NUCLEOSOME_ORGANIZATION
Systematic name | M23298
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of one or more nucleosomes. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_HORMONE_METABOLIC_PROCESS
Systematic name | M12703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any hormone, naturally occurring substances secreted by specialized cells that affects the metabolism or behavior of other cells possessing functional receptors for the hormone, as carried out by individual cells. [GOC:mah]
Full description |

Standard name | GO_IRON_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M23299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which an iron ion is transported from one side of a membrane to the other by means of some agent such as a transporter or pore. [GOC:mah, PMID:11390404]
Full description |

Standard name | GO_REGULATION_OF_IRON_ION_TRANSPORT
Systematic name | M23300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of iron ions (Fe) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_IRON_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M29154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of iron ions (Fe) from one side of a membrane to the other by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_TRANSMEMBRANE_TRANSPORT
Systematic name | M16782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of a solute from one side of a membrane to the other. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSMEMBRANE_TRANSPORT
Systematic name | M10216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of a solute from one side of a membrane to the other. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSMEMBRANE_TRANSPORT
Systematic name | M11713
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of a solute from one side of a membrane to the other. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M23301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of ions from one side of a membrane to the other. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M23302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of ions from one side of a membrane to the other. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M23303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of ions from one side of a membrane to the other. [GOC:mah]
Full description |

Standard name | GO_HISTONE_H4_K20_METHYLATION
Systematic name | M23304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H4 by addition of one or more methyl groups to lysine at position 20 of the histone. [GOC:mah]
Full description |

Standard name | GO_HISTONE_H4_K20_TRIMETHYLATION
Systematic name | M23305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H4 by addition of three methyl groups to lysine at position 20 of the histone. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_HISTAMINE
Systematic name | M16545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a histamine stimulus. Histamine, the biogenic amine 2-(1H-imidazol-4-yl)ethanamine, is involved in local immune responses as well as regulating physiological function in the gut and acting as a neurotransmitter. [GOC:BHF, GOC:mah, GOC:vk]
Full description |

Standard name | GO_HISTONE_ARGININE_METHYLATION
Systematic name | M29155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of a histone by addition of a methyl group to an arginine residue. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_FOLDING_IN_ENDOPLASMIC_RETICULUM
Systematic name | M14955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein folding process that takes place in the endoplasmic reticulum (ER). Secreted, plasma membrane and organelle proteins are folded in the ER, assisted by chaperones and foldases (protein disulphide isomerases), and additional factors required for optimal folding (ATP, Ca2+ and an oxidizing environment to allow disulfide bond formation). [GOC:mah, GOC:vw]
Full description |

Standard name | GO_RESPONSE_TO_ENDOPLASMIC_RETICULUM_STRESS
Systematic name | M10844
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stress acting at the endoplasmic reticulum. ER stress usually results from the accumulation of unfolded or misfolded proteins in the ER lumen. [GOC:cjm, GOC:mah]
Full description |

Standard name | GO_MITOCHONDRIAL_PROTEIN_PROCESSING
Systematic name | M23306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The peptide cleavage of mitochondrial proteins, including cleavage contributing to their import. [GOC:curators]
Full description |

Standard name | GO_PEPTIDYL_LYSINE_DEACETYLATION
Systematic name | M23307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of an acetyl group from an acetylated lysine residue in a peptide or protein. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_SOMATIC_STEM_CELL_POPULATION_MAINTENANCE
Systematic name | M10312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process by which an organism retains a population of somatic stem cells, undifferentiated cells in the embryo or adult which can undergo unlimited division and give rise to cell types of the body other than those of the germ-line. [GOC:bf, ISBN:0582227089]
Full description |

Standard name | GO_REGULATION_OF_RAC_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M12923
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of Rac protein signal transduction. [GOC:bf]
Full description |

Standard name | GO_REGULATION_OF_RHO_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M13862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of Rho protein signal transduction. [GOC:bf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RHO_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M12850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of Rho protein signal transduction. [GOC:bf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RHO_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M11062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of Rho protein signal transduction. [GOC:bf]
Full description |

Standard name | GO_SPERM_EGG_RECOGNITION
Systematic name | M13217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial contact step made between the sperm plasma membrane and outer layer of the egg during fertilization. [GOC:bf]
Full description |

Standard name | GO_EMBRYONIC_HEART_TUBE_DEVELOPMENT
Systematic name | M12452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the embryonic heart tube over time, from its formation to the mature structure. The heart tube forms as the heart rudiment from the heart field. [GOC:go_curators]
Full description |

Standard name | GO_CARDIOCYTE_DIFFERENTIATION
Systematic name | M14538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized structural and/or functional features of a cell that will form part of the cardiac organ of an individual. [GOC:bf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HISTONE_ACETYLATION
Systematic name | M11883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the addition of an acetyl group to a histone protein. [GOC:bf]
Full description |

Standard name | GO_AXONEME_ASSEMBLY
Systematic name | M15673
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The assembly and organization of an axoneme, the bundle of microtubules and associated proteins that forms the core of cilia (also called flagella) in eukaryotic cells and is responsible for their movements. [GOC:bf, GOC:cilia, GOC:jl, ISBN:0815316194]
Full description |

Standard name | GO_MAINTENANCE_OF_APICAL_BASAL_CELL_POLARITY
Systematic name | M23308
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Retaining the established polarization of a cell along its apical/basal axis. [GOC:bf]
Full description |

Standard name | GO_SPERM_CHROMATIN_CONDENSATION
Systematic name | M23309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progressive compaction of the spermatid chromatin so that it reaches a level of condensation that is not compatible with nuclear activities such as transcription or DNA replication. [GOC:bf, PMID:11735001]
Full description |

Standard name | GO_SPERMATOGENESIS_EXCHANGE_OF_CHROMOSOMAL_PROTEINS
Systematic name | M23310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The replacement of somatic histones within sperm chromatin with sperm-specific histones or protamines with unique DNA-binding properties, resulting in condensation of the sperm chromatin. [GOC:bf, PMID:11735001]
Full description |

Standard name | GO_RESPONSE_TO_NICOTINE
Systematic name | M14038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nicotine stimulus. [GOC:bf, GOC:ef, ISBN:0198506732, ISBN:0582227089]
Full description |

Standard name | GO_BEHAVIORAL_RESPONSE_TO_NICOTINE
Systematic name | M23311
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in the behavior of an organism as a result of a nicotine stimulus. [GOC:bf, ISBN:0198506732]
Full description |

Standard name | GO_APPENDAGE_MORPHOGENESIS
Systematic name | M23312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of appendages are generated and organized. An appendage is an organ or part that is attached to the trunk of an organism, such as a limb or a branch. [ISBN:0582227089]
Full description |

Standard name | GO_GENITALIA_MORPHOGENESIS
Systematic name | M23313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of genitalia are generated and organized. The genitalia are the organs of reproduction or generation, external and internal. [GOC:bf]
Full description |

Standard name | GO_EMBRYONIC_APPENDAGE_MORPHOGENESIS
Systematic name | M29156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process, occurring in the embryo, by which the anatomical structures of the appendage are generated and organized. An appendage is an organ or part that is attached to the trunk of an organism, such as a limb or a branch. [ISBN:0582227089]
Full description |

Standard name | GO_EMBRYONIC_FORELIMB_MORPHOGENESIS
Systematic name | M12566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process, occurring in the embryo, by which the anatomical structures of the forelimb are generated and organized. The forelimbs are the front limbs of an animal, e.g. the arms of a human. [ISBN:0198612001]
Full description |

Standard name | GO_EMBRYONIC_HINDLIMB_MORPHOGENESIS
Systematic name | M13437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process, occurring in the embryo, by which the anatomical structures of the hindlimbs are generated and organized. The hindlimbs are the posterior limbs of an animal. [ISBN:0198612001]
Full description |

Standard name | GO_FORELIMB_MORPHOGENESIS
Systematic name | M11468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the forelimb are generated and organized. The forelimbs are the front limbs of an animal, e.g. the arms of a human. [GOC:go_curators]
Full description |

Standard name | GO_HINDLIMB_MORPHOGENESIS
Systematic name | M10782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the hindlimb are generated and organized. [GOC:go_curators]
Full description |

Standard name | GO_TUBE_FORMATION
Systematic name | M14377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Creation of the central hole of a tube in an anatomical structure through which gases and/or liquids flow. [GOC:bf]
Full description |

Standard name | GO_REGULATION_OF_TUBE_SIZE
Systematic name | M23314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Ensuring that a tube is of the correct length and diameter. Tube size must be maintained not only during tube formation, but also throughout development and in some physiological processes. [PMID:10887083]
Full description |

Standard name | GO_EMBRYONIC_HEMOPOIESIS
Systematic name | M10258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The stages of blood cell formation that take place within the embryo. [GOC:bf]
Full description |

Standard name | GO_ECTOPIC_GERM_CELL_PROGRAMMED_CELL_DEATH
Systematic name | M23315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Programmed cell death of an errant germ line cell that is outside the normal migratory path or ectopic to the gonad. This is an important mechanism of regulating germ cell survival within the embryo. [PMID:12814944]
Full description |

Standard name | GO_IONOTROPIC_GLUTAMATE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by glutamate binding to a glutamate receptor on the surface of the target cell, followed by the movement of ions through a channel in the receptor complex. Ends with regulation of a downstream cellular process, e.g. transcription. [GOC:signaling, ISBN:0198506732]
Full description |

Standard name | GO_TUBE_MORPHOGENESIS
Systematic name | M18329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a tube are generated and organized. Epithelial and endothelial tubes transport gases, liquids and cells from one site to another and form the basic structure of many organs and tissues, with tube shape and organization varying from the single-celled excretory organ in Caenorhabditis elegans to the branching trees of the mammalian kidney and insect tracheal system. [GOC:bf, PMID:14624839]
Full description |

Standard name | GO_PEPTIDYL_ARGININE_N_METHYLATION
Systematic name | M23316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a methyl group onto a nitrogen atom of an arginine residue in a protein. [GOC:bf]
Full description |

Standard name | GO_PEPTIDYL_ARGININE_OMEGA_N_METHYLATION
Systematic name | M29157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a methyl group onto a terminal nitrogen (omega nitrogen) atom of an arginine residue in a protein. [PMID:14705965, RESID:AA0067, RESID:AA0068, RESID:AA0069]
Full description |

Standard name | GO_SYNAPTIC_TRANSMISSION_GLUTAMATERGIC
Systematic name | M15296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The vesicular release of glutamate from a presynapse, across a chemical synapse, the subsequent activation of glutamate receptors at the postsynapse of a target cell (neuron, muscle, or secretory cell) and the effects of this activation on the postsynaptic membrane potential and ionic composition of the postsynaptic cytosol. This process encompasses both spontaneous and evoked release of neurotransmitter and all parts of synaptic vesicle exocytosis. Evoked transmission starts with the arrival of an action potential at the presynapse. [GOC:dos]
Full description |

Standard name | GO_MULTICELLULAR_ORGANISM_GROWTH
Systematic name | M13366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The increase in size or mass of an entire multicellular organism, as opposed to cell growth. [GOC:bf, GOC:curators, GOC:dph, GOC:tb]
Full description |

Standard name | GO_ORGAN_GROWTH
Systematic name | M13518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The increase in size or mass of an organ. Organs are commonly observed as visibly distinct structures, but may also exist as loosely associated clusters of cells that function together as to perform a specific function. [GOC:bf, ISBN:0471245208, ISBN:0721662544]
Full description |

Standard name | GO_PROTEIN_MANNOSYLATION
Systematic name | M13289
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a mannose residue to a protein acceptor molecule. [GOC:bf, GOC:pr]
Full description |

Standard name | GO_PROTEIN_O_LINKED_MANNOSYLATION
Systematic name | M12862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of mannose from dolichyl activated mannose to the hydroxyl group of a seryl or threonyl residue of a protein acceptor molecule, to form an O-linked protein-sugar linkage. [GOC:bf, PMID:9878797]
Full description |

Standard name | GO_ENDOCRINE_SYSTEM_DEVELOPMENT
Systematic name | M15186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Progression of the endocrine system over time, from its formation to a mature structure. The endocrine system is a system of hormones and ductless glands, where the glands release hormones directly into the blood, lymph or other intercellular fluid, and the hormones circulate within the body to affect distant organs. The major glands that make up the human endocrine system are the hypothalamus, pituitary, thyroid, parathryoids, adrenals, pineal body, and the reproductive glands which include the ovaries and testes. [GOC:bf, Wikipedia:Development_of_the_endocrine_system]
Full description |

Standard name | GO_EXOCRINE_SYSTEM_DEVELOPMENT
Systematic name | M13401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Progression of the exocrine system over time, from its formation to a mature structure. The exocrine system is a system of hormones and glands, where the glands secrete straight to a target site via ducts or tubes. The human exocrine system includes the salivary glands, sweat glands and many glands of the digestive system. [GOC:bf, Wikipedia:Exocrine_gland]
Full description |

Standard name | GO_MIRNA_MEDIATED_INHIBITION_OF_TRANSLATION
Systematic name | M23317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which microRNAs (miRNAs) block the translation of target mRNAs into proteins. Once incorporated into a RNA-induced silencing complex (RISC), a miRNA will typically mediate repression of translation if the miRNA imperfectly base-pairs with the 3' untranslated regions of target mRNAs. [PMID:14744438, PMID:15196554]
Full description |

Standard name | GO_MIRNA_LOADING_ONTO_RISC_INVOLVED_IN_GENE_SILENCING_BY_MIRNA
Systematic name | M23318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of a microRNA (miRNA) strand from a miRNA:miRNA duplex onto the RNA-initiated silencing complex (RISC). [PMID:14744438]
Full description |

Standard name | GO_SEGMENTATION
Systematic name | M13563
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regionalization process that divides an organism or part of an organism into a series of semi-repetitive parts, or segments, often arranged along a longitudinal axis. [PMID:10611687, PMID:9706689]
Full description |

Standard name | GO_TUBE_DEVELOPMENT
Systematic name | M2973
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a tube over time, from its initial formation to a mature structure. Epithelial and endothelial tubes transport gases, liquids and cells from one site to another and form the basic structure of many organs and tissues including lung and trachea, kidney, the mammary gland, the vascular system and the gastrointestinal and urinary-genital tracts. [PMID:12526790]
Full description |

Standard name | GO_REGULATION_OF_DEPHOSPHORYLATION
Systematic name | M14444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of removal of phosphate groups from a molecule. [GOC:bf]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_DEPHOSPHORYLATION
Systematic name | M23319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of removal of phosphate groups from a protein. [GOC:bf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DEPHOSPHORYLATION
Systematic name | M14155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process the stops, prevents, or reduces the frequency, rate or extent of removal of phosphate groups from a molecule. [GOC:bf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DEPHOSPHORYLATION
Systematic name | M16159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of removal of phosphate groups from a molecule. [GOC:bf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_DEPHOSPHORYLATION
Systematic name | M23320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of removal of phosphate groups from a protein. [GOC:bf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_DEPHOSPHORYLATION
Systematic name | M23321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process the stops, prevents, or reduces the frequency, rate or extent of removal of phosphate groups from a protein. [GOC:bf]
Full description |

Standard name | GO_WOUND_HEALING_SPREADING_OF_EPIDERMAL_CELLS
Systematic name | M15499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The migration of an epidermal cell along or through a wound gap that contributes to the reestablishment of a continuous epidermis. [GOC:bf, PMID:15269788]
Full description |

Standard name | GO_HAIR_CELL_DIFFERENTIATION
Systematic name | M14565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a hair cell. [GOC:bf]
Full description |

Standard name | GO_HIPPO_SIGNALING
Systematic name | M11445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals mediated by the serine/threonine kinase Hippo or one of its orthologs. In Drosophila, Hippo in complex with the scaffold protein Salvador (Sav), phosphorylates and activates Warts (Wts), which in turn phosphorylates and inactivates the Yorkie (Yki) transcriptional activator. The core fly components hippo, sav, wts and mats are conserved in mammals as STK4/3 (MST1/2), SAV1/WW45, LATS1/2 and MOB1. [PMID:17318211, PMID:18328423]
Full description |

Standard name | GO_REGULATION_OF_HIPPO_SIGNALING
Systematic name | M23322
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hippo signaling. [GOC:bf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HIPPO_SIGNALING
Systematic name | M23323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of hippo signaling. [GOC:bf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HIPPO_SIGNALING
Systematic name | M34145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of hippo signaling. [GOC:bf]
Full description |

Standard name | GO_NOTCH_RECEPTOR_PROCESSING_LIGAND_DEPENDENT
Systematic name | M23324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The proteolytic cleavages to the Notch protein that occur as a result of ligand binding. Ligand binding at the cell surface exposes an otherwise inaccessible cleavage site in the extracellular portion of Notch, which when cleaved releases a membrane-tethered form of the Notch intracellular domain. Subsequent cleavage within the transmembrane domain then leads to the release of the soluble Notch intracellular domain (NICD). [GOC:bf, PMID:12651094]
Full description |

Standard name | GO_PEPTIDYL_TYROSINE_DEPHOSPHORYLATION
Systematic name | M23325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of phosphoric residues from peptidyl-O-phospho-tyrosine to form peptidyl-tyrosine. [GOC:bf]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACYL_COA_METABOLIC_PROCESS
Systematic name | M23326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving long-chain fatty-acyl-CoAs, any derivative of coenzyme A in which the sulfhydryl group is in a thioester linkage with a long-chain fatty-acyl group. Long-chain fatty-acyl-CoAs have chain lengths of C13 or more. [ISBN:0198506732]
Full description |

Standard name | GO_FATTY_ACYL_COA_METABOLIC_PROCESS
Systematic name | M12232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a fatty-acyl-CoA, any derivative of coenzyme A in which the sulfhydryl group is in thiolester linkage with a fatty-acyl group. [ISBN:0198506732]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACYL_COA_BIOSYNTHETIC_PROCESS
Systematic name | M23327
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a long-chain fatty-acyl-CoA any derivative of coenzyme A in which the sulfhydryl group is in a thioester linkage with a long-chain fatty-acyl group. Long-chain fatty-acyl-CoAs have chain lengths of C13 or more. [ISBN:0198506732]
Full description |

Standard name | GO_CELLULAR_TRIGLYCERIDE_HOMEOSTASIS
Systematic name | M23328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of triglyceride within a cell or between a cell and its external environment. [GOC:BHF]
Full description |

Standard name | GO_PEROXISOME_PROLIFERATOR_ACTIVATED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of a ligand to any of the peroxisome proliferator activated receptors (alpha, beta or gamma) in the nuclear membrane, and ending with the initiation or termination of the transcription of target genes. [GOC:BHF, PMID:18221086]
Full description |

Standard name | GO_REGULATION_OF_PEROXISOME_PROLIFERATOR_ACTIVATED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M13315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the peroxisome proliferator activated receptor signaling pathway. [GOC:bf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PEROXISOME_PROLIFERATOR_ACTIVATED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the peroxisome proliferator activated receptor signaling pathway. [GOC:bf]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_MICROTUBULE
Systematic name | M23331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained at, a microtubule. [GOC:bf, GOC:lb]
Full description |

Standard name | GO_STEROL_IMPORT
Systematic name | M23332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a sterol into a cell or organelle. Sterols are steroids with one or more hydroxyl groups and a hydrocarbon side-chain in the molecule. [GOC:bf, PMID:19793923]
Full description |

Standard name | GO_THIOESTER_METABOLIC_PROCESS
Systematic name | M11634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a thioester, a compound of general formula RC(=O)SR' in which the linking oxygen in an ester is replaced by a sulfur atom. They are the product of esterification between a carboxylic acid and a thiol. [GOC:bf, Wikipedia:Thioester]
Full description |

Standard name | GO_THIOESTER_BIOSYNTHETIC_PROCESS
Systematic name | M15448
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a thioester, a compound of general formula RC(=O)SR' in which the linking oxygen in an ester is replaced by a sulfur atom. They are the product of esterification between a carboxylic acid and a thiol. [GOC:bf, http://encyclopedia.thefreedictionary.com/Thioester]
Full description |

Standard name | GO_ROUNDABOUT_SIGNALING_PATHWAY
Systematic name | M10948
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a SLIT protein to a Roundabout (ROBO) family receptor on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:BHF, GOC:signaling]
Full description |

Standard name | GO_HISTONE_SERINE_PHOSPHORYLATION
Systematic name | M23333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histones by addition of a phosphate group to a serine residue. [GOC:bf]
Full description |

Standard name | GO_HISTONE_THREONINE_PHOSPHORYLATION
Systematic name | M23334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histones by addition of a phosphate group to a threonine residue. [GOC:bf]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_SYNAPSE
Systematic name | M15091
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, and/or maintained at the synapse, the junction between a nerve fiber of one neuron and another neuron or muscle fiber or glial cell. [GOC:bf]
Full description |

Standard name | GO_AUTOCRINE_SIGNALING
Systematic name | M23335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Signaling between cells of the same type. The signal produced by the signaling cell binds to a receptor on, and affects a cell of the same type. [GOC:bf, ISBN:3527303782]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX_CELL_SIGNALING
Systematic name | M34146
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that mediates the transfer of information between the extracellular matrix and a cell. [GOC:bf]
Full description |

Standard name | GO_COPPER_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M23336
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of copper cation across a membrane. [GOC:vw]
Full description |

Standard name | GO_PHOSPHATE_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M23337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a phosphate is transported across a membrane. [GOC:vw]
Full description |

Standard name | GO_MAINTENANCE_OF_PROTEIN_LOCALIZATION_IN_ENDOPLASMIC_RETICULUM
Systematic name | M23338
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is maintained in the endoplasmic reticulum and prevented from moving elsewhere. These include sequestration within the endoplasmic reticulum, protein stabilization to prevent transport elsewhere and the active retrieval of proteins that escape the endoplasmic reticulum. [GOC:bf, GOC:vw]
Full description |

Standard name | GO_CELL_MIGRATION_INVOLVED_IN_VASCULOGENESIS
Systematic name | M23339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a cell from one site to another that will contribute to the differentiation of an endothelial cell that will form de novo blood vessels and tubes. [GOC:dgh]
Full description |

Standard name | GO_DIPEPTIDE_TRANSMEMBRANE_TRANSPORT
Systematic name | M23340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a dipeptide across a membrane by means of some agent such as a transporter or pore. A dipeptide is a combination of two amino acids linked together by a peptide (-CO-NH-) bond. [GOC:vw]
Full description |

Standard name | GO_TRIPEPTIDE_TRANSMEMBRANE_TRANSPORT
Systematic name | M34147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a tripeptide across a membrane by means of some agent such as a transporter or pore. A tripeptide is a compound containing three amino acids linked together by peptide bonds. [GOC:vw]
Full description |

Standard name | GO_RESPONSE_TO_INTERFERON_ALPHA
Systematic name | M11929
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interferon-alpha stimulus. Interferon-alpha is a type I interferon. [GOC:sl, PMID:11356686]
Full description |

Standard name | GO_RESPONSE_TO_INTERFERON_BETA
Systematic name | M11809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interferon-beta stimulus. Interferon-beta is a type I interferon. [GOC:sl, PMID:9561374]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_INTERFERON_ALPHA
Systematic name | M23341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interferon-alpha stimulus. Interferon-alpha is a type I interferon. [GOC:sl]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_INTERFERON_BETA
Systematic name | M16666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interferon-beta stimulus. Interferon-beta is a type I interferon. [GOC:sl]
Full description |

Standard name | GO_VESICLE_CARGO_LOADING
Systematic name | M23342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a macromolecular complex between the coat proteins and proteins and/or lipoproteins that are going to be transported by a vesicle. [GOC:bf, GOC:lb]
Full description |

Standard name | GO_VITAMIN_TRANSMEMBRANE_TRANSPORT
Systematic name | M23343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a vitamin is transported across a membrane. A vitamin is one of a number of unrelated organic substances that occur in many foods in small amounts and that are necessary in trace amounts for the normal metabolic functioning of the body. [GOC:bf]
Full description |

Standard name | GO_DETERMINATION_OF_PANCREATIC_LEFT_RIGHT_ASYMMETRY
Systematic name | M23344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Determination of the asymmetric location of the pancreas with respect to the left and right halves of the organism. [GOC:dgh, PMID:12702646]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULAR_WOUND_HEALING
Systematic name | M29158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of blood vessel formation when new vessels emerge from the proliferation of pre-existing blood vessels and contribute to the series of events that restore integrity to damaged vasculature. [GOC:rph]
Full description |

Standard name | GO_GASTRIC_MOTILITY
Systematic name | M23345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The spontaneous peristaltic movements of the stomach that aid in digestion, moving food through the stomach and out through the pyloric sphincter into the duodenum. [GOC:cy, ISBN:9781416032458, PMID:16139031]
Full description |

Standard name | GO_GASTRIC_EMPTYING
Systematic name | M23346
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the liquid and liquid-suspended solid contents of the stomach exit through the pylorus into the duodenum. [GOC:cy, ISBN:9781416032458]
Full description |

Standard name | GO_SNARE_COMPLEX_ASSEMBLY
Systematic name | M23347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a SNARE complex, a protein complex involved in membrane fusion; a stable ternary complex consisting of a four-helix bundle, usually formed from one R-SNARE and three Q-SNAREs with an ionic layer sandwiched between hydrophobic layers. [GOC:rb, PMID:10872468]
Full description |

Standard name | GO_METANEPHRIC_PART_OF_URETERIC_BUD_DEVELOPMENT
Systematic name | M23348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The development of the portion of the ureteric bud tube that contributes to the morphogenesis of the metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_REGULATION_OF_MYOSIN_LIGHT_CHAIN_PHOSPHATASE_ACTIVITY
Systematic name | M23349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of myosin-light-chain-phosphatase activity. [GOC:bf, GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MYOSIN_LIGHT_CHAIN_PHOSPHATASE_ACTIVITY
Systematic name | M23350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of myosin-light-chain-phosphatase activity. [GOC:bf, GOC:go_curators]
Full description |

Standard name | GO_DNA_DEALKYLATION
Systematic name | M11562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of an alkyl group from one or more nucleotides within an DNA molecule. [GOC:bf]
Full description |

Standard name | GO_OXIDATIVE_DNA_DEMETHYLATION
Systematic name | M23351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Removal of the methyl group from one or more nucleotides within a DNA molecule involving the oxidation (i.e. electron loss) of one or more atoms. [PMID:12594517, PMID:16482161, PMID:18775698]
Full description |

Standard name | GO_OXIDATIVE_RNA_DEMETHYLATION
Systematic name | M23352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of the methyl group from one or more nucleotides within an RNA molecule involving oxidation (i.e. electron loss) of one or more atoms. [PMID:12594517, PMID:16482161, PMID:18775698]
Full description |

Standard name | GO_HISTONE_H2A_MONOUBIQUITINATION
Systematic name | M11741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H2A by addition of a single ubiquitin group. [PMID:18206970]
Full description |

Standard name | GO_PROTEIN_K29_LINKED_UBIQUITINATION
Systematic name | M23353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein ubiquitination process in which a polymer of ubiquitin, formed by linkages between lysine residues at position 29 of the ubiquitin monomers, is added to a protein. K29-linked ubiquitination targets the substrate protein for degradation. [PMID:17028573]
Full description |

Standard name | GO_MONOUBIQUITINATED_PROTEIN_DEUBIQUITINATION
Systematic name | M23354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of the ubiquitin group from a monoubiquitinated protein. [GOC:bf]
Full description |

Standard name | GO_PROTEIN_K29_LINKED_DEUBIQUITINATION
Systematic name | M23355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein deubiquitination process in which a K29-linked ubiquitin chain, i.e. a polymer of ubiquitin formed by linkages between lysine residues at position 29 of the ubiquitin monomers, is removed from a protein. [GOC:bf]
Full description |

Standard name | GO_PROLINE_TRANSMEMBRANE_TRANSPORT
Systematic name | M23356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of proline, pyrrolidine-2-carboxylic acid, across a membrane by means of some agent such as a transporter or pore. [GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_SNARE_COMPLEX_ASSEMBLY
Systematic name | M23357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of assembly of the SNARE complex. The SNARE complex is a protein complex involved in membrane fusion; a stable ternary complex consisting of a four-helix bundle, usually formed from one R-SNARE and three Q-SNAREs with an ionic layer sandwiched between hydrophobic layers. [GOC:rb]
Full description |

Standard name | GO_REGULATION_OF_CHROMATIN_BINDING
Systematic name | M11819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of chromatin binding. Chromatin binding is the selective interaction with chromatin, the network of fibers of DNA, protein, and sometimes RNA, that make up the chromosomes of the eukaryotic nucleus during interphase. [GOC:bf, PMID:20404130]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHROMATIN_BINDING
Systematic name | M23359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the frequency, rate or extent of chromatin binding. Chromatin binding is the selective interaction with chromatin, the network of fibers of DNA, protein, and sometimes RNA, that make up the chromosomes of the eukaryotic nucleus during interphase. [GOC:bf, PMID:20404130]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHROMATIN_BINDING
Systematic name | M23360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of chromatin binding. Chromatin binding is the selective interaction with chromatin, the network of fibers of DNA, protein, and sometimes RNA, that make up the chromosomes of the eukaryotic nucleus during interphase. [GOC:bf, PMID:20404130]
Full description |

Standard name | GO_REGULATION_OF_KIDNEY_SIZE
Systematic name | M34148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the size of a kidney. [GOC:bf]
Full description |

Standard name | GO_NON_CANONICAL_WNT_SIGNALING_PATHWAY
Systematic name | M10871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of a Wnt protein to a frizzled family receptor on the surface of the target cell, followed by propagation of the signal via effectors other than beta-catenin. [GOC:signaling]
Full description |

Standard name | GO_SEQUESTERING_OF_EXTRACELLULAR_LIGAND_FROM_RECEPTOR
Systematic name | M23361
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of binding or confining an extracellular signaling ligand, such that the ligand is unable to bind to its cell surface receptor. [GOC:BHF, GOC:signaling]
Full description |

Standard name | GO_CALCIUM_MEDIATED_SIGNALING_USING_INTRACELLULAR_CALCIUM_SOURCE
Systematic name | M11392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which a cell uses calcium ions released from an intracellular store to convert a signal into a response. [GOC:bf, GOC:BHF, PMID:20192754]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_PURINERGIC_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M10205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a receptor binding to an extracellular purine or purine derivative and transmitting the signal to a heterotrimeric G-protein complex to initiate a change in cell activity. [GOC:BHF, PMID:9755289]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_PURINERGIC_NUCLEOTIDE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M10348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a receptor binding to an extracellular purine nucleotide and transmitting the signal to a heterotrimeric G-protein complex to initiate a change in cell activity. [GOC:BHF, PMID:9755289]
Full description |

Standard name | GO_PURINERGIC_NUCLEOTIDE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M14531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a receptor binding to an extracellular purine nucleotide to initiate a change in cell activity. [GOC:BHF, PMID:9755289]
Full description |

Standard name | GO_PROTEIN_DEGLUTAMYLATION
Systematic name | M23362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of a glutamate residue from a protein. Glutamate residues in proteins can be gene-encoded, or added as side chains during the protein modification process of polyglutamylation. [GOC:sp, PMID:21074048]
Full description |

Standard name | GO_C_TERMINAL_PROTEIN_DEGLUTAMYLATION
Systematic name | M23363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of a C-terminal, gene-encoded glutamate residue from a protein. [GOC:sp, PMID:21074048]
Full description |

Standard name | GO_PROTEIN_SIDE_CHAIN_DEGLUTAMYLATION
Systematic name | M23364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of a glutamate residue from the side chain of a protein. Glutamate side chains are added to glutamic acid residues within the primary protein sequence during polyglutamylation. [GOC:sp, PMID:21074048]
Full description |

Standard name | GO_STRESS_GRANULE_DISASSEMBLY
Systematic name | M23365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disaggregation of a stress granule into its constituent protein and RNA parts. [GOC:BHF, PMID:19825938]
Full description |

Standard name | GO_RECEPTOR_TRANSACTIVATION
Systematic name | M23366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a receptor is activated by another receptor. Receptor transactivation can occur through different mechanisms and includes cross-talk between signaling pathways where one receptor activates a receptor for a different ligand, and also activation of subunits within a receptor oligomer. [GOC:al, GOC:bf, GOC:BHF, PMID:16870826, PMID:21063387]
Full description |

Standard name | GO_CERAMIDE_TRANSPORT
Systematic name | M23367
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of ceramides into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Ceramides are a class of lipid composed of sphingosine linked to a fatty acid. [GOC:bf, GOC:sart]
Full description |

Standard name | GO_BONE_MINERALIZATION_INVOLVED_IN_BONE_MATURATION
Systematic name | M23368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The deposition of hydroxyapatite, involved in the progression of the skeleton from its formation to its mature state. [GOC:bf, GOC:BHF]
Full description |

Standard name | GO_MAINTENANCE_OF_BLOOD_BRAIN_BARRIER
Systematic name | M34149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Maintaining the structure and function of the blood-brain barrier, thus ensuring specific regulated transport of substances (e.g. macromolecules, small molecules, ions) into the brain, and out of the brain into the blood circulation. [GOC:aruk, GOC:bc, GOC:bf, GOC:sl, PMID:20080302, PMID:30280653]
Full description |

Standard name | GO_RESPONSE_TO_STILBENOID
Systematic name | M23369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of exposure to a stilbenoid. Stilbenoids are secondary products of heartwood formation in trees that can act as phytoalexins. Stilbenoids are hydroxylated derivatives of stilbene. They belong to the family of phenylpropanoids and share most of their biosynthesis pathway with chalcones. [GOC:yaf, Wikipedia:Stilbenoid]
Full description |

Standard name | GO_ENTRY_OF_BACTERIUM_INTO_HOST_CELL
Systematic name | M23370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a bacterium enters a host cell. The host is defined as the larger of the organisms involved in a symbiotic interaction. [GOC:bf, PMID:21187937]
Full description |

Standard name | GO_MULTICELLULAR_ORGANISMAL_SIGNALING
Systematic name | M14752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of information occurring at the level of a multicellular organism. [GOC:go_curators]
Full description |

Standard name | GO_EXPLORATION_BEHAVIOR
Systematic name | M15041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific behavior of an organism in response to a novel environment or stimulus. [GOC:BHF, GOC:pr, PMID:11682103, PMID:9767169]
Full description |

Standard name | GO_LOCOMOTORY_EXPLORATION_BEHAVIOR
Systematic name | M16658
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific movement from place to place of an organism in response to a novel environment. [GOC:sart, PMID:17151232]
Full description |

Standard name | GO_INTERLEUKIN_18_MEDIATED_SIGNALING_PATHWAY
Systematic name | M23371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of interleukin-18 to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, GOC:BHF, GOC:signaling]
Full description |

Standard name | GO_OLIGOPEPTIDE_TRANSMEMBRANE_TRANSPORT
Systematic name | M34150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an oligopeptide is transported across a membrane. Oligopeptides are molecules that contain a small number (2 to 20) of amino-acid residues connected by peptide linkages. [GOC:vw, ISBN:0198506732]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_DRUG
Systematic name | M16502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a drug stimulus. A drug is a substance used in the diagnosis, treatment or prevention of a disease. [GOC:sl]
Full description |

Standard name | GO_MITOCHONDRIAL_PROTEIN_CATABOLIC_PROCESS
Systematic name | M23372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a mitochondrial protein. This process is necessary to maintain the healthy state of mitochondria and is thought to occur via the induction of an intramitochondrial lysosome-like organelle that acts to eliminate the damaged oxidised mitochondrial proteins without destroying the mitochondrial structure. [GOC:sp, PMID:21264221, PMID:21264228]
Full description |

Standard name | GO_MONOCYTE_EXTRAVASATION
Systematic name | M23373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The migration of a monocyte from the blood vessels into the surrounding tissue. [CL:0000576, GOC:BHF, PMID:10657654]
Full description |

Standard name | GO_HEMATOPOIETIC_STEM_CELL_MIGRATION
Systematic name | M23374
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a hematopoietic stem cell from one site to another. A hematopoietic stem cell is a cell from which all cells of the lymphoid and myeloid lineages develop, including blood cells and cells of the immune system. [CL:0000037, GOC:BHF, PMID:20234092]
Full description |

Standard name | GO_CD4_POSITIVE_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M12491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a CD4-positive, alpha-beta T cell resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific. [CL:0000624, GOC:BHF]
Full description |

Standard name | GO_INTRACILIARY_RETROGRADE_TRANSPORT
Systematic name | M23375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of large protein complexes along microtubules from the tip of a cilium (also called flagellum) toward the cell body, mediated by motor proteins. [GOC:BHF, GOC:cilia]
Full description |

Standard name | GO_SODIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M10768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a sodium ion is transported from one side of a membrane to the other by means of some agent such as a transporter or pore. [GOC:vw]
Full description |

Standard name | GO_COMMON_MYELOID_PROGENITOR_CELL_PROLIFERATION
Systematic name | M23376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of common myeloid progenitor cells, resulting in the expansion of a cell population. A common myeloid progenitor cell is a progenitor cell committed to the myeloid lineage. [CL:0000049, GOC:BHF]
Full description |

Standard name | GO_RESPONSE_TO_HEPATOCYTE_GROWTH_FACTOR
Systematic name | M13705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hepatocyte growth factor stimulus. [GOC:bf]
Full description |

Standard name | GO_HEPATIC_STELLATE_CELL_ACTIVATION
Systematic name | M23377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in the morphology or behavior of a hepatic stellate cell resulting from exposure to a cytokine, chemokine, hormone, cellular ligand or soluble factor. [CL:0000632, GOC:bf]
Full description |

Standard name | GO_INTRACILIARY_TRANSPORT_INVOLVED_IN_CILIUM_ASSEMBLY
Systematic name | M23378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The bidirectional movement of large protein complexes along microtubules within a cilium that contributes to cilium assembly. [GOC:bf, GOC:cilia, Reactome:R-HSA-5620924.2]
Full description |

Standard name | GO_CD4_POSITIVE_ALPHA_BETA_T_CELL_PROLIFERATION
Systematic name | M23379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a CD4-positive, alpha-beta T cell population by cell division. [CL:0000624, GOC:BHF]
Full description |

Standard name | GO_CD8_POSITIVE_ALPHA_BETA_T_CELL_PROLIFERATION
Systematic name | M23380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a CD8-positive, alpha-beta T cell population by cell division. [CL:0000625, GOC:BHF]
Full description |

Standard name | GO_CD4_POSITIVE_ALPHA_BETA_T_CELL_CYTOKINE_PRODUCTION
Systematic name | M23381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that contributes to cytokine production by a CD4-positive, alpha-beta T cell. [CL:0000624, GOC:BHF]
Full description |

Standard name | GO_T_HELPER_1_CELL_CYTOKINE_PRODUCTION
Systematic name | M23382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that contributes to cytokine production by a T-helper 1 cell. [CL:0000545, GOC:BHF]
Full description |

Standard name | GO_T_HELPER_2_CELL_CYTOKINE_PRODUCTION
Systematic name | M23383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that contributes to cytokine production by a T-helper 2 cell. [CL:0000546, GOC:BHF]
Full description |

Standard name | GO_NATURAL_KILLER_CELL_CHEMOTAXIS
Systematic name | M23384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a natural killer cell guided by a specific chemical concentration gradient. Movement may be towards a higher concentration (positive chemotaxis) or towards a lower concentration (negative chemotaxis). [CL:0000623, GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_LYSOSOMAL_LUMEN_PH
Systematic name | M23385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the pH of the lysosomal lumen, measured by the concentration of the hydrogen ion. [GOC:rph]
Full description |

Standard name | GO_B_CELL_CHEMOTAXIS
Systematic name | M23386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a B cell guided by a specific chemical concentration gradient. Movement may be towards a higher concentration (positive chemotaxis) or towards a lower concentration (negative chemotaxis). [CL:0000236, GOC:BHF]
Full description |

Standard name | GO_ENDOTHELIAL_CELL_CHEMOTAXIS
Systematic name | M23387
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of an endothelial cell guided by a specific chemical concentration gradient. Movement may be towards a higher concentration (positive chemotaxis) or towards a lower concentration (negative chemotaxis). [CL:0000115, GOC:BHF]
Full description |

Standard name | GO_INTERLEUKIN_4_MEDIATED_SIGNALING_PATHWAY
Systematic name | M23388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of interleukin-4 to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:BHF, GOC:signaling]
Full description |

Standard name | GO_INSULIN_SECRETION_INVOLVED_IN_CELLULAR_RESPONSE_TO_GLUCOSE_STIMULUS
Systematic name | M23389
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of proinsulin from secretory granules (B granules) in the B cells of the pancreas; accompanied by cleavage of proinsulin to form mature insulin, in response to a glucose stimulus. [GOC:bf, GOC:yaf, PMID:8492079]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INSULIN_SECRETION_INVOLVED_IN_CELLULAR_RESPONSE_TO_GLUCOSE_STIMULUS
Systematic name | M16330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the regulated release of insulin that contributes to the response of a cell to glucose. [GOC:bf, GOC:yaf]
Full description |

Standard name | GO_CELL_MIGRATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M23390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a cell from one site to another that will contribute to the progression of the kidney over time, from its formation to the mature organ. [GOC:bf, GOC:mtg_kidney_jan10, GOC:yaf]
Full description |

Standard name | GO_PLATELET_DERIVED_GROWTH_FACTOR_RECEPTOR_ALPHA_SIGNALING_PATHWAY
Systematic name | M23391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a ligand to an alpha-type platelet-derived growth factor receptor (PDGFalpha) on the surface of a signal-receiving cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, GOC:yaf, PMID:10372961]
Full description |

Standard name | GO_PLATELET_DERIVED_GROWTH_FACTOR_RECEPTOR_BETA_SIGNALING_PATHWAY
Systematic name | M23392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a ligand to a beta-type platelet-derived growth factor receptor (PDGFbeta) on the surface of a signal-receiving cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, GOC:signaling, GOC:yaf, PMID:10372961]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MITOCHONDRIAL_MEMBRANE_PERMEABILITY
Systematic name | M23393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the passage or uptake of molecules by the mitochondrial membrane. [PMID:10781072]
Full description |

Standard name | GO_REGULATION_OF_URINE_VOLUME
Systematic name | M13416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the amount of urine excreted from the body over a unit of time. [GOC:mtg_25march11, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_URINE_VOLUME
Systematic name | M13749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the amount of urine excreted from the body over a unit of time. [GOC:mtg_25march11, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_URINE_VOLUME
Systematic name | M29160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the amount of urine excreted from the body over a unit of time. [GOC:mtg_25march11, GOC:yaf]
Full description |

Standard name | GO_RENAL_SODIUM_EXCRETION
Systematic name | M23394
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The elimination by an organism of sodium in the urine. [GOC:mtg_25march11, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RENAL_SODIUM_EXCRETION
Systematic name | M14384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the amount of sodium excreted in urine over a unit of time. [GOC:mtg_25march11, GOC:yaf]
Full description |

Standard name | GO_MODULATION_OF_PROCESS_OF_OTHER_ORGANISM
Systematic name | M11347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an organism effects a change in the structure or processes of another organism. [GOC:bf]
Full description |

Standard name | GO_HOMOLOGOUS_RECOMBINATION
Systematic name | M23395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A DNA recombination process that results in the equal exchange of genetic material between the recombining DNA molecules. [GOC:mah, PMID:11139492, PMID:17304215]
Full description |

Standard name | GO_PHOTORECEPTOR_CELL_OUTER_SEGMENT_ORGANIZATION
Systematic name | M23396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level and results in the assembly, arrangement of constituent parts, or disassembly of the outer segment of a photoreceptor cell, a sensory cell that reacts to the presence of light. The outer segment of the photoreceptor cell contains the light-absorbing materials. [ISBN:0824072820, PMID:14507858]
Full description |

Standard name | GO_EPITHELIAL_CELL_DIFFERENTIATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M15205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features of an epithelial cell that characterize the cells of the kidney as it progresses from its formation to the mature state. [GOC:bf, GOC:mtg_kidney_jan10, GOC:yaf, PMID:16216236]
Full description |

Standard name | GO_MEGAKARYOCYTE_DEVELOPMENT
Systematic name | M13503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a megakaryocyte cell over time, from its formation to the mature structure. Megakaryocyte development does not include the steps involved in committing a cell to a megakaryocyte fate. A megakaryocyte is a giant cell 50 to 100 micron in diameter, with a greatly lobulated nucleus, found in the bone marrow. [CL:0000556, GOC:BHF, GOC:vk]
Full description |

Standard name | GO_GLIAL_CELL_DERIVED_NEUROTROPHIC_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a glial cell-derived neurotrophic factor receptor binding to one of its physiological ligands. [GOC:yaf, PMID:12953054]
Full description |

Standard name | GO_RESPONSE_TO_POTASSIUM_ION
Systematic name | M11214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a potassium ion stimulus. [GOC:yaf]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_POTASSIUM_ION
Systematic name | M23398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a potassium ion stimulus. [GOC:yaf]
Full description |

Standard name | GO_PROTEIN_K11_LINKED_DEUBIQUITINATION
Systematic name | M23399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein deubiquitination process in which a K11-linked ubiquitin chain, i.e. a polymer of ubiquitin formed by linkages between lysine residues at position 11 of the ubiquitin monomers, is removed from a protein. [GOC:sp, PMID:21596315]
Full description |

Standard name | GO_NUCLEOTIDE_BINDING_DOMAIN_LEUCINE_RICH_REPEAT_CONTAINING_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M10860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals generated as a consequence of a nucleotide-binding domain, leucine rich repeat containing receptor (NLR) binding to one of its physiological ligands. NLRs are cytoplasmic receptors defined by their tripartite domain architecture that contains: a variable C-terminus, a middle nucleotide-binding domain, and a LRR domain that is variable in the repeats composition and number. The NLR signaling pathway begins with binding of a ligand to a NLR receptor and ends with regulation of a downstream cellular process. [GOC:sj, PMID:18280719, Reactome:168643]
Full description |

Standard name | GO_LACTATE_TRANSMEMBRANE_TRANSPORT
Systematic name | M34151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which lactate is transported across a membrane. Lactate is 2-hydroxypropanoate, CH3-CHOH-COOH; L(+)-lactate is formed by anaerobic glycolysis in animal tissues, and DL-lactate is found in sour milk, molasses and certain fruit juices. [GOC:mcc, ISBN:0198506732]
Full description |

Standard name | GO_NAIL_DEVELOPMENT
Systematic name | M23400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a nail over time, from its formation to the mature structure. A nail is a horn-like envelope covering the outer end of a finger or toe, and consists of the nail plate, the nail matrix and the nail bed below it, and the grooves surrounding it. [GOC:bf, ISBN:0323025781, UBERON:0001705, Wikipedia:Nail_(anatomy)]
Full description |

Standard name | GO_AMACRINE_CELL_DIFFERENTIATION
Systematic name | M23401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of an amacrine cell, an interneuron generated in the inner nuclear layer (INL) of the vertebrate retina. Amacrine cells integrate, modulate, and interpose a temporal domain in the visual message presented to the retinal ganglion cells, with which they synapse in the inner plexiform layer. Amacrine cells lack large axons. [CL:0000561, GOC:bf]
Full description |

Standard name | GO_ENTEROENDOCRINE_CELL_DIFFERENTIATION
Systematic name | M14305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized structural and/or functional features of an enteroendocrine cell. Enteroendocrine cells are hormonally active epithelial cells in the gut that constitute the diffuse neuroendocrine system. [CL:0000164, GOC:bf]
Full description |

Standard name | GO_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M11408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a vascular smooth muscle cell. [GOC:sl, PMID:16151017, PMID:18267954]
Full description |

Standard name | GO_RESPONSE_TO_ISOLATION_STRESS
Systematic name | M23402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lack of contact with other members of the same species. [GOC:bf, PMID:20203532]
Full description |

Standard name | GO_RESPONSE_TO_IMMOBILIZATION_STRESS
Systematic name | M10626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of being rendered immobile. [GOC:bf, PMID:17683801, PMID:19893991]
Full description |

Standard name | GO_AORTA_DEVELOPMENT
Systematic name | M12034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the aorta over time, from its initial formation to the mature structure. An aorta is an artery that carries blood from the heart to other parts of the body. [GOC:bf, GOC:dgh, MA:0000062, UBERON:0000947, Wikipedia:Aorta]
Full description |

Standard name | GO_ASCENDING_AORTA_DEVELOPMENT
Systematic name | M23403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the ascending aorta over time, from its initial formation to the mature structure. The ascending aorta is the portion of the aorta in a two-pass circulatory system that lies between the heart and the arch of aorta. In a two-pass circulatory system blood passes twice through the heart to supply the body once. [GOC:bf, GOC:dgh, MA:0002570, UBERON:0001496, Wikipedia:Ascending_aorta]
Full description |

Standard name | GO_DORSAL_AORTA_DEVELOPMENT
Systematic name | M23404
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the dorsal aorta over time, from its initial formation to the mature structure. The dorsal aorta is a blood vessel in a single-pass circulatory system that carries oxygenated blood from the gills to the rest of the body. In a single-pass circulatory system blood passes once through the heart to supply the body once. [GOC:bf, GOC:dgh, UBERON:0005805, Wikipedia:Aorta, ZFA:0000014]
Full description |

Standard name | GO_AORTA_MORPHOGENESIS
Systematic name | M16151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of an aorta are generated and organized. An aorta is an artery that carries blood from the heart to other parts of the body. [GOC:bf, GOC:dgh, MA:0000062, UBERON:0000947, Wikipedia:Aorta]
Full description |

Standard name | GO_DORSAL_AORTA_MORPHOGENESIS
Systematic name | M34152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the dorsal aorta are generated and organized. The dorsal aorta is a blood vessel in a single-pass circulatory system that carries oxygenated blood from the gills to the rest of the body. In a single-pass circulatory system blood passes once through the heart to supply the body once. [GOC:bf, GOC:dgh, UBERON:0005805, Wikipedia:Aorta, ZFA:0000014]
Full description |

Standard name | GO_SKELETAL_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M15486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a skeletal muscle cell, a somatic cell located in skeletal muscle. [CL:0000188, GOC:BHF, GOC:vk]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_STIMULUS
Systematic name | M16443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vascular endothelial growth factor stimulus. [GOC:BHF, GOC:rl, PMID:18440775]
Full description |

Standard name | GO_RNA_IMPORT_INTO_MITOCHONDRION
Systematic name | M23406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a rRNA, ribosomal ribonucleic acid, is transported from the cytosol, into the mitochondrial matrix. [GOC:ans, PMID:20691904]
Full description |

Standard name | GO_STEROID_HORMONE_SECRETION
Systematic name | M23407
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of any steroid that acts as a hormone into the circulatory system. [GOC:sl]
Full description |

Standard name | GO_CORTICOSTEROID_HORMONE_SECRETION
Systematic name | M23408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of any corticosteroid hormone into the circulatory system. [GOC:sl]
Full description |

Standard name | GO_MINERALOCORTICOID_SECRETION
Systematic name | M29161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of any mineralocorticoid into the circulatory system. Mineralocorticoids are a class of steroid hormones that regulate water and electrolyte metabolism. [GOC:sl]
Full description |

Standard name | GO_GLUCOCORTICOID_SECRETION
Systematic name | M23410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of any glucocorticoid hormone into the circulatory system. Glucocorticoids are a class of steroid hormones that regulate a variety of physiological processes, in particular control of the concentration of glucose in blood. [GOC:sl]
Full description |

Standard name | GO_CORTICOSTERONE_SECRETION
Systematic name | M23411
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of corticosterone into the circulatory system. Corticosterone is a 21-carbon steroid hormone of the corticosteroid type produced in the cortex of the adrenal glands. [GOC:sl]
Full description |

Standard name | GO_COPI_COATED_VESICLE_BUDDING
Systematic name | M23415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The evagination of a Golgi membrane, resulting in formation of a COPI-coated vesicle. [GOC:br, PMID:10052452, PMID:17041781]
Full description |

Standard name | GO_CARDIOLIPIN_ACYL_CHAIN_REMODELING
Systematic name | M23416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Remodeling the acyl chains of premature (de novo synthesized) cardiolipin (1,3-bis(3-phosphatidyl)glycerol), through sequential deacylation and re-acylation reactions, to generate mature cardiolipin containing high-levels of unsaturated fatty acids. [GOC:bf, GOC:rb, PMID:19244244]
Full description |

Standard name | GO_RESPONSE_TO_TOPOLOGICALLY_INCORRECT_PROTEIN
Systematic name | M16675
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a protein that is not folded in its correct three-dimensional structure. [GOC:bf]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_TOPOLOGICALLY_INCORRECT_PROTEIN
Systematic name | M11845
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a protein that is not folded in its correct three-dimensional structure. [GOC:bf]
Full description |

Standard name | GO_PEPTIDYL_THREONINE_DEPHOSPHORYLATION
Systematic name | M23417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of phosphoric residues from peptidyl-O-phospho-L-threonine to form peptidyl-threonine. [GOC:bf]
Full description |

Standard name | GO_AGGREPHAGY
Systematic name | M23418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Selective degradation of protein aggregates by macroautophagy. [GOC:autophagy, GOC:kmv, PMID:18508269, PMID:25062811]
Full description |

Standard name | GO_ENDODERMAL_CELL_DIFFERENTIATION
Systematic name | M34153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of an endoderm cell, a cell of the inner of the three germ layers of the embryo. [CL:0000223, GOC:yaf, PMID:17624332]
Full description |

Standard name | GO_CHONDROCYTE_PROLIFERATION
Systematic name | M23420
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of chondrocytes by cell division, resulting in the expansion of their population. A chondrocyte is a polymorphic cell that forms cartilage. [CL:0000138, GOC:yaf, PMID:21484705]
Full description |

Standard name | GO_TENDON_DEVELOPMENT
Systematic name | M23421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a tendon over time, from its formation to the mature structure. A tendon is a fibrous, strong, connective tissue that connects muscle to bone or integument and is capable of withstanding tension. Tendons and muscles work together to exert a pulling force. [GOC:yaf, PMID:21412429, UBERON:0000043]
Full description |

Standard name | GO_RESPONSE_TO_MUSCLE_STRETCH
Systematic name | M10522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a myofibril being extended beyond its slack length. [GOC:BHF, GOC:vk, PMID:14583192]
Full description |

Standard name | GO_TETRAHYDROFOLATE_INTERCONVERSION
Systematic name | M14912
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways by which one-carbon (C1) units are transferred between tetrahydrofolate molecules, to synthesise other tetrahydrofolate molecules. [GOC:yaf, PMID:1825999, UniPathway:UPA00193]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_FROM_RNA_POLYMERASE_II_PROMOTER_IN_RESPONSE_TO_STRESS
Systematic name | M13207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of transcription from an RNA polymerase II promoter as a result of a stimulus indicating the organism is under stress. The stress is usually, but not necessarily, exogenous (e.g. temperature, humidity, ionizing radiation). [GOC:mcc]
Full description |

Standard name | GO_RESPONSE_TO_MACROPHAGE_COLONY_STIMULATING_FACTOR
Systematic name | M23422
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a macrophage colony-stimulating factor stimulus. [GOC:yaf, PMID:14687666]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_ENDOSOME
Systematic name | M23423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within an endosome. [GOC:yaf]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_3
Systematic name | M23424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-3 stimulus. [GOC:yaf]
Full description |

Standard name | GO_RESPONSE_TO_ERYTHROPOIETIN
Systematic name | M23425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an erythropoietin stimulus. Erythropoietin is a glycoprotein hormone that controls erythropoiesis. [GOC:yaf]
Full description |

Standard name | GO_OSTEOCLAST_DEVELOPMENT
Systematic name | M23426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a osteoclast from its formation to the mature structure. Cell development does not include the steps involved in committing a cell to a specific fate. An osteoclast is a specialized phagocytic cell associated with the absorption and removal of the mineralized matrix of bone tissue. [CL:0000092, GOC:bf, GOC:yaf]
Full description |

Standard name | GO_CD8_POSITIVE_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M23427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a CD8-positive, alpha-beta T cell resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific. [CL:0000625, GOC:yaf]
Full description |

Standard name | GO_FUCOSYLATION
Systematic name | M14757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment of a fucosyl group to an acceptor molecule. [GOC:sart, PMID:19948734]
Full description |

Standard name | GO_PROTEIN_O_LINKED_FUCOSYLATION
Systematic name | M12872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of transferring a fucosyl group to a serine or threonine residues in a protein acceptor molecule, to form an O-linked protein-sugar linkage. [GOC:sart, PMID:19948734]
Full description |

Standard name | GO_DIRECT_OSSIFICATION
Systematic name | M23428
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of bone or of a bony substance, or the conversion of fibrous tissue or of cartilage into bone or a bony substance, that does not require the replacement of preexisting tissues. [GO_REF:0000034]
Full description |

Standard name | GO_REPLACEMENT_OSSIFICATION
Systematic name | M11955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Ossification that requires the replacement of a preexisting tissue prior to bone tissue formation. [GO_REF:0000034]
Full description |

Standard name | GO_CLEAVAGE_FURROW_FORMATION
Systematic name | M23429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Generation of the cleavage furrow, a shallow groove in the cell surface near the old metaphase plate that marks the site of cytokinesis. This process includes the recruitment and localized activation of signals such as RhoA at the site of the future furrow to ensure that furrowing initiates at the correct site in the cell. [GOC:ans, PMID:15811947, PMID:20687468, PMID:2192590]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_FROM_RNA_POLYMERASE_II_PROMOTER_IN_RESPONSE_TO_OXIDATIVE_STRESS
Systematic name | M23430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of transcription from an RNA polymerase II promoter as a result of a stimulus indicating the organism is under oxidative stress, a state often resulting from exposure to high levels of reactive oxygen species, e.g. superoxide anions, hydrogen peroxide (H2O2), and hydroxyl radicals. [GOC:rn, PMID:14978214, PMID:18439143]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_PHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M11710
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of phosphatidylinositol-3-phosphate, a phosphatidylinositol monophosphate carrying the phosphate group at the 3-position. [GOC:al, GOC:vw]
Full description |

Standard name | GO_GERM_CELL_PROLIFERATION
Systematic name | M23431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of germ cells, reproductive cells in multicellular organisms, resulting in the expansion of a cell population. [CL:0000586, GOC:kmv]
Full description |

Standard name | GO_LEUKOTRIENE_B4_METABOLIC_PROCESS
Systematic name | M34154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving leukotriene B4, a leukotriene composed of (6Z,8E,10E,14Z)-eicosatetraenoic acid having (5S)- and (12R)-hydroxy substituents. [GOC:bf]
Full description |

Standard name | GO_ALPHA_LINOLENIC_ACID_METABOLIC_PROCESS
Systematic name | M13605
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving alpha-linolenic acid, an unsaturated omega-6 fatty acid that has the molecular formula C18H32O2. [PMID:15538555]
Full description |

Standard name | GO_RESPONSE_TO_PLATELET_DERIVED_GROWTH_FACTOR
Systematic name | M13193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a platelet-derived growth factor stimulus. [GOC:yaf]
Full description |

Standard name | GO_HISTONE_H3_K9_DIMETHYLATION
Systematic name | M23432
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of two methyl groups to lysine at position 9 of the histone. [GOC:vw]
Full description |

Standard name | GO_HISTONE_H3_K9_TRIMETHYLATION
Systematic name | M23433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of three methyl groups to lysine at position 9 of the histone. [GOC:vw]
Full description |

Standard name | GO_SCHWANN_CELL_MIGRATION
Systematic name | M23434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a Schwann cell from one site to another. A Schwann cell is a glial cell that ensheathes axons of neuron in the peripheral nervous system and is necessary for their maintainance and function. [CL:0002573, PMID:20335460]
Full description |

Standard name | GO_PHOSPHATIDYLGLYCEROL_ACYL_CHAIN_REMODELING
Systematic name | M15445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Remodeling the acyl chains of phosphatidylglycerol, through sequential deacylation and re-acylation reactions, to generate phosphatidylglycerol containing different types of fatty acid acyl chains. [GOC:mw, PMID:15485873, PMID:18458083]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_ACYL_CHAIN_REMODELING
Systematic name | M16512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Remodeling the acyl chains of phosphatidylinositol, through sequential deacylation and re-acylation reactions, to generate phosphatidylinositol containing different types of fatty acid acyl chains. [GOC:mw, PMID:18094042, PMID:18772128]
Full description |

Standard name | GO_PHOSPHATIDYLSERINE_ACYL_CHAIN_REMODELING
Systematic name | M10047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Remodeling the acyl chains of phosphatidylserine, through sequential deacylation and re-acylation reactions, to generate phosphatidylserine containing different types of fatty acid acyl chains. [GOC:mw, PMID:18287005, PMID:18458083]
Full description |

Standard name | GO_PHOSPHATIDYLCHOLINE_ACYL_CHAIN_REMODELING
Systematic name | M16020
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Remodeling the acyl chains of phosphatidylcholine, through sequential deacylation and re-acylation reactions, to generate phosphatidylcholine containing different types of fatty acid acyl chains. [GOC:mw, PMID:18195019, PMID:18458083]
Full description |

Standard name | GO_PHOSPHATIDYLETHANOLAMINE_ACYL_CHAIN_REMODELING
Systematic name | M15963
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Remodeling the acyl chains of phosphatidylethanolamine, through sequential deacylation and re-acylation reactions, to generate phosphatidylethanolamine containing different types of fatty acid acyl chains. [GOC:mw, PMID:18287005, PMID:18458083]
Full description |

Standard name | GO_ACYLGLYCEROL_ACYL_CHAIN_REMODELING
Systematic name | M23435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Remodeling the acyl chains of an acylglycerol, through sequential deacylation and re-acylation reactions, to generate an acylglycerol containing different types of fatty acid acyl chains. [GOC:mw, PMID:15364929]
Full description |

Standard name | GO_OUTER_DYNEIN_ARM_ASSEMBLY
Systematic name | M13644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an axonemal dynein outer arm, an outer arm structure present on the outer doublet microtubules of ciliary and flagellar axonemes. [GOC:BHF, GOC:vk, PMID:19944400]
Full description |

Standard name | GO_INNER_DYNEIN_ARM_ASSEMBLY
Systematic name | M12111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an axonemal dynein inner arm, an inner arm structure present on the outer doublet microtubules of ciliary and flagellar axonemes. [GOC:BHF, GOC:vk, PMID:19944400]
Full description |

Standard name | GO_PHENOTYPIC_SWITCHING
Systematic name | M23436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A reversible switch of a cell from one cell type or form to another, at a frequency above the expected frequency for somatic mutations. Phenotypic switching involves changes in cell morphology and altered gene expression patterns. For example, Candida albicans switches from white cells to opaque cells for sexual mating. Phenotypic switching also occurs in multicellular organisms; smooth muscle cells (SMCs) exhibit phenotypic transitions to allow rapid adaption to fluctuating environmental cues. [GOC:bf, GOC:di, PMID:12443899, PMID:22406749, PMID:8456504, Wikipedia:Phenotypic_switching]
Full description |

Standard name | GO_MULTIVESICULAR_BODY_ORGANIZATION
Systematic name | M13034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a multivesicular body. A multivesicular body is a type of late endosome in which regions of the limiting endosomal membrane invaginate to form internal vesicles; membrane proteins that enter the internal vesicles are sequestered from the cytoplasm. [GOC:sart, PMID:11566881]
Full description |

Standard name | GO_RNA_CAPPING
Systematic name | M13443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The sequence of enzymatic reactions by which a cap structure is added to the 5' end of nascent RNA polymerase transcripts. Examples of RNA capping include 7-methyl-G caps found on all RNA polymerase II transcripts and nucleotide-containing cofactor caps, such as NAD(H) or FAD, found on bacterial trancripts. [GOC:bf, GOC:krc, GOC:mah, PMID:18775984, PMID:27383794, PMID:29681497, PMID:30353673]
Full description |

Standard name | GO_RNA_GUANINE_N7_METHYLATION
Systematic name | M23437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a methyl group to the N7 atom in the base portion of a guanine nucleotide residue in an RNA molecule. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_PEPTIDYL_SERINE_AUTOPHOSPHORYLATION
Systematic name | M23438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The phosphorylation by a protein of one or more of its own serine amino acid residues, or a serine residue on an identical protein. [GOC:pm]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_INCREASED_OXYGEN_LEVELS
Systematic name | M23439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting an increase in the level of oxygen. [GOC:al]
Full description |

Standard name | GO_RESPONSE_TO_INCREASED_OXYGEN_LEVELS
Systematic name | M12574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting an increase in the level of oxygen. [GOC:al]
Full description |

Standard name | GO_INTERSTRAND_CROSS_LINK_REPAIR
Systematic name | M13951
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Removal of a DNA interstrand crosslink (a covalent attachment of DNA bases on opposite strands of the DNA) and restoration of the DNA. DNA interstrand crosslinks occur when both strands of duplex DNA are covalently tethered together (e.g. by an exogenous or endogenous agent), thus preventing the strand unwinding necessary for essential DNA functions such as transcription and replication. [GOC:vw, PMID:16464006, PMID:22064477]
Full description |

Standard name | GO_MACROPHAGE_COLONY_STIMULATING_FACTOR_PRODUCTION
Systematic name | M23440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of macrophage colony-stimulating factor due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:BHF, GOC:vk]
Full description |

Standard name | GO_ATRIOVENTRICULAR_CANAL_DEVELOPMENT
Systematic name | M23441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the atrioventricular canal over time, from its formation to the mature structure. The atrioventricular canal is the part of the heart connecting the atrium to the cardiac ventricle. [GOC:BHF, GOC:gr, PMID:14701881, UBERON:0002087, ZFA:0001315]
Full description |

Standard name | GO_LYMPH_VESSEL_MORPHOGENESIS
Systematic name | M14470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of lymph vessels are generated and organized. The lymph vessel is the vasculature carrying lymph. [GOC:BHF, GOC:gr, PMID:18093989]
Full description |

Standard name | GO_RESPONSE_TO_STEROL
Systematic name | M12960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a sterol stimulus. [GOC:bf]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_STEROL
Systematic name | M14197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a sterol stimulus. [GOC:bf]
Full description |

Standard name | GO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_RECEPTOR_2_SIGNALING_PATHWAY
Systematic name | M34155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals initiated by the binding of an extracellular ligand to a vascular endothelial growth factor receptor-2 (VEGFR-2) located on the surface of the receiving cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, GOC:uh, PMID:12967471, Wikipedia:Kinase_insert_domain_receptor, Wikipedia:VEGF_receptors]
Full description |

Standard name | GO_DENDRITIC_CELL_MIGRATION
Systematic name | M10441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a dendritic cell within or between different tissues and organs of the body. [CL:0000451, GOC:nhn, PMID:19339990]
Full description |

Standard name | GO_FAS_SIGNALING_PATHWAY
Systematic name | M34156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a ligand to the receptor Fas on the surface of the cell, and ending with regulation of a downstream cellular process, e.g. transcription. Fas is a death domain-containing member of the tumor necrosis factor receptor (TNFR) superfamily. [GOC:nhn, PMID:12040174, Wikipedia:Fas_receptor]
Full description |

Standard name | GO_POST_ANAL_TAIL_MORPHOGENESIS
Systematic name | M15830
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a post-anal tail is generated and organized. A post-anal tail is a muscular region of the body that extends posterior to the anus. The post-anal tail may aid locomotion and balance. [GOC:bf, GOC:kmv, Wikipedia:Chordate]
Full description |

Standard name | GO_PLATELET_MORPHOGENESIS
Systematic name | M12943
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Generation and organization of a platelet, a non-nucleated disk-shaped cell formed by extrusion from megakaryocytes, found in the blood of all mammals, and mainly involved in blood coagulation. [CL:0000233, GOC:BHF, GOC:vk]
Full description |

Standard name | GO_HISTONE_H2A_K119_MONOUBIQUITINATION
Systematic name | M23442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H2A by addition of a single ubiquitin group to lysine-119 (H2A- K119) in metazoans, and at the equivalent residue in other organisms. [GOC:sp, PMID:15386022]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA_ACTIVATION
Systematic name | M23443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The release of transforming growth factor beta (TGF-beta) from its latent state. TGF-beta is secreted as part of a large latent complex (LLC) that is targeted to the extracellular matrix. Release of TGFbeta from its latent state is required for TGFbeta to bind to its receptors, and can occur by a variety of mechanisms. [GOC:bf, GOC:sl, PMID:12482908, PMID:9170210]
Full description |

Standard name | GO_TRANSCRIPTION_FACTOR_CATABOLIC_PROCESS
Systematic name | M34157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a sequence-specific DNA-binding transcription factor by hydrolysis of its peptide bonds, initiated by the covalent attachment of ubiquitin, and mediated by the proteasome. [GOC:al, GOC:vw, PMID:22833559]
Full description |

Standard name | GO_SODIUM_ION_EXPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M23444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of sodium ions from inside of a cell, across the plasma membrane and into the extracellular region. [GOC:vw, PMID:14674689]
Full description |

Standard name | GO_HISTONE_CITRULLINATION
Systematic name | M23445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The hydrolysis of peptidyl-arginine to form peptidyl-citrulline on a histone protein. [GOC:als, PMID:22853951, PMID:23175390]
Full description |

Standard name | GO_CALCIUM_IMPORT_INTO_THE_MITOCHONDRION
Systematic name | M23446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a calcium ion (Ca2+) is transported from the cytosol, into the mitochondrial matrix. [GOC:vw]
Full description |

Standard name | GO_MYOFIBROBLAST_DIFFERENTIATION
Systematic name | M23447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an undifferentiated cell acquires the features of a myofibroblast cell. [CL:0000186, GOC:nhn]
Full description |

Standard name | GO_TRAIL_ACTIVATED_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M23448
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An extrinsic apoptotic signaling pathway initiated by the binding of the ligand TRAIL (tumor necrosis factor-related apoptosis-inducing ligand) to a death receptor on the cell surface. [GOC:bf, GOC:PARL, PMID:21785459]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_RECYCLING
Systematic name | M11777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The trafficking of synaptic vesicles from the pre-synaptic membrane so the vesicle can dock and prime for another round of exocytosis and neurotransmitter release. Recycling occurs after synaptic vesicle exocytosis, and is necessary to replenish presynaptic vesicle pools, sustain transmitter release and preserve the structural integrity of the presynaptic membrane. Recycling can occur following transient fusion with the presynaptic membrane (kiss and run), or via endocytosis of presynaptic membrane. [GOC:bf, GOC:pad, GOC:PARL, PMID:15217342, PMID:22026965, PMID:23245563]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_RECYCLING_VIA_ENDOSOME
Systematic name | M29162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Synaptic vesicle recycling where vesicles endocytosed via clathrin-coated pits re-acidify and refill with neurotransmitters after passing through an endosomal intermediate. [GOC:aruk, GOC:bc, GOC:bf, GOC:dos, GOC:pad, GOC:PARL, PMID:15217342]
Full description |

Standard name | GO_CELL_DEATH_IN_RESPONSE_TO_OXIDATIVE_STRESS
Systematic name | M12737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process that results in permanent cessation of all vital functions of a cell upon exposure to an oxidative stress stimulus. [GOC:bf, GOC:PARL]
Full description |

Standard name | GO_CELL_DEATH_IN_RESPONSE_TO_HYDROGEN_PEROXIDE
Systematic name | M23450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process that results in permanent cessation of all vital functions of a cell upon exposure to hydrogen peroxide (H2O2). [GOC:bf, GOC:PARL]
Full description |

Standard name | GO_NEURON_DEATH_IN_RESPONSE_TO_OXIDATIVE_STRESS
Systematic name | M23451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process that results in permanent cessation of all vital functions of a neuron upon exposure to an oxidative stress stimulus. [GOC:bf, GOC:PARL]
Full description |

Standard name | GO_NEURON_DEATH_IN_RESPONSE_TO_HYDROGEN_PEROXIDE
Systematic name | M23452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process that results in permanent cessation of all vital functions of a neuron upon exposure to hydrogen peroxide (H2O2). [GOC:bf, GOC:PARL]
Full description |

Standard name | GO_NEURON_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_OXIDATIVE_STRESS
Systematic name | M23453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a neuron. The pathway is induced in response to oxidative stress, a state often resulting from exposure to high levels of reactive oxygen species, and ends when the execution phase of apoptosis is triggered. [GOC:bf, GOC:PARL, PMID:23858059]
Full description |

Standard name | GO_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_HYDROGEN_PEROXIDE
Systematic name | M23454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway is induced in response to hydrogen peroxide (H2O2). [GOC:bf, GOC:PARL]
Full description |

Standard name | GO_REGULATION_OF_TRANSLATION_IN_RESPONSE_TO_ENDOPLASMIC_RETICULUM_STRESS
Systematic name | M23455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Modulation of the frequency, rate or extent of translation as a result of endoplasmic reticulum stress. [GOC:bf, GOC:PARL, PMID:14676213, PMID:16835242]
Full description |

Standard name | GO_REGULATION_OF_TRANSLATION_INITIATION_IN_RESPONSE_TO_ENDOPLASMIC_RETICULUM_STRESS
Systematic name | M34158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of translation initiation, as a result of endoplasmic reticulum stress. [GOC:bf, GOC:PARL, PMID:14676213, PMID:16835242]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSLATION_IN_RESPONSE_TO_ENDOPLASMIC_RETICULUM_STRESS
Systematic name | M34159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, or increases the frequency, rate or extent of translation as a result of endoplasmic reticulum stress. [GOC:bf, GOC:PARL]
Full description |

Standard name | GO_IRE1_MEDIATED_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M10426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by the endoplasmic reticulum stress sensor IRE1 (Inositol-requiring transmembrane kinase/endonuclease). Begins with activation of IRE1 in response to endoplasmic reticulum (ER) stress, and ends with regulation of a downstream cellular process, e.g. transcription. One target of activated IRE1 is the transcription factor HAC1 in yeast, or XBP1 in mammals; IRE1 cleaves an intron of a mRNA coding for HAC1/XBP1 to generate an activated HAC1/XBP1 transcription factor, which controls the up regulation of UPR-related genes. At least in mammals, IRE1 can also signal through additional intracellular pathways including JNK and NF-kappaB. [GOC:bf, GOC:PARL, PMID:22013210]
Full description |

Standard name | GO_PERK_MEDIATED_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M14369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by the endoplasmic reticulum membrane stress sensor PERK (PKR-like ER kinase). Begins with activation of PERK in response to endoplasmic reticulum (ER) stress and ends with regulation of a downstream cellular process, e.g. transcription. The main substrate of PERK is the translation initiation factor eIF2alpha. Serine-phosphorylation of eIF2alpha by PERK inactivates eIF2alpha and inhibits general protein translation. In addition, eIF2alpha phosphorylation preferentially increases the translation of selective mRNAs such as ATF4 (activating transcription factor 4), which up regulates a subset of UPR genes required to restore folding capacity. [GOC:bf, GOC:PARL, PMID:22013210, PMID:27629041]
Full description |

Standard name | GO_ATF6_MEDIATED_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M23457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by the endoplasmic reticulum membrane stress sensor ATF6 (activating transcription factor 6). Begins with activation of ATF6 in response to endoplasmic reticulum (ER) stress, and ends with regulation of a downstream cellular process, e.g. transcription. Under conditions of endoplasmic reticulum stress, ATF6 translocates to the Golgi where it is processed by proteases to release a cytoplasmic domain (ATF6f), which operates as a transcriptional activator of many genes required to restore folding capacity. [GOC:bf, GOC:PARL, PMID:22013210]
Full description |

Standard name | GO_ERAD_PATHWAY
Systematic name | M15534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The protein catabolic pathway which targets endoplasmic reticulum (ER)-resident proteins for degradation by the cytoplasmic proteasome. It begins with recognition of the ER-resident protein, includes retrotranslocation (dislocation) of the protein from the ER to the cytosol, protein modifications necessary for correct substrate transfer (e.g. ubiquitination), transport of the protein to the proteasome, and ends with degradation of the protein by the cytoplasmic proteasome. [GOC:bf, GOC:PARL, PMID:20940304, PMID:21969857]
Full description |

Standard name | GO_PROTEIN_DEMANNOSYLATION
Systematic name | M12900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of one or more mannose residues from a mannosylated protein. [GOC:bf, GOC:PARL, PMID:25092655]
Full description |

Standard name | GO_DOPAMINERGIC_NEURON_AXON_GUIDANCE
Systematic name | M23458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemotaxis process that directs the migration of an axon growth cone of a dopaminergic neuron to a specific target site in response to a combination of attractive and repulsive cues. [GOC:bf, GOC:PARL, PMID:21106844, PMID:23517308]
Full description |

Standard name | GO_PARACRINE_SIGNALING
Systematic name | M23459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of information from one cell to another, where the signal travels from the signal-producing cell to the receiving cell by passive diffusion or bulk flow in intercellular fluid. The signaling cell and the receiving cell are usually in the vicinity of each other. [GOC:mtg_signaling_feb11, ISBN:3527303782]
Full description |

Standard name | GO_OPIOID_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23460
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of an opioid receptor binding to one of its physiological ligands. [GOC:bf, PMID:20494127]
Full description |

Standard name | GO_NETRIN_ACTIVATED_SIGNALING_PATHWAY
Systematic name | M23461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular events initiated by the binding of a netrin protein to a receptor on the surface of the target cell, and ending with regulation of a downstream cellular process, e.g. transcription. Netrins can act as chemoattractant signals for some cells and chemorepellent signals for others. Netrins also have roles outside of cell and axon guidance. [GOC:signaling, PMID:10399919, PMID:15960985, PMID:19785719, PMID:20108323]
Full description |

Standard name | GO_REELIN_MEDIATED_SIGNALING_PATHWAY
Systematic name | M23462
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of reelin (a secreted glycoprotein) to a receptor on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, PMID:12827279, PMID:20223215]
Full description |

Standard name | GO_APOLIPOPROTEIN_A_I_MEDIATED_SIGNALING_PATHWAY
Systematic name | M23463
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of apolipoprotein A-I to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, GOC:signaling, PMID:16443932]
Full description |

Standard name | GO_NON_CANONICAL_WNT_SIGNALING_PATHWAY_VIA_MAPK_CASCADE
Systematic name | M23464
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of a Wnt protein to a frizzled family receptor on the surface of the target cell, where the signal is passed on via the MAPKKK cascade. [GOC:BHF, GOC:signaling, GOC:vk, PMID:17720811]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOTHELIAL_CELL_CHEMOTAXIS_BY_VEGF_ACTIVATED_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a vascular endothelial growth factor (VEGF) to a VEGFR on the surface of a cell, which activates or increases the frequency, rate or extent of endothelial cell chemotaxis. [GOC:bf, GOC:BHF, GOC:rl, PMID:21245381]
Full description |

Standard name | GO_SIGNAL_TRANSDUCTION_IN_ABSENCE_OF_LIGAND
Systematic name | M13441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the absence of a ligand or the withdrawal of a ligand from a receptor. [GOC:al, GOC:ppm, GOC:pr, PMID:15044679]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA_SECRETION
Systematic name | M23466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of transforming growth factor-beta (TGF-beta) from a cell into the extracellular region. TGF-beta is mostly secreted as a large latent TGF-beta complex (LLC) containing latency-associated proteins (LAPs) derived from the N-terminal region of the TGF-beta gene product, dimeric TGF-beta and latent TGF-beta binding proteins (LTBPs). [GOC:bf, GOC:yaf, PMID:2350783, Reactome:R-HSA-177107]
Full description |

Standard name | GO_NIK_NF_KAPPAB_SIGNALING
Systematic name | M13738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a signal is passed on to downstream components within the cell through the NIK-dependent processing and activation of NF-KappaB. Begins with activation of the NF-KappaB-inducing kinase (NIK), which in turn phosphorylates and activates IkappaB kinase alpha (IKKalpha). IKKalpha phosphorylates the NF-Kappa B2 protein (p100) leading to p100 processing and release of an active NF-KappaB (p52). [GOC:bf, GOC:mg2, GOC:signaling, GOC:vs, PMID:11239468, PMID:15140882]
Full description |

Standard name | GO_COLLAGEN_ACTIVATED_TYROSINE_KINASE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of collagen to a receptor on the surface of the target cell where the receptor possesses tyrosine kinase activity. The pathway ends with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, GOC:uh, PMID:15888913, PMID:16626936]
Full description |

Standard name | GO_COLLAGEN_ACTIVATED_SIGNALING_PATHWAY
Systematic name | M23468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by collagen binding to a cell surface receptor, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, GOC:uh, PMID:21568710]
Full description |

Standard name | GO_P38MAPK_CASCADE
Systematic name | M23469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An intracellular protein kinase cascade containing at least a p38 MAPK, a MAPKK and a MAP3K. The cascade can also contain an additional tier: the upstream MAP4K. The kinases in each tier phosphorylate and activate the kinases in the downstream tier to transmit a signal within a cell. [GOC:signaling, PMID:20811974]
Full description |

Standard name | GO_PEPTIDYL_TYROSINE_AUTOPHOSPHORYLATION
Systematic name | M14883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The phosphorylation by a protein of one or more of its own tyrosine amino acid residues, or a tyrosine residue on an identical protein. [PMID:10037737, PMID:10068444, PMID:10940390]
Full description |

Standard name | GO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_SIGNALING_PATHWAY
Systematic name | M10406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a vascular endothelial growth factor (VEGF) to a receptor on the surface of the target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:signaling, PMID:17470632]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_MIGRATION_BY_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_SIGNALING_PATHWAY
Systematic name | M23470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a vascular endothelial growth factor (VEGF) to a receptor on the surface of a cell, which activates or increases the frequency, rate or extent of the orderly movement of a cell from one site to another. [GOC:bf, GOC:signaling]
Full description |

Standard name | GO_NODAL_SIGNALING_PATHWAY
Systematic name | M23471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a nodal protein to an activin receptor on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:BHF, GOC:vk, PMID:17287255]
Full description |

Standard name | GO_FC_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M13258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of the Fc portion of an immunoglobulin to an Fc receptor on the surface of a signal-receiving cell, and ending with regulation of a downstream cellular process, e.g. transcription. The Fc portion of an immunoglobulin is its C-terminal constant region. [GOC:phg, Wikipedia:Fc_receptor]
Full description |

Standard name | GO_FC_EPSILON_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of the Fc portion of immunoglobulin E (IgE) to an Fc-epsilon receptor on the surface of a signal-receiving cell, and ending with regulation of a downstream cellular process, e.g. transcription. The Fc portion of an immunoglobulin is its C-terminal constant region. [GOC:phg, PMID:12413516, PMID:15048725]
Full description |

Standard name | GO_INTERLEUKIN_7_MEDIATED_SIGNALING_PATHWAY
Systematic name | M23472
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of interleukin-7 to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:nhn, GOC:signaling]
Full description |

Standard name | GO_INTERLEUKIN_21_MEDIATED_SIGNALING_PATHWAY
Systematic name | M23473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of interleukin-21 to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:nhn, GOC:signaling]
Full description |

Standard name | GO_ERBB_SIGNALING_PATHWAY
Systematic name | M12775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by binding of a ligand to a member of the ERBB family of receptor tyrosine kinases on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:jc, PMID:16460914, Wikipedia:ErbB]
Full description |

Standard name | GO_ERBB2_SIGNALING_PATHWAY
Systematic name | M11834
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by binding of a ligand to a member of the ERBB family of receptors on the surface of a cell, where the signal is transmitted by ERBB2. The pathway ends with regulation of a downstream cellular process, e.g. transcription. ERBB2 receptors are themselves unable to bind to ligands, but act as a signal-amplifying tyrosine kinase within a heterodimeric pair. [GOC:jc, PMID:16460914, Reactome:R-HSA-1227986]
Full description |

Standard name | GO_MACROPHAGE_COLONY_STIMULATING_FACTOR_SIGNALING_PATHWAY
Systematic name | M23474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of the cytokine macrophage colony-stimulating factor (M-CSF) to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:signaling, GOC:uh, PMID:12138890, Wikipedia:Macrophage_colony-stimulating_factor]
Full description |

Standard name | GO_INTERLEUKIN_23_MEDIATED_SIGNALING_PATHWAY
Systematic name | M23475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of interleukin-23 to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:nhn, GOC:signaling]
Full description |

Standard name | GO_THROMBOPOIETIN_MEDIATED_SIGNALING_PATHWAY
Systematic name | M29163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a thrombopoietin to the thrombopoietin receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:nhn, GOC:signaling, PMID:19630807]
Full description |

Standard name | GO_ONCOSTATIN_M_MEDIATED_SIGNALING_PATHWAY
Systematic name | M34160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of oncostatin-M (OSM) to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. OSM can signal via at least two different receptors (a specific receptor and a LIF receptor) to activate different downstream signal transduction pathways. [GOC:nhn, GOC:signaling, PMID:10579456, PMID:12811586]
Full description |

Standard name | GO_ANGIOTENSIN_ACTIVATED_SIGNALING_PATHWAY
Systematic name | M23477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of angiotensin II binding to an angiotensin receptor on the surface of the cell, and proceeding with the activated receptor transmitting the signal to a heterotrimeric G-protein complex to initiate a change in cell activity. Ends with regulation of a downstream cellular process, e.g. transcription. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:nhn, GOC:signaling, PMID:10977869]
Full description |

Standard name | GO_SOMATOSTATIN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a somatostatin receptor (SSTR) binding to one of its physiological ligands and transmitting the signal to a heterotrimeric G-protein complex. The pathway ends with regulation of a downstream cellular process, e.g. transcription. [GOC:jc, PMID:18006219, PMID:8769369]
Full description |

Standard name | GO_CANNABINOID_SIGNALING_PATHWAY
Systematic name | M23479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a cannabinoid binding to a cell surface receptor. The pathway proceeds with the receptor transmitting the signal to a heterotrimeric G-protein complex and ends with regulation of a downstream cellular process, e.g. transcription. Cannabinoids are a class of diverse chemical compounds that include the endocannabinoids and the phytocannabinoids. [GOC:bf, GOC:jc, GOC:signaling, Wikipedia:Cannabinoid]
Full description |

Standard name | GO_NEUROTROPHIN_SIGNALING_PATHWAY
Systematic name | M16665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a neurotrophin to a receptor on the surface of a target cell, and ending with regulation of a downstream cellular process, e.g. transcription. Neurotrophins are a family of secreted growth factors that induce the survival, development, and function of neurons. [GOC:bf, GOC:jc, GOC:signaling, PMID:17466268, Wikipedia:Neurotrophin]
Full description |

Standard name | GO_NERVE_GROWTH_FACTOR_SIGNALING_PATHWAY
Systematic name | M23480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of nerve growth factor (NGF) to a receptor on the surface of the target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, PMID:11520933, Wikipedia:Nerve_growth_factor]
Full description |

Standard name | GO_TORC1_SIGNALING
Systematic name | M23481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of intracellular molecular signals mediated by TORC1; TOR (target of rapamycin) in complex with at least Raptor (regulatory-associated protein of TOR), or orthologs of, and other signaling components. [GOC:lb]
Full description |

Standard name | GO_TORC2_SIGNALING
Systematic name | M23482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of intracellular molecular signals mediated by TORC2; TOR (rapamycin-insensitive companion of TOR) in complex with at least Rictor (regulatory-associated protein of TOR), or orthologs of, and other signaling components. [GOC:lb]
Full description |

Standard name | GO_CYTOPLASMIC_PATTERN_RECOGNITION_RECEPTOR_SIGNALING_PATHWAY_IN_RESPONSE_TO_VIRUS
Systematic name | M23483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of a virus or viral RNA binding to a pattern recognition receptor (PRR) located in the cytoplasm. Cytosolic PRRs such as RIG-I (DDX58) and MDA-5 (IFIH1) detect RNA synthesized during active viral replication and trigger a signaling pathway to protect the host against viral infection, for example by inducing the expression of antiviral cytokines. [GOC:bf, PMID:17328678, PMID:18272355, PMID:19531363]
Full description |

Standard name | GO_RIG_I_SIGNALING_PATHWAY
Systematic name | M23484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of the cytoplasmic pattern recognition receptor (PRR) RIG-1 (also known as DDX58) binding to viral RNA. RIG-I detects RNA synthesized during active viral replication and triggers a signaling pathway to protect the host against viral infection, for example by inducing the expression of antiviral cytokines. [GOC:bf, PMID:17328678, PMID:19620789, PMID:21435580]
Full description |

Standard name | GO_MDA_5_SIGNALING_PATHWAY
Systematic name | M23485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of the cytoplasmic pattern recognition receptor (PRR) MDA-5 (also known as IFIH1) binding to viral RNA. MDA-5 detects RNA synthesized during active viral replication and triggers a signaling pathway to protect the host against viral infection, for example by inducing the expression of antiviral cytokines. [GOC:bf, PMID:19620789]
Full description |

Standard name | GO_REGULATION_OF_VIRAL_INDUCED_CYTOPLASMIC_PATTERN_RECOGNITION_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the series of molecular signals generated as a consequence of a virus or viral RNA binding to a pattern recognition receptor (PRR) located in the cytoplasm. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VIRAL_INDUCED_CYTOPLASMIC_PATTERN_RECOGNITION_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the series of molecular signals generated as a consequence of a virus or viral RNA binding to a pattern recognition receptor (PRR) located in the cytoplasm. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_MDA_5_SIGNALING_PATHWAY
Systematic name | M23487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the series of molecular signals generated as a consequence of the cytoplasmic pattern recognition receptor (PRR) MDA-5 (also known as IFIH1) binding to viral RNA. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RIG_I_SIGNALING_PATHWAY
Systematic name | M23488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the series of molecular signals generated as a consequence of the cytoplasmic pattern recognition receptor (PRR) RIG-1 (also known as DDX58) binding to viral RNA. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_SINGLE_STRANDED_VIRAL_RNA_REPLICATION_VIA_DOUBLE_STRANDED_DNA_INTERMEDIATE
Systematic name | M23489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A viral genome replication where the template is single-stranded RNA (ssRNA), and which proceeds via a double stranded DNA (dsDNA) intermediate molecule. Viral genomic RNA is first reverse transcribed into dsDNA, which integrates into the host chromosomal DNA, where it is transcribed by host RNA polymerase II. [GOC:bf, GOC:jl, ISBN:0198506732, VZ:1937]
Full description |

Standard name | GO_VIRAL_RNA_GENOME_REPLICATION
Systematic name | M23490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The replication of a viral RNA genome. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_VIRAL_BUDDING_VIA_HOST_ESCRT_COMPLEX
Systematic name | M23491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Viral budding which uses a host ESCRT protein complex, or complexes, to mediate the budding process. [UniProtKB-KW:KW-1187, VZ:1536]
Full description |

Standard name | GO_ESTABLISHMENT_OF_MITOTIC_SPINDLE_LOCALIZATION
Systematic name | M15825
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which the directed movement of the mitotic spindle to a specific location in the cell occurs. [GOC:ai]
Full description |

Standard name | GO_GROWTH
Systematic name | M1108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The increase in size or mass of an entire organism, a part of an organism or a cell. [GOC:bf, GOC:ma]
Full description |

Standard name | GO_REGULATION_OF_GROWTH
Systematic name | M1707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the growth of all or part of an organism so that it occurs at its proper speed, either globally or in a specific part of the organism's development. [GOC:ems, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_GROWTH_RATE
Systematic name | M23492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate of growth of all or part of an organism. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MULTICELLULAR_ORGANISM_GROWTH
Systematic name | M12396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of growth of the body of an organism so that it reaches its usual body size. [GOC:dph, GOC:ems, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MULTICELLULAR_ORGANISM_GROWTH
Systematic name | M13946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of growth of an organism to reach its usual body size. [GOC:dph, GOC:ems, GOC:tb]
Full description |

Standard name | GO_EMBRYONIC_CLEAVAGE
Systematic name | M23493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The first few specialized divisions of an activated animal egg. [GOC:clt, ISBN:0070524300]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MULTICELLULAR_ORGANISM_GROWTH
Systematic name | M16157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of growth of an organism to reach its usual body size. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EMBRYONIC_DEVELOPMENT
Systematic name | M16028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of embryonic development. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_MEIOTIC_NUCLEAR_DIVISION
Systematic name | M10801
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of meiotic nuclear division, the process in which the nucleus of a diploid cell divides twice forming four haploid cells, one or more of which usually function as gametes. [GOC:ems, GOC:ma]
Full description |

Standard name | GO_REGULATION_OF_GENE_EXPRESSION_EPIGENETIC
Systematic name | M16267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gene expression; the process is mitotically or meiotically heritable, or is stably self-propagated in the cytoplasm of a resting cell, and does not entail a change in DNA sequence. [PMID:10521337, PMID:11498582]
Full description |

Standard name | GO_SNRNA_MODIFICATION
Systematic name | M23494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent alteration of one or more nucleotides within snRNA, resulting in a change in the properties of the snRNA. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_DEVELOPMENT_HETEROCHRONIC
Systematic name | M14964
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the consistent predetermined time point at which an integrated living unit or organism progresses from an initial condition to a later condition and the rate at which this time point is reached. [PMID:9442909]
Full description |

Standard name | GO_REGULATION_OF_FIBROBLAST_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M13122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of fibroblast growth factor receptor signaling pathway activity. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FIBROBLAST_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of fibroblast growth factor receptor signaling pathway activity. [GOC:go_curators]
Full description |

Standard name | GO_DNA_ENDOREDUPLICATION
Systematic name | M23495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Regulated re-replication of DNA within a single cell cycle, resulting in an increased cell ploidy. An example of this process occurs in the synthesis of Drosophila salivary gland cell polytene chromosomes. [GOC:jl, GOC:vw]
Full description |

Standard name | GO_PROTEIN_REFOLDING
Systematic name | M15562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process carried out by a cell that restores the biological activity of an unfolded or misfolded protein, using helper proteins such as chaperones. [GOC:mb]
Full description |

Standard name | GO_CHEMOKINE_BIOSYNTHETIC_PROCESS
Systematic name | M23496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of chemokines, any member of a family of small chemotactic cytokines; their name is derived from their ability to induce directed chemotaxis in nearby responsive cells. All chemokines possess a number of conserved cysteine residues involved in intramolecular disulfide bond formation. Some chemokines are considered pro-inflammatory and can be induced during an immune response to recruit cells of the immune system to a site of infection, while others are considered homeostatic and are involved in controlling the migration of cells during normal processes of tissue maintenance or development. Chemokines are found in all vertebrates, some viruses and some bacteria. [GOC:BHF, GOC:rl, ISBN:0198506732, PMID:12183377, Wikipedia:Chemokine]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYTOKINE_BIOSYNTHETIC_PROCESS
Systematic name | M15539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of cytokines. [GOC:go_curators]
Full description |

Standard name | GO_FLUID_TRANSPORT
Systematic name | M16901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances that are in liquid form in normal living conditions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_EPITHELIAL_FLUID_TRANSPORT
Systematic name | M23497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of fluid across epithelia. [GOC:jl, PMID:11390830]
Full description |

Standard name | GO_OLFACTORY_BEHAVIOR
Systematic name | M23498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The behavior of an organism in response to an odor. [GOC:jid, GOC:pr]
Full description |

Standard name | GO_WOUND_HEALING
Systematic name | M12074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events that restore integrity to a damaged tissue, following an injury. [GOC:bf, PMID:15269788]
Full description |

Standard name | GO_GLIOGENESIS
Systematic name | M3208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in the generation of glial cells. This includes the production of glial progenitors and their differentiation into mature glia. [GOC:dgh, GOC:jid]
Full description |

Standard name | GO_REGULATION_OF_CATECHOLAMINE_METABOLIC_PROCESS
Systematic name | M15930
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving catecholamines. [GOC:go_curators]
Full description |

Standard name | GO_INTRACILIARY_TRANSPORT
Systematic name | M23499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The bidirectional movement of large protein complexes along microtubules within a cilium, mediated by motor proteins. [GOC:cilia, GOC:kmv, PMID:17981739, PMID:18180368, PMID:22869374, Reactome:R-HSA-5620924.2]
Full description |

Standard name | GO_CELL_MIGRATION_INVOLVED_IN_GASTRULATION
Systematic name | M13468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The migration of individual cells within the blastocyst to help establish the multi-layered body plan of the organism (gastrulation). For example, the migration of cells from the surface to the interior of the embryo (ingression). [GOC:jl, http://www.cellmigration.org/, ISBN:0878932437]
Full description |

Standard name | GO_T_HELPER_1_TYPE_IMMUNE_RESPONSE
Systematic name | M12589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response which is associated with resistance to intracellular bacteria, fungi, and protozoa, and pathological conditions such as arthritis, and which is typically orchestrated by the production of particular cytokines by T-helper 1 cells, most notably interferon-gamma, IL-2, and lymphotoxin. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_TYPE_2_IMMUNE_RESPONSE
Systematic name | M23501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response which is associated with resistance to extracellular organisms such as helminths and pathological conditions such as allergy, which is orchestrated by the production of particular cytokines, most notably IL-4, IL-5, IL-10, and IL-13, by any of a variety of cell types including T-helper 2 cells, eosinophils, basophils, mast cells, and nuocytes, resulting in enhanced production of certain antibody isotypes and other effects. [GOC:add, ISBN:0781735149, PMID:18000958, PMID:18007680, PMID:20065995, PMID:20200518]
Full description |

Standard name | GO_T_CELL_PROLIFERATION
Systematic name | M3083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a T cell population by cell division. Follows T cell activation. [GOC:jl]
Full description |

Standard name | GO_B_CELL_PROLIFERATION
Systematic name | M11204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a B cell population by cell division. Follows B cell activation. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_CELL_PROLIFERATION
Systematic name | M17020
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of T cell proliferation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACTIVATED_T_CELL_PROLIFERATION
Systematic name | M14546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of activated T cell proliferation. [GOC:jl]
Full description |

Standard name | GO_CYTOKINE_METABOLIC_PROCESS
Systematic name | M3372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving cytokines, any of a group of proteins or glycoproteins that function to control the survival, growth and differentiation of tissues and cells, and which have autocrine and paracrine activity. [GO_REF:0000022, GOC:bf, GOC:BHF, ISBN:0198599471]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOKINE_BIOSYNTHETIC_PROCESS
Systematic name | M5435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of cytokines. [GOC:go_curators]
Full description |

Standard name | GO_T_CELL_ACTIVATION
Systematic name | M2810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a mature or immature T cell resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific. [GOC:mgi_curators, ISBN:0781735149]
Full description |

Standard name | GO_B_CELL_ACTIVATION
Systematic name | M10657
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a mature or immature B cell resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific. [GOC:mgi_curators, ISBN:0781735149]
Full description |

Standard name | GO_MACROPHAGE_ACTIVATION
Systematic name | M13410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in morphology and behavior of a macrophage resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. [GOC:mgi_curators, ISBN:0781735149, PMID:14506301]
Full description |

Standard name | GO_MONOCYTE_ACTIVATION
Systematic name | M23505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a monocyte resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. [GOC:mgi_curators, ISBN:0781735149]
Full description |

Standard name | GO_ENDOTHELIAL_CELL_ACTIVATION
Systematic name | M23506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of an endothelial cell resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. [GOC:mgi_curators, ISBN:0781735149, PMID:12851652, PMID:14581484]
Full description |

Standard name | GO_REGULATION_OF_CELL_POPULATION_PROLIFERATION
Systematic name | M4627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell proliferation. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_CELL_PROLIFERATION
Systematic name | M13966
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of T cell proliferation. [GOC:jl]
Full description |

Standard name | GO_NEUROTRANSMITTER_METABOLIC_PROCESS
Systematic name | M15035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving neurotransmitters, any of a group of substances that are released on excitation from the axon terminal of a presynaptic neuron of the central or peripheral nervous system and travel across the synaptic cleft to either excite or inhibit the target cell. [GOC:jl]
Full description |

Standard name | GO_NEUROTRANSMITTER_CATABOLIC_PROCESS
Systematic name | M23508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of any of a group of substances that are released on excitation from the axon terminal of a presynaptic neuron of the central or peripheral nervous system and travel across the synaptic cleft to either excite or inhibit the target cell. [GOC:jl]
Full description |

Standard name | GO_NEUROTRANSMITTER_BIOSYNTHETIC_PROCESS
Systematic name | M11101
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any of a group of substances that are released on excitation from the axon terminal of a presynaptic neuron of the central or peripheral nervous system and travel across the synaptic cleft to either excite or inhibit the target cell. [GOC:jl]
Full description |

Standard name | GO_MEIOTIC_DNA_DOUBLE_STRAND_BREAK_FORMATION
Systematic name | M23509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which double-strand breaks are generated at defined hotspots throughout the genome during meiosis I. This results in the initiation of meiotic recombination. [GOC:elh, GOC:jl, PMID:11529427]
Full description |

Standard name | GO_RETROGRADE_TRANSPORT_ENDOSOME_TO_GOLGI
Systematic name | M15236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of membrane-bounded vesicles from endosomes back to the trans-Golgi network where they are recycled for further rounds of transport. [GOC:jl, PMID:10873832, PMID:16936697]
Full description |

Standard name | GO_STRAND_INVASION
Systematic name | M23510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the nucleoprotein complex (composed of the broken single-strand DNA and the recombinase) searches and identifies a region of homology in intact duplex DNA. The broken single-strand DNA displaces the like strand and forms Watson-Crick base pairs with its complement, forming a duplex in which each strand is from one of the two recombining DNA molecules. [GOC:elh, PMID:10357855]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_GLUCOSE_STARVATION
Systematic name | M15497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of deprivation of glucose. [GOC:jl]
Full description |

Standard name | GO_LIPOPROTEIN_METABOLIC_PROCESS
Systematic name | M10659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any conjugated, water-soluble protein in which the covalently attached nonprotein group consists of a lipid or lipids. [ISBN:0198506732]
Full description |

Standard name | GO_LIPOPROTEIN_BIOSYNTHETIC_PROCESS
Systematic name | M13286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any conjugated, water-soluble protein in which the covalently attached nonprotein group consists of a lipid or lipids. [ISBN:0198506732]
Full description |

Standard name | GO_LIPOPROTEIN_CATABOLIC_PROCESS
Systematic name | M23511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of any conjugated, water-soluble protein in which the covalently attached nonprotein group consists of a lipid or lipids. [ISBN:0198506732]
Full description |

Standard name | GO_HEME_METABOLIC_PROCESS
Systematic name | M14764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving heme, any compound of iron complexed in a porphyrin (tetrapyrrole) ring. [GOC:jl, ISBN:0124325653]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_CATABOLIC_PROCESS
Systematic name | M13743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of a protein by the destruction of the native, active configuration, with or without the hydrolysis of peptide bonds. [GOC:go_curators, GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_CATABOLIC_PROCESS
Systematic name | M11768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of a protein by the destruction of the native, active configuration, with or without the hydrolysis of peptide bonds. [GOC:go_curators, GOC:jl, PMID:10207076]
Full description |

Standard name | GO_XENOBIOTIC_CATABOLIC_PROCESS
Systematic name | M23512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a xenobiotic compound, a compound foreign to living organisms. Used of chemical compounds, e.g. a xenobiotic chemical, such as a pesticide. [GOC:jl]
Full description |

Standard name | GO_CELLULAR_KETONE_METABOLIC_PROCESS
Systematic name | M11614
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any of a class of organic compounds that contain the carbonyl group, CO, and in which the carbonyl group is bonded only to carbon atoms, as carried out by individual cells. The general formula for a ketone is RCOR, where R and R are alkyl or aryl groups. [GOC:jl, ISBN:0787650153]
Full description |

Standard name | GO_KETONE_BIOSYNTHETIC_PROCESS
Systematic name | M14421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of ketones, a class of organic compounds that contain the carbonyl group, CO, and in which the carbonyl group is bonded only to carbon atoms. The general formula for a ketone is RCOR, where R and R are alkyl or aryl groups. [GOC:go_curators]
Full description |

Standard name | GO_KETONE_CATABOLIC_PROCESS
Systematic name | M23513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of ketones, a class of organic compounds that contain the carbonyl group, CO, and in which the carbonyl group is bonded only to carbon atoms. The general formula for a ketone is RCOR, where R and R are alkyl or aryl groups. [GOC:go_curators]
Full description |

Standard name | GO_CELLULAR_MODIFIED_AMINO_ACID_CATABOLIC_PROCESS
Systematic name | M11001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of compounds derived from amino acids, organic acids containing one or more amino substituents. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_COCAINE
Systematic name | M10535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cocaine stimulus. Cocaine is a crystalline alkaloid obtained from the leaves of the coca plant. [GOC:ef, GOC:jl]
Full description |

Standard name | GO_TISSUE_REGENERATION
Systematic name | M13649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regrowth of lost or destroyed tissues. [GOC:curators]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PLANAR_POLARITY_OF_EMBRYONIC_EPITHELIUM
Systematic name | M23517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Coordinated organization of groups of cells in the plane of an embryonic epithelium, such that they all orient to similar coordinates. [GOC:ascb_2009, GOC:dph, GOC:jl, GOC:tb]
Full description |

Standard name | GO_RIBOSOME_BIOGENESIS
Systematic name | M10214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the biosynthesis of constituent macromolecules, assembly, and arrangement of constituent parts of ribosome subunits; includes transport to the sites of protein synthesis. [GOC:ma, PMID:26404467, Wikipedia:Ribosome_biogenesis]
Full description |

Standard name | GO_RIBOSOME_ASSEMBLY
Systematic name | M11348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of the mature ribosome and of its subunits. [GOC:ma]
Full description |

Standard name | GO_MATURE_RIBOSOME_ASSEMBLY
Systematic name | M23518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of the large and small ribosomal subunits into a functional ribosome. [GOC:ma]
Full description |

Standard name | GO_DNA_PROTECTION
Systematic name | M23519
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which DNA is protected from damage by, for example, oxidative stress. [GOC:jl]
Full description |

Standard name | GO_PROTECTION_FROM_NATURAL_KILLER_CELL_MEDIATED_CYTOTOXICITY
Systematic name | M34161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of protecting a cell from natural killer cell mediated cytotoxicity. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_RIBOSOMAL_LARGE_SUBUNIT_BIOGENESIS
Systematic name | M16031
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the biosynthesis of constituent macromolecules, assembly, and arrangement of constituent parts of a large ribosomal subunit; includes transport to the sites of protein synthesis. [GOC:jl]
Full description |

Standard name | GO_RIBOSOMAL_SMALL_SUBUNIT_BIOGENESIS
Systematic name | M12963
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the biosynthesis of constituent macromolecules, assembly, and arrangement of constituent parts of a small ribosomal subunit; includes transport to the sites of protein synthesis. [GOC:jl]
Full description |

Standard name | GO_ERROR_PRONE_TRANSLESION_SYNTHESIS
Systematic name | M14864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The conversion of DNA-damage induced single-stranded gaps into large molecular weight DNA after replication by using a specialized DNA polymerase or replication complex to insert a defined nucleotide across the lesion. This process does not remove the replication-blocking lesions and causes an increase in the endogenous mutation level. For example, in E. coli, a low fidelity DNA polymerase, pol V, copies lesions that block replication fork progress. This produces mutations specifically targeted to DNA template damage sites, but it can also produce mutations at undamaged sites. [GOC:elh, GOC:jl, PMID:11485998]
Full description |

Standard name | GO_PURINE_NUCLEOSIDE_METABOLIC_PROCESS
Systematic name | M23522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving one of a family of organic molecules consisting of a purine base covalently bonded to a sugar ribose (a ribonucleoside) or deoxyribose (a deoxyribonucleoside). [GOC:jl, ISBN:0140512713]
Full description |

Standard name | GO_MOLTING_CYCLE
Systematic name | M13884
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The periodic casting off and regeneration of an outer covering of cuticle, feathers, hair, horns, skin, etc. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_FATTY_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M14401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of fatty acids, any of the aliphatic monocarboxylic acids that can be liberated by hydrolysis from naturally occurring fats and oils. [GOC:go_curators, GOC:jl]
Full description |

Standard name | GO_VASODILATION
Systematic name | M13507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An increase in the internal diameter of blood vessels, especially arterioles or capillaries, due to relaxation of smooth muscle cells that line the vessels, and usually resulting in a decrease in blood pressure. [GOC:pr, ISBN:0192800981]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CIRCADIAN_SLEEP_WAKE_CYCLE_SLEEP
Systematic name | M23524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the duration or quality of sleep, a readily reversible state of reduced awareness and metabolic activity that occurs periodically in many animals. [GOC:go_curators, GOC:jl, ISBN:0192800981]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHORYLATION
Systematic name | M10561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of addition of phosphate groups into a molecule. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PHOSPHORYLATION
Systematic name | M15361
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or decreases the rate of addition of phosphate groups to a molecule. [GOC:jl]
Full description |

Standard name | GO_TAXIS
Systematic name | M12201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a motile cell or organism in response to an external stimulus. [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_KERATAN_SULFATE_METABOLIC_PROCESS
Systematic name | M29167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving keratan sulfate, a glycosaminoglycan with repeat units consisting of beta-1,4-linked D-galactopyranosyl-beta-(1,4)-N-acetyl-D-glucosamine 6-sulfate and with variable amounts of fucose, sialic acid and mannose units; keratan sulfate chains are covalently linked by a glycosidic attachment through the trisaccharide galactosyl-galactosyl-xylose to peptidyl-threonine or serine residues. [GOC:go_curators]
Full description |

Standard name | GO_KERATAN_SULFATE_CATABOLIC_PROCESS
Systematic name | M13546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of keratan sulfate, a glycosaminoglycan with repeat units consisting of beta-1,4-linked D-galactopyranosyl-beta-(1,4)-N-acetyl-D-glucosamine 6-sulfate and with variable amounts of fucose, sialic acid and mannose units; keratan sulfate chains are covalently linked by a glycosidic attachment through the trisaccharide galactosyl-galactosyl-xylose to peptidyl-threonine or serine residues. [GOC:go_curators]
Full description |

Standard name | GO_VITAMIN_D_METABOLIC_PROCESS
Systematic name | M13023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving vitamin D, any of a group of related, fat-soluble compounds that are derived from delta-5,7 steroids and play a central role in calcium metabolism. Specific forms of vitamin D include calciferol (ergocalciferol; vitamin D2) and cholecalciferol (calciol; vitamin D3). [GOC:mah, ISBN:0471331309]
Full description |

Standard name | GO_FAT_SOLUBLE_VITAMIN_BIOSYNTHETIC_PROCESS
Systematic name | M23525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any of a diverse group of vitamins that are soluble in organic solvents and relatively insoluble in water. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_WATER_SOLUBLE_VITAMIN_BIOSYNTHETIC_PROCESS
Systematic name | M23527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any of a diverse group of vitamins that are soluble in water. [GOC:jl]
Full description |

Standard name | GO_VITAMIN_D_BIOSYNTHETIC_PROCESS
Systematic name | M23528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of vitamin D, any of a group of related, fat-soluble compounds that are derived from delta-5,7 steroids and play a central role in calcium metabolism. Specific forms of vitamin D include calciferol (ergocalciferol; vitamin D2) and cholecalciferol (calciol; vitamin D3). [GOC:mah, ISBN:0471331309]
Full description |

Standard name | GO_VITAMIN_K_METABOLIC_PROCESS
Systematic name | M29168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any of the forms of vitamin K, quinone-derived vitamins which are involved in the synthesis of blood-clotting factors in mammals. Vitamin K substances share a methylated naphthoquinone ring structure and vary in the aliphatic side chains attached to the molecule. [GOC:jl, http://www.dentistry.leeds.ac.uk/biochem/thcme/vitamins.html#k]
Full description |

Standard name | GO_PHYLLOQUINONE_METABOLIC_PROCESS
Systematic name | M34162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving phylloquinone, a quinone-derived compound synthesized by green plants. Phylloquinone has vitamin K activity and is known as vitamin K1. [GOC:jl, http://www.dentistry.leeds.ac.uk/biochem/thcme/vitamins.html#k]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_POTENTIAL
Systematic name | M17324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the establishment or extent of a membrane potential, the electric potential existing across any membrane arising from charges in the membrane itself and from the charges present in the media on either side of the membrane. [GOC:jl, GOC:mtg_cardio, GOC:tb, ISBN:0198506732]
Full description |

Standard name | GO_CELLULAR_MODIFIED_AMINO_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M6149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of compounds derived from amino acids, organic acids containing one or more amino substituents. [GOC:ai]
Full description |

Standard name | GO_THYROID_HORMONE_METABOLIC_PROCESS
Systematic name | M11344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any of the compounds secreted by the thyroid gland, largely thyroxine and triiodothyronine. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_CRISTAE_FORMATION
Systematic name | M11776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The assembly of cristae, the inwards folds of the inner mitochondrial membrane. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_NOREPINEPHRINE_METABOLIC_PROCESS
Systematic name | M23529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving norepinephrine, a hormone secreted by the adrenal medulla, and a neurotransmitter in the sympathetic peripheral nervous system and in some tracts in the central nervous system. It is also the demethylated biosynthetic precursor of epinephrine. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_DOPAMINE_BIOSYNTHETIC_PROCESS
Systematic name | M23530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of dopamine, a catecholamine neurotransmitter and a metabolic precursor of noradrenaline and adrenaline. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_DOPAMINE_METABOLIC_PROCESS
Systematic name | M12513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving dopamine, a catecholamine neurotransmitter and a metabolic precursor of noradrenaline and adrenaline. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_NOREPINEPHRINE_BIOSYNTHETIC_PROCESS
Systematic name | M23532
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of norepinephrine, a hormone secreted by the adrenal medulla, and a neurotransmitter in the sympathetic peripheral nervous system and in some tracts in the central nervous system. It is also the demethylated biosynthetic precursor of epinephrine. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_CATECHOLAMINE_BIOSYNTHETIC_PROCESS
Systematic name | M13030
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any of a group of physiologically important biogenic amines that possess a catechol (3,4-dihydroxyphenyl) nucleus and are derivatives of 3,4-dihydroxyphenylethylamine. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_CATECHOLAMINE_CATABOLIC_PROCESS
Systematic name | M29169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of any of a group of physiologically important biogenic amines that possess a catechol (3,4-dihydroxyphenyl) nucleus and are derivatives of 3,4-dihydroxyphenylethylamine. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_CHOLINE_CATABOLIC_PROCESS
Systematic name | M23533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of choline (2-hydroxyethyltrimethylammonium), an amino alcohol that occurs widely in living organisms as a constituent of certain types of phospholipids and in the neurotransmitter acetylcholine. [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_SEROTONIN_METABOLIC_PROCESS
Systematic name | M29170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving serotonin (5-hydroxytryptamine), a monoamine neurotransmitter occurring in the peripheral and central nervous systems, also having hormonal properties. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_INDOLE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M13964
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving compounds that contain an indole (2,3-benzopyrrole) skeleton. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_INDOLE_CONTAINING_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M23534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of compounds that contain an indole (2,3-benzopyrrole) skeleton. [GOC:jl]
Full description |

Standard name | GO_INDOLE_CONTAINING_COMPOUND_CATABOLIC_PROCESS
Systematic name | M23535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of compounds that contain an indole (2,3-benzopyrrole) skeleton. [GOC:jl]
Full description |

Standard name | GO_ETHANOLAMINE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M29171
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving ethanolamine (2-aminoethanol) and compounds derived from it. [GOC:mah]
Full description |

Standard name | GO_PIGMENT_METABOLIC_PROCESS
Systematic name | M13629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving pigment, any general or particular coloring matter in living organisms, e.g. melanin. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_HORMONE_METABOLIC_PROCESS
Systematic name | M3753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any hormone, naturally occurring substances secreted by specialized cells that affects the metabolism or behavior of other cells possessing functional receptors for the hormone. [GOC:jl]
Full description |

Standard name | GO_HORMONE_BIOSYNTHETIC_PROCESS
Systematic name | M13291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any hormone, naturally occurring substances secreted by specialized cells that affects the metabolism or behavior of other cells possessing functional receptors for the hormone. [GOC:jl]
Full description |

Standard name | GO_HORMONE_CATABOLIC_PROCESS
Systematic name | M23537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of any hormone, naturally occurring substances secreted by specialized cells that affects the metabolism or behavior of other cells possessing functional receptors for the hormone. [GOC:jl]
Full description |

Standard name | GO_PROGESTERONE_METABOLIC_PROCESS
Systematic name | M16793
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving progesterone, a steroid hormone produced in the ovary which prepares and maintains the uterus for pregnancy. Also found in plants. [GOC:jl, http://www.cogsci.princeton.edu/]
Full description |

Standard name | GO_PURINE_NUCLEOSIDE_BIOSYNTHETIC_PROCESS
Systematic name | M13727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any purine nucleoside, one of a family of organic molecules consisting of a purine base covalently bonded to a sugar ribose (a ribonucleoside) or deoxyribose (a deoxyribonucleoside). [GOC:go_curators]
Full description |

Standard name | GO_RIBONUCLEOSIDE_CATABOLIC_PROCESS
Systematic name | M16271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of any ribonucleoside, a nucleoside in which purine or pyrimidine base is linked to a ribose (beta-D-ribofuranose) molecule. [GOC:jl]
Full description |

Standard name | GO_PHOTORECEPTOR_CELL_DEVELOPMENT
Systematic name | M13417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Development of a photoreceptor, a cell that responds to incident electromagnetic radiation, particularly visible light. [GOC:go_curators]
Full description |

Standard name | GO_EYE_PHOTORECEPTOR_CELL_DEVELOPMENT
Systematic name | M15705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Development of a photoreceptor, a sensory cell in the eye that reacts to the presence of light. They usually contain a pigment that undergoes a chemical change when light is absorbed, thus stimulating a nerve. [GOC:jl, ISBN:0192800981]
Full description |

Standard name | GO_EAR_MORPHOGENESIS
Systematic name | M14023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the ear are generated and organized. The ear is the sense organ in vertebrates that is specialized for the detection of sound, and the maintenance of balance. Includes the outer ear and middle ear, which collect and transmit sound waves; and the inner ear, which contains the organs of balance and (except in fish) hearing. Also includes the pinna, the visible part of the outer ear, present in some mammals. [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_INNER_EAR_MORPHOGENESIS
Systematic name | M16847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the inner ear are generated and organized. The inner ear is the structure in vertebrates that contains the organs of balance and hearing. It consists of soft hollow sensory structures (the membranous labyrinth) containing fluid (endolymph) surrounded by fluid (perilymph) and encased in a bony cavity (the bony labyrinth). It consists of two chambers, the sacculus and utriculus, from which arise the cochlea and semicircular canals respectively. [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_OUTER_EAR_MORPHOGENESIS
Systematic name | M23538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the outer ear are generated and organized. The outer ear is the part of the ear external to the tympanum (eardrum). It consists of a tube (the external auditory meatus) that directs sound waves on to the tympanum, and may also include the external pinna, which extends beyond the skull. [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_MIDDLE_EAR_MORPHOGENESIS
Systematic name | M13066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the middle ear are generated and organized. The middle ear is the air-filled cavity within the skull of vertebrates that lies between the outer ear and the inner ear. It is linked to the pharynx (and therefore to outside air) via the Eustachian tube and in mammals contains the three ear ossicles, which transmit auditory vibrations from the outer ear (via the tympanum) to the inner ear (via the oval window). [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_ODONTOGENESIS_OF_DENTIN_CONTAINING_TOOTH
Systematic name | M15056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a dentin-containing tooth over time, from its formation to the mature structure. A dentin-containing tooth is a hard, bony organ borne on the jaw or other bone of a vertebrate, and is composed mainly of dentin, a dense calcified substance, covered by a layer of enamel. [GOC:cjm, GOC:mah, GOC:mtg_sensu, PMID:10333884, PMID:15355794]
Full description |

Standard name | GO_ODONTOGENESIS
Systematic name | M16906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a tooth or teeth over time, from formation to the mature structure(s). A tooth is any hard bony, calcareous, or chitinous organ found in the mouth or pharynx of an animal and used in procuring or masticating food. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ODONTOGENESIS
Systematic name | M13601
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the formation and development of a tooth or teeth. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ODONTOGENESIS
Systematic name | M23539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the formation and development of a tooth or teeth. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_ODONTOGENESIS_OF_DENTIN_CONTAINING_TOOTH
Systematic name | M16662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the formation and development of teeth, the hard, bony appendages which are borne on the jaws, or on other bones in the walls of the mouth or pharynx of most vertebrates. [GOC:jl, GOC:mtg_sensu, PMID:15355794]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ODONTOGENESIS_OF_DENTIN_CONTAINING_TOOTH
Systematic name | M34163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the formation and development of teeth, the hard, bony appendages that are borne on the jaws, or on other bones in the walls of the mouth or pharynx of most vertebrates. [GOC:jl, PMID:15355794]
Full description |

Standard name | GO_MECHANORECEPTOR_DIFFERENTIATION
Systematic name | M14332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a mechanoreceptor, a cell specialized to transduce mechanical stimuli and relay that information centrally in the nervous system. [CL:0000199, GOC:jl]
Full description |

Standard name | GO_INNER_EAR_AUDITORY_RECEPTOR_CELL_DIFFERENTIATION
Systematic name | M23541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized inner cell acquires specialized features of an auditory hair cell. [CL:0000201, GOC:jl]
Full description |

Standard name | GO_GAMMA_DELTA_T_CELL_DIFFERENTIATION
Systematic name | M23542
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized hemopoietic cell acquires specialized features of a gamma-delta T cell. A gamma-delta T cell is a T cell that expresses a gamma-delta T cell receptor complex. [CL:0000798, GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_DRUG
Systematic name | M6886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a drug stimulus. A drug is a substance used in the diagnosis, treatment or prevention of a disease. [GOC:jl]
Full description |

Standard name | GO_DETECTION_OF_BACTERIAL_LIPOPROTEIN
Systematic name | M34164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a bacterial lipoprotein stimulus is received by a cell and converted into a molecular signal. Bacterial lipoproteins are lipoproteins characterized by the presence of conserved sequence motifs called pathogen-associated molecular patterns (PAMPs). [GOC:jl, PMID:12077222]
Full description |

Standard name | GO_SERINE_PHOSPHORYLATION_OF_STAT_PROTEIN
Systematic name | M23543
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing a phosphate group to a serine residue of a STAT (Signal Transducer and Activator of Transcription) protein. [GOC:jl, PMID:10918594]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TYROSINE_PHOSPHORYLATION_OF_STAT_PROTEIN
Systematic name | M23544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the introduction of a phosphate group to a tyrosine residue of a STAT (Signal Transducer and Activator of Transcription) protein. [GOC:jl, PMID:11426647]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TYROSINE_PHOSPHORYLATION_OF_STAT_PROTEIN
Systematic name | M23545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the introduction of a phosphate group to a tyrosine residue of a STAT (Signal Transducer and Activator of Transcription) protein. [GOC:jl, PMID:11426647]
Full description |

Standard name | GO_TUMOR_NECROSIS_FACTOR_BIOSYNTHETIC_PROCESS
Systematic name | M23546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of tumor necrosis factor, an inflammatory cytokine produced by macrophages/monocytes during acute inflammation and which is responsible for a diverse range of signaling events within cells, leading to necrosis or apoptosis. [GOC:jl, PMID:10891884]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TUMOR_NECROSIS_FACTOR_BIOSYNTHETIC_PROCESS
Systematic name | M23547
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of tumor necrosis factor, an inflammatory cytokine produced by macrophages/monocytes during acute inflammation and which is responsible for a diverse range of signaling events within cells, leading to necrosis or apoptosis. [GOC:jl, PMID:10891884]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TUMOR_NECROSIS_FACTOR_BIOSYNTHETIC_PROCESS
Systematic name | M23548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of tumor necrosis factor, an inflammatory cytokine produced by macrophages/monocytes during acute inflammation and which is responsible for a diverse range of signaling events within cells, leading to necrosis or apoptosis. [GOC:jl, PMID:10891884]
Full description |

Standard name | GO_BENZENE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M14283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving benzene, C6H6, a volatile, very inflammable liquid, contained in the naphtha produced by the destructive distillation of coal, from which it is separated by fractional distillation, or any of its derivatives. [GOC:jl]
Full description |

Standard name | GO_HYPEROSMOTIC_SALINITY_RESPONSE
Systematic name | M23549
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of detection of, or exposure to, an increase in the concentration of salt (particularly but not exclusively sodium and chloride ions) in the environment. [GOC:jl]
Full description |

Standard name | GO_HEMOGLOBIN_BIOSYNTHETIC_PROCESS
Systematic name | M23550
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of hemoglobin, an oxygen carrying, conjugated protein containing four heme groups and globin. [GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_HYDROGEN_PEROXIDE
Systematic name | M16710
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydrogen peroxide (H2O2) stimulus. [GOC:jl]
Full description |

Standard name | GO_NEURON_MATURATION
Systematic name | M10809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for a neuron to attain its fully functional state. [GOC:dph, GOC:jl]
Full description |

Standard name | GO_SUPEROXIDE_ANION_GENERATION
Systematic name | M14662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The enzymatic generation of superoxide, the superoxide anion O2- (superoxide free radical), or any compound containing this species, by a cell in response to environmental stress, thereby mediating the activation of various stress-inducible signaling pathways. [GOC:jl, PMID:12359750]
Full description |

Standard name | GO_PTERIDINE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M12704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any compound containing pteridine (pyrazino(2,3-dipyrimidine)), e.g. pteroic acid, xanthopterin and folic acid. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_PTERIDINE_CONTAINING_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M12255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any compound containing pteridine (pyrazino(2,3-dipyrimidine)), e.g. pteroic acid, xanthopterin and folic acid. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_RETINOL_METABOLIC_PROCESS
Systematic name | M11434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving retinol, one of the three compounds that makes up vitamin A. [GOC:jl, http://www.indstate.edu/thcme/mwking/vitamins.html, PMID:1924551]
Full description |

Standard name | GO_RETINOIC_ACID_METABOLIC_PROCESS
Systematic name | M13918
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving retinoic acid, one of the three components that makes up vitamin A. [GOC:jl, http://www.indstate.edu/thcme/mwking/vitamins.html]
Full description |

Standard name | GO_RETINAL_METABOLIC_PROCESS
Systematic name | M13880
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving retinal, a compound that plays an important role in the visual process in most vertebrates. In the retina, retinal combines with opsins to form visual pigments. Retinal is one of the forms of vitamin A. [ISBN:0198506732]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_EXOGENOUS_PEPTIDE_ANTIGEN_VIA_MHC_CLASS_I
Systematic name | M13990
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses a peptide antigen of exogenous origin on its cell surface in association with an MHC class I protein complex. The peptide antigen is typically, but not always, processed from a whole protein. Class I here refers to classical class I molecules. [GOC:add, ISBN:0781735149, PMID:15771591]
Full description |

Standard name | GO_HOMEOSTATIC_PROCESS
Systematic name | M17351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process involved in the maintenance of an internal steady state. [GOC:jl, ISBN:0395825172]
Full description |

Standard name | GO_RESPONSE_TO_STARVATION
Systematic name | M16522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a starvation stimulus, deprivation of nourishment. [GOC:go_curators]
Full description |

Standard name | GO_FEAR_RESPONSE
Systematic name | M12834
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The response of an organism to a perceived external threat. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_HAIR_CYCLE
Systematic name | M11508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the cyclical phases of growth (anagen), regression (catagen), quiescence (telogen), and shedding (exogen) in the life of a hair. [GOC:go_curators, PMID:12230507]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HAIR_CYCLE
Systematic name | M13363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the cyclical phases of growth (anagen), regression (catagen), quiescence (telogen), and shedding (exogen) in the life of a hair. [GOC:go_curators, PMID:12230507]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HAIR_CYCLE
Systematic name | M23551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the cyclical phases of growth (anagen), regression (catagen), quiescence (telogen), and shedding (exogen) in the life of a hair. [GOC:go_curators, PMID:12230507]
Full description |

Standard name | GO_ANAGEN
Systematic name | M23552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The growth phase of the hair cycle. Lasts, for example, about 3 to 6 years for human scalp hair. [PMID:12230507]
Full description |

Standard name | GO_REGULATION_OF_CELL_FATE_SPECIFICATION
Systematic name | M15453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that mediates the adoption of a specific fate by a cell. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_MESODERMAL_CELL_FATE_SPECIFICATION
Systematic name | M23553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mesoderm cell fate specification. [GOC:go_curators]
Full description |

Standard name | GO_RETINAL_CONE_CELL_DIFFERENTIATION
Systematic name | M23554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a retinal cone cell. [GOC:go_curators]
Full description |

Standard name | GO_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M17152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a muscle cell. [CL:0000187, GOC:go_curators]
Full description |

Standard name | GO_MUSCLE_CELL_FATE_COMMITMENT
Systematic name | M14615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the cellular identity of muscle cells is acquired and determined. [CL:0000187, GOC:go_curators]
Full description |

Standard name | GO_OVULATION_CYCLE
Systematic name | M5523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The type of sexual cycle seen in females, often with physiologic changes in the endometrium that recur at regular intervals during the reproductive years. [ISBN:0721662544]
Full description |

Standard name | GO_SPERM_EJACULATION
Systematic name | M23555
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expulsion of seminal fluid, thick white fluid containing spermatozoa, from the male genital tract. [GOC:jl, http://www.cogsci.princeton.edu/~wn/]
Full description |

Standard name | GO_THIAMINE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M23556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving thiamine (vitamin B1), and compounds derived from it. [GOC:jl]
Full description |

Standard name | GO_FLAVIN_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M29172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a flavin, any derivative of the dimethylisoalloxazine (7,8-dimethylbenzo[g]pteridine-2,4(3H,10H)-dione) skeleton, with a substituent on the 10 position. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_FIBRINOLYSIS
Systematic name | M15446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that solubilizes fibrin in the bloodstream of a multicellular organism, chiefly by the proteolytic action of plasmin. [GOC:jl, PMID:15842654]
Full description |

Standard name | GO_EMBRYONIC_DIGIT_MORPHOGENESIS
Systematic name | M10708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process, occurring in the embryo, by which the anatomical structures of the digit are generated and organized. A digit is one of the terminal divisions of an appendage, such as a finger or toe. [GOC:bf, GOC:jl, UBERON:0002544]
Full description |

Standard name | GO_DRUG_CATABOLIC_PROCESS
Systematic name | M11061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a drug, a substance used in the diagnosis, treatment or prevention of a disease. [GOC:go_curators]
Full description |

Standard name | GO_DEFENSE_RESPONSE_TO_BACTERIUM
Systematic name | M15579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Reactions triggered in response to the presence of a bacterium that act to protect the cell or organism. [GOC:jl]
Full description |

Standard name | GO_HYDROGEN_PEROXIDE_METABOLIC_PROCESS
Systematic name | M15190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving hydrogen peroxide (H2O2), a potentially harmful byproduct of aerobic cellular respiration which can cause damage to DNA. [GOC:jl, PMID:21734470]
Full description |

Standard name | GO_HYDROGEN_PEROXIDE_CATABOLIC_PROCESS
Systematic name | M10838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of hydrogen peroxide (H2O2). [GOC:jl]
Full description |

Standard name | GO_CIRCADIAN_SLEEP_WAKE_CYCLE
Systematic name | M23557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cycle from wakefulness through an orderly succession of sleep states and stages that occurs on an approximately 24 hour rhythm. [GOC:jl, http://www.sleepquest.com]
Full description |

Standard name | GO_CIRCADIAN_SLEEP_WAKE_CYCLE_REM_SLEEP
Systematic name | M23558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A stage in the circadian sleep cycle during which dreams occur and the body undergoes marked changes including rapid eye movement, loss of reflexes, and increased pulse rate and brain activity. [GOC:jl, ISBN:0395825172]
Full description |

Standard name | GO_CIRCADIAN_SLEEP_WAKE_CYCLE_NON_REM_SLEEP
Systematic name | M23559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | All sleep stages in the circadian sleep/wake cycle other than REM sleep. These stages are characterized by a slowing of brain waves and other physiological functions. [GOC:jl, http://www.sleepquest.com]
Full description |

Standard name | GO_REGULATION_OF_CIRCADIAN_SLEEP_WAKE_CYCLE
Systematic name | M11425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the circadian sleep/wake cycle. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_CIRCADIAN_RHYTHM
Systematic name | M12080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a circadian rhythm. A circadian rhythm is a biological process in an organism that recurs with a regularity of approximately 24 hours. [GOC:dph, GOC:jl, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CIRCADIAN_RHYTHM
Systematic name | M13729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of a circadian rhythm behavior. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CIRCADIAN_RHYTHM
Systematic name | M14104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a circadian rhythm behavior. [GOC:go_curators]
Full description |

Standard name | GO_EATING_BEHAVIOR
Systematic name | M12447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific behavior of an organism relating to the intake of food, any substance (usually solid) that can be metabolized by an organism to give energy and build tissue. [GOC:jl, GOC:pr, PMID:19361967]
Full description |

Standard name | GO_DRINKING_BEHAVIOR
Systematic name | M23560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific behavior of an organism relating to the intake of liquids, especially water. [GOC:curators, GOC:pr]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACID_CATABOLIC_PROCESS
Systematic name | M23561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of long-chain fatty acids, a fatty acid with a chain length between C13 and C22. [PMID:20043225]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M23562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of long-chain fatty acids, any fatty acid with a chain length between C13 and C22. [PMID:18390550]
Full description |

Standard name | GO_VERY_LONG_CHAIN_FATTY_ACID_CATABOLIC_PROCESS
Systematic name | M23563
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a fatty acid which has a chain length greater than C22. [PMID:7744868]
Full description |

Standard name | GO_REGULATION_OF_SULFUR_METABOLIC_PROCESS
Systematic name | M29173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving sulfur, the nonmetallic element sulfur or compounds that contain sulfur. [GOC:go_curators]
Full description |

Standard name | GO_DNA_DAMAGE_RESPONSE_DETECTION_OF_DNA_DAMAGE
Systematic name | M15653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required to receive a stimulus indicating DNA damage has occurred and convert it to a molecular signal. [GOC:go_curators]
Full description |

Standard name | GO_SIGNAL_TRANSDUCTION_IN_RESPONSE_TO_DNA_DAMAGE
Systematic name | M14832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cascade of processes induced by the detection of DNA damage within a cell. [GOC:go_curators]
Full description |

Standard name | GO_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_DNA_DAMAGE_BY_P53_CLASS_MEDIATOR
Systematic name | M10278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway is induced by the cell cycle regulator phosphoprotein p53, or an equivalent protein, in response to the detection of DNA damage, and ends when the execution phase of apoptosis is triggered. [GOC:go_curators, GOC:mtg_apoptosis]
Full description |

Standard name | GO_DNA_DAMAGE_RESPONSE_SIGNAL_TRANSDUCTION_RESULTING_IN_TRANSCRIPTION
Systematic name | M16861
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cascade of processes initiated in response to the detection of DNA damage, and resulting in the induction of transcription. [GOC:go_curators]
Full description |

Standard name | GO_ATP_SYNTHESIS_COUPLED_ELECTRON_TRANSPORT
Systematic name | M23564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of electrons through a series of electron donors and acceptors, generating energy that is ultimately used for synthesis of ATP. [ISBN:0716731363]
Full description |

Standard name | GO_TRNA_3_END_PROCESSING
Systematic name | M23565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the 3' end of a pre-tRNA molecule is converted to that of a mature tRNA. [GOC:go_curators]
Full description |

Standard name | GO_MRNA_TRANSCRIPTION_BY_RNA_POLYMERASE_II
Systematic name | M23566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular synthesis of messenger RNA (mRNA) from a DNA template by RNA polymerase II, originating at an RNA polymerase II promoter. [GOC:jl, ISBN:0321000382]
Full description |

Standard name | GO_NUCLEOLAR_LARGE_RRNA_TRANSCRIPTION_BY_RNA_POLYMERASE_I
Systematic name | M23567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of the large ribosomal RNA (rRNA) transcript which encodes several rRNAs, e.g. in mammals 28S, 18S and 5.8S, from a nuclear DNA template transcribed by RNA polymerase I. [GOC:jl, GOC:txnOH, ISBN:0321000382]
Full description |

Standard name | GO_5S_CLASS_RRNA_TRANSCRIPTION_BY_RNA_POLYMERASE_III
Systematic name | M29174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of 5S ribosomal RNA (rRNA), or an equivalent rRNA, from a DNA template by RNA polymerase III (Pol III), originating at a type 1 RNA polymerase III promoter. [GOC:jl, GOC:txnOH, ISBN:0321000382, PMID:12381659]
Full description |

Standard name | GO_SNRNA_TRANSCRIPTION_BY_RNA_POLYMERASE_III
Systematic name | M23568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of small nuclear RNA (snRNA) from a DNA template by RNA Polymerase III (Pol III), originating at a Pol III promoter. [GOC:jl, ISBN:0321000382]
Full description |

Standard name | GO_VITAMIN_B6_METABOLIC_PROCESS
Systematic name | M29175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any of the vitamin B6 compounds: pyridoxal, pyridoxamine and pyridoxine and the active form, pyridoxal phosphate. [GOC:jl, http://www.indstate.edu/thcme/mwking/vitamins.html]
Full description |

Standard name | GO_PYRUVATE_BIOSYNTHETIC_PROCESS
Systematic name | M29176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of pyruvate, 2-oxopropanoate. [GOC:go_curators]
Full description |

Standard name | GO_XENOBIOTIC_TRANSPORT
Systematic name | M23570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a xenobiotic, a compound foreign to living organisms, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:go_curators]
Full description |

Standard name | GO_TRIPEPTIDE_TRANSPORT
Systematic name | M34165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a tripeptide, a compound containing three amino acids linked together by peptide bonds, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:jl]
Full description |

Standard name | GO_D_AMINO_ACID_TRANSPORT
Systematic name | M23571
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of the D-enantiomer of an amino acid into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:jl, GOC:jsg, GOC:mah]
Full description |

Standard name | GO_ACTIVATION_OF_JANUS_KINASE_ACTIVITY
Systematic name | M23572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing a phosphate group to a tyrosine residue of a JAK (Janus Activated Kinase) protein, thereby activating it. [GOC:jl, PMID:12479803]
Full description |

Standard name | GO_AMYLOID_PRECURSOR_PROTEIN_METABOLIC_PROCESS
Systematic name | M14901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving amyloid precursor protein (APP), the precursor of amyloid-beta, a glycoprotein associated with Alzheimer's disease. [GOC:go_curators]
Full description |

Standard name | GO_AMYLOID_PRECURSOR_PROTEIN_BIOSYNTHETIC_PROCESS
Systematic name | M23573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of amyloid precursor protein (APP), the precursor of amyloid-beta, a glycoprotein associated with Alzheimer's disease. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AMYLOID_PRECURSOR_PROTEIN_BIOSYNTHETIC_PROCESS
Systematic name | M23574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of amyloid precursor protein (APP), the precursor of amyloid-beta. [GOC:go_curators]
Full description |

Standard name | GO_AMYLOID_PRECURSOR_PROTEIN_CATABOLIC_PROCESS
Systematic name | M23575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of amyloid precursor protein (APP), the precursor of amyloid-beta, a glycoprotein associated with Alzheimer's disease. [GOC:go_curators]
Full description |

Standard name | GO_SEQUESTERING_OF_ACTIN_MONOMERS
Systematic name | M23576
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The selective interaction of actin monomers with specific molecules that inhibit their polymerization by preventing their access to other monomers. [GOC:go_curators]
Full description |

Standard name | GO_CYTOPLASMIC_SEQUESTERING_OF_TRANSCRIPTION_FACTOR
Systematic name | M13757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The selective interaction of a transcription factor with specific molecules in the cytoplasm, thereby inhibiting its translocation into the nucleus. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_GOLGI_TO_PLASMA_MEMBRANE_PROTEIN_TRANSPORT
Systematic name | M23577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the transport of proteins from the Golgi to the plasma membrane. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GOLGI_TO_PLASMA_MEMBRANE_PROTEIN_TRANSPORT
Systematic name | M34166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the transport of proteins from the Golgi to the plasma membrane. [GOC:jl]
Full description |

Standard name | GO_GOLGI_TO_PLASMA_MEMBRANE_PROTEIN_TRANSPORT
Systematic name | M13776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of proteins from the Golgi to the plasma membrane in transport vesicles that move from the trans-Golgi network to the plasma membrane. [ISBN:0716731363]
Full description |

Standard name | GO_CAMERA_TYPE_EYE_DEVELOPMENT
Systematic name | M34167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the camera-type eye over time, from its formation to the mature structure. The camera-type eye is an organ of sight that receives light through an aperture and focuses it through a lens, projecting it on a photoreceptor field. [GOC:go_curators, GOC:mtg_sensu]
Full description |

Standard name | GO_MYELOID_DENDRITIC_CELL_DIFFERENTIATION
Systematic name | M16621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a monocyte acquires the specialized features of a dendritic cell, an immunocompetent cell of the lymphoid and hemopoietic systems and skin. [CL:0000782, GOC:jl]
Full description |

Standard name | GO_T_CELL_HOMEOSTASIS
Systematic name | M10932
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of regulating the proliferation and elimination of T cells such that the total number of T cells within a whole or part of an organism is stable over time in the absence of an outside stimulus. [GOC:mgi_curators, ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_MACROPHAGE_ACTIVATION
Systematic name | M11149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency or rate of macrophage activation. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MACROPHAGE_ACTIVATION
Systematic name | M23579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of macrophage activation. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MACROPHAGE_ACTIVATION
Systematic name | M10448
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stimulates, induces or increases the rate of macrophage activation. [GOC:jl]
Full description |

Standard name | GO_AMINO_ACID_ACTIVATION
Systematic name | M10357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of an amino acid to an active form, for incorporation into a peptide, protein or other macromolecule. [GOC:jl]
Full description |

Standard name | GO_PEPTIDE_BIOSYNTHETIC_PROCESS
Systematic name | M23580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of peptides, compounds of 2 or more (but usually less than 100) amino acids where the alpha carboxyl group of one is bound to the alpha amino group of another. This may include the translation of a precursor protein and its subsequent processing into a functional peptide. [GOC:dph, GOC:jl]
Full description |

Standard name | GO_ATP_DEPENDENT_CHROMATIN_REMODELING
Systematic name | M10109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Dynamic structural changes to eukaryotic chromatin that require energy from the hydrolysis of ATP, ranging from local changes necessary for transcriptional regulation to global changes necessary for chromosome segregation, mediated by ATP-dependent chromatin-remodelling factors. [GOC:jl, PMID:12042764]
Full description |

Standard name | GO_DNA_METHYLATION_INVOLVED_IN_GAMETE_GENERATION
Systematic name | M14179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent transfer of a methyl group to C-5 of cytosine that contributes to the establishment of DNA methylation patterns in the gamete. [GOC:go_curators, PMID:12138111]
Full description |

Standard name | GO_EXTRACELLULAR_STRUCTURE_ORGANIZATION
Systematic name | M18884
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of structures in the space external to the outermost structure of a cell. For cells without external protective or external encapsulating structures this refers to space outside of the plasma membrane, and also covers the host cell environment outside an intracellular parasite. [GOC:ai, GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_PENILE_ERECTION
Systematic name | M23581
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The hardening, enlarging and rising of the penis which often occurs in the sexually aroused male and enables sexual intercourse. Achieved by increased inflow of blood into the vessels of erectile tissue, and decreased outflow. [GOC:jl, Wikipedia:Penile_erection]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CATALYTIC_ACTIVITY
Systematic name | M12283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the activity of an enzyme. [GOC:ebc, GOC:jl, GOC:tb, GOC:vw]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CATALYTIC_ACTIVITY
Systematic name | M13991
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the activity of an enzyme. [GOC:ebc, GOC:jl, GOC:tb, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_GTPASE_ACTIVITY
Systematic name | M1114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate of GTP hydrolysis by a GTPase. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_AMINO_ACID_IMPORT
Systematic name | M16172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of amino acids into a cell or organelle. [GOC:jl]
Full description |

Standard name | GO_CELLULAR_METABOLIC_COMPOUND_SALVAGE
Systematic name | M16622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which produces a useful metabolic compound from derivatives of it without de novo synthesis, as carried out by individual cells. [GOC:mlg]
Full description |

Standard name | GO_PURINE_CONTAINING_COMPOUND_SALVAGE
Systematic name | M11752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that generates a purine-containing compound, any nucleobase, nucleoside, nucleotide or nucleic acid that contains a purine base, from derivatives of them without de novo synthesis. [GOC:jl]
Full description |

Standard name | GO_AMINO_ACID_SALVAGE
Systematic name | M23582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which produces an amino acid from derivatives of it, without de novo synthesis. [GOC:jl]
Full description |

Standard name | GO_RECEPTOR_METABOLIC_PROCESS
Systematic name | M13654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a receptor molecule, a macromolecule that undergoes combination with a hormone, neurotransmitter, drug or intracellular messenger to initiate a change in cell function. [GOC:jl]
Full description |

Standard name | GO_RECEPTOR_CLUSTERING
Systematic name | M16895
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The receptor metabolic process that results in grouping of a set of receptors at a cellular location, often to amplify the sensitivity of a signaling response. [GOC:bf, GOC:jl, GOC:pr, PMID:19747931, PMID:21453460]
Full description |

Standard name | GO_REGULATION_OF_VASCULAR_PERMEABILITY
Systematic name | M16377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the extent to which blood vessels can be pervaded by fluid. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASCULAR_PERMEABILITY
Systematic name | M23584
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that reduces the extent to which blood vessels can be pervaded by fluid. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULAR_PERMEABILITY
Systematic name | M14022
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the extent to which blood vessels can be pervaded by fluid. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_I_KAPPAB_KINASE_NF_KAPPAB_SIGNALING
Systematic name | M15704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of I-kappaB kinase/NF-kappaB signaling. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_I_KAPPAB_KINASE_NF_KAPPAB_SIGNALING
Systematic name | M14214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of -kappaB kinase/NF-kappaB signaling. [GOC:jl]
Full description |

Standard name | GO_SURFACTANT_HOMEOSTASIS
Systematic name | M23585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of a steady-state level of the surface-active lipoprotein mixture which coats the alveoli. [PMID:9751757]
Full description |

Standard name | GO_STRESS_FIBER_ASSEMBLY
Systematic name | M34168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a stress fiber. A stress fiber is a contractile actin filament bundle that consists of short actin filaments with alternating polarity. [GOC:go_curators, GOC:mah, PMID:16651381]
Full description |

Standard name | GO_INDUCTION_OF_BACTERIAL_AGGLUTINATION
Systematic name | M23587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which infecting bacteria are clumped together by a host organism. [GOC:jl]
Full description |

Standard name | GO_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS_VIA_THE_MULTIVESICULAR_BODY_SORTING_PATHWAY
Systematic name | M15937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a protein or peptide covalently tagged with ubiquitin, via the multivesicular body (MVB) sorting pathway; ubiquitin-tagged proteins are sorted into MVBs, and delivered to a lysosome/vacuole for degradation. [GOC:jl, PMID:11511343]
Full description |

Standard name | GO_PEPTIDE_CATABOLIC_PROCESS
Systematic name | M16063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of peptides, compounds of 2 or more (but usually less than 100) amino acids where the alpha carboxyl group of one is bound to the alpha amino group of another. [GOC:jl]
Full description |

Standard name | GO_NUCLEOTIDE_SALVAGE
Systematic name | M16619
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which produces a nucleotide, a compound consisting of a nucleoside that is esterified with (ortho)phosphate or an oligophosphate at any hydroxyl group on the glycose moiety, from derivatives of it without de novo synthesis. [GOC:jl]
Full description |

Standard name | GO_NUCLEOSIDE_SALVAGE
Systematic name | M13655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which produces a nucleotide, a nucleobase linked to either beta-D-ribofuranose (ribonucleoside) or 2-deoxy-beta-D-ribofuranose (a deoxyribonucleotide), from derivatives of it without de novo synthesis. [GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_LEUCINE
Systematic name | M23588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a leucine stimulus. [GOC:mlg]
Full description |

Standard name | GO_MYELIN_MAINTENANCE
Systematic name | M15536
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of preserving the structure and function of mature myelin. This includes maintaining the compact structure of myelin necessary for its electrical insulating characteristics as well as the structure of non-compact regions such as Schmidt-Lantermann clefts and paranodal loops. This does not include processes responsible for maintaining the nodes of Ranvier, which are not part of the myelin sheath. [GOC:dgh]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_CONTAINING_COMPLEX_DISASSEMBLY
Systematic name | M14373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of protein complex disassembly, the disaggregation of a protein complex into its constituent components. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_CONTAINING_COMPLEX_DISASSEMBLY
Systematic name | M11530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein complex disassembly, the disaggregation of a protein complex into its constituent components. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_CONTAINING_COMPLEX_DISASSEMBLY
Systematic name | M15714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein complex disassembly, the disaggregation of a protein complex into its constituent components. [GOC:jl]
Full description |

Standard name | GO_TELOMERE_MAINTENANCE_IN_RESPONSE_TO_DNA_DAMAGE
Systematic name | M23589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that occur in response to the presence of critically short or damaged telomeres. [GOC:BHF, GOC:BHF_telomere, GOC:jbu, PMID:15279784]
Full description |

Standard name | GO_PROTEASOME_ASSEMBLY
Systematic name | M11207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a mature, active proteasome complex. [GOC:go_curators, PMID:10872471]
Full description |

Standard name | GO_ERYTHROCYTE_MATURATION
Systematic name | M13459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for an erythrocyte to attain its fully functional state. [GOC:devbiol, GOC:jl]
Full description |

Standard name | GO_SODIUM_INDEPENDENT_ORGANIC_ANION_TRANSPORT
Systematic name | M10192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed, sodium-independent, movement of organic anions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_CONTAINING_COMPLEX_ASSEMBLY
Systematic name | M13689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein complex assembly. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_CARBOHYDRATE_BIOSYNTHETIC_PROCESS
Systematic name | M14240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of carbohydrates. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_POTASSIUM_ION_TRANSPORT
Systematic name | M16600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of potassium ions (K+) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_POTASSIUM_ION_TRANSPORT
Systematic name | M12534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of potassium ions (K+) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_POTASSIUM_ION_TRANSPORT
Systematic name | M11600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of potassium ions (K+) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_ION_TRANSPORT
Systematic name | M15848
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of charged atoms or small charged molecules into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ION_TRANSPORT
Systematic name | M12749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of charged atoms or small charged molecules into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ION_TRANSPORT
Systematic name | M15775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of charged atoms or small charged molecules into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:jl]
Full description |

Standard name | GO_ANOIKIS
Systematic name | M23590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Apoptosis triggered by inadequate or inappropriate adherence to substrate e.g. after disruption of the interactions between normal epithelial cells and the extracellular matrix. [GOC:jl, http://www.copewithcytokines.de/]
Full description |

Standard name | GO_APOPTOTIC_CELL_CLEARANCE
Systematic name | M11346
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The recognition and removal of an apoptotic cell by a neighboring cell or by a phagocyte. [GOC:rk, PMID:14685684]
Full description |

Standard name | GO_RESPONSE_TO_ALKALOID
Systematic name | M12438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an alkaloid stimulus. Alkaloids are a large group of nitrogenous substances found in naturally in plants, many of which have extracts that are pharmacologically active. [GOC:jl]
Full description |

Standard name | GO_APICAL_JUNCTION_ASSEMBLY
Systematic name | M11005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of an apical junction, a functional unit located near the cell apex at the points of contact between epithelial cells composed of the tight junction, the zonula adherens junction and the desmosomes, by the aggregation, arrangement and bonding together of its constituents. [GOC:go_curators, PMID:10854689, PMID:14729475, PMID:15196556]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_DEGRANULATION
Systematic name | M15567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of leukocyte degranulation. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LEUKOCYTE_DEGRANULATION
Systematic name | M14646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the rate of leukocyte degranulation. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LEUKOCYTE_DEGRANULATION
Systematic name | M10766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of leukocyte degranulation. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MAST_CELL_DEGRANULATION
Systematic name | M23592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the rate of mast cell degranulation. [ISBN:0781735149]
Full description |

Standard name | GO_EOSINOPHIL_ACTIVATION
Systematic name | M23593
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a eosinophil resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_NEUTROPHIL_DEGRANULATION
Systematic name | M23594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of neutrophil degranulation. [ISBN:0781735149]
Full description |

Standard name | GO_NATURAL_KILLER_CELL_DEGRANULATION
Systematic name | M23595
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated exocytosis of secretory granules containing preformed mediators such as perforin and granzymes by a natural killer cell. [ISBN:0781735149]
Full description |

Standard name | GO_PROTEIN_TRANSPORT_TO_VACUOLE_INVOLVED_IN_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS_VIA_THE_MULTIVESICULAR_BODY_SORTING_PATHWAY
Systematic name | M34169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of directing proteins towards the vacuole that contributes to protein catabolism via the multivesicular body (MVB) pathway. [GOC:jl, PMID:11511343]
Full description |

Standard name | GO_RESPONSE_TO_DSRNA
Systematic name | M15192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a double-stranded RNA stimulus. [GOC:jl]
Full description |

Standard name | GO_ENUCLEATE_ERYTHROCYTE_DIFFERENTIATION
Systematic name | M23596
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a myeloid precursor cell acquires specialized features of an erythrocyte without a nucleus. An example of this process is found in Mus musculus. [GOC:go_curators]
Full description |

Standard name | GO_CD4_POSITIVE_ALPHA_BETA_T_CELL_DIFFERENTIATION
Systematic name | M29177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized T cell acquires specialized features of a mature CD4-positive, alpha-beta T cell. [CL:0000624, ISBN:0781735149]
Full description |

Standard name | GO_POSITIVE_T_CELL_SELECTION
Systematic name | M13180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of sparing immature T cells which react with self-MHC protein complexes with low affinity levels from apoptotic death. [ISBN:0781735149, PMID:12414722]
Full description |

Standard name | GO_CD4_POSITIVE_OR_CD8_POSITIVE_ALPHA_BETA_T_CELL_LINEAGE_COMMITMENT
Systematic name | M14195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an immature T cell commits to CD4-positive T cell lineage or the CD8-positive lineage of alpha-beta T cells. [ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_CD4_POSITIVE_ALPHA_BETA_T_CELL_DIFFERENTIATION
Systematic name | M23597
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of CD4-positive, alpha-beta T cell differentiation. [GOC:add, GOC:pr, ISBN:0781735149]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CD4_POSITIVE_ALPHA_BETA_T_CELL_DIFFERENTIATION
Systematic name | M12266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of CD4-positive, alpha-beta T cell differentiation. [GOC:add, GOC:pr, ISBN:0781735149]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CD4_POSITIVE_ALPHA_BETA_T_CELL_DIFFERENTIATION
Systematic name | M29178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of CD4-positive, alpha-beta T cell differentiation. [GOC:add, GOC:pr, ISBN:0781735149]
Full description |

Standard name | GO_CD8_POSITIVE_ALPHA_BETA_T_CELL_DIFFERENTIATION
Systematic name | M23599
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized T cell acquires specialized features of a mature CD8-positive, alpha-beta T cell. [ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_CD8_POSITIVE_ALPHA_BETA_T_CELL_DIFFERENTIATION
Systematic name | M23600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of CD8-positive, alpha-beta T cell differentiation. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MEMORY_T_CELL_DIFFERENTIATION
Systematic name | M23601
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of memory T cell differentiation. [ISBN:0781735149]
Full description |

Standard name | GO_NEGATIVE_T_CELL_SELECTION
Systematic name | M14209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of elimination of immature T cells which react strongly with self-antigens. [ISBN:0781735149, PMID:12414722]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_BINDING
Systematic name | M19355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of DNA binding. DNA binding is any process in which a gene product interacts selectively with DNA (deoxyribonucleic acid). [GOC:dph, GOC:jl, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_BINDING
Systematic name | M8840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the frequency, rate or extent of DNA binding. DNA binding is any process in which a gene product interacts selectively with DNA (deoxyribonucleic acid). [GOC:dph, GOC:jl, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_BINDING
Systematic name | M10370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein binding. [GOC:go_curators]
Full description |

Standard name | GO_CORTISOL_SECRETION
Systematic name | M34170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of cortisol, a steroid hormone that in humans is the major circulating hormone of the cortex, or outer layer, of the adrenal gland. [PMID:11027914]
Full description |

Standard name | GO_STEROID_HORMONE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M14771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by a steroid hormone binding to a receptor. [PMID:12606724]
Full description |

Standard name | GO_SKELETAL_MUSCLE_TISSUE_REGENERATION
Systematic name | M10415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regrowth of skeletal muscle tissue to repair injured or damaged muscle fibers in the postnatal stage. [GOC:ef, GOC:mtg_muscle, PMID:12021255, PMID:16607119]
Full description |

Standard name | GO_REGULATION_OF_MAP_KINASE_ACTIVITY
Systematic name | M14969
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of MAP kinase activity. [GOC:dph, GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MAP_KINASE_ACTIVITY
Systematic name | M15225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of MAP kinase activity. [GOC:dph, GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MAP_KINASE_ACTIVITY
Systematic name | M10128
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of MAP kinase activity. [GOC:dph, GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_MAPK_CASCADE
Systematic name | M10496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of signal transduction mediated by the MAP kinase (MAPK) cascade. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MAPK_CASCADE
Systematic name | M11738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of signal transduction mediated by the MAPKKK cascade. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MAPK_CASCADE
Systematic name | M11151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signal transduction mediated by the MAPK cascade. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SKELETAL_MUSCLE_TISSUE_REGENERATION
Systematic name | M23602
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increase the rate of skeletal muscle regeneration. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_SKELETAL_MUSCLE_TISSUE_REGENERATION
Systematic name | M23603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of skeletal muscle. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_BINDING_TRANSCRIPTION_FACTOR_ACTIVITY
Systematic name | M2649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the activity of a transcription factor, any factor involved in the initiation or regulation of transcription. [GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_PEPTIDE_HORMONE
Systematic name | M23605
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptide hormone stimulus. A peptide hormone is any of a class of peptides that are secreted into the blood stream and have endocrine functions in living animals. [PMID:11027914, PMID:15134857, Wikipedia:Peptide_hormone]
Full description |

Standard name | GO_RESPONSE_TO_CORTICOTROPIN_RELEASING_HORMONE
Systematic name | M23606
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a corticotropin-releasing hormone stimulus. Corticotropin-releasing hormone is a peptide hormone involved in the stress response. [PMID:11027914, PMID:15134857, Wikipedia:Corticotropin-releasing_hormone]
Full description |

Standard name | GO_REGULATION_OF_SECONDARY_METABOLIC_PROCESS
Systematic name | M15678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of secondary metabolism, the chemical reactions and pathways involving compounds that are not necessarily required for growth and maintenance of cells, and are often unique to a taxon. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_RESPIRATION
Systematic name | M15348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cellular respiration, the enzymatic release of energy from organic compounds. [GOC:jl]
Full description |

Standard name | GO_PROTON_TRANSPORTING_ATP_SYNTHASE_COMPLEX_ASSEMBLY
Systematic name | M23607
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a proton-transporting ATP synthase (also known as F-type ATPase), a two-sector ATPase found in the inner membrane of mitochondria and chloroplasts, and in bacterial plasma membranes. [GOC:jl, GOC:mah, http://www.mblab.gla.ac.uk/]
Full description |

Standard name | GO_REGULATION_OF_ATPASE_ACTIVITY
Systematic name | M14837
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate of ATP hydrolysis by an ATPase. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_GENERATION_OF_PRECURSOR_METABOLITES_AND_ENERGY
Systematic name | M15085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of precursor metabolites, substances from which energy is derived, and the processes involved in the liberation of energy from these substances. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_CARBOHYDRATE_CATABOLIC_PROCESS
Systematic name | M16356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of the chemical reactions and pathways resulting in the breakdown of carbohydrates. [GOC:mlg]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_CARBOHYDRATE_CATABOLIC_PROCESS
Systematic name | M23608
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of the chemical reactions and pathways resulting in the breakdown of carbohydrates, carried out by individual cells. [GOC:jl]
Full description |

Standard name | GO_PIGMENTATION
Systematic name | M12025
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The accumulation of pigment in an organism, tissue or cell, either by increased deposition or by increased number of cells. [GOC:jl]
Full description |

Standard name | GO_PIGMENT_ACCUMULATION
Systematic name | M16896
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation of coloring matter in a particular location in an organism, tissue or cell, occurring in response to some external stimulus. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_RNA_SPLICING
Systematic name | M16816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of RNA splicing, the process of removing sections of the primary RNA transcript to remove sequences not present in the mature form of the RNA and joining the remaining sections to form the mature form of the RNA. [GOC:jl]
Full description |

Standard name | GO_HISTONE_EXCHANGE
Systematic name | M12044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The replacement, within chromatin, of resident histones or histone subunits with alternative, sometimes variant, histones or subunits. [GOC:jl, PMID:11735001, PMID:15066277]
Full description |

Standard name | GO_RNA_STABILIZATION
Systematic name | M10818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Prevention of degradation of RNA molecules. [GOC:go_curators]
Full description |

Standard name | GO_PROTEIN_KINASE_B_SIGNALING
Systematic name | M13074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of reactions, mediated by the intracellular serine/threonine kinase protein kinase B (also called AKT), which occurs as a result of a single trigger reaction or compound. [GOC:bf, PMID:20517722]
Full description |

Standard name | GO_MUSCLE_ADAPTATION
Systematic name | M13109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which muscle adapts, with consequent modifications to structural and/or functional phenotypes, in response to a stimulus. Stimuli include contractile activity, loading conditions, substrate supply, and environmental factors. These adaptive events occur in both muscle fibers and associated structures (motoneurons and capillaries), and they involve alterations in regulatory mechanisms, contractile properties and metabolic capacities. [GOC:mtg_muscle, PMID:11181628, PMID:11449884, PMID:12605307]
Full description |

Standard name | GO_SKELETAL_MUSCLE_ADAPTATION
Systematic name | M10779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which skeletal muscles change their phenotypic profiles in response to altered functional demands and a variety of signals. [GOC:mtg_muscle, PMID:11181628, PMID:11449884, PMID:12605307]
Full description |

Standard name | GO_REGULATION_OF_MUSCLE_ADAPTATION
Systematic name | M16102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of muscle adaptation. [GOC:go_curators, GOC:mtg_muscle]
Full description |

Standard name | GO_MITOCHONDRIAL_DNA_REPAIR
Systematic name | M23610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of restoring mitochondrial DNA after damage. [PMID:12565799, PMID:15189144, PMID:16050976]
Full description |

Standard name | GO_REGULATION_OF_JUN_KINASE_ACTIVITY
Systematic name | M16363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of JUN kinase activity. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_JUN_KINASE_ACTIVITY
Systematic name | M15527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of JUN kinase activity. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_JUN_KINASE_ACTIVITY
Systematic name | M11419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of JUN kinase activity. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_DNA_DAMAGE_RESPONSE_SIGNAL_TRANSDUCTION_BY_P53_CLASS_MEDIATOR
Systematic name | M11797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the cascade of processes induced by the cell cycle regulator phosphoprotein p53, or an equivalent protein, in response to the detection of DNA damage. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_DAMAGE_RESPONSE_SIGNAL_TRANSDUCTION_BY_P53_CLASS_MEDIATOR
Systematic name | M10314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the rate of the cascade of processes induced by the cell cycle regulator phosphoprotein p53, or an equivalent protein, in response to the detection of DNA damage. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_DAMAGE_RESPONSE_SIGNAL_TRANSDUCTION_BY_P53_CLASS_MEDIATOR
Systematic name | M16832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the cascade of processes induced by the cell cycle regulator phosphoprotein p53, or an equivalent protein, in response to the detection of DNA damage. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEURON_APOPTOTIC_PROCESS
Systematic name | M10229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process in neurons. [GOC:go_curators, GOC:mtg_apoptosis]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEURON_APOPTOTIC_PROCESS
Systematic name | M16430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell death of neurons by apoptotic process. [GOC:go_curators, GOC:mtg_apoptosis]
Full description |

Standard name | GO_BLOOD_VESSEL_ENDOTHELIAL_CELL_MIGRATION
Systematic name | M12259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of an endothelial cell into the extracellular matrix in order to form new blood vessels during angiogenesis. [PMID:11166264]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BLOOD_VESSEL_ENDOTHELIAL_CELL_MIGRATION
Systematic name | M16505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the migration of the endothelial cells of blood vessels. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BLOOD_VESSEL_ENDOTHELIAL_CELL_MIGRATION
Systematic name | M10771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the migration of the endothelial cells of blood vessels. [GOC:go_curators]
Full description |

Standard name | GO_ENDOTHELIAL_CELL_MIGRATION
Systematic name | M7145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of an endothelial cell into the extracellular matrix to form an endothelium. [GOC:go_curators]
Full description |

Standard name | GO_PROTEIN_ACYLATION
Systematic name | M15586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of an acyl group, any group or radical of the form RCO- where R is an organic group, to a protein amino acid. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GTPASE_ACTIVITY
Systematic name | M23611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the activity of a GTPase. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_LIPID_KINASE_ACTIVITY
Systematic name | M13017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lipid kinase activity, the catalysis of the transfer of a phosphate group, usually from ATP, to a simple or complex lipid. [GOC:bf]
Full description |

Standard name | GO_REGULATION_OF_TRANSLATION_IN_RESPONSE_TO_STRESS
Systematic name | M10435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Modulation of the frequency, rate or extent of translation as a result of a stimulus indicating the organism is under stress. The stress is usually, but not necessarily, exogenous (e.g. temperature, humidity, ionizing radiation). [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_TRANSLATIONAL_INITIATION_IN_RESPONSE_TO_STRESS
Systematic name | M14939
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of translation initiation, as a result of a stimulus indicating the organism is under stress. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_INSULIN_LIKE_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of insulin-like growth factor receptor signaling. [GOC:bf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INSULIN_LIKE_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M16863
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of insulin-like growth factor receptor signaling. [GOC:bf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INSULIN_LIKE_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of insulin-like growth factor receptor signaling. [GOC:bf]
Full description |

Standard name | GO_MAINTENANCE_OF_DNA_REPEAT_ELEMENTS
Systematic name | M23613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in sustaining the fidelity and copy number of DNA repeat elements. [GOC:jl]
Full description |

Standard name | GO_PEROXISOMAL_TRANSPORT
Systematic name | M14575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Transport of substances into, out of or within a peroxisome, a small, membrane-bounded organelle that uses dioxygen (O2) to oxidize organic molecules. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_RESPIRATORY_GASEOUS_EXCHANGE
Systematic name | M16358
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the process of gaseous exchange between an organism and its environment. [GOC:jl]
Full description |

Standard name | GO_EAR_DEVELOPMENT
Systematic name | M12465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the ear over time, from its formation to the mature structure. The ear is the sense organ in vertebrates that is specialized for the detection of sound, and the maintenance of balance. Includes the outer ear and middle ear, which collect and transmit sound waves; and the inner ear, which contains the organs of balance and (except in fish) hearing. Also includes the pinna, the visible part of the outer ear, present in some mammals. [GOC:jl, ISBN:0192801023]
Full description |

Standard name | GO_NOSE_DEVELOPMENT
Systematic name | M12568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the nose over time, from its formation to the mature structure. The nose is the specialized structure of the face that serves as the organ of the sense of smell and as part of the respiratory system. Includes the nasi externus (external nose) and cavitas nasi (nasal cavity). [GOC:jl]
Full description |

Standard name | GO_TONGUE_DEVELOPMENT
Systematic name | M11649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the tongue over time, from its formation to the mature structure. The tongue is the movable, muscular organ on the floor of the mouth of most vertebrates, in many other mammals is the principal organ of taste, aids in the prehension of food, in swallowing, and in modifying the voice as in speech. [GOC:jl, UBERON:0001723]
Full description |

Standard name | GO_TONGUE_MORPHOGENESIS
Systematic name | M23614
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the tongue are generated and organized. The tongue is the movable, muscular organ on the floor of the mouth of most vertebrates, in man other mammals is the principal organ of taste, aids in the prehension of food, in swallowing, and in modifying the voice as in speech. [GOC:jl, UBERON:0001723]
Full description |

Standard name | GO_SKIN_DEVELOPMENT
Systematic name | M15889
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the skin over time, from its formation to the mature structure. The skin is the external membranous integument of an animal. In vertebrates the skin generally consists of two layers, an outer nonsensitive and nonvascular epidermis (cuticle or skarfskin) composed of cells which are constantly growing and multiplying in the deeper, and being thrown off in the superficial layers, as well as an inner vascular dermis (cutis, corium or true skin) composed mostly of connective tissue. [GOC:jl, UBERON:0002097]
Full description |

Standard name | GO_SKIN_MORPHOGENESIS
Systematic name | M23615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the skin are generated and organized. The skin is the external membranous integument of an animal. In vertebrates the skin generally consists of two layers, an outer nonsensitive and nonvascular epidermis (cuticle or skarfskin) composed of cells which are constantly growing and multiplying in the deeper, and being thrown off in the superficial layers, as well as an inner, sensitive and vascular dermis (cutis, corium or true skin) composed mostly of connective tissue. [GOC:jl, UBERON:0002097]
Full description |

Standard name | GO_CELLULAR_AMIDE_METABOLIC_PROCESS
Systematic name | M12925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving an amide, any derivative of an oxoacid in which an acidic hydroxy group has been replaced by an amino or substituted amino group, as carried out by individual cells. [GOC:curators]
Full description |

Standard name | GO_AMIDE_BIOSYNTHETIC_PROCESS
Systematic name | M13137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of an amide, any derivative of an oxoacid in which an acidic hydroxy group has been replaced by an amino or substituted amino group. [GOC:curators]
Full description |

Standard name | GO_ASTROCYTE_CELL_MIGRATION
Systematic name | M23616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of an astrocyte, a class of large neuroglial (macroglial) cells in the central nervous system, the largest and most numerous neuroglial cells in the brain and spinal cord. [CL:0000127, GOC:go_curators]
Full description |

Standard name | GO_KERATINOCYTE_PROLIFERATION
Systematic name | M10787
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of keratinocytes, resulting in the expansion of a cell population. Keratinocytes are epidermal cells which synthesize keratin and undergo a characteristic change as they move upward from the basal layers of the epidermis to the cornified (horny) layer of the skin. [CL:0000311]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_FROM_RNA_POLYMERASE_II_PROMOTER_IN_RESPONSE_TO_OXIDATIVE_STRESS
Systematic name | M23617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Modulation of the frequency, rate or extent of transcription from an RNA polymerase II promoter as a result of a stimulus indicating the organism is under oxidative stress, a state often resulting from exposure to high levels of reactive oxygen species, e.g. superoxide anions, hydrogen peroxide (H2O2), and hydroxyl radicals. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_DNA_TEMPLATED_TRANSCRIPTION_IN_RESPONSE_TO_STRESS
Systematic name | M14959
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Modulation of the frequency, rate or extent of transcription from a DNA template as a result of a stimulus indicating the organism is under stress. The stress is usually, but not necessarily, exogenous (e.g. temperature, humidity, ionizing radiation). [GOC:jl, GOC:txnOH]
Full description |

Standard name | GO_CELLULAR_PROTEIN_COMPLEX_DISASSEMBLY
Systematic name | M10303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disaggregation of a protein complex into its constituent components, occurring at the level of an individual cell. Protein complexes may have other associated non-protein prosthetic groups, such as nucleic acids, metal ions or carbohydrate groups. [GOC:jl]
Full description |

Standard name | GO_RESPONSE_TO_ESTROGEN
Systematic name | M13475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of stimulus by an estrogen, C18 steroid hormones that can stimulate the development of female sexual characteristics. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_NCRNA_3_END_PROCESSING
Systematic name | M11110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in forming the mature 3' end of a non-coding RNA molecule. [GOC:jl]
Full description |

Standard name | GO_RNA_POLYADENYLATION
Systematic name | M15034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The enzymatic addition of a sequence of adenylyl residues at the 3' end of an RNA molecule. [GOC:jl]
Full description |

Standard name | GO_MODIFICATION_DEPENDENT_MACROMOLECULE_CATABOLIC_PROCESS
Systematic name | M23618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a macromolecule, initiated by covalent modification of the target molecule. [GOC:jl]
Full description |

Standard name | GO_POLYADENYLATION_DEPENDENT_RNA_CATABOLIC_PROCESS
Systematic name | M23619
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of an RNA molecule, initiated by the enzymatic addition of a sequence of adenylyl residues (polyadenylation) at the 3'-end of the target RNA. [GOC:dgf, GOC:jl, GOC:krc]
Full description |

Standard name | GO_INOSITOL_PHOSPHATE_METABOLIC_PROCESS
Systematic name | M10931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving inositol phosphate, 1,2,3,4,5,6-cyclohexanehexol, with one or more phosphate groups attached. [GOC:jl]
Full description |

Standard name | GO_DICARBOXYLIC_ACID_METABOLIC_PROCESS
Systematic name | M11851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving dicarboxylic acids, any organic acid containing two carboxyl (COOH) groups or anions (COO-). [ISBN:0198506732]
Full description |

Standard name | GO_DICARBOXYLIC_ACID_CATABOLIC_PROCESS
Systematic name | M15883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of dicarboxylic acids, any organic acid containing two carboxyl (-COOH) groups. [ISBN:0198506732]
Full description |

Standard name | GO_DICARBOXYLIC_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M12548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of dicarboxylic acids, any organic acid containing two carboxyl (-COOH) groups. [ISBN:0198506732]
Full description |

Standard name | GO_LINOLEIC_ACID_METABOLIC_PROCESS
Systematic name | M15245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving linoleic acid, an unsaturated omega-6 fatty acid that has the molecular formula C18H32O2. [Wikipedia:Linoleic_Acid]
Full description |

Standard name | GO_ENGULFMENT_OF_APOPTOTIC_CELL
Systematic name | M23620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of the apoptotic cell by phagocytosis, by a neighboring cell or by a phagocyte. [GOC:rk, PMID:15536015]
Full description |

Standard name | GO_MITOCHONDRIAL_FRAGMENTATION_INVOLVED_IN_APOPTOTIC_PROCESS
Systematic name | M23621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in the morphology of the mitochondria in an apoptotic cell from a highly branched network to a fragmented vesicular form. [GOC:mtg_apoptosis, GOC:rk, PMID:12867994]
Full description |

Standard name | GO_RECOGNITION_OF_APOPTOTIC_CELL
Systematic name | M23622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a cell interprets signals (in the form of specific proteins and lipids) on the surface of a dying cell which it will engulf and remove by phagocytosis. [GOC:rk, PMID:15536015]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHOPROTEIN_PHOSPHATASE_ACTIVITY
Systematic name | M15004
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of phosphoprotein phosphatase activity, the catalysis of the hydrolysis of phosphate from a phosphoprotein. [GOC:jp, PMID:11724821]
Full description |

Standard name | GO_POST_TRANSLATIONAL_PROTEIN_MODIFICATION
Systematic name | M13855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of covalently altering one or more amino acids in a protein after the protein has been completely translated and released from the ribosome. [GOC:jsg]
Full description |

Standard name | GO_REVERSE_CHOLESTEROL_TRANSPORT
Systematic name | M15088
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of peripheral cell cholesterol, cholest-5-en-3-beta-ol, towards the liver for catabolism. [GOC:ecd, PMID:7751809]
Full description |

Standard name | GO_DEDIFFERENTIATION
Systematic name | M23623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a specialized structure (cell, tissue or organ) loses structural or functional features that characterize it in the mature organism, or some other relatively stable phase of the organism's life history. Under certain conditions, these structures can revert back to the features of their ancestors. [GOC:dph, GOC:pg]
Full description |

Standard name | GO_REGULATION_OF_MULTI_ORGANISM_PROCESS
Systematic name | M15005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a multi-organism process, a process in which an organism has an effect on another organism of the same or different species. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MULTI_ORGANISM_PROCESS
Systematic name | M15324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a multi-organism process, a process in which an organism has an effect on another organism of the same or different species. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MULTI_ORGANISM_PROCESS
Systematic name | M15994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of a multi-organism process, a process in which an organism has an effect on another organism of the same or different species. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_SYMBIOTIC_PROCESS
Systematic name | M12896
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of symbiosis, an interaction between two organisms living together in more or less intimate association. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_BY_HOST_OF_VIRAL_TRANSCRIPTION
Systematic name | M11284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a host organism stops, prevents, or reduces the frequency, rate or extent of viral transcription. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_BY_HOST_OF_VIRAL_TRANSCRIPTION
Systematic name | M10847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a host organism activates or increases the frequency, rate or extent of viral transcription, the synthesis of either RNA on a template of DNA or DNA on a template of RNA. [GOC:jl]
Full description |

Standard name | GO_OSSIFICATION_INVOLVED_IN_BONE_REMODELING
Systematic name | M29180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation or growth of bone or of a bony substance, or the conversion of fibrous tissue or of cartilage into bone, involved in response to injury or other physical, physiological or environmental stress stimuli. [GO_REF:0000034, GOC:mtg_mpo]
Full description |

Standard name | GO_PROTEIN_CONTAINING_COMPLEX_SUBUNIT_ORGANIZATION
Systematic name | M34171
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which macromolecules aggregate, disaggregate, or are modified, resulting in the formation, disassembly, or alteration of a protein complex. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CAMP_MEDIATED_SIGNALING
Systematic name | M13467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which modulates the frequency, rate or extent of cAMP-mediated signaling, a series of molecular signals in which a cell uses cyclic AMP to convert an extracellular signal into a response. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CAMP_MEDIATED_SIGNALING
Systematic name | M16526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which activates, maintains or increases the frequency, rate or extent of cAMP-mediated signaling, a series of molecular signals in which a cell uses cyclic AMP to convert an extracellular signal into a response. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CAMP_MEDIATED_SIGNALING
Systematic name | M23624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which stops, prevents, or reduces the frequency, rate or extent of cAMP-mediated signaling, a series of molecular signals in which a cell uses cyclic AMP to convert an extracellular signal into a response. [GOC:jl]
Full description |

Standard name | GO_CELLULAR_COMPONENT_MAINTENANCE
Systematic name | M11267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The organization process that preserves a cellular component in a stable functional or structural state. [GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_HISTONE_H3_ACETYLATION
Systematic name | M16197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the addition of an acetyl group. [GOC:jl]
Full description |

Standard name | GO_HISTONE_H4_ACETYLATION
Systematic name | M16029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H4 by the addition of an acetyl group. [GOC:jl]
Full description |

Standard name | GO_HISTONE_H2A_ACETYLATION
Systematic name | M14695
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H2A by the addition of an acetyl group. [GOC:jl]
Full description |

Standard name | GO_HISTONE_H3_K9_ACETYLATION
Systematic name | M23625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the addition of an acetyl group to a lysine residue at position 9 of the histone. [GOC:jl]
Full description |

Standard name | GO_HISTONE_H3_K23_ACETYLATION
Systematic name | M34172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the addition of an acetyl group to a lysine residue at position 23 of the histone. [GOC:jl]
Full description |

Standard name | GO_HISTONE_H4_K5_ACETYLATION
Systematic name | M23626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H4 by the addition of an acetyl group to a lysine residue at position 5 of the histone. [GOC:jl]
Full description |

Standard name | GO_HISTONE_H4_K12_ACETYLATION
Systematic name | M23627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H4 by the addition of an acetyl group to a lysine residue at position 12 of the histone. [GOC:jl]
Full description |

Standard name | GO_HISTONE_H4_K16_ACETYLATION
Systematic name | M15131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H4 by the addition of an acetyl group to a lysine residue at position 16 of the histone. [GOC:jl]
Full description |

Standard name | GO_HISTONE_H4_R3_METHYLATION
Systematic name | M23628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H4 by addition of a methyl group to arginine at position 3 of the histone. [GOC:mah]
Full description |

Standard name | GO_HISTONE_H3_S10_PHOSPHORYLATION
Systematic name | M23629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the addition of an phosphate group to a serine residue at position 10 of the histone. [GOC:jl]
Full description |

Standard name | GO_MODULATION_BY_SYMBIONT_OF_HOST_PROCESS
Systematic name | M12980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a symbiont organism effects a change in the structure or processes of its host organism. [GOC:cc]
Full description |

Standard name | GO_REGULATION_OF_DNA_METHYLATION
Systematic name | M13321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the covalent transfer of a methyl group to either N-6 of adenine or C-5 or N-4 of cytosine. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_SYSTEM_PROCESS
Systematic name | M14237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a system process, a multicellular organismal process carried out by any of the organs or tissues in an organ system. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_DIGESTIVE_SYSTEM_PROCESS
Systematic name | M14082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a digestive system process, a physical, chemical, or biochemical process carried out by living organisms to break down ingested nutrients into components that may be easily absorbed and directed into metabolism. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_ENDOCRINE_PROCESS
Systematic name | M12886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of an endocrine process, a process involving the secretion of or response to endocrine hormones. An endocrine hormone is a hormone released into the circulatory system. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_EXCRETION
Systematic name | M12879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of excretion, the elimination by an organism of the waste products that arise as a result of metabolic activity. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_RESPIRATORY_SYSTEM_PROCESS
Systematic name | M10920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a respiratory system process, an organ system process carried out by any of the organs or tissues of the respiratory system. [GOC:jl]
Full description |

Standard name | GO_MODULATION_BY_SYMBIONT_OF_HOST_CELLULAR_PROCESS
Systematic name | M11888
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a symbiont organism modulates the frequency, rate or extent of a cellular process, any process that is carried out at the cellular level, but not necessarily restricted to a single cell, in its host organism. [MITRE:tk]
Full description |

Standard name | GO_REGULATION_OF_ANION_TRANSPORT
Systematic name | M16202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of anions, atoms or small molecules with a net negative charge into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_COMPONENT_BIOGENESIS
Systematic name | M11589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cellular component biogenesis, a process that results in the biosynthesis of constituent macromolecules, assembly, and arrangement of constituent parts of a cellular component. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_VACUOLE_ORGANIZATION
Systematic name | M11432
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of a vacuole. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_COMPONENT_BIOGENESIS
Systematic name | M12404
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cellular component biogenesis, a process that results in the biosynthesis of constituent macromolecules, assembly, and arrangement of constituent parts of a cellular component. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VACUOLE_ORGANIZATION
Systematic name | M10804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of a vacuole. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_MEMBRANE_BIOGENESIS
Systematic name | M10667
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the biosynthesis of constituent macromolecules, assembly, and arrangement of constituent parts of a membrane. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MOLECULAR_FUNCTION
Systematic name | M13509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate or extent of a molecular function, an elemental biological activity occurring at the molecular level, such as catalysis or binding. [GO:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MOLECULAR_FUNCTION
Systematic name | M12495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of a molecular function, an elemental biological activity occurring at the molecular level, such as catalysis or binding. [GO:jl]
Full description |

Standard name | GO_HISTONE_H3_K14_ACETYLATION
Systematic name | M23632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the addition of an acetyl group to a lysine residue at position 14 of the histone. [GOC:jl, GOC:lb, PMID:17194708]
Full description |

Standard name | GO_LIPID_DIGESTION
Systematic name | M11799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The whole of the physical, chemical, and biochemical processes carried out by living organisms to break down ingested lipids into components that may be easily absorbed and directed into metabolism. [GOC:go_curators]
Full description |

Standard name | GO_CELLULAR_LIPID_CATABOLIC_PROCESS
Systematic name | M5981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of lipids, as carried out by individual cells. [GOC:jl]
Full description |

Standard name | GO_POLYSACCHARIDE_DIGESTION
Systematic name | M23633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The whole of the physical, chemical, and biochemical processes carried out by living organisms to break down ingested polysaccharides into components that may be easily absorbed and directed into metabolism. [GOC:go_curators]
Full description |

Standard name | GO_CELLULAR_POLYSACCHARIDE_CATABOLIC_PROCESS
Systematic name | M29181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of polysaccharides, polymers of many (typically more than 10) monosaccharide residues linked glycosidically, as carried out by individual cells. [GOC:jl]
Full description |

Standard name | GO_CELLULAR_LIPID_METABOLIC_PROCESS
Systematic name | M14398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving lipids, as carried out by individual cells. [GOC:jl]
Full description |

Standard name | GO_CELLULAR_PROTEIN_CATABOLIC_PROCESS
Systematic name | M13306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a protein by individual cells. [GOC:jl]
Full description |

Standard name | GO_CELLULAR_CARBOHYDRATE_METABOLIC_PROCESS
Systematic name | M5309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving carbohydrates, any of a group of organic compounds based of the general formula Cx(H2O)y, as carried out by individual cells. [GOC:jl]
Full description |

Standard name | GO_CELLULAR_MACROMOLECULE_CATABOLIC_PROCESS
Systematic name | M10655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a macromolecule, any large molecule including proteins, nucleic acids and carbohydrates, as carried out by individual cells. [GOC:jl]
Full description |

Standard name | GO_CELLULAR_NITROGEN_COMPOUND_CATABOLIC_PROCESS
Systematic name | M11369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of organic and inorganic nitrogenous compounds. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_SULFUR_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M12583
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of compounds that contain sulfur, such as the amino acids methionine and cysteine or the tripeptide glutathione. [GOC:jl]
Full description |

Standard name | GO_SULFUR_COMPOUND_CATABOLIC_PROCESS
Systematic name | M12614
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of compounds that contain sulfur, such as the amino acids methionine and cysteine or the tripeptide glutathione. [GOC:jl]
Full description |

Standard name | GO_CELLULAR_CARBOHYDRATE_CATABOLIC_PROCESS
Systematic name | M15610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of carbohydrates, any of a group of organic compounds based of the general formula Cx(H2O)y, as carried out by individual cells. [GOC:jl]
Full description |

Standard name | GO_SMALL_MOLECULE_CATABOLIC_PROCESS
Systematic name | M14245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of small molecules, any low molecular weight, monomeric, non-encoded molecule. [GOC:curators, GOC:vw]
Full description |

Standard name | GO_SMALL_MOLECULE_BIOSYNTHETIC_PROCESS
Systematic name | M12217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of small molecules, any low molecular weight, monomeric, non-encoded molecule. [GOC:curators, GOC:pde, GOC:vw]
Full description |

Standard name | GO_PROTEIN_K27_LINKED_UBIQUITINATION
Systematic name | M23636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein ubiquitination process in which a polymer of ubiquitin, formed by linkages between lysine residues at position 27 of the ubiquitin monomers, is added to a protein. [PMID:19345326]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_LEPTIN_STIMULUS
Systematic name | M15436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a leptin stimulus. Leptin is a hormone manufactured primarily in the adipocytes of white adipose tissue, and the level of circulating leptin is directly proportional to the total amount of fat in the body. It plays a key role in regulating energy intake and energy expenditure, including appetite and metabolism. [GOC:yaf]
Full description |

Standard name | GO_RESPONSE_TO_LEPTIN
Systematic name | M16799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a leptin stimulus. Leptin is a hormone manufactured primarily in the adipocytes of white adipose tissue, and the level of circulating leptin is directly proportional to the total amount of fat in the body. It plays a key role in regulating energy intake and energy expenditure, including appetite and metabolism]. [GOC:yaf]
Full description |

Standard name | GO_CELL_CELL_ADHESION_MEDIATED_BY_CADHERIN
Systematic name | M23637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of one cell to another cell via a cadherin, transmembrane proteins having repeating extracellular calcium ion binding domains. [GOC:ha, GOC:hjd, GOC:jl, PMID:10923970]
Full description |

Standard name | GO_CANONICAL_WNT_SIGNALING_PATHWAY_INVOLVED_IN_OSTEOBLAST_DIFFERENTIATION
Systematic name | M23638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of a Wnt protein to a frizzled family receptor on the surface of the target cell, followed by propagation of the signal via beta-catenin, and ending with a change in transcription of target genes involved in osteoblast differentiation. [GOC:BHF, GOC:jl]
Full description |

Standard name | GO_CANONICAL_WNT_SIGNALING_PATHWAY_INVOLVED_IN_REGULATION_OF_CELL_PROLIFERATION
Systematic name | M23639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of a Wnt protein to a frizzled family receptor on the surface of the target cell, followed by propagation of the signal via beta-catenin, and ending with a change in transcription of target genes that contributes to modulating the rate or frequency of cell proliferation. [GOC:BHF, GOC:jl]
Full description |

Standard name | GO_SODIUM_DEPENDENT_PHOSPHATE_TRANSPORT
Systematic name | M23640
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of phosphate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore, by a mechanism dependent upon sodium ions. [GOC:BHF, GOC:jl]
Full description |

Standard name | GO_TYPE_B_PANCREATIC_CELL_PROLIFERATION
Systematic name | M23641
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of pancreatic B cells, resulting in the expansion of an pancreatic B cell population. Pancreatic B cell are cells of the pancreas that secrete insulin. [GOC:jl, GOC:yaf]
Full description |

Standard name | GO_FIBROBLAST_APOPTOTIC_PROCESS
Systematic name | M23642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a fibroblast, a connective tissue cell which secretes an extracellular matrix rich in collagen and other macromolecules. [CL:0000057, GOC:jl, GOC:mtg_apoptosis, GOC:yaf]
Full description |

Standard name | GO_MACROPINOCYTOSIS
Systematic name | M23643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An endocytosis process that results in the uptake of liquid material by cells from their external environment by the 'ruffling' of the cell membrane to form heterogeneously sized intracellular vesicles called macropinosomes, which can be up to 5 micrometers in size. [PMID:14732047]
Full description |

Standard name | GO_MODULATION_OF_MOLECULAR_FUNCTION_IN_OTHER_ORGANISM
Systematic name | M23644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an organism effects a change in the function of proteins in a second organism. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MOLECULAR_FUNCTION_IN_OTHER_ORGANISM
Systematic name | M29183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organism stops, prevents or reduces the frequency, rate or extent of the function of proteins in a second organism. [GOC:jl]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CYTOSKELETON
Systematic name | M10273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within the cytoskeleton. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_KINASE_ACTIVITY_BY_REGULATION_OF_PROTEIN_PHOSPHORYLATION
Systematic name | M23645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The stopping, prevention, or reduction in frequency, rate or extent of protein kinase activity as a result of regulating the phosphorylation status of that protein kinase. [GOC:jl]
Full description |

Standard name | GO_SYMBIOTIC_PROCESS
Systematic name | M34173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process carried out by gene products in an organism that enable the organism to engage in a symbiotic relationship, a more or less intimate association, with another organism. The various forms of symbiosis include parasitism, in which the association is disadvantageous or destructive to one of the organisms; mutualism, in which the association is advantageous, or often necessary to one or both and not harmful to either; and commensalism, in which one member of the association benefits while the other is not affected. However, mutualism, parasitism, and commensalism are often not discrete categories of interactions and should rather be perceived as a continuum of interaction ranging from parasitism to mutualism. In fact, the direction of a symbiotic interaction can change during the lifetime of the symbionts due to developmental changes as well as changes in the biotic/abiotic environment in which the interaction occurs. Microscopic symbionts are often referred to as endosymbionts. [GOC:cc, https://study.com/academy/lesson/symbiont-definition-lesson-quiz.html]
Full description |

Standard name | GO_ADHESION_OF_SYMBIONT_TO_HOST
Systematic name | M23646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a symbiont to its host via adhesion molecules, general stickiness etc., either directly or indirectly. The host is defined as the larger of the organisms involved in a symbiotic interaction. [GOC:bf, GOC:cc, GOC:dos, GOC:jl]
Full description |

Standard name | GO_ENTRY_INTO_HOST
Systematic name | M29184
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Entry of a symbiont into the body, tissues, or cells of a host organism as part of the symbiont life cycle. The host is defined as the larger of the organisms involved in a symbiotic interaction. [GOC:vw]
Full description |

Standard name | GO_TRANSLOCATION_OF_MOLECULES_INTO_HOST
Systematic name | M23647
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a molecule(s) produced by an organism to a location inside its host organism. The host is defined as the larger of the organisms involved in a symbiotic interaction. [GOC:cc]
Full description |

Standard name | GO_MOTILE_CILIUM_ASSEMBLY
Systematic name | M15070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a motile cilium. [GO_REF:0000079, GOC:cilia, GOC:krc, GOC:TermGenie, PMID:19776033, PMID:21129373, ZFIN:dsf]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRIAL_MRNA_STABILITY
Systematic name | M34174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the propensity of mitochondrial mRNA molecules to degradation. Includes processes that both stabilize and destabilize mitochondrial mRNAs. [GOC:al, GOC:jl]
Full description |

Standard name | GO_MODULATION_OF_PROGRAMMED_CELL_DEATH_IN_OTHER_ORGANISM
Systematic name | M23649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which an organism modulates the frequency, rate or extent of programmed cell death in a second organism. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_CIRCULATING_FIBRINOGEN_LEVELS
Systematic name | M23650
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the quantity of fibrinogen circulating in the bloodstream. [GOC:jl]
Full description |

Standard name | GO_NLRP3_INFLAMMASOME_COMPLEX_ASSEMBLY
Systematic name | M23652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form the NLRP3 inflammasome complex, occurring at the level of an individual cell. [GOC:jl, PMID:21048113]
Full description |

Standard name | GO_SECONDARY_METABOLITE_BIOSYNTHETIC_PROCESS
Systematic name | M10270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of secondary metabolites, the compounds that are not necessarily required for growth and maintenance of cells, and are often unique to a taxon. [GOC:jl]
Full description |

Standard name | GO_RELAXATION_OF_SMOOTH_MUSCLE
Systematic name | M23653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which the extent of smooth muscle contraction is reduced. Smooth muscle differs from striated muscle in the much higher actin/myosin ratio, the absence of conspicuous sarcomeres and the ability to contract to a much smaller fraction of its resting length. [GOC:jl]
Full description |

Standard name | GO_2FE_2S_CLUSTER_ASSEMBLY
Systematic name | M23654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The incorporation of two iron atoms and two sulfur atoms into an iron-sulfur cluster. [GOC:jl, GOC:mengo_curators, GOC:pde, GOC:tt, GOC:vw, PMID:15952888]
Full description |

Standard name | GO_HISTONE_H3_K4_DIMETHYLATION
Systematic name | M34175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of two methyl groups to lysine at position 4 of the histone. [GOC:jl, PMID:21875999]
Full description |

Standard name | GO_ADHESION_OF_SYMBIONT_TO_HOST_CELL
Systematic name | M23655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a symbiont to a host cell via adhesion molecules, general stickiness etc., either directly or indirectly. [GOC:jl]
Full description |

Standard name | GO_TOOTH_ERUPTION
Systematic name | M23656
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The tooth development process in which the teeth enter the mouth and become visible. [Wikipedia:Tooth_eruption]
Full description |

Standard name | GO_MULTI_MULTICELLULAR_ORGANISM_PROCESS
Systematic name | M14200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A multicellular organism process which involves another multicellular organism of the same or different species. [GOC:jl]
Full description |

Standard name | GO_DNA_METHYLATION_OR_DEMETHYLATION
Systematic name | M14518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of adding or removing a methyl group from one or more nucleotides within an DNA molecule. [GOC:jl]
Full description |

Standard name | GO_PROTEIN_TRANSMEMBRANE_IMPORT_INTO_INTRACELLULAR_ORGANELLE
Systematic name | M23657
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of proteins into an intracellular organelle, across a membrane. [GOC:jl]
Full description |

Standard name | GO_MULTI_ORGANISM_CELLULAR_PROCESS
Systematic name | M23658
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that is carried out at the cellular level which involves another organism of the same or different species. [GOC:jl]
Full description |

Standard name | GO_CELL_CYCLE_PHASE_TRANSITION
Systematic name | M11012
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process by which a cell commits to entering the next cell cycle phase. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_MEIOTIC_CELL_CYCLE_PHASE_TRANSITION
Systematic name | M23659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process by which a cell commits to entering the next meiotic cell cycle phase. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_MITOTIC_DNA_INTEGRITY_CHECKPOINT
Systematic name | M13712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A mitotic cell cycle process that controls cell cycle progression in response to changes in DNA structure by monitoring the integrity of the DNA. The DNA integrity checkpoint begins with detection of DNA damage, defects in DNA structure or DNA replication, and ends with signal transduction. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_CILIUM_ORGANIZATION
Systematic name | M13049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a cilium, a specialized eukaryotic organelle that consists of a filiform extrusion of the cell surface. Each cilium is bounded by an extrusion of the cytoplasmic membrane, and contains a regular longitudinal array of microtubules, anchored basally in a centriole. [GOC:cilia, GOC:jl]
Full description |

Standard name | GO_METAPHASE_ANAPHASE_TRANSITION_OF_CELL_CYCLE
Systematic name | M23660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which a cell progresses from metaphase to anaphase as part of the cell cycle. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_CELL_CYCLE_DNA_REPLICATION
Systematic name | M10697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The DNA-dependent DNA replication that takes place as part of the cell cycle. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_MODULATION_BY_HOST_OF_VIRAL_PROCESS
Systematic name | M11671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a host organism modulates the frequency, rate or extent of any of a process being mediated by a virus with which it is infected. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_BY_HOST_OF_VIRAL_PROCESS
Systematic name | M23662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a host organism stops, prevents or reduces the frequency, rate or extent of a process being mediated by a virus with which it is infected. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_BY_HOST_OF_VIRAL_PROCESS
Systematic name | M14060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a host organism activates or increases the frequency, rate or extent of the release of a process being mediated by a virus with which it is infected. [GOC:jl]
Full description |

Standard name | GO_MULTI_ORGANISM_MEMBRANE_FUSION
Systematic name | M23663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The membrane organization process that joins two lipid bilayers to form a single membrane, involving more than one organism. [GOC:jl]
Full description |

Standard name | GO_MULTI_ORGANISM_MEMBRANE_ORGANIZATION
Systematic name | M16025
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process which results in the assembly, arrangement of constituent parts, or disassembly of a membrane, involving more than one organism. [GOC:jl]
Full description |

Standard name | GO_AUTOPHAGY_OF_NUCLEUS
Systematic name | M23664
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A form of autophagy, by which damaged or non-essential parts of the nucleus, or even an entire nucleus is degraded. [GOC:autophagy, GOC:jl, PMID:24013549]
Full description |

Standard name | GO_LATE_NUCLEOPHAGY
Systematic name | M34176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A type of nucleophagy, distinct from piecemeal microautophagy of the nucleus (PNM) where the nuclear material is delivered to the vacuole/lysosome for breakdown and recycling later than observed for PNM. [GOC:dgf, GOC:jl, PMID:22768199]
Full description |

Standard name | GO_G_QUADRUPLEX_DNA_UNWINDING
Systematic name | M23665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process by which G-quadruplex (also known as G4) DNA, which is a four-stranded DNA structure held together by guanine base pairing, is unwound or 'melted'. [GOC:jl, GOC:se, PMID:23657261]
Full description |

Standard name | GO_MITOTIC_G2_M_TRANSITION_CHECKPOINT
Systematic name | M11745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle checkpoint that detects and negatively regulates progression from G2 to M phase as part of a mitotic cell cycle. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_MITOTIC_G1_S_TRANSITION_CHECKPOINT
Systematic name | M34177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle checkpoint that detects and negatively regulates progression from G1 to S phase as part of a mitotic cell cycle. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_MODULATION_BY_HOST_OF_VIRAL_GENOME_REPLICATION
Systematic name | M23666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a host organism modulates the frequency, rate or extent of viral genome replication. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_BY_HOST_OF_VIRAL_GENOME_REPLICATION
Systematic name | M23667
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a host organism stops, prevents or reduces the frequency, rate or extent of viral genome replication. [GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_BY_HOST_OF_VIRAL_GENOME_REPLICATION
Systematic name | M23668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a host organism activates or increases the frequency, rate or extent of viral genome replication. [GOC:jl]
Full description |

Standard name | GO_ACTOMYOSIN_CONTRACTILE_RING_ORGANIZATION
Systematic name | M23669
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process which results in the assembly, arrangement of constituent parts, or disassembly of an actomyosin contractile ring. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_CELL_CYCLE_G2_M_PHASE_TRANSITION
Systematic name | M14052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process by which a cell in G2 phase commits to M phase. [GOC:jl, GOC:mtg_cell_cycle]
Full description |

Standard name | GO_CELL_CYCLE_G1_S_PHASE_TRANSITION
Systematic name | M13413
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process by which a cell in G1 phase commits to S phase. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_BIOLOGICAL_PHASE
Systematic name | M23670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A distinct period or stage in a biological process or cycle. [GOC:jl]
Full description |

Standard name | GO_ESTROUS_CYCLE
Systematic name | M16851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A type of ovulation cycle, which occurs in most mammalian therian females, where the endometrium is resorbed if pregnancy does not occur. [GOC:jl, Wikipedia:Estrous_cycle]
Full description |

Standard name | GO_HAIR_CYCLE_PHASE
Systematic name | M34178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cyclical periods of growth (anagen), regression (catagen), quiescence (telogen), and shedding (exogen) in the life of a hair; one of the collection or mass of filaments growing from the skin of an animal, and forming a covering for a part of the head or for any part or the whole of the body. [GOC:jl]
Full description |

Standard name | GO_PLASMA_MEMBRANE_RAFT_ASSEMBLY
Systematic name | M23671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a plasma membrane raft. [GOC:jl]
Full description |

Standard name | GO_PLASMA_MEMBRANE_RAFT_ORGANIZATION
Systematic name | M23672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of plasma membrane rafts. [GOC:jl]
Full description |

Standard name | GO_LIPOPROTEIN_LOCALIZATION
Systematic name | M14212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a lipoprotein is transported to, or maintained in, a specific location. [GOC:jl]
Full description |

Standard name | GO_DOUBLE_STRAND_BREAK_REPAIR_VIA_SINGLE_STRAND_ANNEALING
Systematic name | M23673
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Repair of a DSB made between two repeated sequences oriented in the same direction occurs primarily by the single strand annealing pathway. The ends of the break are processed by a 5' to 3' exonuclease, exposing complementary single-strand regions of the direct repeats that can anneal, resulting in a deletion of the unique DNA between the direct repeats. [PMID:11606529]
Full description |

Standard name | GO_DOUBLE_STRAND_BREAK_REPAIR_VIA_SYNTHESIS_DEPENDENT_STRAND_ANNEALING
Systematic name | M23674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | SDSA is a major mechanism of double-strand break repair in mitosis which allows for the error-free repair of a double-strand break without the exchange of adjacent sequences. The broken DNA searches for and base pairs with a homologous region in an intact chromosome. DNA synthesis initiates from the 3' end of the invading DNA strand, using the intact chromosome as the template. Newly synthesized DNA is then displaced from the template and anneal with its complement on the other side of the double-strand break. [PMID:10357855]
Full description |

Standard name | GO_DNA_DEPENDENT_DNA_REPLICATION_MAINTENANCE_OF_FIDELITY
Systematic name | M10043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A DNA metabolic process that prevents or corrects errors to ensure that DNA is replicated accurately. Errors can be corrected either by intrinsic DNA polymerase proofreading activity or via mismatch repair. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_DNA_DEAMINATION
Systematic name | M23675
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of an amino group from a nucleotide base in DNA. An example is the deamination of cytosine to produce uracil. [GOC:ai]
Full description |

Standard name | GO_DEPYRIMIDINATION
Systematic name | M23676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disruption of the bond between the sugar in the backbone and the C or T base, causing the base to be removed and leaving a depyrimidinated sugar. [GOC:ai]
Full description |

Standard name | GO_ACTIN_NUCLEATION
Systematic name | M15725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial step in the formation of an actin filament, in which actin monomers combine to form a new filament. Nucleation is slow relative to the subsequent addition of more monomers to extend the filament. [ISBN:0815316194]
Full description |

Standard name | GO_GLYCEROLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M13721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of glycerolipids, any lipid with a glycerol backbone. [GOC:ai]
Full description |

Standard name | GO_G0_TO_G1_TRANSITION
Systematic name | M23678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The mitotic cell cycle phase transition whose occurrence commits the cell from the G0 quiescent state to the G1 phase. Under certain conditions, cells exit the cell cycle during G1 and remain in the G0 state as nongrowing, non-dividing (quiescent) cells. Appropriate stimulation of such cells induces them to return to G1 and resume growth and division. The G0 to G1 transition is accompanied by many changes in the program of gene expression. [GOC:mtg_cell_cycle, ISBN:0716731363]
Full description |

Standard name | GO_PLASMA_MEMBRANE_FUSION
Systematic name | M14815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The joining of the lipid bilayer membrane that surround a cell with that of another cell, producing a single cell. [GOC:elh, GOC:mtg_muscle]
Full description |

Standard name | GO_PROTEIN_INSERTION_INTO_MITOCHONDRIAL_INNER_MEMBRANE
Systematic name | M23679
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The processes mediating the insertion of proteins into the mitochondrial inner membrane. Mitochondrial inner membrane proteins can get inserted from the cytosol, by crossing the outer membrane and being guided by an inner membrane translocase complex into their final destination in the inner membrane. Some proteins present in the intermembrane space can get inserted into the inner mitochondrial membrane. Finally, some proteins are inserted into the inner membrane from the matrix side of the membrane. [GOC:mcc, GOC:vw, PMID:18672008]
Full description |

Standard name | GO_PROTEIN_INSERTION_INTO_MITOCHONDRIAL_OUTER_MEMBRANE
Systematic name | M23680
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process comprising the insertion of proteins from outside the organelle into the mitochondrial outer membrane, mediated by large outer membrane translocase complexes. [GOC:mcc, GOC:vw, PMID:18672008]
Full description |

Standard name | GO_PROTEIN_IMPORT_INTO_PEROXISOME_MEMBRANE
Systematic name | M23681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The targeting of proteins into the peroxisomal membrane. The process is not well understood, but both signals and mechanism differ from those involved in peroxisomal matrix protein import. [ISBN:0716731363, PMID:11687502]
Full description |

Standard name | GO_PROTEIN_INSERTION_INTO_ER_MEMBRANE
Systematic name | M23682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in incorporation of a protein into an endoplasmic reticulum (ER) membrane. It depends on specific topogenic sequences of amino acids that ensure that a protein acquires the proper orientation during its insertion into the ER membrane. [ISBN:0716731363]
Full description |

Standard name | GO_PROTEIN_RETENTION_IN_GOLGI_APPARATUS
Systematic name | M23683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The retention of proteins within the Golgi apparatus. Golgi-localized carbohydrate-modifying enzymes have a short N-terminal domain that faces the cytosol, a single transmembrane alpha helix, and a large C-terminal domain that faces the Golgi lumen and that contains the catalytic site. How the membrane-spanning alpha helix in a Golgi enzyme causes its localization and prevents its movement to the plasma membrane is not known. [ISBN:0716731363]
Full description |

Standard name | GO_CONSTITUTIVE_SECRETORY_PATHWAY
Systematic name | M34179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process of exocytosis found in all eukaryotic cells, in which transport vesicles destined for the plasma membrane leave the trans-Golgi network in a steady stream. Upon exocytosis, the membrane proteins and lipids in these vesicles provide new components for the plasma membrane, and the soluble proteins inside the vesicles are released into the extracellular space. [GOC:mah, ISBN:0716731363]
Full description |

Standard name | GO_TRANSCYTOSIS
Systematic name | M16224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of endocytosed material through the cell and its exocytosis from the plasma membrane at the opposite side. [ISBN:0716731363]
Full description |

Standard name | GO_T_CELL_SELECTION
Systematic name | M16724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which T cells that express T cell receptors that are restricted by self MHC protein complexes and tolerant to self antigens are selected for further maturation. [ISBN:0781735149, PMID:12414722]
Full description |

Standard name | GO_POSITIVE_THYMIC_T_CELL_SELECTION
Systematic name | M23684
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of sparing immature T cells in the thymus which react with self-MHC protein complexes with low affinity levels from apoptotic death. [ISBN:0781735149, PMID:12414722]
Full description |

Standard name | GO_THYMIC_T_CELL_SELECTION
Systematic name | M10811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of T cell selection that occurs in the thymus. [ISBN:0781735149, PMID:12414722]
Full description |

Standard name | GO_T_HELPER_1_CELL_DIFFERENTIATION
Systematic name | M23685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized T cell acquires the specialized features of a T-helper 1 (Th1) cell. A Th1 cell is a CD4-positive, alpha-beta T cell that has the phenotype T-bet-positive and produces interferon-gamma. [CL:0000545, GOC:ebc]
Full description |

Standard name | GO_T_HELPER_2_CELL_DIFFERENTIATION
Systematic name | M23686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized T cell acquires specialized features of a T-helper 2 (Th2) cell. A Th2 cell is a CD4-positive, alpha-beta T cell that has the phenotype GATA-3-positive and produces interleukin-4. [CL:0000546, GOC:ebc]
Full description |

Standard name | GO_REGULATORY_T_CELL_DIFFERENTIATION
Systematic name | M23687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized T cell acquires specialized features of a regulatory T cell. Regulatory T cells control or suppress immune responses through a variety of mechanisms and subsets include the CD4+CD25+ cell type as well as certain CD8+ cell types. [ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_VIRAL_GENOME_REPLICATION
Systematic name | M15836
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of viral genome replication. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VIRAL_GENOME_REPLICATION
Systematic name | M11124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of viral genome replication. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VIRAL_GENOME_REPLICATION
Systematic name | M15907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of viral genome replication. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHEMOKINE_BIOSYNTHETIC_PROCESS
Systematic name | M23688
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of chemokines. [GOC:go_curators]
Full description |

Standard name | GO_INNATE_IMMUNE_RESPONSE
Systematic name | M3064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Innate immune responses are defense responses mediated by germline encoded components that directly recognize components of potential pathogens. [GO_REF:0000022, GOC:add, GOC:ebc, GOC:mtg_sensu]
Full description |

Standard name | GO_REGULATION_OF_INNATE_IMMUNE_RESPONSE
Systematic name | M34180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the innate immune response, the organism's first line of defense against infection. [GOC:ebc]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INNATE_IMMUNE_RESPONSE
Systematic name | M34181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the innate immune response, the organism's first line of defense against infection. [GOC:ebc]
Full description |

Standard name | GO_INTERMEDIATE_FILAMENT_BASED_PROCESS
Systematic name | M10384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that depends upon or alters the intermediate filament cytoskeleton, that part of the cytoskeleton comprising intermediate filaments and their associated proteins. [GOC:ai]
Full description |

Standard name | GO_INTERMEDIATE_FILAMENT_ORGANIZATION
Systematic name | M10607
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Control of the spatial distribution of intermediate filaments; includes organizing filaments into meshworks, bundles, or other structures, as by cross-linking. [GOC:ai]
Full description |

Standard name | GO_INTERMEDIATE_FILAMENT_BUNDLE_ASSEMBLY
Systematic name | M23691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of the bundles of intermediate filaments. Intermediate filament-associated proteins (IFAPs) cross-link intermediate filaments with one another, forming a bundle or a network, and with other cell structures, including the plasma membrane. The organization of intermediate filaments and their supportive function in various cells types depends in large part on their linkage to other cell structures via IFAPs. [ISBN:0716731363]
Full description |

Standard name | GO_INTEGRIN_BIOSYNTHETIC_PROCESS
Systematic name | M23692
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of integrins, a large family of transmembrane proteins that act as receptors for cell-adhesion molecules. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_INTEGRIN_BIOSYNTHETIC_PROCESS
Systematic name | M34182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of integrins. [GOC:go_curators]
Full description |

Standard name | GO_PROTEIN_NEDDYLATION
Systematic name | M11286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Covalent attachment of the ubiquitin-like protein NEDD8 (RUB1) to another protein. [PMID:11698580]
Full description |

Standard name | GO_AZOLE_TRANSMEMBRANE_TRANSPORT
Systematic name | M16590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of azoles, heterocyclic compounds found in many biologically important substances, across a lipid bilayer, across a membrane. [GOC:go_curators, ISBN:3527307206, Wikipedia:Azole]
Full description |

Standard name | GO_CELLULAR_EXTRAVASATION
Systematic name | M12221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The migration of a leukocyte from the blood vessels into the surrounding tissue. [GOC:jl]
Full description |

Standard name | GO_MEIOTIC_CHROMOSOME_SEGREGATION
Systematic name | M10086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which genetic material, in the form of chromosomes, is organized into specific structures and then physically separated and apportioned to two or more sets during M phase of the meiotic cell cycle. [GOC:ai, GOC:mah]
Full description |

Standard name | GO_DEVELOPMENT_OF_SECONDARY_SEXUAL_CHARACTERISTICS
Systematic name | M23693
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the secondary sexual characteristics over time, from their formation to the mature structures. In humans, these include growth of axillary, chest, and pubic hair, voice changes, testicular/penile enlargement, breast development and menstrual periods. Development occurs in response to sex hormone secretion. [GOC:ai]
Full description |

Standard name | GO_DEVELOPMENT_OF_PRIMARY_SEXUAL_CHARACTERISTICS
Systematic name | M16813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the primary sexual characteristics over time, from their formation to the mature structures. The primary sexual characteristics are the testes in males and the ovaries in females and they develop in response to sex hormone secretion. [GOC:ai]
Full description |

Standard name | GO_HOMOLOGOUS_CHROMOSOME_SEGREGATION
Systematic name | M14947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which replicated homologous chromosomes are organized and then physically separated and apportioned to two sets during the first division of the meiotic cell cycle. Each replicated chromosome, composed of two sister chromatids, aligns at the cell equator, paired with its homologous partner; this pairing off, referred to as synapsis, permits genetic recombination. One homolog (both sister chromatids) of each morphologic type goes into each of the resulting chromosome sets. [GOC:ai, ISBN:0815316194]
Full description |

Standard name | GO_NEURONAL_ION_CHANNEL_CLUSTERING
Systematic name | M13511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which voltage-gated ion channels become localized to distinct subcellular domains in the neuron. Specific targeting, clustering, and maintenance of these channels in their respective domains are essential to achieve high conduction velocities of action potential propagation. [PMID:11456440]
Full description |

Standard name | GO_CLUSTERING_OF_VOLTAGE_GATED_SODIUM_CHANNELS
Systematic name | M23695
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which voltage-gated sodium channels become localized together in high densities. In animals, nodes of Ranvier differ dramatically from internodal axonal regions in very high densities of voltage-dependent sodium (Nav) channels responsible for the rapid, inward ionic currents that produce membrane depolarization. [PMID:11456440]
Full description |

Standard name | GO_CELL_FATE_COMMITMENT
Systematic name | M15945
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The commitment of cells to specific cell fates and their capacity to differentiate into particular kinds of cells. Positional information is established through protein signals that emanate from a localized source within a cell (the initial one-cell zygote) or within a developmental field. [ISBN:0716731185]
Full description |

Standard name | GO_APICAL_PROTEIN_LOCALIZATION
Systematic name | M10070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, or maintained in, apical regions of the cell. [GOC:bf]
Full description |

Standard name | GO_MAINTENANCE_OF_PROTEIN_LOCATION
Systematic name | M23696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is maintained in a location and prevented from moving elsewhere. These include sequestration, stabilization to prevent transport elsewhere and the active retrieval of proteins that do move away. [GOC:bf]
Full description |

Standard name | GO_REGULATION_OF_CIRCADIAN_SLEEP_WAKE_CYCLE_SLEEP
Systematic name | M34183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of sleep; a readily reversible state of reduced awareness and metabolic activity that occurs periodically in many animals. [GOC:jl, ISBN:0192800981]
Full description |

Standard name | GO_REGULATION_OF_ISOTYPE_SWITCHING
Systematic name | M14253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of isotype switching. [GOC:ai]
Full description |

Standard name | GO_ESTABLISHMENT_OF_EPITHELIAL_CELL_APICAL_BASAL_POLARITY
Systematic name | M23697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specification and formation of the apicobasal polarity of an epithelial cell. [GOC:ascb_2009, GOC:bf, GOC:dph, GOC:tb]
Full description |

Standard name | GO_SARCOMERE_ORGANIZATION
Systematic name | M11569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The myofibril assembly process that results in the organization of muscle actomyosin into sarcomeres. The sarcomere is the repeating unit of a myofibril in a muscle cell, composed of an array of overlapping thick and thin filaments between two adjacent Z discs. [GOC:bf]
Full description |

Standard name | GO_CELL_CELL_JUNCTION_ORGANIZATION
Systematic name | M23698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a cell-cell junction. A cell-cell junction is a specialized region of connection between two cells. [GOC:ai, GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_CELL_CELL_JUNCTION_MAINTENANCE
Systematic name | M34184
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The maintenance of junctions between cells. [GOC:ai]
Full description |

Standard name | GO_MRNA_CIS_SPLICING_VIA_SPLICEOSOME
Systematic name | M15250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The joining together, after removal of an intervening sequence composed of one or more introns, of two segments of the same RNA molecule via spliceosomal catalysis to produce an mRNA composed only of exon sequences that all came from the same primary transcript. [GOC:krc, ISBN:0879695897, PMID:18458335]
Full description |

Standard name | GO_LATE_ENDOSOME_TO_VACUOLE_TRANSPORT
Systematic name | M23700
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from late endosomes to the vacuole. In yeast, after transport to the prevacuolar compartment, endocytic content is delivered to the late endosome and on to the vacuole. This pathway is analogous to endosome to lysosome transport. [PMID:11872141]
Full description |

Standard name | GO_CARNITINE_BIOSYNTHETIC_PROCESS
Systematic name | M23701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of carnitine (hydroxy-trimethyl aminobutyric acid), a compound that participates in the transfer of acyl groups across the inner mitochondrial membrane. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_CELLULAR_RESPIRATION
Systematic name | M15594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The enzymatic release of energy from inorganic and organic compounds (especially carbohydrates and fats) which either requires oxygen (aerobic respiration) or does not (anaerobic respiration). [GOC:das, ISBN:0140513590, ISBN:0198506732]
Full description |

Standard name | GO_FARNESYL_DIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving farnesyl diphosphate, an intermediate in carotenoid, sesquiterpene, squalene and sterol biosynthesis, as well as a substrate in protein farnesylation. [GOC:go_curators]
Full description |

Standard name | GO_MHC_CLASS_I_BIOSYNTHETIC_PROCESS
Systematic name | M23702
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of major histocompatibility protein class I. [GOC:go_curators]
Full description |

Standard name | GO_MHC_CLASS_II_BIOSYNTHETIC_PROCESS
Systematic name | M23703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of major histocompatibility protein class II. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MHC_CLASS_I_BIOSYNTHETIC_PROCESS
Systematic name | M23704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of MHC class I. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MHC_CLASS_II_BIOSYNTHETIC_PROCESS
Systematic name | M23705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of MHC class II. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MHC_CLASS_II_BIOSYNTHETIC_PROCESS
Systematic name | M23706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of MHC class II. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_NITRIC_OXIDE_BIOSYNTHETIC_PROCESS
Systematic name | M29190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of nitric oxide. [GOC:go_curators]
Full description |

Standard name | GO_FAT_CELL_DIFFERENTIATION
Systematic name | M14158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of an adipocyte, an animal connective tissue cell specialized for the synthesis and storage of fat. [CL:0000136, GOC:go_curators]
Full description |

Standard name | GO_MYOBLAST_DIFFERENTIATION
Systematic name | M13632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a myoblast. A myoblast is a mononucleate cell type that, by fusion with other myoblasts, gives rise to the myotubes that eventually develop into striated muscle fibers. [CL:0000056, GOC:go_curators, GOC:mtg_muscle]
Full description |

Standard name | GO_BONE_RESORPTION
Systematic name | M15668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which specialized cells known as osteoclasts degrade the organic and inorganic portions of bone, and endocytose and transport the degradation products. [GOC:mah, PMID:10968780]
Full description |

Standard name | GO_CELL_REDOX_HOMEOSTASIS
Systematic name | M12813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that maintains the redox environment of a cell or compartment within a cell. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_RESPONSE_TO_ETHANOL
Systematic name | M10221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ethanol stimulus. [GOC:go_curators]
Full description |

Standard name | GO_RESPONSE_TO_ETHER
Systematic name | M15946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a ether stimulus. [GOC:go_curators]
Full description |

Standard name | GO_LOCOMOTOR_RHYTHM
Systematic name | M23715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The rhythm of the locomotor activity of an organism during its 24 hour activity cycle. [GOC:go_curators]
Full description |

Standard name | GO_PHOTORECEPTOR_CELL_MAINTENANCE
Systematic name | M12966
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process preventing the degeneration of the photoreceptor, a specialized cell type that is sensitive to light. [CL:0000210, GOC:bf, GOC:rl]
Full description |

Standard name | GO_REGULATION_OF_CHOLESTEROL_BIOSYNTHETIC_PROCESS
Systematic name | M12147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of cholesterol. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHOLESTEROL_BIOSYNTHETIC_PROCESS
Systematic name | M34185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of cholesterol. [GOC:go_curators]
Full description |

Standard name | GO_MAST_CELL_ACTIVATION
Systematic name | M12306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a mast cell resulting from exposure to a cytokine, chemokine, soluble factor, or to (at least in mammals) an antigen which the mast cell has specifically bound via IgE bound to Fc-epsilonRI receptors. [GOC:mgi_curators, ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_B_CELL_DIFFERENTIATION
Systematic name | M13200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of B cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_B_CELL_DIFFERENTIATION
Systematic name | M29191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of B cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_B_CELL_DIFFERENTIATION
Systematic name | M15028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of B cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_DIFFERENTIATION
Systematic name | M13846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_CELL_DIFFERENTIATION
Systematic name | M15033
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of T cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_GAMMA_DELTA_T_CELL_DIFFERENTIATION
Systematic name | M23718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gamma-delta T cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GAMMA_DELTA_T_CELL_DIFFERENTIATION
Systematic name | M34186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of gamma-delta T cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_REGULATORY_T_CELL_DIFFERENTIATION
Systematic name | M23719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the rate of differentiation of regulatory T cells. [ISBN:0781735149]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_REGULATORY_T_CELL_DIFFERENTIATION
Systematic name | M23720
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of differentiation of regulatory T cells. [ISBN:0781735149]
Full description |

Standard name | GO_REGULATION_OF_CELL_DIFFERENTIATION
Systematic name | M4547
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell differentiation, the process in which relatively unspecialized cells acquire specialized structural and functional features. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_DIFFERENTIATION
Systematic name | M9266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_DIFFERENTIATION
Systematic name | M12912
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_FAT_CELL_DIFFERENTIATION
Systematic name | M10293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of adipocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FAT_CELL_DIFFERENTIATION
Systematic name | M10687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of adipocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FAT_CELL_DIFFERENTIATION
Systematic name | M10890
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of adipocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_ENDOTHELIAL_CELL_DIFFERENTIATION
Systematic name | M11127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endothelial cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ENDOTHELIAL_CELL_DIFFERENTIATION
Systematic name | M23721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of endothelial cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOTHELIAL_CELL_DIFFERENTIATION
Systematic name | M10482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of endothelial cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_EPIDERMAL_CELL_DIFFERENTIATION
Systematic name | M14203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of epidermal cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EPIDERMAL_CELL_DIFFERENTIATION
Systematic name | M14453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of epidermal cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPIDERMAL_CELL_DIFFERENTIATION
Systematic name | M11040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of epidermal cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_INNER_EAR_AUDITORY_RECEPTOR_CELL_DIFFERENTIATION
Systematic name | M23722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of auditory hair cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_KERATINOCYTE_DIFFERENTIATION
Systematic name | M14926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of keratinocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_KERATINOCYTE_DIFFERENTIATION
Systematic name | M23723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of keratinocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_KERATINOCYTE_DIFFERENTIATION
Systematic name | M10630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of keratinocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_LYMPHOCYTE_DIFFERENTIATION
Systematic name | M13520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lymphocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LYMPHOCYTE_DIFFERENTIATION
Systematic name | M16917
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of lymphocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LYMPHOCYTE_DIFFERENTIATION
Systematic name | M14088
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of lymphocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_T_HELPER_CELL_DIFFERENTIATION
Systematic name | M11275
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T-helper cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_HELPER_CELL_DIFFERENTIATION
Systematic name | M23724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of T-helper cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_HELPER_CELL_DIFFERENTIATION
Systematic name | M13909
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of T-helper cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_T_HELPER_1_CELL_DIFFERENTIATION
Systematic name | M23725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T-helper 1 cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_HELPER_1_CELL_DIFFERENTIATION
Systematic name | M23726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of T-helper 1 cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_T_HELPER_2_CELL_DIFFERENTIATION
Systematic name | M11638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T-helper 2 cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_HELPER_2_CELL_DIFFERENTIATION
Systematic name | M23727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of T-helper 2 cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_MELANOCYTE_DIFFERENTIATION
Systematic name | M23728
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of melanocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MELANOCYTE_DIFFERENTIATION
Systematic name | M23729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of melanocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_MYELOID_CELL_DIFFERENTIATION
Systematic name | M8700
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of myeloid cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MYELOID_CELL_DIFFERENTIATION
Systematic name | M14891
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of myeloid cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MYELOID_CELL_DIFFERENTIATION
Systematic name | M13875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of myeloid cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_ERYTHROCYTE_DIFFERENTIATION
Systematic name | M13902
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of erythrocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ERYTHROCYTE_DIFFERENTIATION
Systematic name | M23730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of erythrocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ERYTHROCYTE_DIFFERENTIATION
Systematic name | M10440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of erythrocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_MACROPHAGE_DIFFERENTIATION
Systematic name | M15291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of macrophage differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MACROPHAGE_DIFFERENTIATION
Systematic name | M23731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of macrophage differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MACROPHAGE_DIFFERENTIATION
Systematic name | M16762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of macrophage differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_MEGAKARYOCYTE_DIFFERENTIATION
Systematic name | M12954
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of megakaryocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MEGAKARYOCYTE_DIFFERENTIATION
Systematic name | M14703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of megakaryocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MEGAKARYOCYTE_DIFFERENTIATION
Systematic name | M23732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of megakaryocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_MONOCYTE_DIFFERENTIATION
Systematic name | M14623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of monocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MONOCYTE_DIFFERENTIATION
Systematic name | M23733
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of monocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MONOCYTE_DIFFERENTIATION
Systematic name | M23734
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of monocyte differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_MYOBLAST_DIFFERENTIATION
Systematic name | M12330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of myoblast differentiation. A myoblast is a mononucleate cell type that, by fusion with other myoblasts, gives rise to the myotubes that eventually develop into skeletal muscle fibers. [CL:0000056, GOC:go_curators, GOC:mtg_muscle]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MYOBLAST_DIFFERENTIATION
Systematic name | M13403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of myoblast differentiation. A myoblast is a mononucleate cell type that, by fusion with other myoblasts, gives rise to the myotubes that eventually develop into skeletal muscle fibers. [CL:0000056, GOC:go_curators, GOC:mtg_muscle]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MYOBLAST_DIFFERENTIATION
Systematic name | M14562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of myoblast differentiation. A myoblast is a mononucleate cell type that, by fusion with other myoblasts, gives rise to the myotubes that eventually develop into skeletal muscle fibers. [CL:0000056, GOC:go_curators, GOC:mtg_muscle]
Full description |

Standard name | GO_REGULATION_OF_NEURON_DIFFERENTIATION
Systematic name | M12739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neuron differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEURON_DIFFERENTIATION
Systematic name | M10363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of neuron differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEURON_DIFFERENTIATION
Systematic name | M10925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of neuron differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_OSTEOBLAST_DIFFERENTIATION
Systematic name | M14392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of osteoblast differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OSTEOBLAST_DIFFERENTIATION
Systematic name | M15707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of osteoblast differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OSTEOBLAST_DIFFERENTIATION
Systematic name | M15118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of osteoblast differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_OSTEOCLAST_DIFFERENTIATION
Systematic name | M10369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of osteoclast differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OSTEOCLAST_DIFFERENTIATION
Systematic name | M16815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of osteoclast differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OSTEOCLAST_DIFFERENTIATION
Systematic name | M13018
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of osteoclast differentiation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_EPIDERMIS_DEVELOPMENT
Systematic name | M10669
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of epidermis development. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EPIDERMIS_DEVELOPMENT
Systematic name | M13963
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of epidermis development. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPIDERMIS_DEVELOPMENT
Systematic name | M13685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of epidermis development. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_GLIAL_CELL_DIFFERENTIATION
Systematic name | M15023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glia cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLIAL_CELL_DIFFERENTIATION
Systematic name | M11035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of glia cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLIAL_CELL_DIFFERENTIATION
Systematic name | M11043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of glia cell differentiation. [GOC:go_curators]
Full description |

Standard name | GO_LOW_DENSITY_LIPOPROTEIN_PARTICLE_RECEPTOR_BIOSYNTHETIC_PROCESS
Systematic name | M23735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of low-density lipoprotein receptors, cell surface proteins that mediate the endocytosis of low-density lipoprotein particles by cells. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FATTY_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M15179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of fatty acids. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLUCONEOGENESIS
Systematic name | M15808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of gluconeogenesis. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLUCONEOGENESIS
Systematic name | M16444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of gluconeogenesis. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FATTY_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M11966
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of fatty acids. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CILIUM_ASSEMBLY
Systematic name | M23736
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the formation of a cilium. [GOC:cilia, GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSLATION
Systematic name | M16899
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of proteins by the translation of mRNA or circRNA. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_RESPIRATORY_BURST
Systematic name | M13734
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A phase of elevated metabolic activity, during which oxygen consumption increases; this leads to the production, by an NADH dependent system, of hydrogen peroxide (H2O2), superoxide anions and hydroxyl radicals. [ISBN:0198506732]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_CATABOLIC_PROCESS
Systematic name | M11089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of a protein by the destruction of the native, active configuration, with or without the hydrolysis of peptide bonds. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_REPAIR
Systematic name | M10904
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of DNA repair. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_REPAIR
Systematic name | M13735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of DNA repair. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_REPLICATION
Systematic name | M10227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of DNA replication. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPIDERMAL_GROWTH_FACTOR_ACTIVATED_RECEPTOR_ACTIVITY
Systematic name | M14395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of EGF-activated receptor activity. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FIBROBLAST_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of fibroblast growth factor receptor signaling pathway activity. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of G protein-coupled receptor signaling pathway. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of G protein-coupled receptor signaling pathway activity. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NOTCH_SIGNALING_PATHWAY
Systematic name | M11627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the Notch signaling pathway. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NOTCH_SIGNALING_PATHWAY
Systematic name | M11070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the Notch signaling pathway. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ACTION_POTENTIAL
Systematic name | M23740
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of action potential creation, propagation or termination. This typically occurs via modulation of the activity or expression of voltage-gated ion channels. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACTION_POTENTIAL
Systematic name | M11161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of action potential creation, propagation or termination. This typically occurs via modulation of the activity or expression of voltage-gated ion channels. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_ADENYLATE_CYCLASE_ACTIVITY
Systematic name | M12312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of adenylate cyclase activity. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ADENYLATE_CYCLASE_ACTIVITY
Systematic name | M10923
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of adenylate cyclase activity. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AXON_EXTENSION
Systematic name | M13512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of axon extension. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BLOOD_PRESSURE
Systematic name | M14221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which the force of blood traveling through the circulatory system is decreased. [GOC:go_curators, GOC:mtg_cardio]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BLOOD_PRESSURE
Systematic name | M14432
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which the force of blood traveling through the circulatory system is increased. [GOC:go_curators, GOC:mtg_cardio]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OSSIFICATION
Systematic name | M16952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of ossification, the formation of bone or of a bony substance or the conversion of fibrous tissue or of cartilage into bone or a bony substance. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BONE_RESORPTION
Systematic name | M23741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of bone resorption. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_ADHESION
Systematic name | M11923
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell adhesion. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_CYCLE
Systematic name | M12829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of progression through the cell cycle. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_CYCLE
Systematic name | M17705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of progression through the cell cycle. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_SIZE
Systematic name | M23742
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that reduces cell size. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_SIZE
Systematic name | M14777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases cell size. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_VOLUME
Systematic name | M23743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases cell volume. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHROMATIN_ASSEMBLY_OR_DISASSEMBLY
Systematic name | M34187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of chromatin assembly or disassembly. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ENDOCYTOSIS
Systematic name | M11212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of endocytosis. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOCYTOSIS
Systematic name | M10433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of endocytosis. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GENE_EXPRESSION_EPIGENETIC
Systematic name | M12274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any epigenetic process that stops, prevents or reduces the rate of gene expression. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GENE_EXPRESSION_EPIGENETIC
Systematic name | M10235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any epigenetic process that activates or increases the rate of gene expression. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLYCOLYTIC_PROCESS
Systematic name | M23744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of glycolysis. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLYCOLYTIC_PROCESS
Systematic name | M23745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of glycolysis. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HEART_CONTRACTION
Systematic name | M12612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of heart contraction. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HEART_CONTRACTION
Systematic name | M13724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of heart contraction. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INNATE_IMMUNE_RESPONSE
Systematic name | M11125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the innate immune response. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ISOTYPE_SWITCHING
Systematic name | M23746
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of isotype switching. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ISOTYPE_SWITCHING
Systematic name | M23747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of isotype switching. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPID_METABOLIC_PROCESS
Systematic name | M10685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving lipids. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPID_METABOLIC_PROCESS
Systematic name | M15089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving lipids. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MEIOTIC_NUCLEAR_DIVISION
Systematic name | M11402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of meiosis. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MEIOTIC_NUCLEAR_DIVISION
Systematic name | M23748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of meiosis. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MEMBRANE_POTENTIAL
Systematic name | M23749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of establishment or extent of a membrane potential, the electric potential existing across any membrane arising from charges in the membrane itself and from the charges present in the media on either side of the membrane. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MEMBRANE_POTENTIAL
Systematic name | M23750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of establishment or extent of a membrane potential, the electric potential existing across any membrane arising from charges in the membrane itself and from the charges present in the media on either side of the membrane. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOTIC_NUCLEAR_DIVISION
Systematic name | M10168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of mitosis. [GOC:go_curators]
Full description |

Standard name | GO_PH_REDUCTION
Systematic name | M11277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that reduces the internal pH of an organism, part of an organism or a cell, measured by the concentration of the hydrogen ion. [GOC:go_curators]
Full description |

Standard name | GO_PH_ELEVATION
Systematic name | M23751
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the internal pH of an organism, part of an organism or a cell, measured by the concentration of the hydrogen ion. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_KINASE_ACTIVITY
Systematic name | M34188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein kinase activity. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_KINASE_ACTIVITY
Systematic name | M34189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein kinase activity. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEOLYSIS
Systematic name | M10339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the hydrolysis of a peptide bond or bonds within a protein. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEOLYSIS
Systematic name | M14936
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the hydrolysis of a peptide bond or bonds within a protein. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SINGLE_STRANDED_VIRAL_RNA_REPLICATION_VIA_DOUBLE_STRANDED_DNA_INTERMEDIATE
Systematic name | M23752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of single stranded viral RNA replication via double stranded DNA intermediate. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SISTER_CHROMATID_COHESION
Systematic name | M23753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of sister chromatid cohesion. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SISTER_CHROMATID_COHESION
Systematic name | M23754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of sister chromatid cohesion. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMOOTHENED_SIGNALING_PATHWAY
Systematic name | M13653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of smoothened signaling. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SMOOTHENED_SIGNALING_PATHWAY
Systematic name | M15718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of smoothened signaling. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_RNA_POLYMERASE_II_TRANSCRIPTION_PREINITIATION_COMPLEX_ASSEMBLY
Systematic name | M12247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of RNA polymerase II transcriptional preinitiation complex assembly. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RNA_POLYMERASE_II_TRANSCRIPTION_PREINITIATION_COMPLEX_ASSEMBLY
Systematic name | M23755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of RNA polymerase II transcriptional preinitiation complex assembly. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSLATIONAL_ELONGATION
Systematic name | M29193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of translational elongation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSLATIONAL_ELONGATION
Systematic name | M29194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of translational elongation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASOCONSTRICTION
Systematic name | M23756
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of vasoconstriction. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASOCONSTRICTION
Systematic name | M12386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vasoconstriction. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_RECOMBINATION
Systematic name | M10992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of DNA recombination. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_RECOMBINATION
Systematic name | M15127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of DNA recombination. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CARBOHYDRATE_METABOLIC_PROCESS
Systematic name | M14102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving carbohydrate. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CARBOHYDRATE_METABOLIC_PROCESS
Systematic name | M11721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving carbohydrate. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CATECHOLAMINE_METABOLIC_PROCESS
Systematic name | M29195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving catecholamine. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_COMPLEMENT_ACTIVATION
Systematic name | M23757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of complement activation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_COMPLEMENT_ACTIVATION
Systematic name | M23758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of complement activation. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EXOCYTOSIS
Systematic name | M11437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of exocytosis. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EXOCYTOSIS
Systematic name | M13138
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of exocytosis. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FATTY_ACID_METABOLIC_PROCESS
Systematic name | M16838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving fatty acids. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FATTY_ACID_METABOLIC_PROCESS
Systematic name | M15385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving fatty acids. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GROWTH
Systematic name | M6071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of growth, the increase in size or mass of all or part of an organism. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GROWTH
Systematic name | M14190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of growth, the increase in size or mass of all or part of an organism. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MITOTIC_CELL_CYCLE
Systematic name | M13508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of progression through the mitotic cell cycle. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOTIC_CELL_CYCLE
Systematic name | M11049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of progression through the mitotic cell cycle. [GOC:dph, GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MUSCLE_CONTRACTION
Systematic name | M10753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of muscle contraction. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MUSCLE_CONTRACTION
Systematic name | M12252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of muscle contraction. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NUCLEOBASE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M23761
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving nucleobases, nucleosides, nucleotides and nucleic acids. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NUCLEOBASE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M23762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving nucleobases, nucleosides, nucleotides and nucleic acids. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CIRCADIAN_SLEEP_WAKE_CYCLE_SLEEP
Systematic name | M23763
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the duration or quality of sleep, a readily reversible state of reduced awareness and metabolic activity that occurs periodically in many animals. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_STEROID_METABOLIC_PROCESS
Systematic name | M11052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving steroids. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STEROID_METABOLIC_PROCESS
Systematic name | M16578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving steroids. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_BY_RNA_POLYMERASE_I
Systematic name | M23764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of transcription mediated by RNA polymerase I. [GOC:go_curators, GOC:txnOH]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_BY_RNA_POLYMERASE_II
Systematic name | M23765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of transcription from an RNA polymerase II promoter. [GOC:go_curators, GOC:txnOH]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_BY_RNA_POLYMERASE_III
Systematic name | M23766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of transcription mediated by RNA polymerase III. [GOC:go_curators, GOC:txnOH]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSLATIONAL_INITIATION
Systematic name | M11930
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of translational initiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSLATIONAL_INITIATION
Systematic name | M12031
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of translational initiation. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NATURAL_KILLER_CELL_MEDIATED_CYTOTOXICITY
Systematic name | M29196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of natural killer cell mediated cytotoxicity. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CALCIUM_ION_DEPENDENT_EXOCYTOSIS
Systematic name | M11236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of calcium ion-dependent exocytosis. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CALCIUM_ION_DEPENDENT_EXOCYTOSIS
Systematic name | M10430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of calcium ion-dependent exocytosis. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NUCLEOTIDE_METABOLIC_PROCESS
Systematic name | M29197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving nucleotides. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NUCLEOTIDE_METABOLIC_PROCESS
Systematic name | M29198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving nucleotides. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M14169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of smooth muscle contraction. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M12814
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of smooth muscle contraction. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_STRIATED_MUSCLE_CONTRACTION
Systematic name | M23767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of striated muscle contraction. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STRIATED_MUSCLE_CONTRACTION
Systematic name | M12323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of striated muscle contraction. [GOC:go_curators]
Full description |

Standard name | GO_CARBON_CATABOLITE_REGULATION_OF_TRANSCRIPTION
Systematic name | M23768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A transcription regulation process in which the presence of one carbon source leads to the modulation of the frequency, rate, or extent of transcription of specific genes involved in the metabolism of other carbon sources. [GOC:go_curators, GOC:mah, PMID:18359269, PMID:9618445]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EMBRYONIC_DEVELOPMENT
Systematic name | M13997
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of embryonic development. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_EMBRYONIC_DEVELOPMENT
Systematic name | M15221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of embryonic development. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ACTIVATED_T_CELL_PROLIFERATION
Systematic name | M23769
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of activated T cell proliferation. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_BY_GLUCOSE
Systematic name | M23770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involving glucose that modulates the frequency, rate or extent or transcription. [GOC:go_curators]
Full description |

Standard name | GO_AMP_METABOLIC_PROCESS
Systematic name | M16810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving AMP, adenosine monophosphate. [GOC:go_curators]
Full description |

Standard name | GO_ATP_METABOLIC_PROCESS
Systematic name | M23771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving ATP, adenosine triphosphate, a universally important coenzyme and enzyme regulator. [GOC:go_curators]
Full description |

Standard name | GO_GMP_METABOLIC_PROCESS
Systematic name | M15553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving GMP, guanosine monophosphate. [GOC:go_curators]
Full description |

Standard name | GO_GTP_METABOLIC_PROCESS
Systematic name | M15644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving GTP, guanosine triphosphate. [GOC:go_curators]
Full description |

Standard name | GO_IMP_METABOLIC_PROCESS
Systematic name | M29200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving IMP, inosine monophosphate. [GOC:go_curators]
Full description |

Standard name | GO_UTP_METABOLIC_PROCESS
Systematic name | M29201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving UTP, uridine (5'-)triphosphate. [GOC:go_curators]
Full description |

Standard name | GO_CAMP_METABOLIC_PROCESS
Systematic name | M29202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving the nucleotide cAMP (cyclic AMP, adenosine 3',5'-cyclophosphate). [GOC:go_curators]
Full description |

Standard name | GO_DATP_METABOLIC_PROCESS
Systematic name | M29203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving dATP, deoxyadenosine triphosphate (2'-deoxyadenosine 5'-triphosphate). [GOC:go_curators]
Full description |

Standard name | GO_CGMP_METABOLIC_PROCESS
Systematic name | M29204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving cyclic GMP, guanosine 3',5'-phosphate. [GOC:go_curators]
Full description |

Standard name | GO_CGMP_CATABOLIC_PROCESS
Systematic name | M23772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of cyclic GMP, guanosine 3',5'-phosphate. [GOC:go_curators]
Full description |

Standard name | GO_DUMP_METABOLIC_PROCESS
Systematic name | M34190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving dUMP, deoxyuridine (5'-)monophosphate (2'-deoxyuridine 5'-phosphate). [GOC:go_curators]
Full description |

Standard name | GO_ADENOSINE_METABOLIC_PROCESS
Systematic name | M23773
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving adenosine, adenine riboside, a ribonucleoside found widely distributed in cells of every type as the free nucleoside and in combination in nucleic acids and various nucleoside coenzymes. [GOC:go_curators]
Full description |

Standard name | GO_NUCLEOBASE_BIOSYNTHETIC_PROCESS
Systematic name | M16916
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a nucleobase, a nitrogenous base that is a constituent of a nucleic acid. [GOC:ai]
Full description |

Standard name | GO_NUCLEOBASE_CATABOLIC_PROCESS
Systematic name | M23774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a nucleobase, a nitrogenous base that is a constituent of a nucleic acid. [GOC:ai]
Full description |

Standard name | GO_PYRIMIDINE_DEOXYRIBONUCLEOSIDE_METABOLIC_PROCESS
Systematic name | M29205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any one of a family of organic molecules consisting of a pyrimidine base covalently bonded to a sugar deoxyribose (a deoxyribonucleoside). [GOC:ai]
Full description |

Standard name | GO_PYRIMIDINE_RIBONUCLEOSIDE_METABOLIC_PROCESS
Systematic name | M29206
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving any ribonucleoside, a nucleoside in which pyrimidine base is linked to a ribose (beta-D-ribofuranose) molecule. [GOC:ai]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOSIDE_BIOSYNTHETIC_PROCESS
Systematic name | M11659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of one of a family of organic molecules consisting of a pyrimidine base covalently bonded to a sugar ribose (a ribonucleoside) or deoxyribose (a deoxyribonucleoside). [GOC:ai]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOSIDE_CATABOLIC_PROCESS
Systematic name | M15390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of one of a family of organic molecules consisting of a pyrimidine base covalently bonded to a sugar ribose (a ribonucleoside) or deoxyribose (a deoxyribonucleoside). [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VITAMIN_METABOLIC_PROCESS
Systematic name | M34191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving a vitamin, one of a number of unrelated organic substances that occur in many foods in small amounts and that are necessary in trace amounts for the normal metabolic functioning of the body. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VITAMIN_METABOLIC_PROCESS
Systematic name | M23775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving a vitamin, one of a number of unrelated organic substances that occur in many foods in small amounts and that are necessary in trace amounts for the normal metabolic functioning of the body. [GOC:ai]
Full description |

Standard name | GO_TETRAHYDROBIOPTERIN_METABOLIC_PROCESS
Systematic name | M29207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving tetrahydrobiopterin, the reduced form of biopterin (2-amino-4-hydroxy-6-(1,2-dihydroxypropyl)-pteridine). It functions as a hydroxylation coenzyme, e.g. in the conversion of phenylalanine to tyrosine. [PMID:21871890]
Full description |

Standard name | GO_PIGMENT_BIOSYNTHETIC_PROCESS
Systematic name | M15363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a pigment, any general or particular coloring matter in living organisms, e.g. melanin. [ISBN:0198506732]
Full description |

Standard name | GO_PIGMENT_CATABOLIC_PROCESS
Systematic name | M29208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a pigment, any general or particular coloring matter in living organisms, e.g. melanin. [ISBN:0198506732]
Full description |

Standard name | GO_ALCOHOL_CATABOLIC_PROCESS
Systematic name | M16620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of alcohols, any of a class of compounds containing one or more hydroxyl groups attached to a saturated carbon atom. [GOC:ai]
Full description |

Standard name | GO_ALCOHOL_BIOSYNTHETIC_PROCESS
Systematic name | M16484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of alcohols, any of a class of compounds containing one or more hydroxyl groups attached to a saturated carbon atom. [GOC:ai]
Full description |

Standard name | GO_POLYOL_BIOSYNTHETIC_PROCESS
Systematic name | M16513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a polyol, any alcohol containing three or more hydroxyl groups attached to saturated carbon atoms. [GOC:curators]
Full description |

Standard name | GO_POLYOL_CATABOLIC_PROCESS
Systematic name | M11137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a polyol, any alcohol containing three or more hydroxyl groups attached to saturated carbon atoms. [GOC:curators]
Full description |

Standard name | GO_ALDEHYDE_BIOSYNTHETIC_PROCESS
Systematic name | M23776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of aldehydes, any organic compound with the formula R-CH=O. [GOC:ai]
Full description |

Standard name | GO_ALDEHYDE_CATABOLIC_PROCESS
Systematic name | M11096
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of aldehydes, any organic compound with the formula R-CH=O. [GOC:ai]
Full description |

Standard name | GO_PHENOL_CONTAINING_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M10438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a phenol, any compound containing one or more hydroxyl groups directly attached to an aromatic carbon ring. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_FATTY_ACID_OXIDATION
Systematic name | M14956
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of fatty acid oxidation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FATTY_ACID_OXIDATION
Systematic name | M29209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of fatty acid oxidation. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FATTY_ACID_OXIDATION
Systematic name | M23777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of fatty acid oxidation. [GOC:ai]
Full description |

Standard name | GO_GLUCOSE_IMPORT
Systematic name | M13142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of the hexose monosaccharide glucose into a cell or organelle. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_GLUCOSE_IMPORT
Systematic name | M34192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the import of the hexose monosaccharide glucose into a cell or organelle. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLUCOSE_IMPORT
Systematic name | M16320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the import of the hexose monosaccharide glucose into a cell or organelle. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_JNK_CASCADE
Systematic name | M14488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of signal transduction mediated by the JNK cascade. [GOC:bf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_JNK_CASCADE
Systematic name | M23778
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signal transduction mediated by the JNK cascade. [GOC:bf]
Full description |

Standard name | GO_PHOSPHATIDYLETHANOLAMINE_METABOLIC_PROCESS
Systematic name | M29210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving phosphatidylethanolamine, any of a class of glycerophospholipids in which a phosphatidyl group is esterified to the hydroxyl group of ethanolamine. It is a major structural phospholipid in mammalian systems. It tends to be more abundant than phosphatidylcholine in the internal membranes of the cell and is an abundant component of prokaryotic membranes. [GOC:curators, ISBN:0198506732]
Full description |

Standard name | GO_DIACYLGLYCEROL_METABOLIC_PROCESS
Systematic name | M15058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving diacylglycerol, a glyceride in which any two of the R groups (positions not specified) are acyl groups while the remaining R group can be either H or an alkyl group. [PMID:11481335]
Full description |

Standard name | GO_CDP_DIACYLGLYCEROL_METABOLIC_PROCESS
Systematic name | M29211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving CDP-diacylglycerol, CDP-1,2-diacylglycerol, a substance composed of diacylglycerol in glycosidic linkage with cytidine diphosphate. It is a common intermediate in phospholipid biosynthesis. [PMID:24533860]
Full description |

Standard name | GO_AMINO_SUGAR_CATABOLIC_PROCESS
Systematic name | M13698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of any amino sugar, sugars containing an amino group in place of a hydroxyl group. [GOC:curators]
Full description |

Standard name | GO_AMINO_SUGAR_BIOSYNTHETIC_PROCESS
Systematic name | M11449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any amino sugar, sugars containing an amino group in place of a hydroxyl group. [GOC:curators]
Full description |

Standard name | GO_DISACCHARIDE_BIOSYNTHETIC_PROCESS
Systematic name | M23779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of disaccharides, sugars composed of two monosaccharide units. [GOC:ai]
Full description |

Standard name | GO_MONOSACCHARIDE_BIOSYNTHETIC_PROCESS
Systematic name | M12988
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of monosaccharides, polyhydric alcohols containing either an aldehyde or a keto group and between three to ten or more carbon atoms. [ISBN:0198506732]
Full description |

Standard name | GO_MONOSACCHARIDE_CATABOLIC_PROCESS
Systematic name | M11279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of monosaccharides, polyhydric alcohols containing either an aldehyde or a keto group and between three to ten or more carbon atoms. [ISBN:0198506732]
Full description |

Standard name | GO_DEOXYRIBOSE_PHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M23780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of deoxyribose phosphate, the phosphorylated sugar 2-deoxy-erythro-pentose. [ISBN:0198506732]
Full description |

Standard name | GO_DEOXYRIBOSE_PHOSPHATE_CATABOLIC_PROCESS
Systematic name | M14637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of deoxyribose phosphate, the phosphorylated sugar 2-deoxy-erythro-pentose. [ISBN:0198506732]
Full description |

Standard name | GO_RIBOSE_PHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M23781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of ribose phosphate, any phosphorylated ribose sugar. [GOC:ai]
Full description |

Standard name | GO_5_PHOSPHORIBOSE_1_DIPHOSPHATE_METABOLIC_PROCESS
Systematic name | M29212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving 5-phosphoribose 1-diphosphate, also known as 5-phosphoribosyl-1-pyrophosphate. [GOC:ai]
Full description |

Standard name | GO_URATE_METABOLIC_PROCESS
Systematic name | M14906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving urate, the anion of uric acid, 2,6,8-trioxypurine, the end product of purine metabolism in certain mammals and the main excretory product in uricotelic animals. [ISBN:0198506732]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RECEPTOR_SIGNALING_PATHWAY_VIA_JAK_STAT
Systematic name | M29213
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a receptor signaling pathway via JAK-STAT. [GOC:bf]
Full description |

Standard name | GO_ORGANOPHOSPHATE_CATABOLIC_PROCESS
Systematic name | M13815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of organophosphates, any phosphate-containing organic compound. [GOC:ai]
Full description |

Standard name | GO_ICOSANOID_BIOSYNTHETIC_PROCESS
Systematic name | M23782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of icosanoids, any of a group of C20 polyunsaturated fatty acids. [ISBN:0198506732]
Full description |

Standard name | GO_PROSTANOID_BIOSYNTHETIC_PROCESS
Systematic name | M16690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of prostanoids, any compound based on or derived from the prostanoate structure. [GOC:ai]
Full description |

Standard name | GO_SHORT_CHAIN_FATTY_ACID_METABOLIC_PROCESS
Systematic name | M12558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving fatty acids with a chain length of less than C6. [Wikipedia:Fatty_acid_metabolism]
Full description |

Standard name | GO_NEUTRAL_LIPID_BIOSYNTHETIC_PROCESS
Systematic name | M14077
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of neutral lipids, lipids only soluble in solvents of very low polarity. [GOC:ai]
Full description |

Standard name | GO_NEUTRAL_LIPID_CATABOLIC_PROCESS
Systematic name | M13264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of neutral lipids, lipids only soluble in solvents of very low polarity. [GOC:ai]
Full description |

Standard name | GO_MONOACYLGLYCEROL_METABOLIC_PROCESS
Systematic name | M29214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving monoacylglycerol, any ester of glycerol in which any one of its hydroxyl groups has been acylated with a fatty acid, the other being non-esterified. [ISBN:0198506732]
Full description |

Standard name | GO_MEMBRANE_LIPID_CATABOLIC_PROCESS
Systematic name | M11628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of membrane lipids, any lipid found in or associated with a biological membrane. [GOC:ai]
Full description |

Standard name | GO_MEMBRANE_LIPID_BIOSYNTHETIC_PROCESS
Systematic name | M16158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of membrane lipids, any lipid found in or associated with a biological membrane. [GOC:ai]
Full description |

Standard name | GO_PLATELET_ACTIVATING_FACTOR_METABOLIC_PROCESS
Systematic name | M29215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving platelet activating factor, 1-O-alkyl-2-acetyl-sn-glycerol 3-phosphocholine, where alkyl = hexadecyl or octadecyl. Platelet activating factor is an inflammatory mediator released from a variety of cells in response to various stimuli. [ISBN:0198547684]
Full description |

Standard name | GO_PHOSPHATIDYLCHOLINE_METABOLIC_PROCESS
Systematic name | M10345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving phosphatidylcholines, any of a class of glycerophospholipids in which the phosphatidyl group is esterified to the hydroxyl group of choline. They are important constituents of cell membranes. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHATIDYLGLYCEROL_METABOLIC_PROCESS
Systematic name | M11658
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving phosphatidylglycerols, any of a class of phospholipids in which the phosphatidyl group is esterified to the hydroxyl group of glycerol. They are important constituents of cell membranes. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHATIDIC_ACID_METABOLIC_PROCESS
Systematic name | M29216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving phosphatidic acid, any derivative of glycerol phosphate in which both the remaining hydroxyl groups of the glycerol moiety are esterified with fatty acids. [ISBN:0198506732]
Full description |

Standard name | GO_GLYCEROPHOSPHOLIPID_CATABOLIC_PROCESS
Systematic name | M14101
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glycerophospholipids, any derivative of glycerophosphate that contains at least one O-acyl, O-alkyl, or O-alkenyl group attached to the glycerol residue. [ISBN:0198506732]
Full description |

Standard name | GO_GLYCOSYLCERAMIDE_BIOSYNTHETIC_PROCESS
Systematic name | M23783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of glycosylceramides, any compound formed by the replacement of the glycosidic hydroxyl group of a cyclic form of a monosaccharide (or derivative) by a ceramide group. [GOC:ai]
Full description |

Standard name | GO_GLYCOSYLCERAMIDE_CATABOLIC_PROCESS
Systematic name | M23784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glycosylceramides, any compound formed by the replacement of the glycosidic hydroxyl group of a cyclic form of a monosaccharide (or derivative) by a ceramide group. [GOC:ai]
Full description |

Standard name | GO_GLYCEROLIPID_METABOLIC_PROCESS
Systematic name | M12061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycerolipids, any lipid with a glycerol backbone. Diacylglycerol and phosphatidate are key lipid intermediates of glycerolipid biosynthesis. [GOC:ai, PMID:8906569]
Full description |

Standard name | GO_GLYOXYLATE_METABOLIC_PROCESS
Systematic name | M13235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glyoxylate, the anion of glyoxylic acid, HOC-COOH. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_METABOLIC_PROCESS
Systematic name | M10397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving phosphatidylinositol, any glycophospholipid in which a sn-glycerol 3-phosphate residue is esterified to the 1-hydroxyl group of 1D-myo-inositol. [ISBN:0198506732]
Full description |

Standard name | GO_S_ADENOSYLMETHIONINE_METABOLIC_PROCESS
Systematic name | M12669
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving S-adenosylmethionine, S-(5'-adenosyl)-L-methionine, an important intermediate in one-carbon metabolism. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PROTOPORPHYRINOGEN_IX_METABOLIC_PROCESS
Systematic name | M29218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving protoporphyrinogen IX, the specific substrate for the enzyme ferrochelatase, which catalyzes the insertion of iron to form protoheme. It is probably also the substrate for chlorophyll formation. [ISBN:0198506732]
Full description |

Standard name | GO_GLYCEROLIPID_CATABOLIC_PROCESS
Systematic name | M15197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glycerolipids, any lipid with a glycerol backbone. [GOC:ai]
Full description |

Standard name | GO_SPHINGOSINE_BIOSYNTHETIC_PROCESS
Systematic name | M34193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of sphingosine (sphing-4-enine), trans-D-erytho-2-amino-octadec-4-ene-1,3-diol, a long chain amino diol sphingoid base that occurs in most sphingolipids in animal tissues. [GOC:ma, ISBN:0198506732]
Full description |

Standard name | GO_CERAMIDE_BIOSYNTHETIC_PROCESS
Systematic name | M12013
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of ceramides, any N-acylated sphingoid. [GOC:ai]
Full description |

Standard name | GO_CERAMIDE_CATABOLIC_PROCESS
Systematic name | M10160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of ceramides, any N-acetylated sphingoid. [GOC:ai]
Full description |

Standard name | GO_SPHINGOID_METABOLIC_PROCESS
Systematic name | M12454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving sphingoids, any of a class of compounds comprising sphinganine and its homologues and stereoisomers, and derivatives of these compounds. [ISBN:0198506732]
Full description |

Standard name | GO_PHOTORECEPTOR_CELL_DIFFERENTIATION
Systematic name | M14509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specialization of organization of a photoreceptor, a cell that responds to incident electromagnetic radiation, particularly visible light. An example of this process is found in Drosophila melanogaster. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_PHOTORECEPTOR_CELL_DIFFERENTIATION
Systematic name | M23787
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of photoreceptor cell differentiation. An example of this process is found in Drosophila melanogaster. [GOC:go_curators]
Full description |

Standard name | GO_SALIVA_SECRETION
Systematic name | M23789
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of saliva from the salivary glands. In man, the saliva is a turbid and slightly viscous fluid, generally of an alkaline reaction, and is secreted by the parotid, submaxillary, and sublingual glands. In the mouth the saliva is mixed with the secretion from the buccal glands. In man and many animals, saliva is an important digestive fluid on account of the presence of the peculiar enzyme, ptyalin. [GOC:curators, UBERON:0001836]
Full description |

Standard name | GO_DEVELOPMENT_OF_SECONDARY_FEMALE_SEXUAL_CHARACTERISTICS
Systematic name | M23790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the secondary female sexual characteristics over time, from their formation to the mature structures. In female humans, these include growth of axillary and pubic hair, breast development and menstrual periods. Their development occurs in response to sex hormone secretion. [GOC:ai]
Full description |

Standard name | GO_DEVELOPMENT_OF_PRIMARY_FEMALE_SEXUAL_CHARACTERISTICS
Systematic name | M23791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the primary female sexual characteristics over time, from their formation to the mature structure. The primary female sexual characteristics are the ovaries, and they develop in response to sex hormone secretion. [GOC:ai]
Full description |

Standard name | GO_RETINAL_ROD_CELL_DEVELOPMENT
Systematic name | M23792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Development of a rod cell, one of the sensory cells in the eye that reacts to the presence of light. Rod cells contain the photopigment rhodopsin or porphyropsin and are responsible for vision in dim light. [ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_RAS_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M8141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of Ras protein signal transduction. [GOC:bf]
Full description |

Standard name | GO_REGULATION_OF_VIRAL_ENTRY_INTO_HOST_CELL
Systematic name | M16069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the viral entry into the host cell. [GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VIRAL_ENTRY_INTO_HOST_CELL
Systematic name | M14436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the entry of viral entry into a host cell. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_CENTRIOLE_REPLICATION
Systematic name | M11992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the formation of a daughter centriole of an existing centriole. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CENTRIOLE_REPLICATION
Systematic name | M23794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of centriole replication. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CENTRIOLE_REPLICATION
Systematic name | M23795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of centriole replication. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_MITOTIC_CENTROSOME_SEPARATION
Systematic name | M23796
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the separation of duplicated centrosome components at the beginning of mitosis. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_CENTROSOME_CYCLE
Systematic name | M13491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the centrosome cycle, the processes of centrosome duplication and separation. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CENTROSOME_CYCLE
Systematic name | M23797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the centrosome cycle. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CENTROSOME_CYCLE
Systematic name | M23798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the centrosome cycle. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_ORGAN_GROWTH
Systematic name | M12853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of growth of an organ of an organism. [GOC:bf, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ORGAN_GROWTH
Systematic name | M12014
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of growth of an organ of an organism. [GOC:bf, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ORGAN_GROWTH
Systematic name | M16165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of growth of an organ of an organism. [GOC:bf, GOC:tb]
Full description |

Standard name | GO_GAMMA_DELTA_T_CELL_ACTIVATION
Systematic name | M23799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a gamma-delta T cell resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific. [GOC:add]
Full description |

Standard name | GO_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M14300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of an alpha-beta T cell resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific. [GOC:add]
Full description |

Standard name | GO_ALPHA_BETA_T_CELL_DIFFERENTIATION
Systematic name | M10942
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of an alpha-beta T cell. An alpha-beta T cell is a T cell that expresses an alpha-beta T cell receptor complex. [CL:0000789, GOC:ai]
Full description |

Standard name | GO_ALPHA_BETA_T_CELL_PROLIFERATION
Systematic name | M23800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of an alpha-beta T cell population by cell division. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M10453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of alpha-beta T cell activation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M16840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of alpha-beta T cell activation. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M15072
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of alpha-beta T cell activation. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_ALPHA_BETA_T_CELL_DIFFERENTIATION
Systematic name | M13365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of alpha-beta T cell differentiation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ALPHA_BETA_T_CELL_DIFFERENTIATION
Systematic name | M15528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of alpha-beta T cell differentiation. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ALPHA_BETA_T_CELL_DIFFERENTIATION
Systematic name | M15480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of alpha-beta T cell differentiation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ALPHA_BETA_T_CELL_PROLIFERATION
Systematic name | M13471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of alpha-beta T cell proliferation. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ALPHA_BETA_T_CELL_PROLIFERATION
Systematic name | M23801
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of alpha-beta T cell proliferation. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_GAMMA_DELTA_T_CELL_ACTIVATION
Systematic name | M23802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gamma-delta T cell activation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GAMMA_DELTA_T_CELL_ACTIVATION
Systematic name | M23803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of gamma-delta T cell activation. [GOC:ai]
Full description |

Standard name | GO_LYMPHOCYTE_ACTIVATION
Systematic name | M2297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in morphology and behavior of a lymphocyte resulting from exposure to a specific antigen, mitogen, cytokine, chemokine, cellular ligand, or soluble factor. [GOC:mgi_curators, ISBN:0781735149]
Full description |

Standard name | GO_TETRAHYDROFOLATE_METABOLIC_PROCESS
Systematic name | M13150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving tetrahydrofolate, 5,6,7,8-tetrahydrofolic acid, a folate derivative bearing additional hydrogens on the pterin group. [ISBN:0198506732]
Full description |

Standard name | GO_TETRAHYDROFOLATE_BIOSYNTHETIC_PROCESS
Systematic name | M23804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of tetrahydrofolate, 5,6,7,8-tetrahydrofolic acid, a folate derivative bearing additional hydrogens on the pterin group. [ISBN:0198506732]
Full description |

Standard name | GO_FOLIC_ACID_METABOLIC_PROCESS
Systematic name | M16344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving folic acid, pteroylglutamic acid. Folic acid is widely distributed as a member of the vitamin B complex and is essential for the synthesis of purine and pyrimidines. [ISBN:0198506732]
Full description |

Standard name | GO_FEMALE_SEX_DIFFERENTIATION
Systematic name | M13728
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment of the sex of a female organism by physical differentiation. [GOC:bf]
Full description |

Standard name | GO_MALE_SEX_DIFFERENTIATION
Systematic name | M16772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment of the sex of a male organism by physical differentiation. [GOC:bf]
Full description |

Standard name | GO_RETINAL_CELL_PROGRAMMED_CELL_DEATH
Systematic name | M34194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Programmed cell death that occurs in the developing retina. [GOC:bf]
Full description |

Standard name | GO_RESPONSE_TO_ANTIBIOTIC
Systematic name | M15489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an antibiotic stimulus. An antibiotic is a chemical substance produced by a microorganism which has the capacity to inhibit the growth of or to kill other microorganisms. [GOC:ai, GOC:ef]
Full description |

Standard name | GO_RESPONSE_TO_ORGANOPHOSPHORUS
Systematic name | M10407
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organophosphorus stimulus. Organophosphorus is a compound containing phosphorus bound to an organic molecule; several organophosphorus compounds are used as insecticides, and they are highly toxic cholinesterase inhibitors. [ISBN:0721662544]
Full description |

Standard name | GO_RESPONSE_TO_ARSENIC_CONTAINING_SUBSTANCE
Systematic name | M14803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an arsenic stimulus from compounds containing arsenic, including arsenates, arsenites, and arsenides. [GOC:hjd, ISBN:0721662544]
Full description |

Standard name | GO_RESPONSE_TO_CADMIUM_ION
Systematic name | M15781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cadmium (Cd) ion stimulus. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_COPPER_ION
Systematic name | M11424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a copper ion stimulus. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_MERCURY_ION
Systematic name | M15754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mercury ion stimulus. [GOC:ai]
Full description |

Standard name | GO_DECIDUALIZATION
Systematic name | M12009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular and vascular changes occurring in the endometrium of the pregnant uterus just after the onset of blastocyst implantation. This process involves the proliferation and differentiation of the fibroblast-like endometrial stromal cells into large, polyploid decidual cells that eventually form the maternal component of the placenta. [ISBN:0721662544, PMID:11133685]
Full description |

Standard name | GO_GDP_METABOLIC_PROCESS
Systematic name | M14399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving GDP, guanosine 5'-diphosphate. [GOC:ai]
Full description |

Standard name | GO_MUSCLE_CELL_CELLULAR_HOMEOSTASIS
Systematic name | M14949
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular homeostatic process that preserves a muscle cell in a stable functional or structural state. [GOC:mah, PMID:3091429, PMID:7781901]
Full description |

Standard name | GO_ACID_SECRETION
Systematic name | M10367
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled release of acid by a cell or a tissue. [GOC:ai]
Full description |

Standard name | GO_REGULATION_BY_VIRUS_OF_VIRAL_PROTEIN_LEVELS_IN_HOST_CELL
Systematic name | M10918
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any virus-mediated process that modulates the levels of viral proteins in a cell. [GOC:ai]
Full description |

Standard name | GO_VIRAL_BUDDING
Systematic name | M23806
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A viral process by which enveloped viruses acquire a host-derived membrane enriched in viral proteins to form their external envelope. The process starts when nucleocapsids, assembled or in the process of being built, induce formation of a membrane curvature in the host plasma or organelle membrane and wrap up in the forming bud. The process ends when the bud is eventually pinched off by membrane scission to release the enveloped particle into the lumenal or extracellular space. [ISBN:0781718325, VZ:1947]
Full description |

Standard name | GO_PROTEIN_AUTOPHOSPHORYLATION
Systematic name | M16011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The phosphorylation by a protein of one or more of its own amino acid residues (cis-autophosphorylation), or residues on an identical protein (trans-autophosphorylation). [ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_VIRAL_TRANSCRIPTION
Systematic name | M14372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the transcription of the viral genome. [GOC:ai]
Full description |

Standard name | GO_MICROTUBULE_POLYMERIZATION
Systematic name | M16607
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of tubulin heterodimers to one or both ends of a microtubule. [GOC:ai, GOC:go_curators]
Full description |

Standard name | GO_RECEPTOR_MEDIATED_VIRION_ATTACHMENT_TO_HOST_CELL
Systematic name | M23808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process by which a virion attaches to a host cell by binding to a receptor on the host cell surface. [ISBN:0879694971]
Full description |

Standard name | GO_REGULATION_OF_NUCLEOCYTOPLASMIC_TRANSPORT
Systematic name | M12698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of substances between the nucleus and the cytoplasm. [GOC:bf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NUCLEOCYTOPLASMIC_TRANSPORT
Systematic name | M13384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of substances between the cytoplasm and the nucleus. [GOC:bf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NUCLEOCYTOPLASMIC_TRANSPORT
Systematic name | M13934
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of substances between the nucleus and the cytoplasm. [GOC:bf]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_EXPORT_FROM_NUCLEUS
Systematic name | M11196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of proteins from the nucleus to the cytoplasm. [GOC:bf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_EXPORT_FROM_NUCLEUS
Systematic name | M23809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of proteins from the nucleus into the cytoplasm. [GOC:bf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_EXPORT_FROM_NUCLEUS
Systematic name | M15643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of directed movement of proteins from the nucleus into the cytoplasm. [GOC:bf]
Full description |

Standard name | GO_REGULATION_OF_RNA_EXPORT_FROM_NUCLEUS
Systematic name | M34195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of RNA from the nucleus to the cytoplasm. [GOC:bf]
Full description |

Standard name | GO_LIPID_PHOSPHORYLATION
Systematic name | M14497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing one or more phosphate groups into a lipid, any member of a group of substances soluble in lipid solvents but only sparingly soluble in aqueous solvents. [GOC:bf, ISBN:0198506732]
Full description |

Standard name | GO_CARBOHYDRATE_PHOSPHORYLATION
Systematic name | M11297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing a phosphate group into a carbohydrate, any organic compound based on the general formula Cx(H2O)y. [ISBN:0198506732]
Full description |

Standard name | GO_GLYCOLIPID_TRANSPORT
Systematic name | M23810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of glycolipids, compounds containing (usually) 1-4 linked monosaccharide residues joined by a glycosyl linkage to a lipid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_PHOSPHORYLATED_CARBOHYDRATE_DEPHOSPHORYLATION
Systematic name | M23811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of removing a phosphate group from a phosphorylated carbohydrate, any organic compound based on the general formula Cx(H2O)y with a phosphate group attached to it. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHOLIPID_DEPHOSPHORYLATION
Systematic name | M10903
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of removing one or more phosphate groups from a phosphorylated lipid, any member of a group of substances soluble in lipid solvents but only sparingly soluble in aqueous solvents. [ISBN:0198506732]
Full description |

Standard name | GO_FILOPODIUM_ASSEMBLY
Systematic name | M16674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The assembly of a filopodium, a thin, stiff protrusion extended by the leading edge of a motile cell such as a crawling fibroblast or amoeba, or an axonal growth cone. [GOC:dph, GOC:mah, GOC:tb, PMID:16337369, PMID:18464790]
Full description |

Standard name | GO_BONE_REMODELING
Systematic name | M2217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The continuous turnover of bone matrix and mineral that involves first, an increase in resorption (osteoclastic activity) and later, reactive bone formation (osteoblastic activity). The process of bone remodeling takes place in the adult skeleton at discrete foci. The process ensures the mechanical integrity of the skeleton throughout life and plays an important role in calcium homeostasis. An imbalance in the regulation of bone resorption and bone formation results in many of the metabolic bone diseases, such as osteoporosis. [GOC:curators]
Full description |

Standard name | GO_REGULATION_OF_BONE_REMODELING
Systematic name | M13521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of bone remodeling, the processes of bone formation and resorption that combine to maintain skeletal integrity. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BONE_REMODELING
Systematic name | M11510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of bone remodeling. [GOC:ai]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_PHOSPHORYLATION
Systematic name | M23812
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing one or more phosphate groups into a phosphatidylinositol, any glycerophosphoinositol having one phosphatidyl group esterified to one of the hydroxy groups of inositol. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_DEPHOSPHORYLATION
Systematic name | M13981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of removing one or more phosphate groups from a phosphatidylinositol. [ISBN:0198506732]
Full description |

Standard name | GO_QUINOLINATE_METABOLIC_PROCESS
Systematic name | M29219
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving quinolinate, the anion of quinolinic acid, also known as 2,3-pyridinedicarboxylic acid. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_SALIVA_SECRETION
Systematic name | M23813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of saliva from a cell or a tissue. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_HORMONE_SECRETION
Systematic name | M16778
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of a hormone from a cell. [GOC:ai]
Full description |

Standard name | GO_FOLLICLE_STIMULATING_HORMONE_SECRETION
Systematic name | M23814
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of follicle-stimulating hormone, a gonadotropic glycoprotein hormone secreted by the anterior pituitary. [ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_HORMONE_BIOSYNTHETIC_PROCESS
Systematic name | M13824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of hormones. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HORMONE_BIOSYNTHETIC_PROCESS
Systematic name | M23815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of hormones. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HORMONE_SECRETION
Systematic name | M13625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the regulated release of a hormone from a cell. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HORMONE_SECRETION
Systematic name | M14459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the regulated release of a hormone from a cell. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPID_BIOSYNTHETIC_PROCESS
Systematic name | M15494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of lipids. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_LIPID_BIOSYNTHETIC_PROCESS
Systematic name | M12119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of lipids. [GOC:ai]
Full description |

Standard name | GO_SECRETION
Systematic name | M13582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled release of a substance by a cell or a tissue. [GOC:ai]
Full description |

Standard name | GO_INTRACELLULAR_TRANSPORT
Systematic name | M23816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances within a cell. [GOC:ai]
Full description |

Standard name | GO_CELLULAR_TRANSITION_METAL_ION_HOMEOSTASIS
Systematic name | M15481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of transition metal ions at the level of a cell. A transition metal is an element whose atom has an incomplete d-subshell of extranuclear electrons, or which gives rise to a cation or cations with an incomplete d-subshell. Transition metals often have more than one valency state. Biologically relevant transition metals include vanadium, manganese, iron, copper, cobalt, nickel, molybdenum and silver. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEUROTRANSMITTER_SECRETION
Systematic name | M12855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the regulated release of a neurotransmitter. [GOC:ai]
Full description |

Standard name | GO_PORE_COMPLEX_ASSEMBLY
Systematic name | M13274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a pore complex. A pore complex is a small opening in a membrane that allows the passage of liquids and/or gases. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_NUCLEOTIDE_PHOSPHORYLATION
Systematic name | M10234
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing one or more phosphate groups into a nucleotide to produce a phosphorylated nucleoside. [GOC:ai]
Full description |

Standard name | GO_NUCLEOSIDE_MONOPHOSPHATE_PHOSPHORYLATION
Systematic name | M23817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing one or more phosphate groups into a nucleoside monophosphate to produce a polyphosphorylated nucleoside. [GOC:ai]
Full description |

Standard name | GO_FATTY_ACYL_COA_BIOSYNTHETIC_PROCESS
Systematic name | M23818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a fatty-acyl-CoA, any derivative of coenzyme A in which the sulfhydryl group is in thiolester linkage with a fatty-acyl group. [ISBN:0198506732]
Full description |

Standard name | GO_KETONE_BODY_BIOSYNTHETIC_PROCESS
Systematic name | M23820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of ketone bodies, any one of the three substances: acetoacetate, D-3-hydroxybutyrate (beta-hydroxybutyrate) or acetone. Biosynthesis involves the formation of hydroxymethylglutaryl-CoA, which is cleaved to acetate and acetyl-CoA. [ISBN:0198506732]
Full description |

Standard name | GO_NONASSOCIATIVE_LEARNING
Systematic name | M23821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A simple form of learning whereby the repeated presence of a stimulus leads to a change in the probability or strength of the response to that stimulus. There is no association of one type of stimulus with another, rather it is a generalized response to the environment. [ISBN:0582227089]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_OSMOTIC_STRESS
Systematic name | M23822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or extent of the response to osmotic stress. [GOC:ai]
Full description |

Standard name | GO_VESICLE_TRANSPORT_ALONG_MICROTUBULE
Systematic name | M34196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a vesicle along a microtubule, mediated by motor proteins. This process begins with the attachment of a vesicle to a microtubule, and ends when the vesicle reaches its final destination. [GOC:ecd, GOC:rl]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_PEPTIDE_ANTIGEN
Systematic name | M11444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses peptide antigen in association with an MHC protein complex on its cell surface, including proteolysis and transport steps for the peptide antigen both prior to and following assembly with the MHC protein complex. The peptide antigen is typically, but not always, processed from an endogenous or exogenous protein. [GOC:add, ISBN:0781735149, PMID:15771591]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_LIPID_ANTIGEN_VIA_MHC_CLASS_IB
Systematic name | M23823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses lipid antigen in association with an MHC class Ib protein complex on its cell surface, including lipid extraction, degradation, and transport steps for the lipid antigen both prior to and following assembly with the MHC protein complex. The lipid antigen may originate from an endogenous or exogenous source of lipid. Class Ib here refers to non-classical class I molecules, such as those of the CD1 family. [GOC:add, PMID:10375559, PMID:15928678, PMID:15928680]
Full description |

Standard name | GO_ANTIGEN_PROCESSING_AND_PRESENTATION_ENDOGENOUS_LIPID_ANTIGEN_VIA_MHC_CLASS_IB
Systematic name | M23824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an antigen-presenting cell expresses lipid antigen of endogenous origin in association with an MHC class Ib protein complex on its cell surface. Class Ib here refers to non-classical class I molecules, such as those of the CD1 family. [GOC:add, PMID:10375559, PMID:15928678, PMID:15928680]
Full description |

Standard name | GO_PLATELET_DERIVED_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M10050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a platelet-derived growth factor receptor binding to one of its physiological ligands. [GOC:ceb]
Full description |

Standard name | GO_INSULIN_LIKE_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12608
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of the insulin-like growth factor receptor binding to one of its physiological ligands. [GOC:ceb]
Full description |

Standard name | GO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals initiated by the binding of an extracellular ligand to a vascular endothelial growth factor receptor (VEGFR) located on the surface of the receiving cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:ceb, GOC:signaling]
Full description |

Standard name | GO_NEUROTROPHIN_TRK_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M15971
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a neurotrophin to a receptor on the surface of the target cell where the receptor possesses tyrosine kinase activity, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, GOC:ceb, GOC:jc, GOC:signaling, PMID:12065629, Wikipedia:Trk_receptor]
Full description |

Standard name | GO_HEPATOCYTE_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23825
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of the hepatocyte growth factor receptor binding to one of its physiological ligands. [GOC:ceb]
Full description |

Standard name | GO_EPHRIN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M13554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of an ephrin receptor binding to an ephrin. [GOC:ceb]
Full description |

Standard name | GO_INOSITOL_PHOSPHATE_MEDIATED_SIGNALING
Systematic name | M15859
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any intracellular signal transduction in which the signal is passed on within the cell via an inositol phosphate. Includes production of the inositol phosphate, and downstream effectors that further transmit the signal within the cell. Inositol phosphates are a group of mono- to poly-phosphorylated inositols, and include inositol monophosphate (IP), inositol trisphosphate (IP3), inositol pentakisphosphate (IP5) and inositol hexaphosphate (IP6). [GOC:bf, GOC:ceb, GOC:signaling, ISBN:0198506732, PMID:11331907]
Full description |

Standard name | GO_INOSITOL_LIPID_MEDIATED_SIGNALING
Systematic name | M16879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which a cell uses an inositol-containing lipid to convert a signal into a response. Inositol lipids include the phosphoinositides (phosphatidylinositol and its phosphorylated derivatives), ceramides containing inositol, and inositol glycolipids. [GOC:bf, GOC:ceb, PMID:16088939]
Full description |

Standard name | GO_REGULATION_OF_MRNA_SPLICING_VIA_SPLICEOSOME
Systematic name | M14810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mRNA splicing via a spliceosomal mechanism. [GOC:jid]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MRNA_SPLICING_VIA_SPLICEOSOME
Systematic name | M16965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of mRNA splicing via a spliceosomal mechanism. [GOC:jid]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MRNA_SPLICING_VIA_SPLICEOSOME
Systematic name | M12154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of mRNA splicing via a spliceosomal mechanism. [GOC:jid]
Full description |

Standard name | GO_FOCAL_ADHESION_ASSEMBLY
Systematic name | M10965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation and bonding together of a set of components to form a focal adhesion, a complex of intracellular signaling and structural proteins that provides a structural link between the internal actin cytoskeleton and the ECM, and also function as a locus of signal transduction activity. [GOC:jid, GOC:mah]
Full description |

Standard name | GO_EMBRYONIC_EYE_MORPHOGENESIS
Systematic name | M15167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process occurring in the embryo by which the anatomical structures of the post-embryonic eye are generated and organized. [GOC:jid]
Full description |

Standard name | GO_POST_EMBRYONIC_EYE_MORPHOGENESIS
Systematic name | M23827
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process, occurring after embryonic development, by which the anatomical structures of the eye are generated and organized. The eye is the organ of sight. [GOC:jid, GOC:sensu]
Full description |

Standard name | GO_DEVELOPMENTAL_PIGMENTATION
Systematic name | M14311
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process that results in the deposition of coloring matter in an organism, tissue or cell. [ISBN:0582227089]
Full description |

Standard name | GO_EYE_PIGMENTATION
Systematic name | M23828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Establishment of a pattern of pigment in the eye of an organism. [GOC:jid]
Full description |

Standard name | GO_REGULATION_OF_DEVELOPMENTAL_PIGMENTATION
Systematic name | M16711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the developmental process that results in the deposition of coloring matter in an organism. [GOC:dph, GOC:jid, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DEVELOPMENTAL_PIGMENTATION
Systematic name | M23829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the developmental process that results in the deposition of coloring matter in an organism. [GOC:dph, GOC:jid, GOC:tb]
Full description |

Standard name | GO_CHROMATIN_MEDIATED_MAINTENANCE_OF_TRANSCRIPTION
Systematic name | M23830
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Maintenance of transcription by remodelling of chromatin into an 'open configuration'. Once established, this regulation is mitotically stable and is maintained over many cell divisions. It is also heritable. [GOC:jid]
Full description |

Standard name | GO_AUTOPHAGIC_CELL_DEATH
Systematic name | M23831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A form of programmed cell death that is accompanied by the formation of autophagosomes. Autophagic cell death is characterized by lack of chromatin condensation and massive vacuolization of the cytoplasm, with little or no uptake by phagocytic cells. [GOC:autophagy, GOC:mah, GOC:mtg_apoptosis, PMID:18846107, PMID:23347517]
Full description |

Standard name | GO_SOMATIC_STEM_CELL_DIVISION
Systematic name | M14798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The self-renewing division of a somatic stem cell, a stem cell that can give rise to cell types of the body other than those of the germ-line. [GOC:jid, ISBN:0582227089]
Full description |

Standard name | GO_ASTROCYTE_ACTIVATION
Systematic name | M23832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in morphology and behavior of an astrocyte resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. [GOC:mgi_curators, PMID:10526094, PMID:10695728, PMID:12529254, PMID:12580336, PMID:9585813]
Full description |

Standard name | GO_FIBROBLAST_PROLIFERATION
Systematic name | M23833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of fibroblast cells, resulting in the expansion of the fibroblast population. [GOC:jid]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FIBROBLAST_PROLIFERATION
Systematic name | M10907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of multiplication or reproduction of fibroblast cells. [GOC:jid]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FIBROBLAST_PROLIFERATION
Systematic name | M11687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of multiplication or reproduction of fibroblast cells. [GOC:jid]
Full description |

Standard name | GO_BEHAVIORAL_RESPONSE_TO_COCAINE
Systematic name | M14731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in the behavior of an organism as a result of a cocaine stimulus. [GOC:jid]
Full description |

Standard name | GO_BEHAVIORAL_RESPONSE_TO_ETHANOL
Systematic name | M23834
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in the behavior of an organism as a result of an ethanol stimulus. [GOC:jid]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_PLASTICITY
Systematic name | M12474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates synaptic plasticity, the ability of synapses to change as circumstances require. They may alter function, such as increasing or decreasing their sensitivity, or they may increase or decrease in actual numbers. [GOC:dph, GOC:jid, GOC:tb, PMID:11891290]
Full description |

Standard name | GO_REGULATION_OF_NEURONAL_SYNAPTIC_PLASTICITY
Systematic name | M10720
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates neuronal synaptic plasticity, the ability of neuronal synapses to change as circumstances require. They may alter function, such as increasing or decreasing their sensitivity, or they may increase or decrease in actual numbers. [GOC:jid, PMID:11891290]
Full description |

Standard name | GO_REGULATION_OF_LONG_TERM_NEURONAL_SYNAPTIC_PLASTICITY
Systematic name | M14794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates long-term neuronal synaptic plasticity, the ability of neuronal synapses to change long-term as circumstances require. Long-term neuronal synaptic plasticity generally involves increase or decrease in actual synapse numbers. [GOC:jid, PMID:11891290]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LONG_TERM_NEURONAL_SYNAPTIC_PLASTICITY
Systematic name | M23835
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that increases long-term neuronal synaptic plasticity, the ability of neuronal synapses to change long-term as circumstances require. Long-term neuronal synaptic plasticity generally involves increase or decrease in actual synapse numbers. [GOC:jid, PMID:11891290]
Full description |

Standard name | GO_REGULATION_OF_SHORT_TERM_NEURONAL_SYNAPTIC_PLASTICITY
Systematic name | M11095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates short-term neuronal synaptic plasticity, the ability of neuronal synapses to change in the short-term as circumstances require. Short-term neuronal synaptic plasticity generally involves increasing or decreasing synaptic sensitivity. [GOC:jid, PMID:11891290]
Full description |

Standard name | GO_GOLGI_VESICLE_TRANSPORT
Systematic name | M18265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances into, out of or within the Golgi apparatus, mediated by vesicles. [GOC:jid, ISBN:0716731363, PMID:10219233]
Full description |

Standard name | GO_GOLGI_VESICLE_BUDDING
Systematic name | M23836
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The evagination of the Golgi membrane, resulting in formation of a vesicle. [GOC:jid, ISBN:0716731363, PMID:10219233]
Full description |

Standard name | GO_VESICLE_TARGETING_TO_FROM_OR_WITHIN_GOLGI
Systematic name | M23837
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which vesicles are directed to specific destination membranes during transport to, from or within the Golgi apparatus; mediated by the addition of specific coat proteins, including COPI and COPII proteins and clathrin, to the membrane during vesicle formation. [GOC:jid, GOC:mah, ISBN:0716731363, PMID:10219233]
Full description |

Standard name | GO_REGULATION_OF_VESICLE_TARGETING_TO_FROM_OR_WITHIN_GOLGI
Systematic name | M23838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or destination of vesicle-mediated transport to, from or within the Golgi apparatus. [GOC:jid, GOC:mah, ISBN:0716731363, PMID:10219233]
Full description |

Standard name | GO_PLASMA_MEMBRANE_TO_ENDOSOME_TRANSPORT
Systematic name | M23839
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Transport of a vesicle from the plasma membrane to the endosome. [GOC:jid]
Full description |

Standard name | GO_MALE_GAMETE_GENERATION
Systematic name | M11476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Generation of the male gamete; specialised haploid cells produced by meiosis and along with a female gamete takes part in sexual reproduction. [GOC:dph, GOC:jid]
Full description |

Standard name | GO_SPERM_CAPACITATION
Systematic name | M11985
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process required for sperm to reach fertilization competence. Sperm undergo an incompletely understood series of morphological and molecular maturational processes, termed capacitation, involving, among other processes, protein tyrosine phosphorylation and increased intracellular calcium. [GOC:jid, ISBN:978-3-642-58301-8, PMID:11820818]
Full description |

Standard name | GO_EPINEPHRINE_TRANSPORT
Systematic name | M23840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of epinephrine into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:jid]
Full description |

Standard name | GO_NOREPINEPHRINE_SECRETION
Systematic name | M23841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of norepinephrine by a cell. Norepinephrine is a catecholamine and it acts as a hormone and as a neurotransmitter of most of the sympathetic nervous system. [GOC:ef, GOC:jid]
Full description |

Standard name | GO_EOSINOPHIL_CHEMOTAXIS
Systematic name | M23842
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of an eosinophil in response to an external stimulus. [GOC:jid, PMID:11292027, PMID:12391252]
Full description |

Standard name | GO_MACROPHAGE_CHEMOTAXIS
Systematic name | M14291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a macrophage in response to an external stimulus. [GOC:jid]
Full description |

Standard name | GO_LYMPHOCYTE_CHEMOTAXIS
Systematic name | M14280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a lymphocyte in response to an external stimulus. [GOC:hjd, GOC:jid, PMID:12391252]
Full description |

Standard name | GO_ELASTIC_FIBER_ASSEMBLY
Systematic name | M23843
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Assembly of the extracellular matrix fibers that enables the matrix to recoil after transient stretching. [GOC:jid, PMID:10841810, PMID:12615674]
Full description |

Standard name | GO_SNORNA_LOCALIZATION
Systematic name | M23844
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which small nucleolar RNA is transported to, or maintained in, a specific location. [ISBN:0716731363]
Full description |

Standard name | GO_REGULATION_OF_RECEPTOR_MEDIATED_ENDOCYTOSIS
Systematic name | M12909
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of receptor mediated endocytosis, the uptake of external materials by cells, utilizing receptors to ensure specificity of transport. [GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RECEPTOR_MEDIATED_ENDOCYTOSIS
Systematic name | M11511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of receptor mediated endocytosis, the uptake of external materials by cells, utilizing receptors to ensure specificity of transport. [GOC:go_curators, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RECEPTOR_MEDIATED_ENDOCYTOSIS
Systematic name | M15867
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of receptor mediated endocytosis, the uptake of external materials by cells, utilizing receptors to ensure specificity of transport. [GOC:go_curators]
Full description |

Standard name | GO_DETERMINATION_OF_DORSAL_VENTRAL_ASYMMETRY
Systematic name | M23845
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Determination of asymmetry from the dorsal to the ventral side; as, the dorsoventral axis. [GOC:jid]
Full description |

Standard name | GO_RESPONSE_TO_PAIN
Systematic name | M12693
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a pain stimulus. Pain stimuli cause activation of nociceptors, peripheral receptors for pain, include receptors which are sensitive to painful mechanical stimuli, extreme heat or cold, and chemical stimuli. [GOC:jid, PMID:10203867, PMID:12723742, PMID:12843304, Wikipedia:Pain]
Full description |

Standard name | GO_BEHAVIORAL_RESPONSE_TO_PAIN
Systematic name | M12655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in the behavior of an organism as a result of a pain stimulus. Pain stimuli cause activation of nociceptors, peripheral receptors for pain, include receptors which are sensitive to painful mechanical stimuli, extreme heat or cold, and chemical stimuli. [GOC:jid]
Full description |

Standard name | GO_CLATHRIN_COAT_ASSEMBLY
Systematic name | M11401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in the assembly of clathrin triskelia into the ordered structure known as a clathrin cage. [GOC:jid, PMID:11460887, PMID:11977118, PMID:9531549]
Full description |

Standard name | GO_VESICLE_DOCKING
Systematic name | M15765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial attachment of a transport vesicle membrane to the target membrane, mediated by proteins protruding from the membrane of the vesicle and the target membrane. Docking requires only that the two membranes come close enough for these proteins to interact and adhere. [GOC:ai, GOC:jid]
Full description |

Standard name | GO_VESICLE_FUSION_WITH_GOLGI_APPARATUS
Systematic name | M23846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The joining of the lipid bilayer membrane around a vesicle to the lipid bilayer membrane around the Golgi. [GOC:jid]
Full description |

Standard name | GO_ORGANELLE_FUSION
Systematic name | M16852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The creation of a single organelle from two or more organelles. [GOC:jid]
Full description |

Standard name | GO_ORGANELLE_FISSION
Systematic name | M12565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The creation of two or more organelles by division of one organelle. [GOC:jid]
Full description |

Standard name | GO_LUNG_ALVEOLUS_DEVELOPMENT
Systematic name | M16792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the alveolus over time, from its formation to the mature structure. The alveolus is a sac for holding air in the lungs; formed by the terminal dilation of air passageways. [GOC:mtg_lung, PMID:9751757]
Full description |

Standard name | GO_ISOTYPE_SWITCHING_TO_IGA_ISOTYPES
Systematic name | M23847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The switching of activated B cells from IgM biosynthesis to biosynthesis of an IgA isotype, accomplished through a recombination process involving an intrachromosomal deletion between switch regions that reside 5' of the IgM and one of the IgA constant region gene segments in the immunoglobulin heavy chain locus. [ISBN:0781735149, PMID:12370374, PMID:2113175, PMID:9186655]
Full description |

Standard name | GO_ISOTYPE_SWITCHING_TO_IGG_ISOTYPES
Systematic name | M23848
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The switching of activated B cells from IgM biosynthesis to biosynthesis of an IgG isotype, accomplished through a recombination process involving an intrachromosomal deletion between switch regions that reside 5' of the IgM and one of the IgG constant region gene segments in the immunoglobulin heavy chain locus. [ISBN:0781735149, PMID:12370374, PMID:2113175, PMID:9186655]
Full description |

Standard name | GO_REGULATION_OF_ISOTYPE_SWITCHING_TO_IGE_ISOTYPES
Systematic name | M23849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of isotype switching to IgE isotypes. [GOC:jid]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ISOTYPE_SWITCHING_TO_IGA_ISOTYPES
Systematic name | M23850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of isotype switching to IgA isotypes. [GOC:jid]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ISOTYPE_SWITCHING_TO_IGG_ISOTYPES
Systematic name | M23851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of isotype switching to IgG isotypes. [GOC:jid]
Full description |

Standard name | GO_IMMUNOGLOBULIN_SECRETION
Systematic name | M23852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of immunoglobulins from a B cell or plasma cell, whose mechanism includes the use of alternate polyadenylylation signals to favor the biosynthesis of secreted forms of immunoglobulin over membrane-bound immunoglobulin. [GOC:add, ISBN:0781735149, PMID:9185563]
Full description |

Standard name | GO_ORGANELLE_INHERITANCE
Systematic name | M15037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The partitioning of organelles between daughter cells at cell division. [GOC:jid]
Full description |

Standard name | GO_MITOCHONDRION_DISTRIBUTION
Systematic name | M16115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that establishes the spatial arrangement of mitochondria between and within cells. [GOC:jid]
Full description |

Standard name | GO_INTRACELLULAR_DISTRIBUTION_OF_MITOCHONDRIA
Systematic name | M23853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that establishes the spatial arrangement of mitochondria within the cell. [GOC:jid]
Full description |

Standard name | GO_AXIAL_MESODERM_DEVELOPMENT
Systematic name | M23854
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the axial mesoderm over time, from its formation to the mature structure. The axial mesoderm includes the prechordal mesoderm and the chordamesoderm. It gives rise to the prechordal plate and to the notochord. [GOC:dgh]
Full description |

Standard name | GO_MESODERM_MORPHOGENESIS
Systematic name | M13650
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the mesoderm are generated and organized. [GOC:go_curators]
Full description |

Standard name | GO_MESODERMAL_CELL_DIFFERENTIATION
Systematic name | M14281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a mesoderm cell. [GOC:dgh]
Full description |

Standard name | GO_PARAXIAL_MESODERM_DEVELOPMENT
Systematic name | M15054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the paraxial mesoderm over time, from its formation to the mature structure. The paraxial mesoderm is the mesoderm located bilaterally adjacent to the notochord and neural tube. [GOC:dgh]
Full description |

Standard name | GO_PARAXIAL_MESODERM_MORPHOGENESIS
Systematic name | M23855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the paraxial mesoderm are generated and organized. [GOC:go_curators]
Full description |

Standard name | GO_PARAXIAL_MESODERM_FORMATION
Systematic name | M23856
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that gives rise to the paraxial mesoderm. This process pertains to the initial formation of the structure from unspecified parts. [GOC:dgh]
Full description |

Standard name | GO_LATERAL_MESODERM_DEVELOPMENT
Systematic name | M12169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the lateral mesoderm over time, from its formation to the mature structure. [GOC:go_curators]
Full description |

Standard name | GO_MESENDODERM_DEVELOPMENT
Systematic name | M23857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the mesendoderm over time, from its formation to the mature structure. In animal embryos, mesendoderm development gives rise to both mesoderm and endoderm tissues. [GOC:jid]
Full description |

Standard name | GO_RETINOIC_ACID_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M16403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a retinoic acid receptor binding to one of its physiological ligands. [GOC:dgh]
Full description |

Standard name | GO_REGULATION_OF_RETINOIC_ACID_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M11133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of retinoic acid receptor signaling pathway activity. [GOC:dgh]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RETINOIC_ACID_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M34197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of retinoic acid receptor signaling pathway activity. [GOC:dgh]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RETINOIC_ACID_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of retinoic acid receptor signaling pathway activity. [GOC:dgh]
Full description |

Standard name | GO_CELL_MATURATION
Systematic name | M12957
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for a cell to attain its fully functional state. [GOC:go_curators]
Full description |

Standard name | GO_OOGENESIS
Systematic name | M11093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The complete process of formation and maturation of an ovum or female gamete from a primordial female germ cell. Examples of this process are found in Mus musculus and Drosophila melanogaster. [GOC:kmv, GOC:mtg_sensu, GOC:pr]
Full description |

Standard name | GO_REPLICATION_FORK_PROTECTION
Systematic name | M23858
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that prevents the collapse of stalled replication forks. [GOC:vw, PMID:14560029]
Full description |

Standard name | GO_AUTONOMIC_NERVOUS_SYSTEM_DEVELOPMENT
Systematic name | M15038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the autonomic nervous system over time, from its formation to the mature structure. The autonomic nervous system is composed of neurons that are not under conscious control, and is comprised of two antagonistic components, the sympathetic and parasympathetic nervous systems. The autonomic nervous system regulates key functions including the activity of the cardiac (heart) muscle, smooth muscles (e.g. of the gut), and glands. [FMA:9905, GOC:jid, GOC:sr]
Full description |

Standard name | GO_ENTERIC_NERVOUS_SYSTEM_DEVELOPMENT
Systematic name | M14613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the enteric nervous system over time, from its formation to the mature structure. The enteric nervous system is composed of two ganglionated neural plexuses in the gut wall which form one of the three major divisions of the autonomic nervous system. The enteric nervous system innervates the gastrointestinal tract, the pancreas, and the gall bladder. It contains sensory neurons, interneurons, and motor neurons. Thus the circuitry can autonomously sense the tension and the chemical environment in the gut and regulate blood vessel tone, motility, secretions, and fluid transport. The system is itself governed by the central nervous system and receives both parasympathetic and sympathetic innervation. [FMA:66070, GOC:jid, GOC:sr]
Full description |

Standard name | GO_SYMPATHETIC_NERVOUS_SYSTEM_DEVELOPMENT
Systematic name | M13364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the sympathetic nervous system over time, from its formation to the mature structure. The sympathetic nervous system is one of the two divisions of the vertebrate autonomic nervous system (the other being the parasympathetic nervous system). The sympathetic preganglionic neurons have their cell bodies in the thoracic and lumbar regions of the spinal cord and connect to the paravertebral chain of sympathetic ganglia. Innervate heart and blood vessels, sweat glands, viscera and the adrenal medulla. Most sympathetic neurons, but not all, use noradrenaline as a post-ganglionic neurotransmitter. [FMA:9906, GOC:jid, GOC:sr]
Full description |

Standard name | GO_PARASYMPATHETIC_NERVOUS_SYSTEM_DEVELOPMENT
Systematic name | M16085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the parasympathetic nervous system over time, from its formation to the mature structure. The parasympathetic nervous system is one of the two divisions of the vertebrate autonomic nervous system. Parasympathetic nerves emerge cranially as pre ganglionic fibers from oculomotor, facial, glossopharyngeal and vagus and from the sacral region of the spinal cord. Most neurons are cholinergic and responses are mediated by muscarinic receptors. The parasympathetic system innervates, for example: salivary glands, thoracic and abdominal viscera, bladder and genitalia. [FMA:9907, GOC:jid, GOC:sr]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_TRANSPORT
Systematic name | M29223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of synaptic vesicles. [GOC:aruk, GOC:bc, GOC:jid, GOC:lmg, GOC:pr]
Full description |

Standard name | GO_MAINTENANCE_OF_ANIMAL_ORGAN_IDENTITY
Systematic name | M23859
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the identity of an animal organ is maintained. Identity is considered to be the aggregate of characteristics by which a structure is recognized. [GOC:tb]
Full description |

Standard name | GO_RHYTHMIC_PROCESS
Systematic name | M18740
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process pertinent to the generation and maintenance of rhythms in the physiology of an organism. [GOC:jid]
Full description |

Standard name | GO_BLOOD_VESSEL_MORPHOGENESIS
Systematic name | M13415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of blood vessels are generated and organized. The blood vessel is the vasculature carrying blood. [GOC:jid]
Full description |

Standard name | GO_SPERMATID_DIFFERENTIATION
Systematic name | M6833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a spermatid over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. [GOC:dph, GOC:jid]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BEHAVIOR
Systematic name | M11391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of behavior, the internally coordinated responses (actions or inactions) of whole living organisms (individuals or groups) to internal or external stimuli. [GOC:jid, GOC:pr]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BEHAVIOR
Systematic name | M13816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of behavior, the internally coordinated responses (actions or inactions) of whole living organisms (individuals or groups) to internal or external stimuli. [GOC:jid, GOC:pr]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VIRAL_PROCESS
Systematic name | M16056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of a multi-organism process in which a virus is a participant. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VIRAL_PROCESS
Systematic name | M10974
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a multi-organism process in which a virus is a participant. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_ANATOMICAL_STRUCTURE_ARRANGEMENT
Systematic name | M11732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that gives rise to the configuration of the constituent parts of an anatomical structure. This process pertains to the physical shaping of a rudimentary structure. Anatomical structures can be macroscopic such as a carpel, or microscopic such as an acrosome. [GOC:go_curators]
Full description |

Standard name | GO_LYMPH_NODE_DEVELOPMENT
Systematic name | M11111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of lymph nodes over time, from their formation to the mature structure. A lymph node is a round, oval, or bean shaped structure localized in clusters along the lymphatic vessels, with a distinct internal structure including specialized vasculature and B- and T-zones for the activation of lymphocytes. [GOC:add, ISBN:068340007X, ISBN:0781735149]
Full description |

Standard name | GO_SPLEEN_DEVELOPMENT
Systematic name | M16796
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the spleen over time, from its formation to the mature structure. The spleen is a large vascular lymphatic organ composed of white and red pulp, involved both in hemopoietic and immune system functions. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_MUCOSAL_ASSOCIATED_LYMPHOID_TISSUE_DEVELOPMENT
Systematic name | M23860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of mucosal-associated lymphoid tissue over time, from its formation to the mature structure. Mucosal-associated lymphoid tissue is typically found as nodules associated with mucosal epithelia with distinct internal structures including B- and T-zones for the activation of lymphocytes. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_THYMUS_DEVELOPMENT
Systematic name | M11220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the thymus over time, from its formation to the mature structure. The thymus is a symmetric bi-lobed organ involved primarily in the differentiation of immature to mature T cells, with unique vascular, nervous, epithelial, and lymphoid cell components. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_BONE_MARROW_DEVELOPMENT
Systematic name | M23861
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the bone marrow over time, from its formation to the mature structure. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_RESPONSE_TO_STEROID_HORMONE
Systematic name | M13901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a steroid hormone stimulus. [GOC:go_curators]
Full description |

Standard name | GO_DIGESTIVE_TRACT_MORPHOGENESIS
Systematic name | M13216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the digestive tract are generated and organized. The digestive tract is the anatomical structure through which food passes and is processed. [GOC:dph, GOC:go_curators, PMID:12618131]
Full description |

Standard name | GO_REGULATION_OF_PINOCYTOSIS
Systematic name | M23862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of pinocytosis. Pinocytosis is the process in which cells take in liquid material from their external environment; literally 'cell drinking'. Liquid is enclosed in vesicles, formed by invagination of the plasma membrane. These vesicles then move into the cell and pass their contents to endosomes. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PINOCYTOSIS
Systematic name | M23863
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the rate of pinocytosis. Pinocytosis is the process in which cells take in liquid material from their external environment; literally 'cell drinking'. Liquid is enclosed in vesicles, formed by invagination of the plasma membrane. These vesicles then move into the cell and pass their contents to endosomes. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PINOCYTOSIS
Systematic name | M23864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of pinocytosis. Pinocytosis is the process in which cells take in liquid material from their external environment; literally 'cell drinking'. Liquid is enclosed in vesicles, formed by invagination of the plasma membrane. These vesicles then move into the cell and pass their contents to endosomes. [GOC:go_curators]
Full description |

Standard name | GO_EMBRYONIC_DIGESTIVE_TRACT_MORPHOGENESIS
Systematic name | M12122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the digestive tract are generated and organized during embryonic development. The digestive tract is the anatomical structure through which food passes and is processed. [GOC:go_curators]
Full description |

Standard name | GO_EMBRYONIC_ORGAN_MORPHOGENESIS
Systematic name | M12776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Morphogenesis, during the embryonic phase, of a tissue or tissues that work together to perform a specific function or functions. Morphogenesis is the process in which anatomical structures are generated and organized. Organs are commonly observed as visibly distinct structures, but may also exist as loosely associated clusters of cells that work together to perform a specific function or functions. [GOC:jid]
Full description |

Standard name | GO_POST_EMBRYONIC_ANIMAL_ORGAN_MORPHOGENESIS
Systematic name | M23865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Morphogenesis, during the post-embryonic phase, of an animal tissue or tissues that work together to perform a specific function or functions. Morphogenesis pertains to process in which anatomical structures are generated and organized. Organs are commonly observed as visibly distinct structures, but may also exist as loosely associated clusters of cells that work together to perform a specific function or functions. [GOC:jid]
Full description |

Standard name | GO_EMBRYONIC_DIGESTIVE_TRACT_DEVELOPMENT
Systematic name | M12859
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the gut over time, from its formation to the mature structure during embryonic development. The gut is the region of the digestive tract extending from the beginning of the intestines to the anus. [GOC:go_curators]
Full description |

Standard name | GO_EMBRYONIC_ORGAN_DEVELOPMENT
Systematic name | M16163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Development, taking place during the embryonic phase, of a tissue or tissues that work together to perform a specific function or functions. Development pertains to the process whose specific outcome is the progression of a structure over time, from its formation to the mature structure. Organs are commonly observed as visibly distinct structures, but may also exist as loosely associated clusters of cells that work together to perform a specific function or functions. [GOC:jid]
Full description |

Standard name | GO_POST_EMBRYONIC_ANIMAL_ORGAN_DEVELOPMENT
Systematic name | M23866
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Development, taking place during the post-embryonic phase of an animal tissue or tissues that work together to perform a specific function or functions. Development pertains to the process whose specific outcome is the progression of a structure over time, from its formation to the mature structure. Organs are commonly observed as visibly distinct structures, but may also exist as loosely associated clusters of cells that work together to perform a specific function or functions. [GOC:jid]
Full description |

Standard name | GO_NOTOCHORD_MORPHOGENESIS
Systematic name | M23867
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the notochord are generated and organized. The notochord is a mesoderm-derived structure located ventral of the developing nerve cord. In vertebrates, the notochord serves as a core around which other mesodermal cells form the vertebrae. In the most primitive chordates, which lack vertebrae, the notochord persists as a substitute for a vertebral column. [GOC:jid]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_STIMULUS
Systematic name | M7398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a response to a stimulus. Response to stimulus is a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus. [GOC:jid]
Full description |

Standard name | GO_DEVELOPMENTAL_CELL_GROWTH
Systematic name | M14996
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The growth of a cell, where growth contributes to the progression of the cell over time from one condition to another. [GOC:go_curators, GOC:isa_complete]
Full description |

Standard name | GO_DEVELOPMENTAL_GROWTH
Systematic name | M18572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The increase in size or mass of an entire organism, a part of an organism or a cell, where the increase in size or mass has the specific outcome of the progression of the organism over time from one condition to another. [GOC:go_curators]
Full description |

Standard name | GO_EYE_MORPHOGENESIS
Systematic name | M16960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the eye are generated and organized. [GOC:jid, GOC:mtg_sensu]
Full description |

Standard name | GO_CAMERA_TYPE_EYE_MORPHOGENESIS
Systematic name | M15968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the eye are generated and organized. The camera-type eye is an organ of sight that receives light through an aperture and focuses it through a lens, projecting it on a photoreceptor field. [GOC:jid, GOC:mtg_sensu]
Full description |

Standard name | GO_EMBRYONIC_CAMERA_TYPE_EYE_MORPHOGENESIS
Systematic name | M12711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the eye are generated and organized during embryonic development. [GOC:jid, GOC:mtg_sensu]
Full description |

Standard name | GO_EMBRYONIC_MORPHOGENESIS
Systematic name | M18144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which anatomical structures are generated and organized during the embryonic phase. The embryonic phase begins with zygote formation. The end of the embryonic phase is organism-specific. For example, it would be at birth for mammals, larval hatching for insects and seed dormancy in plants. [GOC:jid, GOC:mtg_sensu]
Full description |

Standard name | GO_MYOBLAST_FATE_COMMITMENT
Systematic name | M23868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the developmental fate of a cell becomes restricted such that it will develop into a myoblast. A myoblast is a mononucleate cell type that, by fusion with other myoblasts, gives rise to the myotubes that eventually develop into skeletal muscle fibers. [CL:0000056, GOC:dph, GOC:mtg_muscle]
Full description |

Standard name | GO_SKELETAL_MUSCLE_TISSUE_GROWTH
Systematic name | M23869
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The increase in size or mass of a skeletal muscle. This may be due to a change in the fiber number or size. [GOC:lm, PMID:15726494, PMID:15907921]
Full description |

Standard name | GO_REGULATION_OF_SKELETAL_MUSCLE_TISSUE_GROWTH
Systematic name | M23870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of skeletal muscle growth. [GOC:lm, PMID:15726494, PMID:15907921]
Full description |

Standard name | GO_REGULATION_OF_MUSCLE_ORGAN_DEVELOPMENT
Systematic name | M23871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of muscle development. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_DEVELOPMENTAL_GROWTH
Systematic name | M10722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of developmental growth. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DEVELOPMENTAL_GROWTH
Systematic name | M13900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the rate of developmental growth. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DEVELOPMENTAL_GROWTH
Systematic name | M11940
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of developmental growth. [GOC:go_curators]
Full description |

Standard name | GO_REGULATION_OF_SKELETAL_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M10364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of skeletal muscle tissue development. [GOC:go_curators]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SKELETAL_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M13853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of skeletal muscle tissue development. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SKELETAL_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M10499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the rate of skeletal muscle tissue development. [GOC:go_curators]
Full description |

Standard name | GO_MUSCLE_ORGAN_MORPHOGENESIS
Systematic name | M13393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of muscle are generated and organized. [GOC:jid]
Full description |

Standard name | GO_ANIMAL_ORGAN_FORMATION
Systematic name | M23872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process pertaining to the initial formation of an animal organ from unspecified parts. The process begins with the specific processes that contribute to the appearance of the discrete structure, such as inductive events, and ends when the structural rudiment of the organ is recognizable, such as a condensation of mesenchymal cells into the organ rudiment. Organs are a natural part or structure in an animal or a plant, capable of performing some special action (termed its function), which is essential to the life or well-being of the whole. The heart and lungs are organs of animals, and the petal and leaf are organs of plants. In animals the organs are generally made up of several tissues, one of which usually predominates, and determines the principal function of the organ. [GOC:dph, GOC:jid]
Full description |

Standard name | GO_ANATOMICAL_STRUCTURE_FORMATION_INVOLVED_IN_MORPHOGENESIS
Systematic name | M8071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of an anatomical structure from unspecified parts. This process begins with the specific processes that contribute to the appearance of the discrete structure and ends when the structural rudiment is recognizable. An anatomical structure is any biological entity that occupies space and is distinguished from its surroundings. Anatomical structures can be macroscopic such as a carpel, or microscopic such as an acrosome. [GOC:dph, GOC:jid, GOC:tb]
Full description |

Standard name | GO_SMOOTH_MUSCLE_CELL_PROLIFERATION
Systematic name | M23873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of smooth muscle cells, resulting in the expansion of a cell population. [CL:0000192, GOC:ebc, PMID:1840698]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SMOOTH_MUSCLE_CELL_PROLIFERATION
Systematic name | M12472
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of smooth muscle cell proliferation. [CL:0000192, GOC:ebc]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMOOTH_MUSCLE_CELL_PROLIFERATION
Systematic name | M10483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of smooth muscle cell proliferation. [CL:0000192, GOC:ebc]
Full description |

Standard name | GO_NEURON_FATE_COMMITMENT
Systematic name | M15345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the developmental fate of a cell becomes restricted such that it will develop into a neuron. [GOC:dph]
Full description |

Standard name | GO_NEURON_FATE_DETERMINATION
Systematic name | M23874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a cell becomes capable of differentiating autonomously into a neuron regardless of its environment; upon determination, the cell fate cannot be reversed. [GOC:dph]
Full description |

Standard name | GO_NEURON_FATE_SPECIFICATION
Systematic name | M13126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a cell becomes capable of differentiating autonomously into a neuron in an environment that is neutral with respect to the developmental pathway. Upon specification, the cell fate can be reversed. [GOC:dph]
Full description |

Standard name | GO_NEURON_DEVELOPMENT
Systematic name | M6784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a neuron over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. [GOC:dph]
Full description |

Standard name | GO_CELL_MORPHOGENESIS_INVOLVED_IN_NEURON_DIFFERENTIATION
Systematic name | M15430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the structures of a neuron are generated and organized. This process occurs while the initially relatively unspecialized cell is acquiring the specialized features of a neuron. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_COLLATERAL_SPROUTING
Systematic name | M23875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which outgrowths develop from the shafts of existing axons. [GOC:dgh, GOC:dph, GOC:jid, GOC:lm]
Full description |

Standard name | GO_COLLATERAL_SPROUTING_IN_ABSENCE_OF_INJURY
Systematic name | M23876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which outgrowths develop from the axons of intact undamaged neurons. [GOC:dgh, GOC:dph, GOC:jid, GOC:lm]
Full description |

Standard name | GO_REGULATION_OF_COLLATERAL_SPROUTING
Systematic name | M10321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of collateral sprouting. [GOC:dgh, GOC:dph, GOC:jid, GOC:lm]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_COLLATERAL_SPROUTING
Systematic name | M23877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of collateral sprouting. [GOC:dgh, GOC:dph, GOC:jid, GOC:lm]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_COLLATERAL_SPROUTING
Systematic name | M23878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of collateral sprouting. [GOC:dgh, GOC:dph, GOC:jid, GOC:lm]
Full description |

Standard name | GO_AXON_EXTENSION
Systematic name | M16466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Long distance growth of a single axon process involved in cellular development. [GOC:BHF, GOC:dgh, GOC:dph, GOC:jid, GOC:lm, GOC:rl]
Full description |

Standard name | GO_RESPONSE_TO_AXON_INJURY
Systematic name | M11430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an axon injury stimulus. [GOC:dgh, GOC:dph, GOC:jid, GOC:lm]
Full description |

Standard name | GO_SPROUTING_OF_INJURED_AXON
Systematic name | M34198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process involved in sprouting of an injured axon. [GOC:dgh, GOC:dph, GOC:jid, GOC:lm]
Full description |

Standard name | GO_EMBRYONIC_CRANIAL_SKELETON_MORPHOGENESIS
Systematic name | M16821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the cranial skeleton are generated and organized during the embryonic phase. [GOC:dsf, GOC:jid, PMID:16049113]
Full description |

Standard name | GO_EMBRYONIC_NEUROCRANIUM_MORPHOGENESIS
Systematic name | M23879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the neurocranium are generated and organized during the embryonic phase. The neurocranium is the portion of the vertebrate skull surrounding the brain. [GOC:dsf, GOC:jid, PMID:16049113]
Full description |

Standard name | GO_EMBRYONIC_VISCEROCRANIUM_MORPHOGENESIS
Systematic name | M12022
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the viscerocranium are generated and organized during the embryonic phase. The viscerocranium is the part of the skull comprising the facial bones. [GOC:dsf, GOC:jid, PMID:16049113]
Full description |

Standard name | GO_EMBRYONIC_SKELETAL_SYSTEM_MORPHOGENESIS
Systematic name | M10927
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the skeleton are generated and organized during the embryonic phase. [GOC:dph, GOC:dsf, GOC:jid, GOC:tb, PMID:16049113]
Full description |

Standard name | GO_SKELETAL_SYSTEM_MORPHOGENESIS
Systematic name | M16413
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the skeleton are generated and organized. [GOC:dph, GOC:dsf, GOC:jid, GOC:tb]
Full description |

Standard name | GO_EMBRYONIC_SKELETAL_SYSTEM_DEVELOPMENT
Systematic name | M10808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process, occurring during the embryonic phase, whose specific outcome is the progression of the skeleton over time, from its formation to the mature structure. [GOC:dph, GOC:dsf, GOC:jid, GOC:tb, PMID:16049113]
Full description |

Standard name | GO_ASTROCYTE_DIFFERENTIATION
Systematic name | M13469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of an astrocyte. An astrocyte is the most abundant type of glial cell. Astrocytes provide support for neurons and regulate the environment in which they function. [GOC:vp, PMID:15139015]
Full description |

Standard name | GO_OLIGODENDROCYTE_DIFFERENTIATION
Systematic name | M15768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of an oligodendrocyte. An oligodendrocyte is a type of glial cell involved in myelinating the axons of neurons in the central nervous system. [GOC:vp, PMID:15139015]
Full description |

Standard name | GO_REGULATION_OF_ASTROCYTE_DIFFERENTIATION
Systematic name | M11897
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of astrocyte differentiation. [GOC:vp, PMID:15139015]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ASTROCYTE_DIFFERENTIATION
Systematic name | M16412
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of astrocyte differentiation. [GOC:vp, PMID:15139015]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ASTROCYTE_DIFFERENTIATION
Systematic name | M11852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of astrocyte differentiation. [GOC:vp, PMID:15139015]
Full description |

Standard name | GO_REGULATION_OF_OLIGODENDROCYTE_DIFFERENTIATION
Systematic name | M13568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of oligodendrocyte differentiation. [GOC:vp, PMID:15139015]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OLIGODENDROCYTE_DIFFERENTIATION
Systematic name | M12296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of oligodendrocyte differentiation. [GOC:vp, PMID:15139015]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OLIGODENDROCYTE_DIFFERENTIATION
Systematic name | M10523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of oligodendrocyte differentiation. [GOC:vp, PMID:15139015]
Full description |

Standard name | GO_TISSUE_MORPHOGENESIS
Systematic name | M16103
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a tissue are generated and organized. [GOC:dph, GOC:jid]
Full description |

Standard name | GO_EPIDERMIS_MORPHOGENESIS
Systematic name | M10383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the epidermis are generated and organized. The epidermis is the outer epithelial layer of an animal, it may be a single layer that produces an extracellular material (e.g. the cuticle of arthropods) or a complex stratified squamous epithelium, as in the case of many vertebrate species. [GOC:jid, UBERON:0001003]
Full description |

Standard name | GO_GLAND_DEVELOPMENT
Systematic name | M2173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a gland over time, from its formation to the mature structure. A gland is an organ specialised for secretion. [GOC:jid]
Full description |

Standard name | GO_SEBACEOUS_GLAND_DEVELOPMENT
Systematic name | M23880
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the sebaceous gland over time, from its formation to the mature structure. [GOC:jid]
Full description |

Standard name | GO_APPENDAGE_DEVELOPMENT
Systematic name | M13260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an appendage over time, from its formation to the mature structure. An appendage is an organ or part that is attached to the trunk of an organism, such as a limb or a branch. [GOC:jid, GOC:rc]
Full description |

Standard name | GO_CARDIAC_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M13993
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of cardiac muscle over time, from its formation to the mature structure. [GOC:dph, GOC:jid, GOC:lm]
Full description |

Standard name | GO_CARDIAC_MUSCLE_FIBER_DEVELOPMENT
Systematic name | M23881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of cardiac muscle fiber over time, from its formation to the mature structure. [GOC:dph, GOC:jid, GOC:lm]
Full description |

Standard name | GO_REGULATION_OF_SKELETAL_MUSCLE_FIBER_DEVELOPMENT
Systematic name | M23882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of skeletal muscle fiber development. Muscle fibers are formed by the maturation of myotubes. They can be classed as slow, intermediate/fast or fast. [GOC:dph, GOC:jid, GOC:mtg_muscle, GOC:sm]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SKELETAL_MUSCLE_FIBER_DEVELOPMENT
Systematic name | M23883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the rate of skeletal muscle fiber development. Muscle fibers are formed by the maturation of myotubes. They can be classed as slow, intermediate/fast or fast. [GOC:dph, GOC:jid, GOC:lm, GOC:mtg_muscle]
Full description |

Standard name | GO_SMOOTH_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M12415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of smooth muscle over time, from its formation to the mature structure. [GOC:dph, GOC:jid, GOC:lm]
Full description |

Standard name | GO_MUSCLE_FIBER_DEVELOPMENT
Systematic name | M14841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the muscle fiber over time, from its formation to the mature structure. In skeletal muscle, fibers are formed by the maturation of myotubes. They can be classed as slow, intermediate/fast or fast. [GOC:dph, GOC:jid, GOC:lm, GOC:mtg_muscle]
Full description |

Standard name | GO_SEMICIRCULAR_CANAL_MORPHOGENESIS
Systematic name | M23884
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the semicircular canals are generated and organized. [GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_PIGMENT_GRANULE_ORGANIZATION
Systematic name | M13670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a pigment granule. [GOC:rc]
Full description |

Standard name | GO_BRANCHING_MORPHOGENESIS_OF_AN_EPITHELIAL_TUBE
Systematic name | M16051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of branches in an epithelial tube are generated and organized. A tube is a long hollow cylinder. [GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_BRANCHING_MORPHOGENESIS_OF_A_NERVE
Systematic name | M23885
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of branches in a nerve are generated and organized. This term refers to an anatomical structure (nerve) not a cell (neuron). [GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_PIGMENT_GRANULE_MATURATION
Systematic name | M23886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Steps required to form a membrane-bounded organelle into a pigment granule containing pigment. Maturation is a developmental process, independent of morphogenetic (shape) change, that is required for a cell or structure to attain its fully functional state. [GOC:dgh, GOC:jid, GOC:mh]
Full description |

Standard name | GO_MESENCHYMAL_CELL_DIFFERENTIATION
Systematic name | M12556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a mesenchymal cell. A mesenchymal cell is a loosely associated cell that is part of the connective tissue in an organism. Mesenchymal cells give rise to more mature connective tissue cell types. [GOC:dph, GOC:jid]
Full description |

Standard name | GO_TISSUE_REMODELING
Systematic name | M19176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The reorganization or renovation of existing tissues. This process can either change the characteristics of a tissue such as in blood vessel remodeling, or result in the dynamic equilibrium of a tissue such as in bone remodeling. [GOC:ebc]
Full description |

Standard name | GO_MAINTENANCE_OF_PRESYNAPTIC_ACTIVE_ZONE_STRUCTURE
Systematic name | M23887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process which maintains the organization and the arrangement of proteins at the active zone to ensure the fusion and docking of vesicles and the release of neurotransmitters. [GOC:curators, GOC:dph, GOC:pr]
Full description |

Standard name | GO_CALCIUM_ION_REGULATED_EXOCYTOSIS_OF_NEUROTRANSMITTER
Systematic name | M13690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The release of a neurotransmitter into the synaptic cleft by exocytosis of synaptic vesicles, where the release step is dependent on a rise in cytosolic calcium ion levels. [GOC:curators]
Full description |

Standard name | GO_PRONEPHROS_DEVELOPMENT
Systematic name | M23888
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the pronephros over time, from its formation to the mature structure. In mammals, the pronephros is the first of the three embryonic kidneys to be established and exists only transiently. In lower vertebrates such as fish and amphibia, the pronephros is the fully functional embryonic kidney and is indispensable for larval life. [GOC:bf, GOC:mtg_kidney_jan10, PMID:10535314, PMID:15968585, PMID:18322540, XAO:00002000, ZFA:0000151]
Full description |

Standard name | GO_ANIMAL_ORGAN_MATURATION
Systematic name | M23889
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for an animal organ to attain its fully functional state. An organ is a tissue or set of tissues that work together to perform a specific function or functions. [GOC:curators]
Full description |

Standard name | GO_GENITALIA_DEVELOPMENT
Systematic name | M15894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the genitalia over time, from its formation to the mature structure. [GOC:jid]
Full description |

Standard name | GO_DENDRITE_MORPHOGENESIS
Systematic name | M12944
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a dendrite are generated and organized. [GOC:aruk, GOC:bc, GOC:jl, ISBN:0198506732, PMID:22683681]
Full description |

Standard name | GO_REGULATION_OF_DENDRITE_MORPHOGENESIS
Systematic name | M10964
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of dendrite morphogenesis. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HAIR_FOLLICLE_MATURATION
Systematic name | M23890
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of hair follicle maturation. [GOC:devbiol]
Full description |

Standard name | GO_HAIR_FOLLICLE_MATURATION
Systematic name | M23891
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for a hair follicle to attain its fully functional state. [GOC:devbiol]
Full description |

Standard name | GO_ERYTHROCYTE_DEVELOPMENT
Systematic name | M16510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an erythrocyte over time, from its formation to the mature structure. [GOC:devbiol]
Full description |

Standard name | GO_OTOLITH_DEVELOPMENT
Systematic name | M23892
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the otolith over time, from its formation to the mature structure. [GOC:sr]
Full description |

Standard name | GO_ARTERY_MORPHOGENESIS
Systematic name | M12492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of arterial blood vessels are generated and organized. Arteries are blood vessels that transport blood from the heart to the body and its organs. [GOC:dsf, PMID:16740480]
Full description |

Standard name | GO_VENOUS_BLOOD_VESSEL_MORPHOGENESIS
Systematic name | M23893
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of venous blood vessels are generated and organized. Veins are blood vessels that transport blood from the body and its organs to the heart. [GOC:dsf, PMID:16740480]
Full description |

Standard name | GO_FOREBRAIN_MORPHOGENESIS
Systematic name | M10585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the forebrain are generated and organized. The forebrain is the anterior of the three primary divisions of the developing chordate brain or the corresponding part of the adult brain (in vertebrates, includes especially the cerebral hemispheres, the thalamus, and the hypothalamus and especially in higher vertebrates is the main control center for sensory and associative information processing, visceral functions, and voluntary motor functions). [GOC:cvs, GOC:dgh, GOC:dph, GOC:jid]
Full description |

Standard name | GO_BRAIN_MORPHOGENESIS
Systematic name | M16971
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the brain are generated and organized. The brain is one of the two components of the central nervous system and is the center of thought and emotion. It is responsible for the coordination and control of bodily activities and the interpretation of information from the senses (sight, hearing, smell, etc.). [GOC:dgh, GOC:jid]
Full description |

Standard name | GO_NEURAL_NUCLEUS_DEVELOPMENT
Systematic name | M12662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a neural nucleus from its initial condition to its mature state. A neural nucleus is an anatomical structure consisting of a discrete aggregate of neuronal soma. [GO_REF:0000021]
Full description |

Standard name | GO_FORMATION_OF_ANATOMICAL_BOUNDARY
Systematic name | M23894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the limits of an anatomical structure are generated. An anatomical structure is any biological entity that occupies space and is distinguished from its surroundings. Anatomical structures can be macroscopic such as a carpel, or microscopic such as an acrosome. [GO_REF:0000021]
Full description |

Standard name | GO_LEUKEMIA_INHIBITORY_FACTOR_SIGNALING_PATHWAY
Systematic name | M34199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals initiated by the binding of leukemia inhibitory factor to a receptor on the surface of the target cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:devbiol, GOC:signaling]
Full description |

Standard name | GO_STEM_CELL_DIFFERENTIATION
Systematic name | M15304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a stem cell. A stem cell is a cell that retains the ability to divide and proliferate throughout life to provide progenitor cells that can differentiate into specialized cells. [CL:0000034, GOC:isa_complete]
Full description |

Standard name | GO_STEM_CELL_FATE_COMMITMENT
Systematic name | M23895
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the developmental fate of a cell becomes restricted such that it will develop into a stem cell. [CL:0000034, GOC:isa_complete]
Full description |

Standard name | GO_CELL_MOTILITY
Systematic name | M12003
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the controlled self-propelled movement of a cell that results in translocation of the cell from one place to another. [GOC:dgh, GOC:dph, GOC:isa_complete, GOC:mlg]
Full description |

Standard name | GO_MULTICELLULAR_ORGANISMAL_HOMEOSTASIS
Systematic name | M14669
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state at the level of the multicellular organism. [GOC:isa_complete]
Full description |

Standard name | GO_HOMEOSTASIS_OF_NUMBER_OF_CELLS
Systematic name | M18350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process involved in the maintenance of the steady-state number of cells within a population of cells. [GOC:isa_complete]
Full description |

Standard name | GO_HOMEOSTASIS_OF_NUMBER_OF_CELLS_WITHIN_A_TISSUE
Systematic name | M14873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process involved in the maintenance of the steady-state number of cells within a population of cells in a tissue. [GOC:isa_complete]
Full description |

Standard name | GO_CHEMICAL_HOMEOSTASIS_WITHIN_A_TISSUE
Systematic name | M12244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of the internal steady state of the amount of a chemical at the level of the tissue. [GOC:isa_complete]
Full description |

Standard name | GO_CHEMICAL_HOMEOSTASIS
Systematic name | M17520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process involved in the maintenance of an internal steady state of a chemical. [GOC:isa_complete]
Full description |

Standard name | GO_SENSORY_SYSTEM_DEVELOPMENT
Systematic name | M23896
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a sensory system over time from its formation to the mature structure. [GOC:dgh]
Full description |

Standard name | GO_PERIPHERAL_NERVOUS_SYSTEM_NEURON_DIFFERENTIATION
Systematic name | M12811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a neuron whose cell body resides in the peripheral nervous system. [GOC:dgh]
Full description |

Standard name | GO_CHROMOSOME_LOCALIZATION
Systematic name | M10919
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a chromosome is transported to, or maintained in, a specific location. [GOC:ai]
Full description |

Standard name | GO_3_PHOSPHOADENOSINE_5_PHOSPHOSULFATE_METABOLIC_PROCESS
Systematic name | M23897
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving 3'-phosphoadenosine 5'-phosphosulfate, a naturally occurring mixed anhydride. It is an intermediate in the formation of a variety of sulfo compounds in biological systems. [ISBN:0198506732]
Full description |

Standard name | GO_3_PHOSPHOADENOSINE_5_PHOSPHOSULFATE_BIOSYNTHETIC_PROCESS
Systematic name | M23898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of 3'-phosphoadenosine 5'-phosphosulfate, a naturally occurring mixed anhydride. It is an intermediate in the formation of a variety of sulfo compounds in biological systems. [ISBN:0198506732]
Full description |

Standard name | GO_CATECHOLAMINE_SECRETION
Systematic name | M23899
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of catecholamines by a cell. The catecholamines are a group of physiologically important biogenic amines that possess a catechol (3,4-dihydroxyphenyl) nucleus and are derivatives of 3,4-dihydroxyphenylethylamine. [GOC:ai, GOC:ef]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VIRAL_TRANSCRIPTION
Systematic name | M10037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of viral transcription. [GOC:ai]
Full description |

Standard name | GO_AMYLOID_BETA_METABOLIC_PROCESS
Systematic name | M23900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving amyloid-beta, a glycoprotein associated with Alzheimer's disease, and its precursor, amyloid precursor protein (APP). [GOC:ai]
Full description |

Standard name | GO_ARACHIDONIC_ACID_SECRETION
Systematic name | M23901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled release of arachidonic acid from a cell or a tissue. [GOC:ai]
Full description |

Standard name | GO_CHONDROITIN_SULFATE_PROTEOGLYCAN_BIOSYNTHETIC_PROCESS
Systematic name | M12097
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of chondroitin sulfate proteoglycan, any glycoprotein whose glycosaminoglycan units are chondroitin sulfate. Chondroitin sulfates are a group of 10-60 kDa glycosaminoglycans, widely distributed in cartilage and other mammalian connective tissues; the repeat units consist of beta-(1,4)-linked D-glucuronyl beta-(1,3)-N-acetyl-D-galactosamine sulfate. [GOC:ai]
Full description |

Standard name | GO_CHONDROITIN_SULFATE_PROTEOGLYCAN_METABOLIC_PROCESS
Systematic name | M15611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving chondroitin sulfate proteoglycan, any glycoprotein whose glycosaminoglycan units are chondroitin sulfate. Chondroitin sulfates are a group of 10-60 kDa glycosaminoglycans, widely distributed in cartilage and other mammalian connective tissues; the repeat units consist of beta-(1,4)-linked D-glucuronyl beta-(1,3)-N-acetyl-D-galactosamine sulfate. [GOC:ai]
Full description |

Standard name | GO_DERMATAN_SULFATE_PROTEOGLYCAN_METABOLIC_PROCESS
Systematic name | M29224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving dermatan sulfate proteoglycan, any glycoprotein whose glycosaminoglycan units are dermatan sulfate (chondroitin sulfate B). Dermatan sulfate is a glycosaminoglycan with repeats consisting of beta-(1,4)-linked L-iduronyl-beta-(1,3)-N-acetyl-D-galactosamine 4-sulfate units. [GOC:ai]
Full description |

Standard name | GO_CYTOKINE_SECRETION
Systematic name | M8366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of cytokines from a cell. Cytokines are any of a group of proteins that function to control the survival, growth and differentiation of tissues and cells, and which have autocrine and paracrine activity. [GOC:ai, GOC:bf, ISBN:0198599471]
Full description |

Standard name | GO_HYDROGEN_PEROXIDE_BIOSYNTHETIC_PROCESS
Systematic name | M29225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of hydrogen peroxide (H2O2), a potentially harmful byproduct of aerobic cellular respiration which can cause damage to DNA. [GOC:ai]
Full description |

Standard name | GO_HOMOCYSTEINE_METABOLIC_PROCESS
Systematic name | M12071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving homocysteine, the amino acid alpha-amino-gamma-mercaptobutanoic acid. Homocysteine is an important intermediate in the metabolic reactions of its S-methyl derivative, methionine. [ISBN:0198506732]
Full description |

Standard name | GO_EPITHELIAL_CELL_PROLIFERATION
Systematic name | M15437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of epithelial cells, resulting in the expansion of a cell population. Epithelial cells make up the epithelium, the covering of internal and external surfaces of the body, including the lining of vessels and other small cavities. It consists of cells joined by small amounts of cementing substances. [ISBN:0721662544]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPITHELIAL_CELL_PROLIFERATION
Systematic name | M4581
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of epithelial cell proliferation. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EPITHELIAL_CELL_PROLIFERATION
Systematic name | M10067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of epithelial cell proliferation. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_MRNA_PROCESSING
Systematic name | M23903
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mRNA processing, those processes involved in the conversion of a primary mRNA transcript into a mature mRNA prior to its translation into polypeptide. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MRNA_PROCESSING
Systematic name | M10731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of mRNA processing. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MRNA_PROCESSING
Systematic name | M23904
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of mRNA processing. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DEFENSE_RESPONSE_TO_VIRUS
Systematic name | M12493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of antiviral mechanisms, thereby facilitating viral replication. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_DEFENSE_RESPONSE_TO_VIRUS
Systematic name | M10638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the antiviral response of a cell or organism. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_DEFENSE_RESPONSE_TO_VIRUS_BY_VIRUS
Systematic name | M12635
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any viral process that modulates the frequency, rate, or extent of the antiviral response of the host cell or organism. [GOC:ai, GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_DEFENSE_RESPONSE_TO_VIRUS_BY_HOST
Systematic name | M16125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any host process that modulates the frequency, rate, or extent of the antiviral response of a host cell or organism. [GOC:ai, GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYTOKINE_SECRETION
Systematic name | M14053
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the regulated release of cytokines from a cell. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOKINE_SECRETION
Systematic name | M9438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the regulated release of cytokines from a cell. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_INFLAMMATORY_RESPONSE
Systematic name | M15261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the inflammatory response, the immediate defensive reaction (by vertebrate tissue) to infection or injury caused by chemical or physical agents. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INFLAMMATORY_RESPONSE
Systematic name | M13807
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the inflammatory response. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INFLAMMATORY_RESPONSE
Systematic name | M15877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the inflammatory response. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDYL_TYROSINE_PHOSPHORYLATION
Systematic name | M16603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the phosphorylation of peptidyl-tyrosine. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PEPTIDYL_TYROSINE_PHOSPHORYLATION
Systematic name | M11833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the phosphorylation of peptidyl-tyrosine. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PEPTIDYL_TYROSINE_PHOSPHORYLATION
Systematic name | M10317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the phosphorylation of peptidyl-tyrosine. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_LIPOPROTEIN_METABOLIC_PROCESS
Systematic name | M15439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving lipoproteins, any conjugated, water-soluble protein in which the nonprotein group consists of a lipid or lipids. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPOPROTEIN_METABOLIC_PROCESS
Systematic name | M29229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving lipoproteins, any conjugated, water-soluble protein in which the nonprotein group consists of a lipid or lipids. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPOPROTEIN_METABOLIC_PROCESS
Systematic name | M34200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving lipoproteins, any conjugated, water-soluble protein in which the nonprotein group consists of a lipid or lipids. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_PHAGOCYTOSIS
Systematic name | M15210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of phagocytosis, the process in which phagocytes engulf external particulate material. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PHAGOCYTOSIS
Systematic name | M23910
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of phagocytosis. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHAGOCYTOSIS
Systematic name | M13731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of phagocytosis. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_AXONOGENESIS
Systematic name | M6050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of axonogenesis, the generation of an axon, the long process of a neuron. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AXONOGENESIS
Systematic name | M16129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of axonogenesis. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AXONOGENESIS
Systematic name | M16575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of axonogenesis. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_DENDRITE_DEVELOPMENT
Systematic name | M16290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of dendrite development. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DENDRITE_MORPHOGENESIS
Systematic name | M11364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of dendrite morphogenesis. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DENDRITE_MORPHOGENESIS
Systematic name | M14661
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of dendrite morphogenesis. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_IMMUNE_RESPONSE
Systematic name | M12336
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the immune response, the immunological reaction of an organism to an immunogenic stimulus. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_IMMUNE_RESPONSE
Systematic name | M15641
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the immune response, the immunological reaction of an organism to an immunogenic stimulus. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_IMMUNE_RESPONSE
Systematic name | M4618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the immune response, the immunological reaction of an organism to an immunogenic stimulus. [GOC:ai]
Full description |

Standard name | GO_RNA_DESTABILIZATION
Systematic name | M13474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the stability of an RNA molecule, making it more vulnerable to degradative processes. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_BEHAVIOR
Systematic name | M12371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of behavior, the internally coordinated responses (actions or inactions) of whole living organisms (individuals or groups) to internal or external stimuli. [GOC:go_curators, GOC:pr]
Full description |

Standard name | GO_REGULATION_OF_INSULIN_SECRETION
Systematic name | M23911
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of insulin. [GOC:ai]
Full description |

Standard name | GO_ACTIVATED_T_CELL_PROLIFERATION
Systematic name | M23912
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a T cell population following activation by an antigenic stimulus. [GOC:add, GOC:dph]
Full description |

Standard name | GO_ION_HOMEOSTASIS
Systematic name | M14716
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of ions within an organism or cell. [GOC:ai]
Full description |

Standard name | GO_CIRCADIAN_SLEEP_WAKE_CYCLE_SLEEP
Systematic name | M23913
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The part of the circadian sleep/wake cycle where the organism is asleep. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_SYNAPSE_STRUCTURE_OR_ACTIVITY
Systematic name | M14201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the physical form or the activity of a synapse, the junction between a neuron and a target (neuron, muscle, or secretory cell). [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SYNAPTIC_TRANSMISSION
Systematic name | M12732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of synaptic transmission, the process of communication from a neuron to a target (neuron, muscle, or secretory cell) across a synapse. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPTIC_TRANSMISSION
Systematic name | M15075
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of synaptic transmission, the process of communication from a neuron to a target (neuron, muscle, or secretory cell) across a synapse. [GOC:ai]
Full description |

Standard name | GO_SYNAPSE_ORGANIZATION
Systematic name | M221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a synapse, the junction between a neuron and a target (neuron, muscle, or secretory cell). [GOC:ai, GOC:pr]
Full description |

Standard name | GO_REGULATION_OF_STEROID_BIOSYNTHETIC_PROCESS
Systematic name | M15018
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of steroids, compounds with a 1,2,cyclopentanoperhydrophenanthrene nucleus. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_ACYL_COA_BIOSYNTHETIC_PROCESS
Systematic name | M13222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of acyl-CoA. [GOC:ai]
Full description |

Standard name | GO_COAGULATION
Systematic name | M15909
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a fluid solution, or part of it, changes into a solid or semisolid mass. [ISBN:0198506732]
Full description |

Standard name | GO_REGULATION_OF_COAGULATION
Systematic name | M10666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of coagulation, the process in which a fluid solution, or part of it, changes into a solid or semisolid mass. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_COAGULATION
Systematic name | M12042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of coagulation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_COAGULATION
Systematic name | M11143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of coagulation. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_STABILIZATION
Systematic name | M13097
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in maintaining the structure and integrity of a protein and preventing it from degradation or aggregation. [GOC:ai]
Full description |

Standard name | GO_DEFENSE_RESPONSE_TO_GRAM_NEGATIVE_BACTERIUM
Systematic name | M13838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Reactions triggered in response to the presence of a Gram-negative bacterium that act to protect the cell or organism. [GOC:ai]
Full description |

Standard name | GO_DEFENSE_RESPONSE_TO_GRAM_POSITIVE_BACTERIUM
Systematic name | M14294
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Reactions triggered in response to the presence of a Gram-positive bacterium that act to protect the cell or organism. [GOC:ai]
Full description |

Standard name | GO_DEFENSE_RESPONSE_TO_FUNGUS
Systematic name | M16270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Reactions triggered in response to the presence of a fungus that act to protect the cell or organism. [GOC:ai]
Full description |

Standard name | GO_PROGESTERONE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of a progesterone binding to its receptor. [GOC:ai, GOC:mah, PMID:14744870]
Full description |

Standard name | GO_REGULATION_OF_CALCIUM_MEDIATED_SIGNALING
Systematic name | M10452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of calcium-mediated signaling, the process in which a cell uses calcium ions to convert an extracellular signal into a response. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CALCIUM_MEDIATED_SIGNALING
Systematic name | M15895
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of calcium-mediated signaling. [GOC:ai, PMID:11696592]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CALCIUM_MEDIATED_SIGNALING
Systematic name | M12361
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of calcium-mediated signaling. [GOC:ai]
Full description |

Standard name | GO_ANTIGEN_RECEPTOR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M11047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the cross-linking of an antigen receptor on a B or T cell. [GOC:add]
Full description |

Standard name | GO_T_CELL_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M13926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the cross-linking of an antigen receptor on a T cell. [GOC:add]
Full description |

Standard name | GO_B_CELL_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M16382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the cross-linking of an antigen receptor on a B cell. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_ANTIGEN_RECEPTOR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M10131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of signaling pathways initiated by the cross-linking of an antigen receptor on a B- or T cell. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_B_CELL_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M10092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of signaling pathways initiated by the cross-linking of an antigen receptor on a B cell. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M10062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of signaling pathways initiated by the cross-linking of an antigen receptor on a T cell. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ANTIGEN_RECEPTOR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M13369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signaling pathways initiated by the cross-linking of an antigen receptor on a B- or T cell. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ANTIGEN_RECEPTOR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M15000
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of signaling pathways initiated by the cross-linking of an antigen receptor on a B- or T cell. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_B_CELL_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23916
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of signaling pathways initiated by the cross-linking of an antigen receptor on a B cell. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_CELL_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of signaling pathways initiated by the cross-linking of an antigen receptor on a T cell. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_B_CELL_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23917
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signaling pathways initiated by the cross-linking of an antigen receptor on a B cell. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_CELL_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23918
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signaling pathways initiated by the cross-linking of an antigen receptor on a T cell. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_ACTIVATION
Systematic name | M16253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T cell activation. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_B_CELL_ACTIVATION
Systematic name | M14227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of B cell activation. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_CELL_ACTIVATION
Systematic name | M10107
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell activation, the change in the morphology or behavior of a cell resulting from exposure to an activating factor such as a cellular or soluble ligand. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_ACTIVATION
Systematic name | M14878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cell activation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_ACTIVATION
Systematic name | M13385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of activation. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_B_CELL_ACTIVATION
Systematic name | M11141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of B cell activation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_B_CELL_ACTIVATION
Systematic name | M16078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of B cell activation. [GOC:ai]
Full description |

Standard name | GO_WHITE_FAT_CELL_DIFFERENTIATION
Systematic name | M11092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a white adipocyte, an animal connective tissue cell involved in energy storage. White adipocytes have cytoplasmic lipids arranged in a unique vacuole. [PMID:12508945]
Full description |

Standard name | GO_BROWN_FAT_CELL_DIFFERENTIATION
Systematic name | M13488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a brown adipocyte, an animal connective tissue cell involved in adaptive thermogenesis. Brown adipocytes contain multiple small droplets of triglycerides and a high number of mitochondria. [PMID:12588810]
Full description |

Standard name | GO_NERVOUS_SYSTEM_PROCESS
Systematic name | M9711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A organ system process carried out by any of the organs or tissues of neurological system. [GOC:ai, GOC:mtg_cardio]
Full description |

Standard name | GO_REGULATION_OF_BODY_FLUID_LEVELS
Systematic name | M16235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the levels of body fluids. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_MULTICELLULAR_ORGANISMAL_MOVEMENT
Systematic name | M11399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any physiological process involved in changing the position of a multicellular organism or an anatomical part of a multicellular organism. [GOC:dph, GOC:mtg_muscle, GOC:tb]
Full description |

Standard name | GO_VOLUNTARY_MUSCULOSKELETAL_MOVEMENT
Systematic name | M23921
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of an organism or part of an organism using mechanoreceptors, the nervous system, striated muscle and/or the skeletal system that can be controlled at will. [GOC:dph]
Full description |

Standard name | GO_NEUROMUSCULAR_PROCESS_CONTROLLING_POSTURE
Systematic name | M14763
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organism voluntarily modulates its posture, the alignment of its anatomical parts. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEUROMUSCULAR_PROCESS_CONTROLLING_BALANCE
Systematic name | M11803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that an organism uses to control its balance, the orientation of the organism (or the head of the organism) in relation to the source of gravity. In humans and animals, balance is perceived through visual cues, the labyrinth system of the inner ears and information from skin pressure receptors and muscle and joint receptors. [GOC:ai, GOC:dph]
Full description |

Standard name | GO_ENDOCRINE_PROCESS
Systematic name | M16557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that involves the secretion of or response to endocrine hormones. An endocrine hormone is a hormone released into the circulatory system. [ISBN:0721662544]
Full description |

Standard name | GO_COGNITION
Systematic name | M10386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The operation of the mind by which an organism becomes aware of objects of thought or perception; it includes the mental activities associated with thinking, learning, and memory. [ISBN:0721619908]
Full description |

Standard name | GO_INTESTINAL_ABSORPTION
Systematic name | M16771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which nutrients are taken up from the contents of the intestine. [GOC:ai, GOC:dph]
Full description |

Standard name | GO_LEUKOCYTE_MIGRATION
Systematic name | M12269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a leukocyte within or between different tissues and organs of the body. [GOC:add, ISBN:0781735149, PMID:14680625, PMID:14708592, PMID:7507411, PMID:8600538]
Full description |

Standard name | GO_LEUKOCYTE_TETHERING_OR_ROLLING
Systematic name | M23922
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Transient adhesive interactions between leukocytes and endothelial cells lining blood vessels. Carbohydrates on circulating leukocytes bind selectins on the vessel wall causing the leukocytes to slow down and roll along the inner surface of the vessel wall. During this rolling motion, transitory bonds are formed and broken between selectins and their ligands. Typically the first step in cellular extravasation (the movement of leukocytes out of the circulatory system, towards the site of tissue damage or infection). [GOC:bf, ISBN:0781735149, PMID:14680625, PMID:14708592, PMID:7507411, PMID:8600538, Wikipedia:Leukocyte_extravasation]
Full description |

Standard name | GO_DIAPEDESIS
Systematic name | M23923
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The passage of a leukocyte between the tight junctions of endothelial cells lining blood vessels, typically the fourth and final step of cellular extravasation. [ISBN:0781735149, PMID:14680625, PMID:14708592, PMID:7507411, PMID:8600538]
Full description |

Standard name | GO_NEUROMUSCULAR_PROCESS
Systematic name | M15744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process pertaining to the functions of the nervous and muscular systems of an organism. [GOC:ai]
Full description |

Standard name | GO_DETECTION_OF_STIMULUS_INVOLVED_IN_SENSORY_PERCEPTION
Systematic name | M23924
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events involved in sensory perception in which a sensory stimulus is received and converted into a molecular signal. [GOC:ai, GOC:dos, GOC:dph]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_TASTE
Systematic name | M12833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive a gustatory stimulus, convert it to a molecular signal, and recognize and characterize the signal. Gustation involves the direct detection of chemical composition, usually through contact with chemoreceptor cells. This is a neurological process. [GOC:ai]
Full description |

Standard name | GO_DETECTION_OF_MECHANICAL_STIMULUS_INVOLVED_IN_SENSORY_PERCEPTION_OF_SOUND
Systematic name | M14391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events involved in the perception of sound vibration in which the vibration is received and converted into a molecular signal. [GOC:ai]
Full description |

Standard name | GO_DETECTION_OF_CHEMICAL_STIMULUS_INVOLVED_IN_SENSORY_PERCEPTION_OF_TASTE
Systematic name | M12687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events involved in the perception of taste in which a gustatory chemical stimulus is received and converted into a molecular signal. [GOC:ai]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_BITTER_TASTE
Systematic name | M23925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required to receive a bitter taste stimulus, convert it to a molecular signal, and recognize and characterize the signal. This is a neurological process. [GOC:ai]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_SOUR_TASTE
Systematic name | M23926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required to receive a sour taste stimulus, convert it to a molecular signal, and recognize and characterize the signal. This is a neurological process. [GOC:ai]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_SWEET_TASTE
Systematic name | M23927
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required to receive a sweet taste stimulus, convert it to a molecular signal, and recognize and characterize the signal. This is a neurological process. [GOC:ai]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_UMAMI_TASTE
Systematic name | M23928
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required to receive an umami taste stimulus, convert it to a molecular signal, and recognize and characterize the signal. Umami taste is the savory taste of meats and other foods that are rich in glutamates. This is a neurological process. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_CHEMOTAXIS
Systematic name | M16964
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a motile cell or organism towards a higher concentration of a chemical. [GOC:ai, GOC:bf, GOC:isa_complete]
Full description |

Standard name | GO_NEGATIVE_CHEMOTAXIS
Systematic name | M16725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a motile cell or organism towards a lower concentration of a chemical. [GOC:ai, GOC:bf, GOC:isa_complete]
Full description |

Standard name | GO_REGULATION_OF_CHEMOTAXIS
Systematic name | M14991
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of a motile cell or organism in response to a specific chemical concentration gradient. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHEMOTAXIS
Systematic name | M16001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of a motile cell or organism in response to a specific chemical concentration gradient. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHEMOTAXIS
Systematic name | M13350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of a motile cell or organism in response to a specific chemical concentration gradient. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_POSITIVE_CHEMOTAXIS
Systematic name | M11625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of a motile cell or organism towards a higher concentration in a concentration gradient of a specific chemical. [GOC:ai]
Full description |

Standard name | GO_INDUCTION_OF_POSITIVE_CHEMOTAXIS
Systematic name | M11314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the directed movement of a motile cell or organism towards a higher concentration in a concentration gradient of a specific chemical. [GOC:ai]
Full description |

Standard name | GO_PIGMENT_CELL_DIFFERENTIATION
Systematic name | M13516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a pigmented cell, such as a melanocyte. [GOC:dgh]
Full description |

Standard name | GO_REGULATION_OF_PIGMENT_CELL_DIFFERENTIATION
Systematic name | M23929
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of pigmented cell differentiation. [GOC:ai]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_TEMPERATURE_STIMULUS
Systematic name | M10442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive a sensory temperature stimulus, convert it to a molecular signal, and recognize and characterize the signal. This is a neurological process. [GOC:ai]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_LIGHT_STIMULUS
Systematic name | M13006
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive a sensory light stimulus, convert it to a molecular signal, and recognize and characterize the signal. This is a neurological process. [GOC:ai]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_MECHANICAL_STIMULUS
Systematic name | M10703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive a sensory mechanical stimulus, convert it to a molecular signal, and recognize and characterize the signal. This is a neurological process. [GOC:ai]
Full description |

Standard name | GO_THERMOCEPTION
Systematic name | M34201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive a temperature stimulus, convert it to a molecular signal, and recognize and characterize the signal. Thermoception in larger animals is mainly done in the skin; mammals have at least two types of sensor, for detecting heat (temperatures above body temperature) and cold (temperatures below body temperature). [GOC:ai, Wikipedia:Thermoception]
Full description |

Standard name | GO_EQUILIBRIOCEPTION
Systematic name | M23930
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive an orientational stimulus, convert it to a molecular signal, and recognize and characterize the signal. Equilibrioception refers to a combination of processes by which an organism can perceive its orientation with respect to gravity. In animals, stimuli come from labyrinth system of the inner ears, monitoring the direction of motion; visual stimuli, with information on orientation and motion; pressure receptors, which tell the organism which body surfaces are in contact with the ground; and proprioceptive cues, which report which parts of the body are in motion. [http://www.medterms.com]
Full description |

Standard name | GO_DETECTION_OF_TEMPERATURE_STIMULUS_INVOLVED_IN_SENSORY_PERCEPTION
Systematic name | M15576
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a temperature stimulus is received and converted into a molecular signal as part of sensory perception. [GOC:ai, GOC:dos]
Full description |

Standard name | GO_DETECTION_OF_LIGHT_STIMULUS_INVOLVED_IN_SENSORY_PERCEPTION
Systematic name | M14779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a light stimulus is received by a cell and converted into a molecular signal as part of the sensory perception of light. [GOC:ai, GOC:dos]
Full description |

Standard name | GO_DETECTION_OF_MECHANICAL_STIMULUS_INVOLVED_IN_SENSORY_PERCEPTION_OF_PAIN
Systematic name | M23931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events involved in the perception of pain in which a mechanical stimulus is received and converted into a molecular signal. [GOC:ai, GOC:dos]
Full description |

Standard name | GO_DETECTION_OF_MECHANICAL_STIMULUS_INVOLVED_IN_SENSORY_PERCEPTION
Systematic name | M10733
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a mechanical stimulus is received and converted into a molecular signal as part of sensory perception. [GOC:ai, GOC:dos]
Full description |

Standard name | GO_SENSORY_PERCEPTION_OF_TOUCH
Systematic name | M23932
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events required for an organism to receive a touch stimulus, convert it to a molecular signal, and recognize and characterize the signal. This is a neurological process. The perception of touch in animals is mediated by mechanoreceptors in the skin and mucous membranes and is the sense by which contact with objects gives evidence as to certain of their qualities. Different types of touch can be perceived (for example, light, coarse, pressure and tickling) and the stimulus may be external or internal (e.g. the feeling of a full stomach). [GOC:ai]
Full description |

Standard name | GO_DETECTION_OF_MECHANICAL_STIMULUS
Systematic name | M12192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events by which a mechanical stimulus is received and converted into a molecular signal. [GOC:ai, GOC:dos]
Full description |

Standard name | GO_REGULATION_OF_LIPID_CATABOLIC_PROCESS
Systematic name | M15598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of the chemical reactions and pathways resulting in the breakdown of lipids. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPID_CATABOLIC_PROCESS
Systematic name | M15065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of lipids. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPID_CATABOLIC_PROCESS
Systematic name | M14107
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of lipids. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_NITRIC_OXIDE_SYNTHASE_ACTIVITY
Systematic name | M12116
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the activity of the enzyme nitric-oxide synthase. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NITRIC_OXIDE_SYNTHASE_ACTIVITY
Systematic name | M16279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the activity of the enzyme nitric-oxide synthase. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NITRIC_OXIDE_SYNTHASE_ACTIVITY
Systematic name | M23933
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the activity of the enzyme nitric-oxide synthase. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_LIPOPROTEIN_LIPASE_ACTIVITY
Systematic name | M12290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the activity of the enzyme lipoprotein lipase. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPOPROTEIN_LIPASE_ACTIVITY
Systematic name | M23934
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the activity of the enzyme lipoprotein lipase. [GOC:ai]
Full description |

Standard name | GO_MICROTUBULE_SEVERING
Systematic name | M23935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a microtubule is broken down into smaller segments. Severing enzymes remove dimers from the middle of the filament to create new ends, unlike depolymerizing kinesins that use ATP to uncap microtubules at their ends. [GOC:ai, PMID:27037673]
Full description |

Standard name | GO_ACTIN_FILAMENT_SEVERING
Systematic name | M23936
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an actin filament is broken down into smaller filaments. [GOC:ai, PMID:14657234]
Full description |

Standard name | GO_BARBED_END_ACTIN_FILAMENT_CAPPING
Systematic name | M11054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The binding of a protein or protein complex to the barbed (or plus) end of an actin filament, thus preventing the addition, exchange or removal of further actin subunits. [ISBN:071673706X]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_IMMUNOGLOBULIN_SECRETION
Systematic name | M14089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the regulated release of immunoglobulins from a cell. [GOC:ai]
Full description |

Standard name | GO_CHIASMA_ASSEMBLY
Systematic name | M23937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which a connection between chromatids assembles, indicating where an exchange of homologous segments has taken place by the crossing-over of non-sister chromatids. [PMID:23396135]
Full description |

Standard name | GO_MRNA_TRANSPORT
Systematic name | M23938
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of mRNA, messenger ribonucleic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_RRNA_TRANSPORT
Systematic name | M23939
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of rRNA, ribosomal ribonucleic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_TRNA_TRANSPORT
Systematic name | M34202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of tRNA, transfer ribonucleic acid, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_ENDOSOME_SIZE
Systematic name | M23940
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the volume of an endosome, a membrane-bounded organelle that carries materials newly ingested by endocytosis. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_PROTEIN_ECTODOMAIN_PROTEOLYSIS
Systematic name | M13624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the proteolytic cleavage of transmembrane proteins and release of their ectodomain (extracellular domain). [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MEMBRANE_PROTEIN_ECTODOMAIN_PROTEOLYSIS
Systematic name | M15609
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of membrane protein ectodomain peptidolysis. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MEMBRANE_PROTEIN_ECTODOMAIN_PROTEOLYSIS
Systematic name | M23941
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of membrane protein ectodomain proteolysis. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_SECRETION
Systematic name | M531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the controlled release of a substance from a cell or a tissue. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SECRETION
Systematic name | M4615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the controlled release of a substance from a cell or a tissue. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SECRETION
Systematic name | M1310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the controlled release of a substance from a cell or a tissue. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_TRANSPORT
Systematic name | M15630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of substances (such as macromolecules, small molecules, ions) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSPORT
Systematic name | M15500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of substances (such as macromolecules, small molecules, ions) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSPORT
Systematic name | M12424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of substances (such as macromolecules, small molecules, ions) into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_DNA_METABOLIC_PROCESS
Systematic name | M7262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving DNA. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_METABOLIC_PROCESS
Systematic name | M19816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving DNA. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_METABOLIC_PROCESS
Systematic name | M19524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving DNA. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPID_BIOSYNTHETIC_PROCESS
Systematic name | M11192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of lipids. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_SMALL_GTPASE_MEDIATED_SIGNAL_TRANSDUCTION
Systematic name | M11142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of small GTPase mediated signal transduction. [GOC:go_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SMALL_GTPASE_MEDIATED_SIGNAL_TRANSDUCTION
Systematic name | M15980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of small GTPase mediated signal transduction. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMALL_GTPASE_MEDIATED_SIGNAL_TRANSDUCTION
Systematic name | M11863
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of small GTPase mediated signal transduction. [GOC:ai]
Full description |

Standard name | GO_CHAPERONE_COFACTOR_DEPENDENT_PROTEIN_REFOLDING
Systematic name | M23942
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of assisting in the correct posttranslational noncovalent assembly of proteins, which is dependent on additional protein cofactors. This process occurs over one or several cycles of nucleotide hydrolysis-dependent binding and release. [GOC:rb]
Full description |

Standard name | GO_REGULATION_OF_DNA_BINDING_TRANSCRIPTION_FACTOR_ACTIVITY
Systematic name | M17633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the activity of a transcription factor, any factor involved in the initiation or regulation of transcription. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_BINDING_TRANSCRIPTION_FACTOR_ACTIVITY
Systematic name | M14355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of activity of a transcription factor, any factor involved in the initiation or regulation of transcription. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NF_KAPPAB_TRANSCRIPTION_FACTOR_ACTIVITY
Systematic name | M19425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of activity of the transcription factor NF-kappaB. [GOC:dph, GOC:tb, PMID:15087454, PMID:15170030]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DEVELOPMENTAL_PROCESS
Systematic name | M14753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of development, the biological process whose specific outcome is the progression of an organism over time from an initial condition (e.g. a zygote, or a young adult) to a later condition (e.g. a multicellular animal or an aged adult). [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DEVELOPMENTAL_PROCESS
Systematic name | M15406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of development, the biological process whose specific outcome is the progression of an organism over time from an initial condition (e.g. a zygote, or a young adult) to a later condition (e.g. a multicellular animal or an aged adult). [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_HELICASE_ACTIVITY
Systematic name | M23945
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of helicase activity. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HELICASE_ACTIVITY
Systematic name | M23946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the activity of a helicase. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HELICASE_ACTIVITY
Systematic name | M23947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the activity of a helicase. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_BINDING
Systematic name | M4198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of binding, the selective interaction of a molecule with one or more specific sites on another molecule. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BINDING
Systematic name | M12082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of binding, the selective interaction of a molecule with one or more specific sites on another molecule. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BINDING
Systematic name | M6350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate or extent of binding, the selective interaction of a molecule with one or more specific sites on another molecule. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_DNA_BINDING
Systematic name | M179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA binding. DNA binding is any process in which a gene product interacts selectively with DNA (deoxyribonucleic acid). [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_DNA_LIGATION_INVOLVED_IN_DNA_REPAIR
Systematic name | M11352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The re-formation of a broken phosphodiester bond in the DNA backbone, carried out by DNA ligase, that contributes to DNA repair. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_DNA_LIGATION
Systematic name | M23948
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA ligation, the re-formation of a broken phosphodiester bond in the DNA backbone, carried out by DNA ligase. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_LIGATION
Systematic name | M23949
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of DNA ligation, the re-formation of a broken phosphodiester bond in the DNA backbone, carried out by DNA ligase. [GOC:ai]
Full description |

Standard name | GO_HEPOXILIN_METABOLIC_PROCESS
Systematic name | M29231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving hepoxilins, a class of bioactive icosanoids with roles in the regulation of cell physiology. [PMID:15123652]
Full description |

Standard name | GO_RNA_POLYMERASE_II_PREINITIATION_COMPLEX_ASSEMBLY
Systematic name | M23951
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins on an RNA polymerase II promoter DNA to form the transcriptional preinitiation complex (PIC), the formation of which is a prerequisite for transcription by RNA polymerase. [GOC:txnOH, PMID:10882737, PMID:15020047]
Full description |

Standard name | GO_SYNAPTIC_GROWTH_AT_NEUROMUSCULAR_JUNCTION
Systematic name | M23952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The growth of a synapse at a neuromuscular junction, the site of apposition of a motor end plate and the subneural cleft of the skeletal muscle fiber that it innervates. [ISBN:0721662544]
Full description |

Standard name | GO_REGULATION_OF_ACTIN_NUCLEATION
Systematic name | M10676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of actin nucleation, the initial step in the formation of an actin filament in which actin monomers combine to form a new filament. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ACTIN_NUCLEATION
Systematic name | M23953
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of actin nucleation, the initial step in the formation of an actin filament in which actin monomers combine to form a new filament. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACTIN_NUCLEATION
Systematic name | M12953
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of actin nucleation, the initial step in the formation of an actin filament in which actin monomers combine to form a new filament. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_COMPONENT_ORGANIZATION
Systematic name | M11952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of cell structures, including the plasma membrane and any external encapsulating structures such as the cell wall and cell envelope. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_COMPONENT_ORGANIZATION
Systematic name | M634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of cell structures, including the plasma membrane and any external encapsulating structures such as the cell wall and cell envelope. [GOC:ai]
Full description |

Standard name | GO_CHAPERONE_MEDIATED_PROTEIN_COMPLEX_ASSEMBLY
Systematic name | M11479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a protein complex, mediated by chaperone molecules that do not form part of the finished complex. [GOC:ai]
Full description |

Standard name | GO_NK_T_CELL_ACTIVATION
Systematic name | M23954
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The change in morphology and behavior of a mature or immature natural killer T cell resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific. [ISBN:0781735149, PMID:12154375, PMID:9133426]
Full description |

Standard name | GO_REGULATION_OF_NK_T_CELL_ACTIVATION
Systematic name | M23955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of natural killer T cell activation. [ISBN:0781735149, PMID:12154375, PMID:9133426]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NK_T_CELL_ACTIVATION
Systematic name | M23956
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of natural killer T cell activation. [ISBN:0781735149, PMID:12154375, PMID:9133426]
Full description |

Standard name | GO_REGULATION_OF_NK_T_CELL_DIFFERENTIATION
Systematic name | M23957
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of natural killer T cell differentiation. [ISBN:0781735149, PMID:12154375, PMID:9133426]
Full description |

Standard name | GO_REGULATION_OF_NK_T_CELL_PROLIFERATION
Systematic name | M23958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of natural killer T cell proliferation. [ISBN:0781735149, PMID:12154375, PMID:9133426]
Full description |

Standard name | GO_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M10794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a smooth muscle cell; smooth muscle lacks transverse striations in its constituent fibers and are almost always involuntary. [CL:0000192, GOC:ai]
Full description |

Standard name | GO_STRIATED_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M11134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a striated muscle cell; striated muscle fibers are divided by transverse bands into striations, and cardiac and voluntary muscle are types of striated muscle. [CL:0000737, GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M12956
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of muscle cell differentiation. [CL:0000187, GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M10671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of muscle cell differentiation. [CL:0000187, GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M10756
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of muscle cell differentiation. [CL:0000187, GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M10749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of smooth muscle cell differentiation. [CL:0000192, GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M23959
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of smooth muscle cell differentiation. [CL:0000192, GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M23960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of smooth muscle cell differentiation. [CL:0000192, GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_STRIATED_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M11228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of striated muscle cell differentiation. [CL:0000737, GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_STRIATED_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M10566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of striated muscle cell differentiation. [CL:0000737, GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STRIATED_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M16328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of striated muscle cell differentiation. [CL:0000737, GOC:ai]
Full description |

Standard name | GO_GLUCOSE_6_PHOSPHATE_METABOLIC_PROCESS
Systematic name | M11917
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glucose 6-phosphate, a monophosphorylated derivative of glucose with the phosphate group attached to C-6. [GOC:ai]
Full description |

Standard name | GO_XYLULOSE_5_PHOSPHATE_METABOLIC_PROCESS
Systematic name | M29232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving xylulose 5-phosphate, a derivative of the ketopentose xylulose phosphorylated at the 5 carbon; it is an intermediate in the pentose phosphate pathway. [ISBN:0721662544]
Full description |

Standard name | GO_NUCLEAR_EXPORT
Systematic name | M15413
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances out of the nucleus. [GOC:ai]
Full description |

Standard name | GO_NUCLEAR_TRANSPORT
Systematic name | M12055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances into, out of, or within the nucleus. [GOC:ai]
Full description |

Standard name | GO_IMPORT_INTO_NUCLEUS
Systematic name | M23961
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances into the nucleus. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHORUS_METABOLIC_PROCESS
Systematic name | M16371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving phosphorus or compounds containing phosphorus. [GOC:ai]
Full description |

Standard name | GO_VITAMIN_TRANSPORT
Systematic name | M14054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of vitamins into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. A vitamin is one of a number of unrelated organic substances that occur in many foods in small amounts and that are necessary in trace amounts for the normal metabolic functioning of the body. [GOC:ai]
Full description |

Standard name | GO_PROSTHETIC_GROUP_METABOLIC_PROCESS
Systematic name | M34203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a prosthetic group, the non-amino acid portion of certain protein molecules. Prosthetic groups may be inorganic or organic and are usually required for the biological activity of the protein. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_INSERTION_INTO_MEMBRANE
Systematic name | M16160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in the incorporation of a protein into a biological membrane. Incorporation in this context means having some part or covalently attached group that is inserted into the the hydrophobic region of one or both bilayers. [GOC:ai]
Full description |

Standard name | GO_SEQUESTERING_OF_CALCIUM_ION
Systematic name | M34204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of binding or confining calcium ions such that they are separated from other components of a biological system. [GOC:ai]
Full description |

Standard name | GO_CARTILAGE_DEVELOPMENT
Systematic name | M10512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a cartilage element over time, from its formation to the mature structure. Cartilage elements are skeletal elements that consist of connective tissue dominated by extracellular matrix containing collagen type II and large amounts of proteoglycan, particularly chondroitin sulfate. [GOC:cjm, PMID:23251424]
Full description |

Standard name | GO_CYTOPLASMIC_SEQUESTERING_OF_PROTEIN
Systematic name | M15254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The selective interaction of a protein with specific molecules in the cytoplasm, thereby inhibiting its transport into other areas of the cell. [GOC:ai]
Full description |

Standard name | GO_SPINDLE_ASSEMBLY
Systematic name | M14998
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form the spindle, the array of microtubules and associated molecules that serves to move duplicated chromosomes apart. [GOC:ai, GOC:expert_rg, GOC:mtg_sensu, GOC:tb]
Full description |

Standard name | GO_SPINDLE_ELONGATION
Systematic name | M23967
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which the distance is lengthened between poles of the spindle. [GOC:ai]
Full description |

Standard name | GO_MAINTENANCE_OF_LOCATION
Systematic name | M12798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a cell, substance or cellular entity, such as a protein complex or organelle, is maintained in a location and prevented from moving elsewhere. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_ESTABLISHMENT_OF_RNA_LOCALIZATION
Systematic name | M23968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of RNA to a specific location. [GOC:ai]
Full description |

Standard name | GO_SEQUESTERING_OF_METAL_ION
Systematic name | M11789
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of binding or confining metal ions such that they are separated from other components of a biological system. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MULTICELLULAR_ORGANISMAL_PROCESS
Systematic name | M17126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of an organismal process, any of the processes pertinent to the function of an organism above the cellular level; includes the integrated processes of tissues and organs. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MULTICELLULAR_ORGANISMAL_PROCESS
Systematic name | M1241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of an organismal process, the processes pertinent to the function of an organism above the cellular level; includes the integrated processes of tissues and organs. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_METABOLIC_PROCESS
Systematic name | M1774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving a protein. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_METABOLIC_PROCESS
Systematic name | M14017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of chemical reactions and pathways involving a protein. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_LYMPHOCYTE_ACTIVATION
Systematic name | M16183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lymphocyte activation. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LYMPHOCYTE_ACTIVATION
Systematic name | M23970
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of lymphocyte activation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LYMPHOCYTE_ACTIVATION
Systematic name | M18946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of lymphocyte activation. [GOC:ai]
Full description |

Standard name | GO_SPINDLE_MIDZONE_ASSEMBLY
Systematic name | M23975
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which aggregation, arrangement and bonding together of a set of components to form the spindle midzone. The spindle midzone is the area in the center of the spindle where the spindle microtubules from opposite poles overlap. [GOC:ai, PMID:15296749]
Full description |

Standard name | GO_MITOTIC_SPINDLE_MIDZONE_ASSEMBLY
Systematic name | M23976
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which the aggregation, arrangement and bonding together of a set of components forms the spindle midzone. [GOC:mtg_cell_cycle, GOC:vw, PMID:24239120]
Full description |

Standard name | GO_PROTEIN_POLYMERIZATION
Systematic name | M2405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of creating protein polymers, compounds composed of a large number of component monomers; polymeric proteins may be made up of different or identical monomers. Polymerization occurs by the addition of extra monomers to an existing poly- or oligomeric protein. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_COMPLEX_OLIGOMERIZATION
Systematic name | M23977
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of creating protein oligomers, compounds composed of a small number, usually between three and ten, of component monomers; protein oligomers may be composed of different or identical monomers. Oligomers may be formed by the polymerization of a number of monomers or the depolymerization of a large protein polymer. [GOC:ai, PMID:18293929]
Full description |

Standard name | GO_PROTEIN_HOMOOLIGOMERIZATION
Systematic name | M14817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of creating protein oligomers, compounds composed of a small number, usually between three and ten, of identical component monomers. Oligomers may be formed by the polymerization of a number of monomers or the depolymerization of a large protein polymer. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_DEPOLYMERIZATION
Systematic name | M14516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which protein polymers, compounds composed of a large number of component monomers, are broken down. Depolymerization occurs by the successive removal of monomers from an existing poly- or oligomeric protein. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_TETRAMERIZATION
Systematic name | M16193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a protein tetramer, a macromolecular structure consisting of four noncovalently associated identical or nonidentical subunits. [GOC:ecd]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_COMPONENT_MOVEMENT
Systematic name | M15511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the movement of a cellular component. [GOC:ai, GOC:dph, GOC:jl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_COMPONENT_MOVEMENT
Systematic name | M34205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the movement of a cellular component. [GOC:ai, GOC:dph, GOC:jl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_COMPONENT_MOVEMENT
Systematic name | M34206
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the movement of a cellular component. [GOC:ai, GOC:dph, GOC:jl]
Full description |

Standard name | GO_CHROMOSOME_ORGANIZATION
Systematic name | M10125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level that results in the assembly, arrangement of constituent parts, or disassembly of chromosomes, structures composed of a very long molecule of DNA and associated proteins that carries hereditary information. This term covers covalent modifications at the molecular level as well as spatial relationships among the major components of a chromosome. [GOC:ai, GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_RELEASE_OF_SEQUESTERED_CALCIUM_ION_INTO_CYTOSOL
Systematic name | M15552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the release into the cytosolic compartment of calcium ions sequestered in the endoplasmic reticulum or mitochondria. [GOC:ai, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RELEASE_OF_SEQUESTERED_CALCIUM_ION_INTO_CYTOSOL
Systematic name | M12094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the release into the cytosolic compartment of calcium ions sequestered in the endoplasmic reticulum or mitochondria. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SEQUESTERING_OF_CALCIUM_ION
Systematic name | M10269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the binding or confining calcium ions such that they are separated from other components of a biological system. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_HOMOTETRAMERIZATION
Systematic name | M10572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a protein homotetramer, a macromolecular structure consisting of four noncovalently associated identical subunits. [GOC:go_curators]
Full description |

Standard name | GO_PROTEIN_HETEROTETRAMERIZATION
Systematic name | M12610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a protein heterotetramer, a macromolecular structure consisting of four noncovalently associated subunits, of which not all are identical. [GOC:go_curators]
Full description |

Standard name | GO_PROTEIN_HETEROOLIGOMERIZATION
Systematic name | M16931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of creating protein oligomers, compounds composed of a small number, usually between three and ten, of component monomers that are not all identical. Oligomers may be formed by the polymerization of a number of monomers or the depolymerization of a large protein polymer. [GOC:ai]
Full description |

Standard name | GO_NUCLEAR_PORE_COMPLEX_ASSEMBLY
Systematic name | M14652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a nuclear pore complex. [GOC:ai, GOC:mah]
Full description |

Standard name | GO_ESTABLISHMENT_OF_SPINDLE_ORIENTATION
Systematic name | M10132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that set the alignment of spindle relative to other cellular structures. [GOC:ai]
Full description |

Standard name | GO_ESTABLISHMENT_OF_MEIOTIC_SPINDLE_LOCALIZATION
Systematic name | M23978
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which the directed movement of the meiotic spindle to a specific location in the cell occurs. [GOC:ai]
Full description |

Standard name | GO_CENTROSOME_DUPLICATION
Systematic name | M15996
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The replication of a centrosome, a structure comprised of a pair of centrioles and peri-centriolar material from which a microtubule spindle apparatus is organized. [GOC:ai]
Full description |

Standard name | GO_CENTROSOME_SEPARATION
Systematic name | M23979
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which duplicated centrosome components move away from each other. The centriole pair within each centrosome becomes part of a separate microtubule organizing center that nucleates a radial array of microtubules called an aster. The two asters move to opposite sides of the nucleus to form the two poles of the mitotic spindle. [GOC:ai]
Full description |

Standard name | GO_CELL_DIVISION
Systematic name | M1727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process resulting in division and partitioning of components of a cell to form more cells; may or may not be accompanied by the physical separation of a cell into distinct, individually membrane-bounded daughter cells. [GOC:di, GOC:go_curators, GOC:pr]
Full description |

Standard name | GO_REGULATION_OF_CELL_DIVISION
Systematic name | M13633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the physical partitioning and separation of a cell into daughter cells. [GOC:go_curators]
Full description |

Standard name | GO_CHROMOSOME_SEPARATION
Systematic name | M11331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which paired chromosomes are detached from each other. Chromosome separation begins with the release of cohesin complexes from chromosomes; in budding yeast, this includes the cleavage of cohesin complexes along the chromosome arms, followed by the separation of the centromeric regions. Chromosome separation also includes formation of chromatid axes mediated by condensins, and ends with the disentangling of inter-sister catenation catalyzed by topoisomerase II (topo II). [GOC:ai, GOC:lb, GOC:mah, GOC:mtg_cell_cycle, PMID:20352243]
Full description |

Standard name | GO_CHROMOSOME_MOVEMENT_TOWARDS_SPINDLE_POLE
Systematic name | M23980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of chromosomes in the center of the spindle towards the spindle poles, mediated by the shortening of microtubules attached to the chromosomes. [GOC:ai]
Full description |

Standard name | GO_MEIOTIC_CHROMOSOME_SEPARATION
Systematic name | M13612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which chromosomes are physically detached from each other during meiosis. [GOC:ai]
Full description |

Standard name | GO_METAPHASE_PLATE_CONGRESSION
Systematic name | M16704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The alignment of chromosomes at the metaphase plate (spindle equator), a plane halfway between the poles of the spindle. [GOC:ai]
Full description |

Standard name | GO_ATTACHMENT_OF_MITOTIC_SPINDLE_MICROTUBULES_TO_KINETOCHORE
Systematic name | M23981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which spindle microtubules become physically associated with the proteins making up the kinetochore complex as part of mitotic metaphase plate congression. [GOC:ai, GOC:clt, GOC:dph, GOC:tb, PMID:26258632, PMID:26705896]
Full description |

Standard name | GO_MEIOTIC_CELL_CYCLE
Systematic name | M17093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Progression through the phases of the meiotic cell cycle, in which canonically a cell replicates to produce four offspring with half the chromosomal content of the progenitor cell via two nuclear divisions. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_HYDROLASE_ACTIVITY
Systematic name | M12327
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hydrolase activity, the catalysis of the hydrolysis of various bonds, e.g. C-O, C-N, C-C, phosphoric anhydride bonds, etc. Hydrolase is the systematic name for any enzyme of EC class 3. [EC:3.-.-.-, GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_TRANSFERASE_ACTIVITY
Systematic name | M11329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transferase activity, the catalysis of the transfer of a group, e.g. a methyl group, glycosyl group, acyl group, phosphorus-containing, or other groups, from one compound (generally regarded as the donor) to another compound (generally regarded as the acceptor). Transferase is the systematic name for any enzyme of EC class 2. [EC:2.-.-.-, GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_LYASE_ACTIVITY
Systematic name | M10213
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lyase activity, the catalysis of the cleavage of C-C, C-O, C-N and other bonds by other means than by hydrolysis or oxidation, or conversely adding a group to a double bond. They differ from other enzymes in that two substrates are involved in one reaction direction, but only one in the other direction. When acting on the single substrate, a molecule is eliminated and this generates either a new double bond or a new ring. [EC:4.-.-.-, GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_LIGASE_ACTIVITY
Systematic name | M11254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ligase activity, the catalysis of the ligation of two substances with concomitant breaking of a diphosphate linkage, usually in a nucleoside triphosphate. Ligase is the systematic name for any enzyme of EC class 6. [EC:6.-.-.-, GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_OXIDOREDUCTASE_ACTIVITY
Systematic name | M11255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of oxidoreductase activity, the catalysis of an oxidation-reduction (redox) reaction, a reversible chemical reaction in which the oxidation state of an atom or atoms within a molecule is altered. One substrate acts as a hydrogen or electron donor and becomes oxidized, while the other acts as hydrogen or electron acceptor and becomes reduced. [EC:1.-.-.-, GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_CYCLIC_NUCLEOTIDE_PHOSPHODIESTERASE_ACTIVITY
Systematic name | M23982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cyclic nucleotide phosphodiesterase activity, the catalysis of the reaction: nucleotide 3',5'-cyclic phosphate + H2O = nucleotide 5'-phosphate. [EC:3.1.4.17, GOC:ai, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYCLIC_NUCLEOTIDE_PHOSPHODIESTERASE_ACTIVITY
Systematic name | M23983
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cyclic nucleotide phosphodiesterase activity, the catalysis of the reaction: nucleotide 3',5'-cyclic phosphate + H2O = nucleotide 5'-phosphate. [GOC:ai, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYCLIC_NUCLEOTIDE_PHOSPHODIESTERASE_ACTIVITY
Systematic name | M23984
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate of cyclic nucleotide phosphodiesterase activity, the catalysis of the reaction: nucleotide 3',5'-cyclic phosphate + H2O = nucleotide 5'-phosphate. [GOC:ai, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HYDROLASE_ACTIVITY
Systematic name | M9617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of hydrolase activity, the catalysis of the hydrolysis of various bonds. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HYDROLASE_ACTIVITY
Systematic name | M10900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate of hydrolase activity, the catalysis of the hydrolysis of various bonds. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSFERASE_ACTIVITY
Systematic name | M13495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of transferase activity, the catalysis of the transfer of a group, e.g. a methyl group, glycosyl group, acyl group, phosphorus-containing, or other groups, from a donor compound to an acceptor. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSFERASE_ACTIVITY
Systematic name | M13535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate of transferase activity, the catalysis of the transfer of a group, e.g. a methyl group, glycosyl group, acyl group, phosphorus-containing, or other groups, from a donor compound to an acceptor. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LYASE_ACTIVITY
Systematic name | M11245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of lyase activity, the catalysis of the cleavage of C-C, C-O, C-N and other bonds by other means than by hydrolysis or oxidation, or conversely adding a group to a double bond. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LYASE_ACTIVITY
Systematic name | M14335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate of lyase activity, the catalysis of the cleavage of C-C, C-O, C-N and other bonds by other means than by hydrolysis or oxidation, or conversely adding a group to a double bond. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIGASE_ACTIVITY
Systematic name | M13663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of ligase activity, the catalysis of the ligation of two substances with concomitant breaking of a diphosphate linkage, usually in a nucleoside triphosphate. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OXIDOREDUCTASE_ACTIVITY
Systematic name | M14277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of oxidoreductase activity, the catalysis of an oxidation-reduction (redox) reaction, a reversible chemical reaction in which the oxidation state of an atom or atoms within a molecule is altered. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OXIDOREDUCTASE_ACTIVITY
Systematic name | M12858
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the rate of oxidoreductase activity, the catalysis of an oxidation-reduction (redox) reaction, a reversible chemical reaction in which the oxidation state of an atom or atoms within a molecule is altered. [GOC:ai]
Full description |

Standard name | GO_KINETOCHORE_ASSEMBLY
Systematic name | M23985
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form the kinetochore, a multisubunit complex that is located at the centromeric region of DNA and provides an attachment point for the spindle microtubules. [GOC:ai]
Full description |

Standard name | GO_KINETOCHORE_ORGANIZATION
Systematic name | M16319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the kinetochore, a multisubunit complex that is located at the centromeric region of DNA and provides an attachment point for the spindle microtubules. [GOC:ai, GOC:dph, GOC:jl, GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_MINERALOCORTICOID
Systematic name | M15320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mineralocorticoid stimulus. Mineralocorticoids are hormonal C21 corticosteroids synthesized from cholesterol and characterized by their similarity to aldosterone. Mineralocorticoids act primarily on water and electrolyte balance. [GOC:ai, PMID:9884123]
Full description |

Standard name | GO_REGULATION_OF_NEUROTROPHIN_TRK_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the neurotrophin TRK receptor signaling pathway. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEUROTROPHIN_TRK_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M23987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the neurotrophin TRK receptor signaling pathway. [GOC:ai]
Full description |

Standard name | GO_NEURON_APOPTOTIC_PROCESS
Systematic name | M14106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a neuron, the basic cellular unit of nervous tissue. Each neuron consists of a body, an axon, and dendrites. Their purpose is to receive, conduct, and transmit impulses in the nervous system. [CL:0000540, GOC:mtg_apoptosis, MeSH:A.08.663]
Full description |

Standard name | GO_RESPONSE_TO_NITROSATIVE_STRESS
Systematic name | M23988
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nitrosative stress stimulus. Nitrosative stress is a state often resulting from exposure to high levels of nitric oxide (NO) or the highly reactive oxidant peroxynitrite, which is produced following interaction of NO with superoxide anions. [PMID:15925705]
Full description |

Standard name | GO_DETOXIFICATION_OF_NITROGEN_COMPOUND
Systematic name | M23989
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that reduces or removes the toxicity of nitrogenous compounds which are dangerous or toxic. This includes the aerobic conversion of toxic compounds to harmless substances. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_CORTICOSTERONE
Systematic name | M14370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a corticosterone stimulus. Corticosterone is a 21 carbon steroid hormone of the corticosteroid type, produced in the cortex of the adrenal glands. In many species, corticosterone is the principal glucocorticoid, involved in regulation of fuel metabolism, immune reactions, and stress responses. [PMID:15240347]
Full description |

Standard name | GO_RESPONSE_TO_CORTISOL
Systematic name | M23990
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cortisol stimulus. Cortisol is the major natural glucocorticoid synthesized in the zona fasciculata of the adrenal cortex; it affects the metabolism of glucose, protein, and fats and has appreciable mineralocorticoid activity. It also regulates the immune system and affects many other functions. [ISBN:0721662544, PMID:11276391]
Full description |

Standard name | GO_MICROTUBULE_NUCLEATION_BY_INTERPHASE_MICROTUBULE_ORGANIZING_CENTER
Systematic name | M23991
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The 'de novo' formation of a microtubule by the interphase microtubule organizing center during interphase, the stage of cell cycle between successive rounds of chromosome segregation. [GOC:ai]
Full description |

Standard name | GO_MICROTUBULE_NUCLEATION_BY_MICROTUBULE_ORGANIZING_CENTER
Systematic name | M23992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The 'de novo' formation of a microtubule, mediated by the microtubule organizing center. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_UBIQUITIN_PROTEIN_TRANSFERASE_ACTIVITY
Systematic name | M23993
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ubiquitin transferase activity. [GOC:ai, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_UBIQUITIN_PROTEIN_TRANSFERASE_ACTIVITY
Systematic name | M23994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the rate of ubiquitin transferase activity. [GOC:ai, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_UBIQUITIN_PROTEIN_TRANSFERASE_ACTIVITY
Systematic name | M23995
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of ubiquitin transferase activity. [GOC:ai, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MEIOTIC_CELL_CYCLE
Systematic name | M11561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or extent of progression through the meiotic cell cycle. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MEIOTIC_CELL_CYCLE
Systematic name | M12168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of progression through the meiotic cell cycle. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MEIOTIC_CELL_CYCLE
Systematic name | M12554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the rate or extent of progression through the meiotic cell cycle. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_MYOBLAST_PROLIFERATION
Systematic name | M23996
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of myoblasts, resulting in the expansion of a myoblast cell population. A myoblast is a mononucleate cell type that, by fusion with other myoblasts, gives rise to the myotubes that eventually develop into skeletal muscle fibers. [CL:0000056, GOC:ai, GOC:mtg_muscle]
Full description |

Standard name | GO_MYOBLAST_MIGRATION
Systematic name | M23997
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a myoblast from one site to another, often during the development of a multicellular organism. A myoblast is a cell type that, by fusion with other myoblasts, gives rise to the myotubes that eventually develop into skeletal muscle fibers. [CL:0000056, GOC:ai, GOC:mtg_muscle]
Full description |

Standard name | GO_MAINTENANCE_OF_PROTEIN_LOCATION_IN_NUCLEUS
Systematic name | M15284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is maintained in the nucleus and prevented from moving elsewhere. These include sequestration within the nucleus, protein stabilization to prevent transport elsewhere and the active retrieval of proteins that escape the nucleus. [GOC:ai]
Full description |

Standard name | GO_CORTICOTROPIN_SECRETION
Systematic name | M23998
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of corticotropin by a cell. Corticotropin hormone is a polypeptide hormone synthesized and secreted from corticotropes in the anterior lobe of the pituitary gland in response to corticotropin-releasing hormone (CRH) released by the hypothalamus. [GOC:cjm, PMID:11027914]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CORTICOTROPIN_SECRETION
Systematic name | M23999
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the regulated release of corticotropin hormone from a cell. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_CYTOSOLIC_CALCIUM_ION_CONCENTRATION
Systematic name | M14239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of calcium ions within the cytosol of a cell or between the cytosol and its surroundings. [GOC:ai, GOC:mah, GOC:rph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYTOSOLIC_CALCIUM_ION_CONCENTRATION
Systematic name | M16594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the concentration of calcium ions in the cytosol. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOSOLIC_CALCIUM_ION_CONCENTRATION_INVOLVED_IN_PHOSPHOLIPASE_C_ACTIVATING_G_PROTEIN_COUPLED_SIGNALING_PATHWAY
Systematic name | M16846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the concentration of calcium ions in the cytosol that occurs as part of a PLC-activating G protein-coupled receptor signaling pathway. G-protein-activated PLC hydrolyses phosphatidylinositol-bisphosphate (PIP2) to release diacylglycerol (DAG) and inositol trisphosphate (IP3). IP3 then binds to calcium release channels in the endoplasmic reticulum (ER) to trigger calcium ion release into the cytosol. [GOC:ai, GOC:signaling]
Full description |

Standard name | GO_REGULATION_OF_FILOPODIUM_ASSEMBLY
Systematic name | M16274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the assembly of a filopodium, a thin, stiff protrusion extended by the leading edge of a motile cell such as a crawling fibroblast or amoeba, or an axonal growth cone. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FILOPODIUM_ASSEMBLY
Systematic name | M12726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the assembly of a filopodium, a thin, stiff protrusion extended by the leading edge of a motile cell such as a crawling fibroblast or amoeba, or an axonal growth cone. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CYTOSKELETON_ORGANIZATION
Systematic name | M15989
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the formation, arrangement of constituent parts, or disassembly of cytoskeletal structures. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYTOSKELETON_ORGANIZATION
Systematic name | M7088
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the formation, arrangement of constituent parts, or disassembly of cytoskeletal structures. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOSKELETON_ORGANIZATION
Systematic name | M8358
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the formation, arrangement of constituent parts, or disassembly of cytoskeletal structures. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STRESS_FIBER_ASSEMBLY
Systematic name | M24002
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the assembly of a stress fiber, a bundle of microfilaments and other proteins found in fibroblasts. [GOC:ai]
Full description |

Standard name | GO_ELASTIN_METABOLIC_PROCESS
Systematic name | M24003
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving elastin, a glycoprotein which is randomly coiled and crosslinked to form elastic fibers that are found in connective tissue. [GOC:curators]
Full description |

Standard name | GO_KERATINOCYTE_MIGRATION
Systematic name | M24004
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a keratinocyte, epidermal cells which synthesize keratin, from one site to another. [ISBN:0721662544]
Full description |

Standard name | GO_REGULATION_OF_KERATINOCYTE_MIGRATION
Systematic name | M24005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of keratinocyte migration. [GOC:ai]
Full description |

Standard name | GO_FLAVONE_METABOLIC_PROCESS
Systematic name | M24006
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving flavones, a class of pigmented plant compounds based on 2-phenyl-4H-1-benzopyran-4-one (2-phenylchromone). [PMID:18567791]
Full description |

Standard name | GO_MITOCHONDRIAL_CALCIUM_ION_HOMEOSTASIS
Systematic name | M11953
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of calcium ions within the cytoplasm of a cell or between mitochondria and their surroundings. [GOC:ai, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOCHONDRIAL_CALCIUM_ION_CONCENTRATION
Systematic name | M24007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the concentration of calcium ions in mitochondria. [GOC:ai]
Full description |

Standard name | GO_HISTONE_H3_K9_METHYLATION
Systematic name | M24008
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of one or more methyl groups to lysine at position 9 of the histone. [GOC:ai, GOC:pr]
Full description |

Standard name | GO_HISTONE_H3_K4_METHYLATION
Systematic name | M14220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of one or more methyl groups to lysine at position 4 of the histone. [GOC:ai, GOC:pr]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_H3_K4_METHYLATION
Systematic name | M14428
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the covalent addition of a methyl group to the lysine at position 4 of histone H3. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_H3_K9_METHYLATION
Systematic name | M13506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the covalent addition of a methyl group to the lysine at position 9 of histone H3. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HISTONE_H3_K4_METHYLATION
Systematic name | M11474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the covalent addition of a methyl group to the lysine at position 4 of histone H3. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HISTONE_H3_K4_METHYLATION
Systematic name | M24009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the covalent addition of a methyl group to the lysine at position 4 of histone H3. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HISTONE_H3_K9_METHYLATION
Systematic name | M24010
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the covalent addition of a methyl group to the lysine at position 9 of histone H3. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HISTONE_H3_K9_METHYLATION
Systematic name | M24011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the covalent addition of a methyl group to the lysine at position 9 of histone H3. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_NEUROTRANSMITTER_UPTAKE
Systematic name | M14586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of a neurotransmitter into a neuron or glial cell. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEUROTRANSMITTER_UPTAKE
Systematic name | M24013
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of a neurotransmitter into a neuron or glial cell. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_NEUROTRANSMITTER_TRANSPORT
Systematic name | M13574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of a neurotransmitter into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEUROTRANSMITTER_TRANSPORT
Systematic name | M12238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of a neurotransmitter into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEUROTRANSMITTER_TRANSPORT
Systematic name | M14075
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of a neurotransmitter into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_CAMP
Systematic name | M12949
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cAMP (cyclic AMP, adenosine 3',5'-cyclophosphate) stimulus. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_CALCIUM_ION
Systematic name | M16837
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a calcium ion stimulus. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_FOLIC_ACID
Systematic name | M15985
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a folic acid stimulus. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_METHYLMERCURY
Systematic name | M11991
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a methylmercury stimulus. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_HYDROSTATIC_PRESSURE
Systematic name | M24015
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydrostatic pressure stimulus. Hydrostatic pressure is the force acting on an object in a system where the fluid is at rest (as opposed to moving). The weight of the fluid above the object creates pressure on it. [Wikipedia:Hydrostatic_pressure]
Full description |

Standard name | GO_EXOCYST_LOCALIZATION
Systematic name | M24016
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an exocyst is transported to, or maintained in, a specific location. An exocyst is a protein complex peripherally associated with the plasma membrane that determines where vesicles dock and fuse. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_ELECTRICAL_STIMULUS
Systematic name | M10471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an electrical stimulus. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_MATURATION
Systematic name | M12410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process leading to the attainment of the full functional capacity of a protein. [GOC:ai]
Full description |

Standard name | GO_DETECTION_OF_STIMULUS
Systematic name | M14602
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a stimulus is received by a cell or organism and converted into a molecular signal. [GOC:add, GOC:ai, GOC:dph, GOC:mah]
Full description |

Standard name | GO_DEFENSE_RESPONSE_TO_VIRUS
Systematic name | M14405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Reactions triggered in response to the presence of a virus that act to protect the cell or organism. [GOC:ai]
Full description |

Standard name | GO_HISTAMINE_TRANSPORT
Systematic name | M24017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of histamine into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Histamine is a physiologically active amine, found in plant and animal tissue and released from mast cells as part of an allergic reaction in humans. [GOC:ai]
Full description |

Standard name | GO_SEROTONIN_UPTAKE
Systematic name | M24018
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of serotonin into a cell, typically presynaptic neurons or glial cells. Serotonin (5-hydroxytryptamine) is a monoamine neurotransmitter occurring in the peripheral and central nervous systems. [GOC:ai]
Full description |

Standard name | GO_NOREPINEPHRINE_UPTAKE
Systematic name | M29233
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of norepinephrine into a cell, typically presynaptic neurons or glial cells. Norepinephrine (3,4-dihydroxyphenyl-2-aminoethanol) is a hormone secreted by the adrenal medulla and a neurotransmitter in the sympathetic peripheral nervous system and in some tracts of the CNS. It is also the biosynthetic precursor of epinephrine. [GOC:ai]
Full description |

Standard name | GO_ACTIN_FILAMENT_NETWORK_FORMATION
Systematic name | M24019
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The assembly of a network of actin filaments; actin filaments on different axes and with differing orientations are crosslinked together to form a mesh of filaments. [GOC:ai]
Full description |

Standard name | GO_ORGANELLE_LOCALIZATION
Systematic name | M15951
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organelle is transported to, and/or maintained in, a specific location. [GOC:ai]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_LOCALIZATION
Systematic name | M24020
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which endoplasmic reticulum is transported to, and/or maintained in, a specific location within the cell. [GOC:ai]
Full description |

Standard name | GO_GOLGI_LOCALIZATION
Systematic name | M15338
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which the Golgi is transported to, and/or maintained in, a specific location within the cell. [GOC:ai]
Full description |

Standard name | GO_MITOCHONDRION_LOCALIZATION
Systematic name | M15655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a mitochondrion or mitochondria are transported to, and/or maintained in, a specific location within the cell. [GOC:ai]
Full description |

Standard name | GO_NUCLEUS_LOCALIZATION
Systematic name | M13704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which the nucleus is transported to, and/or maintained in, a specific location within the cell. [GOC:ai]
Full description |

Standard name | GO_VESICLE_LOCALIZATION
Systematic name | M10578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a vesicle or vesicles are transported to, and/or maintained in, a specific location. [GOC:ai]
Full description |

Standard name | GO_MAINTENANCE_OF_LOCATION_IN_CELL
Systematic name | M12579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a substance or cellular entity, such as a protein complex or organelle, is maintained in a specific location within, or in the membrane of, a cell, and is prevented from moving elsewhere. [GOC:ai]
Full description |

Standard name | GO_SPINDLE_LOCALIZATION
Systematic name | M10835
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which is the spindle is transported to, and/or maintained in, a specific location. [GOC:ai]
Full description |

Standard name | GO_ESTABLISHMENT_OF_MITOCHONDRION_LOCALIZATION
Systematic name | M15934
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of the mitochondrion to a specific location. [GOC:ai]
Full description |

Standard name | GO_ESTABLISHMENT_OF_ORGANELLE_LOCALIZATION
Systematic name | M24021
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of an organelle to a specific location. [GOC:ai]
Full description |

Standard name | GO_MAINTENANCE_OF_ORGANELLE_LOCATION
Systematic name | M24022
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organelle is maintained in a specific location within a cell and prevented from moving elsewhere. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_ESTABLISHMENT_OF_CENTROSOME_LOCALIZATION
Systematic name | M24023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of the centrosome to a specific location. [GOC:ai]
Full description |

Standard name | GO_MAINTENANCE_OF_CENTROSOME_LOCATION
Systematic name | M24024
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a centrosome is maintained in a specific location within a cell and prevented from moving elsewhere. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_MEMBRANE_RAFT_LOCALIZATION
Systematic name | M24025
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which membrane rafts are transported to, or maintained in, a specific location. Membrane rafts are small (10-200 nm), heterogeneous, highly dynamic, sterol- and sphingolipid-enriched membrane domains that compartmentalize cellular processes. [GOC:ai, PMID:16645198]
Full description |

Standard name | GO_LOCALIZATION_WITHIN_MEMBRANE
Systematic name | M15600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a substance or cellular entity, such as a protein complex or organelle, is transported to, and/or maintained in, a specific location within a membrane. [GOC:ai]
Full description |

Standard name | GO_MEMBRANE_DISRUPTION_IN_OTHER_ORGANISM
Systematic name | M24027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disruption of the membranes of another organism, leading to damage to its cells and possibly death of that organism. [GOC:ai]
Full description |

Standard name | GO_ESTABLISHMENT_OF_GOLGI_LOCALIZATION
Systematic name | M24028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of the Golgi to a specific location. [GOC:ai]
Full description |

Standard name | GO_POINTED_END_ACTIN_FILAMENT_CAPPING
Systematic name | M24029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The binding of a protein or protein complex to the pointed (or minus) end of an actin filament, thus preventing the addition, exchange or removal of further actin subunits. [ISBN:071673706X]
Full description |

Standard name | GO_INTERACTION_WITH_HOST
Systematic name | M13571
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An interaction between two organisms living together in more or less intimate association. The term host is used for the larger (macro) of the two members of a symbiosis; the various forms of symbiosis include parasitism, commensalism and mutualism. [GOC:cc]
Full description |

Standard name | GO_INTERACTION_WITH_SYMBIONT
Systematic name | M14887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An interaction between two organisms living together in more or less intimate association. The term symbiont is used for the smaller (macro) of the two members of a symbiosis; the various forms of symbiosis include parasitism, commensalism and mutualism. [GOC:cc]
Full description |

Standard name | GO_INTRASPECIES_INTERACTION_BETWEEN_ORGANISMS
Systematic name | M13196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organism has an effect on an organism of the same species. [GOC:ai]
Full description |

Standard name | GO_MULTI_ORGANISM_PROCESS
Systematic name | M11259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A biological process which involves another organism of the same or different species. [GOC:jl]
Full description |

Standard name | GO_REGULATION_OF_KILLING_OF_CELLS_OF_OTHER_ORGANISM
Systematic name | M24030
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the killing by an organism of cells in another organism. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_KILLING_OF_CELLS_OF_OTHER_ORGANISM
Systematic name | M24031
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the killing by an organism of cells in another organism. [GOC:ai]
Full description |

Standard name | GO_CYTOLYSIS_IN_OTHER_ORGANISM
Systematic name | M24032
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The killing by an organism of a cell in another organism by means of the rupture of cell membranes and the loss of cytoplasm. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_DE_ADP_RIBOSYLATION
Systematic name | M24033
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of removing one or more ADP-ribose residues from a protein. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_CELL_CYCLE
Systematic name | M13170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or extent of progression through the cell cycle. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_MEIOTIC_SISTER_CHROMATID_COHESION_CENTROMERIC
Systematic name | M24034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which centromeres of sister chromatids are joined during meiosis. [PMID:14730319, PMID:16325576]
Full description |

Standard name | GO_ACTIN_CROSSLINK_FORMATION
Systematic name | M24035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which two or more actin filaments are connected together by proteins that act as crosslinks between the filaments. The crosslinked filaments may be on the same or differing axes. [GOC:ai]
Full description |

Standard name | GO_NITRIC_OXIDE_SYNTHASE_BIOSYNTHETIC_PROCESS
Systematic name | M24036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a nitric-oxide synthase, an enzyme which catalyzes the reaction L-arginine + n NADPH + n H+ + m O2 = citrulline + nitric oxide + n NADP+. [EC:1.14.13.39, GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NITRIC_OXIDE_SYNTHASE_BIOSYNTHETIC_PROCESS
Systematic name | M12186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of a nitric oxide synthase enzyme. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_REDOX_STATE
Systematic name | M16527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating redox state. Redox state refers to the balance of oxidized versus reduced forms of electron donors and acceptors in an organelle, cell or organ; plastoquinone, glutathione (GSH/GSSG), and nicotinamide nucleotides (NAD+/NADH and NADP+/NADPH) are among the most important. [GOC:mah, PMID:15131240, PMID:16987039]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_DIVISION
Systematic name | M12767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell division. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_DIVISION
Systematic name | M10610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cell division. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_NUCLEAR_DIVISION
Systematic name | M10613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of nuclear division, the partitioning of the nucleus and its genetic information. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NUCLEAR_DIVISION
Systematic name | M15083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of nuclear division, the partitioning of the nucleus and its genetic information. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NUCLEAR_DIVISION
Systematic name | M15441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of nuclear division, the partitioning of the nucleus and its genetic information. [GOC:ai]
Full description |

Standard name | GO_RESPONSE_TO_MISFOLDED_PROTEIN
Systematic name | M16265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a misfolded protein stimulus. [GOC:go_curators]
Full description |

Standard name | GO_MEDIUM_CHAIN_FATTY_ACID_METABOLIC_PROCESS
Systematic name | M29237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving medium-chain fatty acids, any fatty acid with a chain length of between C6 and C12. [Wikipedia:Fatty_acid_metabolisms]
Full description |

Standard name | GO_MEDIUM_CHAIN_FATTY_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M34207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any fatty acid with a chain length of between C6 and C12. [Wikipedia:Fatty_acid_metabolism]
Full description |

Standard name | GO_MEDIUM_CHAIN_FATTY_ACID_CATABOLIC_PROCESS
Systematic name | M34208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of any fatty acid with a chain length of between C6 and C12. [Wikipedia:Fatty_acid_metabolism]
Full description |

Standard name | GO_REGULATION_OF_HAIR_FOLLICLE_DEVELOPMENT
Systematic name | M11775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hair follicle development. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HAIR_FOLLICLE_DEVELOPMENT
Systematic name | M34209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of hair follicle development. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_SYNAPSE_STRUCTURAL_PLASTICITY
Systematic name | M24040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of synapse structural plasticity. Synapse structural plasticity is a type of cytoskeletal remodeling; this remodeling is induced by stimuli that can lead to long term potentiation and it can be activity-dependent or -independent. Examples of cytoskeletal changes include the formation of new spines and increase in spine size; this can be accompanied by the insertion of greater numbers of glutamate (or other neurotransmitter) receptors into the post-synaptic membrane. [PMID:11063967, PMID:14976517, PMID:9884123]
Full description |

Standard name | GO_MODULATION_BY_HOST_OF_SYMBIONT_PROCESS
Systematic name | M34210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an organism effects a change in the structure or processes of a symbiont organism. The symbiont is defined as the smaller of the organisms involved in a symbiotic interaction. [GOC:cc]
Full description |

Standard name | GO_PROTEIN_AUTOUBIQUITINATION
Systematic name | M13272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The ubiquitination by a protein of one or more of its own amino acid residues, or residues on an identical protein. Ubiquitination occurs on the lysine residue by formation of an isopeptide crosslink. [GOC:ai]
Full description |

Standard name | GO_PIGMENT_GRANULE_LOCALIZATION
Systematic name | M10400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a pigment granule is transported to, and/or maintained in, a specific location within the cell. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRIAL_MEMBRANE_POTENTIAL
Systematic name | M14571
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the establishment or extent of the mitochondrial membrane potential, the electric potential existing across the mitochondrial membrane arising from charges in the membrane itself and from the charges present in the media on either side of the membrane. [GOC:ai]
Full description |

Standard name | GO_MITOCHONDRIAL_DEPOLARIZATION
Systematic name | M24043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the potential difference across the mitochondrial membrane is reduced from its steady state level. [Wikipedia:Depolarization, Wikipedia:Mitochondrion]
Full description |

Standard name | GO_KILLING_OF_CELLS_IN_OTHER_ORGANISM_INVOLVED_IN_SYMBIOTIC_INTERACTION
Systematic name | M34211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process mediated by an organism that results in the death of cells in a second organism, where the two organisms are in a symbiotic interaction. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_CARDIOBLAST_DIFFERENTIATION
Systematic name | M24044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardioblast differentiation, the process in which a relatively unspecialized mesodermal cell acquires the specialized structural and/or functional features of a cardioblast. A cardioblast is a cardiac precursor cell. It is a cell that has been committed to a cardiac fate, but will undergo more cell division rather than terminally differentiating. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CARDIOBLAST_DIFFERENTIATION
Systematic name | M24045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cardioblast differentiation, the process in which a relatively unspecialized mesodermal cell acquires the specialized structural and/or functional features of a cardioblast. A cardioblast is a cardiac precursor cell. It is a cell that has been committed to a cardiac fate, but will undergo more cell division rather than terminally differentiating. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_KINASE_B_SIGNALING
Systematic name | M14469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein kinase B signaling, a series of reactions mediated by the intracellular serine/threonine kinase protein kinase B. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_KINASE_B_SIGNALING
Systematic name | M12823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of protein kinase B signaling, a series of reactions mediated by the intracellular serine/threonine kinase protein kinase B. [GOC:ai]
Full description |

Standard name | GO_MEMBRANE_DEPOLARIZATION
Systematic name | M10207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which membrane potential decreases with respect to its steady-state potential, usually from negative potential to a more positive potential. For example, the initial depolarization during the rising phase of an action potential is in the direction from the negative steady-state resting potential towards the positive membrane potential that will be the peak of the action potential. [GOC:dh, Wikipedia:Depolarization]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOCHONDRIAL_DEPOLARIZATION
Systematic name | M24047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of the change in the membrane potential of the mitochondria from negative to positive. [GOC:ai]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PIGMENT_GRANULE_LOCALIZATION
Systematic name | M24048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a pigment granule to a specific location. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_FIBRINOLYSIS
Systematic name | M12741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of fibrinolysis, an ongoing process that solubilizes fibrin, resulting in the removal of small blood clots. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FIBRINOLYSIS
Systematic name | M24049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of fibrinolysis, an ongoing process that solubilizes fibrin, resulting in the removal of small blood clots. [GOC:ai]
Full description |

Standard name | GO_SULFATION
Systematic name | M11560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a sulfate group to a molecule. [Wikipedia:Sulfation]
Full description |

Standard name | GO_REGULATION_OF_CALCIUM_ION_TRANSPORT
Systematic name | M13005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of calcium ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CALCIUM_ION_TRANSPORT
Systematic name | M14592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of calcium ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CALCIUM_ION_TRANSPORT
Systematic name | M10087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of calcium ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_SENSORY_PERCEPTION
Systematic name | M13793
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of sensory perception, the series of events required for an organism to receive a sensory stimulus, convert it to a molecular signal, and recognize and characterize the signal. [GOC:ai]
Full description |

Standard name | GO_SYNAPTIC_TRANSMISSION_GABAERGIC
Systematic name | M24050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The vesicular release of gamma-aminobutyric acid (GABA). from a presynapse, across a chemical synapse, the subsequent activation of GABA receptors at the postsynapse of a target cell (neuron, muscle, or secretory cell) and the effects of this activation on the postsynaptic membrane potential and ionic composition of the postsynaptic cytosol. This process encompasses both spontaneous and evoked release of neurotransmitter and all parts of synaptic vesicle exocytosis. Evoked transmission starts with the arrival of an action potential at the presynapse. [GOC:dos, ISBN:0126603030]
Full description |

Standard name | GO_CATECHOLAMINE_UPTAKE_INVOLVED_IN_SYNAPTIC_TRANSMISSION
Systematic name | M24051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The uptake of catecholamine neurotransmitters by neurons or glial cells. This process leads to inactivation and recycling of neurotransmitters. [ISBN:0123668387]
Full description |

Standard name | GO_L_GLUTAMATE_IMPORT
Systematic name | M24052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-glutamate, the L-enantiomer of the anion of 2-aminopentanedioic acid, into a cell or organelle. [GOC:ai, GOC:jsg, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CATECHOLAMINE_UPTAKE_INVOLVED_IN_SYNAPTIC_TRANSMISSION
Systematic name | M34212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of catecholamine neurotransmitters into a neuron or glial cell. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AMINE_TRANSPORT
Systematic name | M12681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of amines into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AMINE_TRANSPORT
Systematic name | M13913
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of the directed movement of amines into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_AMINO_ACID_TRANSPORT
Systematic name | M14605
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of amino acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AMINO_ACID_TRANSPORT
Systematic name | M24053
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of amino acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AMINO_ACID_TRANSPORT
Systematic name | M16556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of the directed movement of amino acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_NERVOUS_SYSTEM_DEVELOPMENT
Systematic name | M11450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of nervous system development, the origin and formation of nervous tissue. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NERVOUS_SYSTEM_DEVELOPMENT
Systematic name | M11740
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of nervous system development, the origin and formation of nervous tissue. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NERVOUS_SYSTEM_DEVELOPMENT
Systematic name | M11606
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of nervous system development, the origin and formation of nervous tissue. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_SYNAPSE_ASSEMBLY
Systematic name | M12854
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of synapse assembly, the aggregation, arrangement and bonding together of a set of components to form a synapse. [GOC:ai, GOC:pr]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SYNAPSE_ASSEMBLY
Systematic name | M24054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of synapse assembly, the aggregation, arrangement and bonding together of a set of components to form a synapse. [GOC:ai, GOC:pr]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPSE_ASSEMBLY
Systematic name | M11036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of synapse assembly, the aggregation, arrangement and bonding together of a set of components to form a synapse. [GOC:ai, GOC:pr]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_TRANSMISSION_GLUTAMATERGIC
Systematic name | M10724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glutamatergic synaptic transmission, the process of communication from a neuron to another neuron across a synapse using the neurotransmitter glutamate. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SYNAPTIC_TRANSMISSION_GLUTAMATERGIC
Systematic name | M24055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of glutamatergic synaptic transmission, the process of communication from a neuron to another neuron across a synapse using the neurotransmitter glutamate. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPTIC_TRANSMISSION_GLUTAMATERGIC
Systematic name | M10164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of glutamatergic synaptic transmission, the process of communication from a neuron to another neuron across a synapse using the neurotransmitter glutamate. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_TRANSMISSION_OF_NERVE_IMPULSE
Systematic name | M15812
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transmission of a nerve impulse, the sequential electrochemical polarization and depolarization that travels across the membrane of a neuron in response to stimulation. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSMISSION_OF_NERVE_IMPULSE
Systematic name | M24056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of transmission of a nerve impulse, the sequential electrochemical polarization and depolarization that travels across the membrane of a neuron in response to stimulation. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSMISSION_OF_NERVE_IMPULSE
Systematic name | M24057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of transmission of a nerve impulse, the sequential electrochemical polarization and depolarization that travels across the membrane of a neuron in response to stimulation. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_TELOMERASE_ACTIVITY
Systematic name | M16567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of telomerase activity, the catalysis of the reaction: deoxynucleoside triphosphate + DNA(n) = diphosphate + DNA(n+1). Telomerases catalyze extension of the 3'- end of a DNA strand by one deoxynucleotide at a time using an internal RNA template that encodes the telomeric repeat sequence. [EC:2.-.-.-, GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TELOMERASE_ACTIVITY
Systematic name | M11986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of telomerase activity, the catalysis of the reaction: deoxynucleoside triphosphate + DNA(n) = diphosphate + DNA(n+1). [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TELOMERASE_ACTIVITY
Systematic name | M11963
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or reduces the activity of the enzyme telomerase, which catalyzes of the reaction: deoxynucleoside triphosphate + DNA(n) = diphosphate + DNA(n+1). [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_CHROMOSOME_SEGREGATION
Systematic name | M12682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of chromosome segregation, the process in which genetic material, in the form of chromosomes, is organized and then physically separated and apportioned to two or more sets. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHROMOSOME_SEGREGATION
Systematic name | M16418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of chromosome segregation, the process in which genetic material, in the form of chromosomes, is organized and then physically separated and apportioned to two or more sets. [GOC:ai]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHROMOSOME_SEGREGATION
Systematic name | M12137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of chromosome segregation, the process in which genetic material, in the form of chromosomes, is organized and then physically separated and apportioned to two or more sets. [GOC:ai]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ATTACHMENT_OF_SPINDLE_MICROTUBULES_TO_KINETOCHORE
Systematic name | M24058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the attachment of spindle microtubules to the kinetochore. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_ATTACHMENT_OF_SPINDLE_MICROTUBULES_TO_KINETOCHORE
Systematic name | M13865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the attachment of spindle microtubules to the kinetochore. [GOC:ai]
Full description |

Standard name | GO_MODULATION_BY_SYMBIONT_OF_HOST_PROGRAMMED_CELL_DEATH
Systematic name | M29238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organism modulates the frequency, rate or extent of programmed cell death in the host organism. The host is defined as the larger of the organisms involved in a symbiotic interaction. [GOC:mtg_pamgo_17jul06]
Full description |

Standard name | GO_MOVEMENT_IN_HOST_ENVIRONMENT
Systematic name | M34213
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of an organism or motile cell on, within or near its host organism. The host is defined as the larger of the organisms involved in a symbiotic interaction. [GOC:mtg_pamgo_17jul06]
Full description |

Standard name | GO_MODULATION_BY_SYMBIONT_OF_ENTRY_INTO_HOST
Systematic name | M34214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organism modulates the frequency, rate or extent to which it enters into the host organism, where the two organisms are in a symbiotic interaction. [GOC:mtg_pamgo_17jul06]
Full description |

Standard name | GO_NEGATIVE_REGULATION_BY_HOST_OF_SYMBIONT_MOLECULAR_FUNCTION
Systematic name | M29239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organism stops, prevents, or reduces the frequency, rate or extent of the functional activity of symbiont proteins. The symbiont is defined as the smaller of the organisms involved in a symbiotic interaction. [GOC:dph, GOC:mtg_pamgo_17jul06, GOC:tb]
Full description |

Standard name | GO_MODULATION_BY_HOST_OF_SYMBIONT_MOLECULAR_FUNCTION
Systematic name | M24061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an organism effects a change in the function of proteins in the symbiont organism. The symbiont is defined as the smaller of the organisms involved in a symbiotic interaction. [GOC:dph, GOC:mtg_pamgo_17jul06, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDASE_ACTIVITY
Systematic name | M13484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of peptidase activity, the hydrolysis of peptide bonds within proteins. [GOC:ai]
Full description |

Standard name | GO_ALDITOL_PHOSPHATE_METABOLIC_PROCESS
Systematic name | M29240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving alditol phosphates, any phosphorylated polyhydric alcohol derived from the acyclic form of a monosaccharide by reduction of its aldehyde or keto group to an alcoholic group. [PMID:30240188]
Full description |

Standard name | GO_MONOACYLGLYCEROL_CATABOLIC_PROCESS
Systematic name | M34215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of monoacylglycerol, any ester of glycerol in which any one of its hydroxyl groups has been acylated with a fatty acid, the other being non-esterified. [PMID:25290914]
Full description |

Standard name | GO_CELLULAR_GLUCURONIDATION
Systematic name | M29241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of an organic chemical by the conjugation of glucuronic acid. The substances resulting from glucuronidation are known as glucuronosides (or glucuronides) and are often much more water-soluble than the non-glucuronic acid-containing precursor. [GOC:BHF]
Full description |

Standard name | GO_FLAVONOID_GLUCURONIDATION
Systematic name | M24063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of a flavonoid by the conjugation of glucuronic acid. The resultant flavonoid glucuronosides are often much more water-soluble than the precursor. [GOC:BHF, PMID:20056724]
Full description |

Standard name | GO_XENOBIOTIC_GLUCURONIDATION
Systematic name | M24064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of a xenobiotic substance by the conjugation of glucuronic acid. The resultant glucuronosides are often much more water-soluble than the xenobiotic precursor, enabling efficient excretion. [GOC:BHF, PMID:20056724]
Full description |

Standard name | GO_IMIDAZOLE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M29242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving imidazoles, five-membered organic heterocycle containing two nitrogen atoms at positions 1 and 3, or any of its derivatives; compounds containing an imidazole skeleton. [GOC:curators]
Full description |

Standard name | GO_IMIDAZOLE_CONTAINING_COMPOUND_CATABOLIC_PROCESS
Systematic name | M29243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of imidazoles, five-membered organic heterocycle containing two nitrogen atoms at positions 1 and 3, or any of its derivatives; compounds containing an imidazole skeleton. [GOC:curators]
Full description |

Standard name | GO_MUSCLE_CELL_DEVELOPMENT
Systematic name | M16122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a muscle cell over time, from its formation to the mature structure. Muscle cell development does not include the steps involved in committing an unspecified cell to the muscle cell fate. [CL:0000187, GOC:devbiol]
Full description |

Standard name | GO_CARDIAC_MYOFIBRIL_ASSEMBLY
Systematic name | M11375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the cardiac myofibril over time, from its formation to the mature structure. A cardiac myofibril is a myofibril specific to cardiac muscle cells. [GOC:devbiol]
Full description |

Standard name | GO_CARDIAC_CELL_DEVELOPMENT
Systematic name | M16833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a cardiac cell over time, from its formation to the mature state. A cardiac cell is a cell that will form part of the cardiac organ of an individual. [GOC:devbiol]
Full description |

Standard name | GO_CARDIAC_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M13165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a cardiac muscle precursor cell acquires specialized features of a cardiac muscle cell. Cardiac muscle cells are striated muscle cells that are responsible for heart contraction. [GOC:devbiol, GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_MUSCLE_TISSUE_MORPHOGENESIS
Systematic name | M13376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of cardiac muscle tissue are generated and organized. [GOC:devbiol]
Full description |

Standard name | GO_VENTRICULAR_CARDIAC_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M11147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a ventricular cardiac muscle cell. Cardiac muscle cells are striated muscle cells that are responsible for heart contraction. The ventricle is the part of the heart that pumps blood out of the organ. [GOC:devbiol, GOC:mtg_heart]
Full description |

Standard name | GO_VENTRICULAR_CARDIAC_MUSCLE_CELL_DEVELOPMENT
Systematic name | M16099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a ventricular cardiac muscle cell over time, from its formation to the mature state. Cardiac muscle cells are striated muscle cells that are responsible for heart contraction. The ventricle is the part of the heart that pumps blood out of the organ. [GOC:devbiol, GOC:mtg_muscle]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CARDIAC_MUSCLE_TISSUE_GROWTH
Systematic name | M24065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cardiac muscle growth. [GOC:vk]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M10516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardiac muscle tissue development. [GOC:vk]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CARDIAC_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M13538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates, maintains or increases the frequency, rate or extent of cardiac muscle tissue development. [GOC:vk]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CARDIAC_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M15773
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cardiac muscle tissue development. [GOC:vk]
Full description |

Standard name | GO_NEUROBLAST_DIVISION
Systematic name | M24066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process resulting in the physical partitioning and separation of a neuroblast into daughter cells. A neuroblast is any cell that will divide and give rise to a neuron. [PMID:11163136, PMID:11250167]
Full description |

Standard name | GO_ASYMMETRIC_NEUROBLAST_DIVISION
Systematic name | M24067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process resulting in the physical partitioning and separation of a neuroblast into two daughter cells with different developmental potentials. [GOC:dph]
Full description |

Standard name | GO_CHLORIDE_ION_HOMEOSTASIS
Systematic name | M24068
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of chloride ions within an organism or cell. [GOC:jid, GOC:mah]
Full description |

Standard name | GO_METAL_ION_HOMEOSTASIS
Systematic name | M24069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of metal ions within an organism or cell. [GOC:ai, GOC:jid, GOC:mah]
Full description |

Standard name | GO_MONOVALENT_INORGANIC_CATION_HOMEOSTASIS
Systematic name | M6796
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of monovalent inorganic cations within an organism or cell. [GOC:ai, GOC:jid, GOC:mah]
Full description |

Standard name | GO_ZINC_ION_HOMEOSTASIS
Systematic name | M15703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of zinc ions within an organism or cell. [GOC:ai, GOC:jid, GOC:mah]
Full description |

Standard name | GO_COPPER_ION_HOMEOSTASIS
Systematic name | M15302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of copper ions within an organism or cell. [GOC:ai, GOC:jid, GOC:mah]
Full description |

Standard name | GO_IRON_ION_HOMEOSTASIS
Systematic name | M16638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of iron ions within an organism or cell. [GOC:ai, GOC:jid, GOC:mah]
Full description |

Standard name | GO_POTASSIUM_ION_HOMEOSTASIS
Systematic name | M11291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of potassium ions within an organism or cell. [GOC:jid, GOC:mah]
Full description |

Standard name | GO_TRANSITION_METAL_ION_HOMEOSTASIS
Systematic name | M12630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of transition metal ions within an organism or cell. A transition metal is an element whose atom has an incomplete d-subshell of extranuclear electrons, or which gives rise to a cation or cations with an incomplete d-subshell. Transition metals often have more than one valency state. Biologically relevant transition metals include vanadium, manganese, iron, copper, cobalt, nickel, molybdenum and silver. [GOC:jid, GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_SODIUM_ION_HOMEOSTASIS
Systematic name | M13923
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of sodium ions within an organism or cell. [GOC:ai, GOC:jid, GOC:mah]
Full description |

Standard name | GO_ANION_HOMEOSTASIS
Systematic name | M13284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of anions within an organism or cell. [GOC:ceb, GOC:jid, GOC:mah]
Full description |

Standard name | GO_MONOVALENT_INORGANIC_ANION_HOMEOSTASIS
Systematic name | M14345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of monovalent inorganic anions within an organism or cell. [GOC:ai, GOC:jid, GOC:mah]
Full description |

Standard name | GO_TRANSMEMBRANE_TRANSPORT
Systematic name | M16266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a solute is transported across a lipid bilayer, from one side of a membrane to the other. [GOC:dph, GOC:jid]
Full description |

Standard name | GO_NUCLEOBASE_CONTAINING_SMALL_MOLECULE_METABOLIC_PROCESS
Systematic name | M11969
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular chemical reactions and pathways involving a nucleobase-containing small molecule: a nucleobase, a nucleoside, or a nucleotide. [GOC:vw]
Full description |

Standard name | GO_LIPID_HOMEOSTASIS
Systematic name | M12045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of lipid within an organism or cell. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_FATTY_ACID_HOMEOSTASIS
Systematic name | M12334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of fatty acid within an organism or cell. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_ACYLGLYCEROL_HOMEOSTASIS
Systematic name | M10118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of acylglycerol within an organism or cell. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_PHOSPHOLIPID_HOMEOSTASIS
Systematic name | M24070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of phospholipid within an organism or cell. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_STEROL_HOMEOSTASIS
Systematic name | M10645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of sterol within an organism or cell. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_RESPONSE_TO_HYPEROXIA
Systematic name | M24071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating increased oxygen tension. [GOC:kmv]
Full description |

Standard name | GO_OXIDATION_REDUCTION_PROCESS
Systematic name | M13770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A metabolic process that results in the removal or addition of one or more electrons to or from a substance, with or without the concomitant removal or addition of a proton or protons. [GOC:dhl, GOC:ecd, GOC:jh2, GOC:jid, GOC:mlg, GOC:rph]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_CONTRACTION
Systematic name | M15697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardiac muscle contraction. [GOC:ecd]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CARDIAC_MUSCLE_CONTRACTION
Systematic name | M24072
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cardiac muscle contraction. [GOC:ecd]
Full description |

Standard name | GO_RELAXATION_OF_CARDIAC_MUSCLE
Systematic name | M11389
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the extent of cardiac muscle contraction is reduced. [GOC:ecd]
Full description |

Standard name | GO_DIGESTIVE_SYSTEM_DEVELOPMENT
Systematic name | M12187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the digestive system over time, from its formation to the mature structure. The digestive system is the entire structure in which digestion takes place. Digestion is all of the physical, chemical, and biochemical processes carried out by multicellular organisms to break down ingested nutrients into components that may be easily absorbed and directed into metabolism. [GOC:jid]
Full description |

Standard name | GO_REFLEX
Systematic name | M11677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An automatic response to a stimulus beginning with a nerve impulse from a receptor and ending with the action of an effector such as a gland or a muscle. Signaling never reaches a level of consciousness. [GOC:dph, ISBN:0877797099]
Full description |

Standard name | GO_SERTOLI_CELL_DIFFERENTIATION
Systematic name | M16094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized structural and/or functional features of a Sertoli cell. A Sertoli cell is a supporting cell projecting inward from the basement membrane of seminiferous tubules. [GOC:dph]
Full description |

Standard name | GO_SERTOLI_CELL_DEVELOPMENT
Systematic name | M11009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a Sertoli cell over time, from its formation to the mature structure. Cell development does not include the steps involved in committing a cell to a Sertoli cell fate. [GOC:dph]
Full description |

Standard name | GO_SYNAPTIC_TRANSMISSION_GLYCINERGIC
Systematic name | M24073
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The vesicular release of glycine from a presynapse, across a chemical synapse, the subsequent activation of glycine receptors at the postsynapse of a target cell (neuron, muscle, or secretory cell) and the effects of this activation on the postsynaptic membrane potential and ionic composition of the postsynaptic cytosol. This process encompasses both spontaneous and evoked release of neurotransmitter and all parts of synaptic vesicle exocytosis. Evoked transmission starts with the arrival of an action potential at the presynapse. [GOC:dos]
Full description |

Standard name | GO_RIGHTING_REFLEX
Systematic name | M24074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A reflex process in which an animal immediately tries to turn over after being placed in a supine position. [GOC:dph, PMID:8635460]
Full description |

Standard name | GO_PARATHYROID_GLAND_DEVELOPMENT
Systematic name | M24075
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the parathyroid gland over time, from its formation to the mature structure. The parathyroid gland is an organ specialised for secretion of parathyroid hormone. [GOC:dph, ISBN:0721662544]
Full description |

Standard name | GO_RADIAL_GLIAL_CELL_DIFFERENTIATION
Systematic name | M24076
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which neuroepithelial cells of the neural tube give rise to radial glial cells, specialized bipotential progenitors cells of the brain. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GOC:dph]
Full description |

Standard name | GO_BERGMANN_GLIAL_CELL_DIFFERENTIATION
Systematic name | M24077
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which neuroepithelial cells of the neural tube give rise to Brgmann glial cells, specialized bipotential progenitors cells of the cerebellum. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GOC:dph, PMID:10375501]
Full description |

Standard name | GO_ROOF_OF_MOUTH_DEVELOPMENT
Systematic name | M24078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of the roof of the mouth from an initial condition to its mature state. This process begins with the formation of the structure and ends with the mature structure. The roof of the mouth is the partition that separates the nasal and oral cavities. [GOC:dph, ISBN:0721662544]
Full description |

Standard name | GO_HARD_PALATE_DEVELOPMENT
Systematic name | M24079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of the hard palate from an initial condition to its mature state. This process begins with the formation of the structure and ends with the mature structure, whatever form that may be including its natural destruction. The hard palate is the anterior portion of the palate consisting of bone and mucous membranes. [GOC:dph, ISBN:0721662544]
Full description |

Standard name | GO_SOFT_PALATE_DEVELOPMENT
Systematic name | M24080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of the soft palate from an initial condition to its mature state. This process begins with the formation of the structure and ends with the mature structure, whatever form that may be including its natural destruction. The soft palate is the posterior portion of the palate extending from the posterior edge of the hard palate. [GOC:dph, ISBN:0721662544]
Full description |

Standard name | GO_CONVERGENT_EXTENSION
Systematic name | M15001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphogenetic process in which an epithelium narrows along one axis and lengthens in a perpendicular axis. [GOC:dgf, GOC:dph, PMID:12062082]
Full description |

Standard name | GO_CONVERGENT_EXTENSION_INVOLVED_IN_GASTRULATION
Systematic name | M24081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphogenetic process in which an epithelium narrows along one axis and lengthens in a perpendicular axis usually resulting in the formation of the three primary germ layers, ectoderm, mesoderm and endoderm. [GOC:dph, PMID:12062082]
Full description |

Standard name | GO_CONVERGENT_EXTENSION_INVOLVED_IN_AXIS_ELONGATION
Systematic name | M24082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphogenetic process in which an epithelium narrows along one axis and lengthens in a perpendicular axis contributing to the lengthening of the axis of an organism. [GOC:dph, PMID:12062082]
Full description |

Standard name | GO_CONVERGENT_EXTENSION_INVOLVED_IN_ORGANOGENESIS
Systematic name | M24083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphogenetic process in which an epithelium narrows along one axis and lengthens in a perpendicular axis contribution to the shaping of an organ. [GOC:dph, PMID:12062082]
Full description |

Standard name | GO_ANATOMICAL_STRUCTURE_REGRESSION
Systematic name | M12324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process in which an anatomical stucture is destroyed as a part of its normal progression. [GOC:dph]
Full description |

Standard name | GO_PHARYNGEAL_SYSTEM_DEVELOPMENT
Systematic name | M14854
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the pharyngeal system over time, from its formation to the mature structure. The pharyngeal system is a transient embryonic complex that is specific to vertebrates. It comprises the pharyngeal arches, bulges of tissues of mesoderm and neural crest derivation through which pass nerves and pharyngeal arch arteries. The arches are separated internally by pharyngeal pouches, evaginations of foregut endoderm, and externally by pharyngeal clefts, invaginations of surface ectoderm. The development of the system ends when the stucture it contributes to are forming: the thymus, thyroid, parathyroids, maxilla, mandible, aortic arch, cardiac outflow tract, external and middle ear. [GOC:dph]
Full description |

Standard name | GO_CARDIAC_MUSCLE_CELL_PROLIFERATION
Systematic name | M24084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a cardiac muscle cell population by cell division. [GOC:dph, GOC:rph, PMID:11161571]
Full description |

Standard name | GO_PERICARDIUM_DEVELOPMENT
Systematic name | M14572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the pericardium over time, from its formation to the mature structure. The pericardium is a double-walled sac that contains the heart and the roots of the aorta, vena cava and the pulmonary artery. [GOC:dph, GOC:rph, PMID:15138308, PMID:16376438]
Full description |

Standard name | GO_RETINAL_BIPOLAR_NEURON_DIFFERENTIATION
Systematic name | M24085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a bipolar cell, the last neuron to be generated in the retina. [GOC:ascb_2009, GOC:bf, GOC:dph, GOC:tb]
Full description |

Standard name | GO_RETINA_DEVELOPMENT_IN_CAMERA_TYPE_EYE
Systematic name | M15828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the retina over time, from its formation to the mature structure. The retina is the innermost layer or coating at the back of the eyeball, which is sensitive to light and in which the optic nerve terminates. [GOC:bf, GOC:dph, ISBN:0815340729]
Full description |

Standard name | GO_RETINA_MORPHOGENESIS_IN_CAMERA_TYPE_EYE
Systematic name | M16748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the retina is generated and organized. [GOC:bf, GOC:dph, GOC:mtg_sensu]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CARDIAC_MUSCLE_CELL_PROLIFERATION
Systematic name | M24086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cardiac muscle cell proliferation. [GOC:dph, GOC:rph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CARDIAC_MUSCLE_CELL_PROLIFERATION
Systematic name | M14434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cardiac muscle cell proliferation. [GOC:dph, GOC:rph]
Full description |

Standard name | GO_REGULATION_OF_ACROSOME_REACTION
Systematic name | M14285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the acrosome reaction. [GOC:dph]
Full description |

Standard name | GO_CARDIAC_MUSCLE_CONTRACTION
Systematic name | M24087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Muscle contraction of cardiac muscle tissue. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_GLYCOSYLATION
Systematic name | M11686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein glycosylation. Protein glycosylation is the addition of a carbohydrate or carbohydrate derivative unit to a protein amino acid, e.g. the addition of glycan chains to proteins. [GOC:dms, GOC:dph, GOC:pr]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_GLYCOSYLATION
Systematic name | M24088
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the glycosylation of one or more amino acid residues within a protein. Protein glycosylation is the addition of a carbohydrate or carbohydrate derivative unit to a protein amino acid, e.g. the addition of glycan chains to proteins. [GOC:dms, GOC:dph, GOC:pr]
Full description |

Standard name | GO_NEUROFILAMENT_CYTOSKELETON_ORGANIZATION
Systematic name | M24089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of cytoskeletal structures comprising neurofilaments and their associated proteins. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPITHELIAL_CELL_PROLIFERATION_INVOLVED_IN_WOUND_HEALING
Systematic name | M24090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of epithelial cell proliferation, contributing to the restoration of integrity to a damaged tissue following an injury. [GOC:dph]
Full description |

Standard name | GO_ANGIOGENESIS_INVOLVED_IN_WOUND_HEALING
Systematic name | M15711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Blood vessel formation when new vessels emerge from the proliferation of pre-existing blood vessels and contribute to the series of events that restore integrity to a damaged tissue, following an injury. [GOC:dph, PMID:15039218]
Full description |

Standard name | GO_MAMMARY_GLAND_INVOLUTION
Systematic name | M24091
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The tissue remodeling that removes differentiated mammary epithelia during weaning. [GOC:dph, PMID:15282149]
Full description |

Standard name | GO_EMBRYONIC_RETINA_MORPHOGENESIS_IN_CAMERA_TYPE_EYE
Systematic name | M24092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of the retina is generated and organized in a camera-type eye during the embryonic life stage. [GOC:dgh, GOC:dph]
Full description |

Standard name | GO_UTERUS_DEVELOPMENT
Systematic name | M16539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The reproductive developmental process whose specific outcome is the progression of the uterus over time, from its formation to the mature structure. [GOC:dph, GOC:ebc]
Full description |

Standard name | GO_VAGINA_DEVELOPMENT
Systematic name | M24093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The reproductive developmental process whose specific outcome is the progression of the vagina over time, from its formation to the mature structure. [GOC:dph, GOC:ebc]
Full description |

Standard name | GO_CANONICAL_WNT_SIGNALING_PATHWAY
Systematic name | M12752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of a Wnt protein to a frizzled family receptor on the surface of the target cell, followed by propagation of the signal via beta-catenin, and ending with a change in transcription of target genes. In this pathway, the activated receptor signals via downstream effectors that result in the inhibition of beta-catenin phosphorylation, thereby preventing degradation of beta-catenin. Stabilized beta-catenin can then accumulate and travel to the nucleus to trigger changes in transcription of target genes. [GOC:bf, GOC:dph, PMID:11532397, PMID:19619488]
Full description |

Standard name | GO_MICTURITION
Systematic name | M24094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulation of body fluids process in which parasympathetic nerves stimulate the bladder wall muscle to contract and expel urine from the body. [GOC:dph]
Full description |

Standard name | GO_SYNAPSE_MATURATION
Systematic name | M24095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that organizes a synapse so that it attains its fully functional state. Synaptic maturation plays a critical role in the establishment of effective synaptic connections in early development. [GOC:dph, GOC:ef]
Full description |

Standard name | GO_REGULATION_OF_RESTING_MEMBRANE_POTENTIAL
Systematic name | M24096
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the establishment or extent of a resting potential, the electrical charge across the plasma membrane, with the interior of the cell negative with respect to the exterior. The resting potential is the membrane potential of a cell that is not stimulated to be depolarized or hyperpolarized. [GOC:dph, GOC:ef, ISBN:0195088433]
Full description |

Standard name | GO_REGULATION_OF_POSTSYNAPTIC_MEMBRANE_POTENTIAL
Systematic name | M12831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the potential difference across a post-synaptic membrane. [GOC:dph, GOC:ef]
Full description |

Standard name | GO_INHIBITORY_POSTSYNAPTIC_POTENTIAL
Systematic name | M24097
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that causes a temporary decrease in postsynaptic membrane potential due to the flow of negatively charged ions into the postsynaptic cell. The flow of ions that causes an IPSP is an inhibitory postsynaptic current (IPSC) and makes it more difficult for the neuron to fire an action potential. [GOC:dph, GOC:ef]
Full description |

Standard name | GO_MEMBRANE_HYPERPOLARIZATION
Systematic name | M14828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which membrane potential increases with respect to its steady-state potential, usually from negative potential to a more negative potential. For example, during the repolarization phase of an action potential the membrane potential often becomes more negative or hyperpolarized before returning to the steady-state resting potential. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHAGOCYTOSIS_ENGULFMENT
Systematic name | M24100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the internalization of bacteria, immune complexes and other particulate matter or of an apoptotic cell by phagocytosis. [GOC:dph]
Full description |

Standard name | GO_AUDITORY_RECEPTOR_CELL_DEVELOPMENT
Systematic name | M14284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an auditory receptor cell over time, from its formation to the mature structure. Cell development does not include the steps involved in committing a cell to a specific fate. [GOC:dph]
Full description |

Standard name | GO_INNER_EAR_RECEPTOR_CELL_DEVELOPMENT
Systematic name | M16719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an inner ear receptor cell over time, from its formation to the mature structure. Cell development does not include the steps involved in committing a cell to a specific fate. [GOC:dph]
Full description |

Standard name | GO_INNER_EAR_RECEPTOR_CELL_STEREOCILIUM_ORGANIZATION
Systematic name | M24101
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a stereocilium. A stereocilium is an actin-based protrusion from the apical surface of inner ear receptor cells. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_GROWTH_HORMONE_SECRETION
Systematic name | M13765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of growth hormone from a cell. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GROWTH_HORMONE_SECRETION
Systematic name | M24102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the regulated release of growth hormone from a cell. [GOC:dph]
Full description |

Standard name | GO_SOMATOTROPIN_SECRETING_CELL_DIFFERENTIATION
Systematic name | M24103
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized structural and/or functional features of a somatotropin secreting cell. A somatotropin secreting cell is an acidophilic cell of the anterior pituitary that produces growth hormone, somatotropin. [GOC:dph]
Full description |

Standard name | GO_PREPULSE_INHIBITION
Systematic name | M13064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a startle magnitude is reduced when the startling stimulus is preceded by a low-intensity prepulse. [GOC:dph, PMID:10341260]
Full description |

Standard name | GO_MATERNAL_PROCESS_INVOLVED_IN_FEMALE_PREGNANCY
Systematic name | M14720
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A reproductive process occurring in the mother that allows an embryo or fetus to develop within it. [GOC:dph]
Full description |

Standard name | GO_EMBRYONIC_PROCESS_INVOLVED_IN_FEMALE_PREGNANCY
Systematic name | M24104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A reproductive process occurring in the embryo or fetus that allows the embryo or fetus to develop within the mother. [GOC:dph]
Full description |

Standard name | GO_MATERNAL_PROCESS_INVOLVED_IN_PARTURITION
Systematic name | M24105
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A reproductive process occurring in the mother that results in birth. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_SYNCYTIUM_FORMATION_BY_PLASMA_MEMBRANE_FUSION
Systematic name | M13027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the formation of a syncytium, a mass of cytoplasm containing several nuclei enclosed within a single plasma membrane, by the fusion of the plasma membranes of two or more individual cells. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_POSTTRANSCRIPTIONAL_GENE_SILENCING
Systematic name | M15829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the inactivation of gene expression by a posttranscriptional mechanism. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_POSTTRANSCRIPTIONAL_GENE_SILENCING
Systematic name | M24106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the inactivation of gene expression by a posttranscriptional mechanism. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_POSTTRANSCRIPTIONAL_GENE_SILENCING
Systematic name | M24107
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the inactivation of gene expression by a posttranscriptional mechanism. [GOC:dph]
Full description |

Standard name | GO_PLATELET_DENSE_GRANULE_ORGANIZATION
Systematic name | M24108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a platelet dense granule. A platelet dense granule is an electron-dense granule occurring in blood platelets that stores and secretes adenosine nucleotides and serotonin. They contain a highly condensed core consisting of serotonin, histamine, calcium, magnesium, ATP, ADP, pyrophosphate and membrane lysosomal proteins. [GOC:dph, PMID:11487378]
Full description |

Standard name | GO_PHOSPHOLIPASE_C_ACTIVATING_DOPAMINE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a dopamine receptor binding to its physiological ligand, where the pathway proceeds with activation of phospholipase C (PLC) and a subsequent release of inositol trisphosphate (IP3) and diacylglycerol (DAG). [GOC:dph, GOC:signaling, GOC:tb, PMID:12675914]
Full description |

Standard name | GO_REGULATION_OF_DOPAMINE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a dopamine receptor signaling pathway activity. A dopamine receptor signaling pathway is the series of molecular signals generated as a consequence of a dopamine receptor binding to one of its physiological ligands. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DOPAMINE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the dopamine receptor protein signaling pathway. A dopamine receptor signaling pathway is the series of molecular signals generated as a consequence of a dopamine receptor binding to one of its physiological ligands. [GOC:dph]
Full description |

Standard name | GO_LIMB_BUD_FORMATION
Systematic name | M24112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process pertaining to the initial formation of a limb bud from unspecified parts. This process begins with the formation of a local condensation of mesenchyme cells within the prospective limb field, and ends when a limb bud is recognizable. [GOC:dgh, GOC:dph]
Full description |

Standard name | GO_MALE_MATING_BEHAVIOR
Systematic name | M24113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific behavior of a male organism that is associated with reproduction. [GOC:dph, GOC:pr, GOC:tb]
Full description |

Standard name | GO_FEMALE_MATING_BEHAVIOR
Systematic name | M24114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific behavior of a female organism that is associated with reproduction. [GOC:dph, GOC:pr, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_LIPASE_ACTIVITY
Systematic name | M13211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lipase activity, the hydrolysis of a lipid or phospholipid. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPASE_ACTIVITY
Systematic name | M13101
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of lipase activity, the hydrolysis of a lipid or phospholipid. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPASE_ACTIVITY
Systematic name | M15143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of lipase activity, the hydrolysis of a lipid or phospholipid. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_NUCLEAR_TRANSCRIBED_MRNA_POLY_A_TAIL_SHORTENING
Systematic name | M12888
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of poly(A) tail shortening of a nuclear-transcribed mRNA. Poly(A) tail shortening is the decrease in length of the poly(A) tail of an mRNA from full length to an oligo(A) length. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_PRIMITIVE_HEMOPOIESIS
Systematic name | M24115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A first transient wave of blood cell production that, in vertebrates, gives rise to erythrocytes (red blood cells) and myeloid cells. [GOC:bf, GOC:dph, PMID:15378083, PMID:15617691]
Full description |

Standard name | GO_DEFINITIVE_HEMOPOIESIS
Systematic name | M16138
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A second wave of blood cell production that, in vertebrates, generates long-term hemopoietic stem cells that continously provide erythroid, myeloid and lymphoid lineages throughout adulthood. [GOC:bf, GOC:dph, PMID:15378083, PMID:15617691]
Full description |

Standard name | GO_HEMATOPOIETIC_STEM_CELL_DIFFERENTIATION
Systematic name | M11841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a hematopoietic stem cell. A stem cell is a cell that retains the ability to divide and proliferate throughout life to provide progenitor cells that can differentiate into specialized cells. [GOC:bf, GOC:BHF, GOC:dph, GOC:rl, PMID:15378083]
Full description |

Standard name | GO_CAMERA_TYPE_EYE_PHOTORECEPTOR_CELL_DIFFERENTIATION
Systematic name | M13764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a photoreceptor cell in a camera-type eye. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_RETINAL_ROD_CELL_DIFFERENTIATION
Systematic name | M29245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a retinal rod cell. [GOC:dph]
Full description |

Standard name | GO_MESENCHYMAL_TO_EPITHELIAL_TRANSITION
Systematic name | M10691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A transition where a mesenchymal cell establishes apical/basolateral polarity, forms intercellular adhesive junctions, synthesizes basement membrane components and becomes an epithelial cell. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_DELAMINATION
Systematic name | M29246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of negative regulation of cell adhesion that results in a cell or sheet of cells splitting off from an existing epithelial sheet. [GOC:dph, PMID:16962574, PMID:18343170]
Full description |

Standard name | GO_DETECTION_OF_CELL_DENSITY
Systematic name | M29247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which information about the density of cells in a population is received and converted into a molecular signal. [GOC:dph]
Full description |

Standard name | GO_ANATOMICAL_STRUCTURE_HOMEOSTASIS
Systematic name | M16781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A homeostatic process involved in the maintenance of an internal steady state within a defined anatomical structure of an organism, including control of cellular proliferation and death and control of metabolic function. An anatomical structure is any biological entity that occupies space and is distinguished from its surroundings. Anatomical structures can be macroscopic such as a carpel, or microscopic such as an acrosome. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_GLIAL_CELL_PROLIFERATION
Systematic name | M12542
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glial cell proliferation. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLIAL_CELL_PROLIFERATION
Systematic name | M24117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of glial cell proliferation. [GOC:dph, GOC:sl, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLIAL_CELL_PROLIFERATION
Systematic name | M12815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or decreases the rate or extent of glial cell proliferation. [GOC:dph, GOC:sl, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_FEEDING_BEHAVIOR
Systematic name | M12390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of the behavior associated with the intake of food. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_INITIATION_FROM_RNA_POLYMERASE_II_PROMOTER
Systematic name | M16841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of a process involved in starting transcription from an RNA polymerase II promoter. [GOC:dph, GOC:tb, GOC:txnOH]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_INITIATION_FROM_RNA_POLYMERASE_II_PROMOTER
Systematic name | M11004
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of a process involved in starting transcription from an RNA polymerase II promoter. [GOC:dph, GOC:tb, GOC:txnOH]
Full description |

Standard name | GO_REGULATION_OF_RESPIRATORY_BURST
Systematic name | M10095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate frequency or extent of a phase of elevated metabolic activity, during which oxygen consumption increases; this leads to the production, by an NADH dependent system, of hydrogen peroxide (H2O2), superoxide anions and hydroxyl radicals. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPIRATORY_BURST_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M24118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of a phase of elevated metabolic activity, during which oxygen consumption increases made as a defense response ; this leads to the production, by an NADH dependent system, of hydrogen peroxide (H2O2), superoxide anions and hydroxyl radicals. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPIRATORY_BURST
Systematic name | M24119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate frequency or extent of a phase of elevated metabolic activity, during which oxygen consumption increases; this leads to the production, by an NADH dependent system, of hydrogen peroxide (H2O2), superoxide anions and hydroxyl radicals. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPIRATORY_BURST
Systematic name | M24120
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate frequency or extent of a phase of elevated metabolic activity, during which oxygen consumption increases; this leads to the production, by an NADH dependent system, of hydrogen peroxide (H2O2), superoxide anions and hydroxyl radicals. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_EMBRYONIC_SKELETAL_JOINT_MORPHOGENESIS
Systematic name | M24121
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of skeletal joints are generated and organized during the embryonic phase. A skeletal joint is the connecting structure between the bones of the skeleton. [GOC:bf, GOC:BHF, GOC:dph, UBERON:0000982]
Full description |

Standard name | GO_REGULATION_OF_CELL_DEVELOPMENT
Systematic name | M16228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of the progression of the cell over time, from its formation to the mature structure. Cell development does not include the steps involved in committing a cell to a specific fate. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_EPITHELIAL_CILIUM_MOVEMENT_INVOLVED_IN_DETERMINATION_OF_LEFT_RIGHT_ASYMMETRY
Systematic name | M24122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of cilia of epithelial cells of the Left Right Organizer (LRO), also referred to as the node in mouse or the Kupffer's vesicle in zebrafish, resulting in the leftward fluid flow across the LRO and generation or transport of a signal which determines asymmetry in an organism's body plan with respect to the left and right halves. [GOC:dgh, GOC:dph, GOC:krc, GOC:mlg, PMID:28559696, PMID:29367579]
Full description |

Standard name | GO_TRANSDIFFERENTIATION
Systematic name | M24123
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The conversion of a differentiated cell of one fate into a differentiated cell of another fate without first undergoing cell division or reversion to a more primitive or stem cell-like fate. [GOC:dph, GOC:kmv]
Full description |

Standard name | GO_LONG_TERM_SYNAPTIC_POTENTIATION
Systematic name | M14454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates synaptic plasticity such that synapses are changed resulting in the increase in the rate, or frequency of synaptic transmission at the synapse. [GOC:dgh, GOC:dph]
Full description |

Standard name | GO_LONG_TERM_SYNAPTIC_DEPRESSION
Systematic name | M12475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that modulates synaptic plasticity such that synapses are changed resulting in the decrease in the rate, or frequency of synaptic transmission at the synapse. [GOC:dgh, GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_CILIUM_BEAT_FREQUENCY_INVOLVED_IN_CILIARY_MOTILITY
Systematic name | M24125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency of cilium beating involved in ciliary motility. [GOC:BHF, GOC:cilia, GOC:dph, GOC:krc, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SARCOMERE_ORGANIZATION
Systematic name | M24126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of myofibril assembly by organization of muscle actomyosin into sarcomeres. The sarcomere is the repeating unit of a myofibril in a muscle cell, composed of an array of overlapping thick and thin filaments between two adjacent Z discs. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SARCOMERE_ORGANIZATION
Systematic name | M24127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of myofibril assembly by organization of muscle actomyosin into sarcomeres. The sarcomere is the repeating unit of a myofibril in a muscle cell, composed of an array of overlapping thick and thin filaments between two adjacent Z discs. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHATIDYLINOSITOL_DEPHOSPHORYLATION
Systematic name | M24128
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reaction involving the removal of one or more phosphate groups from a phosphatidylinositol. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_REPOLARIZATION
Systematic name | M16233
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the establishment or extent of a membrane potential in the polarizing direction towards the resting potential, usually from positive to negative. [GOC:BHF, GOC:dph, GOC:mtg_cardiac_conduct_nov11, GOC:tb]
Full description |

Standard name | GO_ELASTIN_CATABOLIC_PROCESS
Systematic name | M24129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of elastin. Elastin is a glycoprotein which is randomly coiled and crosslinked to form elastic fibers that are found in connective tissue. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_BLOOD_VESSEL_REMODELING
Systematic name | M24130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of blood vessel remodeling, the reorganization or renovation of existing blood vessels. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_RYANODINE_SENSITIVE_CALCIUM_RELEASE_CHANNEL_ACTIVITY
Systematic name | M13617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the activity of a ryanodine-sensitive calcium-release channel. The ryanodine-sensitive calcium-release channel catalyzes the transmembrane transfer of a calcium ion by a channel that opens when a ryanodine class ligand has been bound by the channel complex or one of its constituent parts. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RYANODINE_SENSITIVE_CALCIUM_RELEASE_CHANNEL_ACTIVITY
Systematic name | M16278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the activity of a ryanodine-sensitive calcium-release channel. The ryanodine-sensitive calcium-release channel catalyzes the transmembrane transfer of a calcium ion by a channel that opens when a ryanodine class ligand has been bound by the channel complex or one of its constituent parts. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RYANODINE_SENSITIVE_CALCIUM_RELEASE_CHANNEL_ACTIVITY
Systematic name | M24131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the activity of a ryanodine-sensitive calcium-release channel. The ryanodine-sensitive calcium-release channel catalyzes the transmembrane transfer of a calcium ion by a channel that opens when a ryanodine class ligand has been bound by the channel complex or one of its constituent parts. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_CARDIAC_EPITHELIAL_TO_MESENCHYMAL_TRANSITION
Systematic name | M15266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A transition where a cardiac epithelial cell loses apical/basolateral polarity, severs intercellular adhesive junctions, degrades basement membrane components and becomes a migratory mesenchymal cell. [GOC:BHF, GOC:dph, PMID:16314491, PMID:1996351]
Full description |

Standard name | GO_DEFINITIVE_ERYTHROCYTE_DIFFERENTIATION
Systematic name | M24132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Erythrocyte differentiation which occurs as part of the process of definitive hemopoiesis. [GOC:add, GOC:BHF, GOC:dph]
Full description |

Standard name | GO_HEAD_DEVELOPMENT
Systematic name | M14257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a head from an initial condition to its mature state. The head is the anterior-most division of the body. [GOC:dph]
Full description |

Standard name | GO_HEAD_MORPHOGENESIS
Systematic name | M16968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the head are generated and organized. The head is the anterior-most division of the body. [GOC:dph]
Full description |

Standard name | GO_FACE_DEVELOPMENT
Systematic name | M13473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a face from an initial condition to its mature state. The face is the ventral division of the head. [GOC:dph]
Full description |

Standard name | GO_CELL_CHEMOTAXIS
Systematic name | M10536
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a motile cell guided by a specific chemical concentration gradient. Movement may be towards a higher concentration (positive chemotaxis) or towards a lower concentration (negative chemotaxis). [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_INTERFERON_GAMMA
Systematic name | M15517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of a response to interferon-gamma. Response to interferon gamma is a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interferon-gamma stimulus. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_INTERFERON_GAMMA
Systematic name | M24134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of a response to interferon-gamma. Response to interferon gamma is a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interferon-gamma stimulus. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_INTERFERON_GAMMA
Systematic name | M24135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of a response to interferon-gamma. Response to interferon gamma is a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interferon-gamma stimulus. [GOC:dph]
Full description |

Standard name | GO_INTERFERON_GAMMA_MEDIATED_SIGNALING_PATHWAY
Systematic name | M14004
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of interferon-gamma to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. Interferon gamma is the only member of the type II interferon found so far. [GOC:add, GOC:dph, GOC:signaling]
Full description |

Standard name | GO_REGULATION_OF_TYPE_I_INTERFERON_MEDIATED_SIGNALING_PATHWAY
Systematic name | M14758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of a type I interferon-mediated signaling pathway. A type I interferon-mediated signaling pathway is the series of molecular events generated as a consequence of a type I interferon binding to a cell surface receptor. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TYPE_I_INTERFERON_MEDIATED_SIGNALING_PATHWAY
Systematic name | M24136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of a type I interferon-mediated signaling pathway. A type I interferon-mediated signaling pathway is the series of molecular events generated as a consequence of a type I interferon binding to a cell surface receptor. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TYPE_I_INTERFERON_MEDIATED_SIGNALING_PATHWAY
Systematic name | M24137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of a type I interferon-mediated signaling pathway. A type I interferon-mediated signaling pathway is the series of molecular events generated as a consequence of a type I interferon binding to a cell surface receptor. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_LOCALIZATION
Systematic name | M13054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a process in which a cell, a substance, or a cellular entity is transported to, or maintained in a specific location within or in the membrane of a cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_TRABECULA_FORMATION
Systematic name | M15294
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of creating a trabecula in an organ. A trabecula is a small, often microscopic, tissue element in the form of a small beam, strut or rod, which generally has a mechanical function. Trabecula are usually but not necessarily, composed of dense collagenous tissue. [GOC:dph]
Full description |

Standard name | GO_BONE_TRABECULA_FORMATION
Systematic name | M24138
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of creating a trabecula in the bone. A trabecula is a tissue element in the form of a small beam, strut or rod. [GOC:dph]
Full description |

Standard name | GO_HEART_TRABECULA_FORMATION
Systematic name | M14824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of creating a trabecula in the heart. A trabecula is a tissue element in the form of a small beam, strut or rod. [GOC:dph]
Full description |

Standard name | GO_BONE_DEVELOPMENT
Systematic name | M12408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of bone over time, from its formation to the mature structure. Bone is the hard skeletal connective tissue consisting of both mineral and cellular components. [GOC:dph]
Full description |

Standard name | GO_BONE_MORPHOGENESIS
Systematic name | M15227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which bones are generated and organized. [GOC:dph]
Full description |

Standard name | GO_ENDOCHONDRAL_BONE_MORPHOGENESIS
Systematic name | M15575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which bones are generated and organized as a result of the conversion of initial cartilaginous anlage into bone. [GOC:dph, PMID:11680679]
Full description |

Standard name | GO_CARTILAGE_DEVELOPMENT_INVOLVED_IN_ENDOCHONDRAL_BONE_MORPHOGENESIS
Systematic name | M14448
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the cartilage that will provide a scaffold for mineralization of endochondral bones. [GOC:dph]
Full description |

Standard name | GO_CELL_ADHESION_MOLECULE_PRODUCTION
Systematic name | M24139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of a cell adhesion molecule due to biosynthesis or secretion. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_ADHESION_MOLECULE_PRODUCTION
Systematic name | M34216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of cell adhesion molecule production. Cell adhesion molecule production is the appearance of a cell adhesion molecule as a result of its biosynthesis or a decrease in its catabolism. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_ADHESION_MOLECULE_PRODUCTION
Systematic name | M34217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of cell adhesion molecule production. Cell adhesion molecule production is the appearance of a cell adhesion molecule as a result of its biosynthesis or a decrease in its catabolism. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_CRANIAL_SUTURE_MORPHOGENESIS
Systematic name | M24141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which any suture between cranial bones is generated and organized. [GOC:dph, GOC:pr, GOC:sl]
Full description |

Standard name | GO_REGULATION_OF_FC_RECEPTOR_MEDIATED_STIMULATORY_SIGNALING_PATHWAY
Systematic name | M24142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of the Fc receptor mediated stimulatory signaling pathway. The Fc receptor mediated stimulatory signaling pathway is a series of molecular signals generated as a consequence of a the binding of the Fc portion of an immunoglobulin by an Fc receptor capable of activating or perpetuating an immune response. The Fc portion of an immunoglobulin is its C-terminal constant region. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FC_RECEPTOR_MEDIATED_STIMULATORY_SIGNALING_PATHWAY
Systematic name | M24143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of the Fc receptor mediated stimulatory signaling pathway. The Fc receptor mediated stimulatory signaling pathway is a series of molecular signals generated as a consequence of a the binding of the Fc portion of an immunoglobulin by an Fc receptor capable of activating or perpetuating an immune response. The Fc portion of an immunoglobulin is its C-terminal constant region. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_ATRIAL_CARDIAC_MUSCLE_CELL_MEMBRANE_DEPOLARIZATION
Systematic name | M24144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the establishment or extent of a membrane potential in the depolarizing direction away from the resting potential in an atrial cardiomyocyte. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_ATRIAL_CARDIAC_MUSCLE_CELL_MEMBRANE_REPOLARIZATION
Systematic name | M24145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the establishment or extent of a membrane potential in the polarizing direction towards the resting potential in an atrial cardiomyocyte. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_VENTRICULAR_CARDIAC_MUSCLE_CELL_MEMBRANE_DEPOLARIZATION
Systematic name | M24146
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the establishment or extent of a membrane potential in the depolarizing direction away from the resting potential in a ventricular cardiomyocyte. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_MAST_CELL_DIFFERENTIATION
Systematic name | M24147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized myeloid precursor cell acquires the specialized features of a mast cell. A mast cell is a cell that is found in almost all tissues containing numerous basophilic granules and capable of releasing large amounts of histamine and heparin upon activation. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CARDIAC_MUSCLE_CELL_MYOBLAST_DIFFERENTIATION
Systematic name | M24148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a cardiac myoblast. A cardiac myoblast is a precursor cell that has been committed to a cardiac muscle cell fate but retains the ability to divide and proliferate throughout life. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_INNERVATION
Systematic name | M16477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a nerve invades a tissue and makes functional synaptic connection within the tissue. [GOC:dph, GOC:sart]
Full description |

Standard name | GO_AXONOGENESIS_INVOLVED_IN_INNERVATION
Systematic name | M24149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The neurite development process that generates a long process of a neuron, as it invades a target tissue. [GOC:dph, GOC:sart]
Full description |

Standard name | GO_PATHWAY_RESTRICTED_SMAD_PROTEIN_PHOSPHORYLATION
Systematic name | M11735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing a phosphate group on to a pathway restricted SMAD protein. A pathway restricted SMAD protein is an effector protein that acts directly downstream of the transforming growth factor family receptor. [GOC:dph, ISBN:3527303782]
Full description |

Standard name | GO_REGULATION_OF_SMAD_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M24150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of SMAD protein signal transduction. Pathway-restricted SMAD proteins and common-partner SMAD proteins are involved in the transforming growth factor beta receptor signaling pathways. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SMAD_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M24151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of SMAD protein signal transduction. Pathway-restricted SMAD proteins and common-partner SMAD proteins are involved in the transforming growth factor beta receptor signaling pathways. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMAD_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M24152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of the SMAD protein signaling pathway. Pathway-restricted SMAD proteins and common-partner SMAD proteins are involved in the transforming growth factor beta receptor signaling pathways. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PATHWAY_RESTRICTED_SMAD_PROTEIN_PHOSPHORYLATION
Systematic name | M13562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of pathway-restricted SMAD protein phosphorylation. Pathway-restricted SMAD proteins and common-partner SMAD proteins are involved in the transforming growth factor beta receptor signaling pathways. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_SMAD_PROTEIN_SIGNAL_TRANSDUCTION
Systematic name | M10081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cascade of processes by which a signal interacts with a receptor, causing a change in the activity of a SMAD protein, and ultimately effecting a change in the functioning of the cell. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_GROWTH_HORMONE_RECEPTOR_SIGNALING_PATHWAY_VIA_JAK_STAT
Systematic name | M24153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which STAT proteins (Signal Transducers and Activators of Transcription) are activated by members of the JAK (janus activated kinase) family of tyrosine kinases, following the binding of physiological ligands to the growth hormone receptor. Once activated, STATs dimerize and translocate to the nucleus and modulate the expression of target genes. [GOC:BHF, GOC:dph, PMID:11445442]
Full description |

Standard name | GO_REGULATION_OF_GROWTH_HORMONE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of the growth hormone receptor signaling pathway. The growth hormone receptor signaling pathway is the series of molecular signals generated as a consequence of growth hormone receptor binding to its physiological ligand. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_CYTOSOLIC_CALCIUM_ION_TRANSPORT
Systematic name | M12779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of calcium ions (Ca2+) into, out of or within the cytosol. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PENILE_ERECTION
Systematic name | M24155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of penile erection. Penile erection is the hardening, enlarging and rising of the penis which often occurs in the sexually aroused male and enables sexual intercourse. Achieved by increased inflow of blood into the vessels of erectile tissue, and decreased outflow. [GOC:add, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PENILE_ERECTION
Systematic name | M24156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of penile erection. Penile erection is the hardening, enlarging and rising of the penis which often occurs in the sexually aroused male and enables sexual intercourse. Achieved by increased inflow of blood into the vessels of erectile tissue, and decreased outflow. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CARDIAC_SEPTUM_MORPHOGENESIS
Systematic name | M15683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structure of a cardiac septum is generated and organized. A cardiac septum is a partition that separates parts of the heart. [GOC:dph, GOC:mtg_heart]
Full description |

Standard name | GO_VENTRICULAR_SEPTUM_MORPHOGENESIS
Systematic name | M10479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process in which a ventricular septum is generated and organized. A ventricular septum is an anatomical structure that separates the lower chambers (ventricles) of the heart from one another. [GOC:dph]
Full description |

Standard name | GO_ATRIAL_SEPTUM_MORPHOGENESIS
Systematic name | M12559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process in which atrial septum is generated and organized. The atrial septum separates the upper chambers (the atria) of the heart from one another. [GOC:dph, GOC:mtg_heart]
Full description |

Standard name | GO_AORTA_SMOOTH_MUSCLE_TISSUE_MORPHOGENESIS
Systematic name | M24157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the structure of the smooth muscle tissue surrounding the aorta is generated and organized. An aorta is an artery that carries blood from the heart to other parts of the body. [GOC:bf, GOC:dgh, GOC:dph, Wikipedia:Aorta]
Full description |

Standard name | GO_RESPONSE_TO_GROWTH_HORMONE
Systematic name | M12897
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a growth hormone stimulus. Growth hormone is a peptide hormone that binds to the growth hormone receptor and stimulates growth. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_HEART_GROWTH
Systematic name | M15398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The increase in size or mass of the heart. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_HEART_GROWTH
Systematic name | M15342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate or extent of heart growth. Heart growth is the increase in size or mass of the heart. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HEART_GROWTH
Systematic name | M11191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate or extent of heart growth. Heart growth is the increase in size or mass of the heart. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_LUNG_MORPHOGENESIS
Systematic name | M11145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the lung are generated and organized. [GOC:dph]
Full description |

Standard name | GO_LUNG_VASCULATURE_DEVELOPMENT
Systematic name | M24158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a lung vasculature from an initial condition to its mature state. This process begins with the formation of the lung vasculature and ends with the mature structure. The lung vasculature is composed of the tubule structures that carry blood or lymph in the lungs. [GOC:dph, GOC:mtg_lung]
Full description |

Standard name | GO_LUNG_EPITHELIUM_DEVELOPMENT
Systematic name | M10346
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of the lung epithelium from an initial condition to its mature state. This process begins with the formation of lung epithelium and ends with the mature structure. The lung epithelium is the specialized epithelium that lines the inside of the lung. [GOC:dph, GOC:mtg_lung]
Full description |

Standard name | GO_EPITHELIUM_DEVELOPMENT
Systematic name | M10268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an epithelium over time, from its formation to the mature structure. An epithelium is a tissue that covers the internal or external surfaces of an anatomical structure. [GOC:dph, GOC:mtg_lung]
Full description |

Standard name | GO_LUNG_SACCULE_DEVELOPMENT
Systematic name | M24159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a lung saccule from an initial condition to its mature state. The lung saccule is the primitive gas exchange portion of the lung composed of type I and type II cells. [GOC:dph, GOC:mtg_lung]
Full description |

Standard name | GO_BRONCHUS_DEVELOPMENT
Systematic name | M24160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a bronchus from an initial condition to its mature state. This process begins with the formation of the bronchus and ends with the mature structure. The bronchus is the portion of the airway that connects to the lungs. [GOC:dph]
Full description |

Standard name | GO_LUNG_GROWTH
Systematic name | M24161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The increase in size or mass of a lung. In all air-breathing vertebrates the lungs are developed from the ventral wall of the oesophagus as a pouch which divides into two sacs. In amphibians and many reptiles the lungs retain very nearly this primitive sac-like character, but in the higher forms the connection with the esophagus becomes elongated into the windpipe and the inner walls of the sacs become more and more divided, until, in the mammals, the air spaces become minutely divided into tubes ending in small air cells, in the walls of which the blood circulates in a fine network of capillaries. In mammals the lungs are more or less divided into lobes, and each lung occupies a separate cavity in the thorax. [GOC:dph]
Full description |

Standard name | GO_TRACHEA_DEVELOPMENT
Systematic name | M13906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a trachea over time, from its formation to the mature structure. The trachea is the portion of the airway that attaches to the bronchi as it branches. [GOC:dph]
Full description |

Standard name | GO_TRACHEA_MORPHOGENESIS
Systematic name | M14492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a trachea is generated and organized. The trachea is the portion of the airway that attaches to the bronchi as it branches. [GOC:dph]
Full description |

Standard name | GO_TRACHEA_FORMATION
Systematic name | M24162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process pertaining to the initial formation of a trachea from unspecified parts. The process begins with the specific processes that contribute to the appearance of the discrete structure and ends when the trachea is recognizable. The trachea is the portion of the airway that attaches to the bronchi as it branches. [GOC:dph]
Full description |

Standard name | GO_EPITHELIAL_TUBE_BRANCHING_INVOLVED_IN_LUNG_MORPHOGENESIS
Systematic name | M10732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a highly ordered sequence of patterning events generates the branched epithelial tubes of the lung, consisting of reiterated combinations of bud outgrowth, elongation, and dichotomous subdivision of terminal units. [GOC:dph, GOC:mtg_lung]
Full description |

Standard name | GO_BRANCHING_INVOLVED_IN_PROSTATE_GLAND_MORPHOGENESIS
Systematic name | M24163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the branching structure of the prostate gland is generated and organized. A branch is a division or offshoot from a main stem. [GOC:dph]
Full description |

Standard name | GO_MAMMARY_GLAND_MORPHOGENESIS
Systematic name | M10302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which anatomical structures of the mammary gland are generated and organized. Morphogenesis refers to the creation of shape. The mammary gland is a large compound sebaceous gland that in female mammals is modified to secrete milk. [GOC:dph]
Full description |

Standard name | GO_BRANCHING_INVOLVED_IN_MAMMARY_GLAND_DUCT_MORPHOGENESIS
Systematic name | M16308
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the branching structure of the mammary gland duct is generated and organized. The mammary gland is a large compound sebaceous gland that in female mammals is modified to secrete milk. [GOC:dph]
Full description |

Standard name | GO_BRANCHING_INVOLVED_IN_SALIVARY_GLAND_MORPHOGENESIS
Systematic name | M16217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the branching structure of the salivary gland is generated and organized. [GOC:dph]
Full description |

Standard name | GO_BUD_ELONGATION_INVOLVED_IN_LUNG_BRANCHING
Systematic name | M24164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a bud in the lung grows out from the point where it is formed. [GOC:dph, GOC:mtg_lung]
Full description |

Standard name | GO_REGULATION_OF_GASTRIC_ACID_SECRETION
Systematic name | M24165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate frequency or extent of gastric secretion. Gastric secretion is the regulated release of gastric acid (hydrochloric acid) by parietal or oxyntic cells during digestion. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GASTRIC_ACID_SECRETION
Systematic name | M24166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate frequency or extent of gastric secretion. Gastric secretion is the regulated release of gastric acid (hydrochloric acid) by parietal or oxyntic cells during digestion. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DIGESTIVE_SYSTEM_PROCESS
Systematic name | M11453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of a digestive system process, a physical, chemical, or biochemical process carried out by living organisms to break down ingested nutrients into components that may be easily absorbed and directed into metabolism. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DIGESTIVE_SYSTEM_PROCESS
Systematic name | M15328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of a digestive system process, a physical, chemical, or biochemical process carried out by living organisms to break down ingested nutrients into components that may be easily absorbed and directed into metabolism. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_LUNG_LOBE_DEVELOPMENT
Systematic name | M24167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a lung lobe from an initial condition to its mature state. This process begins with the formation of a lung lobe by branching morphogenesis and ends with the mature structure. A lung lobe is one of the rounded projections that compose the lung. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FERTILIZATION
Systematic name | M24168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of fertilization. Fertilization is the union of gametes of opposite sexes during the process of sexual reproduction to form a zygote. It involves the fusion of the gametic nuclei (karyogamy) and cytoplasm (plasmogamy). [GOC:dph]
Full description |

Standard name | GO_ACROSOMAL_VESICLE_EXOCYTOSIS
Systematic name | M24169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The calcium ion regulated exocytosis which results in fusion of the acrosomal vesicle with the plasma membrane of the sperm as part of the acrosome reaction. [GOC:dph]
Full description |

Standard name | GO_LUNG_CELL_DIFFERENTIATION
Systematic name | M10854
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells, e.g. embryonic or regenerative cells, acquire specialized structural and/or functional features of a mature cell found in the lung. Differentiation includes the processes involved in commitment of a cell to a specific fate. [GOC:dph, GOC:mtg_lung]
Full description |

Standard name | GO_LOBAR_BRONCHUS_EPITHELIUM_DEVELOPMENT
Systematic name | M24170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a lobar bronchus epithelium from an initial condition to its mature state. This process begins with the formation of the lobar bronchus epithelium and ends with the mature structure. The lobar bronchus epithelium is the tissue made up of epithelial cells that lines the inside of the lobar bronchus. [GOC:dph, GOC:mtg_lung]
Full description |

Standard name | GO_LOBAR_BRONCHUS_DEVELOPMENT
Systematic name | M24171
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a lobar bronchus from an initial condition to its mature state. This process begins with the formation of the lobar bronchus and ends with the mature structure. The lobar bronchus is the major airway within the respiratory tree that starts by division of the principal bronchi on both sides and ends at the point of its own subdivision into tertiary or segmental bronchi. [GOC:dph, GOC:mtg_lung]
Full description |

Standard name | GO_LUNG_ASSOCIATED_MESENCHYME_DEVELOPMENT
Systematic name | M24172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a lung-associated mesenchyme from an initial condition to its mature state. This process begins with the formation of lung-associated mesenchyme and ends with the mature structure. Lung-associated mesenchyme is the tissue made up of loosely connected mesenchymal cells in the lung. [GOC:dph, GOC:mtg_lung]
Full description |

Standard name | GO_MESENCHYME_DEVELOPMENT
Systematic name | M14932
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a mesenchymal tissue over time, from its formation to the mature structure. A mesenchymal tissue is made up of loosely packed stellate cells. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_CELL_PROJECTION_ASSEMBLY
Systematic name | M15341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of cell projection assembly. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPITHELIAL_CELL_PROLIFERATION_INVOLVED_IN_LUNG_MORPHOGENESIS
Systematic name | M24173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate or frequency of epithelial cell proliferation that results in the lung attaining its shape. [GOC:dph]
Full description |

Standard name | GO_EPITHELIAL_CELL_PROLIFERATION_INVOLVED_IN_LUNG_MORPHOGENESIS
Systematic name | M24174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of epithelial cells, resulting in the expansion of a cell population that contributes to the shaping of the lung. [GOC:dph]
Full description |

Standard name | GO_TYPE_I_PNEUMOCYTE_DIFFERENTIATION
Systematic name | M24175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a type I pneumocyte. A type I pneumocyte is a flattened cell with greatly attenuated cytoplasm and a paucity of organelles. [GOC:dph, GOC:mtg_lung, ISBN:0721662544]
Full description |

Standard name | GO_TYPE_II_PNEUMOCYTE_DIFFERENTIATION
Systematic name | M24176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a type II pneumocyte. A type II pneumocyte is a surfactant secreting cell that contains abundant cytoplasm containing numerous lipid-rich multilamellar bodies. [GOC:dph, GOC:mtg_lung, ISBN:0721662544]
Full description |

Standard name | GO_PROSTATE_GLAND_MORPHOGENESIS
Systematic name | M10587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a prostate gland are generated and organized. [GOC:dph, PMID:18977204]
Full description |

Standard name | GO_PROSTATIC_BUD_FORMATION
Systematic name | M24177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphogenetic process in which a region of the fetal urogenital sinus epithelium is specified to become the prostate, resulting in prostate bud outgrowth. [GOC:dph, PMID:18977204]
Full description |

Standard name | GO_PROSTATE_GLANDULAR_ACINUS_DEVELOPMENT
Systematic name | M16057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a glandular acinus of the prostate gland over time, from its initial formation to the mature structure. The glandular acini are the saclike structures of the gland. [GOC:dph, PMID:18977204]
Full description |

Standard name | GO_PROSTATE_GLANDULAR_ACINUS_MORPHOGENESIS
Systematic name | M24178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the prostate glandular acini are generated and organized. The glandular acini are the saclike structures of the gland. [GOC:dph]
Full description |

Standard name | GO_TRACHEA_CARTILAGE_DEVELOPMENT
Systematic name | M24179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the tracheal cartilage over time, from its formation to the mature structure. Cartilage is a connective tissue dominated by extracellular matrix containing collagen type II and large amounts of proteoglycan, particularly chondroitin sulfate. [GOC:dph]
Full description |

Standard name | GO_CARTILAGE_MORPHOGENESIS
Systematic name | M11632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of cartilage are generated and organized. [GOC:dph]
Full description |

Standard name | GO_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M10365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of muscle tissue over time, from its initial formation to its mature state. Muscle tissue is a contractile tissue made up of actin and myosin fibers. [GOC:dph]
Full description |

Standard name | GO_SKELETAL_MUSCLE_ORGAN_DEVELOPMENT
Systematic name | M13253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a skeletal muscle organ over time from its initial formation to its mature state. A skeletal muscle organ includes the skeletal muscle tissue and its associated connective tissue. [GOC:dph]
Full description |

Standard name | GO_DIAPHRAGM_DEVELOPMENT
Systematic name | M24180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the diaphragm over time from its initial formation to the mature structure. The diaphragm is a skeletal muscle that is responsible for contraction and expansion of the lungs. [GOC:dph]
Full description |

Standard name | GO_RESPIRATORY_SYSTEM_DEVELOPMENT
Systematic name | M15095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the respiratory system over time from its formation to its mature structure. The respiratory system carries out respiratory gaseous exchange. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NECROTIC_CELL_DEATH
Systematic name | M16044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of necrotic cell death. Necrotic cell death is a cell death process that is morphologically characterized by a gain in cell volume (oncosis), swelling of organelles, plasma membrane rupture and subsequent loss of intracellular contents. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_DEATH
Systematic name | M13898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate or frequency of cell death. Cell death is the specific activation or halting of processes within a cell so that its vital functions markedly cease, rather than simply deteriorating gradually over time, which culminates in cell death. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_VITAMIN_D_BIOSYNTHETIC_PROCESS
Systematic name | M24181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate frequency or extent of a vitamin D biosynthetic process. Vitamin D biosynthesis is the chemical reactions and pathways resulting in the formation of vitamin D, any of a group of related, fat-soluble compounds that are derived from delta-5,7 steroids and play a central role in calcium metabolism. Specific forms of vitamin D include calciferol (ergocalciferol; vitamin D2) and cholecalciferol (calciol; vitamin D3). [CHEBI:27300, GOC:BHF, GOC:mah, ISBN:0471331309]
Full description |

Standard name | GO_REGULATION_OF_CALCIDIOL_1_MONOOXYGENASE_ACTIVITY
Systematic name | M24182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of calcidiol 1-monooxygenase activity. Calcidiol 1-monooxygenase activity is catalysis of the reaction: calcidiol + NADPH + H+ + O2 = calcitriol + NADP+ + H2O. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_DEVELOPMENTAL_GROWTH_INVOLVED_IN_MORPHOGENESIS
Systematic name | M15682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The increase in size or mass of an anatomical structure that contributes to the structure attaining its shape. [GOC:dph]
Full description |

Standard name | GO_APOPTOTIC_PROCESS_INVOLVED_IN_MORPHOGENESIS
Systematic name | M15365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process that contributes to the shaping of an anatomical structure. [GOC:dph, GOC:mtg_apoptosis]
Full description |

Standard name | GO_EPITHELIAL_TUBE_MORPHOGENESIS
Systematic name | M24183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a tube are generated and organized from an epithelium. Epithelial tubes transport gases, liquids and cells from one site to another and form the basic structure of many organs and tissues, with tube shape and organization varying from the single-celled excretory organ in Caenorhabditis elegans to the branching trees of the mammalian kidney and insect tracheal system. [GOC:dph]
Full description |

Standard name | GO_NEUROEPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M15104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which epiblast cells acquire specialized features of neuroepithelial cells. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_MORPHOGENESIS_OF_AN_EPITHELIAL_FOLD
Systematic name | M12440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphogenetic process in which an epithelial sheet bends along a linear axis. [GOC:dph]
Full description |

Standard name | GO_MORPHOGENESIS_OF_AN_EPITHELIAL_BUD
Systematic name | M24184
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphogenetic process in which a bud forms from an epithelial sheet. A bud is a protrusion that forms form the sheet by localized folding. [GOC:dph]
Full description |

Standard name | GO_CELL_FATE_SPECIFICATION_INVOLVED_IN_PATTERN_SPECIFICATION
Systematic name | M24185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process involved in the specification of the identity of a cell in a field of cells that is being instructed as to how to differentiate. Once specification has taken place, that cell will be committed to differentiate down a specific pathway if left in its normal environment. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_INTESTINAL_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M13813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a columnar/cuboidal epithelial cell of the intestine. [GOC:dph]
Full description |

Standard name | GO_INTESTINAL_EPITHELIAL_CELL_DEVELOPMENT
Systematic name | M12973
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a columnar/cuboidal epithelial cell of the intestine over time, from its formation to the mature structure. [GOC:dph]
Full description |

Standard name | GO_MULTICELLULAR_ORGANISMAL_IRON_ION_HOMEOSTASIS
Systematic name | M24186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of the distribution of iron stores within tissues and organs of a multicellular organism. [GOC:dph, GOC:hjd, GOC:tb]
Full description |

Standard name | GO_CHONDROBLAST_DIFFERENTIATION
Systematic name | M24187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a mesenchymal cell, acquires specialized structural and/or functional features of a chondroblast. Differentiation includes the processes involved in commitment of a cell to a chondroblast fate. A chondroblast is a precursor cell to chondrocytes. [GOC:dph]
Full description |

Standard name | GO_MAMMARY_GLAND_FORMATION
Systematic name | M24188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process pertaining to the initial formation of the mammary gland from unspecified parts. The process begins with formation of the mammary line and ends when the solid mammary bud invades the primary mammary mesenchyme. [GOC:dph, PMID:16168142, PMID:17120154]
Full description |

Standard name | GO_DICHOTOMOUS_SUBDIVISION_OF_AN_EPITHELIAL_TERMINAL_UNIT
Systematic name | M24189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an epithelial cord, rod or tube bifurcates at its end. [GOC:dph]
Full description |

Standard name | GO_LATERAL_SPROUTING_FROM_AN_EPITHELIUM
Systematic name | M24190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a branch forms along the side of an epithelium. [GOC:dph]
Full description |

Standard name | GO_BRANCH_ELONGATION_OF_AN_EPITHELIUM
Systematic name | M10802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The growth process in which a branch increases in length from its base to its tip. [GOC:dph]
Full description |

Standard name | GO_MAMMARY_GLAND_DUCT_MORPHOGENESIS
Systematic name | M16170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which anatomical structures of the mammary ducts are generated and organized. Mammary ducts are epithelial tubes that transport milk. [GOC:dph, PMID:17120154]
Full description |

Standard name | GO_TUBE_LUMEN_CAVITATION
Systematic name | M24191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a lumen by hollowing out a solid rod or cord. [GOC:dph]
Full description |

Standard name | GO_ADIPOSE_TISSUE_DEVELOPMENT
Systematic name | M16487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of adipose tissue over time, from its formation to the mature structure. Adipose tissue is specialized tissue that is used to store fat. [GOC:dph]
Full description |

Standard name | GO_FAT_PAD_DEVELOPMENT
Systematic name | M24193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a fat pad from its initial formation to its mature structure. A fat pad is an accumulation of adipose tissue. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_CHROMOSOME_CONDENSATION
Systematic name | M29248
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of chromosome condensation, the progressive compaction of dispersed interphase chromatin into threadlike chromosomes prior to mitotic or meiotic nuclear division, or during apoptosis, in eukaryotic cells. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_VESICLE_MEDIATED_TRANSPORT
Systematic name | M11889
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of vesicle-mediated transport, the directed movement of substances, either within a vesicle or in the vesicle membrane, into, out of or within a cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_ER_TO_GOLGI_VESICLE_MEDIATED_TRANSPORT
Systematic name | M16654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of ER to Golgi vesicle-mediated transport, the directed movement of substances from the endoplasmic reticulum (ER) to the Golgi, mediated by COP II vesicles. Small COP II coated vesicles form from the ER and then fuse directly with the cis-Golgi. Larger structures are transported along microtubules to the cis-Golgi. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MEIOSIS_I
Systematic name | M24194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of meiosis I, a cell cycle process comprising the steps by which a cell progresses through the first phase of meiosis, in which cells divide and homologous chromosomes are paired and segregated from each other, producing two daughter cells. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MICROTUBULE_BASED_MOVEMENT
Systematic name | M13400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of microtubule-based movement, the movement of organelles, other microtubules and other particles along microtubules, mediated by motor proteins. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSCRIPTION_INITIATION_FROM_RNA_POLYMERASE_II_PROMOTER
Systematic name | M24195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of a process involved in starting transcription from an RNA polymerase II promoter. [GOC:dph, GOC:tb, GOC:txnOH]
Full description |

Standard name | GO_MESENCHYMAL_EPITHELIAL_CELL_SIGNALING
Systematic name | M24196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that mediates the transfer of information from a mesenchymal cell to an epithelial cell where it is received and interpreted. [GOC:dph]
Full description |

Standard name | GO_MAMMARY_GLAND_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M11306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized epithelial cell becomes a more specialized epithelial cell of the mammary gland. [GOC:dph]
Full description |

Standard name | GO_EPITHELIAL_CELL_PROLIFERATION_INVOLVED_IN_SALIVARY_GLAND_MORPHOGENESIS
Systematic name | M24197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of epithelial cells of the submandibular salivary gland, resulting in the expansion of a cell population and the shaping of the gland. [GOC:dph, PMID:17336109]
Full description |

Standard name | GO_DICHOTOMOUS_SUBDIVISION_OF_TERMINAL_UNITS_INVOLVED_IN_SALIVARY_GLAND_BRANCHING
Systematic name | M24198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a salivary epithelial cord bifurcates at its end. [GOC:dph]
Full description |

Standard name | GO_EMBRYONIC_PLACENTA_MORPHOGENESIS
Systematic name | M16456
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the embryonic placenta is generated and organized. [GOC:dph]
Full description |

Standard name | GO_BRANCHING_INVOLVED_IN_LABYRINTHINE_LAYER_MORPHOGENESIS
Systematic name | M14326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the branches of the fetal placental villi are generated and organized. The villous part of the placenta is called the labyrinth layer. [GOC:dph, PMID:16916377]
Full description |

Standard name | GO_PLACENTA_BLOOD_VESSEL_DEVELOPMENT
Systematic name | M12124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a blood vessel of the placenta over time, from its formation to the mature structure. [GOC:dph, PMID:16916377]
Full description |

Standard name | GO_URETERIC_BUD_FORMATION
Systematic name | M24199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of the ureteric bud from the Wolffian duct. This process begins when the bud protrudes from the duct and ends when it is a recognizable bud. [GOC:dph, PMID:16916378]
Full description |

Standard name | GO_URETERIC_BUD_ELONGATION
Systematic name | M24200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental growth in which the ureteric bud grows along its axis beginning with the growth of the primary ureteric bud and ending when the branches of the bud have elongated. [GOC:dph, PMID:16916378]
Full description |

Standard name | GO_BRANCH_ELONGATION_INVOLVED_IN_URETERIC_BUD_BRANCHING
Systematic name | M24201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The growth of a branch of the ureteric bud along its axis. [GOC:dph, PMID:16916378]
Full description |

Standard name | GO_EPITHELIAL_MESENCHYMAL_CELL_SIGNALING
Systematic name | M24202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in the transfer of information from an epithelial cell to a mesenchymal cell where it is interpreted. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_PROSTATIC_BUD_FORMATION
Systematic name | M24203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of prostatic bud formation, the morphogenetic process in which a region of the fetal urogenital sinus epithelium is specified to become the prostate, resulting in prostate bud outgrowth. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_BRANCHING_INVOLVED_IN_PROSTATE_GLAND_MORPHOGENESIS
Systematic name | M24204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of prostate gland branching, the process in which the branching structure of the prostate gland is generated and organized. A branch is a division or offshoot from a main stem. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_MORPHOGENESIS_OF_A_BRANCHING_STRUCTURE
Systematic name | M10470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of branching morphogenesis, the process in which the anatomical structures of branches are generated and organized. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_BRANCHING_INVOLVED_IN_SALIVARY_GLAND_MORPHOGENESIS
Systematic name | M24205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of branching morphogenesis in the salivary gland epithelium. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHOLIPID_CATABOLIC_PROCESS
Systematic name | M24206
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of phospholipid catabolism, the chemical reactions and pathways resulting in the breakdown of phospholipids, any lipid containing phosphoric acid as a mono- or diester. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_RIBONUCLEASE_ACTIVITY
Systematic name | M24207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of ribonuclease activity, catalysis of the hydrolysis of phosphodiester bonds in chains of RNA. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CELL_DIFFERENTIATION_INVOLVED_IN_EMBRYONIC_PLACENTA_DEVELOPMENT
Systematic name | M12035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of the embryonic placenta. [GOC:dph]
Full description |

Standard name | GO_TROPHOBLAST_GIANT_CELL_DIFFERENTIATION
Systematic name | M13834
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a trophoblast giant cell of the placenta. Trophoblast giant cells are the cell of the placenta that line the maternal decidua. [GOC:dph, PMID:16269175]
Full description |

Standard name | GO_CHORIO_ALLANTOIC_FUSION
Systematic name | M24208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell-cell adhesion process in which the cells of the chorion fuse to the cells of the allantois. [GOC:dph]
Full description |

Standard name | GO_LABYRINTHINE_LAYER_DEVELOPMENT
Systematic name | M10149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the labyrinthine layer of the placenta progresses, from its formation to its mature state. [GOC:dph]
Full description |

Standard name | GO_LABYRINTHINE_LAYER_MORPHOGENESIS
Systematic name | M24209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the labyrinthine layer of the placenta is generated and organized. [GOC:dph]
Full description |

Standard name | GO_LABYRINTHINE_LAYER_BLOOD_VESSEL_DEVELOPMENT
Systematic name | M12839
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a blood vessel of the labyrinthine layer of the placenta over time, from its formation to the mature structure. The embryonic vessels grow through the layer to come in close contact with the maternal blood supply. [GOC:dph]
Full description |

Standard name | GO_CHORION_DEVELOPMENT
Systematic name | M24210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a chorion from an initial condition to its mature state. This process begins with the formation of the structure and ends with the mature structure. The chorion is an extraembryonic membrane. [GOC:dph]
Full description |

Standard name | GO_CHORIONIC_TROPHOBLAST_CELL_DIFFERENTIATION
Systematic name | M24211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells of the ectoplacental cone acquire specialized structural and/or functional features that characterize chorionic trophoblasts. These cells will migrate towards the spongiotrophoblast layer and give rise to syncytiotrophoblasts of the labyrinthine layer. [CL:0011101, GOC:dph, PMID:16983341]
Full description |

Standard name | GO_INTESTINAL_EPITHELIAL_STRUCTURE_MAINTENANCE
Systematic name | M24212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A tissue homeostatic process required for the maintenance of the structure of the intestinal epithelium. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_PROSTATE_GLAND_GROWTH
Systematic name | M15092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The increase in size or mass of the prostate gland where the increase in size or mass has the specific outcome of the progression of the gland, from its formation to its mature state. [GOC:dph]
Full description |

Standard name | GO_EPITHELIAL_CELL_DIFFERENTIATION_INVOLVED_IN_PROSTATE_GLAND_DEVELOPMENT
Systematic name | M15613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of an epithelial cell of the prostate gland. [GOC:dph]
Full description |

Standard name | GO_MAMMARY_GLAND_BRANCHING_INVOLVED_IN_PREGNANCY
Systematic name | M24214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the branching structure of the mammary gland duct is generated and organized as a part of pregnancy. [GOC:dph, PMID:19261859]
Full description |

Standard name | GO_PARENTAL_BEHAVIOR
Systematic name | M12928
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A reproductive behavior in which a parent cares for and rears offspring. [GOC:dph]
Full description |

Standard name | GO_MAMMARY_GLAND_ALVEOLUS_DEVELOPMENT
Systematic name | M24215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the mammary gland alveolus over time, from its formation to its mature state. The mammary gland alveolus is a sac-like structure that is found in the mature gland. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_MAST_CELL_CHEMOTAXIS
Systematic name | M24217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of mast cell chemotaxis. Mast cell chemotaxis is the movement of a mast cell in response to an external stimulus. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_CYTOKINE_STIMULUS
Systematic name | M15741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of a response to cytokine stimulus. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_CYTOKINE_STIMULUS
Systematic name | M14359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of a response to cytokine stimulus. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_CYTOKINE_STIMULUS
Systematic name | M14154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of a response to cytokine stimulus. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_ANDROGEN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M12117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the androgen receptor signaling pathway. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ANDROGEN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M13604
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of the androgen receptor signaling pathway. [GOC:dph]
Full description |

Standard name | GO_EPITHELIAL_CELL_PROLIFERATION_INVOLVED_IN_PROSTATE_GLAND_DEVELOPMENT
Systematic name | M24219
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of epithelial cells, resulting in the expansion of a cell population that contributes to the progression of the prostate gland over time. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EPITHELIAL_CELL_PROLIFERATION_INVOLVED_IN_PROSTATE_GLAND_DEVELOPMENT
Systematic name | M24220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of epithelial cell proliferation that contributes to the progression of the prostate gland over time. [GOC:dph]
Full description |

Standard name | GO_HAIR_FOLLICLE_PLACODE_FORMATION
Systematic name | M24221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process in which a hair placode forms. An hair follicle placode is a thickening of the ectoderm that will give rise to the hair follicle bud. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_CELL_FATE_COMMITMENT_INVOLVED_IN_FORMATION_OF_PRIMARY_GERM_LAYER
Systematic name | M12604
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The commitment of cells to specific cell fates of the endoderm, ectoderm, or mesoderm as a part of gastrulation. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_SMOOTHENED_SIGNALING_PATHWAY_INVOLVED_IN_DORSAL_VENTRAL_NEURAL_TUBE_PATTERNING
Systematic name | M24222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of activation of the transmembrane protein Smoothened contributing to the dorsal/ventral pattern of the neural tube. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_LYMPHATIC_ENDOTHELIAL_CELL_DIFFERENTIATION
Systematic name | M24223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a venous blood vessel endothelial cell acquires specialized features of a lymphatic vessel endothelial cell, a thin flattened cell that lines the inside surfaces of lymph vessels. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_BLOOD_VESSEL_ENDOTHELIAL_CELL_DIFFERENTIATION
Systematic name | M24224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a blood vessel endothelial cell, a thin flattened cell that lines the inside surfaces of blood vessels. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_ENDOTHELIAL_CELL_FATE_COMMITMENT
Systematic name | M24225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The commitment of a cell to an endothelial cell fate and its capacity to differentiate into an endothelial cell. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_ARTERY_DEVELOPMENT
Systematic name | M11359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the artery over time, from its initial formation to the mature structure. An artery is a blood vessel that carries blood away from the heart to a capillary bed. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_VENOUS_BLOOD_VESSEL_DEVELOPMENT
Systematic name | M15952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the venous blood vessel over time from its initial formation to the mature structure. Venous blood vessels carry blood back to the heart after the capillary bed. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_ARTERIAL_ENDOTHELIAL_CELL_DIFFERENTIATION
Systematic name | M24226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized endothelial cell acquires specialized features of an arterial endothelial cell, a thin flattened cell that lines the inside surfaces of arteries. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_INVOLVED_IN_CELL_FATE_COMMITMENT
Systematic name | M15684
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transcription from an RNA polymerase II promoter that contributes to the commitment of a cell to a specific fate. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_ESTABLISHMENT_OF_BLOOD_BRAIN_BARRIER
Systematic name | M24227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Establishment of the barrier between the blood and the brain. The cells in the brain are packed tightly together preventing the passage of most molecules from the blood into the brain. Only lipid soluble molecules or those that are actively transported can pass through the blood-brain barrier. [GOC:aruk, GOC:dph, GOC:sart, PMID:20080302, PMID:30280653]
Full description |

Standard name | GO_SEMICIRCULAR_CANAL_DEVELOPMENT
Systematic name | M24228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the semicircular canal from its initial formation to the mature structure. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_NEURAL_PLATE_PATTERN_SPECIFICATION
Systematic name | M24229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process that results in the creation of defined areas or spaces within the neural plate to which cells respond and eventually are instructed to differentiate. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_NEURAL_PLATE_REGIONALIZATION
Systematic name | M24230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The pattern specification process that results in the subdivision of an axis or axes of the neural plate in space to define an area or volume in which specific patterns of cell differentiation will take place or in which cells interpret a specific environment. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_EMBRYONIC_CAMERA_TYPE_EYE_FORMATION
Systematic name | M16433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of a camera-type eye from unspecified neurectoderm. This process begins with the differentiation of cells that form the optic field and ends when the optic cup has attained its shape. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MEIOSIS_I
Systematic name | M24231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of meiosis I, a cell cycle process comprising the steps by which a cell progresses through the first phase of meiosis, in which cells divide and homologous chromosomes are paired and segregated from each other, producing two daughter cells. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MACROPHAGE_CYTOKINE_PRODUCTION
Systematic name | M24232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of macrophage cytokine production. Macrophage cytokine production is the appearance of a chemokine due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CARDIAC_CELL_FATE_COMMITMENT
Systematic name | M13346
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The commitment of cells to specific cardiac cell fates and their capacity to differentiate into cardiac cells. Cardiac cells are cells that comprise the organ which pumps blood through the circulatory system. [GOC:mtg_heart]
Full description |

Standard name | GO_HEART_FORMATION
Systematic name | M13592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of the heart from unspecified parts. This process begins with the specific processes that contribute to the appearance of the heart field and the arrival of cardiac neural crest to the heart region. The process ends when the structural rudiment is recognizable. [GOC:mtg_heart]
Full description |

Standard name | GO_MESENCHYMAL_CELL_PROLIFERATION_INVOLVED_IN_LUNG_DEVELOPMENT
Systematic name | M24233
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of cells, resulting in the expansion of a mesenchymal cell population that contributes to the progression of the lung over time. A mesenchymal cell is a cell that normally gives rise to other cells that are organized as three-dimensional masses, rather than sheets. [GOC:dph]
Full description |

Standard name | GO_CARDIAC_PACEMAKER_CELL_DIFFERENTIATION
Systematic name | M24234
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a pacemaker cell. Pacemaker cells are specialized cardiomyocytes that are responsible for regulating the timing of heart contractions. [GOC:mtg_cardiac_conduct_nov11, GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_MUSCLE_CELL_FATE_COMMITMENT
Systematic name | M24235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The commitment of cells to specific cardiac muscle cell fates and their capacity to differentiate into cardiac muscle cells. Cardiac muscle cells are striated muscle cells that are responsible for heart contraction. [GOC:mtg_heart]
Full description |

Standard name | GO_CARDIAC_VASCULAR_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M24236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a cardiac vascular smooth muscle cell. A cardiac vascular smooth muscle cell covers the heart vasculature and lacks transverse striations in its constituent fibers. [GOC:mtg_heart]
Full description |

Standard name | GO_ENDOCARDIAL_CELL_DIFFERENTIATION
Systematic name | M24237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized structural and/or functional features of an endocardial cell. An endocardial cell is a specialized endothelial cell that makes up the endocardium portion of the heart. The endocardium is the innermost layer of tissue of the heart, and lines the heart chambers. [GOC:mtg_heart]
Full description |

Standard name | GO_REGULATION_OF_GENE_SILENCING
Systematic name | M16555
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of gene silencing, the transcriptional or post-transcriptional process carried out at the cellular level that results in long-term gene inactivation. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GENE_SILENCING
Systematic name | M16226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of gene silencing, the transcriptional or post-transcriptional process carried out at the cellular level that results in long-term gene inactivation. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_LEFT_RIGHT_PATTERN_FORMATION
Systematic name | M12118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The pattern specification process that results in the subdivision of the left/right axis in space to define an area or volume in which specific patterns of cell differentiation will take place or in which cells interpret a specific environment. [GOC:mtg_heart]
Full description |

Standard name | GO_CELL_MIGRATION_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M10271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a cell from one site to another that will contribute to the progression of the heart over time, from its initial formation, to the mature organ. [GOC:mtg_heart]
Full description |

Standard name | GO_CORONARY_VASCULATURE_DEVELOPMENT
Systematic name | M10510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the blood vessels of the heart over time, from its formation to the mature structure. [GOC:mtg_heart]
Full description |

Standard name | GO_CORONARY_VASCULATURE_MORPHOGENESIS
Systematic name | M24238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of blood vessels of the heart are generated and organized. The blood vessel is the vasculature carrying blood. [GOC:mtg_heart]
Full description |

Standard name | GO_VASCULOGENESIS_INVOLVED_IN_CORONARY_VASCULAR_MORPHOGENESIS
Systematic name | M24239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The differentiation of endothelial cells from progenitor cells that contributes to blood vessel development in the heart, and the de novo formation of blood vessels and tubes. [GOC:mtg_heart]
Full description |

Standard name | GO_CORONARY_ARTERY_MORPHOGENESIS
Systematic name | M24240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of coronary arteries are generated and organized. Coronary arteries are blood vessels that transport blood to the heart muscle. [GOC:mtg_heart]
Full description |

Standard name | GO_ENDOCRINE_HORMONE_SECRETION
Systematic name | M24241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of a hormone into the circulatory system. [GOC:dph]
Full description |

Standard name | GO_RESPONSE_TO_FUNGICIDE
Systematic name | M11283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fungicide stimulus. Fungicides are chemicals used to kill fungi. [GOC:dph]
Full description |

Standard name | GO_KIDNEY_MORPHOGENESIS
Systematic name | M15599
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Morphogenesis of a kidney. A kidney is an organ that filters the blood and excretes the end products of body metabolism in the form of urine. [GOC:dph, GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_DENDRITIC_SPINE_DEVELOPMENT
Systematic name | M11017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the dendritic spine over time, from its formation to the mature structure. A dendritic spine is a protrusion from a dendrite and a specialized subcellular compartment involved in synaptic transmission. [GOC:dph]
Full description |

Standard name | GO_DENDRITIC_SPINE_MORPHOGENESIS
Systematic name | M24242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a dendritic spine are generated and organized. A dendritic spine is a protrusion from a dendrite and a specialized subcellular compartment involved in synaptic transmission. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_DENDRITIC_SPINE_DEVELOPMENT
Systematic name | M13079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of dendritic spine development, the process whose specific outcome is the progression of the dendritic spine over time, from its formation to the mature structure. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DENDRITIC_SPINE_DEVELOPMENT
Systematic name | M16055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of dendritic spine development, the process whose specific outcome is the progression of the dendritic spine over time, from its formation to the mature structure. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DENDRITIC_SPINE_DEVELOPMENT
Systematic name | M10173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of dendritic spine development, the process whose specific outcome is the progression of the dendritic spine over time, from its formation to the mature structure. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_DENDRITIC_SPINE_MORPHOGENESIS
Systematic name | M15518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of dendritic spine morphogenesis, the process in which the anatomical structures of a dendritic spine are generated and organized. A dendritic spine is a protrusion from a dendrite and a specialized subcellular compartment involved in synaptic transmission. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DENDRITIC_SPINE_MORPHOGENESIS
Systematic name | M24243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of dendritic spine morphogenesis, the process in which the anatomical structures of a dendritic spine are generated and organized. A dendritic spine is a protrusion from a dendrite and a specialized subcellular compartment involved in synaptic transmission. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DENDRITIC_SPINE_MORPHOGENESIS
Systematic name | M15793
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of dendritic spine morphogenesis, the process in which the anatomical structures of a dendritic spine are generated and organized. A dendritic spine is a protrusion from a dendrite and a specialized subcellular compartment involved in synaptic transmission. [GOC:dph]
Full description |

Standard name | GO_PATTERN_SPECIFICATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M24244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any developmental process that results in the creation of defined areas or spaces within the kidney to which cells respond and eventually are instructed to differentiate. [GOC:dph, GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_CELL_DIFFERENTIATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M12569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features that characterize the cells of the kidney as it progresses from its formation to the mature state. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_HEPATICOBILIARY_SYSTEM_DEVELOPMENT
Systematic name | M10249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the hepaticobiliary system over time, from its formation to the mature structure. The hepaticobiliary system is responsible for metabolic and catabolic processing of small molecules absorbed from the blood or gut, hormones and serum proteins, detoxification, storage of glycogen, triglycerides, metals and lipid soluble vitamins and excretion of bile. Included are the synthesis of albumin, blood coagulation factors, complement, and specific binding proteins. [GOC:dph]
Full description |

Standard name | GO_COMMON_BILE_DUCT_DEVELOPMENT
Systematic name | M29250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the common bile duct over time, from its formation to the mature structure. The common bile duct is formed from the joining of the common hepatic duct running from the liver, and the cystic duct running from the gall bladder. The common bile duct transports bile from the liver and gall bladder to the intestine. [PMID:20614624]
Full description |

Standard name | GO_REGULATION_OF_MRNA_CATABOLIC_PROCESS
Systematic name | M10606
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of a mRNA catabolic process, the chemical reactions and pathways resulting in the breakdown of RNA, ribonucleic acid, one of the two main type of nucleic acid, consisting of a long, unbranched macromolecule formed from ribonucleotides joined in 3',5'-phosphodiester linkage. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MRNA_CATABOLIC_PROCESS
Systematic name | M24245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of a mRNA catabolic process, the chemical reactions and pathways resulting in the breakdown of RNA, ribonucleic acid, one of the two main type of nucleic acid, consisting of a long, unbranched macromolecule formed from ribonucleotides joined in 3',5'-phosphodiester linkage. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_MEMBRANE_ORGANIZATION
Systematic name | M15146
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process which results in the assembly, arrangement of constituent parts, or disassembly of a membrane. A membrane is a double layer of lipid molecules that encloses all cells, and, in eukaryotes, many organelles; may be a single or double lipid bilayer; also includes associated proteins. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_MEMBRANE_FUSION
Systematic name | M11041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The membrane organization process that joins two lipid bilayers to form a single membrane. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CARDIAC_MUSCLE_TISSUE_REGENERATION
Systematic name | M24246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regrowth of cardiac muscle tissue to repair injured or damaged muscle fibers in the postnatal stage. [GOC:dph]
Full description |

Standard name | GO_ESTABLISHMENT_OF_ENDOTHELIAL_BARRIER
Systematic name | M14965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment of a barrier between endothelial cell layers, such as those in the brain, lung or intestine, to exert specific and selective control over the passage of water and solutes, thus allowing formation and maintenance of compartments that differ in fluid and solute composition. [GOC:dph]
Full description |

Standard name | GO_EYELID_DEVELOPMENT_IN_CAMERA_TYPE_EYE
Systematic name | M12770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the eyelid in a camera-type eye from its formation to the mature state. The eyelid is a membranous cover that helps protect and lubricate the eye. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_CARTILAGE_DEVELOPMENT
Systematic name | M10632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of cartilage development, the process whose specific outcome is the progression of the cartilage over time, from its formation to the mature structure. Cartilage is a connective tissue dominated by extracellular matrix containing collagen type II and large amounts of proteoglycan, particularly chondroitin sulfate. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CARTILAGE_DEVELOPMENT
Systematic name | M13973
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of cartilage development, the process whose specific outcome is the progression of the cartilage over time, from its formation to the mature structure. Cartilage is a connective tissue dominated by extracellular matrix containing collagen type II and large amounts of proteoglycan, particularly chondroitin sulfate. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CARTILAGE_DEVELOPMENT
Systematic name | M13499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of cartilage development, the process whose specific outcome is the progression of the cartilage over time, from its formation to the mature structure. Cartilage is a connective tissue dominated by extracellular matrix containing collagen type II and large amounts of proteoglycan, particularly chondroitin sulfate. [GOC:dph]
Full description |

Standard name | GO_UTERUS_MORPHOGENESIS
Systematic name | M24247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which anatomical structures of the uterus are generated and organized. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_WOUND_HEALING
Systematic name | M10495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the series of events that restore integrity to a damaged tissue, following an injury. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_VASCULAR_WOUND_HEALING
Systematic name | M24248
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Blood vessel formation when new vessels emerge from the proliferation of pre-existing blood vessels and contribute to the series of events that restore integrity to damaged vasculature. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_VASCULAR_WOUND_HEALING
Systematic name | M24249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of blood vessel formation when new vessels emerge from the proliferation of pre-existing blood vessels and contribute to the series of events that restore integrity to damaged vasculature. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASCULAR_WOUND_HEALING
Systematic name | M34218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of blood vessel formation when new vessels emerge from the proliferation of pre-existing blood vessels and contribute to the series of events that restore integrity to damaged vasculature. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_WOUND_HEALING
Systematic name | M29251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of the series of events that restore integrity to a damaged tissue, following an injury. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_BRANCHING_INVOLVED_IN_LUNG_MORPHOGENESIS
Systematic name | M24250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the process in which a highly ordered sequence of patterning events generates the branched structures of the lung, consisting of reiterated combinations of bud outgrowth, elongation, and dichotomous subdivision of terminal units. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_CELL_GROWTH_INVOLVED_IN_CARDIAC_MUSCLE_CELL_DEVELOPMENT
Systematic name | M24251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the growth of a cardiac muscle cell, where growth contributes to the progression of the cell over time from its initial formation to its mature state. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_GROWTH_INVOLVED_IN_CARDIAC_MUSCLE_CELL_DEVELOPMENT
Systematic name | M24252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the growth of a cardiac muscle cell, where growth contributes to the progression of the cell over time from its initial formation to its mature state. [GOC:dph]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_GROWTH_INVOLVED_IN_CARDIAC_MUSCLE_CELL_DEVELOPMENT
Systematic name | M24253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of the growth of a cardiac muscle cell, where growth contributes to the progression of the cell over time from its initial formation to its mature state. [GOC:dph]
Full description |

Standard name | GO_SOMITE_DEVELOPMENT
Systematic name | M16087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a somite from its initial formation to the mature structure. Somites are mesodermal clusters that are arranged segmentally along the anterior posterior axis of an embryo. [GOC:dph]
Full description |

Standard name | GO_SCLEROTOME_DEVELOPMENT
Systematic name | M24254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the sclerotome over time, from its initial formation to the mature structure. The sclerotome is the portion of the somite that will give rise to a vertebra. [GOC:dph]
Full description |

Standard name | GO_MUSCLE_STRUCTURE_DEVELOPMENT
Systematic name | M12572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a muscle structure over time, from its formation to its mature state. Muscle structures are contractile cells, tissues or organs that are found in multicellular organisms. [GOC:dph]
Full description |

Standard name | GO_IRIS_MORPHOGENESIS
Systematic name | M24255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the iris is generated and organized. The iris is an anatomical structure in the eye whose opening forms the pupil. The iris is responsible for controlling the diameter and size of the pupil and the amount of light reaching the retina. [GOC:dph]
Full description |

Standard name | GO_CHAPERONE_MEDIATED_PROTEIN_FOLDING
Systematic name | M16577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of inhibiting aggregation and assisting in the covalent and noncovalent assembly of single chain polypeptides or multisubunit complexes into the correct tertiary structure that is dependent on interaction with a chaperone. [GOC:dph, GOC:vw]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MYELOID_LEUKOCYTE_CYTOKINE_PRODUCTION_INVOLVED_IN_IMMUNE_RESPONSE
Systematic name | M15240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the production of a cytokine that contributes to the immune response. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_MYELOID_LEUKOCYTE_CYTOKINE_PRODUCTION
Systematic name | M24256
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that contributes to cytokine production by a myeloid cell. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_H3_K27_METHYLATION
Systematic name | M24257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of histone H3-K27 methylation. Histone H3-K27 methylation is the modification of histone H3 by addition of a methyl group to lysine at position 27 of the histone. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HISTONE_H3_K27_METHYLATION
Systematic name | M29252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of histone H3-K27 methylation. Histone H3-K27 methylation is the modification of histone H3 by addition of a methyl group to lysine at position 27 of the histone. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HISTONE_H3_K27_METHYLATION
Systematic name | M24258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of histone H3-K27 methylation. Histone H3-K27 methylation is the modification of histone H3 by addition of a methyl group to lysine at position 27 of the histone. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SEQUESTERING_OF_ZINC_ION
Systematic name | M24259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of sequestering of zinc ion. Sequestering of zinc ion is the process of binding or confining zinc ions such that they are separated from other components of a biological system. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_TYROSINE_KINASE_ACTIVITY
Systematic name | M10193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of protein tyrosine kinase activity. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_TYROSINE_KINASE_ACTIVITY
Systematic name | M12376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of protein tyrosine kinase activity. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_TYROSINE_KINASE_ACTIVITY
Systematic name | M11144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of protein tyrosine kinase activity. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEUROENDOCRINE_CELL_DIFFERENTIATION
Systematic name | M24260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized structural and/or functional features of a neuroendocrine cell. A neuroendocrine cell is a cell that receives input form a neuron which controls the secretion of an endocrine substance. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_PROTEASOMAL_PROTEIN_CATABOLIC_PROCESS
Systematic name | M13872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the chemical reactions and pathways resulting in the breakdown of a protein or peptide by hydrolysis of its peptide bonds that is mediated by the proteasome. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_LUNG_SECRETORY_CELL_DIFFERENTIATION
Systematic name | M24261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a lung secretory cell. A lung secretory cell is a specialized epithelial cell of the lung that contains large secretory granules in its apical part. [GOC:dph]
Full description |

Standard name | GO_PULMONARY_ARTERY_MORPHOGENESIS
Systematic name | M24262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the pulmonary artery are generated and organized. The pulmonary artery is the artery that carries blood from the heart to the lungs. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_3_UTR_MEDIATED_MRNA_DESTABILIZATION
Systematic name | M24263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An mRNA destabilization process in which one or more RNA-binding proteins associate with the 3'-untranslated region (UTR) of an mRNA. [GOC:dph, GOC:jh]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INSULIN_SECRETION_INVOLVED_IN_CELLULAR_RESPONSE_TO_GLUCOSE_STIMULUS
Systematic name | M24264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the regulated release of insulin that contributes to the response of a cell to glucose. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_MAMMARY_GLAND_EPITHELIUM_DEVELOPMENT
Systematic name | M10968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the mammary gland epithelium over time, from its formation to the mature structure. The mammary gland is a large compound sebaceous gland that in female mammals is modified to secrete milk. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_CHONDROCYTE_DEVELOPMENT
Systematic name | M29253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the process whose specific outcome is the progression of a chondrocyte over time, from its commitment to its mature state. Chondrocyte development does not include the steps involved in committing a chondroblast to a chondrocyte fate. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_FUNGIFORM_PAPILLA_DEVELOPMENT
Systematic name | M24266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the fungiform papilla over time, from its formation to the mature structure. The fungiform papilla is a mushroom-shaped papilla of the tongue. [GOC:dph]
Full description |

Standard name | GO_FUNGIFORM_PAPILLA_MORPHOGENESIS
Systematic name | M24267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the fungiform papilla are generated and organized. The fungiform papilla is a mushroom-shaped papilla of the tongue. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MESONEPHROS_DEVELOPMENT
Systematic name | M16683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of mesonephros development. Mesonephros development is the process whose specific outcome is the progression of the mesonephros over time, from its formation to the mature structure. The mesonephros is an organ that filters the blood and excretes the end products of body metabolism in the form of urine. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_REGULATION_OF_MESONEPHROS_DEVELOPMENT
Systematic name | M11817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of mesonephros development. Mesonephros development is the process whose specific outcome is the progression of the mesonephros over time, from its formation to the mature structure. The mesonephros is an endocrine and metabolic organ that filters the blood and excretes the end products of body metabolism in the form of urine. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_ESTABLISHMENT_OR_MAINTENANCE_OF_BIPOLAR_CELL_POLARITY
Systematic name | M15632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that results in the specification, formation or maintenance of a bipolar intracellular organization or cell growth patterns. [GOC:dph, GOC:vw]
Full description |

Standard name | GO_RETINA_VASCULATURE_DEVELOPMENT_IN_CAMERA_TYPE_EYE
Systematic name | M15224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the vasculature of the retina over time, from its formation to the mature structure. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_RETINA_VASCULATURE_MORPHOGENESIS_IN_CAMERA_TYPE_EYE
Systematic name | M24268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the vasculature of the retina is generated and organized. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_SMOOTH_MUSCLE_CELL_MATRIX_ADHESION
Systematic name | M24269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The binding of a smooth muscle cell to the extracellular matrix via adhesion molecules. [GOC:BHF, GOC:dph, PMID:8837777]
Full description |

Standard name | GO_CORNEA_DEVELOPMENT_IN_CAMERA_TYPE_EYE
Systematic name | M24270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the cornea over time, from its formation to the mature structure. The cornea is the transparent structure that covers the anterior of the eye. [GOC:dph]
Full description |

Standard name | GO_RETINAL_BLOOD_VESSEL_MORPHOGENESIS
Systematic name | M24271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a blood vessel of the retina over time, from its formation to the mature structure. [GOC:BHF, GOC:dph]
Full description |

Standard name | GO_CARDIAC_NEURAL_CREST_CELL_DIFFERENTIATION_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M24272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a cardiac neural crest cell that will migrate to the heart and contribute to its development. Cardiac neural crest cells are specialized cells that migrate toward the heart from the third, fourth and sixth pharyngeal arches. [GOC:dph, GOC:mtg_heart, PMID:19705442]
Full description |

Standard name | GO_CARDIAC_NEURAL_CREST_CELL_DEVELOPMENT_INVOLVED_IN_OUTFLOW_TRACT_MORPHOGENESIS
Systematic name | M24273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process aimed at the progression of a cardiac neural crest cell over time, from initial commitment of the cell to its specific fate, to the fully functional differentiated cell that contributes to the shaping of the outflow tract. [GOC:dph, GOC:mtg_heart]
Full description |

Standard name | GO_CELL_SURFACE_RECEPTOR_SIGNALING_PATHWAY_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M15920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals initiated by the binding of a receptor on the surface of a cell to a physiological ligand, which contributes to the progression of the heart over time. [GOC:dph, GOC:mtg_heart, GOC:signaling]
Full description |

Standard name | GO_BMP_SIGNALING_PATHWAY_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M24274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a member of the BMP (bone morphogenetic protein) family to a receptor on the surface of a target cell, which contributes to the progression of the heart over time. [GOC:dph, GOC:mtg_heart]
Full description |

Standard name | GO_NOTCH_SIGNALING_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M24275
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of an extracellular ligand to a Notch receptor on the surface of the target cell and contributing to the progression of the heart over time. [GOC:mtg_heart]
Full description |

Standard name | GO_CANONICAL_WNT_SIGNALING_PATHWAY_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M24276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals initiated by binding of a Wnt protein to a frizzled family receptor on the surface of the target cell, followed by propagation of the signal via beta-catenin, and ending with a change in transcription of target genes that contributes to the progression of the heart over time. In this pathway, the activated receptor signals via downstream effectors that result in the inhibition of beta-catenin phosphorylation, thereby preventing degradation of beta-catenin. Stabilized beta-catenin can then accumulate and travel to the nucleus to trigger changes in transcription of target genes. [GOC:mtg_heart]
Full description |

Standard name | GO_CELL_PROLIFERATION_INVOLVED_IN_HEART_MORPHOGENESIS
Systematic name | M24277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of cells, resulting in the expansion of a cell population that contributes to the shaping of the heart. [GOC:dph, GOC:mtg_heart]
Full description |

Standard name | GO_RENAL_TUBULE_DEVELOPMENT
Systematic name | M13089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the renal tubule over time from its formation to the mature form. A renal tubule is a tube that filters, re-absorbs and secretes substances to rid an organism of waste and to play a role in fluid homeostasis. [GOC:dph, GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_CARDIAC_CONDUCTION
Systematic name | M16150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Transfer of an organized electrical impulse across the heart to coordinate the contraction of cardiac muscles. The process begins with generation of an action potential (in the sinoatrial node (SA) in humans) and ends with a change in the rate, frequency, or extent of the contraction of the heart muscles. [GOC:dph]
Full description |

Standard name | GO_ESTABLISHMENT_OR_MAINTENANCE_OF_MONOPOLAR_CELL_POLARITY
Systematic name | M10325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular process that results in the specification, formation or maintenance of monopolar intracellular organization or cell growth patterns. Monopolar cell organization is directional organization along an axis. [GOC:dph, GOC:vw]
Full description |

Standard name | GO_CELL_ADHESION_INVOLVED_IN_HEART_MORPHOGENESIS
Systematic name | M24278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a cell, either to another cell or to an underlying substrate such as the extracellular matrix, via cell adhesion molecules that contributes to the shaping of the heart. [GOC:dph, GOC:mtg_heart, PMID:16860783]
Full description |

Standard name | GO_NEURAL_PRECURSOR_CELL_PROLIFERATION
Systematic name | M12054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of neural precursor cells, resulting in the expansion of a cell population. A neural precursor cell is either a nervous system stem cell or a nervous system progenitor cell. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_WNT_PROTEIN_SECRETION
Systematic name | M34219
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled release of a Wnt protein from a cell. [GOC:bf, PMID:19223472]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRIGLYCERIDE_LIPASE_ACTIVITY
Systematic name | M11278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the activity of triglyceride lipase. [GOC:dph]
Full description |

Standard name | GO_TESTOSTERONE_BIOSYNTHETIC_PROCESS
Systematic name | M24279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of testosterone, an androgen having 17beta-hydroxy and 3-oxo groups, together with unsaturation at C-4 C-5. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_TRABECULA_MORPHOGENESIS
Systematic name | M12965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of shaping a trabecula in an organ. A trabecula is a small, often microscopic, tissue element in the form of a small beam, strut or rod, which generally has a mechanical function. Trabecula are usually but not necessarily, composed of dense collagenous tissue. [GOC:dph]
Full description |

Standard name | GO_HEART_TRABECULA_MORPHOGENESIS
Systematic name | M10576
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of shaping a trabecula in the heart. A trabecula is a small, often microscopic, tissue element in the form of a small beam, strut or rod, which generally has a mechanical function. Trabecula are usually but not necessarily, composed of dense collagenous tissue. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_EXTENT_OF_CELL_GROWTH
Systematic name | M15544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the extent of cell growth. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_FROM_RNA_POLYMERASE_II_PROMOTER_IN_RESPONSE_TO_HYPOXIA
Systematic name | M13667
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transcription from an RNA polymerase II promoter as a result of a hypoxia stimulus. [GOC:dph, PMID:12511571]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_FROM_RNA_POLYMERASE_II_PROMOTER_IN_RESPONSE_TO_HYPOXIA
Systematic name | M24282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of transcription from an RNA polymerase II promoter as a result of a hypoxia stimulus. [GOC:dph]
Full description |

Standard name | GO_BONE_TRABECULA_MORPHOGENESIS
Systematic name | M10360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of shaping a trabecula in bone. A trabecula is a tissue element in the form of a small beam, strut or rod. [GOC:BHF, GOC:dph, GOC:vk]
Full description |

Standard name | GO_RENAL_SYSTEM_VASCULATURE_DEVELOPMENT
Systematic name | M14598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of vasculature of the renal system over time, from its formation to the mature structure. [GOC:dph, GOC:mtg_kidney_jan10, PMID:11891195]
Full description |

Standard name | GO_RENAL_SYSTEM_VASCULATURE_MORPHOGENESIS
Systematic name | M24283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the renal system vasculature is generated and organized. Morphogenesis pertains to the creation of form. [GOC:dph, GOC:mtg_kidney_jan10, PMID:11891195]
Full description |

Standard name | GO_CONNECTIVE_TISSUE_DEVELOPMENT
Systematic name | M15014
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of a connective tissue over time, from its formation to the mature structure. [GOC:BHF]
Full description |

Standard name | GO_TROPHOBLAST_CELL_MIGRATION
Systematic name | M24284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Trophoblast cell migration that is accomplished by extension and retraction of a pseudopodium. Trophoblast cells line the outside of the blastocyst. [GOC:dph]
Full description |

Standard name | GO_REPRODUCTIVE_SYSTEM_DEVELOPMENT
Systematic name | M12778
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the reproductive system over time from its formation to the mature structure. The reproductive system consists of the organs that function in reproduction. [GOC:dph]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_LYSOSOME
Systematic name | M11828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a lysosome. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_TYPE_B_PANCREATIC_CELL_PROLIFERATION
Systematic name | M24285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of type B pancreatic cell proliferation. [GOC:dph]
Full description |

Standard name | GO_T_FOLLICULAR_HELPER_CELL_DIFFERENTIATION
Systematic name | M34220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized T cell acquires specialized features of a mature T follicular helper cell. [GOC:dph, PMID:21572431]
Full description |

Standard name | GO_HEMATOPOIETIC_STEM_CELL_HOMEOSTASIS
Systematic name | M29254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process involved in the maintenance of the steady-state number of hematopoietic stem cells within a population of cells. [GOC:dph, PMID:21508411]
Full description |

Standard name | GO_CENTRIOLE_ELONGATION
Systematic name | M24288
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The centrosome organization process by which a centriole increases in length as part of the process of replication. [GOC:dph, PMID:21576394]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CILIUM
Systematic name | M10815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a cilium. [GOC:dph]
Full description |

Standard name | GO_MYELOID_CELL_DEVELOPMENT
Systematic name | M10592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a myeloid cell over time, from its formation to the mature structure. [GOC:dph]
Full description |

Standard name | GO_MACROPHAGE_PROLIFERATION
Systematic name | M24289
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a macrophage population by cell division. [GOC:dph, PMID:12614284, PMID:19466391]
Full description |

Standard name | GO_MICROGLIAL_CELL_PROLIFERATION
Systematic name | M24290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a microglial cell population by cell division. [GOC:dph, PMID:17344397]
Full description |

Standard name | GO_HINDGUT_DEVELOPMENT
Systematic name | M24291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the hindgut over time, from its formation to the mature structure. The hindgut is part of the alimentary canal that lies posterior to the midgut. [GOC:dph]
Full description |

Standard name | GO_GANGLION_DEVELOPMENT
Systematic name | M15677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a ganglion over time, from its formation to the mature structure. [GOC:dph]
Full description |

Standard name | GO_SYMPATHETIC_GANGLION_DEVELOPMENT
Systematic name | M24292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a sympathetic ganglion over time, from its formation to the mature structure. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_CRANIAL_GANGLION_DEVELOPMENT
Systematic name | M24293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a cranial ganglion over time, from its formation to the mature structure. [GOC:dph]
Full description |

Standard name | GO_TRIGEMINAL_GANGLION_DEVELOPMENT
Systematic name | M24294
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a trigeminal ganglion over time, from its formation to the mature structure. [GOC:dph]
Full description |

Standard name | GO_AXON_DEVELOPMENT
Systematic name | M24295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of an axon over time. Covers axonogenesis (de novo generation of an axon) and axon regeneration (regrowth), as well as processes pertaining to the progression of the axon over time (fasciculation and defasciculation). [GOC:dph, GOC:pg, GOC:pr]
Full description |

Standard name | GO_ACTIN_FILAMENT_BUNDLE_ORGANIZATION
Systematic name | M10349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that results in the assembly, arrangement of constituent parts, or disassembly of an actin filament bundle. [GOC:dph]
Full description |

Standard name | GO_CALCIUM_ION_TRANSMEMBRANE_TRANSPORT_VIA_HIGH_VOLTAGE_GATED_CALCIUM_CHANNEL
Systematic name | M24296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a calcium ion is transported from one side of a membrane to the other by means of a high voltage-gated calcium channel. [GOC:dph]
Full description |

Standard name | GO_CALCIUM_ACTIVATED_PHOSPHOLIPID_SCRAMBLING
Systematic name | M24297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a population of phospholipid molecules from one leaflet of the plasma membrane bilayer to the opposite leaflet as a result of a calcium stimulus. [GOC:krc, PMID:23532839]
Full description |

Standard name | GO_PRI_MIRNA_TRANSCRIPTION_BY_RNA_POLYMERASE_II
Systematic name | M24298
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular synthesis of primary microRNA (pri-miRNA) transcripts from a DNA template by RNA polymerase II, originating at an RNA polymerase II promoter. pri-miRNA transcripts are subsequently processed to produce the ~22nt miRNAs that function in gene regulation. [GOC:dph, GOC:kmv, PMID:18778799]
Full description |

Standard name | GO_GLYCOLYTIC_PROCESS_THROUGH_FRUCTOSE_6_PHOSPHATE
Systematic name | M24299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a monosaccharide into pyruvate, occurring through a fructose-6-phosphate intermediate, with the concomitant production of ATP and NADH. [GOC:dph, ISBN:0201090910, ISBN:0879010479]
Full description |

Standard name | GO_FRUCTOSE_CATABOLIC_PROCESS_TO_HYDROXYACETONE_PHOSPHATE_AND_GLYCERALDEHYDE_3_PHOSPHATE
Systematic name | M29255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of fructose that results in the formation of dihydroxyacetone phosphate and glyceraldehyde-3-phosphate. [GOC:dph, ISBN:0201090910]
Full description |

Standard name | GO_PHARYNGEAL_ARCH_ARTERY_MORPHOGENESIS
Systematic name | M24300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a pharyngeal arch artery is generated and organized. The pharyngeal arch arteries are a series of six paired embryological vascular structures, the development of which give rise to several major arteries, such as the stapedial artery, the middle meningeal artery, the internal carotid artery and the pulmonary artery. [GOC:BHF, GOC:dph, PMID:20122914]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_COMPLEX_STABILITY
Systematic name | M24301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that affects the structure and integrity of a protein complex by altering the likelihood of its assembly or disassembly. [GOC:dph]
Full description |

Standard name | GO_CYTOSKELETON_DEPENDENT_CYTOKINESIS
Systematic name | M16898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cytokinesis that involves the function of a set of proteins that are part of the microfilament or microtubule cytoskeleton. [GOC:dph]
Full description |

Standard name | GO_CHEMOREPULSION_OF_AXON
Systematic name | M29256
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a neuron growth cone is directed to a specific target site in response to a repulsive chemical cue. [GOC:dph, GOC:krc]
Full description |

Standard name | GO_HISTONE_H3_K9_MODIFICATION
Systematic name | M11928
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 at a lysine in position 9 of the histone. [GOC:vw]
Full description |

Standard name | GO_MITOCHONDRIAL_RIBOSOME_ASSEMBLY
Systematic name | M24302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of the mitochondrial ribosome and of its subunits. [GOC:dph]
Full description |

Standard name | GO_SPONTANEOUS_NEUROTRANSMITTER_SECRETION
Systematic name | M29257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Neurotransmitter secretion that occurs in the absence of the action of a secretagogue or a presynaptic action potential. [GOC:dph, GOC:pad, GOC:PARL, PMID:21334193]
Full description |

Standard name | GO_CHAPERONE_MEDIATED_AUTOPHAGY
Systematic name | M24303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The autophagy process which begins when chaperones and co-chaperones recognize a target motif and unfold the substrate protein. The proteins are then transported to the lysosome where they are degraded. [GOC:pad, GOC:PARL, PMID:22743996, PMID:23434281]
Full description |

Standard name | GO_DETOXIFICATION_OF_INORGANIC_COMPOUND
Systematic name | M29258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that reduces or removes the toxicity of inorganic compounds. These include transport of such compounds away from sensitive areas and to compartments or complexes whose purpose is sequestration of inorganic compounds. [GOC:vw]
Full description |

Standard name | GO_RETICULOPHAGY
Systematic name | M34221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The selective autohagy process in which parts of the endoplasmic reticulum are loaded into autophagosomes, delivered to the vacuole, and degraded in response to changing cellular conditions. [GOC:autophagy, GOC:dph, PMID:22481944, PMID:24060720, PMID:26040717]
Full description |

Standard name | GO_LIPOPHAGY
Systematic name | M24304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The selective autophagy process in which lipid droplets are delivered to the vacuole and degraded in response to changing cellular conditions. [GOC:autophagy, PMID:23708524, PMID:26076903]
Full description |

Standard name | GO_MITOCHONDRIAL_ACETYL_COA_BIOSYNTHETIC_PROCESS_FROM_PYRUVATE
Systematic name | M24305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of acetyl-CoA from pyruvate in the mitochondrion. The process begins with the transport of pyruvate from the cytosol to the mitochondrion where it is subsequently decarboxylated to form acetyl-CoA. [GOC:dph, ISBN:0201090910]
Full description |

Standard name | GO_PARKIN_MEDIATED_STIMULATION_OF_MITOPHAGY_IN_RESPONSE_TO_MITOCHONDRIAL_DEPOLARIZATION
Systematic name | M24306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A positive regulation of the macromitophagy pathway that is triggered by mitochondrial depolarization and requires the function of a parkin-family molecule. [GOC:autophagy, GOC:dph, GOC:pad, GOC:PARL, PMID:25349190]
Full description |

Standard name | GO_LEUKOTRIENE_SIGNALING_PATHWAY
Systematic name | M24307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals that proceeds with an activated receptor promoting the exchange of GDP for GTP on the alpha-subunit of an associated heterotrimeric G-protein complex. The GTP-bound activated alpha-G-protein then dissociates from the beta- and gamma-subunits to further transmit the signal within the cell. The pathway begins with receptor-leukotriene interaction and ends with regulation of a downstream cellular process, e.g. transcription. [GOC:dph, PMID:21771892]
Full description |

Standard name | GO_MOTOR_LEARNING
Systematic name | M24308
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which an organism acquires a novel neuromuscular action or movement as the result of experience. [GOC:bf, GOC:PARL, Wikipedia:Motor_learning]
Full description |

Standard name | GO_MOTOR_BEHAVIOR
Systematic name | M24309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specific neuromuscular movement of a single organism in response to external or internal stimuli. [GOC:bf, GOC:PARL, PMID:25318560]
Full description |

Standard name | GO_LEUKOCYTE_ADHESION_TO_VASCULAR_ENDOTHELIAL_CELL
Systematic name | M14170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a leukocyte to vascular endothelial cell via adhesion molecules. [GOC:add, GOC:bc, GOC:BHF, GOC:BHF_miRNA, PMID:23897866]
Full description |

Standard name | GO_LEUKOCYTE_ADHESION_TO_ARTERIAL_ENDOTHELIAL_CELL
Systematic name | M34222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of a leukocyte to an arterial endothelial cell via adhesion molecules. [GOC:add, GOC:bc, GOC:BHF, GOC:BHF_miRNA, PMID:22267480]
Full description |

Standard name | GO_ANTIFUNGAL_INNATE_IMMUNE_RESPONSE
Systematic name | M24310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An defense response against a fungus mediated through an innate immune response. An innate immune response is mediated by germline encoded components that directly recognize components of potential pathogens. [GOC:dph, PMID:22470487]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_PLASMA_MEMBRANE_TETHERING
Systematic name | M29259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of an endoplasmic reticulum membrane to the plasma membrane via molecular tethers. [GOC:dph, GOC:vw, PMID:23237950, PMID:26877082, PMID:27875684]
Full description |

Standard name | GO_TELOMERIC_D_LOOP_DISASSEMBLY
Systematic name | M24311
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A telomere loop disassembly process that results in the disassembly of telomeric D-loops. A telomeric D-loop is a three-stranded DNA displacement loop that forms at the site where the telomeric 3' single-stranded DNA overhang (formed of the repeat sequence TTAGGG in mammals) is tucked back inside the double-stranded component of telomeric DNA molecule, thus forming a t-loop or telomeric-loop and protecting the chromosome terminus. [GOC:BHF, GOC:BHF_telomere, GOC:nc, PMID:10338204, PMID:24012755]
Full description |

Standard name | GO_MICROTUBULE_ORGANIZING_CENTER_LOCALIZATION
Systematic name | M24312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which the microtubule organizing center is transported to, and/or maintained in, a specific location within the cell. [PMID:21281821]
Full description |

Standard name | GO_ANTIMICROBIAL_HUMORAL_IMMUNE_RESPONSE_MEDIATED_BY_ANTIMICROBIAL_PEPTIDE
Systematic name | M24313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response against microbes mediated by anti-microbial peptides in body fluid. [PMID:15761415, PMID:24287494]
Full description |

Standard name | GO_REGULATION_OF_ASTROCYTE_ACTIVATION
Systematic name | M24314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of astrocyte activation. [GOC:aruk, GOC:bc, PMID:20005821]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ASTROCYTE_ACTIVATION
Systematic name | M29260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of astrocyte activation. [GOC:aruk, GOC:bc, PMID:20005821]
Full description |

Standard name | GO_GLIAL_CELL_ACTIVATION
Systematic name | M24316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in morphology and behavior of a glial cell resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. [GOC:aruk, GOC:bc, PMID:18723082]
Full description |

Standard name | GO_SELECTIVE_AUTOPHAGY
Systematic name | M24317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The macroautophagy process in which specific structures are targeted by the autophagy process. [PMID:20484971, PMID:21997368, PMID:22966490]
Full description |

Standard name | GO_PROCESS_UTILIZING_AUTOPHAGIC_MECHANISM
Systematic name | M24318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process involving delivery of a portion of the cytoplasm to lysosomes or to the plant or fungal vacuole that does not involve direct transport through the endocytic or vacuolar protein sorting (Vps) pathways. This process typically leads to degradation of the cargo; however, it can also be used to deliver resident proteins, such as in the cytoplasm-to-vacuole targeting (Cvt) pathway. [PMID:21997368, PMID:22966490, PMID:28596378]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_PLASMA_MEMBRANE
Systematic name | M16232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein to a specific location in a plasma membrane. [GOC:dph, GOC:vw]
Full description |

Standard name | GO_MIDBODY_ABSCISSION
Systematic name | M24319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process by which the midbody, the cytoplasmic bridge that connects the two prospective daughter cells, is severed at the end of mitotic cytokinesis, resulting in two separate daughter cells. [PMID:12737809, PMID:29903934]
Full description |

Standard name | GO_MEIOSIS_I_CELL_CYCLE_PROCESS
Systematic name | M24320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that contributes to the first meiotic division. The first meiotic division is the reductive division resulting in the separation of homologous chromosome pairs. [PMID:29385397]
Full description |

Standard name | GO_MEIOSIS_II_CELL_CYCLE_PROCESS
Systematic name | M24321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that coontributes to the second meiotic division. The second meiotic division separates chromatids resulting in a haploid number of chromosomes. [PMID:29385397]
Full description |

Standard name | GO_SECONDARY_PALATE_DEVELOPMENT
Systematic name | M24322
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of the secondary palate from an initial condition to its mature state. This process begins with the formation of the structure and ends with the mature structure. The secondary palate is the part of the palate formed from the fusion of the two palatine shelves, extensions of the maxillary prominences. [PMID:28784960]
Full description |

Standard name | GO_REGULATION_OF_SMALL_MOLECULE_METABOLIC_PROCESS
Systematic name | M24323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of a small molecule metabolic process. [GOC:vw]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SMALL_MOLECULE_METABOLIC_PROCESS
Systematic name | M24324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of a small molecule metabolic process. [GOC:vw]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMALL_MOLECULE_METABOLIC_PROCESS
Systematic name | M24325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of a small molecule metabolic process. [GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_STRESS_GRANULE_ASSEMBLY
Systematic name | M29261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of stress granule assembly, the aggregation, arrangement and bonding together of proteins and RNA molecules to form a stress granule. [PMID:20180778]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOTIC_SISTER_CHROMATID_SEGREGATION
Systematic name | M24326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that starts or increases the frequency, rate or extent of sister chromatid segregation during mitosis. [PMID:12773390]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_EPITHELIAL_TO_MESENCHYMAL_TRANSITION
Systematic name | M24327
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of cardiac epithelial to mesenchymal transition, a transition where a cardiac epithelial cell loses apical/basolateral polarity, severs intercellular adhesive junctions, degrades basement membrane components and becomes a migratory mesenchymal cell. [GOC:BHF, GOC:rph, PMID:20951801]
Full description |

Standard name | GO_REGULATION_OF_PROGRAMMED_NECROTIC_CELL_DEATH
Systematic name | M24328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of programmed necrotic cell death. [GOC:aruk, GOC:rph, PMID:27258785]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROGRAMMED_NECROTIC_CELL_DEATH
Systematic name | M24330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of programmed necrotic cell death. [GOC:aruk, GOC:rph, PMID:27258785]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRIAL_GENE_EXPRESSION
Systematic name | M29262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mitochondrial gene expression. Gene expression is the process in which a gene's coding sequence is converted into a mature gene product or products (proteins or RNA). [PMID:28285835]
Full description |

Standard name | GO_DETECTION_OF_STIMULUS_INVOLVED_IN_SENSORY_PERCEPTION_OF_PAIN
Systematic name | M29263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events involved in the perception of pain in which a stimulus is received and converted into a molecular signal. [PMID:19837031]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_CHEMICAL_STRESS
Systematic name | M29264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a chemical stimulus indicating the organism is under stress. [PMID:26653712]
Full description |

Standard name | GO_REGULATION_OF_PATTERN_RECOGNITION_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M34223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of a pattern recognition receptor signaling pathway. [PMID:30610168]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PATTERN_RECOGNITION_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M34224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of a pattern recognition receptor signaling pathway. [PMID:30610168]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_POSTSYNAPSE
Systematic name | M34225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, and/or maintained at the postsynapse, the part of a synapse that is part of the post-synaptic cell. [PMID:31189538]
Full description |

Standard name | GO_PROTEIN_LIPID_COMPLEX_ASSEMBLY
Systematic name | M11459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins and lipids to form a protein-lipid complex. [GOC:jl]
Full description |

Standard name | GO_NEURON_CELLULAR_HOMEOSTASIS
Systematic name | M24333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular homeostatic process that preserves a neuron in a stable, differentiated functional and structural state. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_ENDOPLASMIC_RETICULUM_STRESS
Systematic name | M16339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway is induced in response to a stimulus indicating endoplasmic reticulum (ER) stress, and ends when the execution phase of apoptosis is triggered. ER stress usually results from the accumulation of unfolded or misfolded proteins in the ER lumen. [GOC:mah, GOC:mtg_apoptosis, PMID:18701708]
Full description |

Standard name | GO_PROTON_TRANSPORTING_V_TYPE_ATPASE_COMPLEX_ASSEMBLY
Systematic name | M24334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a proton-transporting V-type ATPase complex, proton-transporting two-sector ATPase complex that couples ATP hydrolysis to the transport of protons across a concentration gradient. [GOC:mah]
Full description |

Standard name | GO_PROTON_TRANSPORTING_TWO_SECTOR_ATPASE_COMPLEX_ASSEMBLY
Systematic name | M24335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a proton-transporting two-sector ATPase complex, a large protein complex that catalyzes the synthesis or hydrolysis of ATP by a rotational mechanism, coupled to the transport of protons across a membrane. [GOC:mah]
Full description |

Standard name | GO_VACUOLAR_PROTON_TRANSPORTING_V_TYPE_ATPASE_COMPLEX_ASSEMBLY
Systematic name | M29265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a vacuolar proton-transporting V-type ATPase complex, proton-transporting two-sector ATPase complex that couples ATP hydrolysis to the transport of protons across the vacuolar membrane. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_GLYCOSYLATION
Systematic name | M15710
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment and further modification of carbohydrate residues to a substrate molecule. [GOC:hjd, GOC:mah]
Full description |

Standard name | GO_UBIQUITIN_DEPENDENT_ENDOCYTOSIS
Systematic name | M24336
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Endocytosis of a protein that requires the substrate to be modified by ubiquitination. Several plasma membrane proteins, including cell surface permeases and some receptors, are targeted for internalization by endocytosis, and are thereafter delivered to the vacuole or lysosome, where they are degraded. [GOC:jp, GOC:mah, PMID:9409540]
Full description |

Standard name | GO_REGULATION_OF_GLUCAGON_SECRETION
Systematic name | M34226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of glucagon. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CHEMOKINE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M24339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of the series of molecular events generated as a consequence of a chemokine binding to a cell surface receptor. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHEMOKINE_MEDIATED_SIGNALING_PATHWAY
Systematic name | M24340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of the series of molecular events generated as a consequence of a chemokine binding to a cell surface receptor. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_6_MEDIATED_SIGNALING_PATHWAY
Systematic name | M24341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of interleukin-6 to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:add, GOC:BHF, GOC:mah, GOC:signaling]
Full description |

Standard name | GO_REGULATION_OF_INTERLEUKIN_6_MEDIATED_SIGNALING_PATHWAY
Systematic name | M24342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of the series of molecular events generated as a consequence of interleukin-6-mediated binding to a cell surface receptor. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_6_MEDIATED_SIGNALING_PATHWAY
Systematic name | M24343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of the series of molecular events generated as a consequence of interleukin-6 binding to a cell surface receptor. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_27_MEDIATED_SIGNALING_PATHWAY
Systematic name | M24344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of interleukin-27 to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:add, GOC:BHF, GOC:mah, GOC:signaling]
Full description |

Standard name | GO_CILIARY_NEUROTROPHIC_FACTOR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M24345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of a ciliary neurotrophic factor (CNTF) to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_MITOCHONDRIAL_TRANSLATIONAL_TERMINATION
Systematic name | M24346
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process resulting in the release of a polypeptide chain from the ribosome in a mitochondrion, usually in response to a termination codon (note that mitochondria use variants of the universal genetic code that differ between different taxa). [GOC:mah, http://mitogenome.org/index.php/Genetic_Code_of_mitochondria]
Full description |

Standard name | GO_TRNA_AMINOACYLATION_FOR_MITOCHONDRIAL_PROTEIN_TRANSLATION
Systematic name | M24347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The synthesis of aminoacyl tRNA by the formation of an ester bond between the 3'-hydroxyl group of the most 3' adenosine of the tRNA, to be used in ribosome-mediated polypeptide synthesis in a mitochondrion. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOCHONDRIAL_TRANSLATION
Systematic name | M24348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of proteins by the translation of mRNA in a mitochondrion. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_UV_A
Systematic name | M24349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a UV-A radiation stimulus. UV-A radiation (UV-A light) spans the wavelengths 315 to 400 nm. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_BUDDING
Systematic name | M24350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Evagination of a membrane to form a synaptic vesicle. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ADIPONECTIN_SECRETION
Systematic name | M29266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of adiponectin from a cell. [GOC:mah]
Full description |

Standard name | GO_ENAMEL_MINERALIZATION
Systematic name | M12360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which calcium salts, mainly carbonated hydroxyapatite, are deposited in tooth enamel. [GOC:BHF, GOC:mah, GOC:sl, PMID:10206335, PMID:16931858, PMID:21196346]
Full description |

Standard name | GO_REGULATION_OF_TOOTH_MINERALIZATION
Systematic name | M24352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of tooth mineralization, the deposition of calcium salts in tooth structures. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TOOTH_MINERALIZATION
Systematic name | M24353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of tooth mineralization, the deposition of calcium salts in tooth structures. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ENAMEL_MINERALIZATION
Systematic name | M24354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of enamel mineralization, the deposition of calcium salts in tooth enamel. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_KYNURENINE_METABOLIC_PROCESS
Systematic name | M24355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving kynurenine, the amino acid 3-(2-aminobenzoyl)-alanine. [CHEBI:28683, GOC:mah, GOC:rph]
Full description |

Standard name | GO_CHROMOSOME_ORGANIZATION_INVOLVED_IN_MEIOTIC_CELL_CYCLE
Systematic name | M13885
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process of chromosome organization that is involved in a meiotic cell cycle. [GOC:mah]
Full description |

Standard name | GO_SYNAPTONEMAL_COMPLEX_ORGANIZATION
Systematic name | M12195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a synaptonemal complex. A synaptonemal complex is a proteinaceous scaffold formed between homologous chromosomes during meiosis. [GOC:mah]
Full description |

Standard name | GO_MEIOTIC_ATTACHMENT_OF_TELOMERE_TO_NUCLEAR_ENVELOPE
Systematic name | M24356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The meiotic cell cycle process in which physical connections are formed between telomeric heterochromatin and the nuclear envelope, facilitating bouquet formation. [GOC:jp, GOC:pr, GOC:vw, PMID:18818742]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CHROMOSOME_TELOMERIC_REGION
Systematic name | M12907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, or maintained at, the telomeric region of a chromosome. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_CHROMOSOME
Systematic name | M10943
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein to a specific location on a chromosome. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_TELOMERE
Systematic name | M24357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein to a specific location in the telomeric region of a chromosome. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_CHROMOSOME
Systematic name | M11451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of a protein to a specific location on a chromosome. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_PROTEIN_TRIMERIZATION
Systematic name | M12509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a protein trimer, a macromolecular structure consisting of three noncovalently associated identical or nonidentical subunits. [GOC:hjd]
Full description |

Standard name | GO_PROTEIN_POLY_ADP_RIBOSYLATION
Systematic name | M24359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of multiple ADP-ribose residues from NAD to a protein amino acid, forming a poly(ADP-ribose) chain. [GOC:BHF, GOC:mah, GOC:rl, PMID:25043379]
Full description |

Standard name | GO_PROTEIN_AUTO_ADP_RIBOSYLATION
Systematic name | M24360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The ADP-ribosylation by a protein of one or more of its own amino acid residues, or residues on an identical protein. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_LYMPHOCYTE_APOPTOTIC_PROCESS
Systematic name | M16177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a lymphocyte, a leukocyte commonly found in the blood and lymph that has the characteristics of a large nucleus, a neutral staining cytoplasm, and prominent heterochromatin. [CL:0000542, GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_REGULATION_OF_LYMPHOCYTE_APOPTOTIC_PROCESS
Systematic name | M11217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the occurrence or rate of lymphocyte death by apoptotic process. [GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LYMPHOCYTE_APOPTOTIC_PROCESS
Systematic name | M13947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of lymphocyte death by apoptotic process. [GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LYMPHOCYTE_APOPTOTIC_PROCESS
Systematic name | M10232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of lymphocyte death by apoptotic process. [GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_T_CELL_APOPTOTIC_PROCESS
Systematic name | M16401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a T cell, a type of lymphocyte whose defining characteristic is the expression of a T cell receptor complex. [CL:0000084, GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_APOPTOTIC_PROCESS
Systematic name | M12536
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the occurrence or rate of T cell death by apoptotic process. [GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_CELL_APOPTOTIC_PROCESS
Systematic name | M13278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of T cell death by apoptotic process. [GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_CELL_APOPTOTIC_PROCESS
Systematic name | M15584
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of T cell death by apoptotic process. [GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_THYMOCYTE_APOPTOTIC_PROCESS
Systematic name | M24362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a thymocyte, an immature T cell located in the thymus. [CL:0000893, GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_REGULATION_OF_THYMOCYTE_APOPTOTIC_PROCESS
Systematic name | M12760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the occurrence or rate of thymocyte death by apoptotic process. [GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_THYMOCYTE_APOPTOTIC_PROCESS
Systematic name | M24363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of thymocyte death by apoptotic process. [GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_THYMOCYTE_APOPTOTIC_PROCESS
Systematic name | M24364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of thymocyte death by apoptotic process. [GOC:add, GOC:mtg_apoptosis, ISBN:0781765196]
Full description |

Standard name | GO_ACTIN_MEDIATED_CELL_CONTRACTION
Systematic name | M14073
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The actin filament-based process in which cytoplasmic actin filaments slide past one another resulting in contraction of all or part of the cell body. [GOC:mah]
Full description |

Standard name | GO_SOMATOSTATIN_SECRETION
Systematic name | M34227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of somatostatin from secretory granules in the D cells of the pancreas. [GOC:mah]
Full description |

Standard name | GO_MUCUS_SECRETION
Systematic name | M24365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of mucus by the mucosa. Mucus is a viscous slimy secretion consisting of mucins and various inorganic salts dissolved in water, with suspended epithelial cells and leukocytes. The mucosa, or mucous membrane, is the membrane covered with epithelium that lines the tubular organs of the body. Mucins are carbohydrate-rich glycoproteins that have a lubricating and protective function. [GOC:add, ISBN:068340007X, ISBN:0721662544]
Full description |

Standard name | GO_REGULATION_OF_MUCUS_SECRETION
Systematic name | M24366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the regulated release of mucus from a cell or a tissue. [GOC:add]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MUCUS_SECRETION
Systematic name | M24367
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the regulated release of mucus from a cell or a tissue. [GOC:add]
Full description |

Standard name | GO_PEPTIDYL_SERINE_DEPHOSPHORYLATION
Systematic name | M24368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of phosphoric residues from peptidyl-O-phospho-L-serine to form peptidyl-serine. [GOC:bf]
Full description |

Standard name | GO_NECROTIC_CELL_DEATH
Systematic name | M10910
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A type of cell death that is morphologically characterized by an increasingly translucent cytoplasm, swelling of organelles, minor ultrastructural modifications of the nucleus (specifically, dilatation of the nuclear membrane and condensation of chromatin into small, irregular, circumscribed patches) and increased cell volume (oncosis), culminating in the disruption of the plasma membrane and subsequent loss of intracellular contents. Necrotic cells do not fragment into discrete corpses as their apoptotic counterparts do. Moreover, their nuclei remain intact and can aggregate and accumulate in necrotic tissues. [GOC:mtg_apoptosis, PMID:18846107, PMID:20823910]
Full description |

Standard name | GO_CORNIFICATION
Systematic name | M24369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A type of programmed cell death that occurs in the epidermis, morphologically and biochemically distinct from apoptosis. It leads to the formation of corneocytes, i.e. dead keratinocytes containing an amalgam of specific proteins (e.g., keratin, loricrin, SPR and involucrin) and lipids (e.g., fatty acids and ceramides), which are necessary for the function of the cornified skin layer (mechanical resistance, elasticity, water repellence and structural stability). [GOC:krc, PMID:18846107]
Full description |

Standard name | GO_PYROPTOSIS
Systematic name | M24370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A caspase-1-dependent cell death subroutine that is associated with the generation of pyrogenic mediators such as IL-1beta and IL-18. [GOC:mtg_apoptosis, PMID:18846107, PMID:21760595]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX_CONSTITUENT_SECRETION
Systematic name | M24371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The controlled release of molecules that form the extracellular matrix, including carbohydrates and glycoproteins by a cell. [GOC:mah]
Full description |

Standard name | GO_AXONEMAL_DYNEIN_COMPLEX_ASSEMBLY
Systematic name | M12301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an axonemal dynein complex, a dynein complex found in eukaryotic cilia and flagella, in which the motor domain heads interact with adjacent microtubules to generate a sliding force which is converted to a bending motion. [GOC:cilia, GOC:mah, PMID:19052621]
Full description |

Standard name | GO_N_ACYLETHANOLAMINE_METABOLIC_PROCESS
Systematic name | M34228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving N-acylethanolamines. An N-acylethanolamine is an ethanolamine substituted at nitrogen by an acyl group. [CHEBI:52640, GOC:elh, PMID:14634025, PMID:15878693]
Full description |

Standard name | GO_N_ACYLPHOSPHATIDYLETHANOLAMINE_METABOLIC_PROCESS
Systematic name | M29267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving N-acylphosphatidylethanolamines. An N-acylphosphatidylethanolamine is a phosphatidylethanolamine substituted at nitrogen by an acyl group. [GOC:elh, GOC:mah, PMID:14634025, PMID:15878693]
Full description |

Standard name | GO_RENAL_ABSORPTION
Systematic name | M15554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A renal system process in which water, ions, glucose and proteins are taken up from the collecting ducts, glomerulus and proximal and distal loops of the nephron. In non-mammalian species, absorption may occur in related structures (e.g. protein absorption is observed in nephrocytes in Drosophila, see PMID:23264686). [GOC:dph, GOC:mah, GOC:yaf]
Full description |

Standard name | GO_SARCOPLASMIC_RETICULUM_CALCIUM_ION_TRANSPORT
Systematic name | M14090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of calcium ions (Ca2+) into, out of or within the sarcoplasmic reticulum. [GOC:BHF, GOC:vk]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_HYDROGEN_PEROXIDE
Systematic name | M12852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydrogen peroxide (H2O2) stimulus. [CHEBI:16240, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_STRESS_ACTIVATED_PROTEIN_KINASE_SIGNALING_CASCADE
Systematic name | M10591
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of signaling via a stress-activated protein kinase signaling cascade. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_STRESS_ACTIVATED_PROTEIN_KINASE_SIGNALING_CASCADE
Systematic name | M14839
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of signaling via the stress-activated protein kinase signaling cascade. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STRESS_ACTIVATED_PROTEIN_KINASE_SIGNALING_CASCADE
Systematic name | M11724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signaling via the stress-activated protein kinase signaling cascade. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_CGMP
Systematic name | M24372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cGMP (cyclic GMP, guanosine 3',5'-cyclophosphate) stimulus. [GOC:sl]
Full description |

Standard name | GO_LENS_FIBER_CELL_DIFFERENTIATION
Systematic name | M10247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a lens fiber cell, any of the elongated, tightly packed cells that make up the bulk of the mature lens in the camera-type eye. The cytoplasm of a lens fiber cell is devoid of most intracellular organelles including the cell nucleus, and contains primarily crystallins, a group of water-soluble proteins expressed in vary large quantities. [GOC:mah, PMID:7693735]
Full description |

Standard name | GO_LENS_FIBER_CELL_DEVELOPMENT
Systematic name | M16678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a lens fiber cell over time, from its formation to the mature structure. Cell development does not include the steps involved in committing a cell to a lens fiber cell fate. A lens fiber cell is any of the elongated, tightly packed cells that make up the bulk of the mature lens in a camera-type eye. [GOC:mah, PMID:7693735]
Full description |

Standard name | GO_LENS_FIBER_CELL_MORPHOGENESIS
Systematic name | M24373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the structures of a lens fiber cell are generated and organized. This process occurs while the initially relatively unspecialized cell is acquiring the specialized features of a lens fiber cell. A lens fiber cell is any of the elongated, tightly packed cells that make up the bulk of the mature lens in a camera-type eye. [GOC:mah, PMID:7693735]
Full description |

Standard name | GO_G1_TO_G0_TRANSITION
Systematic name | M24374
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell cycle arrest process that results in arrest during G1 phase, whereupon the cell enters a specialized resting state known as G0 or quiescence. [GOC:mah, GOC:mtg_cell_cycle, ISBN:0815316194]
Full description |

Standard name | GO_THYROID_HORMONE_TRANSPORT
Systematic name | M24375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of thyroid hormone into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:rph]
Full description |

Standard name | GO_FAT_CELL_PROLIFERATION
Systematic name | M24376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of fat cells by cell division, resulting in the expansion of their population. A fat cell is an animal connective tissue cell specialized for the synthesis and storage of fat. [GOC:mah, GOC:sl]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FAT_CELL_PROLIFERATION
Systematic name | M24377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops or decreases the rate or extent of fat cell proliferation. [GOC:mah, GOC:sl]
Full description |

Standard name | GO_ACTIN_POLYMERIZATION_DEPENDENT_CELL_MOTILITY
Systematic name | M24378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process involved in the controlled movement of a bacterial cell powered by the continuous polymerization of actin at one pole of the cell. [GOC:mah, PMID:15773977]
Full description |

Standard name | GO_HEPATOCYTE_DIFFERENTIATION
Systematic name | M24379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a hepatocyte. A hepatocyte is specialized epithelial cell that is organized into interconnected plates called lobules, and is the main structural component of the liver. [CL:0000182, PMID:7588884]
Full description |

Standard name | GO_ERK1_AND_ERK2_CASCADE
Systematic name | M16677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An intracellular protein kinase cascade containing at least ERK1 or ERK2 (MAPKs), a MEK (a MAPKK) and a MAP3K. The cascade may involve 4 different kinases, as it can also contain an additional tier: the upstream MAP4K. The kinases in each tier phosphorylate and activate the kinase in the downstream tier to transmit a signal within a cell. [GOC:add, GOC:signaling, ISBN:0121245462, ISBN:0896039986, PMID:20811974, PMID:28903453]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ERK1_AND_ERK2_CASCADE
Systematic name | M10186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of signal transduction mediated by the ERK1 and ERK2 cascade. [GOC:add, ISBN:0121245462, ISBN:0896039986]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ERK1_AND_ERK2_CASCADE
Systematic name | M15144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signal transduction mediated by the ERK1 and ERK2 cascade. [GOC:mah]
Full description |

Standard name | GO_DNA_CYTOSINE_DEAMINATION
Systematic name | M24380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of an amino group from a cytosine residue in DNA, forming a uracil residue. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_LIPOTEICHOIC_ACID
Systematic name | M24381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipoteichoic acid stimulus; lipoteichoic acid is a major component of the cell wall of gram-positive bacteria and typically consists of a chain of glycerol-phosphate repeating units linked to a glycolipid anchor. [GOC:add, PMID:14665680, PMID:16020688]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_COLD
Systematic name | M24382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cold stimulus, a temperature stimulus below the optimal temperature for that organism. [GOC:jp]
Full description |

Standard name | GO_REGULATION_OF_NUCLEOTIDE_BINDING_OLIGOMERIZATION_DOMAIN_CONTAINING_SIGNALING_PATHWAY
Systematic name | M24383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a nucleotide-binding oligomerization domain containing (NOD) pathway. [GOC:add]
Full description |

Standard name | GO_NUCLEOTIDE_BINDING_OLIGOMERIZATION_DOMAIN_CONTAINING_1_SIGNALING_PATHWAY
Systematic name | M29268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of binding to nucleotide-binding oligomerization domain containing 1 (NOD1). [GOC:add, PMID:17944960, PMID:18585455]
Full description |

Standard name | GO_NUCLEOTIDE_BINDING_OLIGOMERIZATION_DOMAIN_CONTAINING_2_SIGNALING_PATHWAY
Systematic name | M24384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any series of molecular signals generated as a consequence of binding to nucleotide-binding oligomerization domain containing 2 (NOD2). [GOC:add, PMID:17944960, PMID:18585455]
Full description |

Standard name | GO_REGULATION_OF_NUCLEOTIDE_BINDING_OLIGOMERIZATION_DOMAIN_CONTAINING_2_SIGNALING_PATHWAY
Systematic name | M24385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of the nucleotide-binding oligomerization domain containing 2 (NOD2) pathway. [GOC:add]
Full description |

Standard name | GO_OLIGODENDROCYTE_PROGENITOR_PROLIFERATION
Systematic name | M24386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of oligodendrocyte progenitor cells by cell division, resulting in the expansion of their population. Oligodendrocyte progenitors give rise to oligodendrocytes, which form the insulating myelin sheath of axons in the central nervous system. [GOC:mah, GOC:sl, PMID:15504915]
Full description |

Standard name | GO_PROLACTIN_SECRETION
Systematic name | M24387
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of prolactin, a peptide hormone that stimulates lactation, from secretory granules in the anterior pituitary. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_UTERINE_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M24388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which force is generated within smooth muscle tissue, resulting in a change in muscle geometry. This process occurs in the uterus. Force generation involves a chemo-mechanical energy conversion step that is carried out by the actin/myosin complex activity, which generates force through ATP hydrolysis. The uterus is a muscular organ of the female mammal for containing and usually for nourishing the young during development prior to birth. [GOC:sl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_UTERINE_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M24389
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of uterine smooth muscle contraction. [GOC:go_curators]
Full description |

Standard name | GO_RRNA_BASE_METHYLATION
Systematic name | M24390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition of a methyl group to an atom in the nucleoside base portion of a nucleotide residue in an rRNA molecule. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_OXYGEN_LEVELS
Systematic name | M12903
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting the presence, absence, or concentration of oxygen. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_LEUKOCYTE_AGGREGATION
Systematic name | M24391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The adhesion of one leukocyte to one or more other leukocytes via adhesion molecules. [GOC:sl, PMID:12972508]
Full description |

Standard name | GO_MONOCYTE_AGGREGATION
Systematic name | M24392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The adhesion of one monocyte to one or more other monocytes via adhesion molecules. [GOC:sl, PMID:12972508]
Full description |

Standard name | GO_THROMBIN_ACTIVATED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a thrombin-activated receptor binding to one of its physiological ligands. [GOC:mah, PMID:1672265]
Full description |

Standard name | GO_INTERLEUKIN_1_MEDIATED_SIGNALING_PATHWAY
Systematic name | M14173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of interleukin-1 to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:BHF, GOC:mah, GOC:signaling]
Full description |

Standard name | GO_REGULATION_OF_MICROTUBULE_CYTOSKELETON_ORGANIZATION
Systematic name | M34229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the formation, arrangement of constituent parts, or disassembly of cytoskeletal structures comprising microtubules and their associated proteins. [GOC:mah]
Full description |

Standard name | GO_CALCIUM_ION_IMPORT
Systematic name | M12652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of calcium ions into a cell or organelle. [GOC:mah]
Full description |

Standard name | GO_TRNA_THREONYLCARBAMOYLADENOSINE_METABOLIC_PROCESS
Systematic name | M15215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving tRNA threonylcarbamoyladenosine, a modified nucleoside found in some tRNA molecules. [GOC:imk, GOC:mah, PMID:19287007]
Full description |

Standard name | GO_PLATELET_AGGREGATION
Systematic name | M16560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The adhesion of one platelet to one or more other platelets via adhesion molecules. [GOC:BHF, GOC:vk]
Full description |

Standard name | GO_PROTEIN_KINASE_C_SIGNALING
Systematic name | M13141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of reactions, mediated by the intracellular serine/threonine kinase protein kinase C, which occurs as a result of a single trigger reaction or compound. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_PROTEIN_K63_LINKED_UBIQUITINATION
Systematic name | M15079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein ubiquitination process in which a polymer of ubiquitin, formed by linkages between lysine residues at position 63 of the ubiquitin monomers, is added to a protein. K63-linked ubiquitination does not target the substrate protein for degradation, but is involved in several pathways, notably as a signal to promote error-free DNA postreplication repair. [GOC:mah, PMID:15556404]
Full description |

Standard name | GO_HISTONE_H2A_K63_LINKED_UBIQUITINATION
Systematic name | M24394
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A histone ubiquitination process in which a polymer of ubiquitin, formed by linkages between lysine residues at position 63 of the ubiquitin monomers, is added to a lysine residue in histone H2A or the variant H2AX. [GOC:mah, PMID:18430235]
Full description |

Standard name | GO_PROTEIN_K63_LINKED_DEUBIQUITINATION
Systematic name | M15375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein deubiquitination process in which a K63-linked ubiquitin chain, i.e. a polymer of ubiquitin formed by linkages between lysine residues at position 63 of the ubiquitin monomers, is removed from a protein. [GOC:mah, PMID:19202061, PMID:19214193]
Full description |

Standard name | GO_RESPONSE_TO_FATTY_ACID
Systematic name | M14177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fatty acid stimulus. [GOC:lp]
Full description |

Standard name | GO_HISTONE_H3_K36_DEMETHYLATION
Systematic name | M24395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the removal of a methyl group from lysine at position 36 of the histone. [GOC:sart, PMID:19061644]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_1
Systematic name | M13436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-1 stimulus. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_VITAMIN_D_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a vitamin D receptor binding to one of its physiological ligands. [GOC:BHF, GOC:mah, PMID:12637589]
Full description |

Standard name | GO_REGULATION_OF_VITAMIN_D_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of vitamin D receptor signaling pathway activity. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_NEURON_PROJECTION_REGENERATION
Systematic name | M14165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of neuron projection regeneration, the regrowth of neuronal processes such as axons or dendrites following their loss or damage. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEURON_PROJECTION_REGENERATION
Systematic name | M24398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of neuron projection regeneration, the regrowth of neuronal processes such as axons or dendrites following their loss or damage. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEURON_PROJECTION_REGENERATION
Systematic name | M24399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of neuron projection regeneration, the regrowth of neuronal processes such as axons or dendrites following their loss or damage. [GOC:mah]
Full description |

Standard name | GO_CADMIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M34230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a cadmium ion is transported from one side of a membrane to the other by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_MITOCHONDRION_MORPHOGENESIS
Systematic name | M15301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a mitochondrion are generated and organized. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_MITOCHONDRION
Systematic name | M15269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within the mitochondrion. [GOC:ecd]
Full description |

Standard name | GO_CELL_CELL_ADHESION_INVOLVED_IN_GASTRULATION
Systematic name | M24400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of one cell to another cell affecting gastrulation. [GOC:dsf, PMID:19091770]
Full description |

Standard name | GO_CALCIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M15680
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a calcium ion is transported from one side of a membrane to the other by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_DENDRITE_SELF_AVOIDANCE
Systematic name | M24401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which dendrites recognize and avoid contact with sister dendrites from the same cell. [GOC:sart, PMID:17482551]
Full description |

Standard name | GO_CENTROMERIC_SISTER_CHROMATID_COHESION
Systematic name | M24402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cell cycle process in which the sister chromatids of a replicated chromosome are joined along the length of the centromeric region of the chromosome. [GOC:mah]
Full description |

Standard name | GO_TRANSEPITHELIAL_TRANSPORT
Systematic name | M13303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a substance from one side of an epithelium to the other. [GOC:mah, GOC:yaf, ISBN:0716731363]
Full description |

Standard name | GO_VITAMIN_D3_METABOLIC_PROCESS
Systematic name | M24403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving vitamin D3, (3S,5Z,7E)-9,10-secocholesta-5,7,10(19)-trien-3-ol. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_PROTEIN_MODIFICATION_BY_SMALL_PROTEIN_REMOVAL
Systematic name | M11656
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein modification process in which one or more covalently attached groups of a small protein, such as ubiquitin or a ubiquitin-like protein, are removed from a target protein. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_MODIFICATION_BY_SMALL_PROTEIN_CONJUGATION_OR_REMOVAL
Systematic name | M11174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein modification process in which one or more groups of a small protein, such as ubiquitin or a ubiquitin-like protein, are covalently attached to or removed from a target protein. [GOC:mah]
Full description |

Standard name | GO_LEUKOCYTE_PROLIFERATION
Systematic name | M12516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a leukocyte population by cell division. [GOC:add]
Full description |

Standard name | GO_MAST_CELL_PROLIFERATION
Systematic name | M34231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a mast cell population by cell division. [GOC:add]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_PROLIFERATION
Systematic name | M10218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of leukocyte proliferation. [GOC:add, GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LEUKOCYTE_PROLIFERATION
Systematic name | M10715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of leukocyte proliferation. [GOC:add, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LEUKOCYTE_PROLIFERATION
Systematic name | M11973
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of leukocyte proliferation. [GOC:add, GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_2
Systematic name | M24404
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-2 stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_4
Systematic name | M10629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-4 stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_12
Systematic name | M24405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-12 stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_15
Systematic name | M24406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-15 stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_18
Systematic name | M24407
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-18 stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_MACROMOLECULE_LOCALIZATION
Systematic name | M15870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a macromolecule is transported to, and/or maintained in, a specific location at the level of a cell. Localization at the cellular level encompasses movement within the cell, from within the cell to the cell surface, or from one location to another at the surface of a cell. [GOC:mah]
Full description |

Standard name | GO_HISTONE_H3_K27_METHYLATION
Systematic name | M24408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of one or more methyl groups to lysine at position 27 of the histone. [GOC:mah, GOC:pr]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_6
Systematic name | M14320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-6 stimulus. [GOC:mah]
Full description |

Standard name | GO_INTERLEUKIN_35_MEDIATED_SIGNALING_PATHWAY
Systematic name | M24409
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by the binding of interleukin-35 to a receptor on the surface of a cell, and ending with regulation of a downstream cellular process, e.g. transcription. [GOC:add, GOC:mah, GOC:signaling]
Full description |

Standard name | GO_L_ASPARTATE_TRANSMEMBRANE_TRANSPORT
Systematic name | M24410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-aspartate across a membrane. [PMID:21307582]
Full description |

Standard name | GO_PHOSPHATIDYLSERINE_EXPOSURE_ON_APOPTOTIC_CELL_SURFACE
Systematic name | M24411
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A phospholipid scrambling process that results in the appearance of phosphatidylserine on the outer leaflet of the plasma membrane of an apoptotic cell, which acts as an 'eat-me' signal for engulfing cells. Phosphatidylserine is exposed on the apoptotic cell surface by a phospholipid scramblase activity. [GOC:mah, GOC:mtg_apoptosis, GOC:rk, PMID:11536005]
Full description |

Standard name | GO_HYDROGEN_SULFIDE_METABOLIC_PROCESS
Systematic name | M29269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving hydrogen sulfide, H2S. [GOC:mah]
Full description |

Standard name | GO_HYDROGEN_SULFIDE_BIOSYNTHETIC_PROCESS
Systematic name | M34232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of hydrogen sulfide, H2S. [GOC:mah]
Full description |

Standard name | GO_PHOSPHORYLATION_OF_RNA_POLYMERASE_II_C_TERMINAL_DOMAIN
Systematic name | M24412
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of introducing a phosphate group on to an amino acid residue in the C-terminal domain of RNA polymerase II. Typically, this occurs during the transcription cycle and results in production of an RNA polymerase II enzyme where the carboxy-terminal domain (CTD) of the largest subunit is extensively phosphorylated, often referred to as hyperphosphorylated or the II(0) form. Specific types of phosphorylation within the CTD are usually associated with specific regions of genes, though there are exceptions. The phosphorylation state regulates the association of specific complexes such as the capping enzyme or 3'-RNA processing machinery to the elongating RNA polymerase complex. [GOC:krc, GOC:mah, PMID:17079683]
Full description |

Standard name | GO_CHROMATIN_MAINTENANCE
Systematic name | M34233
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chromatin organization process that preserves chromatin in a stable functional or structural state. [GOC:mah]
Full description |

Standard name | GO_HETEROCHROMATIN_ORGANIZATION
Systematic name | M15752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in the specification, formation or maintenance of the physical structure of eukaryotic heterochromatin, a compact and highly condensed form of chromatin. [GOC:mah]
Full description |

Standard name | GO_BASEMENT_MEMBRANE_ASSEMBLY
Systematic name | M24413
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a basement membrane, a part of the extracellular region that consists of a thin layer of dense material found in various animal tissues interposed between the cells and the adjacent connective tissue. [GOC:mah]
Full description |

Standard name | GO_DEHYDROASCORBIC_ACID_TRANSPORT
Systematic name | M29270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of dehydroascorbate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Dehydroascorbate, 5-(1,2-dihydroxyethyl)furan-2,3,4(5H)-trione, is an oxidized form of vitamin C. [GOC:sl]
Full description |

Standard name | GO_DIVALENT_METAL_ION_EXPORT
Systematic name | M34234
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of divalent metal cations, any metal ion with a +2 electric charge, out of a cell or organelle. [GOC:mah]
Full description |

Standard name | GO_INCLUSION_BODY_ASSEMBLY
Systematic name | M24414
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an inclusion body. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_AGGRESOME_ASSEMBLY
Systematic name | M24415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an aggresome; requires the microtubule cytoskeleton and dynein. [GOC:BHF, GOC:rl, PMID:14675537]
Full description |

Standard name | GO_RESPONSE_TO_GROWTH_FACTOR
Systematic name | M14540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a growth factor stimulus. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_EPIDERMAL_GROWTH_FACTOR
Systematic name | M11712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an epidermal growth factor stimulus. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_BILE_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M24416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of bile acids. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_EXIT_FROM_ENDOPLASMIC_RETICULUM
Systematic name | M15603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of proteins from the endoplasmic reticulum. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_EXIT_FROM_ENDOPLASMIC_RETICULUM
Systematic name | M24417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the directed movement of proteins from the endoplasmic reticulum. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_EXIT_FROM_ENDOPLASMIC_RETICULUM
Systematic name | M24418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of directed movement of proteins from the endoplasmic reticulum. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_GLYCOGEN_METABOLIC_PROCESS
Systematic name | M13753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving glycogen. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLYCOGEN_METABOLIC_PROCESS
Systematic name | M24419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways involving glycogen. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLYCOGEN_METABOLIC_PROCESS
Systematic name | M12515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving glycogen. [GOC:mah]
Full description |

Standard name | GO_TRANSCRIPTION_PREINITIATION_COMPLEX_ASSEMBLY
Systematic name | M24420
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of proteins on promoter DNA to form the transcriptional preinitiation complex (PIC), required for transcription. [GOC:jp, GOC:txnOH]
Full description |

Standard name | GO_MITOCHONDRIAL_TRNA_METHYLATION
Systematic name | M24422
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The posttranscriptional addition of methyl groups to specific residues in a mitochondrial tRNA molecule. [GOC:mah, GOC:mcc]
Full description |

Standard name | GO_GLOBAL_GENOME_NUCLEOTIDE_EXCISION_REPAIR
Systematic name | M13221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The nucleotide-excision repair process in which DNA lesions are removed from nontranscribed strands and from transcriptionally silent regions over the entire genome. [PMID:10197977, PMID:18794354]
Full description |

Standard name | GO_UV_DAMAGE_EXCISION_REPAIR
Systematic name | M24423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A DNA repair process that is initiated by an endonuclease that introduces a single-strand incision immediately 5' of a UV-induced damage site. UV-damage excision repair acts on both cyclobutane pyrimidine dimers (CPDs) and pyrimidine-pyrimidone 6-4 photoproducts (6-4PPs). [GOC:mah, PMID:9619100]
Full description |

Standard name | GO_PRODUCTION_OF_SMALL_RNA_INVOLVED_IN_GENE_SILENCING_BY_RNA
Systematic name | M24424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a double-stranded RNA precursor is processed into short (20-30 nt) fragments. RNA cleavage is catalyzed by a Dicer endonuclease. [GOC:mah, PMID:19239886]
Full description |

Standard name | GO_REGULATION_OF_PRODUCTION_OF_SMALL_RNA_INVOLVED_IN_GENE_SILENCING_BY_RNA
Systematic name | M24425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the production of small RNA involved in gene silencing by RNA. [GOC:mah]
Full description |

Standard name | GO_SMALL_RNA_LOADING_ONTO_RISC
Systematic name | M24426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a single-stranded small RNA associates with the RNA-initiated silencing complex (RISC); occurs as part of a process of gene silencing by small RNA. [GOC:mah, PMID:19239886]
Full description |

Standard name | GO_ORGANELLE_ASSEMBLY
Systematic name | M13708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an organelle. An organelle is an organized structure of distinctive morphology and function. Includes the nucleus, mitochondria, plastids, vacuoles, vesicles, ribosomes and the cytoskeleton. Excludes the plasma membrane. [GOC:mah]
Full description |

Standard name | GO_HISTONE_H3_DEACETYLATION
Systematic name | M16751
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the removal of one or more acetyl groups. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_HISTONE_H4_DEACETYLATION
Systematic name | M24427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H4 by the removal of one or more acetyl groups. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_CRD_MEDIATED_MRNA_STABILIZATION
Systematic name | M24428
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An mRNA stabilization process in which one or more RNA-binding proteins associate with a sequence in the open reading frame called the coding region instability determinant (CRD). [GOC:mah, PMID:19029303]
Full description |

Standard name | GO_3_UTR_MEDIATED_MRNA_STABILIZATION
Systematic name | M11060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An mRNA stabilization process in which one or more RNA-binding proteins associate with the 3'-untranslated region (UTR) of an mRNA. [GOC:mah, PMID:19029303]
Full description |

Standard name | GO_PROTEIN_K48_LINKED_UBIQUITINATION
Systematic name | M15645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein ubiquitination process in which a polymer of ubiquitin, formed by linkages between lysine residues at position 48 of the ubiquitin monomers, is added to a protein. K48-linked ubiquitination targets the substrate protein for degradation. [GOC:cvs, PMID:15556404]
Full description |

Standard name | GO_DEPHOSPHORYLATION_OF_RNA_POLYMERASE_II_C_TERMINAL_DOMAIN
Systematic name | M24429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of removing a phosphate group from an amino acid residue in the C-terminal domain of RNA polymerase II. Some dephosphorylation occurs during transcription while some may occur after the enzyme is released from the template in order to prepare it for the beginning of the transcription cycle again. RNA polymerase II with little or no phosphorylation is referred to as the hypophosphorylated or II(A) form. [GOC:krc, GOC:mah, PMID:17079683]
Full description |

Standard name | GO_NEUTROPHIL_MEDIATED_CYTOTOXICITY
Systematic name | M24430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed killing of a target cell by a neutrophil. [GOC:add, ISBN:0781765196]
Full description |

Standard name | GO_NEUTROPHIL_MEDIATED_KILLING_OF_SYMBIONT_CELL
Systematic name | M24431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed killing of a symbiont target cell by a neutrophil. The symbiont is defined as the smaller of the organisms involved in a symbiotic interaction. [GOC:add, ISBN:0781765196]
Full description |

Standard name | GO_NEUTROPHIL_MEDIATED_KILLING_OF_GRAM_NEGATIVE_BACTERIUM
Systematic name | M24432
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed killing of a gram-negative bacterium by a neutrophil. [GOC:add, ISBN:0781765196]
Full description |

Standard name | GO_REGULATION_OF_NEUTROPHIL_MEDIATED_CYTOTOXICITY
Systematic name | M24433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of neutrophil mediated killing of a target cell, the directed killing of a target cell by a neutrophil. [GOC:add, GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_ENDOPLASMIC_RETICULUM
Systematic name | M12040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within the endoplasmic reticulum. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_ENDOPLASMIC_RETICULUM_EXIT_SITE
Systematic name | M24435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location at an endoplasmic reticulum exit site. [GOC:mah]
Full description |

Standard name | GO_BONE_MATURATION
Systematic name | M16580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for bone to attain its fully functional state. [GOC:dph, GOC:mah]
Full description |

Standard name | GO_PROTEIN_K11_LINKED_UBIQUITINATION
Systematic name | M12685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein ubiquitination process in which ubiquitin monomers are attached to a protein, and then ubiquitin polymers are formed by linkages between lysine residues at position 11 of the ubiquitin monomers. K11-linked polyubiquitination targets the substrate protein for degradation. The anaphase-promoting complex promotes the degradation of mitotic regulators by assembling K11-linked polyubiquitin chains. [GOC:jsg, GOC:pr, GOC:sp, PMID:18485873, PMID:20655260, PMID:21113135]
Full description |

Standard name | GO_LEFT_RIGHT_AXIS_SPECIFICATION
Systematic name | M12935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment, maintenance and elaboration of the left/right axis. The left/right axis is defined by a line that runs orthogonal to both the anterior/posterior and dorsal/ventral axes. Each side is defined from the viewpoint of the organism rather of the observer (as per anatomical axes). [GOC:dph, GOC:gvg, GOC:mah]
Full description |

Standard name | GO_ERROR_FREE_TRANSLESION_SYNTHESIS
Systematic name | M12348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The conversion of DNA-damage induced single-stranded gaps into large molecular weight DNA after replication by using a specialized DNA polymerase or replication complex to insert a defined nucleotide across the lesion. This process does not remove the replication-blocking lesions but does not causes an increase in the endogenous mutation level. For S. cerevisiae, RAD30 encodes DNA polymerase eta, which incorporates two adenines. When incorporated across a thymine-thymine dimer, it does not increase the endogenous mutation level. [GOC:elh]
Full description |

Standard name | GO_DEMETHYLATION
Systematic name | M12000
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of removing one or more methyl groups from a molecule. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_OXIDATIVE_DEMETHYLATION
Systematic name | M11148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of removing one or more methyl groups from a molecule, involving the oxidation (i.e. electron loss) of one or more atoms in the substrate. [GOC:BHF, GOC:mah, GOC:rl]
Full description |

Standard name | GO_NEURON_DEATH
Systematic name | M15850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of cell death in a neuron. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_RNA_SURVEILLANCE
Systematic name | M12433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The set of processes involved in identifying and degrading defective or aberrant RNAs. [GOC:dgf, GOC:krc, PMID:18644474]
Full description |

Standard name | GO_NUCLEAR_NCRNA_SURVEILLANCE
Systematic name | M24436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The set of processes involved in identifying and degrading defective or aberrant ncRNAs within the nucleus. [GOC:dgf, GOC:krc, PMID:18644474]
Full description |

Standard name | GO_NUCLEAR_RETENTION_OF_PRE_MRNA_AT_THE_SITE_OF_TRANSCRIPTION
Systematic name | M24437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process involved in retention of aberrant or improperly formed mRNAs, e.g. those that are incorrectly or incompletely spliced or that have incorrectly formed 3'-ends, within the nucleus at the site of transcription. [GOC:dgf, GOC:krc, PMID:11586364, PMID:12417728, PMID:14718167, PMID:18644474]
Full description |

Standard name | GO_HISTONE_MRNA_CATABOLIC_PROCESS
Systematic name | M14800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of histone messenger RNA (mRNA). [GOC:dgf, GOC:krc, PMID:17179095, PMID:17855393]
Full description |

Standard name | GO_POLYADENYLATION_DEPENDENT_SNORNA_3_END_PROCESSING
Systematic name | M24439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in forming the mature 3' end of a snoRNA molecule linked to prior polyadenylation of the 3'-end of the precursor snoRNA. [GOC:dgf, GOC:krc, PMID:18951092]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M14751
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of phospholipids. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PHOSPHOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M24440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of phospholipids. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHOSPHOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M24441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of phospholipids. [GOC:mah]
Full description |

Standard name | GO_RNA_3_URIDYLATION
Systematic name | M34235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The enzymatic addition of a sequence of uridylyl residues at the 3' end of an RNA molecule. [GOC:vw, PMID:19430462]
Full description |

Standard name | GO_DNA_CONFORMATION_CHANGE
Systematic name | M12191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in a change in the spatial configuration of a DNA molecule. A conformation change can bend DNA, or alter the, twist, writhe, or linking number of a DNA molecule. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_9
Systematic name | M24442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-9 stimulus. [GOC:mah, GOC:yaf]
Full description |

Standard name | GO_RESPONSE_TO_PARATHYROID_HORMONE
Systematic name | M14737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a parathyroid hormone stimulus. [GOC:mah, GOC:yaf]
Full description |

Standard name | GO_PROTEIN_K48_LINKED_DEUBIQUITINATION
Systematic name | M14122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein deubiquitination process in which a K48-linked ubiquitin chain, i.e. a polymer of ubiquitin formed by linkages between lysine residues at position 48 of the ubiquitin monomers, is removed from a protein. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CELL_CYCLE_ARREST
Systematic name | M14809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of cell cycle arrest, the process in which the cell cycle is halted during one of the normal phases. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_CYCLE_ARREST
Systematic name | M13248
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of cell cycle arrest, the process in which the cell cycle is halted during one of the normal phases. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_CYCLE_ARREST
Systematic name | M15012
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of cell cycle arrest, the process in which the cell cycle is halted during one of the normal phases. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CHROMATIN
Systematic name | M12871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, or maintained at, a part of a chromosome that is organized into chromatin. [GOC:mah]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_CHROMATIN
Systematic name | M24443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein to a part of a chromosome that is organized into chromatin. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_JUXTAPARANODE_REGION_OF_AXON
Systematic name | M24444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, or maintained at, the juxtaparanode region of an axon. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ABIOTIC_STIMULUS
Systematic name | M16709
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an abiotic (non-living) stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_BIOTIC_STIMULUS
Systematic name | M10812
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a biotic stimulus, a stimulus caused or produced by a living organism. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_MOLECULE_OF_BACTERIAL_ORIGIN
Systematic name | M34236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus by molecules of bacterial origin such as peptides derived from bacterial flagellin. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_BACTERIAL_LIPOPROTEIN
Systematic name | M34237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a bacterial lipoprotein stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_PEPTIDOGLYCAN
Systematic name | M24445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptidoglycan stimulus. Peptidoglycan is a bacterial cell wall macromolecule. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_MURAMYL_DIPEPTIDE
Systematic name | M24446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a muramyl dipeptide stimulus. Muramyl dipeptide is derived from peptidoglycan. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ACID_CHEMICAL
Systematic name | M11553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus by the chemical structure of the anion portion of the dissociated acid (rather than the acid acting as a proton donor). The acid chemical may be in gaseous, liquid or solid form. [GOC:go_curators, GOC:mah, Wikipedia:Acid]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_LEUCINE
Systematic name | M24447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a leucine stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ANTIBIOTIC
Systematic name | M14334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an antibiotic stimulus. An antibiotic is a chemical substance produced by a microorganism which has the capacity to inhibit the growth of or to kill other microorganisms. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_INORGANIC_SUBSTANCE
Systematic name | M14161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an inorganic substance stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ARSENIC_CONTAINING_SUBSTANCE
Systematic name | M13181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an arsenic stimulus from compounds containing arsenic, including arsenates, arsenites, and arsenides. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ELECTRICAL_STIMULUS
Systematic name | M12134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an electrical stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_MECHANICAL_STIMULUS
Systematic name | M16302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mechanical stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_CADMIUM_ION
Systematic name | M10980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cadmium (Cd) ion stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_CALCIUM_ION
Systematic name | M14517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a calcium ion stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_COPPER_ION
Systematic name | M24449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a copper ion stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_IRON_ION
Systematic name | M24450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an iron ion stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_LITHIUM_ION
Systematic name | M10966
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lithium (Li+) ion stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_MAGNESIUM_ION
Systematic name | M24452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a magnesium ion stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_MANGANESE_ION
Systematic name | M24453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a manganese ion stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ZINC_ION
Systematic name | M14069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a zinc ion stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_VITAMIN
Systematic name | M15636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_RETINOIC_ACID
Systematic name | M12477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a retinoic acid stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_VITAMIN_D
Systematic name | M15639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin D stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ALKALOID
Systematic name | M16868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an alkaloid stimulus. Alkaloids are a large group of nitrogenous substances found in naturally in plants, many of which have extracts that are pharmacologically active. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_CAFFEINE
Systematic name | M24454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a caffeine stimulus. Caffeine is an alkaloid found in numerous plant species, where it acts as a natural pesticide that paralyzes and kills certain insects feeding upon them. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_NICOTINE
Systematic name | M24456
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nicotine stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ISOQUINOLINE_ALKALOID
Systematic name | M34238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an isoquinoline alkaloid stimulus. An isoquinoline alkaloid is any member of a group of compounds with the heterocyclic ring structure of benzo(c)pyridine which is a structure characteristic of the group of opium alkaloids. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ATP
Systematic name | M12102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ATP (adenosine 5'-triphosphate) stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_CAMP
Systematic name | M13154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cAMP (cyclic AMP, adenosine 3',5'-cyclophosphate) stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_CARBOHYDRATE_STIMULUS
Systematic name | M11029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a carbohydrate stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_FRUCTOSE_STIMULUS
Systematic name | M24457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fructose stimulus. [GOC:mah]
Full description |

Standard name | GO_SKELETAL_MUSCLE_ACETYLCHOLINE_GATED_CHANNEL_CLUSTERING
Systematic name | M24458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The accumulation of acetylcholine-gated cation channels in a narrow, central region of muscle fibers, in apposition to nerve terminals. [GOC:bf, GOC:dsf, PMID:19285469]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_DSRNA
Systematic name | M14408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a double-stranded RNA stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_EXOGENOUS_DSRNA
Systematic name | M14247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an exogenous double-stranded RNA stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ETHANOL
Systematic name | M13732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ethanol stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ETHER
Systematic name | M24459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a ether stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_GONADOTROPIN_STIMULUS
Systematic name | M16827
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a gonadotropin stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_FOLLICLE_STIMULATING_HORMONE_STIMULUS
Systematic name | M24460
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a follicle-stimulating hormone stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_PARATHYROID_HORMONE_STIMULUS
Systematic name | M24461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a parathyroid hormone stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_PEPTIDE_HORMONE_STIMULUS
Systematic name | M24462
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptide hormone stimulus. A peptide hormone is any of a class of peptides that are secreted into the blood stream and have endocrine functions in living animals. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_GLUCAGON_STIMULUS
Systematic name | M12974
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucagon stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_GROWTH_HORMONE_STIMULUS
Systematic name | M12561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a growth hormone stimulus. Growth hormone is a peptide hormone that binds to the growth hormone receptor and stimulates growth. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_PROSTAGLANDIN_STIMULUS
Systematic name | M10971
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a prostagladin stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_PROSTAGLANDIN_E_STIMULUS
Systematic name | M13725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a prostagladin E stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_STEROID_HORMONE_STIMULUS
Systematic name | M14380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a steroid hormone stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_CORTICOSTEROID_STIMULUS
Systematic name | M12623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a corticosteroid hormone stimulus. A corticosteroid is a steroid hormone that is produced in the adrenal cortex. Corticosteroids are involved in a wide range of physiologic systems such as stress response, immune response and regulation of inflammation, carbohydrate metabolism, protein catabolism, blood electrolyte levels, and behavior. They include glucocorticoids and mineralocorticoids. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_MINERALOCORTICOID_STIMULUS
Systematic name | M24463
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mineralocorticoid stimulus. Mineralocorticoids are hormonal C21 corticosteroids synthesized from cholesterol and characterized by their similarity to aldosterone. Mineralocorticoids act primarily on water and electrolyte balance. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ESTROGEN_STIMULUS
Systematic name | M14988
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of stimulus by an estrogen, C18 steroid hormones that can stimulate the development of female sexual characteristics. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ESTRADIOL_STIMULUS
Systematic name | M15287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of stimulus by estradiol, a C18 steroid hormone hydroxylated at C3 and C17 that acts as a potent estrogen. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_TESTOSTERONE_STIMULUS
Systematic name | M24464
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a testosterone stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_LIPID
Systematic name | M10653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipid stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_CHOLESTEROL
Systematic name | M13781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cholesterol stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_FATTY_ACID
Systematic name | M14343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fatty acid stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_LIPOPROTEIN_PARTICLE_STIMULUS
Systematic name | M10052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipoprotein particle stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_LOW_DENSITY_LIPOPROTEIN_PARTICLE_STIMULUS
Systematic name | M24465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a low-density lipoprotein particle stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ORGANIC_CYCLIC_COMPOUND
Systematic name | M10841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic cyclic compound stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_PURINE_CONTAINING_COMPOUND
Systematic name | M24466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a purine-containing compound stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_HISTAMINE
Systematic name | M24467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a histamine stimulus. Histamine, the biogenic amine 2-(1H-imidazol-4-yl)ethanamine, is involved in local immune responses as well as regulating physiological function in the gut and acting as a neurotransmitter. [GOC:mah]
Full description |

Standard name | GO_MANGANESE_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M24468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a manganese ion is transported from one side of a membrane to the other by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_SUCCINATE_TRANSMEMBRANE_TRANSPORT
Systematic name | M34239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which succinate is transported across a membrane. [GOC:mah]
Full description |

Standard name | GO_HEMATOPOIETIC_STEM_CELL_PROLIFERATION
Systematic name | M13085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of a hematopoietic stem cell population by cell division. A hematopoietic stem cell is a stem cell from which all cells of the lymphoid and myeloid lineages develop. [CL:0000037, GOC:add, GOC:BHF, GOC:mah, GOC:rl]
Full description |

Standard name | GO_RRNA_CONTAINING_RIBONUCLEOPROTEIN_COMPLEX_EXPORT_FROM_NUCLEUS
Systematic name | M16317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a ribonucleoprotein complex that contains ribosomal RNA from the nucleus to the cytoplasm. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_H3_K14_ACETYLATION
Systematic name | M24469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the addition of an acetyl group to histone H3 at position 14 of the histone. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_HYDROPEROXIDE
Systematic name | M24470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydroperoxide stimulus. Hydroperoxides are monosubstitution products of hydrogen peroxide, HOOH. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_OXYGEN_RADICAL
Systematic name | M15152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an oxygen radical stimulus. An oxygen radical is any oxygen species that carries a free electron; examples include hydroxyl radicals and the superoxide anion. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_OXYGEN_LEVELS
Systematic name | M12594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting the presence, absence, or concentration of oxygen. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_HYPEROXIA
Systematic name | M24471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating increased oxygen tension. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CHROMOSOME_CENTROMERIC_REGION
Systematic name | M12643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, or maintained at, the centromeric region of a chromosome. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_PH
Systematic name | M14462
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a pH stimulus. pH is a measure of the acidity or basicity of an aqueous solution. [GOC:mah, Wikipedia:PH]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ACIDIC_PH
Systematic name | M24473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a pH stimulus with pH < 7. pH is a measure of the acidity or basicity of an aqueous solution. [GOC:go_curators, GOC:mah, Wikipedia:PH]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_OSMOTIC_STRESS
Systematic name | M15515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating an increase or decrease in the concentration of solutes outside the organism or cell. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_SALT_STRESS
Systematic name | M24474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating an increase or decrease in the concentration of salt (particularly but not exclusively sodium and chloride ions) in the environment. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_HYPEROSMOTIC_RESPONSE
Systematic name | M24475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of detection of, or exposure to, a hyperosmotic environment, i.e. an environment with a higher concentration of solutes than the organism or cell. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_HYPEROSMOTIC_SALINITY_RESPONSE
Systematic name | M29271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of detection of, or exposure to, an increase in the concentration of salt (particularly but not exclusively sodium and chloride ions) in the environment. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_HYPOTONIC_RESPONSE
Systematic name | M24476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of detection of, or exposure to, a hypotonic environment, i.e. an environment with a lower concentration of solutes than the organism or cell. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_RADIATION
Systematic name | M14657
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an electromagnetic radiation stimulus. Electromagnetic radiation is a propagating wave in space with electric and magnetic components. These components oscillate at right angles to each other and to the direction of propagation. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_IONIZING_RADIATION
Systematic name | M14071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a ionizing radiation stimulus. Ionizing radiation is radiation with sufficient energy to remove electrons from atoms and may arise from spontaneous decay of unstable isotopes, resulting in alpha and beta particles and gamma rays. Ionizing radiation also includes X-rays. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_GAMMA_RADIATION
Systematic name | M11307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a gamma radiation stimulus. Gamma radiation is a form of electromagnetic radiation (EMR) or light emission of a specific frequency produced from sub-atomic particle interaction, such as electron-positron annihilation and radioactive decay. Gamma rays are generally characterized as EMR having the highest frequency and energy, and also the shortest wavelength, within the electromagnetic radiation spectrum. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_X_RAY
Systematic name | M24477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of X-ray radiation. An X-ray is a form of electromagnetic radiation with a wavelength in the range of 10 nanometers to 100 picometers (corresponding to frequencies in the range 30 PHz to 3 EHz). [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_LIGHT_STIMULUS
Systematic name | M10846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a light stimulus, electromagnetic radiation of wavelengths classified as infrared, visible or ultraviolet light. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_UV_B
Systematic name | M24478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a UV-B radiation stimulus. UV-B radiation (UV-B light) spans the wavelengths 280 to 315 nm. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_UV_C
Systematic name | M24479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a UV-C radiation stimulus. UV-C radiation (UV-C light) spans the wavelengths 100 to 280 nm. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ENDOGENOUS_STIMULUS
Systematic name | M15026
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus arising within the organism. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_EXTERNAL_STIMULUS
Systematic name | M10729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an external stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_FLUID_SHEAR_STRESS
Systematic name | M10935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fluid shear stress stimulus. Fluid shear stress is the force acting on an object in a system where the fluid is moving across a solid surface. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_LAMINAR_FLUID_SHEAR_STRESS
Systematic name | M24480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a laminar fluid shear stress stimulus. Laminar fluid flow is the force acting on an object in a system where the fluid is moving across a solid surface in parallel layers. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_NITROSATIVE_STRESS
Systematic name | M24481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nitrosative stress stimulus. Nitrosative stress is a state often resulting from exposure to high levels of nitric oxide (NO) or the highly reactive oxidant peroxynitrite, which is produced following interaction of NO with superoxide anions. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_STEROL_DEPLETION
Systematic name | M29272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating deprivation of sterols. Sterols are a group of steroids characterized by the presence of one or more hydroxyl groups and a hydrocarbon side-chain in the molecule. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_TEMPERATURE_STIMULUS
Systematic name | M24482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a temperature stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_HEPARIN
Systematic name | M24483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a heparin stimulus. [GOC:mah, GOC:yaf]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_HEPARIN
Systematic name | M24484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a heparin stimulus. [GOC:mah, GOC:yaf]
Full description |

Standard name | GO_GENETIC_IMPRINTING
Systematic name | M13829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving macromolecules by a mechanism that is mediated by DNA, is mitotically or meiotically heritable, or is stably self-propagated in the cytoplasm of a resting cell, and does not entail a change in DNA sequence. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_SEMAPHORIN_PLEXIN_SIGNALING_PATHWAY
Systematic name | M15378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals generated as a consequence of a semaphorin receptor (composed of a plexin and a neurophilin) binding to a semaphorin ligand. [GOC:BHF, GOC:mah, GOC:vk, PMID:15239959]
Full description |

Standard name | GO_DOPAMINERGIC_NEURON_DIFFERENTIATION
Systematic name | M15307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a neuroblast acquires the specialized structural and functional features of a dopaminergic neuron, a neuron that secretes dopamine. [GOC:rph]
Full description |

Standard name | GO_DIPHOSPHOINOSITOL_POLYPHOSPHATE_METABOLIC_PROCESS
Systematic name | M34240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a diphosphoinositol polyphosphate, 1,2,3,4,5,6-cyclohexanehexol with one or more diphosphate groups and multiple monophosphate groups attached. [GOC:mah, PMID:12387729]
Full description |

Standard name | GO_INOSITOL_PHOSPHATE_CATABOLIC_PROCESS
Systematic name | M11032
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of an inositol phosphate, 1,2,3,4,5,6-cyclohexanehexol, with one or more phosphate groups attached. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_DEXAMETHASONE
Systematic name | M15159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a dexamethasone stimulus. [GOC:mah, GOC:yaf]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_DEXAMETHASONE_STIMULUS
Systematic name | M16203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a dexamethasone stimulus. [GOC:mah, GOC:yaf]
Full description |

Standard name | GO_DEATH_INDUCING_SIGNALING_COMPLEX_ASSEMBLY
Systematic name | M24485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process of protein complex assembly in which the arrangement and bonding together of the set of components that form the protein complex is mediated by a death domain (DD) interaction, as part of the extrinsic apoptotic signaling pathway. [GOC:amm, GOC:mtg_apoptosis, InterPro:IPR000488]
Full description |

Standard name | GO_HISTONE_H3_K27_DEMETHYLATION
Systematic name | M24486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by the removal of a methyl group from lysine at position 27 of the histone. [GOC:sp, PMID:20023638]
Full description |

Standard name | GO_RESPONSE_TO_TRANSFORMING_GROWTH_FACTOR_BETA
Systematic name | M12916
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a transforming growth factor beta stimulus. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_UFMYLATION
Systematic name | M24487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Covalent attachment of the ubiquitin-like protein UFM1 to another protein. [GOC:vw, PMID:20018847]
Full description |

Standard name | GO_ZINC_ION_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M24489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of zinc(2+) ions from outside of a cell, across the plasma membrane and into the cytosol. [GOC:vw, PMID:18637840]
Full description |

Standard name | GO_LYMPHOCYTE_AGGREGATION
Systematic name | M29273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The adhesion of one lymphocyte to one or more other lymphocytes via adhesion molecules. [GOC:sl]
Full description |

Standard name | GO_OTIC_VESICLE_DEVELOPMENT
Systematic name | M10898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the otic vesicle over time, from its formation to the mature structure. The otic vesicle is a transient embryonic structure formed during development of the vertebrate inner ear. [GOC:mah]
Full description |

Standard name | GO_OTIC_VESICLE_MORPHOGENESIS
Systematic name | M24490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the otic vesicle are generated and organized. The otic vesicle is a transient embryonic structure formed during development of the vertebrate inner ear. [GOC:mah]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA_PRODUCTION
Systematic name | M24491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of any member of the transforming growth factor-beta family of cytokines due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. Transforming growth factor-beta family members include TGF-B1, TGF-B2, and TGF-B3. [GOC:add, GOC:rv]
Full description |

Standard name | GO_MONOCYTE_CHEMOTACTIC_PROTEIN_1_PRODUCTION
Systematic name | M24492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of monocyte chemotactic protein-1 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:add, GOC:rv]
Full description |

Standard name | GO_MACROPHAGE_INFLAMMATORY_PROTEIN_1_ALPHA_PRODUCTION
Systematic name | M24493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of macrophage inflammatory protein 1 alpha due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:add, GOC:rv]
Full description |

Standard name | GO_CHEMOKINE_C_C_MOTIF_LIGAND_5_PRODUCTION
Systematic name | M24494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of chemokine (C-C motif) ligand 5 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:add, GOC:rv]
Full description |

Standard name | GO_GRANULOCYTE_COLONY_STIMULATING_FACTOR_PRODUCTION
Systematic name | M24495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of granulocyte colony-stimulating factor due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:add, GOC:rv]
Full description |

Standard name | GO_GRANULOCYTE_CHEMOTAXIS
Systematic name | M34241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a granulocyte in response to an external stimulus. [GOC:rph]
Full description |

Standard name | GO_REGULATION_OF_GRANULOCYTE_CHEMOTAXIS
Systematic name | M13549
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of granulocyte chemotaxis. Granulocyte chemotaxis is the movement of a granulocyte in response to an external stimulus. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GRANULOCYTE_CHEMOTAXIS
Systematic name | M24496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of granulocyte chemotaxis. Granulocyte chemotaxis is the movement of a granulocyte in response to an external stimulus. [GOC:mah]
Full description |

Standard name | GO_VOCALIZATION_BEHAVIOR
Systematic name | M13775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The behavior in which an organism produces sounds by a mechanism involving its respiratory system. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSFORMING_GROWTH_FACTOR_BETA_PRODUCTION
Systematic name | M24497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of production of transforming growth factor-beta. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSFORMING_GROWTH_FACTOR_BETA_PRODUCTION
Systematic name | M14267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of production of transforming growth factor-beta. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MONOCYTE_CHEMOTACTIC_PROTEIN_1_PRODUCTION
Systematic name | M24498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of production of monocyte chemotactic protein-1. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MONOCYTE_CHEMOTACTIC_PROTEIN_1_PRODUCTION
Systematic name | M24499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of production of monocyte chemotactic protein-1. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHEMOKINE_C_C_MOTIF_LIGAND_5_PRODUCTION
Systematic name | M24500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate, or extent of production of chemokine (C-C motif) ligand 5. [GOC:mah]
Full description |

Standard name | GO_SMOOTH_MUSCLE_CELL_CHEMOTAXIS
Systematic name | M24501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a smooth muscle cell in response to an external stimulus. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_SMOOTH_MUSCLE_CELL_CHEMOTAXIS
Systematic name | M24502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of smooth muscle cell chemotaxis. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMOOTH_MUSCLE_CELL_CHEMOTAXIS
Systematic name | M24503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate, or extent of smooth muscle cell chemotaxis. [GOC:mah]
Full description |

Standard name | GO_MONONUCLEAR_CELL_MIGRATION
Systematic name | M24504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a mononuclear cell within or between different tissues and organs of the body. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MONONUCLEAR_CELL_MIGRATION
Systematic name | M12011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of mononuclear cell migration. Mononuclear cell migration is the movement of a mononuclear cell within or between different tissues and organs of the body. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MONONUCLEAR_CELL_MIGRATION
Systematic name | M24505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of mononuclear cell migration. Mononuclear cell migration is the movement of a mononuclear cell within or between different tissues and organs of the body. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MONONUCLEAR_CELL_MIGRATION
Systematic name | M24506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of mononuclear cell migration. Mononuclear cell migration is the movement of a mononuclear cell within or between different tissues and organs of the body. [GOC:mah]
Full description |

Standard name | GO_COMMISSURAL_NEURON_AXON_GUIDANCE
Systematic name | M24507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the migration of an axon growth cone of a commissural neuron is directed to its target in the brain in response to a combination of attractive and repulsive cues. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_INDOLE_3_METHANOL
Systematic name | M24508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an indole-3-methanol stimulus. [GOC:mah, GOC:yaf]
Full description |

Standard name | GO_ORGANISM_EMERGENCE_FROM_PROTECTIVE_STRUCTURE
Systematic name | M24509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process in which an organism emerges from a surrounding protective structure such as an egg or pupa case. [GOC:mah]
Full description |

Standard name | GO_MAINTENANCE_OF_PROTEIN_LOCATION_IN_EXTRACELLULAR_REGION
Systematic name | M29274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is maintained in a specific location within the extracellular region and is prevented from moving elsewhere. [GOC:mah]
Full description |

Standard name | GO_ANATOMICAL_STRUCTURE_MATURATION
Systematic name | M12218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A developmental process, independent of morphogenetic (shape) change, that is required for an anatomical structure to attain its fully functional state. [GOC:mah]
Full description |

Standard name | GO_ECTODERMAL_PLACODE_DEVELOPMENT
Systematic name | M13730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of an ectodermal placode over time from its initial formation until its mature state. An ectodermal placode is a thickening of the ectoderm that is the primordium of many structures derived from the ectoderm. [GOC:mah]
Full description |

Standard name | GO_TUMOR_NECROSIS_FACTOR_SUPERFAMILY_CYTOKINE_PRODUCTION
Systematic name | M24512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of any member of the TNF superfamily due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:add]
Full description |

Standard name | GO_BASEMENT_MEMBRANE_ORGANIZATION
Systematic name | M16086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the basement membrane. [GOC:mah]
Full description |

Standard name | GO_ER_ASSOCIATED_MISFOLDED_PROTEIN_CATABOLIC_PROCESS
Systematic name | M24513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of misfolded proteins transported from the endoplasmic reticulum and targeted to cytoplasmic proteasomes for degradation. [GOC:mah, GOC:vw, PMID:14607247, PMID:19520858]
Full description |

Standard name | GO_RESPONSE_TO_DIACYL_BACTERIAL_LIPOPEPTIDE
Systematic name | M29275
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a diacylated bacterial lipopeptide stimulus. [GOC:add, PMID:12077222, PMID:12524386, PMID:2757794]
Full description |

Standard name | GO_RESPONSE_TO_NITRIC_OXIDE
Systematic name | M16967
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nitric oxide stimulus. [GOC:mah, GOC:yaf]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_NITRIC_OXIDE
Systematic name | M11925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nitric oxide stimulus. [GOC:mah, GOC:yaf]
Full description |

Standard name | GO_NUCLEAR_MEMBRANE_ORGANIZATION
Systematic name | M24514
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the nuclear inner or outer membrane. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_BMP
Systematic name | M14241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a bone morphogenetic protein (BMP) stimulus. [GOC:mah, GOC:yaf]
Full description |

Standard name | GO_RESPONSE_TO_FIBROBLAST_GROWTH_FACTOR
Systematic name | M13039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fibroblast growth factor stimulus. [GOC:mah]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_TUBULAR_NETWORK_ORGANIZATION
Systematic name | M24515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of the endoplasmic reticulum (ER) tubular network. The ER tubular network is the ER part that that has membranes with high curvature in cross-section. [GOC:vw, PMID:16469703, PMID:20434336]
Full description |

Standard name | GO_RESPONSE_TO_PROSTAGLANDIN_D
Systematic name | M24516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a prostagladin D stimulus. [GOC:sl]
Full description |

Standard name | GO_PODOSOME_ASSEMBLY
Systematic name | M24517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a podosome, an actin-rich adhesion structure characterized by formation upon cell substrate contact and localization at the substrate-attached part of the cell. [GOC:mah, GOC:sl]
Full description |

Standard name | GO_REGULATION_OF_PODOSOME_ASSEMBLY
Systematic name | M10562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of podosome assembly. [GOC:mah, GOC:sl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PODOSOME_ASSEMBLY
Systematic name | M24518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the rate or extent of podosome assembly. [GOC:mah, GOC:sl]
Full description |

Standard name | GO_PROTEIN_TRANSMEMBRANE_TRANSPORT
Systematic name | M15048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a protein is transported across a membrane. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_TAIL_ANCHORED_MEMBRANE_PROTEIN_INSERTION_INTO_ER_MEMBRANE
Systematic name | M34242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process of protein insertion into the endoplasmic reticulum (ER) membrane in which a tail-anchored (TA) transmembrane protein is incorporated into an endoplasmic reticulum (ER) membrane. TA transmembrane protein, also named type II transmembrane proteins, contain a single C- terminal transmembrane region. [GOC:mah, GOC:sp, PMID:20516149, PMID:20676083]
Full description |

Standard name | GO_PROTEIN_DNA_COMPLEX_SUBUNIT_ORGANIZATION
Systematic name | M15278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which macromolecules aggregate, disaggregate, or are modified, resulting in the formation, disassembly, or alteration of a protein-DNA complex. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LIPID_COMPLEX_SUBUNIT_ORGANIZATION
Systematic name | M13277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which macromolecules aggregate, disaggregate, or are modified, resulting in the formation, disassembly, or alteration of a protein-lipid complex. [GOC:mah]
Full description |

Standard name | GO_RIBONUCLEOPROTEIN_COMPLEX_SUBUNIT_ORGANIZATION
Systematic name | M13539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which macromolecules aggregate, disaggregate, or are modified, resulting in the formation, disassembly, or alteration of a ribonucleoprotein complex. [GOC:mah]
Full description |

Standard name | GO_TRIGLYCERIDE_RICH_LIPOPROTEIN_PARTICLE_CLEARANCE
Systematic name | M24519
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a triglyceride-rich lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. [GOC:BHF]
Full description |

Standard name | GO_CELL_PROLIFERATION_IN_BONE_MARROW
Systematic name | M24520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of cells, resulting in the expansion of a cell population in the bone marrow. [GOC:mah, GOC:yaf, PMID:17063141]
Full description |

Standard name | GO_APOPTOTIC_PROCESS_IN_BONE_MARROW_CELL
Systematic name | M24521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The apoptotic process in cells in the bone marrow. [GOC:mah, GOC:mtg_apoptosis, PMID:17063141]
Full description |

Standard name | GO_MITOTIC_CELL_CYCLE_ARREST
Systematic name | M11958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the mitotic cell cycle is halted during one of the normal phases (G1, S, G2, M). [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_PROLIFERATION_IN_BONE_MARROW
Systematic name | M24522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that activates or increases the frequency, rate or extent of cell proliferation in the bone marrow. [GOC:mah, GOC:yaf, PMID:17063141]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_APOPTOTIC_PROCESS_IN_BONE_MARROW_CELL
Systematic name | M24523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the occurrence or rate of cell death by apoptotic process in the bone marrow. [GOC:mah, GOC:mtg_apoptosis, GOC:yaf, PMID:17063141]
Full description |

Standard name | GO_RESPONSE_TO_CATECHOLAMINE
Systematic name | M24524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a catecholamine stimulus. A catecholamine is any of a group of biogenic amines that includes 4-(2-aminoethyl)pyrocatechol [4-(2-aminoethyl)benzene-1,2-diol] and derivatives formed by substitution. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_EPINEPHRINE
Systematic name | M15290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an epinephrine stimulus. Epinephrine is a catecholamine that has the formula C9H13NO3; it is secreted by the adrenal medulla to act as a hormone, and released by certain neurons to act as a neurotransmitter active in the central nervous system. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_EPINEPHRINE_STIMULUS
Systematic name | M13395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an epinephrine stimulus. Epinephrine is a catecholamine that has the formula C9H13NO3; it is secreted by the adrenal medulla to act as a hormone, and released by certain neurons to act as a neurotransmitter active in the central nervous system. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_ADRENERGIC_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M13056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals generated as a consequence of an adrenergic receptor binding to one of its physiological ligands. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ADENYLATE_CYCLASE_ACTIVATING_ADRENERGIC_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of an adenylate cyclase-activating adrenergic receptor protein signaling pathway activity. An adrenergic receptor signaling pathway is the series of molecular signals generated as a consequence of an adrenergic receptor binding to one of its physiological ligands. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_INHIBITING_ADRENERGIC_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of an adrenergic receptor binding to its physiological ligand, where the pathway proceeds with inhibition of adenylyl cyclase and a subsequent decrease in the concentration of cyclic AMP (cAMP). [GOC:BHF, GOC:mah, GOC:signaling]
Full description |

Standard name | GO_LEUKOCYTE_APOPTOTIC_PROCESS
Systematic name | M13996
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a leukocyte, an achromatic cell of the myeloid or lymphoid lineages capable of ameboid movement, found in blood or other tissue. [CL:0000738, GOC:BHF, GOC:mah, GOC:mtg_apoptosis]
Full description |

Standard name | GO_MACROPHAGE_APOPTOTIC_PROCESS
Systematic name | M24527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a macrophage, a mononuclear phagocyte present in a variety of tissues. [CL:0000235, GOC:BHF, GOC:mah, GOC:mtg_apoptosis]
Full description |

Standard name | GO_ODONTOBLAST_DIFFERENTIATION
Systematic name | M24528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell of neural crest origin acquires the specialized features of an odontoblast, a cell on the outer surface of the dental pulp whose biological function is the creation of dentin. [GOC:sl, PMID:20425127]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_ADHERENS_JUNCTION
Systematic name | M34243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, and/or maintained at the adherens junction. [GOC:aruk, GOC:bc, GOC:BHF, GOC:mah, PMID:26412237]
Full description |

Standard name | GO_DNA_BIOSYNTHETIC_PROCESS
Systematic name | M13892
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular DNA metabolic process resulting in the formation of DNA, deoxyribonucleic acid, one of the two main types of nucleic acid, consisting of a long unbranched macromolecule formed from one or two strands of linked deoxyribonucleotides, the 3'-phosphate group of each constituent deoxyribonucleotide being joined in 3',5'-phosphodiester linkage to the 5'-hydroxyl group of the deoxyribose moiety of the next one. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_SERINE_THREONINE_KINASE_ACTIVITY
Systematic name | M15624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of protein serine/threonine kinase activity. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_SERINE_THREONINE_KINASE_ACTIVITY
Systematic name | M16865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of protein serine/threonine kinase activity. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_SERINE_THREONINE_KINASE_ACTIVITY
Systematic name | M13485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of protein serine/threonine kinase activity. [GOC:mah]
Full description |

Standard name | GO_DETERMINATION_OF_DIGESTIVE_TRACT_LEFT_RIGHT_ASYMMETRY
Systematic name | M24529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Determination of the asymmetric location of various parts of the digestive tract with respect to the left and right halves of the organism. The digestive tract is the anatomical structure through which food passes and is processed. [GOC:cvs]
Full description |

Standard name | GO_DETERMINATION_OF_LIVER_LEFT_RIGHT_ASYMMETRY
Systematic name | M24530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Determination of the asymmetric location of the liver with respect to the left and right halves of the organism. [GOC:cvs]
Full description |

Standard name | GO_COHESIN_LOADING
Systematic name | M24531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The protein localization to chromatin by which a cohesin ring complex is topologically linked to DNA. [GOC:dph, GOC:mah, GOC:vw, PMID:10882066, PMID:17113138, PMID:26687354]
Full description |

Standard name | GO_REGULATION_OF_COHESIN_LOADING
Systematic name | M24532
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a process in which a cohesin complex is transported to, or maintained at, a part of a chromosome that is organized into chromatin. [GOC:lb, GOC:mah, PMID:17113138]
Full description |

Standard name | GO_ENDOCANNABINOID_SIGNALING_PATHWAY
Systematic name | M34244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of an endocannabinoid binding to a cell surface receptor. The pathway proceeds with the receptor transmitting the signal to a heterotrimeric G-protein complex and ends with regulation of a downstream cellular process, e.g. transcription. Endocannabinoids are small molecules derived from arachidonic acid, anandamide (arachidonoylethanolamide) and 2-arachidonoylglycerol. [GOC:bf, GOC:mah, PMID:15550444]
Full description |

Standard name | GO_PROTEIN_DEUBIQUITINATION_INVOLVED_IN_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS
Systematic name | M24533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of one or more ubiquitin groups from a protein as part of a process of ubiquitin-dependent protein catabolism. [GOC:mah]
Full description |

Standard name | GO_EXTRACELLULAR_EXOSOME_ASSEMBLY
Systematic name | M24534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an extracellular vesicular exosome, a membrane-bounded vesicle that is released into the extracellular region by fusion of the limiting endosomal membrane of a multivesicular body with the plasma membrane. Exosomes are defined by their size, which generally ranges from 30 nm to 100 nm. [GOC:mah, GOC:tfm, PMID:19442504, PMID:27462458]
Full description |

Standard name | GO_MULTIVESICULAR_BODY_SORTING_PATHWAY
Systematic name | M13634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A vesicle-mediated transport process in which transmembrane proteins are ubiquitylated to facilitate their entry into luminal vesicles of multivesicular bodies (MVBs); upon subsequent fusion of MVBs with lysosomes or vacuoles, the cargo proteins are degraded. [GOC:mah, PMID:17603537]
Full description |

Standard name | GO_NEPHRON_DEVELOPMENT
Systematic name | M15872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the nephron over time, from its formation to the mature structure. A nephron is the functional unit of the kidney. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_GLOMERULAR_MESANGIAL_CELL_DIFFERENTIATION
Systematic name | M24536
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features that characterize the glomerular mesangial cells of the kidney as it progresses from its formation to the mature state. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_NEPHRON_EPITHELIUM_DEVELOPMENT
Systematic name | M12799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the nephron epithelium over time, from its formation to the mature structure. An epithelium is a tissue that covers the internal or external surfaces of an anatomical structure. The nephron epithelium is a tissue that covers the surface of a nephron. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_GLOMERULAR_EPITHELIUM_DEVELOPMENT
Systematic name | M14527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the glomerular epithelium over time, from its formation to the mature structure. The glomerular epithelium is an epithelial tissue that covers the outer surfaces of the glomerulus. The glomerular epithelium consists of both parietal and visceral epithelium. Metanephric glomerular parietal epithelial cells are specialized epithelial cells that form tight junctions as a barrier to protein transport. A metanephric glomerular visceral epithelial cell is a specialized epithelial cell that contains 'feet' that interdigitate with the 'feet' of other glomerular epithelial cells in the metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_PROXIMAL_TUBULE_DEVELOPMENT
Systematic name | M24537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the proximal tubule over time, from its formation to the mature structure. In mammals, the proximal tubule is a nephron tubule that connects Bowman's capsule to the descending thin limb of the loop of Henle. It has a brush border epithelial morphology. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_DISTAL_TUBULE_DEVELOPMENT
Systematic name | M13821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the distal tubule over time, from its formation to the mature structure. In mammals, the distal tubule is a nephron tubule that begins at the macula densa and extends to the connecting tubule. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_DISTAL_CONVOLUTED_TUBULE_DEVELOPMENT
Systematic name | M24538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the distal convoluted tubule over time, from its formation to the mature structure. The distal convoluted tubule is the first segment of the nephron lying just downstream from the loop of Henle, immediately after the macula densa. Among other functions, in humans it is responsible for the reabsorption of about 5% of filtered sodium via the thiazide-sensitive Na-Cl symporter. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_NEPHRON_MORPHOGENESIS
Systematic name | M24539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the nephron are generated and organized. A nephron is the functional unit of the kidney. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_RENAL_VESICLE_FORMATION
Systematic name | M24540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of the renal vesicle from condensed mesenchymal cells. The renal vesicle is the primordial structure of the nephron epithelium, and is formed by the condensation of mesenchymal cells. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_MESENCHYMAL_STEM_CELL_MAINTENANCE_INVOLVED_IN_NEPHRON_MORPHOGENESIS
Systematic name | M24541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an organism retains a population of mesenchymal stem cells that contributes to the shaping of a nephron. A mesenchymal stem cell is a cell that retains the ability to divide and proliferate throughout life to provide progenitor cells that can differentiate into specialized mesenchymal cells. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_COLLECTING_DUCT_DEVELOPMENT
Systematic name | M15735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a collecting duct over time, from its formation to the mature structure. The collecting duct responds to vasopressin and aldosterone to regulate water, electrolyte and acid-base balance. It is the final common path through which urine flows before entering the ureter and then emptying into the bladder. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_COMMA_SHAPED_BODY_MORPHOGENESIS
Systematic name | M24543
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the comma-shaped body is generated and organized. The comma-shaped body is the precursor structure to the S-shaped body that contributes to the morphogenesis of the nephron. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_S_SHAPED_BODY_MORPHOGENESIS
Systematic name | M24544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the S-shaped body is generated and organized. The S-shaped body is the successor of the comma-shaped body that contributes to the morphogenesis of the nephron. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_LOOP_OF_HENLE_DEVELOPMENT
Systematic name | M10785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the loop of Henle over time, from its formation to the mature structure. The loop of Henle is a nephron tubule that connects the proximal convoluted tubule to the distal convoluted tubule. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_KIDNEY_EPITHELIUM_DEVELOPMENT
Systematic name | M11503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an epithelium in the kidney over time, from its formation to the mature structure. An epithelium is a tissue that covers the internal or external surfaces of an anatomical structure. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_KIDNEY_MESENCHYME_DEVELOPMENT
Systematic name | M14682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a kidney mesenchyme from an initial condition to its mature state. This process begins with the formation of kidney mesenchyme and ends with the mature structure. Kidney mesenchyme is the tissue made up of loosely connected mesenchymal cells in the kidney. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_MESENCHYME_DEVELOPMENT
Systematic name | M14282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a metanephric mesenchyme from an initial condition to its mature state. This process begins with the formation of metanephric mesenchyme and ends with the mature structure. Metanephric mesenchyme is the tissue made up of loosely connected mesenchymal cells in the metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_NEPHRON_TUBULE_FORMATION
Systematic name | M15772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of a nephron tubule from unspecified parts. A nephron tubule is an epithelial tube that is part of the nephron, the functional part of the kidney. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_RENAL_VESICLE_DEVELOPMENT
Systematic name | M11175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the renal vesicle over time, from its formation to the mature structure. An epithelium is a tissue that covers the internal or external surfaces of an anatomical structure. The renal vesicle is the primordial structure of the nephron epithelium, and is formed by the condensation of mesenchymal cells. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_STEM_CELL_PROLIFERATION
Systematic name | M11822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of stem cells, resulting in the expansion of a stem cell population. A stem cell is a cell that retains the ability to divide and proliferate throughout life to provide progenitor cells that can differentiate into specialized cells. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_REGULATION_OF_STEM_CELL_PROLIFERATION
Systematic name | M14567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of stem cell proliferation. A stem cell is a cell that retains the ability to divide and proliferate throughout life to provide progenitor cells that can differentiate into specialized cells. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_GLOMERULUS_MORPHOGENESIS
Systematic name | M24545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the glomerulus are generated and organized. The glomerulus is a capillary tuft surrounded by Bowman's capsule in nephrons of the vertebrate kidney. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_GLOMERULUS_VASCULATURE_MORPHOGENESIS
Systematic name | M24546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the glomerulus vasculature are generated and organized. The glomerulus vasculature is composed of the tubule structures that carry blood or lymph in the glomerulus. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_GLOMERULAR_MESANGIUM_DEVELOPMENT
Systematic name | M24547
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the glomerular mesangium over time, from its formation to the mature structure. The glomerular mesangium is the thin membrane connective tissue composed of mesangial cells, which helps to support the capillary loops in a renal glomerulus. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_GLOMERULAR_MESANGIAL_CELL_PROLIFERATION
Systematic name | M24548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of glomerular mesangial cells, resulting in the expansion of the population. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_CELL_PROLIFERATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M24549
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of cells, resulting in the expansion of the population in the kidney. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLOMERULAR_MESANGIAL_CELL_PROLIFERATION
Systematic name | M24550
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of glomerular mesangial cell proliferation. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_MESENCHYME_MORPHOGENESIS
Systematic name | M15995
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a mesenchymal tissue are generated and organized. A mesenchymal tissue is made up of loosely packed stellate cells. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_MESANGIAL_CELL_DEVELOPMENT
Systematic name | M24551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a mesangial cell in the kidney over time, from its formation to the mature structure. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_GLOMERULAR_MESANGIAL_CELL_DEVELOPMENT
Systematic name | M29277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a glomerular mesangial cell in the kidney over time, from its formation to the mature structure. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_EPITHELIAL_CELL_FATE_COMMITMENT
Systematic name | M16390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the developmental fate of a cell becomes restricted such that it will develop into an epithelial cell. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_NEPHRON_TUBULE_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M24552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features that characterize the cells of the nephron tubule as it progresses from its formation to the mature state. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_MESENCHYMAL_CELL_DIFFERENTIATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M24553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features that characterize the mesenchymal cells of the kidney as it progresses from its formation to the mature state. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_MESENCHYMAL_CELL_DIFFERENTIATION
Systematic name | M24554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features that characterize the mesenchymal cells of the metanephros as it progresses from its formation to the mature state. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_MESONEPHRIC_TUBULE_MORPHOGENESIS
Systematic name | M13433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a mesonephric tubule are generated and organized. A mesonephric tubule is an epithelial tube that is part of the mesonephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_MESONEPHRIC_TUBULE_FORMATION
Systematic name | M24555
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of a mesonephric tubule from unspecified parts. A mesonephric tubule is an epithelial tube that is part of the mesonephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_TUBULE_MORPHOGENESIS
Systematic name | M24556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a metanephric tubule are generated and organized from an epithelium. A metanephric tubule is an epithelial tube that is part of the metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_TUBULE_FORMATION
Systematic name | M24557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of a metanephric tubule. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_EPITHELIAL_TUBE_FORMATION
Systematic name | M29278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of an epithelial tube. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_NEPHRIC_DUCT_DEVELOPMENT
Systematic name | M12344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a nephric duct over time, from its initial formation to a mature structure. A nephric duct is a tube that drains a primitive kidney. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_MESONEPHRIC_DUCT_DEVELOPMENT
Systematic name | M24558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a mesonephric duct over time, from its initial formation to a mature structure. A mesonephric duct is a tube drains the mesonephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_NEPHRIC_DUCT_MORPHOGENESIS
Systematic name | M16627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the nephric duct are generated and organized. A nephric duct is a tube that drains a primitive kidney. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_NEPHRIC_DUCT_FORMATION
Systematic name | M24559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of a nephric duct. A nephric duct is a tube that drains a primitive kidney. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_URETER_DEVELOPMENT
Systematic name | M10305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the ureter over time, from its formation to the mature structure. The ureter is a muscular tube that transports urine from the kidney to the urinary bladder or from the Malpighian tubule to the hindgut. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_URETER_MORPHOGENESIS
Systematic name | M24560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the ureter are generated and organized. The ureter is a muscular tube that transports urine from the kidney to the urinary bladder. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MESENCHYMAL_CELL_PROLIFERATION
Systematic name | M24561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of mesenchymal cell proliferation. A mesenchymal cell is a cell that normally gives rise to other cells that are organized as three-dimensional masses, rather than sheets. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_CELL_DIFFERENTIATION_INVOLVED_IN_METANEPHROS_DEVELOPMENT
Systematic name | M11534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features that characterize the cells of the metanephros as it progresses from its formation to the mature state. [GOC:mah, GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_CELL_PROLIFERATION_INVOLVED_IN_METANEPHROS_DEVELOPMENT
Systematic name | M24562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of cells, resulting in the expansion of the population in the metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_COLLECTING_DUCT_DEVELOPMENT
Systematic name | M24563
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a collecting duct in the metanephros over time, from its formation to the mature structure. The collecting duct responds to vasopressin and aldosterone to regulate water, electrolyte and acid-base balance. The collecting duct is the final common path through which urine flows before entering the ureter and then emptying into the bladder. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_EPITHELIUM_DEVELOPMENT
Systematic name | M10744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an epithelium in the metanephros over time, from its formation to the mature structure. An epithelium is a tissue that covers the internal or external surfaces of an anatomical structure. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_NEPHRON_DEVELOPMENT
Systematic name | M13904
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a nephron in the metanephros over time, from its formation to the mature structure. A nephron is the functional unit of the kidney. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_REGULATION_OF_METANEPHROS_DEVELOPMENT
Systematic name | M14618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of metanephros development. Metanephros development is the process whose specific outcome is the progression of the metanephros over time, from its formation to the mature structure. The metanephros is an endocrine and metabolic organ that filters the blood and excretes the end products of body metabolism in the form of urine. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_METANEPHROS_DEVELOPMENT
Systematic name | M10231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of metanephros development. Metanephros development is the process whose specific outcome is the progression of the metanephros over time, from its formation to the mature structure. The metanephros is an organ that filters the blood and excretes the end products of body metabolism in the form of urine. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_METANEPHROS_DEVELOPMENT
Systematic name | M24564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of metanephros development. Metanephros development is the process whose specific outcome is the progression of the metanephros over time, from its formation to the mature structure. The metanephros is an organ that filters the blood and excretes the end products of body metabolism in the form of urine. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_GLOMERULAR_MESANGIUM_DEVELOPMENT
Systematic name | M24565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the metanephric glomerular mesangium over time, from its formation to the mature structure. The metanephric glomerular mesangium is the thin membrane connective tissue composed of mesangial cells in the metanephros, which helps to support the capillary loops in a renal glomerulus. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_GLOMERULUS_DEVELOPMENT
Systematic name | M24566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the metanephric glomerulus over time from its initial formation until its mature state. The metanephric glomerulus is a capillary tuft which forms a close network with the visceral epithelium (podocytes) and the mesangium to form the filtration barrier and is surrounded by Bowman's capsule in nephrons of the mature vertebrate kidney, or metanephros. [GOC:mah]
Full description |

Standard name | GO_METANEPHRIC_DISTAL_TUBULE_DEVELOPMENT
Systematic name | M24567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the metanephric distal tubule over time, from its formation to the mature structure. The metanephric distal tubule is a metanephric nephron tubule that begins at the metanephric macula densa and extends to the metanephric connecting tubule. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_LOOP_OF_HENLE_DEVELOPMENT
Systematic name | M24568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the metanephric loop of Henle over time, from its formation to the mature structure. The metanephric loop of Henle is a metanephric nephron tubule that connects the proximal convoluted tubule to the distal convoluted tubule in the metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_GLOMERULUS_VASCULATURE_DEVELOPMENT
Systematic name | M24569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The biological process whose specific outcome is the progression of a metanephric glomerulus vasculature from an initial condition to its mature state. This process begins with the formation of the metanephric glomerulus vasculature and ends with the mature structure. The metanephric glomerulus vasculature is composed of the tubule structures that carry blood or lymph in the metanephric glomerulus. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_NEPHRON_EPITHELIUM_DEVELOPMENT
Systematic name | M24570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the metanephric nephron epithelium over time, from its formation to the mature structure. An epithelium is a tissue that covers the internal or external surfaces of an anatomical structure. The metanephric nephron epithelium is a tissue that covers the surface of a nephron in the metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_NEPHRON_TUBULE_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M24571
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which relatively unspecialized cells acquire specialized structural and/or functional features that characterize the cells of the metanephric nephron tubule as it progresses from its formation to the mature state. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_NEPHRON_MORPHOGENESIS
Systematic name | M10135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the metanephric nephron are generated and organized. A metanephric nephron is the functional unit of the metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_NEPHRON_TUBULE_MORPHOGENESIS
Systematic name | M24572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a metanephric nephron tubule are generated and organized. A metanephric nephron tubule is an epithelial tube that is part of the metanephric nephron, the functional part of the metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_RENAL_VESICLE_MORPHOGENESIS
Systematic name | M12849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the metanephric renal vesicle are generated and organized. The renal vesicle is the primordial structure of the metanephric nephron epithelium, and is formed by the condensation of mesenchymal cells. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_METANEPHRIC_S_SHAPED_BODY_MORPHOGENESIS
Systematic name | M24573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the metanephric S-shaped body is generated and organized. The metanephric S-shaped body is the successor of the metanephric comma-shaped body that contributes to the morphogenesis of a nephron in the metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_REGULATION_OF_METANEPHRIC_GLOMERULUS_DEVELOPMENT
Systematic name | M24574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of metanephric glomerulus development, the progression of the metanephric glomerulus over time from its initial formation until its mature state. The metanephric glomerulus is a capillary tuft surrounded by Bowman's capsule in nephrons of the vertebrate kidney, or metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_METANEPHRIC_GLOMERULUS_DEVELOPMENT
Systematic name | M24575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of metanephric glomerulus development, the progression of the metanephric glomerulus over time from its initial formation until its mature state. The metanephric glomerulus is a capillary tuft surrounded by Bowman's capsule in nephrons of the vertebrate kidney, or metanephros. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_GLOMERULAR_EPITHELIAL_CELL_DEVELOPMENT
Systematic name | M24576
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a glomerular epithelial cell over time, from its formation to the mature structure. Glomerular epithelial cells are specialized epithelial cells that form part of the glomerulus; there are two types, glomerular parietal epithelial cells and glomerular visceral epithelial cells. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_GLOMERULAR_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M24577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a glomerular epithelial cell. Glomerular epithelial cells are specialized epithelial cells that form part of the glomerulus; there are two types, glomerular parietal epithelial cells and glomerular visceral epithelial cells. [GOC:mtg_kidney_jan10]
Full description |

Standard name | GO_VESICLE_UNCOATING
Systematic name | M24578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein depolymerization process that results in the disassembly of vesicle coat proteins. [GOC:mah]
Full description |

Standard name | GO_CHAPERONE_MEDIATED_PROTEIN_TRANSPORT
Systematic name | M24579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of proteins into, out of or within a cell, or between cells, mediated by chaperone molecules that bind to the transported proteins. [GOC:mah, PMID:20378773]
Full description |

Standard name | GO_MONOCARBOXYLIC_ACID_CATABOLIC_PROCESS
Systematic name | M15447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of monocarboxylic acids, any organic acid containing one carboxyl (-COOH) group. [GOC:mah]
Full description |

Standard name | GO_MONOCARBOXYLIC_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M14020
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of monocarboxylic acids, any organic acid containing one carboxyl (-COOH) group. [GOC:mah]
Full description |

Standard name | GO_SIGNAL_TRANSDUCTION_BY_P53_CLASS_MEDIATOR
Systematic name | M14109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An intracellular signaling process that is induced by the cell cycle regulator phosphoprotein p53 or an equivalent protein. [GOC:mah]
Full description |

Standard name | GO_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_BY_P53_CLASS_MEDIATOR
Systematic name | M15049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway is induced by the cell cycle regulator phosphoprotein p53, or an equivalent protein, and ends when the execution phase of apoptosis is triggered. [GOC:mah, GOC:mtg_apoptosis]
Full description |

Standard name | GO_MODIFIED_AMINO_ACID_TRANSPORT
Systematic name | M10877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of modified amino acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_RESCUE_OF_STALLED_RIBOSOME
Systematic name | M29279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process of translational elongation that takes place when a ribosome has stalled during translation, and results in freeing the ribosome from the stalled translation complex. [GOC:jh2, GOC:mah, PMID:18557701, PMID:19170872, PMID:20117091, PMID:20185543]
Full description |

Standard name | GO_SULFUR_COMPOUND_TRANSPORT
Systematic name | M13590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of compounds that contain sulfur, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:mah]
Full description |

Standard name | GO_TRICARBOXYLIC_ACID_METABOLIC_PROCESS
Systematic name | M13081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving dicarboxylic acids, any organic acid containing three carboxyl (COOH) groups or anions (COO-). [GOC:mah]
Full description |

Standard name | GO_CIRCULATORY_SYSTEM_DEVELOPMENT
Systematic name | M16442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the circulatory system over time, from its formation to the mature structure. The circulatory system is the organ system that passes nutrients (such as amino acids and electrolytes), gases, hormones, blood cells, etc. to and from cells in the body to help fight diseases and help stabilize body temperature and pH to maintain homeostasis. [GOC:mah, UBERON:0001009]
Full description |

Standard name | GO_PROTEIN_ACTIVATION_CASCADE
Systematic name | M10315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A response to a stimulus that consists of a sequential series of modifications to a set of proteins where the product of one reaction acts catalytically in the following reaction. The magnitude of the response is typically amplified at each successive step in the cascade. Modifications typically include proteolysis or covalent modification, and may also include binding events. [GOC:add, GOC:mah, GOC:pde]
Full description |

Standard name | GO_ORGANELLE_TRANSPORT_ALONG_MICROTUBULE
Systematic name | M11482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of an organelle along a microtubule, mediated by motor proteins. This process begins with the attachment of an organelle to a microtubule, and ends when the organelle reaches its final destination. [GOC:mah]
Full description |

Standard name | GO_MINUS_END_DIRECTED_ORGANELLE_TRANSPORT_ALONG_MICROTUBULE
Systematic name | M24582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of an organelle towards the minus end of a microtubule, mediated by motor proteins. This process begins with the attachment of an organelle to a microtubule, and ends when the organelle reaches its final destination. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_PLUS_END_DIRECTED_ORGANELLE_TRANSPORT_ALONG_MICROTUBULE
Systematic name | M24583
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of an organelle towards the plus end of a microtubule, mediated by motor proteins. This process begins with the attachment of an organelle to a microtubule, and ends when the organelle reaches its final destination. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_MICROTUBULE_ANCHORING_AT_MICROTUBULE_ORGANIZING_CENTER
Systematic name | M24584
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a microtubule is maintained in a specific location in a cell by attachment to a microtubule organizing center. [GOC:BHF, PMID:19825938]
Full description |

Standard name | GO_SIGNAL_TRANSDUCTION_INVOLVED_IN_CELL_CYCLE_CHECKPOINT
Systematic name | M24585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A signal transduction process that contributes to a cell cycle checkpoint. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_RESPONSE_TO_CELL_CYCLE_CHECKPOINT_SIGNALING
Systematic name | M24586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that occurs in response to signals generated as a result of cell cycle checkpoint signaling. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_SIGNAL_TRANSDUCTION_INVOLVED_IN_G2_DNA_DAMAGE_CHECKPOINT
Systematic name | M24587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A signal transduction process that contributes to a G2/M transition DNA damage checkpoint. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_MESENCHYMAL_STEM_CELL_DIFFERENTIATION
Systematic name | M24588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a mesenchymal stem cell. A mesenchymal stem cell is a cell that retains the ability to divide and proliferate throughout life to provide progenitor cells that can differentiate into specialized mesenchymal cells. [CL:0002452, GOC:BHF]
Full description |

Standard name | GO_EMBRYONIC_SKELETAL_JOINT_DEVELOPMENT
Systematic name | M14009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process, occurring during the embryonic phase, whose specific outcome is the progression of the skeletal joints over time, from formation to mature structure. [GOC:BHF, GOC:vk]
Full description |

Standard name | GO_CELLULAR_DIVALENT_INORGANIC_ANION_HOMEOSTASIS
Systematic name | M24589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of divalent inorganic anions at the level of a cell. [GOC:mah]
Full description |

Standard name | GO_DIVALENT_INORGANIC_ANION_HOMEOSTASIS
Systematic name | M15314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of divalent inorganic anions within an organism or cell. [GOC:mah]
Full description |

Standard name | GO_DIVALENT_INORGANIC_CATION_HOMEOSTASIS
Systematic name | M14129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of divalent cations within an organism or cell. [GOC:mah]
Full description |

Standard name | GO_DIVALENT_INORGANIC_CATION_TRANSPORT
Systematic name | M16925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of inorganic cations with a valency of two into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Inorganic cations are atoms or small molecules with a positive charge which do not contain carbon in covalent linkage. [GOC:mah]
Full description |

Standard name | GO_SEMINIFEROUS_TUBULE_DEVELOPMENT
Systematic name | M24590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The reproductive developmental process whose specific outcome is the progression of the seminiferous tubule over time, from its formation to the mature structure. Seminiferous tubules are ducts located in the testicles, and are the specific location of meiosis, and the subsequent creation of gametes, namely spermatozoa. [GOC:BHF, GOC:mah, UBERON:0001343]
Full description |

Standard name | GO_PURINE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M15746
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a purine-containing compound, i.e. any compound that contains purine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_PURINE_CONTAINING_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M13246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a purine-containing compound, i.e. any compound that contains purine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_PURINE_CONTAINING_COMPOUND_CATABOLIC_PROCESS
Systematic name | M15874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a purine-containing compound, i.e. any compound that contains purine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_PYRIDINE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M24591
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a pyridine-containing compound, i.e. any compound that contains pyridine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_PYRIDINE_CONTAINING_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M34245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a pyridine-containing compound, i.e. any compound that contains pyridine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_PYRIDINE_CONTAINING_COMPOUND_CATABOLIC_PROCESS
Systematic name | M29280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a pyridine-containing compound, i.e. any compound that contains pyridine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_PYRIMIDINE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M13768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a pyrimidine-containing compound, i.e. any compound that contains pyrimidine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_PYRIMIDINE_CONTAINING_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M16659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a pyrimidine-containing compound, i.e. any compound that contains pyrimidine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_PYRIMIDINE_CONTAINING_COMPOUND_CATABOLIC_PROCESS
Systematic name | M12076
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a pyrimidine-containing compound, i.e. any compound that contains pyrimidine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_PURINE_CONTAINING_COMPOUND_TRANSMEMBRANE_TRANSPORT
Systematic name | M24592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a purine-containing compound is transported across a membrane. A purine-containing compound is any compound that contains purine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_PYRIMIDINE_CONTAINING_COMPOUND_TRANSMEMBRANE_TRANSPORT
Systematic name | M14712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a pyrimidine-containing compound is transported across a membrane. A pyrimidine-containing compound is any compound that contains pyrimidine or a formal derivative thereof. [GOC:mah]
Full description |

Standard name | GO_FIBROBLAST_ACTIVATION
Systematic name | M24593
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in the morphology or behavior of a fibroblast resulting from exposure to an activating factor such as a cellular or soluble ligand. [CL:0000057, GOC:BHF, GOC:mah]
Full description |

Standard name | GO_T_HELPER_17_TYPE_IMMUNE_RESPONSE
Systematic name | M24594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An immune response which is associated with resistance to intracellular bacteria with a key role in inflammation and tissue injury. This immune response is associated with pathological autoimmune conditions such as multiple sclerosis, arthritis and psoriasis which is typically orchestrated by the production of particular cytokines by T-helper 17 cells, most notably interleukin-17, IL-21 and IL-22. [GOC:BHF, GOC:ebc]
Full description |

Standard name | GO_T_HELPER_17_CELL_LINEAGE_COMMITMENT
Systematic name | M24595
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a CD4-positive, alpha-beta T cell becomes committed to becoming a T-helper 17 cell, a CD4-positive, alpha-beta T cell with the phenotype RORgamma-t-positive that produces IL-17. [CL:0000899, GOC:BHF, GOC:ebc]
Full description |

Standard name | GO_TERMINAL_BUTTON_ORGANIZATION
Systematic name | M24596
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a terminal button. A terminal button is the terminal inflated portion of the axon, containing the specialized apparatus necessary to release neurotransmitters. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_CHEMOKINE_C_X_C_MOTIF_LIGAND_1_PRODUCTION
Systematic name | M34246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of chemokine (C-X-C motif) ligand 1 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_CHEMOKINE_C_X_C_MOTIF_LIGAND_2_PRODUCTION
Systematic name | M24597
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of chemokine (C-X-C motif) ligand 2 due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_LIVER_MORPHOGENESIS
Systematic name | M24598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of the liver are generated and organized. [GOC:mah]
Full description |

Standard name | GO_ENDOTHELIAL_CELL_APOPTOTIC_PROCESS
Systematic name | M24599
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in an endothelial cell. An endothelial cell comprises the outermost layer or lining of anatomical structures and can be squamous or cuboidal. [CL:0000115, GOC:BHF, GOC:mah, GOC:mtg_apoptosis]
Full description |

Standard name | GO_NEUROTRANSMITTER_GATED_ION_CHANNEL_CLUSTERING
Systematic name | M24600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The receptor clustering process in which neurotransmitter-gated ion channels are localized to distinct domains in the cell membrane. [GOC:dsf, PMID:20843816]
Full description |

Standard name | GO_CLATHRIN_DEPENDENT_ENDOCYTOSIS
Systematic name | M24601
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An endocytosis process that begins when material is taken up into clathrin-coated pits, which then pinch off to form clathrin-coated endocytic vesicles. [GOC:BHF, GOC:mah, PMID:18498251, PMID:8970738, PMID:9234965]
Full description |

Standard name | GO_CAVEOLIN_MEDIATED_ENDOCYTOSIS
Systematic name | M24602
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An endocytosis process that begins when material is taken up into plasma membrane caveolae, which then pinch off to form endocytic caveolar carriers. [GOC:BHF, GOC:mah, PMID:17318224, PMID:18498251, PMID:8970738, PMID:9234965]
Full description |

Standard name | GO_OXYGEN_METABOLIC_PROCESS
Systematic name | M24603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving diatomic oxygen (O2). [GOC:mah]
Full description |

Standard name | GO_REACTIVE_OXYGEN_SPECIES_METABOLIC_PROCESS
Systematic name | M15990
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a reactive oxygen species, any molecules or ions formed by the incomplete one-electron reduction of oxygen. They contribute to the microbicidal activity of phagocytes, regulation of signal transduction and gene expression, and the oxidative damage to biopolymers. [GOC:mah]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_ORGANELLE
Systematic name | M11490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein to a specific location on or in an organelle. Encompasses establishment of localization in the membrane or lumen of a membrane-bounded organelle. [GOC:mah]
Full description |

Standard name | GO_MAINTENANCE_OF_PROTEIN_LOCALIZATION_IN_ORGANELLE
Systematic name | M13203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is maintained in a specific location a specific location on or in an organelle, and is prevented from moving elsewhere. Encompasses establishment of localization in the membrane or lumen of a membrane-bounded organelle. [GOC:mah]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_ENDOPLASMIC_RETICULUM
Systematic name | M11209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein to a specific location in the endoplasmic reticulum. [GOC:mah]
Full description |

Standard name | GO_MAINTENANCE_OF_PROTEIN_LOCATION_IN_MITOCHONDRION
Systematic name | M24614
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is maintained in a specific location in a mitochondrion, and is prevented from moving elsewhere. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_MEMBRANE
Systematic name | M12431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a specific location in a membrane. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_PLASMA_MEMBRANE
Systematic name | M24615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a specific location in the plasma membrane. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_VACUOLE
Systematic name | M12847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained at, a location in a vacuole. [GOC:ecd]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_VACUOLE
Systematic name | M14603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein to a specific location in a vacuole. [GOC:mah]
Full description |

Standard name | GO_NEUTROPHIL_EXTRAVASATION
Systematic name | M24616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The migration of a neutrophil from the blood vessels into the surrounding tissue. [CL:0000775, GOC:BHF]
Full description |

Standard name | GO_LAMELLIPODIUM_MORPHOGENESIS
Systematic name | M24617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level and in which the structure of a lamellipodium is organized. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_MULTINUCLEAR_OSTEOCLAST_DIFFERENTIATION
Systematic name | M24618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized monocyte acquires the specialized features of a multinuclear osteoclast. An osteoclast is a specialized phagocytic cell associated with the absorption and removal of the mineralized matrix of bone tissue. [CL:0000779, GOC:mah, PMID:12713016]
Full description |

Standard name | GO_OSTEOCLAST_FUSION
Systematic name | M24619
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The plasma membrane fusion process that results in fusion of mononuclear osteoclasts to form a multinuclear osteoclast. [CL:0000092, CL:0000779, GOC:BHF, GOC:mah, PMID:12713016]
Full description |

Standard name | GO_LYMPHOCYTE_MIGRATION
Systematic name | M15399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a lymphocyte within or between different tissues and organs of the body. [CL:0000542, GOC:BHF, GOC:mah]
Full description |

Standard name | GO_EOSINOPHIL_MIGRATION
Systematic name | M24620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of an eosinophil within or between different tissues and organs of the body. [CL:0000771, GOC:BHF, GOC:mah]
Full description |

Standard name | GO_T_CELL_MIGRATION
Systematic name | M14198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a T cell within or between different tissues and organs of the body. [CL:0000084, GOC:BHF, GOC:mah]
Full description |

Standard name | GO_THYMOCYTE_MIGRATION
Systematic name | M24621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a thymocyte through distinct intrathymic niches (e.g. medulla, cortex), where it receives a unique set of developmental cues required for T-cell development. [CL:0000893, GOC:BHF, GOC:mah]
Full description |

Standard name | GO_T_CELL_EXTRAVASATION
Systematic name | M24622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The migration of a T cell from the blood vessels into the surrounding tissue. [CL:0000084, GOC:BHF, GOC:mah]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CELL_CORTEX
Systematic name | M24623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, the cell cortex. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_SORBITOL
Systematic name | M24624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a sorbitol stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_HYDROXYUREA
Systematic name | M24625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydroxyurea stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_CISPLATIN
Systematic name | M24626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cisplatin stimulus. [GOC:mah]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_CISPLATIN
Systematic name | M24627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cisplatin stimulus. [GOC:mah]
Full description |

Standard name | GO_RESPONSE_TO_STAUROSPORINE
Systematic name | M24628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a staurosporine stimulus. [GOC:mah]
Full description |

Standard name | GO_MODULATION_BY_SYMBIONT_OF_HOST_AUTOPHAGY
Systematic name | M24629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a symbiont organism modulates the frequency, rate or extent of autophagy in the host cell. The host is defined as the larger of the organisms involved in a symbiotic interaction. [GOC:pamgo_curators]
Full description |

Standard name | GO_POSITIVE_REGULATION_BY_SYMBIONT_OF_ENTRY_INTO_HOST
Systematic name | M34247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent to which it enters into the host organism, where the two organisms are in a symbiotic interaction. [GOC:pamgo_curators]
Full description |

Standard name | GO_ENDOCYTOSIS_INVOLVED_IN_VIRAL_ENTRY_INTO_HOST_CELL
Systematic name | M34248
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any endocytosis that is involved in the uptake of a virus into a host cell. [GOC:bf, GOC:jl, VZ:977]
Full description |

Standard name | GO_IRES_DEPENDENT_VIRAL_TRANSLATIONAL_INITIATION
Systematic name | M24630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Process by which viral mRNA translation is initiated, where a domain in the 5' untranslated region (UTR) of the viral mRNA called an internal ribosome entry site (IRES) binds the host 43S preinitiation complex, circumventing regular cap-dependent translation initiation. [GOC:bf, GOC:jl, PMID:19632368, VZ:867]
Full description |

Standard name | GO_VIRAL_TRANSLATIONAL_TERMINATION_REINITIATION
Systematic name | M24631
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process which occurs as part of viral mRNA translation which allows expression of a downstream open reading frame (ORF) in a dicistronic mRNA. In this process, ribosomes translate the upstream ORF but following termination, a proportion of 40S subunits remain tethered to the mRNA and go on to re-initiate translation at the start codon of the downstream ORF. [GOC:bf, GOC:ch, GOC:jl, PMID:18631147, PMID:18824510, VZ:858]
Full description |

Standard name | GO_MRNA_METHYLATION
Systematic name | M24632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The posttranscriptional addition of methyl groups to specific residues in an mRNA molecule. [PMID:18505803]
Full description |

Standard name | GO_DNA_DEMETHYLATION
Systematic name | M13249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of a methyl group from one or more nucleotides within an DNA molecule. [PMID:17208187]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_STRESS
Systematic name | M13345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a response to stress. Response to stress is a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a disturbance in organismal or cellular homeostasis, usually, but not necessarily, exogenous (e.g. temperature, humidity, ionizing radiation). [GOC:dhl]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_RESPONSE_TO_STRESS
Systematic name | M14850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a cellular response to stress. Cellular response to stress is a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating the organism is under stress. The stress is usually, but not necessarily, exogenous (e.g. temperature, humidity, ionizing radiation). [GOC:dhl]
Full description |

Standard name | GO_AMINO_ACID_HOMEOSTASIS
Systematic name | M29282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of an internal steady state of amino acid within an organism or cell. [PMID:19955263]
Full description |

Standard name | GO_REGULATION_OF_FERTILIZATION
Systematic name | M24633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of fertilization. Fertilization is the union of gametes of opposite sexes during the process of sexual reproduction to form a zygote. It involves the fusion of the gametic nuclei (karyogamy) and cytoplasm (plasmogamy). [GOC:DHL, PMID:20478994]
Full description |

Standard name | GO_LYTIC_VACUOLE_ORGANIZATION
Systematic name | M14989
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a lytic vacuole. [PMID:20729380]
Full description |

Standard name | GO_HISTONE_H3_K4_TRIMETHYLATION
Systematic name | M14986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of three methyl groups to lysine at position 4 of the histone. [GOC:BHF, GOC:se, GOC:tb]
Full description |

Standard name | GO_RESPONSE_TO_PHENYLPROPANOID
Systematic name | M11066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as the result of a phenylpropanoid stimulus. The process begins with detection of the stimulus and ends with a change in state or activity or the cell or organism. A phenylpropanoid is any of secondary metabolites with structures based on a phenylpropane skeleton. The class includes phenylpropanoid esters, flavonoids, anthocyanins, coumarins and many small phenolic molecules. Phenylpropanoids are also precursors of lignin. [GOC:tb]
Full description |

Standard name | GO_PROTEIN_K6_LINKED_UBIQUITINATION
Systematic name | M24634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein ubiquitination process in which a polymer of ubiquitin, formed by linkages between lysine residues at position 6 of the ubiquitin monomers, is added to a protein. K6-linked ubiquitination is involved in DNA repair. [GOC:sp]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX_ASSEMBLY
Systematic name | M11366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of the extracellular matrix. [GOC:jl]
Full description |

Standard name | GO_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M14476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An action potential that occurs in a cardiac muscle cell. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL_INVOLVED_IN_CONTRACTION
Systematic name | M24635
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An action potential that occurs in a cardiac muscle cell and is involved in its contraction. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_CARDIAC_MUSCLE_CELL_CONTRACTION
Systematic name | M13694
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The actin filament-based process in which cytoplasmic actin filaments slide past one another resulting in contraction of a cardiac muscle cell. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_VENTRICULAR_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M14176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An action potential that occurs in a ventricular cardiac muscle cell. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_MEMBRANE_REPOLARIZATION
Systematic name | M15960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which ions are transported across a membrane such that the membrane potential changes in the repolarizing direction, toward the steady state potential. For example, the repolarization during an action potential is from a positive membrane potential towards a negative resting potential. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_MEMBRANE_DEPOLARIZATION_DURING_ACTION_POTENTIAL
Systematic name | M10863
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which membrane potential changes in the depolarizing direction from the negative resting potential towards the positive membrane potential that will be the peak of the action potential. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_MEMBRANE_REPOLARIZATION_DURING_ACTION_POTENTIAL
Systematic name | M24636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which ions are transported across a membrane such that the membrane potential changes in the direction from the positive membrane potential at the peak of the action potential towards the negative resting potential. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_MEMBRANE_DEPOLARIZATION_DURING_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M13463
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which cardiac muscle cell membrane potential changes in the depolarizing direction from the negative resting potential towards the positive membrane potential that will be the peak of the action potential. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_CELL_CELL_SIGNALING_INVOLVED_IN_CARDIAC_CONDUCTION
Systematic name | M13356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that mediates the transfer of information from one cell to another and contributes to the heart process that regulates cardiac muscle contraction; beginning with the generation of an action potential in the sinoatrial node and ending with regulation of contraction of the myocardium. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_ACTIVATING_ADRENERGIC_RECEPTOR_SIGNALING_PATHWAY_INVOLVED_IN_HEART_PROCESS
Systematic name | M24637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals beginning with a G protein-coupled adrenergic cell surface receptor combining with epinephrine or norepinephrine, to activate adenylate cyclase, which contributes to a circulatory system process carried out by the heart. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_ATRIAL_CARDIAC_MUSCLE_CELL_TO_AV_NODE_CELL_SIGNALING
Systematic name | M24638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that mediates the transfer of information from an atrial cardiomyocyte to an AV node cell. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_BUNDLE_OF_HIS_CELL_TO_PURKINJE_MYOCYTE_SIGNALING
Systematic name | M24639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that mediates the transfer of information from a bundle of His cardiomyocyte to a Purkinje myocyte. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_PURKINJE_MYOCYTE_TO_VENTRICULAR_CARDIAC_MUSCLE_CELL_SIGNALING
Systematic name | M24640
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that mediates the transfer of information from a Purkinje myocyte to a ventricular cardiac muscle cell. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_CELL_MEMBRANE_POTENTIAL
Systematic name | M24641
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the establishment or extent of a membrane potential in a cardiac muscle cell (a cardiomyocyte). A membrane potential is the electric potential existing across any membrane arising from charges in the membrane itself and from the charges present in the media on either side of the membrane. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_CARDIAC_MUSCLE_CELL_CARDIAC_MUSCLE_CELL_ADHESION
Systematic name | M24642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of one cardiomyocyte to another cardiomyocyte via adhesion molecules. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_MEMBRANE_DEPOLARIZATION_DURING_AV_NODE_CELL_ACTION_POTENTIAL
Systematic name | M24643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which AV node cardiac muscle cell membrane potential changes in the depolarizing direction from the negative resting potential towards the positive membrane potential that will be the peak of the action potential. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_MEMBRANE_DEPOLARIZATION_DURING_SA_NODE_CELL_ACTION_POTENTIAL
Systematic name | M24644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which SA node cardiac muscle cell membrane potential changes in the depolarizing direction from the negative resting potential towards the positive membrane potential that will be the peak of the action potential. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_CELL_COMMUNICATION_BY_ELECTRICAL_COUPLING_INVOLVED_IN_CARDIAC_CONDUCTION
Systematic name | M24645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that mediates signaling interactions between one cell and another cell by transfer of current between their adjacent cytoplasms via intercellular protein channels and contributes to the process of cardiac conduction. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_CELL_COMMUNICATION_INVOLVED_IN_CARDIAC_CONDUCTION
Systematic name | M12906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that mediates interactions between a cell and its surroundings that contributes to the process of cardiac conduction. Encompasses interactions such as signaling or attachment between one cell and another cell, between a cell and an extracellular matrix, or between a cell and any other aspect of its environment. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_AV_NODE_CELL_TO_BUNDLE_OF_HIS_CELL_COMMUNICATION
Systematic name | M24646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that mediates interactions between an AV node cell and its surroundings that contributes to the process of the AV node cell communicating with a bundle of His cell in cardiac conduction. Encompasses interactions such as signaling or attachment between one cell and another cell, between a cell and an extracellular matrix, or between a cell and any other aspect of its environment. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_BUNDLE_OF_HIS_CELL_TO_PURKINJE_MYOCYTE_COMMUNICATION
Systematic name | M10299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that mediates interactions between a bundle of His cell and its surroundings that contributes to the process of the bundle of His cell communicating with a Purkinje myocyte in cardiac conduction. Encompasses interactions such as signaling or attachment between one cell and another cell, between a cell and an extracellular matrix, or between a cell and any other aspect of its environment. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_SA_NODE_CELL_TO_ATRIAL_CARDIAC_MUSCLE_CELL_COMMUNICATION
Systematic name | M24647
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that mediates interactions between an SA node cardiomyocyte and its surroundings that contributes to the process of the SA node cardiomyocyte communicating with an atrial cardiomyocyte in cardiac conduction. Encompasses interactions such as signaling or attachment between one cell and another cell, between a cell and an extracellular matrix, or between a cell and any other aspect of its environment. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_REGULATION_OF_HEART_RATE_BY_CARDIAC_CONDUCTION
Systematic name | M14420
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cardiac conduction process that modulates the frequency or rate of heart contraction. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_ENDOTHELIN_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M34249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by an endothelin receptor binding to one of its physiological ligands, and proceeding with the activated receptor promoting the exchange of GDP for GTP on the alpha-subunit of an associated heterotrimeric G-protein complex. Ends with regulation of a downstream cellular process, e.g. transcription. [GOC:bf, GOC:BHF, GOC:mtg_cardiac_conduct_nov11, PMID:10977869]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY_INVOLVED_IN_HEART_PROCESS
Systematic name | M24648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An G protein-coupled receptor signaling pathway which contributes to a circulatory system process carried out by the heart. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11, PMID:17376402]
Full description |

Standard name | GO_L_HISTIDINE_TRANSMEMBRANE_TRANSPORT
Systematic name | M34250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-histidine across a membrane. [PMID:21307582]
Full description |

Standard name | GO_PRIMITIVE_STREAK_FORMATION
Systematic name | M11065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process pertaining to the initial formation of the primitive streak from unspecified parts. The primitive streak is a ridge of cells running along the midline of the embryo where the mesoderm ingresses. It defines the anterior-posterior axis. [GOC:dph, GOC:sdb_2009, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_NEUTROPHIL_CHEMOTAXIS
Systematic name | M29283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of neutrophil chemotaxis. Neutrophil chemotaxis is the directed movement of a neutrophil cell, the most numerous polymorphonuclear leukocyte found in the blood, in response to an external stimulus, usually an infection or wounding. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MONOCYTE_CHEMOTAXIS
Systematic name | M16721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of monocyte chemotaxis. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MONOCYTE_CHEMOTAXIS
Systematic name | M16250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate, or extent of monocyte chemotaxis. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MONOCYTE_CHEMOTAXIS
Systematic name | M24649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate, or extent of monocyte chemotaxis. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_STEROID_HORMONE_BIOSYNTHETIC_PROCESS
Systematic name | M24650
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of steroid hormones,compounds with a 1, 2, cyclopentanoperhydrophenanthrene nucleus that act as hormones. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_KINASE_C_SIGNALING
Systematic name | M14848
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of a series of reactions, mediated by the intracellular serine/threonine kinase protein kinase C, which occurs as a result of a single trigger reaction or compound. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_KINASE_C_SIGNALING
Systematic name | M24651
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate, or extent of a series of reactions, mediated by the intracellular serine/threonine kinase protein kinase C, which occurs as a result of a single trigger reaction or compound. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_TUBULIN_DEACETYLATION
Systematic name | M24652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of an acetyl group from tubulin. An acetyl group is CH3CO-, derived from acetic [ethanoic] acid. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TUBULIN_DEACETYLATION
Systematic name | M24653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of tubulin deacetylation. Tubulin deacetylation is the removal of an acetyl group from a protein amino acid. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DEACETYLASE_ACTIVITY
Systematic name | M24654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of deacetylase activity, the catalysis of the hydrolysis of an acetyl group or groups from a substrate molecule. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CELL_MIGRATION_INVOLVED_IN_SPROUTING_ANGIOGENESIS
Systematic name | M12982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell migration involved in sprouting angiogenesis. Cell migration involved in sprouting angiogenesis is the orderly movement of endothelial cells into the extracellular matrix in order to form new blood vessels contributing to the process of sprouting angiogenesis. [GOC:BHF, GOC:dph, GOC:rl, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_MIGRATION_INVOLVED_IN_SPROUTING_ANGIOGENESIS
Systematic name | M24655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of cell migration involved in sprouting angiogenesis. Cell migration involved in sprouting angiogenesis is the orderly movement of endothelial cells into the extracellular matrix in order to form new blood vessels contributing to the process of sprouting angiogenesis. [GOC:BHF, GOC:dph, GOC:rl, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_MIGRATION_INVOLVED_IN_SPROUTING_ANGIOGENESIS
Systematic name | M24656
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of cell migration involved in sprouting angiogenesis. Cell migration involved in sprouting angiogenesis is the orderly movement of endothelial cells into the extracellular matrix in order to form new blood vessels contributing to the process of sprouting angiogenesis. [GOC:BHF, GOC:dph, GOC:rl, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MICROTUBULE_NUCLEATION
Systematic name | M34251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of microtubule nucleation. Microtubule nucleation is the 'de novo' formation of a microtubule, in which tubulin heterodimers form metastable oligomeric aggregates, some of which go on to support formation of a complete microtubule. Microtubule nucleation usually occurs from a specific site within a cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_ANATOMICAL_STRUCTURE_SIZE
Systematic name | M12279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the size of an anatomical structure. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_CYCLE_PROCESS
Systematic name | M13340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of a cellular process that is involved in the progression of biochemical and morphological phases and events that occur in a cell during successive cell replication or nuclear replication events. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_RIBOSOME_BIOGENESIS
Systematic name | M24657
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of ribosome biogenesis. Ribosome biogenesis is the cellular process that results in the biosynthesis of constituent macromolecules, assembly, and arrangement of constituent parts of ribosome subunits. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RIBOSOME_BIOGENESIS
Systematic name | M24658
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of ribosome biogenesis. Ribosome biogenesis is the cellular process that results in the biosynthesis of constituent macromolecules, assembly, and arrangement of constituent parts of ribosome subunits. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RIBOSOME_BIOGENESIS
Systematic name | M34252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of ribosome biogenesis. Ribosome biogenesis is the cellular process that results in the biosynthesis of constituent macromolecules, assembly, and arrangement of constituent parts of ribosome subunits. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_RELAXATION_OF_MUSCLE
Systematic name | M13236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which the extent of muscle contraction is reduced. Muscle relaxation can involve a number of processes including the removal of calcium from the cytoplasm to the sarcoplasmic reticulum lumen through the action of Ca2+ ATPases. In some muscles, calcium-independent pathways also play a role in muscle relaxation by decreasing the phosphorylation state of myosin light chain. [GOC:BHF, GOC:rl, PMID:19996365]
Full description |

Standard name | GO_FOAM_CELL_DIFFERENTIATION
Systematic name | M24660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a foam cell. A foam cell is a type of cell containing lipids in small vacuoles and typically seen in atherosclerotic lesions, as well as other conditions. [GOC:add, GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MAPKKK_CASCADE_BY_FIBROBLAST_GROWTH_FACTOR_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24661
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of molecular signals generated as a consequence of a fibroblast growth factor receptor binding to one of its physiological ligands resulting in an increase in the rate or frequency of a MAPKKK cascade. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_INCLUSION_BODY_ASSEMBLY
Systematic name | M13842
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of inclusion body assembly. Inclusion body assembly is the aggregation, arrangement and bonding together of a set of components to form an inclusion body. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INCLUSION_BODY_ASSEMBLY
Systematic name | M24662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of inclusion body assembly. Inclusion body assembly is the aggregation, arrangement and bonding together of a set of components to form an inclusion body. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_DEUBIQUITINATION
Systematic name | M24663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein deubiquitination. Protein deubiquitination is the removal of one or more ubiquitin groups from a protein. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDE_TRANSPORT
Systematic name | M34253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the directed movement of peptides, compounds of two or more amino acids where the alpha carboxyl group of one is bound to the alpha amino group of another, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CANONICAL_WNT_SIGNALING_PATHWAY
Systematic name | M29284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of the Wnt signaling pathway through beta-catenin, the series of molecular signals initiated by binding of a Wnt protein to a frizzled family receptor on the surface of the target cell, followed by propagation of the signal via beta-catenin, and ending with a change in transcription of target genes. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EXTRACELLULAR_MATRIX_DISASSEMBLY
Systematic name | M24664
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of extracellular matrix disassembly. Extracellular matrix disassembly is a process that results in the breakdown of the extracellular matrix. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TRANSMEMBRANE_RECEPTOR_PROTEIN_SERINE_THREONINE_KINASE_SIGNALING_PATHWAY
Systematic name | M12865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the series of molecular signals generated as a consequence of a transmembrane receptor serine/threonine kinase binding to its physiological ligand. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSMEMBRANE_RECEPTOR_PROTEIN_SERINE_THREONINE_KINASE_SIGNALING_PATHWAY
Systematic name | M16041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the series of molecular signals generated as a consequence of a transmembrane receptor serine/threonine kinase binding to its physiological ligand. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSMEMBRANE_RECEPTOR_PROTEIN_SERINE_THREONINE_KINASE_SIGNALING_PATHWAY
Systematic name | M16180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of the series of molecular signals generated as a consequence of a transmembrane receptor serine/threonine kinase binding to its physiological ligand. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_COCHLEA_DEVELOPMENT
Systematic name | M14694
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The progression of the cochlea over time from its formation to the mature structure. The cochlea is the snail-shaped portion of the inner ear that is responsible for the detection of sound. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_COCHLEA_MORPHOGENESIS
Systematic name | M15060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the cochlea is generated and organized. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_COPII_COATED_VESICLE_CARGO_LOADING
Systematic name | M24665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a macromolecular complex between the COPII coat proteins and proteins and/or lipoproteins that are going to be transported by the COPII vesicle to the Golgi. [GOC:ascb_2009, GOC:dph, GOC:lb, GOC:tb]
Full description |

Standard name | GO_COPII_COATED_VESICLE_BUDDING
Systematic name | M24666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The evagination of an endoplasmic reticulum membrane, resulting in formation of a COPII-coated vesicle. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_RECEPTOR_MEDIATED_ENDOCYTOSIS_INVOLVED_IN_CHOLESTEROL_TRANSPORT
Systematic name | M24667
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A receptor-mediated endocytosis process involved in intracellular cholesterol transport. [GOC:ascb_2009, GOC:dph, GOC:pr, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SYNAPSE_MATURATION
Systematic name | M16375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the extent of synapse maturation, the process that organizes a synapse so that it attains its fully functional state. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPSE_MATURATION
Systematic name | M12810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the extent of synapse maturation, the process that organizes a synapse so that it attains its fully functional state. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_TISSUE_MIGRATION
Systematic name | M12932
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the population of cells that make up a tissue undergo directed movement. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_MESENCHYME_MIGRATION
Systematic name | M24668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the population of cells that make up a mesenchyme undergo directed movement. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_EPITHELIAL_CELL_CELL_ADHESION
Systematic name | M12249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of an epithelial cell to another epithelial cell via adhesion molecules. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRIAL_FISSION
Systematic name | M13263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of mitochondrial fission. Mitochondrial fission is the division of a mitochondrion within a cell to form two or more separate mitochondrial compartments. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOCHONDRIAL_FISSION
Systematic name | M10378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of mitochondrial fission. Mitochondrial fission is the division of a mitochondrion within a cell to form two or more separate mitochondrial compartments. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_MEMBRANE_FISSION
Systematic name | M24669
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the separation of a single continuous membrane into two membranes. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_MEMBRANE
Systematic name | M13481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein to a specific location in a membrane. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_MITOCHONDRIAL_MEMBRANE
Systematic name | M24670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein to a specific location in the mitochondrial membrane. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SPHINGOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M24671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of sphingolipid biosynthesis. Sphingolipid biosynthesis is the chemical reactions and pathways resulting in the formation of sphingolipids, any of a class of lipids containing the long-chain amine diol sphingosine or a closely related base (a sphingoid). [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SPHINGOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M24672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of sphingolipid biosynthesis. Sphingolipid biosynthesis is the chemical reactions and pathways resulting in the formation of sphingolipids, any of a class of lipids containing the long-chain amine diol sphingosine or a closely related base (a sphingoid). [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SPHINGOLIPID_BIOSYNTHETIC_PROCESS
Systematic name | M29286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of sphingolipid biosynthesis. Sphingolipid biosynthesis is the chemical reactions and pathways resulting in the formation of sphingolipids, any of a class of lipids containing the long-chain amine diol sphingosine or a closely related base (a sphingoid). [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_CELLULAR_SPHINGOLIPID_HOMEOSTASIS
Systematic name | M29287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any biological process involved in the maintenance of an internal steady state of sphingolipids at the level of the cell. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_MEMBRANE_ORGANIZATION
Systematic name | M34254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of an endoplasmic reticulum membrane. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_GOLGI_TO_LYSOSOME_TRANSPORT
Systematic name | M24673
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from the Golgi to lysosomes. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_GOLGI_RIBBON_FORMATION
Systematic name | M14362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The formation of a continuous ribbon of interconnected Golgi stacks of flat cisternae. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_ESTABLISHMENT_OF_EPITHELIAL_CELL_POLARITY
Systematic name | M10706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The specification and formation of anisotropic intracellular organization of an epithelial cell. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_GOLGI_DISASSEMBLY
Systematic name | M24674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the breakdown of a Golgi apparatus that contributes to Golgi inheritance. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SPINDLE_ASSEMBLY
Systematic name | M15257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of spindle assembly. Spindle assembly is the aggregation, arrangement and bonding together of a set of components to form the spindle, the array of microtubules and associated molecules that serves to move duplicated chromosomes apart. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_ORGANELLE_MEMBRANE_FUSION
Systematic name | M12989
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The joining of two lipid bilayers to form a single organelle membrane. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PLANAR_POLARITY_INVOLVED_IN_NEURAL_TUBE_CLOSURE
Systematic name | M24675
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Coordinated organization of groups of cells in the plane of an epithelium that contributes to the closure of the neural tube. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CHOLESTEROL_METABOLIC_PROCESS
Systematic name | M15312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of cholesterol metabolism, the chemical reactions and pathways involving cholesterol, cholest-5-en-3 beta-ol, the principal sterol of vertebrates and the precursor of many steroids, including bile acids and steroid hormones. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_KIDNEY_DEVELOPMENT
Systematic name | M12397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of kidney development. Kidney development is the process whose specific outcome is the progression of the kidney over time, from its formation to the mature structure. The kidney is an organ that filters the blood and excretes the end products of body metabolism in the form of urine. [GOC:dph, GOC:tb, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_KIDNEY_DEVELOPMENT
Systematic name | M10982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of kidney development. Kidney development is the process whose specific outcome is the progression of the kidney over time, from its formation to the mature structure. The kidney is an organ that filters the blood and excretes the end products of body metabolism in the form of urine. [GOC:dph, GOC:tb, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_KIDNEY_DEVELOPMENT
Systematic name | M10114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of kidney development. Kidney development is the process whose specific outcome is the progression of the kidney over time, from its formation to the mature structure. The kidney is an organ that filters the blood and excretes the end products of body metabolism in the form of urine. [GOC:dph, GOC:tb, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_PANCREATIC_JUICE_SECRETION
Systematic name | M24676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of pancreatic juice secretion, the regulated release of pancreatic juice by the exocrine pancreas into the upper part of the intestine. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_GLOMERULUS_DEVELOPMENT
Systematic name | M13850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of glomerulus development, the progression of the glomerulus over time from its initial formation until its mature state. The glomerulus is a capillary tuft surrounded by Bowman's capsule in nephrons of the vertebrate kidney. [GOC:dph, GOC:tb, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLOMERULUS_DEVELOPMENT
Systematic name | M24678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of glomerulus development, the progression of the glomerulus over time from its initial formation until its mature state. The glomerulus is a capillary tuft surrounded by Bowman's capsule in nephrons of the vertebrate kidney. [GOC:dph, GOC:tb, GOC:yaf]
Full description |

Standard name | GO_CHEMOKINE_SECRETION
Systematic name | M24679
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of chemokines from a cell. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHEMOKINE_SECRETION
Systematic name | M24680
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of chemokine secretion, the regulated release of chemokines from a cell. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_REGULATION_OF_RELEASE_OF_CYTOCHROME_C_FROM_MITOCHONDRIA
Systematic name | M13355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of release of cytochrome c from mitochondria, the process in which cytochrome c is enabled to move from the mitochondrial intermembrane space into the cytosol, which is an early step in apoptosis and leads to caspase activation. [GOC:dph, GOC:mtg_apoptosis, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RELEASE_OF_CYTOCHROME_C_FROM_MITOCHONDRIA
Systematic name | M11859
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of release of cytochrome c from mitochondria, the process in which cytochrome c is enabled to move from the mitochondrial intermembrane space into the cytosol, which is an early step in apoptosis and leads to caspase activation. [GOC:BHF, GOC:dph, GOC:mtg_apoptosis, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RELEASE_OF_CYTOCHROME_C_FROM_MITOCHONDRIA
Systematic name | M13583
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of release of cytochrome c from mitochondria, the process in which cytochrome c is enabled to move from the mitochondrial intermembrane space into the cytosol, which is an early step in apoptosis and leads to caspase activation. [GOC:BHF, GOC:dph, GOC:mtg_apoptosis, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHOLESTEROL_METABOLIC_PROCESS
Systematic name | M29289
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of cholesterol metabolism, the chemical reactions and pathways involving cholesterol, cholest-5-en-3 beta-ol, the principal sterol of vertebrates and the precursor of many steroids, including bile acids and steroid hormones. [GOC:dph, GOC:sl, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHOLESTEROL_METABOLIC_PROCESS
Systematic name | M29290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of cholesterol metabolism, the chemical reactions and pathways involving cholesterol, cholest-5-en-3 beta-ol, the principal sterol of vertebrates and the precursor of many steroids, including bile acids and steroid hormones. [GOC:dph, GOC:sl, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TRIGLYCERIDE_METABOLIC_PROCESS
Systematic name | M10533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving triglyceride, any triester of glycerol. [GOC:dph, GOC:sl, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRIGLYCERIDE_METABOLIC_PROCESS
Systematic name | M29291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the chemical reactions and pathways involving triglyceride, any triester of glycerol. [GOC:dph, GOC:sl, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRIGLYCERIDE_METABOLIC_PROCESS
Systematic name | M29292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the chemical reactions and pathways involving triglyceride, any triester of glycerol. [GOC:dph, GOC:sl, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPID_KINASE_ACTIVITY
Systematic name | M10763
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of lipid kinase activity, the catalysis of the transfer of a phosphate group, usually from ATP, to a simple or complex lipid. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPID_KINASE_ACTIVITY
Systematic name | M24681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of lipid kinase activity, the catalysis of the transfer of a phosphate group, usually from ATP, to a simple or complex lipid. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CHROMOSOME_LOCALIZATION_TO_NUCLEAR_ENVELOPE_INVOLVED_IN_HOMOLOGOUS_CHROMOSOME_SEGREGATION
Systematic name | M34255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a chromosome to the nuclear envelope that contributes to homologous chromosome segregation and precedes synapsis. [GOC:ascb_2009, GOC:dph, GOC:tb, PMID:19913287]
Full description |

Standard name | GO_REGULATION_OF_SPINDLE_ORGANIZATION
Systematic name | M12780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of the assembly, arrangement of constituent parts, or disassembly of the microtubule spindle. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CENTROMERE_COMPLEX_ASSEMBLY
Systematic name | M29293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of centromere complex assembly, the aggregation, arrangement and bonding together of proteins and centromeric DNA molecules to form a centromeric protein-DNA complex. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SPINDLE_CHECKPOINT
Systematic name | M12321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the spindle checkpoint, a cell cycle checkpoint that delays the metaphase/anaphase transition until the spindle is correctly assembled and oriented, and chromosomes are attached to the spindle. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SPINDLE_CHECKPOINT
Systematic name | M24682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the spindle checkpoint, a cell cycle checkpoint that delays the metaphase/anaphase transition until the spindle is correctly assembled and oriented, and chromosomes are attached to the spindle. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_METAPHASE_PLATE_CONGRESSION
Systematic name | M24683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of metaphase plate congression, the alignment of chromosomes at the metaphase plate, a plane halfway between the poles of the spindle. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_ARACHIDONIC_ACID_SECRETION
Systematic name | M24684
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of arachidonic acid secretion, the controlled release of arachidonic acid from a cell or a tissue. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ARACHIDONIC_ACID_SECRETION
Systematic name | M24685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of arachidonic acid secretion, the controlled release of arachidonic acid from a cell or a tissue. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_H4_ACETYLATION
Systematic name | M15690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of histone H4 acetylation, the modification of histone H4 by the addition of an acetyl group. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HISTONE_H4_ACETYLATION
Systematic name | M24686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of histone H4 acetylation, the modification of histone H4 by the addition of an acetyl group. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HISTONE_H4_ACETYLATION
Systematic name | M24687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of histone H4 acetylation, the modification of histone H4 by the addition of an acetyl group. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_AXIS_ELONGATION_INVOLVED_IN_SOMITOGENESIS
Systematic name | M24688
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental growth that results in the elongation of the rostral-caudal axis that contributes to somitogenesis. [GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_MUSCLE_SYSTEM_PROCESS
Systematic name | M15722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a muscle system process, a multicellular organismal process carried out by any of the organs or tissues in a muscle system. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_RETINAL_GANGLION_CELL_AXON_GUIDANCE
Systematic name | M24689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of retinal ganglion cell axon guidance, the process in which the migration of an axon growth cone of a retinal ganglion cell (RGC) is directed to its target in the brain in response to a combination of attractive and repulsive cues. [GOC:tb, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CANONICAL_WNT_SIGNALING_PATHWAY
Systematic name | M14526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the Wnt signaling pathway through beta-catenin, the series of molecular signals initiated by binding of a Wnt protein to a frizzled family receptor on the surface of the target cell, followed by propagation of the signal via beta-catenin, and ending with a change in transcription of target genes. [GOC:tb]
Full description |

Standard name | GO_FIBROBLAST_GROWTH_FACTOR_PRODUCTION
Systematic name | M24690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The appearance of a fibroblast growth factor due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FIBROBLAST_GROWTH_FACTOR_PRODUCTION
Systematic name | M24691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency or extent of the appearance of a fibroblast growth factor due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FIBROBLAST_GROWTH_FACTOR_PRODUCTION
Systematic name | M34256
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of the appearance of a fibroblast growth factor due to biosynthesis or secretion following a cellular stimulus, resulting in an increase in its intracellular or extracellular levels. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDE_HORMONE_SECRETION
Systematic name | M24692
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the regulated release of a peptide hormone from secretory granules. [GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PEPTIDE_HORMONE_SECRETION
Systematic name | M24693
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the regulated release of a peptide hormone from secretory granules. [GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PEPTIDE_HORMONE_SECRETION
Systematic name | M24694
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of the regulated release of a peptide hormone from secretory granules. [GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CALCIUM_ION_IMPORT
Systematic name | M12968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the directed movement of calcium ions into a cell or organelle. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CALCIUM_ION_IMPORT
Systematic name | M14471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the directed movement of calcium ions into a cell or organelle. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CALCIUM_ION_IMPORT
Systematic name | M12702
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of the directed movement of calcium ions into a cell or organelle. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_RESPONSE_TO_GROWTH_FACTOR_STIMULUS
Systematic name | M10257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a growth factor stimulus. [GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_RESPONSE_TO_GROWTH_FACTOR_STIMULUS
Systematic name | M12333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a growth factor stimulus. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_OSTEOCLAST_PROLIFERATION
Systematic name | M24696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the multiplication or reproduction of osteoclasts, resulting in the expansion of an osteoclast cell population. [GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_WOUND_HEALING
Systematic name | M14541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the series of events that restore integrity to a damaged tissue, following an injury. [GOC:BHF]
Full description |

Standard name | GO_NUCLEIC_ACID_PHOSPHODIESTER_BOND_HYDROLYSIS
Systematic name | M12241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The nucleic acid metabolic process in which the phosphodiester bonds between nucleotides are cleaved by hydrolysis. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_SPINDLE_ASSEMBLY_INVOLVED_IN_MEIOSIS
Systematic name | M24697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form the spindle that contributes to the process of meiosis. [GOC:tb, GOC:vw]
Full description |

Standard name | GO_MITOTIC_SPINDLE_ASSEMBLY
Systematic name | M12435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Mitotic bipolar spindle assembly begins with spindle microtubule nucleation from the separated spindle pole body, includes spindle elongation during prometaphase, and is complete when all kinetochores are stably attached the spindle, and the spindle assembly checkpoint is satisfied. [GOC:tb, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_DNA_METHYLATION_DEPENDENT_HETEROCHROMATIN_ASSEMBLY
Systematic name | M24698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of the repression of transcription by methylation of DNA, leading to the formation of heterochromatin. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_METHYLATION_DEPENDENT_HETEROCHROMATIN_ASSEMBLY
Systematic name | M24699
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of the repression of transcription by methylation of DNA, leading to the formation of heterochromatin. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_DEACETYLATION
Systematic name | M10897
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of protein deacetylation, the removal of an acetyl group from a protein amino acid. An acetyl group is CH3CO-, derived from acetic [ethanoic] acid. [GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_DEACETYLATION
Systematic name | M14870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of protein deacetylation, the removal of an acetyl group from a protein amino acid. An acetyl group is CH3CO-, derived from acetic [ethanoic] acid. [GOC:ecd, PMID:20027304]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_TARGETING_TO_MEMBRANE
Systematic name | M11502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the process of directing proteins towards a membrane, usually using signals contained within the protein. [GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_TARGETING_TO_MEMBRANE
Systematic name | M16470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the process of directing proteins towards a membrane, usually using signals contained within the protein. [GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_TARGETING_TO_MEMBRANE
Systematic name | M24700
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the process of directing proteins towards a membrane, usually using signals contained within the protein. [GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTRACELLULAR_PROTEIN_TRANSPORT
Systematic name | M10915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the directed movement of proteins within cells. [GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTRACELLULAR_PROTEIN_TRANSPORT
Systematic name | M12270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the directed movement of proteins within cells. [GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_SUPEROXIDE_METABOLIC_PROCESS
Systematic name | M14788
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of superoxide metabolism, the chemical reactions and pathways involving superoxide, the superoxide anion O2- (superoxide free radical), or any compound containing this species. [GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OXIDATIVE_PHOSPHORYLATION
Systematic name | M24701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of the chemical reactions and pathways resulting in the phosphorylation of ADP to ATP that accompanies the oxidation of a metabolite through the operation of the respiratory chain. Oxidation of compounds establishes a proton gradient across the membrane, providing the energy for ATP synthesis. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_LOCOMOTION_INVOLVED_IN_LOCOMOTORY_BEHAVIOR
Systematic name | M24702
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of the self-propelled movement of a cell or organism from one location to another in a behavioral context; the aspect of locomotory behavior having to do with movement. [GOC:dph, GOC:kmv, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_DNA_DEPENDENT_DNA_REPLICATION
Systematic name | M10569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of DNA-dependent DNA replication, the process in which new strands of DNA are synthesized, using parental DNA as a template for the DNA-dependent DNA polymerases that synthesize the new strands. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_PLATELET_AGGREGATION
Systematic name | M12339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of platelet aggregation. Platelet aggregation is the adhesion of one platelet to one or more other platelets via adhesion molecules. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PLATELET_AGGREGATION
Systematic name | M24703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency or extent of platelet aggregation. Platelet aggregation is the adhesion of one platelet to one or more other platelets via adhesion molecules. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_BROWN_FAT_CELL_DIFFERENTIATION
Systematic name | M11381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of brown fat cell differentiation. Brown fat cell differentiation is the process in which a relatively unspecialized cell acquires specialized features of a brown adipocyte, an animal connective tissue cell involved in adaptive thermogenesis. Brown adipocytes contain multiple small droplets of triglycerides and a high number of mitochondria. [GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BROWN_FAT_CELL_DIFFERENTIATION
Systematic name | M24704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of brown fat cell differentiation. Brown fat cell differentiation is the process in which a relatively unspecialized cell acquires specialized features of a brown adipocyte, an animal connective tissue cell involved in adaptive thermogenesis. Brown adipocytes contain multiple small droplets of triglycerides and a high number of mitochondria. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_CELL_AGING
Systematic name | M16568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of cell aging. Cell aging is the progression of the cell from its inception to the end of its lifespan. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_AGING
Systematic name | M24705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the rate, frequency, or extent of cell aging. Cell aging is the progression of the cell from its inception to the end of its lifespan. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_AGING
Systematic name | M12032
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the rate, frequency, or extent of cell aging. Cell aging is the progression of the cell from its inception to the end of its lifespan. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHOLESTEROL_EFFLUX
Systematic name | M24706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of cholesterol efflux. Cholesterol efflux is the directed movement of cholesterol, cholest-5-en-3-beta-ol, out of a cell or organelle. [GOC:dph, GOC:tb, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_HEART_INDUCTION
Systematic name | M24707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency, or extent of heart induction. Heart induction is the close range interaction between mesoderm and endoderm or ectoderm that causes cells to change their fates and specify the development of the heart. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_PHAGOSOME_MATURATION
Systematic name | M12757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the arrangement of constituent parts of a phagosome within a cell. Phagosome maturation begins with endocytosis and formation of the early phagosome and ends with the formation of the hybrid organelle, the phagolysosome. [GOC:kmv, GOC:tb]
Full description |

Standard name | GO_PHAGOSOME_ACIDIFICATION
Systematic name | M13530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that reduces the pH of the phagosome, measured by the concentration of the hydrogen ion. [GOC:kmv, GOC:tb]
Full description |

Standard name | GO_PHAGOSOME_LYSOSOME_FUSION
Systematic name | M24708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The creation of a phagolysosome from a phagosome and a lysosome. [GOC:kmv, GOC:tb]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EXCITATORY_POSTSYNAPTIC_POTENTIAL
Systematic name | M24709
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that prevents the establishment or decreases the extent of the excitatory postsynaptic potential (EPSP) which is a temporary increase in postsynaptic potential due to the flow of positively charged ions into the postsynaptic cell. The flow of ions that causes an EPSP is an excitatory postsynaptic current (EPSC) and makes it easier for the neuron to fire an action potential. [GOC:BHF]
Full description |

Standard name | GO_CELLULAR_SENESCENCE
Systematic name | M11558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell aging process stimulated in response to cellular stress, whereby normal cells lose the ability to divide through irreversible cell cycle arrest. [GOC:BHF]
Full description |

Standard name | GO_REPLICATIVE_SENESCENCE
Systematic name | M14683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell aging process associated with the dismantling of a cell as a response to telomere shortening and/or cellular aging. [GOC:BHF]
Full description |

Standard name | GO_STRESS_INDUCED_PREMATURE_SENESCENCE
Systematic name | M24710
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular senescence process associated with the dismantling of a cell as a response to environmental factors such as hydrogen peroxide or X-rays. [GOC:BHF]
Full description |

Standard name | GO_ORGANOPHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M11681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the biosynthesis of deoxyribose phosphate, the phosphorylated sugar 2-deoxy-erythro-pentose. [GOC:chem_mtg]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_NUCLEAR_ENVELOPE
Systematic name | M24711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained at, a location within a nuclear envelope. [GOC:tb]
Full description |

Standard name | GO_CATECHOLAMINE_UPTAKE
Systematic name | M24712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of catecholamine into a cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_RNA_PHOSPHODIESTER_BOND_HYDROLYSIS
Systematic name | M12877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The RNA metabolic process in which the phosphodiester bonds between ribonucleotides are cleaved by hydrolysis. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_RNA_PHOSPHODIESTER_BOND_HYDROLYSIS_ENDONUCLEOLYTIC
Systematic name | M16958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving the hydrolysis of internal 3',5'-phosphodiester bonds in one or two strands of ribonucleotides. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_RNA_PHOSPHODIESTER_BOND_HYDROLYSIS_EXONUCLEOLYTIC
Systematic name | M16222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving the hydrolysis of terminal 3',5'-phosphodiester bonds in one or two strands of ribonucleotides. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_EPIBOLY
Systematic name | M13804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The expansion of one cell sheet over other cells or yolk. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_SPHINGOLIPID_MEDIATED_SIGNALING_PATHWAY
Systematic name | M10851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by a sphingolipid. [PMID:9525917]
Full description |

Standard name | GO_ACTIN_FILAMENT_REORGANIZATION
Systematic name | M24713
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in dynamic structural changes to the arrangement of actin filaments. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_ESTABLISHMENT_OF_ENDOTHELIAL_INTESTINAL_BARRIER
Systematic name | M10692
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The establishment of a barrier between endothelial cell layers of the intestine to exert specific and selective control over the passage of water and solutes, thus allowing formation and maintenance of compartments that differ in fluid and solute composition. [GOC:krc, PMID:22155109]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_PERMEABILITY
Systematic name | M15860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the passage or uptake of molecules by a membrane. [GOC:kmv, PMID:22677064]
Full description |

Standard name | GO_INFLAMMATORY_RESPONSE_TO_WOUNDING
Systematic name | M24714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The immediate defensive reaction by vertebrate tissue to injury caused by chemical or physical agents. [GOC:add]
Full description |

Standard name | GO_SENSORY_ORGAN_MORPHOGENESIS
Systematic name | M15276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Morphogenesis of a sensory organ. A sensory organ is defined as a tissue or set of tissues that work together to receive and transmit signals from external or internal stimuli. Morphogenesis is the process in which anatomical structures are generated and organized. Organs are commonly observed as visibly distinct structures, but may also exist as loosely associated clusters of cells that work together to perform a specific function or functions. [GOC:kmv, ISBN:978-0199210893]
Full description |

Standard name | GO_UBIQUITIN_INDEPENDENT_PROTEIN_CATABOLIC_PROCESS_VIA_THE_MULTIVESICULAR_BODY_SORTING_PATHWAY
Systematic name | M24715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a protein or peptide, via the multivesicular body (MVB) sorting pathway; proteins are sorted into MVBs, and delivered to a lysosome/vacuole for degradation. This process is independent of ubiquitination. [PMID:22547407]
Full description |

Standard name | GO_ACTIVATION_OF_GTPASE_ACTIVITY
Systematic name | M10929
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of an inactive GTPase through the replacement of GDP by GTP. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_MITOCHONDRIAL_TRNA_PROCESSING
Systematic name | M24716
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a pre-tRNA molecule is converted to a mature tRNA, ready for addition of an aminoacyl group, in the mitochondrion. [GOC:vw]
Full description |

Standard name | GO_MODULATION_OF_AGE_RELATED_BEHAVIORAL_DECLINE
Systematic name | M24717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the processes that arise as an organism progresses toward the end of its lifespan that results in a decline in behavioral activities such as locomotory behavior, and learning or memory. [GOC:cjm, GOC:kmv, PMID:20523893]
Full description |

Standard name | GO_RESPONSE_TO_OXYGEN_GLUCOSE_DEPRIVATION
Systematic name | M24718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of the deprivation of oxygen and glucose. [GOC:sl, PMID:21525936]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_OXYGEN_GLUCOSE_DEPRIVATION
Systematic name | M34257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of the deprivation of oxygen and glucose. [GOC:sl, PMID:21525936]
Full description |

Standard name | GO_TELOMERIC_LOOP_DISASSEMBLY
Systematic name | M24719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The telomere maintenance process in which telomeric loops are disassembled to permit efficient telomere replication. [GOC:BHF, GOC:BHF_telomere, GOC:nc, PMID:22579284]
Full description |

Standard name | GO_WALKING_BEHAVIOR
Systematic name | M16566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The behavior of an organism relating to the progression of that organism along the ground by the process of lifting and setting down each leg. [GOC:tb]
Full description |

Standard name | GO_CEREBROSPINAL_FLUID_CIRCULATION
Systematic name | M34258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The neurological system process driven by motile cilia on ependymal cells of the brain by which cerebrospinal fluid circulates from the sites of secretion to the sites of absorption. In ventricular cavities, the flow is unidirectional and rostrocaudal, in subarachnoid spaces, the flow is multi-directional. [GOC:mgi_curators, PMID:22100360, PMID:24229449]
Full description |

Standard name | GO_SCARNA_LOCALIZATION_TO_CAJAL_BODY
Systematic name | M24720
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a small Cajal body-specific RNA is transported to, or maintained in, a Cajal body. [GOC:BHF, GOC:BHF_telomere, GOC:nc, PMID:25467444]
Full description |

Standard name | GO_TELOMERASE_RNA_LOCALIZATION
Systematic name | M24721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which telomerase RNA is transported to, or maintained in, a specific location. [GOC:BHF, GOC:BHF_telomere, GOC:nc, PMID:25467444]
Full description |

Standard name | GO_ENDOTHELIAL_CELL_MATRIX_ADHESION
Systematic name | M24722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The binding of an endothelial cell to the extracellular matrix via adhesion molecules. [GOC:bc, GOC:BHF, GOC:BHF_miRNA, PMID:19460962]
Full description |

Standard name | GO_ENDOTHELIAL_CELL_MATRIX_ADHESION_VIA_FIBRONECTIN
Systematic name | M34259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The binding of an endothelial cell to the extracellular matrix via fibronectin. [GOC:bc, GOC:BHF, GOC:BHF_miRNA, PMID:19460962]
Full description |

Standard name | GO_REVERSIBLE_DIFFERENTIATION
Systematic name | M24723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A phenotypic switching process where a cell reversibly differentiates and dedifferentiates from one cell type into another. [GOC:curators]
Full description |

Standard name | GO_CELL_DIFFERENTIATION_INVOLVED_IN_PHENOTYPIC_SWITCHING
Systematic name | M24724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cell differentiation process that is a part of a reversible switch of a cell from one cell type or form to another, at a frequency above the expected frequency for somatic mutations. [GOC:curators]
Full description |

Standard name | GO_IMMUNOLOGICAL_MEMORY_PROCESS
Systematic name | M24725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process of the immune system that can contribute to the formation of immunological memory or an immune response based upon activation of immunological memory. [GOC:add, PMID:26086132, PMID:26831526]
Full description |

Standard name | GO_IMMUNOLOGICAL_MEMORY_FORMATION_PROCESS
Systematic name | M24726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any immunological memory process that can contribute to the formation of immunological memory. [GOC:add, PMID:26086132, PMID:26831526]
Full description |

Standard name | GO_DNA_REPAIR_COMPLEX_ASSEMBLY
Systematic name | M24727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a DNA repair complex. [GOC:pg, PMID:27113759, PMID:27233470]
Full description |

Standard name | GO_REGULATION_OF_PLASMA_LIPOPROTEIN_PARTICLE_LEVELS
Systematic name | M14600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the maintenance of internal levels of plasma lipoprotein particles within an organism. [GOC:BHF]
Full description |

Standard name | GO_ENERGY_HOMEOSTASIS
Systematic name | M14714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the balance between food intake (energy input) and energy expenditure. [GOC:yaf, PMID:15919751]
Full description |

Standard name | GO_RESPONSE_TO_GRANULOCYTE_MACROPHAGE_COLONY_STIMULATING_FACTOR
Systematic name | M24728
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a granulocyte macrophage colony-stimulating factor stimulus. [GOC:pr]
Full description |

Standard name | GO_LYMPHOCYTE_MIGRATION_INTO_LYMPHOID_ORGANS
Systematic name | M34260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a lymphocyte within the lymphatic system into lymphoid organs such as lymph nodes, spleen or Peyer's patches, and its subsequent positioning within defined functional compartments such as sites of cell activation by antigen. [GOC:BHF, GOC:pr, PMID:18379575]
Full description |

Standard name | GO_DENDRITIC_CELL_DIFFERENTIATION
Systematic name | M10358
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a precursor cell type acquires the specialized features of a dendritic cell. A dendritic cell is a leukocyte of dendritic lineage specialized in the uptake, processing, and transport of antigens to lymph nodes for the purpose of stimulating an immune response via T cell activation. [CL:0000451, GOC:pr]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_LIPID_DISTRIBUTION
Systematic name | M11676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the proportions or spatial arrangement of lipids in a cellular membrane. [GOC:mah, PMID:18441123, PMID:20823909]
Full description |

Standard name | GO_PROTEIN_LINEAR_POLYUBIQUITINATION
Systematic name | M24729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A protein ubiquitination process in which a linear polymer of ubiquitin, formed by the amino-terminal methionine (M1) of one ubiquitin molecule and by the carboxy-terminal glycine (G76) of the next, is added to a protein. [GOC:jsg, GOC:sp, PMID:21455173, PMID:21455180, PMID:21455181]
Full description |

Standard name | GO_DENDRITIC_CELL_APOPTOTIC_PROCESS
Systematic name | M24730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a dendritic cell, a cell of hematopoietic origin, typically resident in particular tissues, specialized in the uptake, processing, and transport of antigens to lymph nodes for the purpose of stimulating an immune response via T cell activation. [CL:0000451, GOC:BHF, GOC:mtg_apoptosis, PMID:15059845]
Full description |

Standard name | GO_MOTOR_NEURON_APOPTOTIC_PROCESS
Systematic name | M24731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a motor neuron, an efferent neuron that passes from the central nervous system or a ganglion toward or to a muscle and conducts an impulse that causes movement. [CL:0000100, GOC:BHF, GOC:mtg_apoptosis, PMID:14523086]
Full description |

Standard name | GO_TYPE_B_PANCREATIC_CELL_APOPTOTIC_PROCESS
Systematic name | M24732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a type B pancreatic cell, a cell located towards center of the islets of Langerhans that secretes insulin. [CL:0000169, GOC:BHF, GOC:mtg_apoptosis, PMID:16087305]
Full description |

Standard name | GO_L_KYNURENINE_METABOLIC_PROCESS
Systematic name | M29295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving L-kynurenine, the L-enantiomer of the amino acid kynurenine (3-(2-aminobenzoyl)-alanine). [GOC:yaf]
Full description |

Standard name | GO_DENDRITIC_SPINE_MAINTENANCE
Systematic name | M24733
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The organization process that preserves a dendritic spine in a stable functional or structural state. A dendritic spine is a specialized protrusion from a neuronal dendrite and is involved in synaptic transmission. [GOC:BHF, PMID:20410104]
Full description |

Standard name | GO_NCRNA_EXPORT_FROM_NUCLEUS
Systematic name | M24734
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a non-coding RNA transcript (ncRNA) from the nucleus to the cytoplasm. [GOC:dgf, PMID:11352936]
Full description |

Standard name | GO_ANTERIOR_HEAD_DEVELOPMENT
Systematic name | M24735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the anterior part of the head over time, from its formation to the mature structure. [GOC:yaf, PMID:14695376, PMID:15857913]
Full description |

Standard name | GO_RESPONSE_TO_THYROID_HORMONE
Systematic name | M15044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a thyroid hormone stimulus. [GOC:sjw, PMID:9916872]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_THYROID_HORMONE_STIMULUS
Systematic name | M13357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a thyroid hormone stimulus. [GOC:sjw, PMID:9916872]
Full description |

Standard name | GO_DUCTUS_ARTERIOSUS_CLOSURE
Systematic name | M24736
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The morphogenesis process in which the ductus arteriosus changes to no longer permit blood flow after birth. The ductus arteriosus is the shunt between the aorta and the pulmonary artery which allows blood to bypass the fetus' lungs. [GOC:hw]
Full description |

Standard name | GO_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_DEVELOPMENT
Systematic name | M24737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process aimed at the progression of a vascular smooth muscle cell over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. A vascular smooth muscle cell is a non-striated, elongated, spindle-shaped cell found lining the blood vessels. [GOC:BHF]
Full description |

Standard name | GO_PRESYNAPTIC_MEMBRANE_ORGANIZATION
Systematic name | M24738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process which results in the assembly, arrangement of constituent parts, or disassembly of a presynaptic membrane, including any proteins associated with the membrane, but excluding other cellular components. A presynaptic membrane is a specialized area of membrane of the axon terminal that faces the plasma membrane of the neuron or muscle fiber with which the axon terminal establishes a synaptic junction. [GOC:BHF, GOC:pr, GOC:sjp, PMID:19730411]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_CLUSTERING
Systematic name | M24739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process that results in grouping synaptic vesicles in presynaptic structures. [GOC:ans, GOC:pr, PMID:19900895, PMID:7568108]
Full description |

Standard name | GO_CRANIOFACIAL_SUTURE_MORPHOGENESIS
Systematic name | M15587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which any suture between cranial and/or facial bones is generated and organized. [GOC:pr, GOC:sl, Wikipedia:Cranial_sutures, Wikipedia:Head_and_neck_anatomy#Musculoskeletal_system]
Full description |

Standard name | GO_POSTSYNAPTIC_MEMBRANE_ASSEMBLY
Systematic name | M24740
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a postsynaptic membrane, a specialized area of membrane facing the presynaptic membrane on the tip of the nerve ending and separated from it by a minute cleft (the synaptic cleft). [GOC:BHF, GOC:sjp, PMID:21424692]
Full description |

Standard name | GO_AMPA_GLUTAMATE_RECEPTOR_CLUSTERING
Systematic name | M24743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The glutamate receptor clustering process in which alpha-amino-3-hydroxy-5-methyl-4-isoxazole propionate (AMPA) receptors are localized to distinct domains in the cell membrane. [GOC:BHF, GOC:pr, GOC:sjp, PMID:12796785]
Full description |

Standard name | GO_POSTSYNAPTIC_DENSITY_PROTEIN_95_CLUSTERING
Systematic name | M24744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The clustering process in which postsynaptic density protein 95 (PSD-95) molecules are localized to distinct domains in the cell membrane. PSD-95 is mostly located in the post synaptic density of neurons, and is involved in anchoring synaptic proteins. [GOC:BHF, GOC:sjp, PMID:10433269]
Full description |

Standard name | GO_RECEPTOR_LOCALIZATION_TO_SYNAPSE
Systematic name | M24745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a receptor is transported to, and/or maintained at the synapse, the junction between a nerve fiber of one neuron and another neuron or muscle fiber or glial cell. [GOC:BHF, GOC:sjp, PMID:21525273]
Full description |

Standard name | GO_NEURONAL_STEM_CELL_POPULATION_MAINTENANCE
Systematic name | M14286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in by an organism or tissue maintains a population of neuronal stem cells. [CL:0000047, GOC:dos, GOC:yaf, PMID:11399758]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INHIBITORY_POSTSYNAPTIC_POTENTIAL
Systematic name | M24746
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of inhibitory postsynaptic potential (IPSP). IPSP is a temporary decrease in postsynaptic membrane potential due to the flow of negatively charged ions into the postsynaptic cell. The flow of ions that causes an IPSP is an inhibitory postsynaptic current (IPSC) and makes it more difficult for the neuron to fire an action potential. [GOC:BHF, GOC:sjp, PMID:18550748]
Full description |

Standard name | GO_MESENCHYMAL_CELL_APOPTOTIC_PROCESS
Systematic name | M24747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a mesenchymal cell. A mesenchymal cell is a loosely associated cell that is part of the connective tissue in an organism. Mesenchymal cells give rise to more mature connective tissue cell types. [CL:0000134, GOC:mtg_apoptosis, GOC:yaf, PMID:18231833]
Full description |

Standard name | GO_GABAERGIC_NEURON_DIFFERENTIATION
Systematic name | M11870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a neuroblast acquires the specialized structural and functional features of a GABAergic neuron. [GOC:kmv, PMID:11517269]
Full description |

Standard name | GO_AMMONIUM_ION_METABOLIC_PROCESS
Systematic name | M10285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving the ammonium ion. [GOC:dhl, GOC:tb, PMID:14671018]
Full description |

Standard name | GO_MESENCHYMAL_STEM_CELL_PROLIFERATION
Systematic name | M24748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of mesenchymal stem cells, resulting in the expansion of a stem cell population. A mesenchymal stem cell, or MSC, is a cell that retains the ability to divide and proliferate throughout life to provide progenitor cells that can differentiate into specialized mesenchymal cells. [CL:0000134, GOC:yaf, PMID:20626275]
Full description |

Standard name | GO_EPOXIDE_METABOLIC_PROCESS
Systematic name | M34261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving epoxides, compounds in which an oxygen atom is directly attached to two adjacent or non-adjacent carbon atoms of a carbon chain or ring system; thus cyclic ethers. [GOC:rs, PMID:15822179]
Full description |

Standard name | GO_RUFFLE_ASSEMBLY
Systematic name | M24749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a ruffle, a projection at the leading edge of a crawling cell; the protrusions are supported by a microfilament meshwork. The formation of ruffles (also called membrane ruffling) is thought to be controlled by a group of enzymes known as Rho GTPases, specifically RhoA, Rac1 and cdc42. [GOC:yaf, http:en.wikipedia.org/wiki/Membrane_ruffling, PMID:12556481]
Full description |

Standard name | GO_AMELOGENESIS
Systematic name | M14160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the formation of tooth enamel, occurring in two stages: secretory stage and maturation stage. [GOC:cjm, GOC:sl, PMID:10206335, PMID:21196346]
Full description |

Standard name | GO_DENTINOGENESIS
Systematic name | M24750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the formation of dentin, the mineralized tissue that constitutes the major bulk of teeth. Dentin may be one of three types: primary dentin, secondary dentin, and tertiary dentin. [GOC:cjm, GOC:sl, PMID:10206335, PMID:21196346]
Full description |

Standard name | GO_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M12660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals which triggers the apoptotic death of a cell. The pathway starts with reception of a signal, and ends when the execution phase of apoptosis is triggered. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_EXTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M11317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which a signal is conveyed from the cell surface to trigger the apoptotic death of a cell. The pathway starts with either a ligand binding to a cell surface receptor, or a ligand being withdrawn from a cell surface receptor (e.g. in the case of signaling by dependence receptors), and ends when the execution phase of apoptosis is triggered. [GOC:mtg_apoptosis, GOC:yaf, PMID:17340152]
Full description |

Standard name | GO_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M13922
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway starts with reception of an intracellular signal (e.g. DNA damage, endoplasmic reticulum stress, oxidative stress etc.), and ends when the execution phase of apoptosis is triggered. The intrinsic apoptotic signaling pathway is crucially regulated by permeabilization of the mitochondrial outer membrane (MOMP). [GOC:mtg_apoptosis, GOC:yaf, PMID:11919192, PMID:17340152, PMID:18852119]
Full description |

Standard name | GO_EXECUTION_PHASE_OF_APOPTOSIS
Systematic name | M15953
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A stage of the apoptotic process that starts with the controlled breakdown of the cell through the action of effector caspases or other effector molecules (e.g. cathepsins, calpains etc.). Key steps of the execution phase are rounding-up of the cell, retraction of pseudopodes, reduction of cellular volume (pyknosis), chromatin condensation, nuclear fragmentation (karyorrhexis), plasma membrane blebbing and fragmentation of the cell into apoptotic bodies. When the execution phase is completed, the cell has died. [GOC:mtg_apoptosis, PMID:21760595]
Full description |

Standard name | GO_HISTONE_H3_K36_TRIMETHYLATION
Systematic name | M29296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of three methyl groups to lysine at position 36 of the histone. [GOC:se, PMID:17948059]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSCRIPTION_FROM_RNA_POLYMERASE_II_PROMOTER_IN_RESPONSE_TO_STRESS
Systematic name | M24751
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the frequency, rate or extent of transcription from an RNA polymerase II promoter as a result of a stimulus indicating the organism is under stress. The stress is usually, but not necessarily, exogenous (e.g. temperature, humidity, ionizing radiation). [GOC:rn, PMID:11027285, PMID:15575969, PMID:16556235, PMID:18086556, PMID:18627600]
Full description |

Standard name | GO_ACTIVATION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY
Systematic name | M11815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of the inactive enzyme cysteine-type endopeptidase. [GOC:mtg_apoptosis, PMID:21726810]
Full description |

Standard name | GO_RENAL_FILTRATION
Systematic name | M16139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A renal system process in which fluid circulating through the body is filtered through a barrier system. [GOC:pr, GOC:sart]
Full description |

Standard name | GO_RESPONSE_TO_GONADOTROPIN_RELEASING_HORMONE
Systematic name | M24752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a gonadotropin-releasing hormone stimulus. Gonadotropin-releasing hormone (GnRH) is a peptide hormone responsible for the release of follicle-stimulating hormone (FSH) and luteinizing hormone (LH) from the anterior pituitary. GnRH is synthesized and released by the hypothalamus. [GOC:yaf, PMID:15976007]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_TOXIC_SUBSTANCE
Systematic name | M12658
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a toxic stimulus. [GOC:pr]
Full description |

Standard name | GO_AMYLOID_BETA_CLEARANCE
Systematic name | M24753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which amyloid-beta is removed from extracellular brain regions by mechanisms involving cell surface receptors. [GOC:aruk, GOC:bc, GOC:BHF, PMID:18289866, PMID:19098903, PMID:26005850]
Full description |

Standard name | GO_MITOCHONDRIAL_RESPIRASOME_ASSEMBLY
Systematic name | M34262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of respiratory enzyme complexes of the mitochondrial inner membrane (including, for example, complex II, complex III, complex IV) to form a large supercomplex. [GOC:mcc, PMID:21909073, PMID:22342701]
Full description |

Standard name | GO_SELF_PROTEOLYSIS
Systematic name | M24754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The hydrolysis of proteins into smaller polypeptides and/or amino acids by cleavage of their own peptide bonds. [GOC:yaf, PMID:18676612, PMID:19144634]
Full description |

Standard name | GO_OMEGA_HYDROXYLASE_P450_PATHWAY
Systematic name | M24755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways by which arachidonic acid is converted to other compounds initially by omega-hydroxylation. [GOC:mw, PMID:10681399]
Full description |

Standard name | GO_COMPLEMENT_DEPENDENT_CYTOTOXICITY
Systematic name | M29297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell killing caused by the membrane attack complex formed following complement activation. [GOC:add, GOC:rv]
Full description |

Standard name | GO_KERATINOCYTE_APOPTOTIC_PROCESS
Systematic name | M24756
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a keratinocyte. A keratinocyte is an epidermal cell which synthesizes keratin and undergoes a characteristic change as it moves upward from the basal layers of the epidermis to the cornified (horny) layer of the skin. [CL:0000312, GOC:jc, GOC:mtg_apoptosis, PMID:10201527]
Full description |

Standard name | GO_HEPATOCYTE_APOPTOTIC_PROCESS
Systematic name | M13149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a hepatocyte, the main structural component of the liver. [CL:0000182, GOC:jc, GOC:mtg_apoptosis, PMID:15856020]
Full description |

Standard name | GO_PROGRAMMED_NECROTIC_CELL_DEATH
Systematic name | M24757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A necrotic cell death process that results from the activation of endogenous cellular processes, such as signaling involving death domain receptors or Toll-like receptors. [GOC:mtg_apoptosis, PMID:21760595]
Full description |

Standard name | GO_RESPONSE_TO_ALCOHOL
Systematic name | M16155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an alcohol stimulus. [GOC:pr, PMID:24014527]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ALCOHOL
Systematic name | M14879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an alcohol stimulus. [GOC:pr]
Full description |

Standard name | GO_PLASMA_MEMBRANE_TUBULATION
Systematic name | M24758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A membrane tubulation process occurring in a plasma membrane. [GOC:BHF, GOC:pr, PMID:15252009, PMID:20730103]
Full description |

Standard name | GO_RESPONSE_TO_ANTINEOPLASTIC_AGENT
Systematic name | M24759
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an antineoplastic agent stimulus. An antineoplastic agent is a substance that inhibits or prevents the proliferation of neoplasms. [GOC:pr]
Full description |

Standard name | GO_ZYMOGEN_INHIBITION
Systematic name | M24761
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that prevents the proteolytic processing of an inactive enzyme to an active form. [GOC:mtg_apoptosis, PMID:20383739]
Full description |

Standard name | GO_MITOCHONDRIAL_OUTER_MEMBRANE_PERMEABILIZATION
Systematic name | M24762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process by which the mitochondrial outer membrane becomes permeable to the passing of proteins and other molecules from the intermembrane space to the cytosol as part of the apoptotic signaling pathway. [GOC:BHF, GOC:mtg_apoptosis, GOC:pg, PMID:21041309]
Full description |

Standard name | GO_NEUTROPHIL_CLEARANCE
Systematic name | M24763
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The selective elimination of senescent neutrophils from the body by autoregulatory mechanisms. [GOC:BHF, PMID:21957127]
Full description |

Standard name | GO_AUTOPHAGOSOME_MATURATION
Systematic name | M24764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Removal of PI3P and Atg8/LC3 after the closure of the phagophore and before the fusion with the endosome/lysosome (e.g. mammals and insects) or vacuole (yeast), and that very likely destabilizes other Atg proteins and thus enables their efficient dissociation and recycling. [GOC:autophagy, GOC:lf, PMID:28077293]
Full description |

Standard name | GO_PRENYLATION
Systematic name | M24765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment of a prenyl group to a molecule; geranyl, farnesyl, or geranylgeranyl groups may be added. [GOC:di, PMID:18029206, PMID:21351751, PMID:22123822, PMID:22642693, PMID:22660767]
Full description |

Standard name | GO_CHORIONIC_TROPHOBLAST_CELL_PROLIFERATION
Systematic name | M29298
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of chorionic trophoblast cells, resulting in the expansion of their population. [CL:0011101, GOC:BHF, PMID:15150278]
Full description |

Standard name | GO_ESTABLISHMENT_OF_SERTOLI_CELL_BARRIER
Systematic name | M24767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Establishment of a structure near the basement membrane in adjacent Sertoli cells of the seminiferous epithelium for maintaining spermatogenesis. The structure consists of tight junctions, basal ectoplasmic specializations, and desmosome-like junctions. [GOC:sl, PMID:19509333, Wikipedia:Blood-testis_barrier]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_17
Systematic name | M24769
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-17 stimulus. [GOC:pr]
Full description |

Standard name | GO_HYPOXIA_INDUCIBLE_FACTOR_1ALPHA_SIGNALING_PATHWAY
Systematic name | M24770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals mediated by hypoxia-inducible factor (HIF1) in response to lowered oxygen levels (hypoxia). Under hypoxic conditions, the oxygen-sensitive alpha-subunit of hypoxia-inducible factor (HIF)-1 dimerizes with a HIF1-beta subunit (also called ARNT or aryl-hydrocarbon-receptor nuclear translocator), translocates to the nucleus and activates transcription of genes whose products participate in responding to hypoxia. [GOC:bf, GOC:jc, http://www.sabiosciences.com/pathway.php?sn=HIF1Alpha_Pathway]
Full description |

Standard name | GO_LIVER_REGENERATION
Systematic name | M13445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regrowth of lost or destroyed liver. [GOC:gap, PMID:19447520]
Full description |

Standard name | GO_PROTEIN_MATURATION_BY_IRON_SULFUR_CLUSTER_TRANSFER
Systematic name | M24771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of an assembled iron-sulfur cluster from a scaffold protein to an acceptor protein that contributes to the attainment of the full functional capacity of a protein. [GOC:al, GOC:mah, PMID:11939799, PMID:18322036, PMID:21977977]
Full description |

Standard name | GO_SUPRAMOLECULAR_FIBER_ORGANIZATION
Systematic name | M24772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a supramolecular fiber, a polymer consisting of an indefinite number of protein or protein complex subunits that have polymerised to form a fiber-shaped structure. [GOC:pr]
Full description |

Standard name | GO_PROGRAMMED_CELL_DEATH_IN_RESPONSE_TO_REACTIVE_OXYGEN_SPECIES
Systematic name | M24773
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell death resulting from activation of endogenous cellular processes and occurring as a result of a reactive oxygen species stimulus. Reactive oxygen species include singlet oxygen, superoxide, and oxygen free radicals. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_MOTOR_NEURON_MIGRATION
Systematic name | M24774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a motor neuron from one site to another. A motor neuron is an efferent neuron that passes from the central nervous system or a ganglion toward or to a muscle and conducts an impulse that causes movement. [CL:0000100, GOC:yaf, PMID:20711475]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_LOCALIZATION
Systematic name | M10129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a synaptic vesicle or vesicles are transported to, and/or maintained in, a specific location. [GOC:pr]
Full description |

Standard name | GO_DENDRITE_EXTENSION
Systematic name | M24775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Long distance growth of a single dendrite involved in cellular development. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_NEURON_PROJECTION_GUIDANCE
Systematic name | M15608
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the migration of a neuron projection is directed to a specific target site in response to a combination of attractive and repulsive cues. [GOC:BHF, GOC:rl, PMID:22790009]
Full description |

Standard name | GO_REGULATION_OF_VESICLE_SIZE
Systematic name | M29300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the size of a vesicle. [GOC:pm, PMID:20007772]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_NON_MOTILE_CILIUM
Systematic name | M24776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a non-motile cilium. [GOC:cilia, GOC:kmv, PMID:23128241]
Full description |

Standard name | GO_RECEPTOR_LOCALIZATION_TO_NON_MOTILE_CILIUM
Systematic name | M34263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a receptor is transported to, or maintained in, a location within a non-motile cilium. [GOC:cilia, GOC:kmv, PMID:23128241]
Full description |

Standard name | GO_MANNOSYLATION
Systematic name | M16464
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment of a mannose residue to a substrate molecule. [GOC:cjm]
Full description |

Standard name | GO_SIALYLATION
Systematic name | M16553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The covalent attachment of sialic acid to a substrate molecule. [GOC:cjm]
Full description |

Standard name | GO_NECROPTOTIC_SIGNALING_PATHWAY
Systematic name | M24779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals which triggers the necroptotic death of a cell. The pathway starts with reception of a signal, is characterized by activation of receptor-interacting serine/threonine-protein kinase 1 and/or 3 (RIPK1/3, also called RIP1/3), and ends when the execution phase of necroptosis is triggered. [GOC:mtg_apoptosis, PMID:20823910]
Full description |

Standard name | GO_MYELOID_LEUKOCYTE_MIGRATION
Systematic name | M10503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a myeloid leukocyte within or between different tissues and organs of the body. [GOC:cvs, PMID:22342843, PMID:24157461]
Full description |

Standard name | GO_GRANULOCYTE_MIGRATION
Systematic name | M13368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a granulocyte within or between different tissues and organs of the body. [GOC:cvs, PMID:24163421, PMID:24193336]
Full description |

Standard name | GO_MAST_CELL_MIGRATION
Systematic name | M24780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a mast cell within or between different tissues and organs of the body. [GOC:cvs, PMID:24152847]
Full description |

Standard name | GO_CALCIUM_ION_TRANSMEMBRANE_IMPORT_INTO_CYTOSOL
Systematic name | M24781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a calcium ion is transported from one side of a membrane to the other into the cytosol by means of some agent such as a transporter or pore. [GOC:vw]
Full description |

Standard name | GO_SEQUESTERING_OF_IRON_ION
Systematic name | M24782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process of binding or confining iron ions such that they are separated from other components of a biological system. [GOC:mr, PMID:3099306]
Full description |

Standard name | GO_LAMELLIPODIUM_ORGANIZATION
Systematic name | M14411
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a lamellipodium. A lamellipodium is a thin sheetlike process extended by the leading edge of a crawling fibroblast; contains a dense meshwork of actin filaments. [GOC:als, PMID:16054028]
Full description |

Standard name | GO_POTASSIUM_ION_EXPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M24783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of potassium ions from inside of a cell, across the plasma membrane and into the extracellular region. [GOC:vw, PMID:11932440]
Full description |

Standard name | GO_L_ARGININE_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M34264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-arginine from outside of a cell, across the plasma membrane and into the cytosol. [GOC:krc, PMID:8195186]
Full description |

Standard name | GO_CALCITONIN_FAMILY_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals initiated by an extracellular member of the calcitonin family (e.g. adrenomedullin, adrenomedullin 2 (intermedin), amylin, calcitonin and calcitonin gene-related peptides (CGRPs)) combining with a calcitonin family receptor on the surface of the target cell. Calcitonin family receptors may form dimers, trimers or tetramers; adrenomedullin and amylin receptors have only been observed as dimers so far. [GOC:bhm, PMID:10871296, PMID:12037140, PMID:18687416]
Full description |

Standard name | GO_DOUBLE_STRAND_BREAK_REPAIR_VIA_CLASSICAL_NONHOMOLOGOUS_END_JOINING
Systematic name | M29301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An instance of double-strand break repair via nonhomologous end joining that requires a number of factors important for V(D)J recombination, including the KU70/80 heterodimer (KU), XRCC4, ligase IV, and DNA-PKcs in mammals. It does not produce translocations (as opposed to the alternative nonhomologous end joining). [GOC:rph, PMID:18584027]
Full description |

Standard name | GO_HISTONE_H3_K4_MONOMETHYLATION
Systematic name | M34265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of one methyl group to lysine at position 4 of the histone. [GOC:jh2, PMID:26320581]
Full description |

Standard name | GO_RECEPTOR_SIGNALING_PATHWAY_VIA_STAT
Systematic name | M24785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | An intracellular signal transduction process in which STAT proteins (Signal Transducers and Activators of Transcription) convey a signal to trigger a change in the activity or state of a cell. The STAT cascade begins with receptor activation followed by activation of STAT proteins by kinases. It proceeds through STA dimerization and subsequent nuclear translocation of STAT proteins, and ends with regulation of target gene expression by STAT proteins. [GOC:rjd, PMID:21534947, PMID:24587195]
Full description |

Standard name | GO_CONNECTIVE_TISSUE_REPLACEMENT
Systematic name | M24786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events leading to growth of connective tissue when loss of tissues that are incapable of regeneration occurs, or when fibrinous exudate cannot be adequately cleared. [GOC:bc, GOC:BHF, GOC:BHF_miRNA, PMID:25590961]
Full description |

Standard name | GO_CILIARY_BASAL_BODY_PLASMA_MEMBRANE_DOCKING
Systematic name | M24787
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The docking of a cytosolic centriole/basal body to the plasma membrane via the ciliary transition fibers. In some species this may happen via an intermediate step, by first docking to the ciliary vesicle via the ciliary transition fibers. The basal body-ciliary vesicle then relocates to the plasma membrane, followed by the ciliary vesicle fusing with the plasma membrane, effectively attaching the basal body to the plasma membrane. [GOC:cilia, PMID:13978319, PMID:23348840, PMID:23530209, PMID:25686250, PMID:26981235, Reactome:R-HSA-5620912.1]
Full description |

Standard name | GO_CALCINEURIN_MEDIATED_SIGNALING
Systematic name | M24788
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any intracellular signal transduction in which the signal is passed on within the cell by activation of a transcription factor as a consequence of dephosphorylation by Ca(2+)-activated calcineurin. The process begins with calcium-dependent activation of the phosphatase calcineurin. Calcineurin is a calcium- and calmodulin-dependent serine/threonine protein phosphatase with a conserved function in eukaryotic species from yeast to humans. In yeast and fungi, calcineurin regulates stress signaling and cell cycle, and sporulation and virulence in pathogenic fungi. In metazoans, calcineurin is involved in cell commitment, organogenesis and organ development and immune function of T-lymphocytes. By a conserved mechanism, calcineurin phosphatase activates fungal Crz1 and mammalian NFATc by dephosphorylation and translocation of these transcription factors to the nucleus to regulate gene expression. [GOC:di, PMID:25655284, PMID:25878052, PMID:26851544]
Full description |

Standard name | GO_SPERM_MOTILITY
Systematic name | M11766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process involved in the controlled movement of a sperm cell. [GOC:cilia, GOC:krc]
Full description |

Standard name | GO_DE_NOVO_CENTRIOLE_ASSEMBLY
Systematic name | M24789
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Centriole assembly in which a centriole arises de novo, rather than by replication from an existing centriole. This process may occur via different mechanisms. Examples include the deuterosome pathway in multicilated epithelial animal cells and formation of centrioles during parthenogenesis in some insects. [GOC:cilia, PMID:25047614, PMID:25291643]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BLOOD_VESSEL_DIAMETER
Systematic name | M24790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the diameter of blood vessels. [GOC:pr]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BLOOD_VESSEL_DIAMETER
Systematic name | M24791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that decreases the diameter of blood vessels. [GOC:pr]
Full description |

Standard name | GO_SKELETAL_MUSCLE_FIBER_DIFFERENTIATION
Systematic name | M24793
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires specialized features of a skeletal muscle fiber cell. Skeletal muscle fiber differentiation starts with myoblast fusion and the appearance of specific cell markers (this is the cell development step). Then individual skeletal muscle fibers fuse to form bigger myotubes and start to contract. [GOC:dos]
Full description |

Standard name | GO_HISTONE_H3_K27_TRIMETHYLATION
Systematic name | M24794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H3 by addition of three methyl groups to lysine at position 27 of the histone. [PMID:19270745]
Full description |

Standard name | GO_CENTRIOLE_ASSEMBLY
Systematic name | M12352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the assembly of one or more centrioles. [GOC:dos, PMID:24075808]
Full description |

Standard name | GO_DEFENSE_RESPONSE_TO_OTHER_ORGANISM
Systematic name | M12514
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Reactions triggered in response to the presence of another organism that act to protect the cell or organism from damage caused by that organism. [GOC:dos]
Full description |

Standard name | GO_DETECTION_OF_OTHER_ORGANISM
Systematic name | M11462
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which a stimulus from another organism is received and converted into a molecular signal. [GOC:dos]
Full description |

Standard name | GO_DETECTION_OF_EXTERNAL_BIOTIC_STIMULUS
Systematic name | M24795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The series of events in which an external biotic stimulus is detected and converted into a molecular signal. An external biotic stimulus is defined as one caused or produced by a living organism other than the one being stimulated. [GOC:dos]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_VIRUS
Systematic name | M10352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a virus. [GOC:dos]
Full description |

Standard name | GO_OBSERVATIONAL_LEARNING
Systematic name | M24796
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Learning that occurs through observing the behavior of others. [GOC:dos, Wikipedia:Observational_learning&oldid=603524137]
Full description |

Standard name | GO_LEARNED_VOCALIZATION_BEHAVIOR_OR_VOCAL_LEARNING
Systematic name | M24797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Vocalisation behavior that is the result of learning, or the process by which new vocalizations are learned. [GOC:BHF, GOC:dos, GOC:rl, PMID:16418265, PMID:17035521]
Full description |

Standard name | GO_CELL_CELL_ADHESION
Systematic name | M12087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of one cell to another cell via adhesion molecules. [GOC:dos]
Full description |

Standard name | GO_CATION_TRANSMEMBRANE_TRANSPORT
Systematic name | M24798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a cation is transported across a membrane. [GOC:dos, GOC:vw]
Full description |

Standard name | GO_ANION_TRANSMEMBRANE_TRANSPORT
Systematic name | M11169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an anion is transported across a membrane. [GOC:dos, GOC:vw]
Full description |

Standard name | GO_IMPORT_INTO_CELL
Systematic name | M15727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of some substance from outside of a cell into a cell. This may occur via transport across the plasma membrane or via endocytosis. [GOC:dos]
Full description |

Standard name | GO_INORGANIC_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M16329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an inorganic ion is transported across a membrane. [GOC:mah]
Full description |

Standard name | GO_INORGANIC_ANION_TRANSMEMBRANE_TRANSPORT
Systematic name | M24799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an inorganic anion is transported across a membrane. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_VESICLE_CYCLE
Systematic name | M24800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the synaptic vesicle cycle. [GOC:dos]
Full description |

Standard name | GO_REGULATION_OF_NEUROTRANSMITTER_RECEPTOR_LOCALIZATION_TO_POSTSYNAPTIC_SPECIALIZATION_MEMBRANE
Systematic name | M24801
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neurotransmitter receptor localization to postsynaptic specialization membrane. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_SPECIALIZATION_ASSEMBLY
Systematic name | M24802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a postsynaptic specialization, a region that lies adjacent to the cytoplasmic face of the postsynaptic membrane. [GOC:dos]
Full description |

Standard name | GO_NEUROTRANSMITTER_LOADING_INTO_SYNAPTIC_VESICLE
Systematic name | M24803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The active transport of neurotransmitters into a synaptic vesicle. This import is fuelled by an electrochemical gradient across the vesicle membrane, established by the action of proton pumps. [GOC:bf, GOC:pad, GOC:PARL, PMID:10099709, PMID:15217342]
Full description |

Standard name | GO_CARBOHYDRATE_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M34266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a carbohydrate from outside of a cell, across the plasma membrane and into the cytosol. [GOC:dos]
Full description |

Standard name | GO_GLUCOSE_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M34267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of glucose from outside of a cell, across the plasma membrane and into the cytosol. [GOC:dos]
Full description |

Standard name | GO_IRON_ION_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M34268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of iron ions from outside of a cell, across the plasma membrane and into the cytosol. [GOC:mah, PMID:8321236]
Full description |

Standard name | GO_LEUCINE_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M34269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of leucine from outside of a cell, across the plasma membrane and into the cytosol. [GOC:dos]
Full description |

Standard name | GO_SODIUM_ION_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M24804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of sodium ions from outside of a cell, across the plasma membrane and into the cytosol. [GOC:dos]
Full description |

Standard name | GO_ASYMMETRIC_STEM_CELL_DIVISION
Systematic name | M24805
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Division of a stem cell during which it retains its identity and buds off a daughter cell with a new identity. [GOC:dos, PMID:18513950]
Full description |

Standard name | GO_MAINTENANCE_OF_CELL_NUMBER
Systematic name | M13800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process by which the numbers of cells of a particular type or in a tissue are maintained. [GOC:dos]
Full description |

Standard name | GO_MACROMOLECULE_DEACYLATION
Systematic name | M11076
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of an acyl group, any group or radical of the form RCO- where R is an organic group, from a macromolecule. [GOC:dos]
Full description |

Standard name | GO_MACROMOLECULE_DEPALMITOYLATION
Systematic name | M24806
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The removal of palymitoyl groups from a macromolecule. [GOC:dos]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_THE_FORCE_OF_HEART_CONTRACTION
Systematic name | M24807
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the force of heart muscle contraction. [GOC:BHF, GOC:dos, GOC:mtg_cardiac_conduct_nov11, GOC:rl, PMID:17242280]
Full description |

Standard name | GO_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M24808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of some substance from outside of a cell, across the plasma membrane and into the cytosol. [GOC:dos]
Full description |

Standard name | GO_CELL_CELL_ADHESION_VIA_PLASMA_MEMBRANE_ADHESION_MOLECULES
Systematic name | M16429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of one cell to another cell via adhesion molecules that are at least partially embedded in the plasma membrane. [GOC:dos]
Full description |

Standard name | GO_CELL_AGGREGATION
Systematic name | M13025
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The clustering together and adhesion of initially separate cells to form an aggregate. Examples include the clustering of unicellular organisms or blood cells in suspension and the condensation of mesenchymal cells during cartilage formation. [GOC:dos]
Full description |

Standard name | GO_BONE_CELL_DEVELOPMENT
Systematic name | M11179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a bone cell over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. [GOC:dos]
Full description |

Standard name | GO_DETOXIFICATION
Systematic name | M13476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that reduces or removes the toxicity of a toxic substance. These may include transport of the toxic substance away from sensitive areas and to compartments or complexes whose purpose is sequestration of the toxic substance. [GOC:dos]
Full description |

Standard name | GO_RESPONSE_TO_INTERLEUKIN_7
Systematic name | M24809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-7 stimulus. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_SKIN_EPIDERMIS_DEVELOPMENT
Systematic name | M34270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of the skin epidermis over time, from its formation to the mature structure. [GOC:dos]
Full description |

Standard name | GO_RESPONSE_TO_MITOCHONDRIAL_DEPOLARISATION
Systematic name | M24810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) in response to the depolarization of one or more mitochondria. [GOC:dos]
Full description |

Standard name | GO_NCRNA_TRANSCRIPTION
Systematic name | M12478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transcription of non (protein) coding RNA from a DNA template. [GOC:dos]
Full description |

Standard name | GO_MRNA_CLEAVAGE_INVOLVED_IN_MRNA_PROCESSING
Systematic name | M24811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cleavage of an immature mRNA transcript to produce one or more more mature mRNA transcripts, prior to translation into polypeptide. [GOC:dos]
Full description |

Standard name | GO_XENOPHAGY
Systematic name | M11496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The selective autophagy process in which a region of cytoplasm containing an intracellular pathogen or some part of an intracellular pathogen (e.g. viral capsid) is enclosed in a double membrane bound autophagosome, which then fuses with the lysosome leading to degradation of the contents. [GOC:autophagy, GOC:pad, GOC:PARL, PMID:19802565, PMID:20159618, PMID:25497060]
Full description |

Standard name | GO_REGULATION_OF_RENAL_SYSTEM_PROCESS
Systematic name | M15521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a system process, a multicellular organismal process carried out by the renal system. [GOC:dos]
Full description |

Standard name | GO_NEUROTRANSMITTER_REUPTAKE
Systematic name | M24812
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of neurotransmitter molecules from the extrasynaptic space into the presynaptic cytosol. [GOC:dos]
Full description |

Standard name | GO_NUCLEAR_CHROMOSOME_SEGREGATION
Systematic name | M16660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which genetic material, in the form of nuclear chromosomes, is organized into specific structures and then physically separated and apportioned to two or more sets. Nuclear chromosome segregation begins with the condensation of chromosomes, includes chromosome separation, and ends when chromosomes have completed movement to the spindle poles. [GOC:dos]
Full description |

Standard name | GO_SPONTANEOUS_SYNAPTIC_TRANSMISSION
Systematic name | M24813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The low level of synaptic transmission that occurs via spontaneous neurotransmitter release into the synaptic cleft in the absence of a presynaptic action potential. [PMID:20200227]
Full description |

Standard name | GO_MODULATION_OF_EXCITATORY_POSTSYNAPTIC_POTENTIAL
Systematic name | M13703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of excitatory postsynaptic potential (EPSP). EPSP is a process that leads to a temporary increase in postsynaptic potential due to the flow of positively charged ions into the postsynaptic cell. The flow of ions that causes an EPSP is an excitatory postsynaptic current (EPSC) and makes it easier for the neuron to fire an action potential. [GOC:dos]
Full description |

Standard name | GO_FOLATE_TRANSMEMBRANE_TRANSPORT
Systematic name | M24814
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a folic acid, or one of its derivatives (dihydrofolate, tetrahydrofolate, methylene-tetrahydrofolate or methyl-tetrahydrofolate) is transported across a membrane. [PMID:24745983]
Full description |

Standard name | GO_PROTEIN_TRANSPORT_ALONG_MICROTUBULE
Systematic name | M13759
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein along a microtubule, mediated by motor proteins. [PMID:25987607]
Full description |

Standard name | GO_INTESTINAL_LIPID_ABSORPTION
Systematic name | M24815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which lipids are taken up from the contents of the intestine. [GOC:dos, GOC:sl, PMID:18768481]
Full description |

Standard name | GO_BONE_GROWTH
Systematic name | M11652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The increase in size or mass of a bone that contributes to the shaping of that bone. [GOC:dos]
Full description |

Standard name | GO_CELLULAR_OXIDANT_DETOXIFICATION
Systematic name | M34271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process carried out at the cellular level that reduces or removes the toxicity superoxide radicals or hydrogen peroxide. [GOC:dos, GOC:vw]
Full description |

Standard name | GO_VESICLE_MEDIATED_TRANSPORT_TO_THE_PLASMA_MEMBRANE
Systematic name | M24816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances to the plasma membrane in transport vesicles that fuse with the plasma membrane by exocytosis. [GOC:dos]
Full description |

Standard name | GO_MAINTENANCE_OF_POSTSYNAPTIC_SPECIALIZATION_STRUCTURE
Systematic name | M24817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process which maintains the organization and the arrangement of proteins in the presynaptic specialization. [GOC:dos]
Full description |

Standard name | GO_SYNAPSE_PRUNING
Systematic name | M24819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular process that results in the controlled breakdown of synapse. After it starts the process is continuous until the synapse has disappeared. [GOC:dos, PMID:12062020, PMID:18083105, PMID:22632716, PMID:29844190]
Full description |

Standard name | GO_POSTSYNAPTIC_NEUROTRANSMITTER_RECEPTOR_INTERNALIZATION
Systematic name | M24820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A receptor-mediated endocytosis process that results in the internalization of a neurotransmitter receptor from the postsynaptic membrane endocytic zone into an endocytic vesicle. [GOC:dos]
Full description |

Standard name | GO_MODIFICATION_OF_POSTSYNAPTIC_ACTIN_CYTOSKELETON
Systematic name | M24821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modifies the structure of a postsynaptic actin cytoskeleton. [GOC:dos]
Full description |

Standard name | GO_NEUROTRANSMITTER_RECEPTOR_TRANSPORT_ENDOSOME_TO_POSTSYNAPTIC_MEMBRANE
Systematic name | M34272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of neurotransmitter receptor from the postsynaptic endosome to the postsynaptic membrane in transport vesicles. [GOC:dos]
Full description |

Standard name | GO_REGULATION_OF_ACTION_POTENTIAL
Systematic name | M13868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of action potential creation, propagation or termination. This typically occurs via modulation of the activity or expression of voltage-gated ion channels. [GOC:dos, GOC:dph, GOC:go_curators, GOC:tb, ISBN:978-0-07-139011-8]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M13362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of action potential creation, propagation or termination in a cardiac muscle cell. This typically occurs via modulation of the activity or expression of voltage-gated ion channels. [GOC:dos, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_DEPOLARIZATION_DURING_ACTION_POTENTIAL
Systematic name | M24822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of membrane depolarization during an action potential. Membrane depolarization is the process in which membrane potential changes in the depolarizing direction from the resting potential. [GOC:dos, GOC:dph, GOC:tb, ISBN:978-0-07-139011-8]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_REPOLARIZATION_DURING_ACTION_POTENTIAL
Systematic name | M24823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the rate, frequency or extent of membrane repolarization during an action potential. Membrane repolarization is the process in which membrane potential changes in the repolarizing direction, towards the resting potential. [GOC:dos, GOC:dph, GOC:tb, ISBN:978-0-07-139011-8]
Full description |

Standard name | GO_REGULATION_OF_NEURONAL_ACTION_POTENTIAL
Systematic name | M24824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of action potential creation, propagation or termination in a neuron. This typically occurs via modulation of the activity or expression of voltage-gated ion channels. [GOC:dph, GOC:isa_complete, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL_INVOLVED_IN_REGULATION_OF_CONTRACTION
Systematic name | M24825
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of action potential creation, propagation or termination in a cardiac muscle cell contributing to the regulation of its contraction. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_REGULATION_OF_ATRIAL_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M24826
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of action potential creation, propagation or termination in an atrial cardiac muscle cell contributing to the regulation of its contraction. This typically occurs via modulation of the activity or expression of voltage-gated ion channels. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_REGULATION_OF_VENTRICULAR_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M12329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of action potential creation, propagation or termination in a ventricular cardiac muscle cell contributing to the regulation of its contraction. This typically occurs via modulation of the activity or expression of voltage-gated ion channels. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_MEMBRANE_REPOLARIZATION_DURING_ATRIAL_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M24827
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which ions are transported across a membrane such that the atrial cardiomyocyte membrane potential changes in the direction from the positive membrane potential at the peak of the action potential towards the negative resting potential. [GOC:dph, GOC:mtg_cardiac_conduct_nov11, GOC:tb]
Full description |

Standard name | GO_MEMBRANE_REPOLARIZATION_DURING_VENTRICULAR_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M24828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which ions are transported across a membrane such that the ventricular cardiomyocyte membrane potential changes in the direction from the positive membrane potential at the peak of the action potential towards the negative resting potential. [GOC:BHF, GOC:dph, GOC:mtg_cardiac_conduct_nov11, GOC:tb]
Full description |

Standard name | GO_RETROGRADE_TRANS_SYNAPTIC_SIGNALING
Systematic name | M24829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell-cell signaling from post to pre-synapse, across the synaptic cleft. [GOC:dos]
Full description |

Standard name | GO_RETROGRADE_TRANS_SYNAPTIC_SIGNALING_BY_LIPID
Systematic name | M24830
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell-cell signaling from postsynapse to presynapse, across the synaptic cleft, mediated by a lipid ligand. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_SIGNAL_TRANSDUCTION
Systematic name | M24831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Signal transduction in which the initial step occurs in a postsynapse. [GOC:dos]
Full description |

Standard name | GO_VESICLE_MEDIATED_TRANSPORT_BETWEEN_ENDOSOMAL_COMPARTMENTS
Systematic name | M14502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A cellular transport process in which transported substances are moved in membrane-bounded vesicles between endosomal compartments, e.g, between early endosome and sorting endosome. [GOC:dos, PMID:10930469]
Full description |

Standard name | GO_AXONAL_TRANSPORT
Systematic name | M34273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of organelles or molecules along microtubules in axons. [ISBN:0815316194]
Full description |

Standard name | GO_DENDRITIC_TRANSPORT
Systematic name | M24833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of organelles or molecules along microtubules in dendrites. [ISBN:0815316194]
Full description |

Standard name | GO_ANTEROGRADE_DENDRITIC_TRANSPORT
Systematic name | M24834
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of organelles or molecules along microtubules from the cell body toward the postsynapse in dendrites. [ISBN:0815316194]
Full description |

Standard name | GO_NEUROTRANSMITTER_RECEPTOR_TRANSPORT_POSTSYNAPTIC_ENDOSOME_TO_LYSOSOME
Systematic name | M24835
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of neurotransmitter receptor from the postsynaptic endosome in tranpsort vesicles to the lysosome for degradation. [GOC:dos]
Full description |

Standard name | GO_RECEPTOR_DIFFUSION_TRAPPING
Systematic name | M24836
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process by which a membrane receptor, diffusing freely within the plasma membeane, becomes trapped in some plasma membrane region. This can happen when a receptor bind, directly or indirectly, to some component of the underlying matrix. [PMID:18832033]
Full description |

Standard name | GO_ANTEROGRADE_AXONAL_TRANSPORT_OF_MITOCHONDRION
Systematic name | M34274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of mitochondria along microtubules in axons away from the cell body and towards the presynapse. [GOC:dos]
Full description |

Standard name | GO_REGULATION_OF_POSTSYNAPTIC_NEUROTRANSMITTER_RECEPTOR_ACTIVITY
Systematic name | M24837
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neurotransmitter receptor activity involved in synaptic transmission. Modulation may be via an effect on ligand affinity, or effector funtion such as ion selectivity or pore opening/closing in ionotropic receptors. [GOC:dos]
Full description |

Standard name | GO_EXOCYTIC_INSERTION_OF_NEUROTRANSMITTER_RECEPTOR_TO_POSTSYNAPTIC_MEMBRANE
Systematic name | M29302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The exocytic fusion of neurotransmitter receptor containing vesicles with the postsynaptic membrane resulting in the integration of NT receptors, enabling them to participate in neurotransmitter reception. This process includes tethering and docking steps that prepare vesicles for fusion. [PMID:19503082]
Full description |

Standard name | GO_EXCITATORY_CHEMICAL_SYNAPTIC_TRANSMISSION
Systematic name | M24839
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Synaptic transmission that results in an excitatory postsynaptic potential. [GOC:dos]
Full description |

Standard name | GO_VESICLE_MEDIATED_TRANSPORT_IN_SYNAPSE
Systematic name | M24840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any vesicle-mediated transport that occurs in a synapse. [GOC:dos]
Full description |

Standard name | GO_CALMODULIN_DEPENDENT_KINASE_SIGNALING_PATHWAY
Systematic name | M24841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any signal transduction pathway involving calmodulin dependent kinase activity. [GOC:dos]
Full description |

Standard name | GO_MODIFICATION_OF_POSTSYNAPTIC_STRUCTURE
Systematic name | M24842
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modifies the structure of a postsynapse. [GOC:dos]
Full description |

Standard name | GO_VESICLE_TETHERING
Systematic name | M24843
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial, indirect interaction between a vesicle membrane and a membrane to which it is targeted for fusion. This interaction is mediated by tethering factors (or complexes), which interact with both membranes. Interaction can occur via direct binding to membrane phospholipids or membrane proteins, or via binding to vesicle coat proteins. This process is distinct from and prior to interaction between factors involved in fusion. [PMID:27243008]
Full description |

Standard name | GO_VESICLE_TETHERING_TO_GOLGI
Systematic name | M29303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The initial, indirect interaction between a transport vesicle membrane and the membrane of the Golgi. This interaction is mediated by tethering factors (or complexes), which interact with both membranes. Interaction can occur via direct binding to membrane phospholipids or membrane proteins, or via binding to vesicle coat proteins. This process is distinct from and prior fusion. [PMID:27243008]
Full description |

Standard name | GO_POSTSYNAPSE_ASSEMBLY
Systematic name | M24844
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a postsynapse. [GOC:bf, GOC:dos, GOCL:PARL]
Full description |

Standard name | GO_REGULATION_OF_POSTSYNAPTIC_MEMBRANE_NEUROTRANSMITTER_RECEPTOR_LEVELS
Systematic name | M24845
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that regulates the the local concentration of neurotransmitter receptor at the postsynaptic membrane. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_SPECIALIZATION_ORGANIZATION
Systematic name | M24846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that results in the assembly, arrangement of constituent parts, or disassembly of a postsynaptic specialization, a structure that lies adjacent to the cytoplasmic face of the postsynaptic membrane. [GOC:BHF, GOC:sjp, PMID:21525273, PMID:26834556]
Full description |

Standard name | GO_MICROTUBULE_BASED_TRANSPORT
Systematic name | M29304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A microtubule-based process that results in the transport of organelles, other microtubules, or other cellular components. Examples include motor-driven movement along microtubules and movement driven by polymerization or depolymerization of microtubules. [GOC:cjm, ISBN:0815316194]
Full description |

Standard name | GO_TRNA_5_END_PROCESSING
Systematic name | M24847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the 5' end of a pre-tRNA molecule is converted to that of a mature tRNA. [GOC:dos, GOC:pf, PMID:27484477]
Full description |

Standard name | GO_REGULATION_OF_POSTSYNAPTIC_NEUROTRANSMITTER_RECEPTOR_INTERNALIZATION
Systematic name | M24849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endocytosis of neurotransmitter receptor at the postsynapse. [GOC:ai]
Full description |

Standard name | GO_REGULATION_OF_POSTSYNAPTIC_SPECIALIZATION_ASSEMBLY
Systematic name | M24850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of postsynaptic specialization assembly, the aggregation, arrangement and bonding together of a set of components to form a postsynaptic specialization. [GOC:dos]
Full description |

Standard name | GO_REGULATION_OF_MODIFICATION_OF_POSTSYNAPTIC_STRUCTURE
Systematic name | M24851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of modification of postsynaptic structure. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_MODULATION_OF_CHEMICAL_SYNAPTIC_TRANSMISSION
Systematic name | M24852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process, acting in the postsynapse that results in modulation of chemical synaptic transmission. [GOC:dos]
Full description |

Standard name | GO_PRESYNAPTIC_MODULATION_OF_CHEMICAL_SYNAPTIC_TRANSMISSION
Systematic name | M24853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process, acting in the presynapse that results in modulation of chemical synaptic transmission. [GOC:dos]
Full description |

Standard name | GO_PRESYNAPSE_ORGANIZATION
Systematic name | M24854
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a presynapse. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPSE_ORGANIZATION
Systematic name | M24855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a postsynapse. [GOC:dos]
Full description |

Standard name | GO_REGULATION_OF_PRESYNAPSE_ORGANIZATION
Systematic name | M24856
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the physical form of a presynapse. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_POSTSYNAPSE_ORGANIZATION
Systematic name | M24857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the physical form of a postsynapse. [GOC:ai, GOC:dph, GOC:tb]
Full description |

Standard name | GO_REGULATION_OF_TRANS_SYNAPTIC_SIGNALING
Systematic name | M24858
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of trans-synaptic signaling. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_CYTOSKELETON_ORGANIZATION
Systematic name | M24859
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of cytoskeletal structures comprising cytoskeletal filaments and their associated proteins in the postsynaptic cytoskeleton. [GOC:dos]
Full description |

Standard name | GO_VESICLE_FUSION_TO_PLASMA_MEMBRANE
Systematic name | M12537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Fusion of the membrane of a vesicle with the plasma membrane, thereby releasing its contents into the extracellular space. [GOC:aruk, GOC:bc, ISBN:0071120009, PMID:18618940]
Full description |

Standard name | GO_REGULATION_OF_PRESYNAPTIC_MEMBRANE_POTENTIAL
Systematic name | M24860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the potential difference across a presynaptic membrane. [GOC:dph, GOC:ef]
Full description |

Standard name | GO_REGULATION_OF_PRESYNAPTIC_CYTOSOLIC_CALCIUM_ION_CONCENTRATION
Systematic name | M24861
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that regulates the concentration of calcium in the presynaptic cytosol. [GOC:dos]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_CYTOSKELETAL_TRANSPORT
Systematic name | M10852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of synaptic vesicles along cytoskeletal fibers such as microfilaments or microtubules within a cell, powered by molecular motors. [GOC:dos]
Full description |

Standard name | GO_ACTIN_FILAMENT_BASED_TRANSPORT
Systematic name | M24862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transport of organelles or other particles from one location in the cell to another along actin filaments. [GOC:dos, GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_VESICLE_CYTOSKELETAL_TRAFFICKING
Systematic name | M12551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a vesicle along a cytoskeletal fiber such as a microtubule or and actin filament, mediated by motor proteins. [GOC:ecd, GOC:rl]
Full description |

Standard name | GO_PRESYNAPTIC_DENSE_CORE_VESICLE_EXOCYTOSIS
Systematic name | M24863
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The secretion of molecules (e.g. neuropeptides and neuromodulators such as serotonin and dopamine) contained within a membrane-bounced dense in response to increased presynaptic cytosolic calcium levels. [PMID:17553987, PMID:24653208]
Full description |

Standard name | GO_POSTSYNAPSE_TO_NUCLEUS_SIGNALING_PATHWAY
Systematic name | M29305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals that conveys information from the postsynapse to the nucleus via cytoskeletal transport of a protein from a postsynapse to the component to the nucleus where it affects biochemical processes that occur in the nucleus (e.g DNA transcription, mRNA splicing, or DNA/histone modifications). [GOC:dos, PMID:24317321, PMID:25652077]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_ENDOSOMAL_PROCESSING
Systematic name | M24864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which synaptic vesicles fuse to the presynaptic endosome followed by sorting of synaptic vesicle components and budding of new synaptic vesicles. [GOC:aruk, GOC:bc, GOC:dos]
Full description |

Standard name | GO_SYNAPTIC_SIGNALING
Systematic name | M14034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell-cell signaling to, from or within a synapse. [GOC:dos]
Full description |

Standard name | GO_TRANS_SYNAPTIC_SIGNALING_BY_LIPID
Systematic name | M24865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell-cell signaling from post to pre-synapse, across the synaptic cleft, mediated by a lipid. [GOC:dos]
Full description |

Standard name | GO_TRANS_SYNAPTIC_SIGNALING_BY_TRANS_SYNAPTIC_COMPLEX
Systematic name | M24866
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell-cell signaling between presynapse and postsynapse mediated by a trans-synaptic protein complex. [GOC:dos]
Full description |

Standard name | GO_TRANS_SYNAPTIC_SIGNALING_MODULATING_SYNAPTIC_TRANSMISSION
Systematic name | M24868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cell-cell signaling between presynapse and postsynapse, across the synaptic cleft, that modulates the synaptic transmission properties of the synapse. [GOC:dos]
Full description |

Standard name | GO_MAINTENANCE_OF_SYNAPSE_STRUCTURE
Systematic name | M24869
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that preserves the structural organistation and orientation of a synaptic cellular component such as the synaptic cytoskeleton and molecular scaffolds. [GOC:dos, PMID:24449494, PMID:25611509]
Full description |

Standard name | GO_SYNAPTIC_MEMBRANE_ADHESION
Systematic name | M24870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The attachment of presynaptic membrane to postsynaptic membrane via adhesion molecules that are at least partially embedded in the plasma membrane. [GOC:dos]
Full description |

Standard name | GO_MODIFICATION_OF_SYNAPTIC_STRUCTURE
Systematic name | M24871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modifies the structure/morphology of a synapse. [GOC:dos]
Full description |

Standard name | GO_CHEMICAL_SYNAPTIC_TRANSMISSION_POSTSYNAPTIC
Systematic name | M24872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The part of synaptic transmission occurring in the post-synapse: a signal transduction pathway consisting of neurotransmitter receptor activation and its effects on postsynaptic membrane potential and the ionic composition of the postsynaptic cytosol. [GOC:dos]
Full description |

Standard name | GO_REGULATION_OF_POSTSYNAPTIC_CYTOSOLIC_CALCIUM_ION_CONCENTRATION
Systematic name | M24873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that regulates the concentration of calcium in the postsynaptic cytosol. [GOC:dos]
Full description |

Standard name | GO_INORGANIC_ION_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M24874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of inorganic ions from outside of a cell, across the plasma membrane and into the cytosol. [GOC:dos]
Full description |

Standard name | GO_NEUROTRANSMITTER_RECEPTOR_INTERNALIZATION
Systematic name | M24875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A receptor-mediated endocytosis process that results in the internalization of a neurotransmitter receptor. [GOC:dos]
Full description |

Standard name | GO_REGULATION_OF_NEUROTRANSMITTER_RECEPTOR_ACTIVITY
Systematic name | M15384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neurotransmitter receptor activity. Modulation may be via an effect on ligand affinity, or effector funtion such as ion selectivity or pore opening/closing in ionotropic receptors. [GOC:dos]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_AXON
Systematic name | M24876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to or maintained in a location within an axon. [GOC:dos, PMID:26157139]
Full description |

Standard name | GO_CARDIAC_MUSCLE_CELL_MEMBRANE_REPOLARIZATION
Systematic name | M24877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which ions are transported across the plasma membrane of a cardiac muscle cell such that the membrane potential changes in the repolarizing direction, toward the steady state potential. For example, the repolarization during an action potential is from a positive membrane potential towards a negative resting potential. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_CELL_MEMBRANE_REPOLARIZATION
Systematic name | M12211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the establishment or extent of a change in membrane potential in the polarizing direction towards the resting potential in a cardiomyocyte. [GOC:BHF, GOC:dos, GOC:rl]
Full description |

Standard name | GO_ATRIAL_CARDIAC_MUSCLE_CELL_MEMBRANE_REPOLARIZATION
Systematic name | M24878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which ions are transported across the plasma membrane of an atrial cardiac muscle cell such that the membrane potential changes in the repolarizing direction, toward the steady state potential. For example, the repolarization during an action potential is from a positive membrane potential towards a negative resting potential. [GOC:BHF]
Full description |

Standard name | GO_VENTRICULAR_CARDIAC_MUSCLE_CELL_MEMBRANE_REPOLARIZATION
Systematic name | M24879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which ions are transported across the plasma membrane of a ventricular cardiac muscle cell such that the membrane potential changes in the repolarizing direction, toward the steady state potential. For example, the repolarization during an action potential is from a positive membrane potential towards a negative resting potential. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_NEUROTRANSMITTER_RECEPTOR_TRANSPORT
Systematic name | M29306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of neurotransmitter receptors. [GOC:dos]
Full description |

Standard name | GO_ENDOSOME_TO_PLASMA_MEMBRANE_PROTEIN_TRANSPORT
Systematic name | M24881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of proteins from the endosome to the plasma membrane in transport vesicles. [GOC:dos]
Full description |

Standard name | GO_AXO_DENDRITIC_PROTEIN_TRANSPORT
Systematic name | M24882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of proteins along microtubules in neuron projections. [ISBN:0815316194]
Full description |

Standard name | GO_ANTEROGRADE_AXONAL_PROTEIN_TRANSPORT
Systematic name | M24883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of proteins along microtubules from the cell body toward the cell periphery in nerve cell axons. [GOC:dos]
Full description |

Standard name | GO_NEUROTRANSMITTER_RECEPTOR_LOCALIZATION_TO_POSTSYNAPTIC_SPECIALIZATION_MEMBRANE
Systematic name | M24885
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a neurotransmitter is transported to, or maintained in, a location within the membrane adjacent to a postsynaptic specialization (e.g. postsynaptic density). [GOC:dos]
Full description |

Standard name | GO_REGULATION_OF_HEART_INDUCTION_BY_CANONICAL_WNT_SIGNALING_PATHWAY
Systematic name | M34275
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any canonical Wnt signaling pathway process that regulates heart induction. [GOC:cjm, GOC:obol]
Full description |

Standard name | GO_VASCULAR_ENDOTHELIAL_CELL_PROLIFERATION
Systematic name | M24886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of blood vessel endothelial cells, resulting in the expansion of a cell population. [GOC:BHF, GOC:BHF_telomere, GOC:nc, PMID:23201774]
Full description |

Standard name | GO_INTESTINAL_HEXOSE_ABSORPTION
Systematic name | M24887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Uptake of hexoses, notably D-glucose, fructose, and galactose, into the blood by absorption from the small intestine. [GOC:hjd]
Full description |

Standard name | GO_REGULATION_OF_INFLAMMATORY_RESPONSE_TO_WOUNDING
Systematic name | M24888
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the inflammatory response to wounding. [GOC:BHF, GOC:BHF_miRNA, GOC:rph, PMID:26022821]
Full description |

Standard name | GO_NEURON_PROJECTION_ORGANIZATION
Systematic name | M24889
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a prolongation or process extending from a neuron, e.g. an axon, or a dendrite. [GOC:aruk, GOC:bc, PMID:11585923]
Full description |

Standard name | GO_PROTEIN_MATURATION_BY_4FE_4S_CLUSTER_TRANSFER
Systematic name | M24890
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transfer of an assembled 4Fe-4S] cluster from a scaffold protein to an acceptor protein that contributes to the attainment of the full functional capacity of a protein. [PMID:23615440]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_RESPONSE_TO_OSMOTIC_STRESS
Systematic name | M24891
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the cellular response to osmotic stress. [PMID:10398679]
Full description |

Standard name | GO_REGULATION_OF_CALCINEURIN_MEDIATED_SIGNALING
Systematic name | M24892
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of calcineurin-mediated signaling. [PMID:25081204]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CALCINEURIN_MEDIATED_SIGNALING
Systematic name | M24893
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of calcineurin-mediated signalling. [PMID:25081204]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CALCINEURIN_MEDIATED_SIGNALING
Systematic name | M24894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of calcineurin-mediated signaling. [PMID:25081204]
Full description |

Standard name | GO_REGULATION_OF_ADENYLATE_CYCLASE_ACTIVATING_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24895
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of an adenylate cyclase-activating G protein-coupled receptor signaling pathway. [GOC:hjd, PMID:19246489]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ADENYLATE_CYCLASE_ACTIVATING_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24896
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of an adenylate cyclase-activating G protein-coupled receptor signaling pathway. [GOC:hjd, PMID:19246489]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ADENYLATE_CYCLASE_ACTIVATING_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24897
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of an adenylate cyclase-activating G protein-coupled receptor signaling pathway. [GOC:hjd, PMID:19246489]
Full description |

Standard name | GO_AMINOACYL_TRNA_METABOLISM_INVOLVED_IN_TRANSLATIONAL_FIDELITY
Systematic name | M24898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process which detects an amino-acid acetylated tRNA is charged with the correct amino acid, or removes incorrect amino acids from a charged tRNA. This process can be performed by tRNA synthases, or by subsequent reactions after tRNA aminoacylation. [GOC:hjd]
Full description |

Standard name | GO_REGULATION_OF_GLUTAMATE_RECEPTOR_CLUSTERING
Systematic name | M34276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glutamate receptor clustering. [GOC:ha, PMID:28455372]
Full description |

Standard name | GO_REGULATION_OF_ACTOMYOSIN_STRUCTURE_ORGANIZATION
Systematic name | M24899
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the assembly, arrangement of constituent parts, or disassembly of cytoskeletal structures containing both actin and myosin or paramyosin. [GOC:lf, PMID:22790195]
Full description |

Standard name | GO_CARDIAC_MUSCLE_MYOBLAST_PROLIFERATION
Systematic name | M24900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The multiplication or reproduction of cardiac muscle myoblasts, resulting in the expansion of a cardiac muscle myoblast cell population. A cardiac myoblast is a precursor cell that has been committed to a cardiac muscle cell fate but retains the ability to divide and proliferate throughout life. [GOC:BHF, GOC:BHF_miRNA, GOC:rph, PMID:26512644]
Full description |

Standard name | GO_REGULATION_OF_ACTIN_FILAMENT_ORGANIZATION
Systematic name | M24901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of actin filament organization. [GOC:kmv]
Full description |

Standard name | GO_CELLULAR_DETOXIFICATION_OF_ALDEHYDE
Systematic name | M24902
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process carried out at the cellular level that reduces or removes the toxicity of an aldehyde. These may include transport of aldehydes away from sensitive areas and to compartments or complexes whose purpose is sequestration of the toxic substance. [GOC:vw, PMID:25656103]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_ALDEHYDE
Systematic name | M24903
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an aldehyde stimulus. [GOC:vw, PMID:25656103]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ANIMAL_ORGAN_MORPHOGENESIS
Systematic name | M24904
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of animal organ morphogenesis. [GOC:kmv]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ANIMAL_ORGAN_MORPHOGENESIS
Systematic name | M24905
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of animal organ morphogenesis. [GOC:kmv]
Full description |

Standard name | GO_REGULATION_OF_LIPID_TRANSPORTER_ACTIVITY
Systematic name | M24906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate, or extent of lipid transporter activity. [GOC:BHF, GOC:BHF_miRNA, GOC:rph, PMID:27365390]
Full description |

Standard name | GO_BIOMINERALIZATION
Systematic name | M29307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process where mineral crystals are formed and deposited in an organized fashion in a matrix (either cellular or extracellular) by living organisms. This gives rise to inorganic compound-based structures such as skeleton, teeth, ivory, shells, cuticle, and corals as well as bacterial biomineralization products. [GOC:aa, PMID:24395694, PMID:28229486]
Full description |

Standard name | GO_REGULATION_OF_BIOMINERALIZATION
Systematic name | M29308
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of biomineralization, the formation and deposition of mineral crystals by living organisms. [PMID:22992051]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BIOMINERALIZATION
Systematic name | M29309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of biomineralization, the formation and deposition of mineral crystals by living organisms. [PMID:22992051]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BIOMINERALIZATION
Systematic name | M29310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of biomineralization, the formation and deposition of mineral crystals by living organisms. [PMID:22992051]
Full description |

Standard name | GO_RNA_DECAPPING
Systematic name | M29311
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Cleavage of the 5'-cap of an RNA. [GOC:sp, PMID:25533955, PMID:31101919]
Full description |

Standard name | GO_INTERMEMBRANE_LIPID_TRANSFER
Systematic name | M24907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The transport of lipids between membranes in which a lipid molecule is transported through an aqueous phase from the outer leaflet of a donor membrane to the outer leaflet of an acceptor membrane. This process does not require metabolic energy and can be either spontaneous or mediated by lipid transfer proteins (LTPs). [GOC:krc, PMID:20823909, PMID:24220498, PMID:25797198]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PLASMA_MEMBRANE_BOUNDED_CELL_PROJECTION_ASSEMBLY
Systematic name | M24908
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of plasma membrane bounded cell projection assembly. [GOC:krc]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PLASMA_MEMBRANE_BOUNDED_CELL_PROJECTION_ASSEMBLY
Systematic name | M24909
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of plasma membrane bounded cell projection assembly. [GOC:krc]
Full description |

Standard name | GO_REGULATION_OF_MACROPHAGE_PROLIFERATION
Systematic name | M34277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of macrophage proliferation. [GOC:BHF, GOC:BHF_miRNA, GOC:rph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_COLD_INDUCED_THERMOGENESIS
Systematic name | M24910
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cold-induced thermogenesis. [PMID:27876809]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_COLD_INDUCED_THERMOGENESIS
Systematic name | M24911
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the rate of cold-induced thermogenesis. [PMID:27876809]
Full description |

Standard name | GO_STEROID_HORMONE_BIOSYNTHETIC_PROCESS
Systematic name | M29312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of any steroid hormone, naturally occurring substances secreted by specialized cells that affects the metabolism or behavior of other cells possessing functional receptors for the hormone. [GOC:krc, GOC:nln]
Full description |

Standard name | GO_REGULATION_OF_FOCAL_ADHESION_DISASSEMBLY
Systematic name | M34278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of disaggregation of a focal adhesion into its constituent components. [PMID:25490267]
Full description |

Standard name | GO_MITOTIC_NUCLEAR_DIVISION
Systematic name | M13328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A mitotic cell cycle process comprising the steps by which the nucleus of a eukaryotic cell divides; the process involves condensation of chromosomal DNA into a highly compacted form. Canonically, mitosis produces two daughter nuclei whose chromosome complement is identical to that of the mother cell. [ISBN:0198547684]
Full description |

Standard name | GO_EXOCYTIC_PROCESS
Systematic name | M24913
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cellular processes that contribute to exocytosis. [Wikipedia:Exocytosis]
Full description |

Standard name | GO_LIPID_DROPLET_FORMATION
Systematic name | M34279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that results in the assembly, arrangement of constituent parts of a lipid droplet. [PMID:28011631]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_OXIDISED_LOW_DENSITY_LIPOPROTEIN_PARTICLE_STIMULUS
Systematic name | M24914
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an oxidized lipoprotein particle stimulus. [GOC:aruk, GOC:BHF, PMID:20037584, PMID:27607416]
Full description |

Standard name | GO_MITOCHONDRIAL_GENE_EXPRESSION
Systematic name | M24915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a mitochondrial gene's sequence is converted into a mature gene product or products (proteins or RNA). This includes the production of an RNA transcript as well as any processing to produce a mature RNA product or an mRNA or circRNA (for protein-coding genes) and the translation of that mRNA or circRNA into protein. Protein maturation is included when required to form an active form of a product from an inactive precursor form. [PMID:27058308]
Full description |

Standard name | GO_NEURON_PROJECTION_ARBORIZATION
Systematic name | M24916
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a neuron projection are generated and organized into branches. A neuron projection is any process extending from a neural cell, such as axons or dendrites. [GOC:aruk, GOC:bc, PMID:17114044, PMID:23270857, PMID:23764288]
Full description |

Standard name | GO_DENDRITE_ARBORIZATION
Systematic name | M24917
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which the anatomical structures of a dendritic tree are generated and organized into dendritic branches. [GOC:aruk, GOC:bc, PMID:23270857]
Full description |

Standard name | GO_EXTRACELLULAR_VESICLE_BIOGENESIS
Systematic name | M24918
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The assembly and secretion a set of components to form an extracellular vesicule, a membrane-bounded vesicle that is released into the extracellular region. Extracellular vesicles include exosomes, microvesicles and apoptotic bodies, based on the mechanism by which they are released from cells and differentiated based on their size and content. [PMID:28736435]
Full description |

Standard name | GO_EXPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M24919
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of some substance from inside of a cell, across the plasma membrane and into the extracellular region. [GOC:pg]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LYMPHOCYTE_CHEMOTAXIS
Systematic name | M24920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of lymphocyte chemotaxis. [PMID:19255442]
Full description |

Standard name | GO_REGULATION_OF_ADENYLATE_CYCLASE_ACTIVATING_ADRENERGIC_RECEPTOR_SIGNALING_PATHWAY_INVOLVED_IN_HEART_PROCESS
Systematic name | M24921
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of an adenylate cyclase-activating adrenergic receptor signaling pathway involved in some heart process. [GOC:BHF, GOC:BHF_miRNA, GOC:rph]
Full description |

Standard name | GO_REGULATION_OF_LONG_CHAIN_FATTY_ACID_IMPORT_INTO_CELL
Systematic name | M24922
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of long-chain fatty acid import into a cell. [PMID:28178239]
Full description |

Standard name | GO_PRESYNAPTIC_ENDOCYTOSIS
Systematic name | M34280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A vesicle-mediated transport process in which the presynapse take up external materials or membrane constituents by the invagination of a small region of the plasma membrane to form a new membrane-bounded vesicle. [PMID:24719103]
Full description |

Standard name | GO_LIPID_EXPORT_FROM_CELL
Systematic name | M29313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a lipid from a cell, into the extracellular region. [GOC:pg]
Full description |

Standard name | GO_LIPID_IMPORT_INTO_CELL
Systematic name | M29314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a lipid from outside of a cell into a cell. This may occur via transport across the plasma membrane or via endocytosis. [GOC:pg]
Full description |

Standard name | GO_SIGNALING_RECEPTOR_LIGAND_PRECURSOR_PROCESSING
Systematic name | M34281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The cleavage of a peptide bond in a precursor form of a signaling receptor ligand, resulting in the mature (active) form of the ligand. [PMID:29247995]
Full description |

Standard name | GO_REGULATION_OF_SPONTANEOUS_SYNAPTIC_TRANSMISSION
Systematic name | M24924
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of spontaneous synaptic transmission. [GOC:aruk, GOC:bc, PMID:15457210]
Full description |

Standard name | GO_REGULATION_OF_NEURON_PROJECTION_ARBORIZATION
Systematic name | M24925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the process in which the anatomical structures of a neuron projection are generated and organized into branches. [GOC:aruk, GOC:bc, PMID:17114044]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEURON_PROJECTION_ARBORIZATION
Systematic name | M29315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the process in which the anatomical structures of a neuron projection are generated and organized into branches. [GOC:aruk, GOC:bc, PMID:17114044]
Full description |

Standard name | GO_REGULATION_OF_DEACETYLASE_ACTIVITY
Systematic name | M24926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of deacetylase activity. [GOC:aruk, GOC:bc, PMID:19457097]
Full description |

Standard name | GO_NEUROINFLAMMATORY_RESPONSE
Systematic name | M24927
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The immediate defensive reaction by neural vertebrate tissue to infection or injury caused by chemical or physical agents. [GOC:aruk, GOC:bc, PMID:10981966, PMID:11099416, PMID:18164423]
Full description |

Standard name | GO_REGULATION_OF_NEUROINFLAMMATORY_RESPONSE
Systematic name | M24928
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neuroinflammatory response. [GOC:aruk, GOC:bc, PMID:10981966, PMID:11099416, PMID:18164423]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEUROINFLAMMATORY_RESPONSE
Systematic name | M24929
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of neuroinflammatory response. [GOC:aruk, GOC:bc]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEUROINFLAMMATORY_RESPONSE
Systematic name | M24930
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of neuroinflammatory response. [GOC:aruk, GOC:bc, PMID:11099416, PMID:18164423]
Full description |

Standard name | GO_AMYLOID_BETA_CLEARANCE_BY_TRANSCYTOSIS
Systematic name | M24931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which amyloid-beta is removed from extracellular brain regions by cell surface receptor-mediated endocytosis, followed by transcytosis across the blood-brain barrier. [GOC:aruk, GOC:bc, PMID:26005850]
Full description |

Standard name | GO_AMYLOID_BETA_CLEARANCE_BY_CELLULAR_CATABOLIC_PROCESS
Systematic name | M24932
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which amyloid-beta is removed from extracellular brain regions by cell surface receptor-mediated endocytosis, followed by intracellular degradation. [GOC:aruk, GOC:bc, PMID:18289866]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CELL_CELL_JUNCTION
Systematic name | M29317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained, in a location within a cell-cell junction. [GOC:aruk, GOC:bc, PMID:26706435]
Full description |

Standard name | GO_CELL_SUBSTRATE_JUNCTION_ORGANIZATION
Systematic name | M29318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of a cell-substrate junction. A cell-substrate junction is a specialized region of connection between a cell and the extracellular matrix. [GOC:aruk, GOC:bc, PMID:10419689, PMID:1643657, PMID:16805308, PMID:26923917, PMID:8314002]
Full description |

Standard name | GO_REGULATION_OF_CELL_SUBSTRATE_JUNCTION_ORGANIZATION
Systematic name | M34282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell-substrate junction organization. [GOC:aruk]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_SUBSTRATE_JUNCTION_ORGANIZATION
Systematic name | M29319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell-substrate junction organization. [GOC:aruk]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_SUBSTRATE_JUNCTION_ORGANIZATION
Systematic name | M29320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cell-substrate junction organization. [GOC:aruk]
Full description |

Standard name | GO_CELL_JUNCTION_DISASSEMBLY
Systematic name | M34283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disaggregation of a cell junction into its constituent components. [GOC:aruk, PMID:25490267]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHATIDYLCHOLINE_METABOLIC_PROCESS
Systematic name | M34284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of phosphatidylcholine metabolic process. [GOC:aruk, GOC:bc, PMID:30074985]
Full description |

Standard name | GO_CELL_CELL_SIGNALING_BY_WNT
Systematic name | M24933
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that mediates the transfer of information from one cell to another, medaited by a wnt family protein ligand. This process includes wnt signal transduction in the receiving cell, release of wnt ligand from a secreting cell as well as any processes that actively facilitate wnt transport and presentation to receptor on the recieving cell. [GOC:dos]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DENDRITE_DEVELOPMENT
Systematic name | M13461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of dendrite development. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYTOKINE_PRODUCTION_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M24934
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cytokine production involved in inflammatory response. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOKINE_PRODUCTION_INVOLVED_IN_INFLAMMATORY_RESPONSE
Systematic name | M24935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cytokine production involved in inflammatory response. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_KINASE_C_ACTIVITY
Systematic name | M24936
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein kinase C activity. [GOC:signaling, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_SUBSTRATE_ADHESION_DEPENDENT_CELL_SPREADING
Systematic name | M12343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of substrate adhesion-dependent cell spreading. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SUBSTRATE_ADHESION_DEPENDENT_CELL_SPREADING
Systematic name | M16820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of substrate adhesion-dependent cell spreading. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SUBSTRATE_ADHESION_DEPENDENT_CELL_SPREADING
Systematic name | M11525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of substrate adhesion-dependent cell spreading. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_RUFFLE_ASSEMBLY
Systematic name | M11232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ruffle assembly. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RUFFLE_ASSEMBLY
Systematic name | M24937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of ruffle assembly. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RUFFLE_ASSEMBLY
Systematic name | M24938
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of ruffle assembly. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_RESPONSE_TO_HEAT
Systematic name | M11699
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cellular response to heat. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_RESPONSE_TO_HYPOXIA
Systematic name | M12758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cellular response to hypoxia. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_RESPONSE_TO_HYPOXIA
Systematic name | M24939
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cellular response to hypoxia. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_K63_LINKED_UBIQUITINATION
Systematic name | M24941
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein K63-linked ubiquitination. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_K63_LINKED_UBIQUITINATION
Systematic name | M24942
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein K63-linked ubiquitination. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CERAMIDE_BIOSYNTHETIC_PROCESS
Systematic name | M29321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of a ceramide biosynthetic process. [GOC:TermGenie, PMID:15302821]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_RESPONSE_TO_INSULIN_STIMULUS
Systematic name | M15871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cellular response to insulin stimulus. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_RESPONSE_TO_INSULIN_STIMULUS
Systematic name | M10996
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cellular response to insulin stimulus. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_RESPONSE_TO_INSULIN_STIMULUS
Systematic name | M13645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cellular response to insulin stimulus. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDYL_TYROSINE_AUTOPHOSPHORYLATION
Systematic name | M24943
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of peptidyl-tyrosine autophosphorylation. [GOC:bf, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_G1_S_TRANSITION_OF_MITOTIC_CELL_CYCLE
Systematic name | M11801
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any signalling pathway that increases or activates a cell cycle cyclin-dependent protein kinase to modulate the switch from G1 phase to S phase of the mitotic cell cycle. [GOC:mtg_cell_cycle]
Full description |

Standard name | GO_REGULATION_OF_ENDOPLASMIC_RETICULUM_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M15498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endoplasmic reticulum unfolded protein response. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ENDOPLASMIC_RETICULUM_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M14363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of endoplasmic reticulum unfolded protein response. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOPLASMIC_RETICULUM_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M13959
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of endoplasmic reticulum unfolded protein response. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_NODAL_SIGNALING_PATHWAY
Systematic name | M24944
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of nodal signaling pathway. [GOC:BHF, GOC:TermGenie, GOC:vk]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_H3_K9_TRIMETHYLATION
Systematic name | M24945
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of histone H3-K9 trimethylation. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HISTONE_H3_K9_TRIMETHYLATION
Systematic name | M24946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of histone H3-K9 trimethylation. [GOC:TermGenie]
Full description |

Standard name | GO_EXTRACELLULAR_REGULATION_OF_SIGNAL_TRANSDUCTION
Systematic name | M13296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any regulation of signal transduction that takes place in the extracellular region. [GOC:signaling, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_EXECUTION_PHASE_OF_APOPTOSIS
Systematic name | M16835
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of execution phase of apoptosis. [GOC:mtg_apoptosis, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EXECUTION_PHASE_OF_APOPTOSIS
Systematic name | M24947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of execution phase of apoptosis. [GOC:mtg_apoptosis, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EXECUTION_PHASE_OF_APOPTOSIS
Systematic name | M16450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of execution phase of apoptosis. [GOC:mtg_apoptosis, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_RECEPTOR_BINDING
Systematic name | M11596
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a protein or other molecule binding to a receptor. [GOC:signaling, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RECEPTOR_BINDING
Systematic name | M16437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of a protein or other molecule binding to a receptor. [GOC:signaling, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RECEPTOR_BINDING
Systematic name | M24948
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of a protein or other molecule binding to a receptor. [GOC:signaling, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_HYALURONAN_BIOSYNTHETIC_PROCESS
Systematic name | M24949
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hyaluronan biosynthetic process. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_NODAL_SIGNALING_PATHWAY_INVOLVED_IN_DETERMINATION_OF_LEFT_RIGHT_ASYMMETRY
Systematic name | M24950
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a nodal signaling pathway, where the nodal signaling pathway is involved in determination of left/right asymmetry. [GOC:BHF, GOC:signaling, GOC:TermGenie, GOC:vk]
Full description |

Standard name | GO_REGULATION_OF_NUCLEAR_TRANSCRIBED_MRNA_CATABOLIC_PROCESS_DEADENYLATION_DEPENDENT_DECAY
Systematic name | M16889
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of nuclear-transcribed mRNA catabolic process, deadenylation-dependent decay. [GOC:mcc, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_BONE_MINERALIZATION_INVOLVED_IN_BONE_MATURATION
Systematic name | M24951
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of bone mineralization involved in bone maturation. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_NUCLEUS
Systematic name | M15292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to nucleus. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_NUCLEUS
Systematic name | M24954
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein localization to nucleus. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_NUCLEUS
Systematic name | M12260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein localization to nucleus. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_OOCYTE_MATURATION
Systematic name | M24955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of oocyte maturation. [GOC:kmv, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_AMYLOID_BETA_CLEARANCE
Systematic name | M24956
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of amyloid-beta clearance. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AMYLOID_BETA_CLEARANCE
Systematic name | M24957
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of amyloid-beta clearance. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AMYLOID_BETA_CLEARANCE
Systematic name | M24958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of amyloid-beta clearance. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NLRP3_INFLAMMASOME_COMPLEX_ASSEMBLY
Systematic name | M24959
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of NLRP3 inflammasome complex assembly. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NLRP3_INFLAMMASOME_COMPLEX_ASSEMBLY
Systematic name | M24960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of NLRP3 inflammasome complex assembly. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_PHENOTYPIC_SWITCHING
Systematic name | M24961
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of phenotypic switching. [GOC:di, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHENOTYPIC_SWITCHING
Systematic name | M24962
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of phenotypic switching. [GOC:di, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_VESICLE_ENDOCYTOSIS
Systematic name | M24963
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of synaptic vesicle endocytosis. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPTIC_VESICLE_ENDOCYTOSIS
Systematic name | M24964
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of synaptic vesicle endocytosis. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RIG_I_SIGNALING_PATHWAY
Systematic name | M24965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of RIG-I signaling pathway. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_DNA_DIRECTED_DNA_POLYMERASE_ACTIVITY
Systematic name | M24966
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA-directed DNA polymerase activity. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_LONG_TERM_SYNAPTIC_POTENTIATION
Systematic name | M14943
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of long-term synaptic potentiation. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LONG_TERM_SYNAPTIC_POTENTIATION
Systematic name | M24967
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of long-term synaptic potentiation. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LONG_TERM_SYNAPTIC_POTENTIATION
Systematic name | M14095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of long-term synaptic potentiation. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHOLIPASE_C_ACTIVITY
Systematic name | M10721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of phospholipase C activity. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_MRNA_POLYADENYLATION
Systematic name | M13860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mRNA polyadenylation. [GOC:se, GOC:TermGenie, PMID:15121841]
Full description |

Standard name | GO_REGULATION_OF_RNA_INTERFERENCE
Systematic name | M29323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of RNA interference. [GOC:kmv, GOC:TermGenie, PMID:22412382]
Full description |

Standard name | GO_REGULATION_OF_SECONDARY_METABOLITE_BIOSYNTHETIC_PROCESS
Systematic name | M34285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of secondary metabolite biosynthetic process. [GOC:di, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SECONDARY_METABOLITE_BIOSYNTHETIC_PROCESS
Systematic name | M24968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of secondary metabolite biosynthetic process. [GOC:di, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_DEFENSE_RESPONSE_TO_BACTERIUM
Systematic name | M16342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of defense response to bacterium. [GOC:TermGenie, PMID:22346749]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DEFENSE_RESPONSE_TO_BACTERIUM
Systematic name | M24970
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of defense response to bacterium. [GOC:TermGenie, PMID:22346749]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DEFENSE_RESPONSE_TO_BACTERIUM
Systematic name | M24971
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of defense response to bacterium. [GOC:TermGenie, PMID:22346749]
Full description |

Standard name | GO_REGULATION_OF_GLUTAMATE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24972
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glutamate receptor signaling pathway. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLUTAMATE_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24973
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of glutamate receptor signaling pathway. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_LONG_TERM_SYNAPTIC_DEPRESSION
Systematic name | M24974
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of long term synaptic depression. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LONG_TERM_SYNAPTIC_DEPRESSION
Systematic name | M24975
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of long term synaptic depression. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHOLIPASE_C_ACTIVATING_G_PROTEIN_COUPLED_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M24976
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of phospholipase C-activating G protein-coupled receptor signaling pathway. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_P38MAPK_CASCADE
Systematic name | M13817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of p38MAPK cascade. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_SIGNALING_PATHWAY
Systematic name | M24977
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vascular endothelial growth factor signaling pathway. [GOC:TermGenie]
Full description |

Standard name | GO_MITOCHONDRIAL_RNA_MODIFICATION
Systematic name | M24978
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any RNA modification that takes place in mitochondrion. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_POTASSIUM_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M15818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of potassium ion transmembrane transporter activity. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_POTASSIUM_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M13782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of potassium ion transmembrane transporter activity. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_CALCIUM_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M16440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of calcium ion transmembrane transporter activity. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CALCIUM_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M12908
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of calcium ion transmembrane transporter activity. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRIAL_OUTER_MEMBRANE_PERMEABILIZATION_INVOLVED_IN_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M14673
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mitochondrial outer membrane permeabilization involved in apoptotic signaling pathway. [GOC:BHF, GOC:mtg_apoptosis, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MITOCHONDRIAL_OUTER_MEMBRANE_PERMEABILIZATION_INVOLVED_IN_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M24979
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of mitochondrial outer membrane permeabilization involved in apoptotic signaling pathway. [GOC:BHF, GOC:mtg_apoptosis, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOCHONDRIAL_OUTER_MEMBRANE_PERMEABILIZATION_INVOLVED_IN_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M15559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of mitochondrial outer membrane permeabilization involved in apoptotic signaling pathway. [GOC:BHF, GOC:mtg_apoptosis, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_REACTIVE_OXYGEN_SPECIES
Systematic name | M16764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of response to reactive oxygen species. [GOC:kmv, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_REACTIVE_OXYGEN_SPECIES
Systematic name | M34286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of response to reactive oxygen species. [GOC:kmv, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_REACTIVE_OXYGEN_SPECIES
Systematic name | M24980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of response to reactive oxygen species. [GOC:kmv, GOC:TermGenie]
Full description |

Standard name | GO_GUANOSINE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M12092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving guanosine-containing compounds (guanosines). [GOC:TermGenie]
Full description |

Standard name | GO_GUANOSINE_CONTAINING_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M12863
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of guanosine-containing compounds (guanosines). [GOC:TermGenie]
Full description |

Standard name | GO_GLUCOSAMINE_CONTAINING_COMPOUND_METABOLIC_PROCESS
Systematic name | M11908
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glucosamine-containing compounds (glucosamines). [GOC:TermGenie]
Full description |

Standard name | GO_GLUCOSAMINE_CONTAINING_COMPOUND_CATABOLIC_PROCESS
Systematic name | M29324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glucosamine-containing compounds (glucosamines). [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_RELAXATION_OF_MUSCLE
Systematic name | M24981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of relaxation of muscle. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RELAXATION_OF_MUSCLE
Systematic name | M24982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of relaxation of muscle. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_AUTOPHAGOSOME_MATURATION
Systematic name | M24983
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of autophagosome maturation. [GOC:autophagy, GOC:TermGenie, PMID:10436019, PMID:21383079]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AUTOPHAGOSOME_MATURATION
Systematic name | M34287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of autophagosome maturation. [GOC:autophagy, GOC:TermGenie, PMID:10436019, PMID:21383079]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AUTOPHAGOSOME_MATURATION
Systematic name | M24984
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of autophagosome maturation. [GOC:autophagy, GOC:TermGenie, PMID:10436019, PMID:21383079]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SIGNAL_TRANSDUCTION_IN_ABSENCE_OF_LIGAND
Systematic name | M16493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of signal transduction in absence of ligand. [GOC:TermGenie]
Full description |

Standard name | GO_CARBOHYDRATE_DERIVATIVE_METABOLIC_PROCESS
Systematic name | M11818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving carbohydrate derivative. [GOC:TermGenie]
Full description |

Standard name | GO_CARBOHYDRATE_DERIVATIVE_CATABOLIC_PROCESS
Systematic name | M11157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of carbohydrate derivative. [GOC:TermGenie]
Full description |

Standard name | GO_CARBOHYDRATE_DERIVATIVE_BIOSYNTHETIC_PROCESS
Systematic name | M12992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of carbohydrate derivative. [GOC:TermGenie]
Full description |

Standard name | GO_INSULIN_METABOLIC_PROCESS
Systematic name | M24985
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving insulin. [GOC:TermGenie]
Full description |

Standard name | GO_PRIMARY_AMINO_COMPOUND_METABOLIC_PROCESS
Systematic name | M12679
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving primary amino compound. [GOC:TermGenie]
Full description |

Standard name | GO_PRIMARY_AMINO_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M24987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of primary amino compound. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TROPHOBLAST_CELL_MIGRATION
Systematic name | M24988
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of trophoblast cell migration. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TROPHOBLAST_CELL_MIGRATION
Systematic name | M24989
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of trophoblast cell migration. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_NEURAL_CREST_CELL_MIGRATION_INVOLVED_IN_AUTONOMIC_NERVOUS_SYSTEM_DEVELOPMENT
Systematic name | M24990
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any neural crest cell migration that is involved in autonomic nervous system development. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_ERBB_SIGNALING_PATHWAY
Systematic name | M10477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ERBB signaling pathway. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ERBB_SIGNALING_PATHWAY
Systematic name | M10799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of ERBB signaling pathway. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ERBB_SIGNALING_PATHWAY
Systematic name | M15817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of ERBB signaling pathway. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_EXTRACELLULAR_MATRIX_ASSEMBLY
Systematic name | M11824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of extracellular matrix assembly. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EXTRACELLULAR_MATRIX_ASSEMBLY
Systematic name | M24991
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of extracellular matrix assembly. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_FROM_RNA_POLYMERASE_II_PROMOTER_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M24992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transcription from an RNA polymerase II promoter that contributes to the development of the heart over time. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEURON_DEATH
Systematic name | M16268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of neuron death. [GOC:rph, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEURON_DEATH
Systematic name | M10507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of neuron death. [GOC:rph, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_NIK_NF_KAPPAB_SIGNALING
Systematic name | M13660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of NIK/NF-kappaB signaling. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NIK_NF_KAPPAB_SIGNALING
Systematic name | M24993
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of NIK/NF-kappaB signaling. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NIK_NF_KAPPAB_SIGNALING
Systematic name | M12728
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of NIK/NF-kappaB signaling. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_FROM_RNA_POLYMERASE_II_PROMOTER_INVOLVED_IN_HEART_DEVELOPMENT
Systematic name | M24994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any positive regulation of transcription from RNA polymerase II promoter that is involved in heart development. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_CARBOHYDRATE_DERIVATIVE_TRANSPORT
Systematic name | M16136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a carbohydrate derivative into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:bf, GOC:jl, GOC:TermGenie]
Full description |

Standard name | GO_NUCLEOSIDE_PHOSPHATE_CATABOLIC_PROCESS
Systematic name | M14500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of a nucleoside phosphate. [GOC:TermGenie]
Full description |

Standard name | GO_NUCLEOSIDE_PHOSPHATE_BIOSYNTHETIC_PROCESS
Systematic name | M11456
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of a nucleoside phosphate. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HYDROGEN_PEROXIDE_MEDIATED_PROGRAMMED_CELL_DEATH
Systematic name | M24995
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of hydrogen peroxide-mediated programmed cell death. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HYDROGEN_PEROXIDE_MEDIATED_PROGRAMMED_CELL_DEATH
Systematic name | M34288
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of hydrogen peroxide-mediated programmed cell death. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_FLAGELLATED_SPERM_MOTILITY
Systematic name | M24997
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of flagellated sperm motility. [GOC:cilia, GOC:krc, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_STORE_OPERATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M24999
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of store-operated calcium channel activity. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STORE_OPERATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M25000
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of store-operated calcium channel activity. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_VASCULATURE_DEVELOPMENT
Systematic name | M16954
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of vasculature development. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASCULATURE_DEVELOPMENT
Systematic name | M13575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of vasculature development. [GOC:TermGenie]
Full description |

Standard name | GO_ORGANIC_CYCLIC_COMPOUND_CATABOLIC_PROCESS
Systematic name | M14287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of organic cyclic compound. [GOC:TermGenie]
Full description |

Standard name | GO_ACETATE_ESTER_TRANSPORT
Systematic name | M25001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of an acetate ester into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_POTASSIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M16068
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of potassium ion transmembrane transport. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_VOLTAGE_GATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M11276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of voltage-gated calcium channel activity. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VOLTAGE_GATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M25002
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of voltage-gated calcium channel activity. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VOLTAGE_GATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M25003
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of voltage-gated calcium channel activity. [GOC:BHF, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_TRANSFORMING_GROWTH_FACTOR_BETA_ACTIVATION
Systematic name | M25004
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transforming growth factor beta activation. [GOC:sl, GOC:TermGenie]
Full description |

Standard name | GO_PYRUVATE_TRANSMEMBRANE_TRANSPORT
Systematic name | M25005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of pyruvate across a membrane. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_LYMPHANGIOGENESIS
Systematic name | M29327
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lymphangiogenesis. [GOC:dph, GOC:TermGenie, PMID:20133819]
Full description |

Standard name | GO_ETHER_BIOSYNTHETIC_PROCESS
Systematic name | M34289
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of ether. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_ENDOTHELIAL_TUBE_MORPHOGENESIS
Systematic name | M25006
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endothelial tube morphogenesis. [GOC:dph, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_FROM_RNA_POLYMERASE_II_PROMOTER_INVOLVED_IN_CELLULAR_RESPONSE_TO_CHEMICAL_STIMULUS
Systematic name | M15947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any positive regulation of transcription from RNA polymerase II promoter that is involved in cellular response to chemical stimulus. [GOC:TermGenie, PMID:22840777]
Full description |

Standard name | GO_ICOSANOID_CATABOLIC_PROCESS
Systematic name | M25007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of icosanoid. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_MITOPHAGY
Systematic name | M14044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of macromitophagy. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MITOPHAGY
Systematic name | M25008
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of mitophagy. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOPHAGY
Systematic name | M25009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of mitophagy. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_HEMATOPOIETIC_PROGENITOR_CELL_DIFFERENTIATION
Systematic name | M14258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hematopoietic progenitor cell differentiation. [GOC:BHF, GOC:rl, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HEMATOPOIETIC_PROGENITOR_CELL_DIFFERENTIATION
Systematic name | M12416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of hematopoietic progenitor cell differentiation. [GOC:BHF, GOC:rl, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HEMATOPOIETIC_PROGENITOR_CELL_DIFFERENTIATION
Systematic name | M29328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of hematopoietic progenitor cell differentiation. [GOC:BHF, GOC:rl, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_DNA_DEMETHYLATION
Systematic name | M25010
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA demethylation. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_DEMETHYLATION
Systematic name | M34290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of DNA demethylation. [GOC:TermGenie]
Full description |

Standard name | GO_CHANGES_TO_DNA_METHYLATION_INVOLVED_IN_EMBRYO_DEVELOPMENT
Systematic name | M25011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The addition or removal of methyl groups to DNA that contributes to the epigenetic regulation of embryonic gene expression. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_ENDOTHELIAL_CELL_DEVELOPMENT
Systematic name | M12049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endothelial cell development. [GOC:pr, GOC:TermGenie, PMID:19470579]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOTHELIAL_CELL_DEVELOPMENT
Systematic name | M25012
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of endothelial cell development. [GOC:pr, GOC:TermGenie, PMID:19470579]
Full description |

Standard name | GO_RESPONSE_TO_CAMPTOTHECIN
Systematic name | M25013
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a camptothecin stimulus. [GOC:TermGenie]
Full description |

Standard name | GO_ORGANONITROGEN_COMPOUND_CATABOLIC_PROCESS
Systematic name | M11892
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of organonitrogen compound. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_ORGANONITROGEN_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M15162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of organonitrogen compound. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_FATTY_ACID_DERIVATIVE_METABOLIC_PROCESS
Systematic name | M16181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving fatty acid derivative. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_FATTY_ACID_DERIVATIVE_CATABOLIC_PROCESS
Systematic name | M25014
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of fatty acid derivative. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_FATTY_ACID_DERIVATIVE_BIOSYNTHETIC_PROCESS
Systematic name | M15813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of fatty acid derivative. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_FATTY_ACID_DERIVATIVE_TRANSPORT
Systematic name | M13716
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a fatty acid derivative into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_ALPHA_AMINO_ACID_METABOLIC_PROCESS
Systematic name | M10829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving an alpha-amino acid. [GOC:TermGenie]
Full description |

Standard name | GO_ALPHA_AMINO_ACID_CATABOLIC_PROCESS
Systematic name | M11265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of an alpha-amino acid. [GOC:TermGenie]
Full description |

Standard name | GO_ALPHA_AMINO_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M10690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of an alpha-amino acid. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_VESICLE_TRANSPORT_ALONG_MICROTUBULE
Systematic name | M34291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of vesicle transport along microtubule. [GOC:TermGenie]
Full description |

Standard name | GO_ORGANIC_HYDROXY_COMPOUND_METABOLIC_PROCESS
Systematic name | M11251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving organic hydroxy compound. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_ORGANIC_HYDROXY_COMPOUND_CATABOLIC_PROCESS
Systematic name | M12060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of organic hydroxy compound. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_ORGANIC_HYDROXY_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M14755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of organic hydroxy compound. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_SMOOTHENED_SIGNALING_PATHWAY_INVOLVED_IN_DORSAL_VENTRAL_NEURAL_TUBE_PATTERNING
Systematic name | M25015
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of smoothened signaling pathway involved in dorsal/ventral neural tube patterning. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SMOOTHENED_SIGNALING_PATHWAY_INVOLVED_IN_DORSAL_VENTRAL_NEURAL_TUBE_PATTERNING
Systematic name | M25016
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of smoothened signaling pathway involved in dorsal/ventral neural tube patterning. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_LYMPHOCYTE_CHEMOTAXIS
Systematic name | M13318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lymphocyte chemotaxis. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_POSTSYNAPTIC_MEMBRANE_ORGANIZATION
Systematic name | M25017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of postsynaptic membrane organization. [GOC:TermGenie, PMID:22426000]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_POSTSYNAPTIC_MEMBRANE_ORGANIZATION
Systematic name | M34292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of postsynaptic membrane organization. [GOC:TermGenie, PMID:22426000]
Full description |

Standard name | GO_NUCLEOSIDE_TRANSMEMBRANE_TRANSPORT
Systematic name | M34293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of nucleoside across a membrane. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_RESPONSE_TO_PEPTIDE
Systematic name | M10640
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptide stimulus. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_PEPTIDE
Systematic name | M15470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptide stimulus. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_RESPONSE_TO_KETONE
Systematic name | M12822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A response that results in a state of tolerance to ketone. [GOC:mengo_curators, PMID:23356676]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_KETONE
Systematic name | M14664
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a ketone stimulus. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_GLYCOSYL_COMPOUND_METABOLIC_PROCESS
Systematic name | M14640
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glycosyl compound. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_GLYCOSYL_COMPOUND_CATABOLIC_PROCESS
Systematic name | M16186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the breakdown of glycosyl compound. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_GLYCOSYL_COMPOUND_BIOSYNTHETIC_PROCESS
Systematic name | M16359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of glycosyl compound. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_QUINONE_METABOLIC_PROCESS
Systematic name | M16900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving quinone. [GOC:go_curators, GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_SUPEROXIDE_DISMUTASE_ACTIVITY
Systematic name | M25021
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of superoxide dismutase activity. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_MITOTIC_SPINDLE_ASSEMBLY
Systematic name | M25022
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mitotic spindle assembly. [GOC:TermGenie]
Full description |

Standard name | GO_IRON_COORDINATION_ENTITY_TRANSPORT
Systematic name | M10662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of an iron coordination entity into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_NUCLEOTIDE_TRANSMEMBRANE_TRANSPORT
Systematic name | M13338
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of nucleotide across a membrane. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_GLUTATHIONE_DERIVATIVE_METABOLIC_PROCESS
Systematic name | M29329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving glutathione derivative. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_RESPONSE_TO_NITROGEN_COMPOUND
Systematic name | M10215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nitrogen compound stimulus. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_NITROGEN_COMPOUND
Systematic name | M13878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nitrogen compound stimulus. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_RESPONSE_TO_OXYGEN_CONTAINING_COMPOUND
Systematic name | M13558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an oxygen-containing compound stimulus. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_OXYGEN_CONTAINING_COMPOUND
Systematic name | M11609
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an oxygen-containing compound stimulus. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_CELL_PROLIFERATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M12280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell proliferation involved in kidney development. [GOC:TermGenie, PMID:18182616]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_PROLIFERATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M25024
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cell proliferation involved in kidney development. [GOC:TermGenie, PMID:18182616]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_PROLIFERATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M25025
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell proliferation involved in kidney development. [GOC:TermGenie, PMID:18182616]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_DEACETYLASE_ACTIVITY
Systematic name | M25026
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of histone deacetylase activity. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:20497126]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HISTONE_DEACETYLASE_ACTIVITY
Systematic name | M25027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of histone deacetylase activity. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:20497126]
Full description |

Standard name | GO_REGULATION_OF_MYOBLAST_FUSION
Systematic name | M14580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of myoblast fusion. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:21364645]
Full description |

Standard name | GO_LEUKOTRIENE_D4_METABOLIC_PROCESS
Systematic name | M29330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving leukotriene D4. [GOC:TermGenie, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_SIGNAL_TRANSDUCTION_BY_P53_CLASS_MEDIATOR
Systematic name | M14674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of signal transduction by p53 class mediator. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SIGNAL_TRANSDUCTION_BY_P53_CLASS_MEDIATOR
Systematic name | M15126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of signal transduction by p53 class mediator. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SIGNAL_TRANSDUCTION_BY_P53_CLASS_MEDIATOR
Systematic name | M12284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signal transduction by p53 class mediator. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEASOMAL_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of proteasomal protein catabolic process. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:21669198]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_OF_NUCLEOLAR_LARGE_RRNA_BY_RNA_POLYMERASE_I
Systematic name | M29331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transcription of nuclear large rRNA mediated by RNA polymerase I. [GOC:sart, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_OF_NUCLEOLAR_LARGE_RRNA_BY_RNA_POLYMERASE_I
Systematic name | M25030
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of transcription of nuclear large rRNA mediated by RNA polymerase I. [GOC:sart, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_HIGH_VOLTAGE_GATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M25031
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of high voltage-gated calcium channel activity. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:12754254]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HIGH_VOLTAGE_GATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M25033
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of high voltage-gated calcium channel activity. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:12754254]
Full description |

Standard name | GO_REGULATION_OF_CELL_COMMUNICATION_BY_ELECTRICAL_COUPLING_INVOLVED_IN_CARDIAC_CONDUCTION
Systematic name | M25034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell communication by electrical coupling involved in cardiac conduction. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:17130302]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_RESPIRATION
Systematic name | M29332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cellular respiration. [GOC:TermGenie, GOC:yaf, PMID:23150719]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_RESPIRATION
Systematic name | M25035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cellular respiration. [GOC:TermGenie, GOC:yaf, PMID:23150719]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M15202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of muscle tissue development. [GOC:TermGenie, GOC:yaf, PMID:23150719]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MUSCLE_TISSUE_DEVELOPMENT
Systematic name | M15042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of muscle tissue development. [GOC:TermGenie, GOC:yaf, PMID:23150719]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_DEPOLYMERIZATION
Systematic name | M25036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein depolymerization. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:12032137]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_DEPOLYMERIZATION
Systematic name | M14747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein depolymerization. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:12032137]
Full description |

Standard name | GO_REGULATION_OF_CELL_JUNCTION_ASSEMBLY
Systematic name | M11353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell junction assembly. [GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_JUNCTION_ASSEMBLY
Systematic name | M11443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cell junction assembly. [GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_JUNCTION_ASSEMBLY
Systematic name | M12995
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell junction assembly. [GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_ATPASE_COUPLED_CALCIUM_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M25037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of an ATPase-coupled calcium transmembrane transporter activity. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:19708671]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ATPASE_COUPLED_CALCIUM_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M29333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of an ATPase-coupled calcium transmembrane transporter activity. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:19708671]
Full description |

Standard name | GO_REGULATION_OF_RELAXATION_OF_CARDIAC_MUSCLE
Systematic name | M25038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of relaxation of cardiac muscle. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:19708671]
Full description |

Standard name | GO_DENSE_CORE_GRANULE_TRANSPORT
Systematic name | M25039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement a dense core granule within a cell. [GOC:kmv, GOC:TermGenie, PMID:23358451]
Full description |

Standard name | GO_REGULATION_OF_CELL_CYCLE_CHECKPOINT
Systematic name | M10224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell cycle checkpoint. [GOC:mtg_cell_cycle, GOC:TermGenie, PMID:23028116]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_CYCLE_CHECKPOINT
Systematic name | M25040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cell cycle checkpoint. [GOC:mtg_cell_cycle, GOC:TermGenie, PMID:23028116]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_CYCLE_CHECKPOINT
Systematic name | M25041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell cycle checkpoint. [GOC:mtg_cell_cycle, GOC:TermGenie, PMID:23028116]
Full description |

Standard name | GO_REGULATION_OF_INWARD_RECTIFIER_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M25042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of inward rectifier potassium channel activity. [GOC:TermGenie, PMID:23449501]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_ACETYLATION
Systematic name | M13920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein acetylation. [GOC:TermGenie, PMID:22117195]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_ACETYLATION
Systematic name | M15405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein acetylation. [GOC:TermGenie, PMID:22117195]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_ACETYLATION
Systematic name | M14589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein acetylation. [GOC:TermGenie, PMID:22117195]
Full description |

Standard name | GO_REGULATION_OF_CELL_CYCLE_PHASE_TRANSITION
Systematic name | M15372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell cycle phase transition. [GOC:mtg_cell_cycle, GOC:TermGenie, PMID:22841721]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_CYCLE_PHASE_TRANSITION
Systematic name | M14554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cell cycle phase transition. [GOC:mtg_cell_cycle, GOC:TermGenie, PMID:22841721]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_CYCLE_PHASE_TRANSITION
Systematic name | M16281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell cycle phase transition. [GOC:mtg_cell_cycle, GOC:TermGenie, PMID:22841721]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MEIOTIC_CELL_CYCLE_PHASE_TRANSITION
Systematic name | M25043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of meiotic cell cycle phase transition. [GOC:mtg_cell_cycle, GOC:TermGenie, PMID:22841721]
Full description |

Standard name | GO_TOXIN_TRANSPORT
Systematic name | M14133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a toxin into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:dph, GOC:TermGenie, PMID:17118486]
Full description |

Standard name | GO_FATTY_ACID_TRANSMEMBRANE_TRANSPORT
Systematic name | M25044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a fatty acid is transported across a membrane. [GOC:rb, GOC:TermGenie, PMID:9395310]
Full description |

Standard name | GO_REGULATION_OF_AMYLOID_BETA_FORMATION
Systematic name | M25045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of amyloid-beta formation. [GOC:dph, GOC:TermGenie, PMID:17098871]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AMYLOID_BETA_FORMATION
Systematic name | M25046
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of amyloid-beta formation. [GOC:dph, GOC:TermGenie, PMID:17098871]
Full description |

Standard name | GO_REGULATION_OF_CILIUM_ASSEMBLY
Systematic name | M14937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cilium assembly. [GOC:cilia, GOC:dph, GOC:TermGenie, PMID:17719545]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CILIUM_ASSEMBLY
Systematic name | M25047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cilium assembly. [GOC:cilia, GOC:dph, GOC:TermGenie, PMID:17719545]
Full description |

Standard name | GO_REGULATION_OF_CILIUM_DEPENDENT_CELL_MOTILITY
Systematic name | M29334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cilium-dependent cell motility. [GOC:cilia, GOC:jl, GOC:TermGenie]
Full description |

Standard name | GO_L_ARGININE_TRANSPORT
Systematic name | M25049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a L-arginine into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:kmv, GOC:TermGenie, PMID:22822152]
Full description |

Standard name | GO_REGULATION_OF_NADP_METABOLIC_PROCESS
Systematic name | M34294
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of NADP metabolic process. [GOC:TermGenie, PMID:23334421]
Full description |

Standard name | GO_REGULATION_OF_HEMATOPOIETIC_STEM_CELL_PROLIFERATION
Systematic name | M25050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hematopoietic stem cell proliferation. [GOC:TermGenie, PMID:23403623]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HEMATOPOIETIC_STEM_CELL_PROLIFERATION
Systematic name | M25051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of hematopoietic stem cell proliferation. [GOC:TermGenie, PMID:23403623]
Full description |

Standard name | GO_REGULATION_OF_HEMATOPOIETIC_STEM_CELL_DIFFERENTIATION
Systematic name | M34295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hematopoietic stem cell differentiation. [GOC:TermGenie, PMID:23403623]
Full description |

Standard name | GO_REGULATION_OF_EXTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_VIA_DEATH_DOMAIN_RECEPTORS
Systematic name | M12226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of extrinsic apoptotic signaling pathway via death domain receptors. [GOC:TermGenie, PMID:17245429]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EXTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_VIA_DEATH_DOMAIN_RECEPTORS
Systematic name | M14522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of extrinsic apoptotic signaling pathway via death domain receptors. [GOC:TermGenie, PMID:17245429]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EXTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_VIA_DEATH_DOMAIN_RECEPTORS
Systematic name | M15786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of extrinsic apoptotic signaling pathway via death domain receptors. [GOC:TermGenie, PMID:17245429]
Full description |

Standard name | GO_RESPONSE_TO_L_GLUTAMATE
Systematic name | M25052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an L-glutamate stimulus. [GOC:TermGenie, PMID:23574009]
Full description |

Standard name | GO_RESPONSE_TO_SALT
Systematic name | M15571
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a salt stimulus. [GOC:mls, GOC:TermGenie, PMID:16666921]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_SALT
Systematic name | M25053
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a salt stimulus. [GOC:mls, GOC:TermGenie, PMID:16666921]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PEPTIDYL_CYSTEINE_S_NITROSYLATION
Systematic name | M25054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of peptidyl-cysteine S-nitrosylation. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:19198614]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_METAPHASE_ANAPHASE_TRANSITION_OF_CELL_CYCLE
Systematic name | M25056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of metaphase/anaphase transition of cell cycle. [GOC:mtg_cell_cycle, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_DIFFERENTIATION
Systematic name | M12177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of leukocyte differentiation. [GOC:add, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LEUKOCYTE_DIFFERENTIATION
Systematic name | M16252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of leukocyte differentiation. [GOC:add, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LEUKOCYTE_DIFFERENTIATION
Systematic name | M12316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of leukocyte differentiation. [GOC:add, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRIAL_MEMBRANE_PERMEABILITY_INVOLVED_IN_APOPTOTIC_PROCESS
Systematic name | M10596
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any regulation of mitochondrial membrane permeability that is involved in apoptotic process. [GOC:mtg_apoptosis, GOC:pm, GOC:TermGenie, PMID:19168129]
Full description |

Standard name | GO_REGULATION_OF_ORGANELLE_ASSEMBLY
Systematic name | M15477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of organelle assembly. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ORGANELLE_ASSEMBLY
Systematic name | M11808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of organelle assembly. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ORGANELLE_ASSEMBLY
Systematic name | M16790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of organelle assembly. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_DNA_DAMAGE_BY_P53_CLASS_MEDIATOR
Systematic name | M13683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of intrinsic apoptotic signaling pathway in response to DNA damage by p53 class mediator. [GOC:TermGenie, PMID:17719541]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_REACTIVE_NITROGEN_SPECIES
Systematic name | M15925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a reactive nitrogen species stimulus. [GOC:sl, GOC:TermGenie, PMID:22504638]
Full description |

Standard name | GO_REGULATION_OF_OXIDATIVE_STRESS_INDUCED_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M16761
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of an oxidative stress-induced intrinsic apoptotic signaling pathway. [GOC:BHF, GOC:mtg_apoptosis, GOC:TermGenie, PMID:11672522]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OXIDATIVE_STRESS_INDUCED_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M16039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of an oxidative stress-induced intrinsic apoptotic signaling pathway. [GOC:BHF, GOC:mtg_apoptosis, GOC:TermGenie, PMID:11672522]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OXIDATIVE_STRESS_INDUCED_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M25058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of an oxidative stress-induced intrinsic apoptotic signaling pathway. [GOC:BHF, GOC:mtg_apoptosis, GOC:TermGenie, PMID:11672522]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VIRAL_RELEASE_FROM_HOST_CELL
Systematic name | M16090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of viral release from host cell. [GOC:TermGenie, PMID:18305167]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VIRAL_RELEASE_FROM_HOST_CELL
Systematic name | M11241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of viral release from host cell. [GOC:TermGenie, PMID:18305167]
Full description |

Standard name | GO_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_OSMOTIC_STRESS
Systematic name | M29335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of intrinsic apoptotic signaling pathway in response to osmotic stress. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:14569084]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_OSMOTIC_STRESS
Systematic name | M25059
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of intrinsic apoptotic signaling pathway in response to osmotic stress. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:14569084]
Full description |

Standard name | GO_KETONE_BODY_METABOLIC_PROCESS
Systematic name | M29336
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving ketone body. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_DNA_DAMAGE
Systematic name | M14467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of intrinsic apoptotic signaling pathway in response to DNA damage. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:15314165]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_DNA_DAMAGE
Systematic name | M11635
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of intrinsic apoptotic signaling pathway in response to DNA damage. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:15314165]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_DNA_DAMAGE
Systematic name | M25060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of intrinsic apoptotic signaling pathway in response to DNA damage. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:15314165]
Full description |

Standard name | GO_REGULATION_OF_ENDOPLASMIC_RETICULUM_STRESS_INDUCED_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M12961
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of an endoplasmic reticulum stress-induced intrinsic apoptotic signaling pathway. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:20160352]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ENDOPLASMIC_RETICULUM_STRESS_INDUCED_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M15084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of an endoplasmic reticulum stress-induced intrinsic apoptotic signaling pathway. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:20160352]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOPLASMIC_RETICULUM_STRESS_INDUCED_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M25061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of an endoplasmic reticulum stress-induced intrinsic apoptotic signaling pathway. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:20160352]
Full description |

Standard name | GO_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_BY_P53_CLASS_MEDIATOR
Systematic name | M15194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of intrinsic apoptotic signaling pathway by p53 class mediator. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:15705871]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_BY_P53_CLASS_MEDIATOR
Systematic name | M10537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of intrinsic apoptotic signaling pathway by p53 class mediator. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:15705871]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_BY_P53_CLASS_MEDIATOR
Systematic name | M25062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of intrinsic apoptotic signaling pathway by p53 class mediator. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, GOC:TermGenie, PMID:15705871]
Full description |

Standard name | GO_REGULATION_OF_DELAYED_RECTIFIER_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M14676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of delayed rectifier potassium channel activity. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:11299204]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DELAYED_RECTIFIER_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M25063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of delayed rectifier potassium channel activity. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:11299204]
Full description |

Standard name | GO_APOPTOTIC_PROCESS_INVOLVED_IN_BLOOD_VESSEL_MORPHOGENESIS
Systematic name | M34296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process that is involved in blood vessel morphogenesis. [GOC:dph, GOC:mtg_apoptosis, GOC:TermGenie, PMID:16163358]
Full description |

Standard name | GO_REGULATION_OF_POLYAMINE_TRANSMEMBRANE_TRANSPORT
Systematic name | M25064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of polyamine transmembrane transport. [GOC:TermGenie, PMID:23755272]
Full description |

Standard name | GO_REGULATION_OF_CHROMATIN_ORGANIZATION
Systematic name | M14569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of chromatin organization. [GO_REF:0000058, GOC:bf, GOC:TermGenie, GOC:vw, PMID:18314879]
Full description |

Standard name | GO_NEURON_PROJECTION_EXTENSION_INVOLVED_IN_NEURON_PROJECTION_GUIDANCE
Systematic name | M10902
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any neuron projection extension that is involved in neuron projection guidance. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:22790009]
Full description |

Standard name | GO_SEMAPHORIN_PLEXIN_SIGNALING_PATHWAY_INVOLVED_IN_NEURON_PROJECTION_GUIDANCE
Systematic name | M14983
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any semaphorin-plexin signaling pathway that is involved in neuron projection guidance. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:22790009]
Full description |

Standard name | GO_CELL_CYCLE_DNA_REPLICATION_INITIATION
Systematic name | M34297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any DNA replication initiation that is involved in cell cycle DNA replication. [GOC:mtg_cell_cycle, GOC:TermGenie]
Full description |

Standard name | GO_PRE_REPLICATIVE_COMPLEX_ASSEMBLY_INVOLVED_IN_CELL_CYCLE_DNA_REPLICATION
Systematic name | M29337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any pre-replicative complex assembly that is involved in cell cycle DNA replication. [GOC:mtg_cell_cycle, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_SODIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M16475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of sodium ion transmembrane transport. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:18591664]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SODIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M25065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of sodium ion transmembrane transport. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:18591664]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SODIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M13723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of sodium ion transmembrane transport. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:18591664]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDYL_SERINE_DEPHOSPHORYLATION
Systematic name | M25066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of peptidyl-serine dephosphorylation. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:11953308]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_APOPTOTIC_PROCESS_INVOLVED_IN_MORPHOGENESIS
Systematic name | M25068
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of apoptotic process involved in morphogenesis. [GOC:sart, GOC:TermGenie, PMID:12202035]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RNA_CATABOLIC_PROCESS
Systematic name | M25069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of RNA catabolic process. [GOC:bf, GOC:TermGenie, PMID:16640457]
Full description |

Standard name | GO_CERAMIDE_1_PHOSPHATE_TRANSPORT
Systematic name | M25070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a ceramide 1-phosphate into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. [GOC:TermGenie, PMID:23863933]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_BICELLULAR_TIGHT_JUNCTION
Systematic name | M34298
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a bicellular tight junction. [GOC:TermGenie, PMID:18332111]
Full description |

Standard name | GO_MITOTIC_CYTOKINETIC_PROCESS
Systematic name | M25071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cytokinetic process that is involved in mitotic cell cycle. [GOC:mtg_cell_cycle, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_MITOTIC_CYTOKINESIS
Systematic name | M25072
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mitotic cytokinesis. [GOC:mtg_cell_cycle, GOC:TermGenie]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CELL_JUNCTION
Systematic name | M25073
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a cell junction. [GOC:TermGenie, PMID:18332111]
Full description |

Standard name | GO_REGULATION_OF_MRNA_BINDING
Systematic name | M25074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mRNA binding. [GOC:rb, GOC:TermGenie, PMID:22890846]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AMYLOID_BETA_FORMATION
Systematic name | M29338
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of amyloid-beta formation. [GOC:hjd, GOC:TermGenie, PMID:22992957]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_STEM_CELL_POPULATION_MAINTENANCE
Systematic name | M25075
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of stem cell population maintenance. [GOC:hjd, GOC:TermGenie, PMID:22969033]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STEM_CELL_POPULATION_MAINTENANCE
Systematic name | M25076
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of stem cell population maintenance. [GOC:hjd, GOC:TermGenie, PMID:22969033]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_SYNAPSE
Systematic name | M25077
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to synapse. [GOC:kmv, GOC:TermGenie, PMID:22588719]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_SYNAPSE
Systematic name | M25078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein localization to synapse. [GOC:kmv, GOC:TermGenie, PMID:22588719]
Full description |

Standard name | GO_L_ALPHA_AMINO_ACID_TRANSMEMBRANE_TRANSPORT
Systematic name | M10375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-alpha-amino acid across a membrane. [GOC:kmv, GOC:TermGenie, PMID:14668347]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_AUTOUBIQUITINATION
Systematic name | M25080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein autoubiquitination. [GOC:rb, GOC:TermGenie, PMID:24069405]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_APOPTOTIC_DNA_FRAGMENTATION
Systematic name | M29339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of apoptotic DNA fragmentation. [GOC:hjd, GOC:TermGenie, PMID:15572351]
Full description |

Standard name | GO_REGULATION_OF_ORGANELLE_TRANSPORT_ALONG_MICROTUBULE
Systematic name | M25082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of organelle transport along microtubule. [GOC:dph, GOC:TermGenie, PMID:21147087]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_MONOUBIQUITINATION
Systematic name | M25083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein monoubiquitination. [GOC:TermGenie, PMID:21931591]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_MONOUBIQUITINATION
Systematic name | M25084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein monoubiquitination. [GOC:TermGenie, PMID:21931591]
Full description |

Standard name | GO_REGULATION_OF_INTRACELLULAR_SIGNAL_TRANSDUCTION
Systematic name | M11395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of intracellular signal transduction. [GOC:dph, GOC:signaling, GOC:tb, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTRACELLULAR_SIGNAL_TRANSDUCTION
Systematic name | M11941
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of intracellular signal transduction. [GOC:dph, GOC:signaling, GOC:tb, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTRACELLULAR_SIGNAL_TRANSDUCTION
Systematic name | M14232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of intracellular signal transduction. [GOC:BHF, GOC:dph, GOC:signaling, GOC:tb, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_RESPONSE_TO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_STIMULUS
Systematic name | M14229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cellular response to vascular endothelial growth factor stimulus. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:17895370]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_RESPONSE_TO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_STIMULUS
Systematic name | M25085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cellular response to vascular endothelial growth factor stimulus. [GOC:BHF, GOC:rl, GOC:TermGenie, PMID:17895370]
Full description |

Standard name | GO_REGULATION_OF_NEUTROPHIL_ACTIVATION
Systematic name | M25086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neutrophil activation. [GOC:TermGenie, PMID:17588661]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEUTROPHIL_ACTIVATION
Systematic name | M25087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of neutrophil activation. [GOC:TermGenie, PMID:17588661]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_NUCLEOLUS
Systematic name | M25089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a nucleolus. [GOC:TermGenie, PMID:22809626]
Full description |

Standard name | GO_REGULATION_OF_SERINE_TYPE_PEPTIDASE_ACTIVITY
Systematic name | M11051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of serine-type peptidase activity. [GOC:krc, GOC:TermGenie, PMID:20179351]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SERINE_TYPE_PEPTIDASE_ACTIVITY
Systematic name | M11683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of serine-type peptidase activity. [GOC:krc, GOC:TermGenie, PMID:20179351]
Full description |

Standard name | GO_MULTI_ORGANISM_LOCALIZATION
Systematic name | M13896
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A localization which involves another organism. [GO_REF:0000089, GOC:jl, GOC:TermGenie]
Full description |

Standard name | GO_PROTON_TRANSMEMBRANE_TRANSPORT
Systematic name | M25091
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a proton across a membrane. [GO_REF:0000069, GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_RESPONSE_TO_FLUORIDE
Systematic name | M25092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fluoride stimulus. [GO_REF:0000071, GOC:kmv, GOC:TermGenie, PMID:8138152]
Full description |

Standard name | GO_REGULATION_OF_NEUTROPHIL_MIGRATION
Systematic name | M16301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neutrophil migration. [GO_REF:0000058, GOC:TermGenie, PMID:1826836]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEUTROPHIL_MIGRATION
Systematic name | M34299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of neutrophil migration. [GO_REF:0000058, GOC:TermGenie, PMID:1826836]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEUTROPHIL_MIGRATION
Systematic name | M12319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of neutrophil migration. [GO_REF:0000058, GOC:TermGenie, PMID:1826836]
Full description |

Standard name | GO_TERTIARY_ALCOHOL_METABOLIC_PROCESS
Systematic name | M25093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving tertiary alcohol. [GO_REF:0000068, GOC:mengo_curators, GOC:TermGenie, PMID:11288200]
Full description |

Standard name | GO_CALCIUM_ION_IMPORT_INTO_CYTOSOL
Systematic name | M16606
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of calcium ion into a cytosol. [GO_REF:0000075, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_AXON_GUIDANCE
Systematic name | M11421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of axon guidance. [GO_REF:0000058, GOC:hjd, GOC:TermGenie, PMID:23006775]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AXON_GUIDANCE
Systematic name | M12205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of axon guidance. [GO_REF:0000058, GOC:hjd, GOC:TermGenie, PMID:23006775]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AXON_GUIDANCE
Systematic name | M25095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of axon guidance. [GO_REF:0000058, GOC:hjd, GOC:TermGenie, PMID:23006775]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RNA_BIOSYNTHETIC_PROCESS
Systematic name | M25096
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of RNA biosynthetic process. [GO:jl, GO_REF:0000058, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RNA_BIOSYNTHETIC_PROCESS
Systematic name | M34300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of RNA biosynthetic process. [GO:jl, GO_REF:0000058, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_RECEPTOR_LOCALIZATION_TO_SYNAPSE
Systematic name | M25098
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of receptor localization to synapse. [GO_REF:0000058, GOC:kmv, GOC:TermGenie, PMID:22252129]
Full description |

Standard name | GO_REGULATION_OF_NEUROBLAST_PROLIFERATION
Systematic name | M13528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neuroblast proliferation. [GO_REF:0000058, GOC:PARL, GOC:rl, GOC:TermGenie, PMID:21168496]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHONDROCYTE_PROLIFERATION
Systematic name | M34301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of the multiplication or reproduction of chondrocytes by cell division, resulting in the expansion of their population. A chondrocyte is a polymorphic cell that forms cartilage. [GO_REF:0000058, GOC:TermGenie, PMID:23212449]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHONDROCYTE_PROLIFERATION
Systematic name | M34302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases the frequency, rate or extent of the multiplication or reproduction of chondrocytes by cell division, resulting in the expansion of their population. A chondrocyte is a polymorphic cell that forms cartilage. [GO_REF:0000058, GOC:TermGenie, PMID:23212449]
Full description |

Standard name | GO_APOPTOTIC_PROCESS_INVOLVED_IN_DEVELOPMENT
Systematic name | M13915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process that is involved in anatomical structure development. [GO_REF:0000060, GOC:mtg_apoptosis, GOC:pg, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_LAMELLIPODIUM_ORGANIZATION
Systematic name | M14628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lamellipodium organization. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:16054028]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LAMELLIPODIUM_ORGANIZATION
Systematic name | M25101
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of lamellipodium organization. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:16054028]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LAMELLIPODIUM_ORGANIZATION
Systematic name | M15948
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of lamellipodium organization. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:16054028]
Full description |

Standard name | GO_REGULATION_OF_LENS_FIBER_CELL_DIFFERENTIATION
Systematic name | M34303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lens fiber cell differentiation. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:17592637]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LENS_FIBER_CELL_DIFFERENTIATION
Systematic name | M34304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of lens fiber cell differentiation. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:17592637]
Full description |

Standard name | GO_REGULATION_OF_CELL_CYCLE_G2_M_PHASE_TRANSITION
Systematic name | M12021
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any signalling pathway that modulates the activity of a cell cycle cyclin-dependent protein kinase to modulate the switch from G2 phase to M phase of the cell cycle. [GO_REF:0000058, GOC:jl, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_CYCLE_G2_M_PHASE_TRANSITION
Systematic name | M14479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any signalling pathway that decreases or inhibits the activity of a cell cycle cyclin-dependent protein kinase to modulate the switch from G2 phase to M phase of the cell cycle. [GO_REF:0000058, GOC:jl, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_CYCLE_G2_M_PHASE_TRANSITION
Systematic name | M12129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any signalling pathway that activates or increases the activity of a cell cycle cyclin-dependent protein kinase to modulate the switch from G2 phase to M phase of the cell cycle. [GO_REF:0000058, GOC:jl, GOC:TermGenie]
Full description |

Standard name | GO_LATE_ENDOSOME_TO_LYSOSOME_TRANSPORT
Systematic name | M25102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from late endosome to lysosome. [GO_REF:0000076, GOC:TermGenie, PMID:23949442]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_VESICLE_TRANSPORT
Systematic name | M16752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of synaptic vesicle transport. [GO_REF:0000058, GOC:kmv, GOC:TermGenie, PMID:23527112]
Full description |

Standard name | GO_REGULATION_OF_CELL_CYCLE_G1_S_PHASE_TRANSITION
Systematic name | M13282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any signalling pathway that modulates the activity of a cell cycle cyclin-dependent protein kinase to modulate the switch from G1 phase to S phase of the cell cycle. [GO_REF:0000058, GOC:mtg_cell_cycle, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_CYCLE_G1_S_PHASE_TRANSITION
Systematic name | M14671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any signalling pathway that decreases or inhibits the activity of a cell cycle cyclin-dependent protein kinase to modulate the switch from G1 phase to S phase of the cell cycle. [GO_REF:0000058, GOC:mtg_cell_cycle, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_CYCLE_G1_S_PHASE_TRANSITION
Systematic name | M16176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any signalling pathway that activates or increases the activity of a cell cycle cyclin-dependent protein kinase to modulate the switch from G1 phase to S phase of the cell cycle. [GO_REF:0000058, GOC:mtg_cell_cycle, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_MICROTUBULE
Systematic name | M25105
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein localization to microtubule. [GO_REF:0000058, GOC:TermGenie, GOC:vw, PMID:23087209]
Full description |

Standard name | GO_MICROTUBULE_CYTOSKELETON_ORGANIZATION_INVOLVED_IN_MITOSIS
Systematic name | M25106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any microtubule cytoskeleton organization that is involved in mitosis. [GO_REF:0000060, GOC:TermGenie, PMID:18799626]
Full description |

Standard name | GO_REGULATION_OF_NON_MOTILE_CILIUM_ASSEMBLY
Systematic name | M25107
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of non-motile cilium assembly. [GO_REF:0000058, GOC:cilia, GOC:kmv, GOC:TermGenie, PMID:23807208]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NON_MOTILE_CILIUM_ASSEMBLY
Systematic name | M25108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of non-motile cilium assembly. [GO_REF:0000058, GOC:cilia, GOC:kmv, GOC:TermGenie, PMID:23807208]
Full description |

Standard name | GO_REGULATION_OF_RETINA_DEVELOPMENT_IN_CAMERA_TYPE_EYE
Systematic name | M25109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of retina development in camera-type eye. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:16872597]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_OXIDATIVE_STRESS
Systematic name | M15642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of response to oxidative stress. [GO_REF:0000058, GOC:kmv, GOC:TermGenie, PMID:16899554]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_OXIDATIVE_STRESS
Systematic name | M11478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of response to oxidative stress. [GO_REF:0000058, GOC:kmv, GOC:TermGenie, PMID:16899554]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_OXIDATIVE_STRESS
Systematic name | M12508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of response to oxidative stress. [GO_REF:0000058, GOC:kmv, GOC:TermGenie, PMID:16899554]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PRI_MIRNA_TRANSCRIPTION_BY_RNA_POLYMERASE_II
Systematic name | M25110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of pri-miRNA transcription mediated by RNA polymerase II. [GO_REF:0000058, GOC:dph, GOC:kmv, GOC:TermGenie, PMID:24699545]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PRI_MIRNA_TRANSCRIPTION_BY_RNA_POLYMERASE_II
Systematic name | M25111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of pri-miRNA transcription mediated by RNA polymerase II. [GO_REF:0000058, GOC:dph, GOC:kmv, GOC:TermGenie, PMID:24699545]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AUTOPHAGOSOME_ASSEMBLY
Systematic name | M25112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of autophagosome assembly. [GO_REF:0000058, GOC:als, GOC:autophagy, GOC:TermGenie, PMID:21975012]
Full description |

Standard name | GO_REGULATION_OF_SUPRAMOLECULAR_FIBER_ORGANIZATION
Systematic name | M25113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of supramolecular fiber organization. [GO_REF:0000058, GOC:PARL, GOC:rl, GOC:TermGenie, PMID:23921388]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SUPRAMOLECULAR_FIBER_ORGANIZATION
Systematic name | M25114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of fibril organization. [GO_REF:0000058, GOC:PARL, GOC:rl, GOC:TermGenie, PMID:23921388]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SUPRAMOLECULAR_FIBER_ORGANIZATION
Systematic name | M25115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of supramolecular fiber organization. [GO_REF:0000058, GOC:PARL, GOC:rl, GOC:TermGenie, PMID:23921388]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_POLYUBIQUITINATION
Systematic name | M16035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein polyubiquitination. [GO_REF:0000058, GOC:di, GOC:TermGenie, PMID:23645667]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_POLYUBIQUITINATION
Systematic name | M25116
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein polyubiquitination. [GO_REF:0000058, GOC:di, GOC:TermGenie, PMID:23645667]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_POLYUBIQUITINATION
Systematic name | M25117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein polyubiquitination. [GO_REF:0000058, GOC:di, GOC:TermGenie, PMID:23645667]
Full description |

Standard name | GO_REGULATION_OF_ALCOHOL_BIOSYNTHETIC_PROCESS
Systematic name | M15905
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of alcohol biosynthetic process. [GO_REF:0000058, GOC:mengo_curators, GOC:TermGenie, PMID:23332010]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ALCOHOL_BIOSYNTHETIC_PROCESS
Systematic name | M11330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of alcohol biosynthetic process. [GO_REF:0000058, GOC:mengo_curators, GOC:TermGenie, PMID:23332010]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ALCOHOL_BIOSYNTHETIC_PROCESS
Systematic name | M11535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of alcohol biosynthetic process. [GO_REF:0000058, GOC:mengo_curators, GOC:TermGenie, PMID:23332010]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_EARLY_ENDOSOME
Systematic name | M25118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within an early endosome. [GO_REF:0000087, GOC:sjp, GOC:TermGenie, PMID:22621900]
Full description |

Standard name | GO_REGULATION_OF_TAU_PROTEIN_KINASE_ACTIVITY
Systematic name | M25119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of tau-protein kinase activity. [GO_REF:0000059, GOC:sjp, GOC:TermGenie, PMID:15897157, PMID:22986780]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TAU_PROTEIN_KINASE_ACTIVITY
Systematic name | M25120
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of tau-protein kinase activity. [GO_REF:0000059, GOC:sjp, GOC:TermGenie, PMID:15897157, PMID:22986780]
Full description |

Standard name | GO_REGULATION_OF_DENDRITIC_SPINE_MAINTENANCE
Systematic name | M25121
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of dendritic spine maintenance. [GO_REF:0000058, GOC:sjp, GOC:TermGenie, PMID:24328732]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRIAL_ELECTRON_TRANSPORT_NADH_TO_UBIQUINONE
Systematic name | M29340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mitochondrial electron transport, NADH to ubiquinone. [GO_REF:0000058, GOC:dph, GOC:TermGenie, PMID:23530063]
Full description |

Standard name | GO_REGULATION_OF_ASPARTIC_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_AMYLOID_PRECURSOR_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of aspartic-type endopeptidase activity involved in amyloid precursor protein catabolic process. [GO_REF:0000059, GOC:sjp, GOC:TermGenie, PMID:24577224]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_EARLY_ENDOSOME
Systematic name | M25123
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein localization to early endosome. [GO_REF:0000058, GOC:sjp, GOC:TermGenie, PMID:22621900]
Full description |

Standard name | GO_MITOTIC_DNA_REPLICATION
Systematic name | M25124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any nuclear DNA replication that is involved in a mitotic cell cycle. [GO_REF:0000060, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_AMYLOID_PRECURSOR_PROTEIN_CATABOLIC_PROCESS
Systematic name | M12220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of amyloid precursor protein catabolic process. [GO_REF:0000058, GOC:PARL, GOC:rl, GOC:TermGenie, PMID:24499793]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AMYLOID_PRECURSOR_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of amyloid precursor protein catabolic process. [GO_REF:0000058, GOC:PARL, GOC:rl, GOC:TermGenie, PMID:24499793]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AMYLOID_PRECURSOR_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of amyloid precursor protein catabolic process. [GO_REF:0000058, GOC:PARL, GOC:rl, GOC:TermGenie, PMID:24499793]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_DEUBIQUITINATION
Systematic name | M25127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein deubiquitination. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:22970133]
Full description |

Standard name | GO_ORGANELLE_DISASSEMBLY
Systematic name | M16645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disaggregation of an organelle into its constituent components. [GO_REF:0000079, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_BONE_DEVELOPMENT
Systematic name | M12141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of bone development. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:22510437]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BONE_DEVELOPMENT
Systematic name | M25128
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of bone development. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:22510437]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BONE_DEVELOPMENT
Systematic name | M25129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of bone development. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:22510437]
Full description |

Standard name | GO_REGULATION_OF_GLYCOPROTEIN_METABOLIC_PROCESS
Systematic name | M12368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glycoprotein metabolic process. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:23544079]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLYCOPROTEIN_METABOLIC_PROCESS
Systematic name | M29341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of glycoprotein metabolic process. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:23544079]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLYCOPROTEIN_METABOLIC_PROCESS
Systematic name | M14041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of glycoprotein metabolic process. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:23544079]
Full description |

Standard name | GO_REGULATION_OF_RNA_POLYMERASE_II_REGULATORY_REGION_SEQUENCE_SPECIFIC_DNA_BINDING
Systematic name | M25130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of RNA polymerase II regulatory region sequence-specific DNA binding. [GO_REF:0000059, GOC:dph, GOC:krc, GOC:TermGenie, PMID:20026326]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RNA_POLYMERASE_II_REGULATORY_REGION_SEQUENCE_SPECIFIC_DNA_BINDING
Systematic name | M25131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of RNA polymerase II regulatory region sequence-specific DNA binding. [GO_REF:0000059, GOC:dph, GOC:krc, GOC:TermGenie, PMID:20026326]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_WOUNDING
Systematic name | M13178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of response to wounding. [GO_REF:0000058, GOC:kmv, GOC:TermGenie, pmid:19164535]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_WOUNDING
Systematic name | M16105
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of response to wounding. [GO_REF:0000058, GOC:kmv, GOC:TermGenie, pmid:19164535]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_WOUNDING
Systematic name | M14125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of response to wounding. [GO_REF:0000058, GOC:kmv, GOC:TermGenie, pmid:19164535]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LEUKOCYTE_CELL_CELL_ADHESION
Systematic name | M25132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of leukocyte cell-cell adhesion. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:21106532]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LEUKOCYTE_CELL_CELL_ADHESION
Systematic name | M25133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of leukocyte cell-cell adhesion. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:21106532]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_MEMBRANE_RAFT
Systematic name | M25134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a membrane raft. [GO_REF:0000087, GOC:dl, GOC:TermGenie, PMID:19414744]
Full description |

Standard name | GO_MEIOTIC_CELL_CYCLE_PROCESS
Systematic name | M14993
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is part of the meiotic cell cycle. [GO_REF:0000060, GOC:mtg_cell_cycle, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEOLYSIS_INVOLVED_IN_CELLULAR_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of proteolysis involved in cellular protein catabolic process. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:18307834]
Full description |

Standard name | GO_REGULATION_OF_EXTRACELLULAR_MATRIX_ORGANIZATION
Systematic name | M11743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of extracellular matrix organization. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:22357537]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EXTRACELLULAR_MATRIX_ORGANIZATION
Systematic name | M25137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of extracellular matrix organization. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:22357537]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EXTRACELLULAR_MATRIX_ORGANIZATION
Systematic name | M13047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of extracellular matrix organization. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:22357537]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LIPIDATION
Systematic name | M25138
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein lipidation. [GO_REF:0000058, GOC:rph, GOC:TermGenie, PMID:21909394]
Full description |

Standard name | GO_REGULATION_OF_ER_ASSOCIATED_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ER-associated ubiquitin-dependent protein catabolic process. [GO_REF:0000058, GOC:rph, GOC:TermGenie, PMID:17872946]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ER_ASSOCIATED_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of ER-associated ubiquitin-dependent protein catabolic process. [GO_REF:0000058, GOC:rph, GOC:TermGenie, PMID:17872946]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_PLASMA_MEMBRANE
Systematic name | M25141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to plasma membrane. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:11602640]
Full description |

Standard name | GO_REGULATION_OF_ACTIN_FILAMENT_BASED_MOVEMENT
Systematic name | M15281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of actin filament-based movement. [GO_REF:0000058, GOC:TermGenie, PMID:24798735]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACTIN_FILAMENT_BASED_MOVEMENT
Systematic name | M25142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of actin filament-based movement. [GO_REF:0000058, GOC:TermGenie, PMID:24798735]
Full description |

Standard name | GO_REGULATION_OF_TRAIL_ACTIVATED_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M25143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of TRAIL-activated apoptotic signaling pathway. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie]
Full description |

Standard name | GO_MONONUCLEAR_CELL_DIFFERENTIATION
Systematic name | M25144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a mononuclear cell. [CL:0000842, GO_REF:0000086, GOC:TermGenie, PMID:24759906]
Full description |

Standard name | GO_REGULATION_OF_AUTOPHAGY_OF_MITOCHONDRION
Systematic name | M25145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mitochondrion degradation by an autophagic process. [GO_REF:0000058, GOC:autophagy, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24600391]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AUTOPHAGY_OF_MITOCHONDRION
Systematic name | M25146
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of mitochondrion degradation by autophagy. [GO_REF:0000058, GOC:autophagy, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24600391]
Full description |

Standard name | GO_REGULATION_OF_CALCIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M12642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of calcium ion transmembrane transport. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:24125847]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CALCIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M16095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of calcium ion transmembrane transport. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:24125847]
Full description |

Standard name | GO_REGULATION_OF_OXIDATIVE_STRESS_INDUCED_CELL_DEATH
Systematic name | M14819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of oxidative stress-induced cell death. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OXIDATIVE_STRESS_INDUCED_NEURON_DEATH
Systematic name | M25147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of oxidative stress-induced neuron death. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24252804]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OXIDATIVE_STRESS_INDUCED_CELL_DEATH
Systematic name | M16313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of oxidative stress-induced cell death. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:20969476]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_TARGETING_TO_MITOCHONDRION
Systematic name | M10069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein targeting to mitochondrion. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_TARGETING_TO_MITOCHONDRION
Systematic name | M25148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein targeting to mitochondrion. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:21370995]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OXIDATIVE_STRESS_INDUCED_NEURON_DEATH
Systematic name | M29342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of oxidative stress-induced neuron death. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:23858059]
Full description |

Standard name | GO_REGULATION_OF_ENDODERMAL_CELL_DIFFERENTIATION
Systematic name | M34305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endodermal cell differentiation. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:23154389]
Full description |

Standard name | GO_MELANOSOME_ASSEMBLY
Systematic name | M25150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a melanosome, a tissue-specific, membrane-bounded cytoplasmic organelle within which melanin pigments are synthesized and stored. [GO_REF:0000079, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:22511774]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_TETHERING_OR_ROLLING
Systematic name | M25151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of leukocyte tethering or rolling. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:18308860]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LEUKOCYTE_TETHERING_OR_ROLLING
Systematic name | M34306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of leukocyte tethering or rolling. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:18308860]
Full description |

Standard name | GO_MULTI_CILIATED_EPITHELIAL_CELL_DIFFERENTIATION
Systematic name | M25152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a multi-ciliated epithelial cell. [GO_REF:0000086, GOC:sp, GOC:TermGenie, PMID:22231168, PMID:24934224]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TUMOR_NECROSIS_FACTOR_MEDIATED_SIGNALING_PATHWAY
Systematic name | M25153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of tumor necrosis factor-mediated signaling pathway. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:23453807]
Full description |

Standard name | GO_REGULATION_OF_POTASSIUM_ION_IMPORT
Systematic name | M25154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of potassium ion import. [GO_REF:0000058, GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:10636900]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HYPOXIA_INDUCED_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M25155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of hypoxia-induced intrinsic apoptotic signaling pathway. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24553947]
Full description |

Standard name | GO_REGULATION_OF_HEXOKINASE_ACTIVITY
Systematic name | M13028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hexokinase activity. [GO_REF:0000059, GOC:mr, GOC:TermGenie, PMID:15804508]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HEXOKINASE_ACTIVITY
Systematic name | M25156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of hexokinase activity. [GO_REF:0000059, GOC:mr, GOC:TermGenie, PMID:15804508]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HEXOKINASE_ACTIVITY
Systematic name | M25157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of hexokinase activity. [GO_REF:0000059, GOC:mr, GOC:TermGenie, PMID:15804508]
Full description |

Standard name | GO_REGULATION_OF_REGULATED_SECRETORY_PATHWAY
Systematic name | M13691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of regulated secretory pathway. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:12526776]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_REGULATED_SECRETORY_PATHWAY
Systematic name | M11533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of regulated secretory pathway. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:12526776]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_REGULATED_SECRETORY_PATHWAY
Systematic name | M12496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of regulated secretory pathway. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:12526776]
Full description |

Standard name | GO_REGULATION_OF_MRNA_METABOLIC_PROCESS
Systematic name | M29343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mRNA metabolic process. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MRNA_METABOLIC_PROCESS
Systematic name | M29344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of mRNA metabolic process. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MRNA_METABOLIC_PROCESS
Systematic name | M29345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of mRNA metabolic process. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_MATURATION
Systematic name | M14016
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein maturation. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_MATURATION
Systematic name | M16220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein maturation. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_MATURATION
Systematic name | M10076
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein maturation. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_MODIFICATION_BY_SMALL_PROTEIN_CONJUGATION_OR_REMOVAL
Systematic name | M13239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein modification by small protein conjugation or removal. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_MODIFICATION_BY_SMALL_PROTEIN_CONJUGATION_OR_REMOVAL
Systematic name | M10356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein modification by small protein conjugation or removal. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_MODIFICATION_BY_SMALL_PROTEIN_CONJUGATION_OR_REMOVAL
Systematic name | M16937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein modification by small protein conjugation or removal. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_FOLDING
Systematic name | M25158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein folding. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_FOLDING
Systematic name | M25159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein folding. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_VACUOLAR_TRANSPORT
Systematic name | M12133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of vacuolar transport. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BICELLULAR_TIGHT_JUNCTION_ASSEMBLY
Systematic name | M29346
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of tight junction assembly. [GO_REF:0000058, GOC:jz, GOC:TermGenie, PMID:25050009]
Full description |

Standard name | GO_RESPONSE_TO_DOPAMINE
Systematic name | M25161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a dopamine stimulus. [GO_REF:0000071, GOC:mr, GOC:TermGenie, PMID:11118945]
Full description |

Standard name | GO_REGULATION_OF_GOLGI_ORGANIZATION
Systematic name | M10103
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of Golgi organization. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:17562788]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_BASOLATERAL_PLASMA_MEMBRANE
Systematic name | M25162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process in which a protein is transported to, or maintained in, basolateral regions of the plasma membrane. [GO_REF:0000087, GOC:kmv, GOC:TermGenie, PMID:24785082, PMID:9425351]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_PROTEIN_CATABOLIC_PROCESS
Systematic name | M14908
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cellular protein catabolic process. [GO_REF:0000058, GOC:kmv, GOC:obol, GOC:TermGenie, PMID:24785082]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_PROTEIN_CATABOLIC_PROCESS
Systematic name | M11426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cellular protein catabolic process. [GO_REF:0000058, GOC:kmv, GOC:obol, GOC:TermGenie, PMID:24785082]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_PROTEIN_CATABOLIC_PROCESS
Systematic name | M10644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cellular protein catabolic process. [GO_REF:0000058, GOC:kmv, GOC:obol, GOC:TermGenie, PMID:24785082]
Full description |

Standard name | GO_REGULATION_OF_FEAR_RESPONSE
Systematic name | M25163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of fear response. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:8677262]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FEAR_RESPONSE
Systematic name | M25164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of fear response. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:8677262]
Full description |

Standard name | GO_REGULATION_OF_ENDOPLASMIC_RETICULUM_TUBULAR_NETWORK_ORGANIZATION
Systematic name | M25165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endoplasmic reticulum tubular network organization. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:24891604]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OXIDATIVE_STRESS_INDUCED_NEURON_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M25166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of oxidative stress-induced neuron intrinsic apoptotic signaling pathway. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:15790595]
Full description |

Standard name | GO_REGULATION_OF_ADHERENS_JUNCTION_ORGANIZATION
Systematic name | M12631
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of adherens junction organization. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:21724833]
Full description |

Standard name | GO_L_ARGININE_TRANSMEMBRANE_TRANSPORT
Systematic name | M29347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-arginine across a membrane. [GO_REF:0000069, GOC:krc, GOC:TermGenie, PMID:8195186]
Full description |

Standard name | GO_L_LYSINE_TRANSMEMBRANE_TRANSPORT
Systematic name | M34307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of L-lysine across a membrane. [GO_REF:0000069, GOC:krc, GOC:TermGenie, PMID:8195186]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_NUCLEAR_BODY
Systematic name | M34308
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a nuclear body. [GO_REF:0000087, GOC:TermGenie, PMID:24713849]
Full description |

Standard name | GO_REACTIVE_OXYGEN_SPECIES_BIOSYNTHETIC_PROCESS
Systematic name | M12185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of reactive oxygen species, any molecules or ions formed by the incomplete one-electron reduction of oxygen. [GO_REF:0000068, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24252804]
Full description |

Standard name | GO_RESPONSE_TO_BILE_ACID
Systematic name | M34309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a bile acid stimulus. [GO_REF:0000071, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:21757002]
Full description |

Standard name | GO_RESPONSE_TO_GLYCOSIDE
Systematic name | M29348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glycoside stimulus. [GO_REF:0000071, GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:12027881, PMID:16243970]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_VESICLE_RECYCLING
Systematic name | M25167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of synaptic vesicle recycling. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:22745285]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPTIC_VESICLE_RECYCLING
Systematic name | M25168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of synaptic vesicle recycling. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:22745285]
Full description |

Standard name | GO_REGULATION_OF_REACTIVE_OXYGEN_SPECIES_BIOSYNTHETIC_PROCESS
Systematic name | M15379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of reactive oxygen species biosynthetic process. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24252804]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_REACTIVE_OXYGEN_SPECIES_BIOSYNTHETIC_PROCESS
Systematic name | M16007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of reactive oxygen species biosynthetic process. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24252804]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_REACTIVE_OXYGEN_SPECIES_BIOSYNTHETIC_PROCESS
Systematic name | M10827
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of reactive oxygen species biosynthetic process. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24252804]
Full description |

Standard name | GO_REGULATION_OF_CELL_MATURATION
Systematic name | M10300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell maturation. [GO_REF:0000058, GOC:TermGenie, PMID:17459944]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_MATURATION
Systematic name | M25169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cell maturation. [GO_REF:0000058, GOC:TermGenie, PMID:17459944]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_MATURATION
Systematic name | M25170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell maturation. [GO_REF:0000058, GOC:TermGenie, PMID:17459944]
Full description |

Standard name | GO_REGULATION_OF_TORC1_SIGNALING
Systematic name | M34310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of TORC1 signaling. [GO_REF:0000058, GOC:TermGenie]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CILIARY_MEMBRANE
Systematic name | M25172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a ciliary membrane. [GO_REF:0000087, GOC:cilia, GOC:krc, GOC:TermGenie, PMID:22139371]
Full description |

Standard name | GO_LIPOSACCHARIDE_METABOLIC_PROCESS
Systematic name | M15175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving liposaccharide. [GO_REF:0000068, GOC:dph, GOC:TermGenie, PMID:9452964]
Full description |

Standard name | GO_MUCOPOLYSACCHARIDE_METABOLIC_PROCESS
Systematic name | M16368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving mucopolysaccharide. [GO_REF:0000068, GOC:dph, GOC:TermGenie, PMID:4236091]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_TO_CYTOSOL_TRANSPORT
Systematic name | M10203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances from endoplasmic reticulum to cytosol. [GO_REF:0000076, GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:16402920]
Full description |

Standard name | GO_RELEASE_OF_SEQUESTERED_CALCIUM_ION_INTO_CYTOSOL_BY_ENDOPLASMIC_RETICULUM
Systematic name | M25173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of calcium ion from endoplasmic reticulum to cytosol. [GO_REF:0000078, GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:16402920]
Full description |

Standard name | GO_REGULATION_OF_BLOOD_CIRCULATION
Systematic name | M16818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of blood circulation. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:10659969]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BLOOD_CIRCULATION
Systematic name | M12545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of blood circulation. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:10659969]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BLOOD_CIRCULATION
Systematic name | M15274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of blood circulation. [GO_REF:0000058, GOC:mr, GOC:TermGenie, PMID:10659969]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_TUBULATION
Systematic name | M25174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of membrane tubulation. [GO_REF:0000058, GOC:pm, GOC:TermGenie, PMID:18388313]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_TARGETING
Systematic name | M16731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein targeting. [GO_REF:0000058, GOC:TermGenie]
Full description |

Standard name | GO_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_POSTSYNAPTIC_MEMBRANE
Systematic name | M25176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a protein to a specific location in a postsynaptic membrane. [GO_REF:0000087, GOC:kmv, GOC:TermGenie, pmid:9753322]
Full description |

Standard name | GO_REGULATION_OF_EXOSOMAL_SECRETION
Systematic name | M13840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of exosomal secretion. [GO_REF:0000058, GOC:TermGenie, PMID:24105262]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_PHOTORECEPTOR_OUTER_SEGMENT
Systematic name | M25177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a photoreceptor outer segment. [GO_REF:0000087, GOC:TermGenie, PMID:11481257, PMID:21867699]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TUMOR_NECROSIS_FACTOR_SUPERFAMILY_CYTOKINE_PRODUCTION
Systematic name | M16514
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of tumor necrosis factor superfamily cytokine production. [GO_REF:0000058, GOC:TermGenie, PMID:24187568]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TUMOR_NECROSIS_FACTOR_SUPERFAMILY_CYTOKINE_PRODUCTION
Systematic name | M11905
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of tumor necrosis factor superfamily cytokine production. [GO_REF:0000058, GOC:TermGenie, PMID:24187568]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CILIUM
Systematic name | M25178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to cilium. [GO_REF:0000058, GOC:cilia, GOC:krc, GOC:TermGenie, PMID:22072986]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CILIUM
Systematic name | M25179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein localization to cilium. [GO_REF:0000058, GOC:cilia, GOC:krc, GOC:TermGenie, PMID:22072986]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_ENDOPLASMIC_RETICULUM_STRESS
Systematic name | M10079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of a response to endoplasmic reticulum stress. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:11381086]
Full description |

Standard name | GO_CORNIFIED_ENVELOPE_ASSEMBLY
Systematic name | M34311
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a cornified envelope. [GO_REF:0000079, GOC:pm, GOC:TermGenie, PMID:22226963, PMID:24794495]
Full description |

Standard name | GO_REGULATION_OF_ATP_METABOLIC_PROCESS
Systematic name | M29349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ATP metabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:20695849]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ATP_METABOLIC_PROCESS
Systematic name | M29350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of ATP metabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:20695849]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ATP_METABOLIC_PROCESS
Systematic name | M29351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of ATP metabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:20695849]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_BLOOD_VESSEL_ENDOTHELIAL_CELL_PROLIFERATION_INVOLVED_IN_SPROUTING_ANGIOGENESIS
Systematic name | M25180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of blood vessel endothelial cell proliferation involved in sprouting angiogenesis. [GO_REF:0000058, GOC:TermGenie, PMID:23388056]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BLOOD_VESSEL_ENDOTHELIAL_CELL_PROLIFERATION_INVOLVED_IN_SPROUTING_ANGIOGENESIS
Systematic name | M25181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of blood vessel endothelial cell proliferation involved in sprouting angiogenesis. [GO_REF:0000058, GOC:TermGenie, PMID:23388056]
Full description |

Standard name | GO_REGULATION_OF_HISTAMINE_SECRETION_BY_MAST_CELL
Systematic name | M34312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of histamine secretion by mast cell. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:18253931]
Full description |

Standard name | GO_REGULATION_OF_GAP_JUNCTION_ASSEMBLY
Systematic name | M29352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gap junction assembly. [GO_REF:0000058, GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:25017399]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AUTOPHAGY_OF_MITOCHONDRION
Systematic name | M25182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of mitochondrion degradation by autophagy. [GO_REF:0000058, GOC:autophagy, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:21753002]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CYTOPLASMIC_STRESS_GRANULE
Systematic name | M25183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a cytoplasmic stress granule. [GO_REF:0000087, GOC:TermGenie, PMID:24755092]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_TYROSINE_PHOSPHATASE_ACTIVITY
Systematic name | M25184
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein tyrosine phosphatase activity. [GO_REF:0000059, GOC:TermGenie, PMID:11129957]
Full description |

Standard name | GO_REGULATION_OF_DNA_CATABOLIC_PROCESS
Systematic name | M25185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA catabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:2001740]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_CATABOLIC_PROCESS
Systematic name | M29353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of DNA catabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:2001740]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_CATABOLIC_PROCESS
Systematic name | M25186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of DNA catabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:2001740]
Full description |

Standard name | GO_REGULATION_OF_CHAPERONE_MEDIATED_PROTEIN_FOLDING
Systematic name | M29354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of chaperone-mediated protein folding. [GO_REF:0000058, GOC:TermGenie, PMID:24375412]
Full description |

Standard name | GO_REGULATION_OF_CYTOPLASMIC_TRANSPORT
Systematic name | M14193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cytoplasmic transport. [GO_REF:0000058, GOC:TermGenie, PMID:25049409]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOPLASMIC_TRANSPORT
Systematic name | M11225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cytoplasmic transport. [GO_REF:0000058, GOC:TermGenie, PMID:25049409]
Full description |

Standard name | GO_REGULATION_OF_COMPLEMENT_DEPENDENT_CYTOTOXICITY
Systematic name | M29355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of complement-dependent cytotoxicity. [GO_REF:0000058, GOC:TermGenie, PMID:24280217]
Full description |

Standard name | GO_REGULATION_OF_SPROUTING_ANGIOGENESIS
Systematic name | M15869
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of sprouting angiogenesis. [GO_REF:0000058, GOC:TermGenie, PMID:16756958]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SPROUTING_ANGIOGENESIS
Systematic name | M12788
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of sprouting angiogenesis. [GO_REF:0000058, GOC:TermGenie, PMID:16756958]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SPROUTING_ANGIOGENESIS
Systematic name | M14963
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of sprouting angiogenesis. [GO_REF:0000058, GOC:TermGenie, PMID:16756958]
Full description |

Standard name | GO_REGULATION_OF_WOUND_HEALING_SPREADING_OF_EPIDERMAL_CELLS
Systematic name | M25187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of wound healing, spreading of epidermal cells. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:18394891]
Full description |

Standard name | GO_REGULATION_OF_HEMOPOIESIS
Systematic name | M12354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hemopoiesis. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:20080761]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_HEMOPOIESIS
Systematic name | M12955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of hemopoiesis. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:20080761]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HEMOPOIESIS
Systematic name | M10459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of hemopoiesis. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:20080761]
Full description |

Standard name | GO_REGULATION_OF_AEROBIC_RESPIRATION
Systematic name | M25188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of aerobic respiration. [GO_REF:0000058, GOC:TermGenie, PMID:19266076]
Full description |

Standard name | GO_REGULATION_OF_I_KAPPAB_PHOSPHORYLATION
Systematic name | M25189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of I-kappaB phosphorylation. [GO_REF:0000058, GOC:TermGenie, PMID:23675531]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_I_KAPPAB_PHOSPHORYLATION
Systematic name | M25190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of I-kappaB phosphorylation. [GO_REF:0000058, GOC:TermGenie, PMID:23675531]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHOLIPID_METABOLIC_PROCESS
Systematic name | M11757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of phospholipid metabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:10657240]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PHOSPHOLIPID_METABOLIC_PROCESS
Systematic name | M29356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of phospholipid metabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:10657240]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHOSPHOLIPID_METABOLIC_PROCESS
Systematic name | M29357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of phospholipid metabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:10657240]
Full description |

Standard name | GO_REGULATION_OF_PLASMA_MEMBRANE_ORGANIZATION
Systematic name | M14083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of plasma membrane organization. [GO_REF:0000058, GOC:TermGenie, PMID:24514900]
Full description |

Standard name | GO_REGULATION_OF_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_MITOCHONDRION
Systematic name | M13792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of establishment of protein localization to mitochondrion. [GO_REF:0000058, GOC:TermGenie, PMID:16857185]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_MITOCHONDRION
Systematic name | M25192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of establishment of protein localization to mitochondrion. [GO_REF:0000058, GOC:TermGenie, PMID:16857185]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_MITOCHONDRION
Systematic name | M25193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of establishment of protein localization to mitochondrion. [GO_REF:0000058, GOC:TermGenie, PMID:16857185]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_P38MAPK_CASCADE
Systematic name | M25194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of p38MAPK cascade. [GO_REF:0000058, GOC:TermGenie, PMID:18681888]
Full description |

Standard name | GO_REGULATION_OF_VOLTAGE_GATED_POTASSIUM_CHANNEL_ACTIVITY_INVOLVED_IN_VENTRICULAR_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL_REPOLARIZATION
Systematic name | M25195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of voltage-gated potassium channel activity involved in ventricular cardiac muscle cell action potential repolarization. [GO_REF:0000059, GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:18337493]
Full description |

Standard name | GO_REGULATION_OF_POTASSIUM_ION_EXPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M25196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of potassium ion export across the plasma membrane. [GO_REF:0000058, GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:19646991]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_CONDUCTION
Systematic name | M15784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardiac conduction. [GO_REF:0000058, GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rph, GOC:TermGenie, PMID:12967627]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ANION_TRANSPORT
Systematic name | M12265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of anion transport. [GO_REF:0000058, GOC:TermGenie, PMID:11336802]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ANION_TRANSPORT
Systematic name | M16717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of anion transport. [GO_REF:0000058, GOC:TermGenie, PMID:11336802]
Full description |

Standard name | GO_REGULATION_OF_INORGANIC_ANION_TRANSMEMBRANE_TRANSPORT
Systematic name | M25198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of inorganic anion transmembrane transport. [GO_REF:0000058, GOC:TermGenie, PMID:11336802]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PRODUCTION_OF_MIRNAS_INVOLVED_IN_GENE_SILENCING_BY_MIRNA
Systematic name | M25199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of production of miRNAs involved in gene silencing by miRNA. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:22269326]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PRODUCTION_OF_MIRNAS_INVOLVED_IN_GENE_SILENCING_BY_MIRNA
Systematic name | M25200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of production of miRNAs involved in gene silencing by miRNA. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:22269326]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VOLTAGE_GATED_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M25201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of voltage-gated potassium channel activity. [GO_REF:0000059, GOC:TermGenie, PMID:19219384]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VOLTAGE_GATED_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M25202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of voltage-gated potassium channel activity. [GO_REF:0000059, GOC:TermGenie, PMID:19219384]
Full description |

Standard name | GO_ORGANIC_ACID_TRANSMEMBRANE_TRANSPORT
Systematic name | M14013
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which an organic acid is transported across a membrane. [GO_REF:0000069, GOC:TermGenie]
Full description |

Standard name | GO_ARGININE_TRANSMEMBRANE_TRANSPORT
Systematic name | M25203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of arginine across a membrane. [GO_REF:0000069, GOC:TermGenie, PMID:18357653]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_PROTEIN_LOCALIZATION
Systematic name | M16077
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cellular protein localization. Cellular protein localization is any process in which a protein is transported to, and/or maintained in, a specific location and encompasses movement within the cell, from within the cell to the cell surface, or from one location to another at the surface of a cell. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_PROTEIN_LOCALIZATION
Systematic name | M11705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cellular protein localization. Cellular protein localization is any process in which a protein is transported to, and/or maintained in, a specific location and encompasses movement within the cell, from within the cell to the cell surface, or from one location to another at the surface of a cell. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_PROTEIN_LOCALIZATION
Systematic name | M11085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cellular protein localization. Cellular protein localization is any process in which a protein is transported to, and/or maintained in, a specific location and encompasses movement within the cell, from within the cell to the cell surface, or from one location to another at the surface of a cell. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_RESPONSE_TO_TRANSFORMING_GROWTH_FACTOR_BETA_STIMULUS
Systematic name | M13980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cellular response to transforming growth factor beta stimulus. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:22269326]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_RESPONSE_TO_TRANSFORMING_GROWTH_FACTOR_BETA_STIMULUS
Systematic name | M25204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cellular response to transforming growth factor beta stimulus. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:22269326]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELLULAR_RESPONSE_TO_TRANSFORMING_GROWTH_FACTOR_BETA_STIMULUS
Systematic name | M11759
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cellular response to transforming growth factor beta stimulus. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:22269326]
Full description |

Standard name | GO_REGULATION_OF_AORTA_MORPHOGENESIS
Systematic name | M25205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of aorta morphogenesis. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:22269326]
Full description |

Standard name | GO_REGULATION_OF_DENDRITE_EXTENSION
Systematic name | M15666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of dendrite extension. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:24898855]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OXIDATIVE_PHOSPHORYLATION
Systematic name | M25206
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of oxidative phosphorylation. [GO_REF:0000058, GOC:TermGenie, PMID:10225962]
Full description |

Standard name | GO_EXTRAEMBRYONIC_MEMBRANE_DEVELOPMENT
Systematic name | M25207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an extraembryonic membrane over time, from its formation to the mature structure. [GO_REF:0000094, GOC:TermGenie, ISBN:0073040584]
Full description |

Standard name | GO_REGULATION_OF_IRE1_MEDIATED_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M11965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the IRE1-mediated unfolded protein response. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:22013210]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_IRE1_MEDIATED_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M34313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of the IRE1-mediated unfolded protein response. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:22013210]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_IRE1_MEDIATED_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M25208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the IRE1-mediated unfolded protein response. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:22013210]
Full description |

Standard name | GO_REGULATION_OF_PERK_MEDIATED_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M25209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the PERK-mediated unfolded protein response. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:22013210]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PERK_MEDIATED_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M25210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of the PERK-mediated unfolded protein response. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:22013210]
Full description |

Standard name | GO_REGULATION_OF_VIRAL_LIFE_CYCLE
Systematic name | M25211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of viral life cycle. [GO_REF:0000058, GOC:TermGenie, PMID:18005716]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VIRAL_LIFE_CYCLE
Systematic name | M29359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of viral life cycle. [GO_REF:0000058, GOC:TermGenie, PMID:18005716]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VIRAL_LIFE_CYCLE
Systematic name | M25212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of viral life cycle. [GO_REF:0000058, GOC:TermGenie, PMID:18005716]
Full description |

Standard name | GO_REGULATION_OF_RECEPTOR_CLUSTERING
Systematic name | M25213
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of receptor clustering. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:23575248]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RECEPTOR_CLUSTERING
Systematic name | M25214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of receptor clustering. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:23575248]
Full description |

Standard name | GO_RESPONSE_TO_SODIUM_ARSENITE
Systematic name | M25215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a sodium arsenite stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:18674524]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_SODIUM_ARSENITE
Systematic name | M25216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a sodium arsenite stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:18674524]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_TARGETING_TO_MITOCHONDRION
Systematic name | M25217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein targeting to mitochondrion. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:24270810]
Full description |

Standard name | GO_REGULATION_OF_ANION_TRANSMEMBRANE_TRANSPORT
Systematic name | M14130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of anion transmembrane transport. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ANION_TRANSMEMBRANE_TRANSPORT
Systematic name | M25218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of anion transmembrane transport. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ANION_TRANSMEMBRANE_TRANSPORT
Systematic name | M25219
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of anion transmembrane transport. [GO_REF:0000058, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_CELLULAR_RESPONSE_TO_MACROPHAGE_COLONY_STIMULATING_FACTOR_STIMULUS
Systematic name | M25220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cellular response to macrophage colony-stimulating factor stimulus. [GO_REF:0000058, GOC:BHF, GOC:nc, GOC:TermGenie, PMID:19100238]
Full description |

Standard name | GO_REGULATION_OF_GLIAL_CELL_MIGRATION
Systematic name | M25221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glial cell migration. [GO_REF:0000058, GOC:BHF, GOC:nc, GOC:TermGenie, PMID:19100238]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLIAL_CELL_MIGRATION
Systematic name | M34314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of glial cell migration. [GO_REF:0000058, GOC:BHF, GOC:nc, GOC:TermGenie, PMID:19100238]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLIAL_CELL_MIGRATION
Systematic name | M25222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of glial cell migration. [GO_REF:0000058, GOC:BHF, GOC:nc, GOC:TermGenie, PMID:19100238]
Full description |

Standard name | GO_REGULATION_OF_MICROGLIAL_CELL_ACTIVATION
Systematic name | M25223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of microglial cell activation. [GO_REF:0000058, GOC:BHF, GOC:nc, GOC:TermGenie, PMID:19100238]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MICROGLIAL_CELL_ACTIVATION
Systematic name | M25224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of microglial cell activation. [GO_REF:0000058, GOC:BHF, GOC:nc, GOC:TermGenie, PMID:19100238]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MICROGLIAL_CELL_ACTIVATION
Systematic name | M25225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of microglial cell activation. [GO_REF:0000058, GOC:BHF, GOC:nc, GOC:TermGenie, PMID:19100238]
Full description |

Standard name | GO_REGULATION_OF_NON_MEMBRANE_SPANNING_PROTEIN_TYROSINE_KINASE_ACTIVITY
Systematic name | M25226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of non-membrane spanning protein tyrosine kinase activity. [GO_REF:0000059, GOC:BHF, GOC:nc, GOC:TermGenie, PMID:10518561]
Full description |

Standard name | GO_REGULATION_OF_EATING_BEHAVIOR
Systematic name | M25227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of eating behavior. [GO_REF:0000058, GOC:TermGenie, PMID:11961051]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULATURE_DEVELOPMENT
Systematic name | M11039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vasculature development. [GO_REF:0000058, GOC:TermGenie, PMID:21472453]
Full description |

Standard name | GO_EPITHELIAL_CELL_APOPTOTIC_PROCESS
Systematic name | M14182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in an epithelial cell. [GO_REF:0000085, GOC:TermGenie, PMID:19137015]
Full description |

Standard name | GO_REGULATION_OF_COLLAGEN_FIBRIL_ORGANIZATION
Systematic name | M25228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of collagen fibril organization. [GO_REF:0000058, GOC:TermGenie, PMID:25451920]
Full description |

Standard name | GO_REGULATION_OF_CYCLIN_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M14915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cyclin-dependent protein kinase activity. [GO_REF:0000059, GOC:als, GOC:TermGenie, PMID:22995177]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYCLIN_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M10177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cyclin-dependent protein kinase activity. [GO_REF:0000059, GOC:als, GOC:TermGenie, PMID:22995177]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYCLIN_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M16332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cyclin-dependent protein kinase activity. [GO_REF:0000059, GOC:als, GOC:TermGenie, PMID:22995177]
Full description |

Standard name | GO_REGULATION_OF_EPITHELIAL_CELL_APOPTOTIC_PROCESS
Systematic name | M10343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of epithelial cell apoptotic process. [GO_REF:0000058, GOC:TermGenie, PMID:19137015]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EPITHELIAL_CELL_APOPTOTIC_PROCESS
Systematic name | M12488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of epithelial cell apoptotic process. [GO_REF:0000058, GOC:TermGenie, PMID:19137015]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPITHELIAL_CELL_APOPTOTIC_PROCESS
Systematic name | M13093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of epithelial cell apoptotic process. [GO_REF:0000058, GOC:TermGenie, PMID:19137015]
Full description |

Standard name | GO_RESPONSE_TO_ALDOSTERONE
Systematic name | M34315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an aldosterone stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:17644563]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_PRODUCTION
Systematic name | M34316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of vascular endothelial growth factor production. [GO_REF:0000058, GOC:TermGenie, PMID:19404486]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SENSORY_PERCEPTION_OF_PAIN
Systematic name | M25229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of sensory perception of pain. [GO_REF:0000058, GOC:TermGenie, PMID:17167094]
Full description |

Standard name | GO_REGULATION_OF_CATION_TRANSMEMBRANE_TRANSPORT
Systematic name | M16624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cation transmembrane transport. [GO_REF:0000058, GOC:TermGenie, PMID:15304482]
Full description |

Standard name | GO_MICROGLIAL_CELL_MIGRATION
Systematic name | M25230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a microglial cell from one site to another. [GO_REF:0000091, GOC:BHF, GOC:nc, GOC:TermGenie, PMID:19100238]
Full description |

Standard name | GO_REGULATION_OF_RETROGRADE_PROTEIN_TRANSPORT_ER_TO_CYTOSOL
Systematic name | M15078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of retrograde protein transport, ER to cytosol. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:18555783]
Full description |

Standard name | GO_REGULATION_OF_ADIPOSE_TISSUE_DEVELOPMENT
Systematic name | M25232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of adipose tissue development. [GO_REF:0000058, GOC:TermGenie, PMID:23081848]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ADIPOSE_TISSUE_DEVELOPMENT
Systematic name | M25233
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of adipose tissue development. [GO_REF:0000058, GOC:TermGenie, PMID:23081848]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MEMBRANE_DEPOLARIZATION
Systematic name | M25234
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of membrane depolarization. [GO_REF:0000058, GOC:TermGenie, PMID:20826763]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MEMBRANE_DEPOLARIZATION
Systematic name | M11499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of membrane depolarization. [GO_REF:0000058, GOC:TermGenie, PMID:20826763]
Full description |

Standard name | GO_REGULATION_OF_PYRUVATE_DEHYDROGENASE_ACTIVITY
Systematic name | M29360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of pyruvate dehydrogenase activity. [GO_REF:0000059, GOC:dph, GOC:TermGenie, PMID:25525879]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PYRUVATE_DEHYDROGENASE_ACTIVITY
Systematic name | M34317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of pyruvate dehydrogenase activity. [GO_REF:0000059, GOC:dph, GOC:TermGenie, PMID:25525879]
Full description |

Standard name | GO_PERICYTE_CELL_DIFFERENTIATION
Systematic name | M25235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a pericyte cell. [GO_REF:0000086, GOC:dph, GOC:TermGenie, PMID:23868830]
Full description |

Standard name | GO_REGULATION_OF_BILE_ACID_METABOLIC_PROCESS
Systematic name | M25236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of bile acid metabolic process. [GO_REF:0000058, GOC:bf, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_BASEMENT_MEMBRANE_ASSEMBLY_INVOLVED_IN_EMBRYONIC_BODY_MORPHOGENESIS
Systematic name | M25238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of basement membrane assembly involved in embryonic body morphogenesis. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:23940118]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TORC1_SIGNALING
Systematic name | M25239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of TORC1 signaling. [GO_REF:0000058, GOC:TermGenie, PMID:25366275]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TORC1_SIGNALING
Systematic name | M25240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of TORC1 signaling. [GO_REF:0000058, GOC:TermGenie, PMID:25366275]
Full description |

Standard name | GO_REGULATION_OF_ERAD_PATHWAY
Systematic name | M16460
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ERAD pathway. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ERAD_PATHWAY
Systematic name | M15415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of ERAD pathway. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:22590560]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ERAD_PATHWAY
Systematic name | M16695
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of ERAD pathway. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GASTRO_INTESTINAL_SYSTEM_SMOOTH_MUSCLE_CONTRACTION
Systematic name | M25241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of gastro-intestinal system smooth muscle contraction. [GO_REF:0000058, GOC:TermGenie, PMID:10821044]
Full description |

Standard name | GO_RESPONSE_TO_FORSKOLIN
Systematic name | M25242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a forskolin stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:15937517]
Full description |

Standard name | GO_REGULATION_OF_DOPAMINERGIC_NEURON_DIFFERENTIATION
Systematic name | M25243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of dopaminergic neuron differentiation. [GO_REF:0000058, GOC:TermGenie, PMID:15522889]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_CATABOLIC_PROCESS_IN_THE_VACUOLE
Systematic name | M25244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein catabolic process in the vacuole. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:25635054]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_CATABOLIC_PROCESS_IN_THE_VACUOLE
Systematic name | M25245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein catabolic process in the vacuole. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:25635054]
Full description |

Standard name | GO_REGULATION_OF_TELOMERE_CAPPING
Systematic name | M15350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of telomere capping. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:23959892]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TELOMERE_CAPPING
Systematic name | M25246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of telomere capping. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:23959892]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TELOMERE_CAPPING
Systematic name | M12680
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of telomere capping. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:23959892]
Full description |

Standard name | GO_REGULATION_OF_TELOMERE_MAINTENANCE_VIA_TELOMERE_LENGTHENING
Systematic name | M16081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of telomere maintenance via telomere lengthening. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:23959892]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TELOMERE_MAINTENANCE_VIA_TELOMERE_LENGTHENING
Systematic name | M13041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of telomere maintenance via telomere lengthening. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:23959892]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TELOMERE_MAINTENANCE_VIA_TELOMERE_LENGTHENING
Systematic name | M13953
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of telomere maintenance via telomere lengthening. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:23959892]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CELL_PERIPHERY
Systematic name | M25247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to cell periphery. [GO_REF:0000058, GOC:TermGenie, PMID:18216290]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CELL_PERIPHERY
Systematic name | M14750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein localization to cell periphery. [GO_REF:0000058, GOC:TermGenie, PMID:18216290]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CELL_PERIPHERY
Systematic name | M12028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein localization to cell periphery. [GO_REF:0000058, GOC:TermGenie, PMID:18216290]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_MANNOSE_TRIMMING
Systematic name | M25248
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any protein alpha-1,2-demannosylation that takes place in the endoplasmic reticulum quality control compartment (ERQC). [GO_REF:0000062, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24519966]
Full description |

Standard name | GO_RESPONSE_TO_L_PHENYLALANINE_DERIVATIVE
Systematic name | M29364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a L-phenylalanine derivative stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:12112407]
Full description |

Standard name | GO_REGULATION_OF_SKELETAL_MUSCLE_ACETYLCHOLINE_GATED_CHANNEL_CLUSTERING
Systematic name | M25249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of skeletal muscle acetylcholine-gated channel clustering. [GO_REF:0000058, GOC:TermGenie, PMID:7722643]
Full description |

Standard name | GO_REGULATION_OF_NEUROMUSCULAR_JUNCTION_DEVELOPMENT
Systematic name | M25250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neuromuscular junction development. [GO_REF:0000058, GOC:TermGenie, PMID:7722643]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEUROMUSCULAR_JUNCTION_DEVELOPMENT
Systematic name | M25251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of neuromuscular junction development. [GO_REF:0000058, GOC:TermGenie, PMID:7722643]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NITRIC_OXIDE_METABOLIC_PROCESS
Systematic name | M29365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of nitric oxide metabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:11991626]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NITRIC_OXIDE_METABOLIC_PROCESS
Systematic name | M29366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of nitric oxide metabolic process. [GO_REF:0000058, GOC:TermGenie, PMID:11991626]
Full description |

Standard name | GO_REGULATION_OF_XENOPHAGY
Systematic name | M25252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of xenophagy. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:21617041]
Full description |

Standard name | GO_REGULATION_OF_GTP_BINDING
Systematic name | M25253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of GTP binding. [GO_REF:0000059, GOC:TermGenie, PMID:19066305, PMID:21454546]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CALCIUM_ION_TRANSMEMBRANE_TRANSPORT
Systematic name | M12807
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of calcium ion transmembrane transport. [GO_REF:0000058, GOC:TermGenie, PMID:22910094]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TUBULIN_DEACETYLATION
Systematic name | M25254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of tubulin deacetylation. [GO_REF:0000058, GOC:TermGenie, PMID:23886946]
Full description |

Standard name | GO_REGULATION_OF_T_CIRCLE_FORMATION
Systematic name | M25255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of t-circle formation. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:22579284]
Full description |

Standard name | GO_FOLATE_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M25256
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of folic acid from outside of a cell, across the plasma membrane and into the cytosol. [GO_REF:0000075, GOC:BHF, GOC:hal, GOC:TermGenie, PMID:19762432]
Full description |

Standard name | GO_REGULATION_OF_MATRIX_METALLOPEPTIDASE_SECRETION
Systematic name | M29367
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of matrix metallopeptidase secretion. [GO_REF:0000058, GOC:TermGenie, PMID:8679543]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MATRIX_METALLOPEPTIDASE_SECRETION
Systematic name | M29368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of matrix metallopeptidase secretion. [GO_REF:0000058, GOC:TermGenie, PMID:8679543]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TUMOR_NECROSIS_FACTOR_SECRETION
Systematic name | M25257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of tumor necrosis factor secretion. [GO_REF:0000058, GOC:TermGenie, PMID:15560120]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TUMOR_NECROSIS_FACTOR_SECRETION
Systematic name | M25258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of tumor necrosis factor secretion. [GO_REF:0000058, GOC:TermGenie, PMID:15560120]
Full description |

Standard name | GO_REGULATION_OF_INTESTINAL_ABSORPTION
Systematic name | M25259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of intestinal absorption. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:12469120]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CILIARY_TRANSITION_ZONE
Systematic name | M25260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a ciliary transition zone. [GO_REF:0000087, GOC:kmv, GOC:TermGenie, PMID:21422230]
Full description |

Standard name | GO_REGULATION_OF_LIPOPHAGY
Systematic name | M25261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lipophagy. [GO_REF:0000058, GOC:autophagy, GOC:dph, GOC:TermGenie, PMID:25383539]
Full description |

Standard name | GO_REGULATION_OF_MICROTUBULE_BINDING
Systematic name | M25262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of microtubule binding. [GO_REF:0000059, GOC:als, GOC:TermGenie, PMID:24520051]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MICROTUBULE_BINDING
Systematic name | M25263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of microtubule binding. [GO_REF:0000059, GOC:als, GOC:TermGenie, PMID:24520051]
Full description |

Standard name | GO_RESPONSE_TO_GLYCOPROTEIN
Systematic name | M29369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glycoprotein stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:14597422]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_IMPORT
Systematic name | M14145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein import. [GO_REF:0000058, GOC:TermGenie, PMID:11406629]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_IMPORT
Systematic name | M34318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein import. [GO_REF:0000058, GOC:TermGenie, PMID:11406629]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_IMPORT
Systematic name | M14921
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein import. [GO_REF:0000058, GOC:TermGenie, PMID:11406629]
Full description |

Standard name | GO_RESPONSE_TO_PHORBOL_13_ACETATE_12_MYRISTATE
Systematic name | M25264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a phorbol 13-acetate 12-myristate stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:2200903]
Full description |

Standard name | GO_RESPONSE_TO_AMYLOID_BETA
Systematic name | M25265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a amyloid-beta stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:23555824]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_AMYLOID_BETA
Systematic name | M29370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a amyloid-beta stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:23555824]
Full description |

Standard name | GO_REGULATION_OF_UBIQUITIN_PROTEIN_LIGASE_ACTIVITY
Systematic name | M15755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ubiquitin protein ligase activity. [GO_REF:0000059, GOC:dph, GOC:TermGenie, GOC:vw, PMID:10921876, PMID:26216882]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_UBIQUITIN_PROTEIN_LIGASE_ACTIVITY
Systematic name | M25266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of ubiquitin protein ligase activity. [GO_REF:0000059, GOC:dph, GOC:tb, GOC:TermGenie, PMID:26216882]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_UBIQUITIN_PROTEIN_LIGASE_ACTIVITY
Systematic name | M25267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of ubiquitin protein ligase activity. [GO_REF:0000059, GOC:dph, GOC:TermGenie, GOC:vw, PMID:10921876, PMID:26216882]
Full description |

Standard name | GO_REGULATION_OF_SOMATIC_STEM_CELL_POPULATION_MAINTENANCE
Systematic name | M25268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of somatic stem cell population maintenance. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:19409607]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SOMATIC_STEM_CELL_POPULATION_MAINTENANCE
Systematic name | M25269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of somatic stem cell population maintenance. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:19409607]
Full description |

Standard name | GO_REGULATION_OF_METALLOENDOPEPTIDASE_ACTIVITY
Systematic name | M25270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of metalloendopeptidase activity. [GO_REF:0000059, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:18591254]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_METALLOENDOPEPTIDASE_ACTIVITY
Systematic name | M25271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of metalloendopeptidase activity. [GO_REF:0000059, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:18591254]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_METALLOENDOPEPTIDASE_ACTIVITY
Systematic name | M25272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of metalloendopeptidase activity. [GO_REF:0000059, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:18591254]
Full description |

Standard name | GO_REGULATION_OF_CYTOPLASMIC_TRANSLATIONAL_INITIATION
Systematic name | M25273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cytoplasmic translational initiation. [GO_REF:0000058, GOC:TermGenie, PMID:12242291]
Full description |

Standard name | GO_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_PROLIFERATION
Systematic name | M25274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of vascular smooth muscle cell proliferation. [GO_REF:0000058, GOC:TermGenie, PMID:23246467]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_PROLIFERATION
Systematic name | M25275
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of vascular smooth muscle cell proliferation. [GO_REF:0000058, GOC:TermGenie, PMID:23246467]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_PROLIFERATION
Systematic name | M25276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vascular smooth muscle cell proliferation. [GO_REF:0000058, GOC:TermGenie, PMID:23246467]
Full description |

Standard name | GO_REGULATION_OF_CHAPERONE_MEDIATED_AUTOPHAGY
Systematic name | M25277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of chaperone-mediated autophagy. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:20176123]
Full description |

Standard name | GO_REGULATION_OF_ELECTRON_TRANSFER_ACTIVITY
Systematic name | M29371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of electron transfer activity. [GO_REF:0000059, GOC:TermGenie, PMID:25416781]
Full description |

Standard name | GO_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_MIGRATION
Systematic name | M25278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a vascular associated smooth muscle cell from one site to another. [GO_REF:0000091, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:20693317]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_APOPTOTIC_PROCESS_INVOLVED_IN_DEVELOPMENT
Systematic name | M25279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of apoptotic process involved in development. [GO_REF:0000058, GOC:TermGenie, PMID:22801495]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_APOPTOTIC_PROCESS_INVOLVED_IN_DEVELOPMENT
Systematic name | M25280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of apoptotic process involved in development. [GO_REF:0000058, GOC:TermGenie, PMID:22801495]
Full description |

Standard name | GO_REGULATION_OF_APOPTOTIC_PROCESS_INVOLVED_IN_DEVELOPMENT
Systematic name | M25281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of apoptotic process involved in development. [GO_REF:0000058, GOC:TermGenie, PMID:22801495]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_NUCLEOLUS
Systematic name | M25282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to nucleolus. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:24415760]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_MIGRATION
Systematic name | M25283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of vascular associated smooth muscle cell migration. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:20693317]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_MIGRATION
Systematic name | M25284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vascular associated smooth muscle cell migration. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:20693317]
Full description |

Standard name | GO_REGULATION_OF_MYOFIBROBLAST_DIFFERENTIATION
Systematic name | M25285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of myofibroblast differentiation. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:20533548]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CELL_CORTEX
Systematic name | M25286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to cell cortex. [GO_REF:0000058, GOC:TermGenie, PMID:17115027]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CELL_CORTEX
Systematic name | M25287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein localization to cell cortex. [GO_REF:0000058, GOC:TermGenie, PMID:17115027]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CENTROSOME
Systematic name | M25288
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to centrosome. [GO_REF:0000058, GOC:TermGenie, PMID:17115027]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CENTROSOME
Systematic name | M25289
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein localization to centrosome. [GO_REF:0000058, GOC:TermGenie, PMID:17115027]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NMDA_GLUTAMATE_RECEPTOR_ACTIVITY
Systematic name | M29373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of NMDA glutamate receptor activity. [GO_REF:0000059, GOC:mr, GOC:TermGenie, PMID:12857]
Full description |

Standard name | GO_REGULATION_OF_CORE_PROMOTER_BINDING
Systematic name | M25290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of core promoter binding. [GO_REF:0000059, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:22723415]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CORE_PROMOTER_BINDING
Systematic name | M34319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of core promoter binding. [GO_REF:0000059, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:22723415]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CHROMOSOME_TELOMERIC_REGION
Systematic name | M14217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to chromosome, telomeric region. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:19487455]
Full description |

Standard name | GO_BETA_CATENIN_TCF_COMPLEX_ASSEMBLY
Systematic name | M15756
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a beta-catenin-TCF complex. [GO_REF:0000079, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:18936100]
Full description |

Standard name | GO_REGULATION_OF_CELL_CHEMOTAXIS_TO_FIBROBLAST_GROWTH_FACTOR
Systematic name | M25291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell chemotaxis to fibroblast growth factor. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:23233752]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_CHEMOTAXIS_TO_FIBROBLAST_GROWTH_FACTOR
Systematic name | M25292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cell chemotaxis to fibroblast growth factor. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:23233752]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION_TO_TELOMERE
Systematic name | M25293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of establishment of protein localization to telomere. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:25467444]
Full description |

Standard name | GO_EXCITATORY_SYNAPSE_ASSEMBLY
Systematic name | M25294
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an excitatory synapse. [GO_REF:0000079, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:21670302]
Full description |

Standard name | GO_INHIBITORY_SYNAPSE_ASSEMBLY
Systematic name | M25295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form an inhibitory synapse. [GO_REF:0000079, GOC:bf, GOC:PARL, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TELOMERASE_RNA_LOCALIZATION_TO_CAJAL_BODY
Systematic name | M25296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of telomerase RNA localization to Cajal body. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:25467444]
Full description |

Standard name | GO_BETA_CATENIN_DESTRUCTION_COMPLEX_ASSEMBLY
Systematic name | M25297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a beta-catenin destruction complex. [GO_REF:0000079, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:17143292, PMID:23169527]
Full description |

Standard name | GO_BETA_CATENIN_DESTRUCTION_COMPLEX_DISASSEMBLY
Systematic name | M12106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disaggregation of a beta-catenin destruction complex into its constituent components. [GO_REF:0000079, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:23169527]
Full description |

Standard name | GO_CRANIAL_SKELETAL_SYSTEM_DEVELOPMENT
Systematic name | M13822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a cranial skeletal system over time, from its formation to the mature structure. The cranial skeletal system is the skeletal subdivision of the head, and includes the skull (cranium plus mandible), pharyngeal and/or hyoid apparatus. [GO_REF:0000094, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:11262227]
Full description |

Standard name | GO_REGULATION_OF_EXCITATORY_SYNAPSE_ASSEMBLY
Systematic name | M25298
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of excitatory synapse assembly. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie]
Full description |

Standard name | GO_REGULATION_OF_RECEPTOR_SIGNALING_PATHWAY_VIA_STAT
Systematic name | M25299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of receptor signaling via STAT. [GO_REF:0000058, GOC:rjd, GOC:TermGenie, PMID:24587195]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RECEPTOR_SIGNALING_PATHWAY_VIA_STAT
Systematic name | M25300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of receptor signaling via STAT. [GO_REF:0000058, GOC:rjd, GOC:TermGenie, PMID:24587195]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RECEPTOR_SIGNALING_PATHWAY_VIA_STAT
Systematic name | M25301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of receptor signaling pathway via STAT. [GO_REF:0000058, GOC:rjd, GOC:TermGenie, PMID:24587195]
Full description |

Standard name | GO_ESCRT_COMPLEX_DISASSEMBLY
Systematic name | M25302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The disaggregation of an ESCRT complex into its constituent components. [GO_REF:0000079, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:21118109]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOTHELIAL_CELL_MATRIX_ADHESION_VIA_FIBRONECTIN
Systematic name | M34320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of endothelial cell-matrix adhesion via fibronectin. [GO_REF:0000058, GOC:bc, GOC:BHF, GOC:BHF_miRNA, GOC:TermGenie, PMID:19460962]
Full description |

Standard name | GO_REGULATION_OF_AUTOPHAGY_OF_MITOCHONDRION_IN_RESPONSE_TO_MITOCHONDRIAL_DEPOLARIZATION
Systematic name | M25303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of autophagy of mitochondrion in response to mitochondrial depolarization. [GO_REF:0000058, GOC:pad, GOC:PARL, GOC:TermGenie, PMID:22020285]
Full description |

Standard name | GO_MIDBRAIN_DOPAMINERGIC_NEURON_DIFFERENTIATION
Systematic name | M25304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a relatively unspecialized cell acquires the specialized features of a midbrain dopaminergic neuron. [GO_REF:0000086, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:17331494, PMID:19122665]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION
Systematic name | M13086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of establishment of protein localization. [GO_REF:0000058, GOC:TermGenie, PMID:22761445]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ESTABLISHMENT_OF_PROTEIN_LOCALIZATION
Systematic name | M16565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of establishment of protein localization. [GO_REF:0000058, GOC:TermGenie, PMID:22761445]
Full description |

Standard name | GO_WNT_SIGNALING_PATHWAY_INVOLVED_IN_MIDBRAIN_DOPAMINERGIC_NEURON_DIFFERENTIATION
Systematic name | M25305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any Wnt signaling pathway that is involved in midbrain dopaminergic neuron differentiation. [GO_REF:0000060, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:21347250, PMID:22988876, PMID:23517308]
Full description |

Standard name | GO_REGULATION_OF_MIDBRAIN_DOPAMINERGIC_NEURON_DIFFERENTIATION
Systematic name | M25306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of midbrain dopaminergic neuron differentiation. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:21347250]
Full description |

Standard name | GO_BRUSH_BORDER_ASSEMBLY
Systematic name | M25307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of adjacent microvilli through the formation of Ca(2+)-dependent adhesion links between them, forming a brush border. [GO_REF:0000079, GOC:lb, GOC:TermGenie, PMID:24725409]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_ADHESION_TO_VASCULAR_ENDOTHELIAL_CELL
Systematic name | M25308
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of leukocyte adhesion to vascular endothelial cell. [GO_REF:0000058, GOC:bc, GOC:BHF, GOC:BHF_miRNA, GOC:TermGenie, PMID:23897866]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LEUKOCYTE_ADHESION_TO_VASCULAR_ENDOTHELIAL_CELL
Systematic name | M25309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of leukocyte adhesion to vascular endothelial cell. [GO_REF:0000058, GOC:bc, GOC:BHF, GOC:BHF_miRNA, GOC:TermGenie, PMID:23897866]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LEUKOCYTE_ADHESION_TO_VASCULAR_ENDOTHELIAL_CELL
Systematic name | M25310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of leukocyte adhesion to vascular endothelial cell. [GO_REF:0000058, GOC:bc, GOC:BHF, GOC:BHF_miRNA, GOC:TermGenie, PMID:23897866]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_ADHESION_TO_ARTERIAL_ENDOTHELIAL_CELL
Systematic name | M34321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of leukocyte adhesion to arterial endothelial cell. [GO_REF:0000058, GOC:bc, GOC:BHF, GOC:BHF_miRNA, GOC:TermGenie, PMID:22267480]
Full description |

Standard name | GO_REGULATION_OF_EPITHELIAL_TO_MESENCHYMAL_TRANSITION_INVOLVED_IN_ENDOCARDIAL_CUSHION_FORMATION
Systematic name | M25311
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of epithelial to mesenchymal transition involved in endocardial cushion formation. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:18718461]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPITHELIAL_TO_MESENCHYMAL_TRANSITION_INVOLVED_IN_ENDOCARDIAL_CUSHION_FORMATION
Systematic name | M25312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of epithelial to mesenchymal transition involved in endocardial cushion formation. [GO_REF:0000058, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:18718461]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_REPOLARIZATION_DURING_VENTRICULAR_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M25313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of membrane repolarization during ventricular cardiac muscle cell action potential. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:mtg_cardiac_conduct_nov11, GOC:rph, GOC:TermGenie, PMID:19893015]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_REPOLARIZATION_DURING_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M25314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of membrane repolarization during cardiac muscle cell action potential. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:mtg_cardiac_conduct_nov11, GOC:rph, GOC:TermGenie, PMID:23157812]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MEMBRANE_REPOLARIZATION_DURING_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M25315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of membrane repolarization during cardiac muscle cell action potential. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:mtg_cardiac_conduct_nov11, GOC:rph, GOC:TermGenie, PMID:23157812]
Full description |

Standard name | GO_AUTOPHAGOSOME_ORGANIZATION
Systematic name | M16504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of an autophagosome. [GOC:bf, GOC:PARL, GOC:TermGenie, PMID:22186024]
Full description |

Standard name | GO_REGULATION_OF_METALLOPEPTIDASE_ACTIVITY
Systematic name | M25316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of metallopeptidase activity. [GO_REF:0000059, GOC:TermGenie, PMID:26473732]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_METALLOPEPTIDASE_ACTIVITY
Systematic name | M25317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of metallopeptidase activity. [GO_REF:0000059, GOC:TermGenie, PMID:26473732]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_METALLOPEPTIDASE_ACTIVITY
Systematic name | M25318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of metallopeptidase activity. [GO_REF:0000059, GOC:TermGenie, PMID:26473732]
Full description |

Standard name | GO_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M25319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of vascular smooth muscle cell differentiation. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:19088079]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M25320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of vascular smooth muscle cell differentiation. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:19088079]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M25321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vascular smooth muscle cell differentiation. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:19088079]
Full description |

Standard name | GO_REGULATION_OF_GUANYL_NUCLEOTIDE_EXCHANGE_FACTOR_ACTIVITY
Systematic name | M25322
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of guanyl-nucleotide exchange factor activity. [GO_REF:0000059, GOC:TermGenie, PMID:20484009]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GUANYL_NUCLEOTIDE_EXCHANGE_FACTOR_ACTIVITY
Systematic name | M25323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of guanyl-nucleotide exchange factor activity. [GO_REF:0000059, GOC:TermGenie, PMID:20484009]
Full description |

Standard name | GO_CELL_SURFACE_RECEPTOR_SIGNALING_PATHWAY_INVOLVED_IN_CELL_CELL_SIGNALING
Systematic name | M14356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cell surface receptor signaling pathway that is involved in cell-cell signaling. [GO_REF:0000060, GOC:TermGenie, ISBN:0-7167-3051-0]
Full description |

Standard name | GO_RESPONSE_TO_ACETYLCHOLINE
Systematic name | M14251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an acetylcholine stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:21238497]
Full description |

Standard name | GO_LYSOSOMAL_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any cellular protein catabolic process that takes place in a lysosome. [GO_REF:0000062, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24334770]
Full description |

Standard name | GO_REGULATION_OF_VOLTAGE_GATED_SODIUM_CHANNEL_ACTIVITY
Systematic name | M34322
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of voltage-gated sodium channel activity. [GO_REF:0000059, GOC:TermGenie, PMID:24198377]
Full description |

Standard name | GO_REGULATION_OF_MEMBRANE_INVAGINATION
Systematic name | M15230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of membrane invagination. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:26589353]
Full description |

Standard name | GO_REGULATION_OF_LYSOSOMAL_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lysosomal protein catabolic process. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:23499937]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DOUBLE_STRAND_BREAK_REPAIR_VIA_HOMOLOGOUS_RECOMBINATION
Systematic name | M25326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of double-strand break repair via homologous recombination. [GO_REF:0000058, GOC:TermGenie, PMID:12023299]
Full description |

Standard name | GO_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_DEDIFFERENTIATION
Systematic name | M25327
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of vascular smooth muscle cell dedifferentiation. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:19088079]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_TISSUE_REGENERATION
Systematic name | M25328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardiac muscle tissue regeneration. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:23222520]
Full description |

Standard name | GO_REGULATION_OF_CONNECTIVE_TISSUE_REPLACEMENT
Systematic name | M25329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of connective tissue replacement. [GO_REF:0000058, GOC:bc, GOC:BHF, GOC:BHF_miRNA, GOC:TermGenie, PMID:25590961]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HYDROGEN_PEROXIDE_INDUCED_CELL_DEATH
Systematic name | M29375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell death in response to hydrogen peroxide. [GO_REF:0000058, GOC:bc, GOC:BHF, GOC:BHF_miRNA, GOC:TermGenie, PMID:20550618]
Full description |

Standard name | GO_REGULATION_OF_CARDIOCYTE_DIFFERENTIATION
Systematic name | M25330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardiocyte differentiation. [GO_REF:0000058, GOC:bc, GOC:BHF, GOC:BHF_miRNA, GOC:TermGenie, PMID:23069713]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CARDIOCYTE_DIFFERENTIATION
Systematic name | M25331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cardiocyte differentiation. [GO_REF:0000058, GOC:bc, GOC:BHF, GOC:BHF_miRNA, GOC:TermGenie, PMID:23069713]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CARDIOCYTE_DIFFERENTIATION
Systematic name | M25332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cardiocyte differentiation. [GO_REF:0000058, GOC:bc, GOC:BHF, GOC:BHF_miRNA, GOC:TermGenie, PMID:23069713]
Full description |

Standard name | GO_REGULATION_OF_RNA_BINDING
Systematic name | M25333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of RNA binding. [GO_REF:0000059, GOC:bf, GOC:PARL, GOC:TermGenie]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RNA_BINDING
Systematic name | M25334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of RNA binding. [GO_REF:0000059, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:25116364]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_L_GLUTAMATE
Systematic name | M29376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a L-glutamate(1-) stimulus. [GO_REF:0000071, GOC:TermGenie, PMID:25962137]
Full description |

Standard name | GO_REGULATION_OF_MODIFICATION_OF_SYNAPTIC_STRUCTURE
Systematic name | M25335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of modification of synaptic structure. [GO_REF:0000058, GOC:TermGenie, PMID:25164660]
Full description |

Standard name | GO_REGULATION_OF_ASPARTIC_TYPE_PEPTIDASE_ACTIVITY
Systematic name | M25336
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of aspartic-type peptidase activity. [GO_REF:0000059, GOC:jl, GOC:TermGenie, PMID:21745575]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ASPARTIC_TYPE_PEPTIDASE_ACTIVITY
Systematic name | M25337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of aspartic-type peptidase activity. [GO_REF:0000059, GOC:jl, GOC:TermGenie, PMID:21745575]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHROMATIN_ORGANIZATION
Systematic name | M25338
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of chromatin organization. [GO_REF:0000058, GOC:pr, GOC:TermGenie, GOC:vw, PMID:654321]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHROMATIN_ORGANIZATION
Systematic name | M25339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of chromatin organization. [GO_REF:0000058, GOC:pr, GOC:TermGenie, GOC:vw, PMID:654321]
Full description |

Standard name | GO_REGULATION_OF_MODIFICATION_OF_POSTSYNAPTIC_ACTIN_CYTOSKELETON
Systematic name | M29377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of modification of postsynaptic actin cytoskeleton. [GO_REF:0000058, GOC:TermGenie, PMID:21068295]
Full description |

Standard name | GO_REGULATION_OF_EPITHELIAL_TUBE_FORMATION
Systematic name | M25340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of epithelial tube formation. [GO_REF:0000058, GOC:bhm, GOC:TermGenie, PMID:25745997]
Full description |

Standard name | GO_REGULATION_OF_RETROGRADE_TRANSPORT_ENDOSOME_TO_GOLGI
Systematic name | M34323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of retrograde transport, endosome to Golgi. [GO_REF:0000058, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:23395371]
Full description |

Standard name | GO_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M25341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any apoptotic process in a vascular associated smooth muscle cell. [GO_REF:0000085, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:26493107]
Full description |

Standard name | GO_SEMI_LUNAR_VALVE_DEVELOPMENT
Systematic name | M25342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a semi-lunar valve over time, from its formation to the mature structure. [GO_REF:0000094, GOC:BHF, GOC:rl, GOC:TermGenie, PMID:19409885]
Full description |

Standard name | GO_TELOMERASE_HOLOENZYME_COMPLEX_ASSEMBLY
Systematic name | M25343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a telomerase holoenzyme complex. [GO_REF:0000079, GOC:TermGenie, PMID:26305931]
Full description |

Standard name | GO_REGULATION_OF_MORPHOGENESIS_OF_AN_EPITHELIUM
Systematic name | M25344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of morphogenesis of an epithelium. [GO_REF:0000058, GOC:bhm, GOC:TermGenie, PMID:25745997]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MORPHOGENESIS_OF_AN_EPITHELIUM
Systematic name | M25345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of morphogenesis of an epithelium. [GO_REF:0000058, GOC:bhm, GOC:TermGenie, PMID:25745997]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MORPHOGENESIS_OF_AN_EPITHELIUM
Systematic name | M25346
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of morphogenesis of an epithelium. [GO_REF:0000058, GOC:bhm, GOC:TermGenie, PMID:25745997]
Full description |

Standard name | GO_REGULATION_OF_GASTRIC_MOTILITY
Systematic name | M25347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gastric motility. [GO_REF:0000058, GOC:als, GOC:TermGenie, PMID:9924029]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_PRESYNAPSE
Systematic name | M25348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a presynapse. [GO_REF:0000087, GOC:TermGenie, PMID:24449494]
Full description |

Standard name | GO_REGULATION_OF_MITOCHONDRIAL_ATP_SYNTHESIS_COUPLED_ELECTRON_TRANSPORT
Systematic name | M25349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mitochondrial ATP synthesis coupled electron transport. [GO_REF:0000058, GOC:bc, GOC:PARL, GOC:TermGenie, PMID:23707074]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MITOCHONDRIAL_ATP_SYNTHESIS_COUPLED_ELECTRON_TRANSPORT
Systematic name | M29378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of mitochondrial ATP synthesis coupled electron transport. [GO_REF:0000058, GOC:bc, GOC:PARL, GOC:TermGenie, PMID:23707074]
Full description |

Standard name | GO_REGULATION_OF_FC_GAMMA_RECEPTOR_SIGNALING_PATHWAY_INVOLVED_IN_PHAGOCYTOSIS
Systematic name | M25350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of Fc-gamma receptor signaling pathway involved in phagocytosis. [GO_REF:0000058, GOC:TermGenie, PMID:18832707]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FC_GAMMA_RECEPTOR_SIGNALING_PATHWAY_INVOLVED_IN_PHAGOCYTOSIS
Systematic name | M25351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of Fc-gamma receptor signaling pathway involved in phagocytosis. [GO_REF:0000058, GOC:TermGenie, PMID:18832707]
Full description |

Standard name | GO_REGULATION_OF_LYMPHOID_PROGENITOR_CELL_DIFFERENTIATION
Systematic name | M25352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lymphoid progenitor cell differentiation. [GO_REF:0000058, GOC:TermGenie, PMID:27010503]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M25353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of vascular associated smooth muscle cell apoptotic process. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:26493107]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULAR_ASSOCIATED_SMOOTH_MUSCLE_CELL_APOPTOTIC_PROCESS
Systematic name | M25354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vascular associated smooth muscle cell apoptotic process. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:26493107]
Full description |

Standard name | GO_REGULATION_OF_DNA_DUPLEX_UNWINDING
Systematic name | M25355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA duplex unwinding. [GO_REF:0000058, GOC:TermGenie, PMID:26503245]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_MEMBRANE
Systematic name | M25356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to membrane. [GO_REF:0000058, GOC:bc, GOC:PARL, GOC:TermGenie, PMID:26911690]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_MEMBRANE
Systematic name | M25357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of protein localization to membrane. [GO_REF:0000058, GOC:bc, GOC:PARL, GOC:TermGenie, PMID:26911690]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_MEMBRANE
Systematic name | M25358
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein localization to membrane. [GO_REF:0000058, GOC:bc, GOC:PARL, GOC:TermGenie, PMID:26911690]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_MICROTUBULE_ORGANIZING_CENTER
Systematic name | M25359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within a microtubule organizing center. [GO_REF:0000087, GOC:TermGenie, PMID:19001497]
Full description |

Standard name | GO_NON_MOTILE_CILIUM_ASSEMBLY
Systematic name | M25360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The aggregation, arrangement and bonding together of a set of components to form a non-motile cilium. [GO_REF:0000079, GOC:cilia, GOC:kmv, GOC:TermGenie, PMID:14521833, PMID:14521834]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FERTILIZATION
Systematic name | M25361
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of fertilization. [GO_REF:0000058, GOC:hbye, GOC:TermGenie, PMID:27564576]
Full description |

Standard name | GO_MACROPHAGE_MIGRATION
Systematic name | M25362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The orderly movement of a macrophage from one site to another. [GO_REF:0000091, GOC:TermGenie, PMID:25749876]
Full description |

Standard name | GO_REGULATION_OF_MACROPHAGE_MIGRATION
Systematic name | M25363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of macrophage migration. [GO_REF:0000058, GOC:TermGenie, PMID:25749876]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MACROPHAGE_MIGRATION
Systematic name | M25364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of macrophage migration. [GO_REF:0000058, GOC:TermGenie, PMID:25749876]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MACROPHAGE_MIGRATION
Systematic name | M25365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of macrophage migration. [GO_REF:0000058, GOC:TermGenie, PMID:25749876]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_VASCULAR_ENDOTHELIAL_CELL_PROLIFERATION
Systematic name | M25366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of vascular endothelial cell proliferation. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:23201774]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULAR_ENDOTHELIAL_CELL_PROLIFERATION
Systematic name | M25367
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vascular endothelial cell proliferation. [GO_REF:0000058, GOC:BHF, GOC:BHF_telomere, GOC:nc, GOC:TermGenie, PMID:23201774]
Full description |

Standard name | GO_REGULATION_OF_RECEPTOR_MEDIATED_ENDOCYTOSIS_INVOLVED_IN_CHOLESTEROL_TRANSPORT
Systematic name | M29379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of receptor-mediated endocytosis involved in cholesterol transport. [GO_REF:0000058, GOC:BHF, GOC:nc, GOC:TermGenie, PMID:22848640]
Full description |

Standard name | GO_REGULATION_OF_BLOOD_BRAIN_BARRIER_PERMEABILITY
Systematic name | M34324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates blood-brain barrier permeability, the quality of the blood-brain barrier that allows for a controlled passage of substances (e.g. macromolecules, small molecules, ions) into and out of the brain. [GO_REF:0000058, GOC:als, GOC:aruk, GOC:bc, GOC:TermGenie, PMID:22524708, PMID:30280653]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BLOOD_BRAIN_BARRIER_PERMEABILITY
Systematic name | M34325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that increases blood-brain barrier permeability, the quality of the blood-brain barrier that allows for a controlled passage of substances (e.g. macromolecules, small molecules, ions) into and out of the brain. [GO_REF:0000058, GOC:als, GOC:aruk, GOC:bc, GOC:TermGenie, PMID:22524708, PMID:30280653]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CHROMATIN
Systematic name | M25369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to chromatin. [GO_REF:0000058, GOC:TermGenie, PMID:20889714]
Full description |

Standard name | GO_REGULATION_OF_ARTERY_MORPHOGENESIS
Systematic name | M25370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of artery morphogenesis. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:27389411]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ARTERY_MORPHOGENESIS
Systematic name | M25371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of artery morphogenesis. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:27389411]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_ENDOSOME
Systematic name | M25372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to endosome. [GO_REF:0000058, GOC:bc, GOC:PARL, GOC:TermGenie, PMID:22732145]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MEMBRANE_PERMEABILITY
Systematic name | M25374
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of the passage or uptake of molecules by a membrane. [PMID:27482894]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MEMBRANE_PERMEABILITY
Systematic name | M25375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the passage or uptake of molecules by a membrane. [PMID:27482894]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_MICROTUBULE_END
Systematic name | M29380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location at a microtubule end. [GO_REF:0000087, GOC:TermGenie, PMID:12034771]
Full description |

Standard name | GO_REGULATION_OF_ENDOSOME_TO_PLASMA_MEMBRANE_PROTEIN_TRANSPORT
Systematic name | M34326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endosome to plasma membrane protein transport. [GO_REF:0000058, GOC:TermGenie, PMID:22869721]
Full description |

Standard name | GO_REGULATION_OF_MESODERMAL_CELL_DIFFERENTIATION
Systematic name | M25376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mesodermal cell differentiation. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:23765923]
Full description |

Standard name | GO_REGULATION_OF_DNA_HELICASE_ACTIVITY
Systematic name | M34327
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ATP-dependent DNA helicase activity. [GOC:rb, GOC:TermGenie, PMID:13679365, PMID:19734539]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SYNAPSE_ORGANIZATION
Systematic name | M25377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of synapse organization. [GO_REF:0000058, GOC:TermGenie, PMID:27779093]
Full description |

Standard name | GO_REGULATION_OF_CHROMOSOME_SEPARATION
Systematic name | M25378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of chromosome separation. [GO_REF:0000058, GOC:bhm, GOC:TermGenie, PMID:21795393]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHROMOSOME_SEPARATION
Systematic name | M25379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of chromosome separation. [GO_REF:0000058, GOC:bhm, GOC:TermGenie, PMID:21795393]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SPINDLE_ASSEMBLY
Systematic name | M25380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of spindle assembly. [GO_REF:0000058, GOC:TermGenie, PMID:27689799]
Full description |

Standard name | GO_EPIDIDYMIS_DEVELOPMENT
Systematic name | M34328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of an epididymis over time, from its formation to the mature structure. [GO_REF:0000094, GOC:TermGenie, PMID:12388089]
Full description |

Standard name | GO_REGULATION_OF_3_UTR_MEDIATED_MRNA_STABILIZATION
Systematic name | M34329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of 3'-UTR-mediated mRNA stabilization. [GO_REF:0000058, GOC:TermGenie, PMID:19737525]
Full description |

Standard name | GO_REGULATION_OF_POSTSYNAPTIC_DENSITY_ORGANIZATION
Systematic name | M25381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of postsynaptic density organization. [GO_REF:0000058, GOC:TermGenie, PMID:21887379]
Full description |

Standard name | GO_REGULATION_OF_OOGENESIS
Systematic name | M25382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of oogenesis. [GO_REF:0000058, GOC:TermGenie, PMID:26434723]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OOGENESIS
Systematic name | M34330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of oogenesis. [GO_REF:0000058, GOC:TermGenie, PMID:26434723]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_ENDOPLASMIC_RETICULUM_STRESS
Systematic name | M25383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of response to endoplasmic reticulum stress. [GO_REF:0000058, GOC:aruk, GOC:bc, GOC:TermGenie, PMID:21803450]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_ENDOPLASMIC_RETICULUM_STRESS
Systematic name | M25384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of response to endoplasmic reticulum stress. [GO_REF:0000058, GOC:aruk, GOC:bc, GOC:TermGenie, PMID:21803450]
Full description |

Standard name | GO_REGULATION_OF_MESODERM_FORMATION
Systematic name | M25385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mesoderm formation. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:23939491]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MESODERM_FORMATION
Systematic name | M25386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of mesoderm formation. [GO_REF:0000058, GOC:BHF, GOC:BHF_miRNA, GOC:rph, GOC:TermGenie, PMID:23939491]
Full description |

Standard name | GO_REGULATION_OF_AMYLOID_FIBRIL_FORMATION
Systematic name | M25387
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of amyloid fibril formation. [GO_REF:0000058, GOC:aruk, GOC:bc, GOC:TermGenie, PMID:23106396]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_AMYLOID_FIBRIL_FORMATION
Systematic name | M29381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of amyloid fibril formation. [GO_REF:0000058, GOC:aruk, GOC:bc, GOC:TermGenie, PMID:23106396]
Full description |

Standard name | GO_REGULATION_OF_GONAD_DEVELOPMENT
Systematic name | M25388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of gonad development. [GO_REF:0000058, GOC:TermGenie, PMID:15342467]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GONAD_DEVELOPMENT
Systematic name | M25389
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of gonad development. [GO_REF:0000058, GOC:TermGenie, PMID:15342467]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GONAD_DEVELOPMENT
Systematic name | M25390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of gonad development. [GO_REF:0000058, GOC:TermGenie, PMID:15342467]
Full description |

Standard name | GO_REGULATION_OF_LIPID_LOCALIZATION
Systematic name | M25391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lipid localization. [GO_REF:0000058, GOC:TermGenie, PMID:17564681]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LIPID_LOCALIZATION
Systematic name | M25392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of lipid localization. [GO_REF:0000058, GOC:TermGenie, PMID:17564681]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LIPID_LOCALIZATION
Systematic name | M25393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of lipid localization. [GO_REF:0000058, GOC:TermGenie, PMID:17564681]
Full description |

Standard name | GO_AMYLOID_FIBRIL_FORMATION
Systematic name | M25394
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The generation of amyloid fibrils, insoluble fibrous protein aggregates exhibiting beta sheet structure, from proteins. [GOC:cvs, GOC:jj, GOC:ppm, GOC:sj, PMID:21148556, PMID:22817896, PMID:28937655, PMID:29654159]
Full description |

Standard name | GO_INHIBITION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_APOPTOTIC_PROCESS
Systematic name | M25395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that prevents the activation of an inactive cysteine-type endopeptidase involved in an apoptotic process. [GOC:mtg_apoptosis, PMID:11943137]
Full description |

Standard name | GO_CALCIUM_ION_EXPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M25396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of calcium ions from inside of a cell, across the plasma membrane and into the extracellular region. [GOC:mah, PMID:2145281]
Full description |

Standard name | GO_CALCIUM_ION_IMPORT_INTO_SARCOPLASMIC_RETICULUM
Systematic name | M29382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of calcium ions into a sarcoplasmic reticulum. [GOC:BHF, PMID:17286271]
Full description |

Standard name | GO_ANTEROGRADE_NEURONAL_DENSE_CORE_VESICLE_TRANSPORT
Systematic name | M34331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of substances in neuronal dense core vesicles along axonal microtubules towards the presynapse. [GOC:kmv, PMID:23358451]
Full description |

Standard name | GO_RETROGRADE_NEURONAL_DENSE_CORE_VESICLE_TRANSPORT
Systematic name | M25397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of neuronal dense core vesicles along axonal microtubules towards the cell body. [GOC:kmv, PMID:23358451, PMID:24762653]
Full description |

Standard name | GO_ACTIVATION_OF_PROTEIN_KINASE_C_ACTIVITY
Systematic name | M34332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that initiates the activity of the inactive enzyme protein kinase C. [PMID:3156004]
Full description |

Standard name | GO_RESPONSE_TO_NERVE_GROWTH_FACTOR
Systematic name | M11962
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nerve growth factor stimulus. [PMID:22399805]
Full description |

Standard name | GO_RETROGRADE_TRANSPORT_ENDOSOME_TO_PLASMA_MEMBRANE
Systematic name | M14187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of membrane-bounded vesicles from endosomes back to the plasma membrane, a trafficking pathway that promotes the recycling of internalized transmembrane proteins. [PMID:23563491]
Full description |

Standard name | GO_NEURON_PROJECTION_EXTENSION
Systematic name | M10515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Long distance growth of a single neuron projection involved in cellular development. A neuron projection is a prolongation or process extending from a nerve cell, e.g. an axon or dendrite. [GOC:BHF, GOC:rl, PMID:22790009]
Full description |

Standard name | GO_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_RESPONSE_TO_HYPOXIA
Systematic name | M25398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway is induced in response to hypoxia (lowered oxygen tension). Hypoxia, defined as a decline in O2 levels below normoxic levels of 20.8 - 20.95%, results in metabolic adaptation at both the cellular and organismal level. The pathway ends when the execution phase of apoptosis is triggered. [GOC:BHF, GOC:mtg_apoptosis, GOC:rl, PMID:20436456]
Full description |

Standard name | GO_HISTONE_H2A_PHOSPHORYLATION
Systematic name | M34333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The modification of histone H2A by the addition of a phosphate group. [GOC:mah, PMID:23080121]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_NUCLEOPLASM
Systematic name | M25399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, a location within the nucleoplasm. [GOC:mah, PMID:22918952]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_LEUCINE_STARVATION
Systematic name | M25400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of deprivation of leucine. [PMID:19033384]
Full description |

Standard name | GO_PEPTIDYL_TYROSINE_DEPHOSPHORYLATION_INVOLVED_IN_INACTIVATION_OF_PROTEIN_KINASE_ACTIVITY
Systematic name | M25401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any peptidyl-tyrosine dephosphorylation that is involved in inactivation of protein kinase activity. [PMID:7501024]
Full description |

Standard name | GO_NEUTROPHIL_MIGRATION
Systematic name | M25402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The movement of a neutrophil within or between different tissues and organs of the body. [PMID:1826836]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_INSULIN_LIKE_GROWTH_FACTOR_STIMULUS
Systematic name | M25403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an insulin-like growth factor stimulus. [PMID:20042609]
Full description |

Standard name | GO_LIPID_TRANSPORT_ACROSS_BLOOD_BRAIN_BARRIER
Systematic name | M34334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of lipid molecules passing through the blood-brain barrier. [GOC:sjp, PMID:24345162]
Full description |

Standard name | GO_HYALOID_VASCULAR_PLEXUS_REGRESSION
Systematic name | M34335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The developmental process in which the hyaloid vascular plexus is destroyed as a part of its normal progression. [GOC:hjd, PMID:18841878]
Full description |

Standard name | GO_EMBRYONIC_BRAIN_DEVELOPMENT
Systematic name | M25404
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process occurring during the embryonic phase whose specific outcome is the progression of the brain over time, from its formation to the mature structure. [PMID:15918910]
Full description |

Standard name | GO_REPLICATION_BORN_DOUBLE_STRAND_BREAK_REPAIR_VIA_SISTER_CHROMATID_EXCHANGE
Systematic name | M29383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The repair of a replication-born double-strand DNA break in which the DNA molecule is repaired using the homologous sequence of the sister chromatid which serves as a template to repair the breaks. [GOC:rb, PMID:12820977, PMID:16888651]
Full description |

Standard name | GO_CELLULAR_RESPONSE_TO_BRAIN_DERIVED_NEUROTROPHIC_FACTOR_STIMULUS
Systematic name | M25405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a brain-derived neurotrophic factor stimulus. [PMID:21958434]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_FROM_RNA_POLYMERASE_II_PROMOTER_IN_RESPONSE_TO_ENDOPLASMIC_RETICULUM_STRESS
Systematic name | M16786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of transcription from an RNA polymerase II promoter as a result of an endoplasmic reticulum stress. [GOC:bf, GOC:PARL, PMID:21113145]
Full description |

Standard name | GO_MRNA_PSEUDOURIDINE_SYNTHESIS
Systematic name | M25406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The intramolecular conversion of uridine to pseudouridine in an mRNA molecule. [PMID:25192136]
Full description |

Standard name | GO_DENSE_CORE_GRANULE_EXOCYTOSIS
Systematic name | M25407
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The secretion of molecules (e.g. neuropeptides, insulin-related peptides or neuromodulators such as serotonin and dopamine) contained within a membrane-bounced dense core granule by fusion of the granule with the plasma membrane of a cell in response to increased cytosolic calcium levels. [GOC:kmv, PMID:17553987, PMID:24653208]
Full description |

Standard name | GO_PIRNA_BIOSYNTHETIC_PROCESS
Systematic name | M25408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways resulting in the formation of piRNAs, Piwi-associated RNAs, a class of 24- to 30-nucleotide RNA derived from repeat or complex DNA sequence elements and processed by a Dicer-independent mechanism. [GOC:kmv, PMID:24696457]
Full description |

Standard name | GO_NEURON_PROJECTION_MAINTENANCE
Systematic name | M25409
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The organization process that preserves a neuron projection in a stable functional or structural state. A neuron projection is a prolongation or process extending from a nerve cell, e.g. an axon or dendrite. [GOC:kmv, PMID:25359212]
Full description |

Standard name | GO_MITOCHONDRIAL_TRANSMEMBRANE_TRANSPORT
Systematic name | M11920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which a solute is transported from one side of a membrane to the other into, out of or within a mitochondrion. [PMID:20533899]
Full description |

Standard name | GO_PROTEIN_POLYUFMYLATION
Systematic name | M25410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Covalent attachment of the ubiquitin-like protein UFM1 to a protein, forming an UFM1 chain. [PMID:25219498]
Full description |

Standard name | GO_UDP_N_ACETYLGLUCOSAMINE_TRANSMEMBRANE_TRANSPORT
Systematic name | M34336
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process in which UDP-N-acetylglucosamine is transported across a membrane. [PMID:10788474]
Full description |

Standard name | GO_POTASSIUM_ION_IMPORT_ACROSS_PLASMA_MEMBRANE
Systematic name | M25411
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of potassium ions from outside of a cell, across the plasma membrane and into the cytosol. [PMID:9139127]
Full description |

Standard name | GO_VESICLE_FUSION_WITH_ENDOPLASMIC_RETICULUM_GOLGI_INTERMEDIATE_COMPARTMENT_ERGIC_MEMBRANE
Systematic name | M25412
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The joining of the lipid bilayer membrane around a vesicle to the lipid bilayer membrane of the ERGIC. This can involve anterograde or retrograde transport vesicles. [GOC:bhm, PMID:16038056, PMID:24119662]
Full description |

Standard name | GO_PRESYNAPTIC_ACTIVE_ZONE_ORGANIZATION
Systematic name | M25413
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that results in the assembly, arrangement of constituent parts, or disassembly of a presynaptic active zone. [GOC:pr, PMID:16865347, PMID:17068967]
Full description |

Standard name | GO_TUMOR_NECROSIS_FACTOR_SECRETION
Systematic name | M25415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated release of tumor necrosis factor from a cell. Tumor necrosis factor is an inflammatory cytokine produced by macrophages/monocytes during acute inflammation and which is responsible for a diverse range of signaling events within cells, leading to necrosis or apoptosis. [PMID:15560120]
Full description |

Standard name | GO_RESPONSE_TO_ANGIOTENSIN
Systematic name | M11016
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an angiotensin stimulus. Angiotensin is any of three physiologically active peptides (angiotensin II, III, or IV) processed from angiotensinogen. [PMID:22982863]
Full description |

Standard name | GO_PROTEIN_LOCALIZATION_TO_CELL_PERIPHERY
Systematic name | M11684
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process in which a protein is transported to, or maintained in, the cell periphery. [PMID:18216290]
Full description |

Standard name | GO_DORSAL_ROOT_GANGLION_DEVELOPMENT
Systematic name | M25416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The process whose specific outcome is the progression of a dorsal root ganglion over time, from its formation to the mature structure. [PMID:18583150]
Full description |

Standard name | GO_BASIC_AMINO_ACID_TRANSMEMBRANE_TRANSPORT
Systematic name | M25417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of basic amino acids from one side of a membrane to the other. [GOC:dph, GOC:vw]
Full description |

Standard name | GO_RESPONSE_TO_LEUKEMIA_INHIBITORY_FACTOR
Systematic name | M25418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a leukemia inhibitory factor stimulus. [PMID:12801913]
Full description |

Standard name | GO_ADAPTIVE_THERMOGENESIS
Systematic name | M25419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The regulated production of heat in response to short term environmental changes, such as stress, diet or reduced temperature. [PMID:17260010, PMID:20363363]
Full description |

Standard name | GO_RESPONSE_TO_CHEMOKINE
Systematic name | M25420
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a chemokine stimulus. [PMID:11113082]
Full description |

Standard name | GO_DOUBLE_STRAND_BREAK_REPAIR_INVOLVED_IN_MEIOTIC_RECOMBINATION
Systematic name | M34337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The repair of double-strand breaks in DNA via homologous and nonhomologous mechanisms to reform a continuous DNA helix that contributes to reciprocal meiotic recombination. [GOC:mah, PMID:15238514]
Full description |

Standard name | GO_RESPONSE_TO_AMINO_ACID_STARVATION
Systematic name | M25422
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of deprivation of amino acids. [PMID:7765311]
Full description |

Standard name | GO_XENOBIOTIC_DETOXIFICATION_BY_TRANSMEMBRANE_EXPORT_ACROSS_THE_PLASMA_MEMBRANE
Systematic name | M29384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | A process that reduces or removes the toxicity of a xenobiotic by exporting it outside the cell. [PMID:28355133]
Full description |

Standard name | GO_XENOBIOTIC_TRANSPORT_ACROSS_BLOOD_BRAIN_BARRIER
Systematic name | M34338
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The directed movement of a xenobiotic through the blood-brain barrier. [PMID:25053619]
Full description |

Standard name | GO_REGULATION_OF_DNA_DAMAGE_CHECKPOINT
Systematic name | M14416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of a DNA damage checkpoint. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_DAMAGE_CHECKPOINT
Systematic name | M25423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of a DNA damage checkpoint. [GOC:BHF, GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CELL_SURFACE
Systematic name | M12673
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of protein localization to the cell surface. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CELL_SURFACE
Systematic name | M25424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of protein localization to the cell surface. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PROTEIN_LOCALIZATION_TO_CELL_SURFACE
Systematic name | M11173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of protein localization to the cell surface. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_MALE_GONAD_DEVELOPMENT
Systematic name | M25425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of male gonad development. [GOC:obol, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_ANIMAL_ORGAN_MORPHOGENESIS
Systematic name | M25426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of animal organ morphogenesis. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_STEM_CELL_DIVISION
Systematic name | M25427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of stem cell division. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_STEM_CELL_POPULATION_MAINTENANCE
Systematic name | M13952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of stem cell population maintenance. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DOUBLE_STRAND_BREAK_REPAIR_VIA_HOMOLOGOUS_RECOMBINATION
Systematic name | M25428
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of double-strand break repair via homologous recombination. [GOC:vw]
Full description |

Standard name | GO_REGULATION_OF_CELL_CELL_ADHESION_MEDIATED_BY_CADHERIN
Systematic name | M10737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cell-cell adhesion mediated by cadherin. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELL_CELL_ADHESION_MEDIATED_BY_CADHERIN
Systematic name | M25429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cell-cell adhesion mediated by cadherin. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_CELL_ADHESION_MEDIATED_BY_CADHERIN
Systematic name | M25430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell-cell adhesion mediated by cadherin. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_NON_CANONICAL_WNT_SIGNALING_PATHWAY
Systematic name | M10985
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of non-canonical Wnt signaling pathway. [GOC:obol, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NON_CANONICAL_WNT_SIGNALING_PATHWAY
Systematic name | M25431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of non-canonical Wnt signaling pathway. [GOC:obol, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NON_CANONICAL_WNT_SIGNALING_PATHWAY
Systematic name | M13392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of non-canonical Wnt-activated signaling pathway. [GOC:obol, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25432
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ubiquitin-dependent protein catabolic process. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of ubiquitin-dependent protein catabolic process. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_UBIQUITIN_DEPENDENT_PROTEIN_CATABOLIC_PROCESS
Systematic name | M25434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of ubiquitin-dependent protein catabolic process. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_TYPE_B_PANCREATIC_CELL_DEVELOPMENT
Systematic name | M25435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of pancreatic B cell development. [GOC:obol, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_WNT_SIGNALING_PATHWAY_PLANAR_CELL_POLARITY_PATHWAY
Systematic name | M16663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of Wnt signaling pathway, planar cell polarity pathway. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_WNT_SIGNALING_PATHWAY_PLANAR_CELL_POLARITY_PATHWAY
Systematic name | M25436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of Wnt signaling pathway, planar cell polarity pathway. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_DEPENDENT_DNA_REPLICATION
Systematic name | M11691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of DNA-dependent DNA replication. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_DEPENDENT_DNA_REPLICATION
Systematic name | M12156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of DNA-dependent DNA replication. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_LEUKOCYTE_APOPTOTIC_PROCESS
Systematic name | M10649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of leukocyte apoptotic process. [GOC:BHF, GOC:mtg_apoptosis]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LEUKOCYTE_APOPTOTIC_PROCESS
Systematic name | M11979
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of leukocyte apoptotic process. [GOC:BHF, GOC:mtg_apoptosis]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LEUKOCYTE_APOPTOTIC_PROCESS
Systematic name | M10581
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of leukocyte apoptotic process. [GOC:BHF, GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_MACROPHAGE_APOPTOTIC_PROCESS
Systematic name | M25437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of macrophage apoptotic process. [GOC:BHF, GOC:mtg_apoptosis]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MACROPHAGE_APOPTOTIC_PROCESS
Systematic name | M25438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of macrophage apoptotic process. [GOC:BHF, GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY
Systematic name | M14849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cysteine-type endopeptidase activity. [GOC:obol, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY
Systematic name | M14008
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of cysteine-type endopeptidase activity. [GOC:obol, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_SODIUM_DEPENDENT_PHOSPHATE_TRANSPORT
Systematic name | M25439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of sodium-dependent phosphate transport. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_REMOVAL_OF_SUPEROXIDE_RADICALS
Systematic name | M12130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of removal of superoxide radicals. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CELL_PROLIFERATION_INVOLVED_IN_HEART_MORPHOGENESIS
Systematic name | M25440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cell proliferation involved in heart morphogenesis. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_DNA_TEMPLATED_TRANSCRIPTION_INITIATION
Systematic name | M13231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA-templated transcription initiation. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_TEMPLATED_TRANSCRIPTION_INITIATION
Systematic name | M25441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of DNA-templated transcription initiation. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_TEMPLATED_TRANSCRIPTION_INITIATION
Systematic name | M10901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of DNA-templated transcription initiation. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_REGULATION_OF_UBIQUITIN_SPECIFIC_PROTEASE_ACTIVITY
Systematic name | M29385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of regulation of ubiquitin-specific protease activity (deubiquitinase) activity. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDYL_CYSTEINE_S_NITROSYLATION
Systematic name | M25443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of peptidyl-cysteine S-nitrosylation. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DENDRITE_DEVELOPMENT
Systematic name | M13001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of dendrite development. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_BRANCHING_MORPHOGENESIS_OF_A_NERVE
Systematic name | M25444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of branching morphogenesis of a nerve. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_NEURAL_PRECURSOR_CELL_PROLIFERATION
Systematic name | M16126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neural precursor cell proliferation. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEURAL_PRECURSOR_CELL_PROLIFERATION
Systematic name | M15242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of neural precursor cell proliferation. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEURAL_PRECURSOR_CELL_PROLIFERATION
Systematic name | M13374
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of neural precursor cell proliferation. [GOC:dph, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_FATTY_ACID_TRANSPORT
Systematic name | M13290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of fatty acid transport. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FATTY_ACID_TRANSPORT
Systematic name | M25445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of fatty acid transport. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FATTY_ACID_TRANSPORT
Systematic name | M25446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of fatty acid transport. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_FEMALE_GONAD_DEVELOPMENT
Systematic name | M12759
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of female gonad development. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FEMALE_GONAD_DEVELOPMENT
Systematic name | M25447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of female gonad development. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_RIBONUCLEOPROTEIN_COMPLEX_LOCALIZATION
Systematic name | M25448
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ribonucleoprotein complex localization. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ANOIKIS
Systematic name | M14433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of anoikis. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ANOIKIS
Systematic name | M25449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of anoikis. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_REPRODUCTIVE_PROCESS
Systematic name | M13623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of reproductive process. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_REPRODUCTIVE_PROCESS
Systematic name | M10204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents, or reduces the frequency, rate or extent of reproductive process. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_REPRODUCTIVE_PROCESS
Systematic name | M10230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of reproductive process. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_ACTIN_CYTOSKELETON_REORGANIZATION
Systematic name | M15418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of actin cytoskeleton reorganization. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACTIN_CYTOSKELETON_REORGANIZATION
Systematic name | M11200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of actin cytoskeleton reorganization. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FEEDING_BEHAVIOR
Systematic name | M25450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of feeding behavior. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FEEDING_BEHAVIOR
Systematic name | M25451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of feeding behavior. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_FIBROBLAST_APOPTOTIC_PROCESS
Systematic name | M25452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of fibroblast apoptotic process. [GOC:mtg_apoptosis, GOC:obol, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_FIBROBLAST_APOPTOTIC_PROCESS
Systematic name | M25453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of fibroblast apoptotic process. [GOC:mtg_apoptosis, GOC:obol, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SIGNALING_RECEPTOR_ACTIVITY
Systematic name | M25454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of a signaling receptor activity. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SIGNALING_RECEPTOR_ACTIVITY
Systematic name | M25455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of signaling receptor activity. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_DNA_BIOSYNTHETIC_PROCESS
Systematic name | M14805
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA biosynthetic process. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DNA_BIOSYNTHETIC_PROCESS
Systematic name | M12557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of DNA biosynthetic process. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MYOBLAST_PROLIFERATION
Systematic name | M25456
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of myoblast proliferation. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_VESICLE_EXOCYTOSIS
Systematic name | M29386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of synaptic vesicle exocytosis. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SYNAPTIC_VESICLE_EXOCYTOSIS
Systematic name | M25457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of synaptic vesicle exocytosis. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPTIC_VESICLE_EXOCYTOSIS
Systematic name | M29387
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of synaptic vesicle exocytosis. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_NMDA_RECEPTOR_ACTIVITY
Systematic name | M25458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of N-methyl-D-aspartate selective glutamate receptor activity. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_AMPA_RECEPTOR_ACTIVITY
Systematic name | M25459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of AMPA selective glutamate receptor activity. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_T_HELPER_17_TYPE_IMMUNE_RESPONSE
Systematic name | M25460
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T-helper 17 type immune response. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_HELPER_17_TYPE_IMMUNE_RESPONSE
Systematic name | M29388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of T-helper 17 type immune response. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_HELPER_17_TYPE_IMMUNE_RESPONSE
Systematic name | M25461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of T-helper 17 type immune response. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_HELPER_17_CELL_DIFFERENTIATION
Systematic name | M25463
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of T-helper 17 cell differentiation. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_GLUCOCORTICOID_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M25464
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glucocorticoid receptor signaling pathway. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GLUCOCORTICOID_RECEPTOR_SIGNALING_PATHWAY
Systematic name | M29389
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of glucocorticoid receptor signaling pathway. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_T_HELPER_17_CELL_LINEAGE_COMMITMENT
Systematic name | M25465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T-helper 17 cell lineage commitment. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHEMOKINE_C_X_C_MOTIF_LIGAND_2_PRODUCTION
Systematic name | M25467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of chemokine (C-X-C motif) ligand 2 production. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ACROSOME_REACTION
Systematic name | M29390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of the acrosome reaction. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_HEPATOCYTE_PROLIFERATION
Systematic name | M10116
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hepatocyte proliferation. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HEPATOCYTE_PROLIFERATION
Systematic name | M25468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of hepatocyte proliferation. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_CD40_SIGNALING_PATHWAY
Systematic name | M25469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of signaling via the CD40 signaling pathway. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ENDOTHELIAL_CELL_APOPTOTIC_PROCESS
Systematic name | M15824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of endothelial cell apoptotic process. [GOC:BHF, GOC:mah, GOC:mtg_apoptosis]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOTHELIAL_CELL_APOPTOTIC_PROCESS
Systematic name | M15578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of endothelial cell apoptotic process. [GOC:BHF, GOC:mah, GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_OVARIAN_FOLLICLE_DEVELOPMENT
Systematic name | M25470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ovarian follicle development. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_BINDING_OF_SPERM_TO_ZONA_PELLUCIDA
Systematic name | M25471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of binding of sperm to the zona pellucida. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_CLATHRIN_DEPENDENT_ENDOCYTOSIS
Systematic name | M25472
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of clathrin-mediated endocytosis. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CLATHRIN_DEPENDENT_ENDOCYTOSIS
Systematic name | M34339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of clathrin-mediated endocytosis. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_DNA_TOPOISOMERASE_ATP_HYDROLYZING_ACTIVITY
Systematic name | M25473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of DNA topoisomerase (ATP-hydrolyzing) activity. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_REACTIVE_OXYGEN_SPECIES_METABOLIC_PROCESS
Systematic name | M13446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of reactive oxygen species metabolic process. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_REACTIVE_OXYGEN_SPECIES_METABOLIC_PROCESS
Systematic name | M10894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of reactive oxygen species metabolic process. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_REACTIVE_OXYGEN_SPECIES_METABOLIC_PROCESS
Systematic name | M13580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of reactive oxygen species metabolic process. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_MESODERM_DEVELOPMENT
Systematic name | M12588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mesoderm development. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MESODERM_DEVELOPMENT
Systematic name | M25474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of mesoderm development. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MESODERM_DEVELOPMENT
Systematic name | M25475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of mesoderm development. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_NEUTROPHIL_EXTRAVASATION
Systematic name | M29391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neutrophil extravasation. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_LAMELLIPODIUM_MORPHOGENESIS
Systematic name | M25476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lamellipodium morphogenesis. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LAMELLIPODIUM_MORPHOGENESIS
Systematic name | M25477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of lamellipodium morphogenesis. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_LYMPHOCYTE_MIGRATION
Systematic name | M16579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of lymphocyte migration. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_LYMPHOCYTE_MIGRATION
Systematic name | M25478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of lymphocyte migration. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_LYMPHOCYTE_MIGRATION
Systematic name | M10993
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of lymphocyte migration. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_MIGRATION
Systematic name | M16940
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T cell migration. [GOC:mah]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_T_CELL_MIGRATION
Systematic name | M25479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of T cell migration. [GOC:mah]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_CELL_MIGRATION
Systematic name | M25480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of T cell migration. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_EXTRAVASATION
Systematic name | M29392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T cell extravasation. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_EOSINOPHIL_MIGRATION
Systematic name | M25481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of eosinophil migration. [GOC:mah]
Full description |

Standard name | GO_REGULATION_OF_APOPTOTIC_CELL_CLEARANCE
Systematic name | M25482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of apoptotic cell clearance. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_APOPTOTIC_CELL_CLEARANCE
Systematic name | M25483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of apoptotic cell clearance. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EXCITATORY_POSTSYNAPTIC_POTENTIAL
Systematic name | M13561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that enhances the establishment or increases the extent of the excitatory postsynaptic potential (EPSP) which is a temporary increase in postsynaptic potential due to the flow of positively charged ions into the postsynaptic cell. The flow of ions that causes an EPSP is an excitatory postsynaptic current (EPSC) and makes it easier for the neuron to fire an action potential. [GOC:bf, GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_GLYCOGEN_STARCH_SYNTHASE_ACTIVITY
Systematic name | M25484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of glycogen (starch) synthase activity. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLYCOGEN_STARCH_SYNTHASE_ACTIVITY
Systematic name | M25485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of glycogen (starch) synthase activity. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_CAMP_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M16326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cAMP-dependent protein kinase activity. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CAMP_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M25486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cAMP-dependent protein kinase activity. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CAMP_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M25487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cAMP-dependent protein kinase activity. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_HEPATIC_STELLATE_CELL_ACTIVATION
Systematic name | M29393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of hepatic stellate cell activation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_NATURAL_KILLER_CELL_CHEMOTAXIS
Systematic name | M25489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of natural killer cell chemotaxis. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NATURAL_KILLER_CELL_CHEMOTAXIS
Systematic name | M25490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of natural killer cell chemotaxis. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_BLOOD_VESSEL_REMODELING
Systematic name | M25491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of blood vessel remodeling. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_DENDRITIC_CELL_CHEMOTAXIS
Systematic name | M25492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of dendritic cell chemotaxis. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_CD4_POSITIVE_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M13744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of CD4-positive, alpha-beta T cell activation. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CD4_POSITIVE_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M15747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of CD4-positive, alpha-beta T cell activation. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CD4_POSITIVE_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M13316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of CD4-positive, alpha-beta T cell activation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_ENTRY_OF_BACTERIUM_INTO_HOST_CELL
Systematic name | M25493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of entry of bacterium into host cell. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_GASTRULATION
Systematic name | M25494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of gastrulation. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GASTRULATION
Systematic name | M25495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of gastrulation. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ENDOTHELIAL_CELL_CHEMOTAXIS_TO_FIBROBLAST_GROWTH_FACTOR
Systematic name | M34340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of endothelial cell chemotaxis to fibroblast growth factor. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_T_HELPER_2_CELL_CYTOKINE_PRODUCTION
Systematic name | M25496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T-helper 2 cell cytokine production. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_T_HELPER_2_CELL_CYTOKINE_PRODUCTION
Systematic name | M25497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of T-helper 2 cell cytokine production. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_T_HELPER_1_CELL_CYTOKINE_PRODUCTION
Systematic name | M25498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T-helper 1 cell cytokine production. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CD4_POSITIVE_ALPHA_BETA_T_CELL_PROLIFERATION
Systematic name | M25499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of CD4-positive, alpha-beta T cell proliferation. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CD4_POSITIVE_ALPHA_BETA_T_CELL_PROLIFERATION
Systematic name | M29394
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of CD4-positive, alpha-beta T cell proliferation. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DNA_BIOSYNTHETIC_PROCESS
Systematic name | M10447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of DNA biosynthetic process. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_MICROTUBULE_MOTOR_ACTIVITY
Systematic name | M25500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of microtubule motor activity. [GOC:kmv]
Full description |

Standard name | GO_REGULATION_OF_PLATELET_DERIVED_GROWTH_FACTOR_RECEPTOR_ALPHA_SIGNALING_PATHWAY
Systematic name | M25501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of platelet-derived growth factor receptor-alpha signaling pathway. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_PLATELET_DERIVED_GROWTH_FACTOR_RECEPTOR_BETA_SIGNALING_PATHWAY
Systematic name | M25502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of platelet-derived growth factor receptor-beta signaling pathway. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ARP2_3_COMPLEX_MEDIATED_ACTIN_NUCLEATION
Systematic name | M25503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of Arp2/3 complex-mediated actin nucleation. [PMID:21454476]
Full description |

Standard name | GO_REGULATION_OF_THYROID_HORMONE_GENERATION
Systematic name | M25504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of thyroid hormone generation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_H3_K9_ACETYLATION
Systematic name | M16828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of histone H3-K9 acetylation. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_HISTONE_H3_K9_ACETYLATION
Systematic name | M25505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of histone H3-K9 acetylation. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_H4_K16_ACETYLATION
Systematic name | M25506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of histone H4-K16 acetylation. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_MIRNA_METABOLIC_PROCESS
Systematic name | M25507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of miRNA metabolic process. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_MIRNA_METABOLIC_PROCESS
Systematic name | M29396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of miRNA metabolic process. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_SREBP_SIGNALING_PATHWAY
Systematic name | M34341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of the SREBP signaling pathway. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_EARLY_ENDOSOME_TO_LATE_ENDOSOME_TRANSPORT
Systematic name | M13065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of early endosome to late endosome transport. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EARLY_ENDOSOME_TO_LATE_ENDOSOME_TRANSPORT
Systematic name | M25508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of early endosome to late endosome transport. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_RECEPTOR_CATABOLIC_PROCESS
Systematic name | M25509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of receptor catabolic process. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RECEPTOR_CATABOLIC_PROCESS
Systematic name | M25510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of receptor catabolic process. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_STEM_CELL_PROLIFERATION
Systematic name | M12131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of stem cell proliferation. [GOC:dph]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STEM_CELL_PROLIFERATION
Systematic name | M15864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of stem cell proliferation. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_SODIUM_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M14999
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of sodium ion transmembrane transporter activity. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SODIUM_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M16914
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of sodium ion transmembrane transporter activity. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_GENETIC_IMPRINTING
Systematic name | M34342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of genetic imprinting. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_INTERLEUKIN_1_MEDIATED_SIGNALING_PATHWAY
Systematic name | M25511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of interleukin-1-mediated signaling pathway. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTERLEUKIN_1_MEDIATED_SIGNALING_PATHWAY
Systematic name | M25512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of interleukin-1-mediated signaling pathway. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DENDRITIC_CELL_APOPTOTIC_PROCESS
Systematic name | M25515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of dendritic cell apoptotic process. [GOC:mtg_apoptosis, GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_MOTOR_NEURON_APOPTOTIC_PROCESS
Systematic name | M25516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of motor neuron apoptotic process. [GOC:mtg_apoptosis, GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TYPE_B_PANCREATIC_CELL_APOPTOTIC_PROCESS
Systematic name | M25517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of type B pancreatic cell apoptotic process. [GOC:mtg_apoptosis, GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_TRANSCRIPTION_REGULATORY_REGION_DNA_BINDING
Systematic name | M16209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of transcription regulatory region DNA binding. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_TRANSCRIPTION_REGULATORY_REGION_DNA_BINDING
Systematic name | M10225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of transcription regulatory region DNA binding. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_TRANSCRIPTION_REGULATORY_REGION_DNA_BINDING
Systematic name | M14659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of transcription regulatory region DNA binding. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_EPITHELIAL_CELL_DIFFERENTIATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M11540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of epithelial cell differentiation involved in kidney development. [GOC:mtg_kidney_jan10, GOC:yaf]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EPITHELIAL_CELL_DIFFERENTIATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M25518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of epithelial cell differentiation involved in kidney development. [GOC:mtg_kidney_jan10, GOC:yaf]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EPITHELIAL_CELL_DIFFERENTIATION_INVOLVED_IN_KIDNEY_DEVELOPMENT
Systematic name | M25519
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of epithelial cell differentiation involved in kidney development. [GOC:mtg_kidney_jan10, GOC:yaf]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_VASCULAR_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M25520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardiac vascular smooth muscle cell differentiation. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CARDIAC_VASCULAR_SMOOTH_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M25521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cardiac vascular smooth muscle cell differentiation. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_CARDIAC_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M11452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cardiac muscle cell differentiation. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CARDIAC_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M16753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cardiac muscle cell differentiation. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_STEM_CELL_DIFFERENTIATION
Systematic name | M16970
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of stem cell differentiation. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_STEM_CELL_DIFFERENTIATION
Systematic name | M10848
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of stem cell differentiation. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STEM_CELL_DIFFERENTIATION
Systematic name | M13189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of stem cell differentiation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_MESENCHYMAL_STEM_CELL_DIFFERENTIATION
Systematic name | M25523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of mesenchymal stem cell differentiation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_PEPTIDYL_LYSINE_ACETYLATION
Systematic name | M25524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of peptidyl-lysine acetylation. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_PEPTIDYL_LYSINE_ACETYLATION
Systematic name | M25525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of peptidyl-lysine acetylation. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PEPTIDYL_LYSINE_ACETYLATION
Systematic name | M25526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of peptidyl-lysine acetylation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_CYTOPLASMIC_TRANSLATION
Systematic name | M15572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cytoplasmic translation. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYTOPLASMIC_TRANSLATION
Systematic name | M25527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cytoplasmic translation. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYTOPLASMIC_TRANSLATION
Systematic name | M25528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cytoplasmic translation. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CELLULAR_SENESCENCE
Systematic name | M14545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cellular senescence. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_DOUBLE_STRAND_BREAK_REPAIR
Systematic name | M10088
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of double-strand break repair. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DOUBLE_STRAND_BREAK_REPAIR
Systematic name | M25529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of double-strand break repair. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_AUTOPHAGOSOME_ASSEMBLY
Systematic name | M15991
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of autophagosome assembly. [GOC:autophagy, GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AUTOPHAGOSOME_ASSEMBLY
Systematic name | M25530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of autophagic vacuole assembly. [GOC:autophagy, GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_EPITHELIAL_CELL_PROLIFERATION_INVOLVED_IN_LUNG_MORPHOGENESIS
Systematic name | M25531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of epithelial cell proliferation involved in lung morphogenesis. [PMID:21513708]
Full description |

Standard name | GO_REGULATION_OF_SYNAPTIC_VESICLE_CLUSTERING
Systematic name | M25532
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of synaptic vesicle clustering. [PMID:21513708]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SYNAPTIC_VESICLE_CLUSTERING
Systematic name | M25533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of synaptic vesicle clustering. [PMID:21513708]
Full description |

Standard name | GO_REGULATION_OF_BICELLULAR_TIGHT_JUNCTION_ASSEMBLY
Systematic name | M16769
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of tight junction assembly. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ANOIKIS
Systematic name | M13662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of anoikis. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_BARBED_END_ACTIN_FILAMENT_CAPPING
Systematic name | M29398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of barbed-end actin filament capping. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MYOBLAST_PROLIFERATION
Systematic name | M25534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of myoblast proliferation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_GROOMING_BEHAVIOR
Systematic name | M29399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of grooming behavior. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_HEART_MORPHOGENESIS
Systematic name | M12668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of heart morphogenesis. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_STEROID_HORMONE_SECRETION
Systematic name | M25535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of steroid hormone secretion. [GOC:sl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CORTICOSTEROID_HORMONE_SECRETION
Systematic name | M25536
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of corticosteroid hormone secretion. [GOC:sl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_GLUCOCORTICOID_SECRETION
Systematic name | M25537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of glucocorticoid secretion. [GOC:sl]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_AMPA_RECEPTOR_ACTIVITY
Systematic name | M25538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of AMPA selective glutamate receptor activity. [PMID:21423165]
Full description |

Standard name | GO_REGULATION_OF_FOREBRAIN_NEURON_DIFFERENTIATION
Systematic name | M29400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of forebrain neuron differentiation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_SKELETAL_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M10643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of skeletal muscle cell differentiation. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_SKELETAL_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M25539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of skeletal muscle cell differentiation. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_SKELETAL_MUSCLE_CELL_DIFFERENTIATION
Systematic name | M25540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of skeletal muscle cell differentiation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_DNA_DAMAGE_STIMULUS
Systematic name | M16503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of response to DNA damage stimulus. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_RESPONSE_TO_DNA_DAMAGE_STIMULUS
Systematic name | M10954
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of response to DNA damage stimulus. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_RESPONSE_TO_DNA_DAMAGE_STIMULUS
Systematic name | M15873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of response to DNA damage stimulus. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_RESPONSE_TO_DRUG
Systematic name | M25541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of response to drug. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_ENDOTHELIAL_CELL_CHEMOTAXIS
Systematic name | M15557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endothelial cell chemotaxis. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_ENDOTHELIAL_CELL_CHEMOTAXIS
Systematic name | M25544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of endothelial cell chemotaxis. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOTHELIAL_CELL_CHEMOTAXIS
Systematic name | M10481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of endothelial cell chemotaxis. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_DOUBLE_STRAND_BREAK_REPAIR_VIA_NONHOMOLOGOUS_END_JOINING
Systematic name | M25545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of double-strand break repair via nonhomologous end joining. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DOUBLE_STRAND_BREAK_REPAIR_VIA_NONHOMOLOGOUS_END_JOINING
Systematic name | M25546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of double-strand break repair via nonhomologous end joining. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_DOUBLE_STRAND_BREAK_REPAIR_VIA_NONHOMOLOGOUS_END_JOINING
Systematic name | M25547
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of double-strand break repair via nonhomologous end joining. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_INTEGRIN_MEDIATED_SIGNALING_PATHWAY
Systematic name | M25551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of integrin-mediated signaling pathway. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTEGRIN_MEDIATED_SIGNALING_PATHWAY
Systematic name | M25552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of integrin-mediated signaling pathway. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_MESENCHYMAL_CELL_APOPTOTIC_PROCESS
Systematic name | M25553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of mesenchymal cell apoptotic process. [GOC:mtg_apoptosis, GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY
Systematic name | M25554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cysteine-type endopeptidase activity. [GOC:obol]
Full description |

Standard name | GO_REACTIVE_NITROGEN_SPECIES_METABOLIC_PROCESS
Systematic name | M12765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a reactive nitrogen species. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_ENDOCYTIC_RECYCLING
Systematic name | M25555
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of endocytic recycling. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ENDOCYTIC_RECYCLING
Systematic name | M25556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of endocytic recycling. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_PHOSPHOLIPID_TRANSPORT
Systematic name | M25557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of phospholipid transport. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_HISTONE_H2B_UBIQUITINATION
Systematic name | M25558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of histone H2B ubiquitination. [PMID:12876293]
Full description |

Standard name | GO_REGULATION_OF_ATP_BIOSYNTHETIC_PROCESS
Systematic name | M25559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of ATP biosynthetic process. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_ATP_BIOSYNTHETIC_PROCESS
Systematic name | M25560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of ATP biosynthetic process. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_CD8_POSITIVE_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M25563
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of CD8-positive, alpha-beta T cell activation. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CD8_POSITIVE_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M25564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of CD8-positive, alpha-beta T cell activation. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CD8_POSITIVE_ALPHA_BETA_T_CELL_ACTIVATION
Systematic name | M25565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of CD8-positive, alpha-beta T cell activation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_T_CELL_ACTIVATION_VIA_T_CELL_RECEPTOR_CONTACT_WITH_ANTIGEN_BOUND_TO_MHC_MOLECULE_ON_ANTIGEN_PRESENTING_CELL
Systematic name | M25566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of T cell activation via T cell receptor contact with antigen bound to MHC molecule on antigen presenting cell. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_DENDRITIC_CELL_DIFFERENTIATION
Systematic name | M10677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of dendritic cell differentiation. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_DENDRITIC_CELL_DIFFERENTIATION
Systematic name | M25567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of dendritic cell differentiation. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_OSTEOCLAST_DEVELOPMENT
Systematic name | M25568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of osteoclast development. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_OSTEOCLAST_DEVELOPMENT
Systematic name | M25569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of osteoclast development. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_OSTEOCLAST_DEVELOPMENT
Systematic name | M25570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of osteoclast development. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_VASCULOGENESIS
Systematic name | M10244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of vasculogenesis. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_VASCULOGENESIS
Systematic name | M25571
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of vasculogenesis. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_NEURON_MIGRATION
Systematic name | M13430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of neuron migration. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_NEURON_MIGRATION
Systematic name | M25572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of neuron migration. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_NEURON_MIGRATION
Systematic name | M14792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of neuron migration. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_CHLORIDE_TRANSPORT
Systematic name | M25573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of chloride transport. [GOC:dph]
Full description |

Standard name | GO_REGULATION_OF_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M16933
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M14668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M16706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_EXTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M13195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of extrinsic apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_EXTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M12140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of extrinsic apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EXTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M15721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of extrinsic apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_EXTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_ABSENCE_OF_LIGAND
Systematic name | M13197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of extrinsic apoptotic signaling pathway in absence of ligand. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_EXTRINSIC_APOPTOTIC_SIGNALING_PATHWAY_IN_ABSENCE_OF_LIGAND
Systematic name | M13029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of extrinsic apoptotic signaling pathway in absence of ligand. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M16230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of intrinsic apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M12485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of intrinsic apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_INTRINSIC_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M15321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of intrinsic apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_PHOSPHATIDYLCHOLINE_BIOSYNTHETIC_PROCESS
Systematic name | M25574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of phosphatidylcholine biosynthetic process. [GOC:obol]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CHROMOSOME_ORGANIZATION
Systematic name | M13802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of chromosome organization. [GOC:obol]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CHROMOSOME_ORGANIZATION
Systematic name | M14831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of chromosome organization. [GOC:obol]
Full description |

Standard name | GO_REGULATION_OF_STORE_OPERATED_CALCIUM_ENTRY
Systematic name | M25575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of store-operated calcium entry. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_CATION_CHANNEL_ACTIVITY
Systematic name | M16262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cation channel activity. [GOC:BHF]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CATION_CHANNEL_ACTIVITY
Systematic name | M12421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cation channel activity. [GOC:BHF]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CATION_CHANNEL_ACTIVITY
Systematic name | M10559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cation channel activity. [GOC:BHF]
Full description |

Standard name | GO_REGULATION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M14055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cysteine-type endopeptidase activity involved in apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_NEGATIVE_REGULATION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M25576
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that stops, prevents or reduces the frequency, rate or extent of cysteine-type endopeptidase activity involved in apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M14375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of cysteine-type endopeptidase activity involved in apoptotic signaling pathway. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_EXECUTION_PHASE_OF_APOPTOSIS
Systematic name | M25577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of cysteine-type endopeptidase activity involved in execution phase of apoptosis. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_REGULATION_OF_UNSATURATED_FATTY_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M25578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of unsaturated fatty acid biosynthetic process. [GO:0006636]
Full description |

Standard name | GO_POSITIVE_REGULATION_OF_UNSATURATED_FATTY_ACID_BIOSYNTHETIC_PROCESS
Systematic name | M25579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that activates or increases the frequency, rate or extent of unsaturated fatty acid biosynthetic process. [GO:0006636]
Full description |

Standard name | GO_REGULATION_OF_CAVEOLIN_MEDIATED_ENDOCYTOSIS
Systematic name | M25580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | Any process that modulates the frequency, rate or extent of caveolin-mediated endocytosis. [GOC:obol]
Full description |

Standard name | GO_LIPOXIN_METABOLIC_PROCESS
Systematic name | M29402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:BP
Brief description | The chemical reactions and pathways involving a lipoxin. A lipoxin is a non-classic eicosanoid and signalling molecule that has four conjugated double bonds and is derived from arachidonic acid. [GOC:mw]
Full description |

Standard name | GO_NUCLEOTIDE_EXCISION_REPAIR_COMPLEX
Systematic name | M17704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any complex formed of proteins that act in nucleotide-excision repair. [PMID:10915862]
Full description |

Standard name | GO_HISTONE_DEACETYLASE_COMPLEX
Systematic name | M17795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that possesses histone deacetylase activity. [GOC:mah]
Full description |

Standard name | GO_SAGA_COMPLEX
Systematic name | M17050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A SAGA-type histone acetyltransferase complex that contains Spt8 (in budding yeast) or a homolog thereof; additional polypeptides include Spt group, consisting of Spt7, Spt3, and Spt20/Ada5, which interact with the TATA-binding protein (TBP); the Ada group, consisting of Ada1, Ada2, Ada3, Ada4/Gcn5, and Ada5/Spt20, which is functionally linked to the nucleosomal HAT activity; Tra1, an ATM/PI-3 kinase-related protein that targets DNA-bound activators for recruitment to promoters; the TBP-associated factor (TAF) proteins, consisting of Taf5, Taf6, Taf9, Taf10, and Taf12, which mediate nucleosomal HAT activity and are thought to help recruit the basal transcription machinery; the ubiquitin specifc protease Ubp-8. [PMID:10637607, PMID:17337012, PMID:19056896, PMID:20838651]
Full description |

Standard name | GO_PCAF_COMPLEX
Systematic name | M25582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large multiprotein complex that possesses histone acetyltransferase activity and is involved in regulation of transcription. The composition is similar to that of the SAGA complex, but includes fewer Spt and Ada proteins, and more TAFs. [PMID:10637607]
Full description |

Standard name | GO_TRANSCRIPTION_FACTOR_TFIIIC_COMPLEX
Systematic name | M25584
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterotrimeric transcription factor complex that is involved in regulating transcription from RNA polymerase III (Pol III) promoters. TFIIIC contains three conserved subunits that associate with the proximal Pol III promoter element, and additional subunits that associate with sequence elements downstream of the promoter and are more diverged among species. It also functions as a boundary element to partition genome content into distinct domains outside Pol III promoter regions. [GOC:mah, GOC:vw, PMID:11433012, PMID:16751097]
Full description |

Standard name | GO_GOLGI_CIS_CISTERNA
Systematic name | M25585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The Golgi cisterna closest to the endoplasmic reticulum; the first processing compartment through which proteins pass after export from the ER. [ISBN:0815316194]
Full description |

Standard name | GO_GOLGI_TRANS_CISTERNA
Systematic name | M25586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The Golgi cisterna farthest from the endoplasmic reticulum; the final processing compartment through which proteins pass before exiting the Golgi apparatus; the compartment in which N-linked protein glycosylation is completed. [ISBN:0815316194]
Full description |

Standard name | GO_GOLGI_MEMBRANE
Systematic name | M9395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding any of the compartments of the Golgi apparatus. [GOC:mah]
Full description |

Standard name | GO_EXOCYST
Systematic name | M17570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex peripherally associated with the plasma membrane that determines where vesicles dock and fuse. At least eight complex components are conserved between yeast and mammals. [GOC:cilia, PMID:15292201, PMID:27243008, PMID:9700152]
Full description |

Standard name | GO_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M18504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that includes a ubiquitin-protein ligase and enables ubiquitin protein ligase activity. The complex also contains other proteins that may confer substrate specificity on the complex. [GOC:jh2, PMID:9529603]
Full description |

Standard name | GO_NUCLEAR_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M14738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex found in the nucleus. [GOC:mah]
Full description |

Standard name | GO_CYTOPLASMIC_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M17051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex found in the cytoplasm. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_PHOSPHATASE_TYPE_2A_COMPLEX
Systematic name | M17783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that has protein serine/threonine phosphatase activity that is polycation-stimulated (PCS), being directly stimulated by protamine, polylysine, or histone H1; it constitutes a subclass of several enzymes activated by different histones and polylysine, and consists of catalytic, scaffolding, and regulatory subunits. The catalytic and scaffolding subunits form the core enzyme, and the holoenzyme also includes the regulatory subunit. [GOC:mah, ISBN:0198547684, PMID:17245430]
Full description |

Standard name | GO_PROTEIN_PHOSPHATASE_TYPE_1_COMPLEX
Systematic name | M17249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that possesses magnesium-dependent protein serine/threonine phosphatase (AMD phosphatase) activity, and consists of a catalytic subunit and one or more regulatory subunits that dictates the phosphatase's substrate specificity, function, and activity. [GOC:mah, GOC:ssd]
Full description |

Standard name | GO_RIBONUCLEASE_MRP_COMPLEX
Systematic name | M25587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains an RNA molecule of the snoRNA family, and cleaves the rRNA precursor as part of rRNA transcript processing. It also has other roles: In S. cerevisiae it is involved in cell cycle-regulated degradation of daughter cell-specific mRNAs, while in mammalian cells it also enters the mitochondria and processes RNAs to create RNA primers for DNA replication. [GOC:sgd_curators, PMID:10690410, PMID:14729943, PMID:7510714]
Full description |

Standard name | GO_NUCLEAR_EXOSOME_RNASE_COMPLEX
Systematic name | M16997
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonuclease complex that has 3-prime to 5-prime processive and distributive hydrolytic exoribonuclease activity and endoribonuclease activity, producing 5-prime-phosphomonoesters. Participates in a multitude of cellular RNA processing and degradation events preventing nuclear export and/or translation of aberrant RNAs. Restricted to processing linear and circular single-stranded RNAs (ssRNA) only. RNAs with complex secondary structures may have to be unwound or pre-processed by co-factors prior to entering the complex, esp if the 3-prime end is structured. [PMID:17174896, PMID:20531386, PMID:26726035]
Full description |

Standard name | GO_CYTOPLASMIC_EXOSOME_RNASE_COMPLEX
Systematic name | M17171
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonuclease complex that has 3-prime to 5-prime processive hydrolytic exoribonuclease activity producing 5-prime-phosphomonoesters. Participates in a multitude of cellular RNA processing and degradation events preventing nuclear export and/or translation of aberrant RNAs. Restricted to processing linear and circular single-stranded RNAs (ssRNA) only. RNAs with complex secondary structures may have to be unwound or pre-processed by co-factors prior to entering the complex, esp if the 3-prime end is structured. [PMID:17174896, PMID:20531386, PMID:26726035]
Full description |

Standard name | GO_NUCLEAR_CHROMOSOME
Systematic name | M18650
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A chromosome that encodes the nuclear genome and is found in the nucleus of a eukaryotic cell during the cell cycle phases when the nucleus is intact. [GOC:dph, GOC:mah]
Full description |

Standard name | GO_PERICENTRIOLAR_MATERIAL
Systematic name | M17701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A network of small fibers that surrounds the centrioles in cells; contains the microtubule nucleating activity of the centrosome. [GOC:clt, ISBN:0815316194]
Full description |

Standard name | GO_COMMITMENT_COMPLEX
Systematic name | M25588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spliceosomal complex that is formed by association of the U1 snRNP with the 5' splice site of an unspliced intron in an RNA transcript. [GOC:krc, ISBN:0879695897, PMID:9150140]
Full description |

Standard name | GO_MITOCHONDRIAL_PROTON_TRANSPORTING_ATP_SYNTHASE_COMPLEX_CATALYTIC_SECTOR_F_1
Systematic name | M29403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The catalytic sector of the mitochondrial hydrogen-transporting ATP synthase; it comprises the catalytic core and central stalk, and is peripherally associated with the mitochondrial inner membrane when the entire ATP synthase is assembled. [GOC:mtg_sensu, PMID:10838056]
Full description |

Standard name | GO_CYCLIN_DEPENDENT_PROTEIN_KINASE_HOLOENZYME_COMPLEX
Systematic name | M17847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Cyclin-dependent protein kinases (CDKs) are enzyme complexes that contain a kinase catalytic subunit associated with a regulatory cyclin partner. [GOC:krc, PMID:11602261]
Full description |

Standard name | GO_ORGANELLAR_RIBOSOME
Systematic name | M17286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribosome contained within a subcellular membrane-bounded organelle. [GOC:mah, GOC:mcc]
Full description |

Standard name | GO_TRANSCRIPTION_EXPORT_COMPLEX
Systematic name | M17018
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The transcription export (TREX) complex couples transcription elongation by RNA polymerase II to mRNA export. The complex associates with the polymerase and travels with it along the length of the transcribed gene. TREX is composed of the THO transcription elongation complex as well as other proteins that couple THO to mRNA export proteins. The TREX complex is known to be found in a wide range of eukaryotes, including S. cerevisiae and metazoans. [GOC:krc, PMID:11979277]
Full description |

Standard name | GO_THO_COMPLEX
Systematic name | M25590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The THO complex is a nuclear complex that is required for transcription elongation through genes containing tandemly repeated DNA sequences. The THO complex is also part of the TREX (TRanscription EXport) complex that is involved in coupling transcription to export of mRNAs to the cytoplasm. In S. cerevisiae, it is composed of four subunits: Hpr1p, Tho2p, Thp1p, and Mft1p, while the human complex is composed of 7 subunits. [GOC:krc, PMID:11060033, PMID:11979277, PMID:16983072]
Full description |

Standard name | GO_PHAGOPHORE_ASSEMBLY_SITE
Systematic name | M25591
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Punctate structures proximal to the endoplasmic reticulum which are the sites where the Atg machinery assembles upon autophagy induction. [GOC:elh, PMID:11689437, PMID:12048214, PMID:12554655]
Full description |

Standard name | GO_EKC_KEOPS_COMPLEX
Systematic name | M25592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex involved in t6A tRNA modification; originally proposed to be involved in transcription as well as promoting telomere uncapping and telomere elongation. For example, in Saccharomyces cerevisiae the complex contains Bud32p, Kae1p, Gon7p, Cgi121p, and Pcc1p. [GOC:elh, GOC:vw, PMID:16564010, PMID:16874308, PMID:21183954, PMID:23945934]
Full description |

Standard name | GO_AUTOPHAGOSOME_MEMBRANE
Systematic name | M17575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding an autophagosome, a double-membrane-bounded vesicle in which endogenous cellular material is sequestered. [GOC:autophagy, GOC:isa_complete]
Full description |

Standard name | GO_GLYCOSYLPHOSPHATIDYLINOSITOL_N_ACETYLGLUCOSAMINYLTRANSFERASE_GPI_GNT_COMPLEX
Systematic name | M25594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An enzyme complex that catalyzes the transfer of GlcNAc from UDP-GlcNAc to an acceptor phosphatidylinositol, the first step in the production of GPI anchors for cell surface proteins. The complex contains PIG-A, PIG-C, PIG-H, PIG-Q, PIG-P, and DPM2 in human, and Eri1p, Gpi1p, Gpi2p, Gpi15p, Gpi19p, and Spt14p in budding yeast. [GOC:kp, GOC:rb, PMID:10944123, PMID:15163411]
Full description |

Standard name | GO_CHROMOSOME_CENTROMERIC_REGION
Systematic name | M4721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of a chromosome that includes the centromeric DNA and associated proteins. In monocentric chromosomes, this region corresponds to a single area of the chromosome, whereas in holocentric chromosomes, it is evenly distributed along the chromosome. [GOC:cjm, GOC:elh, GOC:kmv, GOC:pr]
Full description |

Standard name | GO_KINETOCHORE
Systematic name | M9421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit complex that is located at the centromeric region of DNA and provides an attachment point for the spindle microtubules. [GOC:elh]
Full description |

Standard name | GO_CONDENSED_NUCLEAR_CHROMOSOME_KINETOCHORE
Systematic name | M25595
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit complex that is located at the centromeric region of a condensed nuclear chromosome and provides an attachment point for the spindle microtubules. [GOC:elh]
Full description |

Standard name | GO_CONDENSED_CHROMOSOME_CENTROMERIC_REGION
Systematic name | M17499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of a condensed chromosome that includes the centromere and associated proteins, including the kinetochore. In monocentric chromosomes, this region corresponds to a single area of the chromosome, whereas in holocentric chromosomes, it is evenly distributed along the chromosome. [GOC:elh, GOC:kmv]
Full description |

Standard name | GO_CONDENSED_NUCLEAR_CHROMOSOME_CENTROMERIC_REGION
Systematic name | M17548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of a condensed nuclear chromosome that includes the centromere and associated proteins, including the kinetochore. In monocentric chromosomes, this region corresponds to a single area of the chromosome, whereas in holocentric chromosomes, it is evenly distributed along the chromosome. [GOC:elh, GOC:kmv]
Full description |

Standard name | GO_CHROMOSOME_TELOMERIC_REGION
Systematic name | M17650
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The terminal region of a linear chromosome that includes the telomeric DNA repeats and associated proteins. [GOC:elh]
Full description |

Standard name | GO_TELOMERE_CAP_COMPLEX
Systematic name | M17703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex of DNA and protein located at the end of a linear chromosome that protects and stabilizes a linear chromosome. [GOC:elh]
Full description |

Standard name | GO_NUCLEAR_CHROMOSOME_TELOMERIC_REGION
Systematic name | M16976
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The end of a linear chromosome, required for the integrity and maintenance of the end. A chromosome telomere usually includes a region of telomerase-encoded repeats the length of which rarely exceeds 20 bp each and that permits the formation of a telomeric loop (T-loop). The telomeric repeat region is usually preceded by a sub-telomeric region that is gene-poor but rich in repetitive elements. Some telomeres only consist of the latter part (for eg. D. melanogaster telomeres). [GOC:elh]
Full description |

Standard name | GO_CHROMATIN
Systematic name | M5728
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The ordered and organized complex of DNA, protein, and sometimes RNA, that forms the chromosome. [GOC:elh, PMID:20404130]
Full description |

Standard name | GO_NUCLEAR_NUCLEOSOME
Systematic name | M17236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex comprised of DNA wound around a multisubunit core and associated proteins, which forms the primary packing unit of DNA in the nucleus into higher order structures. [GOC:elh]
Full description |

Standard name | GO_EUCHROMATIN
Systematic name | M17611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A dispersed and relatively uncompacted form of chromatin. [GOC:elh]
Full description |

Standard name | GO_HETEROCHROMATIN
Systematic name | M17538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A compact and highly condensed form of chromatin. [GOC:elh]
Full description |

Standard name | GO_CONDENSED_CHROMOSOME
Systematic name | M451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A highly compacted molecule of DNA and associated proteins resulting in a cytologically distinct structure. [GOC:elh]
Full description |

Standard name | GO_CONDENSED_NUCLEAR_CHROMOSOME
Systematic name | M18735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A highly compacted molecule of DNA and associated proteins resulting in a cytologically distinct nuclear chromosome. [GOC:elh]
Full description |

Standard name | GO_CONDENSIN_COMPLEX
Systematic name | M25596
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit protein complex that plays a central role in chromosome condensation. [GOC:elh]
Full description |

Standard name | GO_NUCLEAR_COHESIN_COMPLEX
Systematic name | M34343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cohesin complex required for cohesion between sister chromatids that remain in the nucleus. [GOC:elh]
Full description |

Standard name | GO_LATERAL_ELEMENT
Systematic name | M17618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A proteinaceous core found between sister chromatids during meiotic prophase. [GOC:elh]
Full description |

Standard name | GO_CENTRAL_ELEMENT
Systematic name | M25597
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structural unit of the synaptonemal complex found between the lateral elements. [GOC:elh]
Full description |

Standard name | GO_SEX_CHROMOSOME
Systematic name | M17147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A chromosome involved in sex determination. [GOC:elh]
Full description |

Standard name | GO_X_CHROMOSOME
Systematic name | M25598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The sex chromosome present in both sexes of species in which the male is the heterogametic sex. Two copies of the X chromosome are present in each somatic cell of females and one copy is present in males. [GOC:mah, GOC:mr, ISBN:0582227089, PMID:20622855, Wikipedia:XY_sex-determination_system]
Full description |

Standard name | GO_ORIGIN_RECOGNITION_COMPLEX
Systematic name | M25599
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit complex that is located at the replication origins of a chromosome. [GOC:elh]
Full description |

Standard name | GO_SWR1_COMPLEX
Systematic name | M25600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit protein complex that is involved in chromatin remodeling. It is required for the incorporation of the histone variant H2AZ into chromatin. In S. cerevisiae, the complex contains Swr1p, a Swi2/Snf2-related ATPase, and 12 additional subunits. [GOC:rb, PMID:14645854, PMID:14690608, PMID:19355820]
Full description |

Standard name | GO_ESCRT_I_COMPLEX
Systematic name | M25601
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An endosomal sorting complex required for transport. It consists of the class E vacuolar protein sorting (Vps) proteins and interacts with ubiquitinated cargoes. [GOC:rb, PMID:12892785, PMID:12900393]
Full description |

Standard name | GO_ESCRT_III_COMPLEX
Systematic name | M17734
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An endosomal sorting complex required for transport. Consists of two soluble subcomplexes of highly charged coiled-coil proteins and is required for sorting and/or concentration of multivesicular body (MVB) cargoes. [GOC:rb, PMID:12892785, PMID:12900393]
Full description |

Standard name | GO_ER_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M25602
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex found in the ER. [GOC:elh]
Full description |

Standard name | GO_HRD1P_UBIQUITIN_LIGASE_ERAD_L_COMPLEX
Systematic name | M29404
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiprotein complex that recognizes and ubiquitinates proteins with misfolded luminal domains during ER-associated protein degradation (ERAD). In S. cerevisiae, this complex contains the ubiquitin ligase Hrd1p. [GOC:elh, PMID:16873065, PMID:16873066]
Full description |

Standard name | GO_SPINDLE_POLE
Systematic name | M4499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Either of the ends of a spindle, where spindle microtubules are organized; usually contains a microtubule organizing center and accessory molecules, spindle microtubules and astral microtubules. [GOC:clt]
Full description |

Standard name | GO_EQUATORIAL_MICROTUBULE_ORGANIZING_CENTER
Systematic name | M25603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A microtubule organizing center formed by a band of gamma-tubulin that is recruited to a circumferential band of F-actin at the midpoint of a cell and which nucleates microtubules from the cell division site at the end of mitosis. [PMID:11792817]
Full description |

Standard name | GO_GAMMA_TUBULIN_COMPLEX
Systematic name | M17566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiprotein complex composed of gamma-tubulin and other non-tubulin proteins. Gamma-tubulin complexes are localized to microtubule organizing centers, and play an important role in the nucleation of microtubules. The number and complexity of non-tubulin proteins associated with these complexes varies between species. [GOC:clt, PMID:12134075]
Full description |

Standard name | GO_GAMMA_TUBULIN_LARGE_COMPLEX
Systematic name | M25604
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex of gamma tubulin and associated proteins thought to be formed by multimerization of gamma-tubulin small complexes. An example of this structure is found in Schizosaccharomyces pombe. [GOC:mtg_sensu, PMID:12134075]
Full description |

Standard name | GO_P_BODY
Systematic name | M25605
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A focus in the cytoplasm where mRNAs may become inactivated by decapping or some other mechanism. Protein and RNA localized to these foci are involved in mRNA degradation, nonsense-mediated mRNA decay (NMD), translational repression, and RNA-mediated gene silencing. [GOC:clt, PMID:12730603]
Full description |

Standard name | GO_GARP_COMPLEX
Systematic name | M25606
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A quatrefoil tethering complex required for retrograde traffic from the early endosome back to the late Golgi and biogenesis of cytoplasmic vesicles. [GOC:clt, GOC:rn, PMID:10637310, PMID:12077354, PMID:12446664]
Full description |

Standard name | GO_CONDENSED_CHROMOSOME_INNER_KINETOCHORE
Systematic name | M29405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of a condensed chromosome kinetochore closest to centromeric DNA; in mammals the CREST antigens (CENP proteins) are found in this layer; this layer may help define underlying centromeric chromatin structure and position of the kinetochore on the chromosome. [GOC:clt, PMID:10619130, PMID:11483983]
Full description |

Standard name | GO_CONDENSED_CHROMOSOME_OUTER_KINETOCHORE
Systematic name | M17516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of a condensed chromosome kinetochore most external to centromeric DNA; this outer region mediates kinetochore-microtubule interactions. [GOC:clt, PMID:11483983]
Full description |

Standard name | GO_PRP19_COMPLEX
Systematic name | M17498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex consisting of Prp19 and associated proteins that is involved in the transition from the precatalytic spliceosome to the activated form that catalyzes step 1 of splicing, and which remains associated with the spliceosome through the second catalytic step. It is widely conserved, found in both yeast and mammals, though the exact composition varies. In S. cerevisiae, it contains Prp19p, Ntc20p, Snt309p, Isy1p, Syf2p, Cwc2p, Prp46p, Clf1p, Cef1p, and Syf1p. [GOC:krc, PMID:16540691, PMID:19239890]
Full description |

Standard name | GO_SAM_COMPLEX
Systematic name | M25607
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large complex of the mitochondrial outer membrane that mediates sorting of some imported proteins to the outer membrane and their assembly in the membrane; functions after import of incoming proteins by the mitochondrial outer membrane translocase complex. [PMID:12891361]
Full description |

Standard name | GO_PAM_COMPLEX_TIM23_ASSOCIATED_IMPORT_MOTOR
Systematic name | M25608
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Protein complex located on the matrix side of the mitochondrial inner membrane and associated with the TIM23 mitochondrial import inner membrane translocase complex (GO:0005744); ATPase motor activity to drive import of proteins into the mitochondrial matrix. [GOC:mcc, GOC:vw, PMID:14517234, PMID:14638855]
Full description |

Standard name | GO_VOLTAGE_GATED_SODIUM_CHANNEL_COMPLEX
Systematic name | M17379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A sodium channel in a cell membrane whose opening is governed by the membrane potential. [ISBN:0198506732]
Full description |

Standard name | GO_OUTER_DENSE_FIBER
Systematic name | M25609
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A supramolecular fiber found in the flagella of mammalian sperm that surrounds the nine microtubule doublets. These dense fibers are stiff and noncontractile. In human, they consist of about 10 major and at least 15 minor proteins, where all major proteins are ODF1, ODF2 or ODF2-related proteins. [GOC:cilia, GOC:krc, ISBN:0824072820, PMID:10381817, PMID:21586547, PMID:25361759]
Full description |

Standard name | GO_MICROFIBRIL
Systematic name | M25610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Extracellular matrix components occurring independently or along with elastin. Thought to have force-bearing functions in tendon. In addition to fibrillins, microfibrils may contain other associated proteins. [PMID:27026396]
Full description |

Standard name | GO_CORNIFIED_ENVELOPE
Systematic name | M17690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A type of plasma membrane that has been modified through addition of distinct intracellular and extracellular components, including ceramide, found in cornifying epithelial cells (corneocytes). [GOC:add, PMID:11112355, PMID:11590230, PMID:15803139]
Full description |

Standard name | GO_RADIAL_SPOKE
Systematic name | M25611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Protein complex that links the outer microtubule doublet of the ciliary or flagellum axoneme with the sheath that surrounds the central pair of microtubules. Composed of a stalk that attaches to each doublet microtubule and a globular structure (spoke head) that projects toward the central pair of microtubules. [ISBN:0124325653, PMID:9450971]
Full description |

Standard name | GO_FIBRILLAR_CENTER
Systematic name | M25612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structure found most metazoan nucleoli, but not usually found in lower eukaryotes; surrounded by the dense fibrillar component; the zone of transcription from multiple copies of the pre-rRNA genes is in the border region between these two structures. [PMID:10754561]
Full description |

Standard name | GO_GRANULAR_COMPONENT
Systematic name | M25613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structure found in the nucleolus, which contains nearly completed preribosomal particles destined for the cytoplasm. [PMID:10754561]
Full description |

Standard name | GO_ACROSOMAL_VESICLE
Systematic name | M17623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structure in the head of a spermatozoon that contains acid hydrolases, and is concerned with the breakdown of the outer membrane of the ovum during fertilization. It lies just beneath the plasma membrane and is derived from the lysosome. [ISBN:0124325653, ISBN:0198506732]
Full description |

Standard name | GO_MALE_GERM_CELL_NUCLEUS
Systematic name | M17137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The nucleus of a male germ cell, a reproductive cell in males. [CL:0000015, GOC:hjd, GOC:mtg_sensu]
Full description |

Standard name | GO_RUFFLE
Systematic name | M11447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Projection at the leading edge of a crawling cell; the protrusions are supported by a microfilament meshwork. [ISBN:0124325653]
Full description |

Standard name | GO_SEX_CHROMATIN
Systematic name | M25615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Chromatin that is part of a sex chromosome. [GOC:dos, ISBN:0198506732]
Full description |

Standard name | GO_BARR_BODY
Systematic name | M29406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structure found in a female mammalian cell containing an unpaired X chromosome that has become densely heterochromatic, silenced and localized at the nuclear periphery. [GOC:hjd, GOC:mr, NIF_Subcellular:sao1571698684]
Full description |

Standard name | GO_XY_BODY
Systematic name | M17457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structure found in a male mammalian spermatocyte containing an unpaired X chromosome that has become densely heterochromatic, silenced and localized at the nuclear periphery. [GOC:hjd, GOC:mr, PMID:20622855, Wikipedia:XY_sex-determination_system]
Full description |

Standard name | GO_PHOTORECEPTOR_OUTER_SEGMENT
Systematic name | M17796
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The outer segment of a vertebrate photoreceptor that contains a stack of membrane discs embedded with photoreceptor proteins. [GOC:cilia, GOC:krc, GOC:pde, ISBN:0824072820, PMID:19501669, PMID:26574505, PMID:6771304]
Full description |

Standard name | GO_IMMUNOLOGICAL_SYNAPSE
Systematic name | M17012
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An area of close contact between a lymphocyte (T-, B-, or natural killer cell) and a target cell formed through the clustering of particular signaling and adhesion molecules and their associated membrane rafts on both the lymphocyte and the target cell and facilitating activation of the lymphocyte, transfer of membrane from the target cell to the lymphocyte, and in some situations killing of the target cell through release of secretory granules and/or death-pathway ligand-receptor interaction. [GOC:mgi_curators, PMID:11244041, PMID:11376300]
Full description |

Standard name | GO_PHAGOCYTIC_CUP
Systematic name | M17344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An invagination of the cell membrane formed by an actin dependent process during phagocytosis. Following internalization it is converted into a phagosome. [PMID:10358769]
Full description |

Standard name | GO_PHOTORECEPTOR_INNER_SEGMENT
Systematic name | M17610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The inner segment of a vertebrate photoreceptor containing mitochondria, ribosomes and membranes where opsin molecules are assembled and passed to be part of the outer segment discs. [GOC:add, PMID:12019563]
Full description |

Standard name | GO_FEMALE_PRONUCLEUS
Systematic name | M25616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The pronucleus originating from the ovum that is being fertilized. [GOC:hjd, ISBN:0198506732]
Full description |

Standard name | GO_MALE_PRONUCLEUS
Systematic name | M25617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The pronucleus originating from the spermatozoa that was involved in fertilization. [GOC:hjd, ISBN:0198506732]
Full description |

Standard name | GO_INNER_ACROSOMAL_MEMBRANE
Systematic name | M25618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The acrosomal membrane region that underlies the acrosomal vesicle and is located toward the sperm nucleus. This region is responsible for molecular interactions allowing the sperm to penetrate the zona pellucida and fuses with the egg plasma membrane. [GOC:dph, PMID:3899643, PMID:8936405]
Full description |

Standard name | GO_ACROSOMAL_MEMBRANE
Systematic name | M17075
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The membrane that surrounds the acrosomal lumen. The acrosome is a special type of lysosome in the head of a spermatozoon that contains acid hydrolases and is concerned with the breakdown of the outer membrane of the ovum during fertilization. [GOC:dph]
Full description |

Standard name | GO_PODOSOME
Systematic name | M17573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An actin-rich adhesion structure characterized by formation upon cell substrate contact and localization at the substrate-attached part of the cell, contain an F-actin-rich core surrounded by a ring structure containing proteins such as vinculin and talin, and have a diameter of 0.5 mm. [PMID:12837608, PMID:15890982]
Full description |

Standard name | GO_SEMAPHORIN_RECEPTOR_COMPLEX
Systematic name | M17529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A stable binary complex of a neurophilin and a plexin, together forming a functional semaphorin receptor. [GOC:hjd, PMID:10934324, PMID:12367632, PMID:12613544]
Full description |

Standard name | GO_STEREOCILIA_COUPLING_LINK
Systematic name | M25619
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structure involved in coupling stereocilia to one another in sensory hair cells There are four morphologically distinct types: tip links, horizontal top connectors, shaft connectors and ankle links. Tip links and horizontal top connectors are the only inter-stereocilia links associated with mature cochlea, whereas ankle links appear during development of the auditory hair bundle. [PMID:16775142]
Full description |

Standard name | GO_MANCHETTE
Systematic name | M25620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A tubular array of microtubules that extends from the perinuclear ring surrounding the spermatid nucleus to the flagellar axoneme. The manchette may also contain F-actin filaments. [GOC:krc, PMID:15018141, PMID:22319670, PMID:24440897, PMID:26792866]
Full description |

Standard name | GO_PALMITOYLTRANSFERASE_COMPLEX
Systematic name | M25621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex with palmitoyltransferase activity. [GOC:hjd]
Full description |

Standard name | GO_RIBOSE_PHOSPHATE_DIPHOSPHOKINASE_COMPLEX
Systematic name | M25622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex having ribose phosphate diphosphokinase activity. [GO:hjd, PMID:9348095]
Full description |

Standard name | GO_ZONA_PELLUCIDA_RECEPTOR_COMPLEX
Systematic name | M25623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit complex comprising the chaperonin-containing T-complex and several other components involved in mediating sperm-oocyte Interaction. [GOC:hjd, PMID:21880732]
Full description |

Standard name | GO_FIBRINOGEN_COMPLEX
Systematic name | M25624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A highly soluble, elongated protein complex found in blood plasma and involved in clot formation. It is converted into fibrin monomer by the action of thrombin. In the mouse, fibrinogen is a hexamer, 46 nm long and 9 nm maximal diameter, containing two sets of nonidentical chains (alpha, beta, and gamma) linked together by disulfide bonds. [ISBN:0198547684]
Full description |

Standard name | GO_MEMBRANE_ATTACK_COMPLEX
Systematic name | M25625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex produced by sequentially activated components of the complement cascade inserted into a target cell membrane and forming a pore leading to cell lysis via ion and water flow. [GOC:add, ISBN:0198547684, ISBN:068340007X, ISBN:0781735149]
Full description |

Standard name | GO_COLLAGEN_TRIMER
Systematic name | M10742
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex consisting of three collagen chains assembled into a left-handed triple helix. These trimers typically assemble into higher order structures. [GOC:dos, GOC:mah, ISBN:0721639976, PMID:19693541, PMID:21421911]
Full description |

Standard name | GO_FIBRILLAR_COLLAGEN_TRIMER
Systematic name | M25626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any triple helical collagen trimer that forms fibrils. [GOC:mah, ISBN:0721639976, PMID:21421911]
Full description |

Standard name | GO_COLLAGEN_TYPE_IV_TRIMER
Systematic name | M25627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A collagen heterotrimer containing type IV alpha chains; [alpha1(IV)]2alpha2(IV) trimers are commonly observed, although more type IV alpha chains exist and may be present in type IV trimers; type IV collagen triple helices associate to form 3 dimensional nets within basement membranes. [ISBN:0721639976, PMID:19693541, PMID:21421911]
Full description |

Standard name | GO_FACIT_COLLAGEN_TRIMER
Systematic name | M25628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A collagen trimer that associates with collagen fibrils and consists of collagen monomers that contain two or more relatively short triple-helical domains connected by non-triple-helical sequences. [ISBN:0198599587, PMID:21421911]
Full description |

Standard name | GO_BASEMENT_MEMBRANE
Systematic name | M15249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A collagen-containing extracellular matrix consisting of a thin layer of dense material found in various animal tissues interposed between the cells and the adjacent connective tissue. It consists of the basal lamina plus an associated layer of reticulin fibers. [ISBN:0198547684, PMID:22505934]
Full description |

Standard name | GO_INTERSTITIAL_MATRIX
Systematic name | M17473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A type of extracellular matrix found in interstitial connective tissue, characterized by the presence of fibronectins, proteoglycans, and types I, III, V, VI, VII and XII collagens. [PMID:8450001]
Full description |

Standard name | GO_NUCLEAR_ENVELOPE
Systematic name | M16993
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The double lipid bilayer enclosing the nucleus and separating its contents from the rest of the cytoplasm; includes the intermembrane space, a gap of width 20-40 nm (also called the perinuclear space). [ISBN:0198547684]
Full description |

Standard name | GO_NUCLEAR_INNER_MEMBRANE
Systematic name | M17443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The inner, i.e. lumen-facing, lipid bilayer of the nuclear envelope. [GOC:ma]
Full description |

Standard name | GO_LAMIN_FILAMENT
Systematic name | M29408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of a group of intermediate-filament proteins that form the fibrous matrix on the inner surface of the nuclear envelope. They are classified as lamins A, B and C. [ISBN:0198547684]
Full description |

Standard name | GO_NUCLEAR_OUTER_MEMBRANE
Systematic name | M17036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The outer, i.e. cytoplasm-facing, lipid bilayer of the nuclear envelope; continuous with the endoplasmic reticulum of the cell and sometimes studded with ribosomes. [ISBN:0198547684]
Full description |

Standard name | GO_NUCLEAR_ENVELOPE_LUMEN
Systematic name | M25629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region between the two lipid bilayers of the nuclear envelope; 20-40 nm wide. [GOC:ai]
Full description |

Standard name | GO_ANNULATE_LAMELLAE
Systematic name | M25630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Stacks of endoplasmic reticulum (ER) membranes containing a high density of nuclear pores, thought to form from excess nuclear membrane components, that have been described in a number of different cells. Annulate lamellar membranes are continuous with and embedded within the ER. [PMID:12631728]
Full description |

Standard name | GO_NUCLEAR_PORE
Systematic name | M17706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the numerous similar discrete openings in the nuclear envelope of a eukaryotic cell, where the inner and outer nuclear membranes are joined. [ISBN:0198547684]
Full description |

Standard name | GO_NUCLEAR_LAMINA
Systematic name | M25631
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The fibrous, electron-dense layer lying on the nucleoplasmic side of the inner membrane of a cell nucleus, composed of lamin filaments. The polypeptides of the lamina are thought to be concerned in the dissolution of the nuclear envelope and its re-formation during mitosis. The lamina is composed of lamin A and lamin C filaments cross-linked into an orthogonal lattice, which is attached via lamin B to the inner nuclear membrane through interactions with a lamin B receptor, an IFAP, in the membrane. [ISBN:0198506732, ISBN:0716731363]
Full description |

Standard name | GO_NUCLEOLAR_RIBONUCLEASE_P_COMPLEX
Systematic name | M25632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonuclease P complex located in the nucleolus of a eukaryotic cell, where it catalyzes the 5' endonucleolytic cleavage of precursor tRNAs to yield mature tRNAs. Eukaryotic nucleolar ribonuclease P complexes generally contain a single RNA molecule that is necessary but not sufficient for catalysis, and several protein molecules. [GOC:mah, PMID:12045094]
Full description |

Standard name | GO_REPLICATION_FORK
Systematic name | M8237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The Y-shaped region of a replicating DNA molecule, resulting from the separation of the DNA strands and in which the synthesis of new strands takes place. Also includes associated protein complexes. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_ALPHA_DNA_POLYMERASE_PRIMASE_COMPLEX
Systematic name | M25633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex of four polypeptides, comprising large and small DNA polymerase alpha subunits and two primase subunits, which are capable of catalyzing the synthesis of an RNA primer on the lagging strand of replicating DNA and the subsequent synthesis of a smal stretch of DNA. The smaller of the two primase subunits alone can catalyze oligoribonucleotide synthesis. [GOC:mah, PMID:11395402, PMID:26975377]
Full description |

Standard name | GO_DNA_REPLICATION_FACTOR_A_COMPLEX
Systematic name | M17220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A conserved heterotrimeric complex that binds nonspecifically to single-stranded DNA and is required for multiple processes in eukaryotic DNA metabolism, including DNA replication, DNA repair, and recombination. In all eukaryotic organisms examined the complex is composed of subunits of approximately 70, 30, and 14 kDa. [PMID:9242902]
Full description |

Standard name | GO_DNA_REPLICATION_FACTOR_C_COMPLEX
Systematic name | M25634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex that loads the DNA polymerase processivity factor proliferating cell nuclear antigen (PCNA) onto DNA, thereby permitting processive DNA synthesis catalyzed by DNA polymerase. In eukaryotes the complex consists of five polypeptides. [PMID:14614842, PMID:14646196, PMID:16172520]
Full description |

Standard name | GO_RNA_POLYMERASE_II_CORE_COMPLEX
Systematic name | M18167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | RNA polymerase II, one of three nuclear DNA-directed RNA polymerases found in all eukaryotes, is a multisubunit complex; typically it produces mRNAs, snoRNAs, and some of the snRNAs. Two large subunits comprise the most conserved portion including the catalytic site and share similarity with other eukaryotic and bacterial multisubunit RNA polymerases. The largest subunit of RNA polymerase II contains an essential carboxyl-terminal domain (CTD) composed of a variable number of heptapeptide repeats (YSPTSPS). The remainder of the complex is composed of smaller subunits (generally ten or more), some of which are also found in RNA polymerases I and III. Although the core is competent to mediate ribonucleic acid synthesis, it requires additional factors to select the appropriate template. [GOC:krc, GOC:mtg_sensu]
Full description |

Standard name | GO_RNA_POLYMERASE_III_COMPLEX
Systematic name | M25636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | RNA polymerase III, one of three nuclear DNA-directed RNA polymerases found in all eukaryotes, is a multisubunit complex; typically it produces 5S rRNA, tRNAs and some of the small nuclear RNAs. Two large subunits comprise the most conserved portion including the catalytic site and share similarity with other eukaryotic and bacterial multisubunit RNA polymerases. The remainder of the complex is composed of smaller subunits (generally ten or more), some of which are also found in RNA polymerase I and others of which are also found in RNA polymerases I and II. Although the core is competent to mediate ribonucleic acid synthesis, it requires additional factors to select the appropriate template. [GOC:krc, GOC:mtg_sensu]
Full description |

Standard name | GO_TRANSCRIPTION_REGULATOR_COMPLEX
Systematic name | M17313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that is capable of associating with DNA by direct binding, or via other DNA-binding proteins or complexes, and regulating transcription. [GOC:jl]
Full description |

Standard name | GO_TRANSCRIPTION_FACTOR_TFIID_COMPLEX
Systematic name | M16999
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex composed of TATA binding protein (TBP) and TBP associated factors (TAFs); the total mass is typically about 800 kDa. Most of the TAFs are conserved across species. In TATA-containing promoters for RNA polymerase II (Pol II), TFIID is believed to recognize at least two distinct elements, the TATA element and a downstream promoter element. TFIID is also involved in recognition of TATA-less Pol II promoters. Binding of TFIID to DNA is necessary but not sufficient for transcription initiation from most RNA polymerase II promoters. [GOC:krc, GOC:mah, ISBN:0471953393, ISBN:0879695501]
Full description |

Standard name | GO_ADA2_GCN5_ADA3_TRANSCRIPTION_ACTIVATOR_COMPLEX
Systematic name | M17069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiprotein complex that possesses histone acetyltransferase and is involved in regulation of transcription. Contains either GCN5 or PCAF in a mutually exclusive manner. The budding yeast complex includes Gcn5p, two proteins of the Ada family, and two TBP-associate proteins (TAFs); analogous complexes in other species have analogous compositions, and usually contain homologs of the yeast proteins. Both ATAC- or SAGA (see GO:0000124, SAGA complex) are involved in the acetylation of histone H3K9 and K14 residues. [PMID:10637607]
Full description |

Standard name | GO_TRANSCRIPTION_FACTOR_TFIIA_COMPLEX
Systematic name | M25637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A component of the transcription machinery of RNA Polymerase II. In humans, TFIIA is a heterotrimer composed of an alpha (P35), beta (P19) and gamma subunits (P12). [GOC:jl, PMID:17560669]
Full description |

Standard name | GO_TRANSCRIPTION_FACTOR_TFIIH_HOLO_COMPLEX
Systematic name | M25638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex that is capable of kinase activity directed towards the C-terminal Domain (CTD) of the largest subunit of RNA polymerase II and is essential for initiation at RNA polymerase II promoters in vitro. It is composed of the core TFIIH complex and the TFIIK complex. [GOC:ew, GOC:krc, PMID:14500720, PMID:22308316, PMID:22572993, PMID:7813015]
Full description |

Standard name | GO_CHROMATIN_SILENCING_COMPLEX
Systematic name | M25639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that mediates changes in chromatin structure that result in transcriptional silencing. [GOC:mah]
Full description |

Standard name | GO_ANAPHASE_PROMOTING_COMPLEX
Systematic name | M17133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex that degrades mitotic cyclins and anaphase inhibitory protein, thereby triggering sister chromatid separation and exit from mitosis. Substrate recognition by APC occurs through degradation signals, the most common of which is termed the Dbox degradation motif, originally discovered in cyclin B. [GOC:jh, GOC:vw, PMID:10465783, PMID:10611969]
Full description |

Standard name | GO_SPLICEOSOMAL_COMPLEX
Systematic name | M17545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of a series of ribonucleoprotein complexes that contain snRNA(s) and small nuclear ribonucleoproteins (snRNPs), and are formed sequentially during the spliceosomal splicing of one or more substrate RNAs, and which also contain the RNA substrate(s) from the initial target RNAs of splicing, the splicing intermediate RNA(s), to the final RNA products. During cis-splicing, the initial target RNA is a single, contiguous RNA transcript, whether mRNA, snoRNA, etc., and the released products are a spliced RNA and an excised intron, generally as a lariat structure. During trans-splicing, there are two initial substrate RNAs, the spliced leader RNA and a pre-mRNA. [GOC:editors, GOC:mah, ISBN:0198547684, PMID:19239890]
Full description |

Standard name | GO_U5_SNRNP
Systematic name | M17388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains small nuclear RNA U5. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_U7_SNRNP
Systematic name | M25640
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains the U7 snRNA and is required for the 3'-end processing of replication-dependent histone pre-mRNAs. [PMID:12872004]
Full description |

Standard name | GO_U2_TYPE_SPLICEOSOMAL_COMPLEX
Systematic name | M17071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any spliceosomal complex that forms during the splicing of a messenger RNA primary transcript to excise an intron that has canonical consensus sequences near the 5' and 3' ends. [GOC:krc, GOC:mah, PMID:11343900]
Full description |

Standard name | GO_U1_SNRNP
Systematic name | M17022
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains small nuclear RNA U1. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_U2_SNRNP
Systematic name | M17226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains small nuclear RNA U2. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_U4_SNRNP
Systematic name | M25641
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains small nuclear RNA U4. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_U6_SNRNP
Systematic name | M25642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains small nuclear RNA U6. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_U12_TYPE_SPLICEOSOMAL_COMPLEX
Systematic name | M19132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any spliceosomal complex that forms during the splicing of a messenger RNA primary transcript to excise an intron; the series of U12-type spliceosomal complexes is involved in the splicing of the majority of introns that contain atypical AT-AC terminal dinucleotides, as well as other non-canonical introns. The entire splice site signal, not just the terminal dinucleotides, is involved in determining which spliceosome utilizes the site. [GOC:krc, GOC:mah, PMID:11574683, PMID:11971955]
Full description |

Standard name | GO_TELOMERASE_HOLOENZYME_COMPLEX
Systematic name | M17066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Telomerase is a ribonucleoprotein enzyme complex, with a minimal catalytic core composed of a catalytic reverse transcriptase subunit and an RNA subunit that provides the template for telomeric DNA addition. In vivo, the holoenzyme complex often contains additional subunits. [PMID:11884619]
Full description |

Standard name | GO_NUCLEAR_EUCHROMATIN
Systematic name | M17354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The dispersed less dense form of chromatin in the interphase nucleus. It exists in at least two forms, a some being in the form of transcriptionally active chromatin which is the least condensed, while the rest is inactive euchromatin which is more condensed than active chromatin but less condensed than heterochromatin. [ISBN:0198506732]
Full description |

Standard name | GO_NUCLEAR_HETEROCHROMATIN
Systematic name | M17399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A condensed form of chromatin, occurring in the nucleus during interphase, that stains strongly with basophilic dyes. The DNA of heterochromatin is typically replicated at a later stage in the cell-division cycle than euchromatin. [ISBN:0198506732]
Full description |

Standard name | GO_PERICENTRIC_HETEROCHROMATIN
Systematic name | M17356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Heterochromatin that is located adjacent to the CENP-A rich centromere 'central core' and characterized by the modified histone H3K9me3. [PMID:12019236, PMID:20206496, PMID:22729156]
Full description |

Standard name | GO_PERICHROMATIN_FIBRILS
Systematic name | M25643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Structures of variable diameter visible in the nucleoplasm by electron microscopy, mainly observed near the border of condensed chromatin. The fibrils are enriched in RNA, and are believed to be sites of pre-mRNA splicing and polyadenylylation representing the in situ form of nascent transcripts. [PMID:14731598]
Full description |

Standard name | GO_NUCLEOLUS
Systematic name | M17699
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A small, dense body one or more of which are present in the nucleus of eukaryotic cells. It is rich in RNA and protein, is not bounded by a limiting membrane, and is not seen during mitosis. Its prime function is the transcription of the nucleolar DNA into 45S ribosomal-precursor RNA, the processing of this RNA into 5.8S, 18S, and 28S components of ribosomal RNA, and the association of these components with 5S RNA and proteins synthesized outside the nucleolus. This association results in the formation of ribonucleoprotein precursors; these pass into the cytoplasm and mature into the 40S and 60S subunits of the ribosome. [ISBN:0198506732]
Full description |

Standard name | GO_SMALL_NUCLEOLAR_RIBONUCLEOPROTEIN_COMPLEX
Systematic name | M17555
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains an RNA molecule of the small nucleolar RNA (snoRNA) family and associated proteins. Most are involved in a step of processing of rRNA: cleavage, 2'-O-methylation, or pseudouridylation. The majority, though not all, fall into one of two classes, box C/D type or box H/ACA type. [GOC:krc, GOC:mah, ISBN:0879695897]
Full description |

Standard name | GO_RNA_POLYMERASE_I_COMPLEX
Systematic name | M25644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | RNA polymerase I, one of three nuclear DNA-directed RNA polymerases found in all eukaryotes, is a multisubunit complex; typically it produces rRNAs. Two large subunits comprise the most conserved portion including the catalytic site and share similarity with other eukaryotic and bacterial multisubunit RNA polymerases. The remainder of the complex is composed of smaller subunits (generally ten or more), some of which are also found in RNA polymerase III and others of which are also found in RNA polymerases II and III. Although the core is competent to mediate ribonucleic acid synthesis, it requires additional factors to select the appropriate template. [GOC:krc, GOC:mtg_sensu]
Full description |

Standard name | GO_MITOCHONDRION
Systematic name | M8479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A semiautonomous, self replicating organelle that occurs in varying numbers, shapes, and sizes in the cytoplasm of virtually all eukaryotic cells. It is notably the site of tissue respiration. [GOC:giardia, ISBN:0198506732]
Full description |

Standard name | GO_MITOCHONDRIAL_ENVELOPE
Systematic name | M13651
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The double lipid bilayer enclosing the mitochondrion and separating its contents from the cell cytoplasm; includes the intermembrane space. [GOC:ai, GOC:pz]
Full description |

Standard name | GO_MITOCHONDRIAL_OUTER_MEMBRANE_TRANSLOCASE_COMPLEX
Systematic name | M25645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large complex of the mitochondrial outer membrane that mediates transport of proteins into all mitochondrial compartments. [PMID:12581629]
Full description |

Standard name | GO_TIM23_MITOCHONDRIAL_IMPORT_INNER_MEMBRANE_TRANSLOCASE_COMPLEX
Systematic name | M25646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The protein transport machinery of the mitochondrial inner membrane that typically transports proteins that possess a matrix-targeting N-terminal presequence. The TIM23 complex contains three essential Tim proteins: Tim17 and Tim23 are thought to build a preprotein translocation channel while Tim44 interacts transiently with the matrix heat-shock protein Hsp70 to form an ATP-driven import motor. [EC:7.4.2.3, PMID:27554484, PMID:8851659]
Full description |

Standard name | GO_MITOCHONDRIAL_RESPIRATORY_CHAIN_COMPLEX_IV
Systematic name | M25648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex located in the mitochondrial inner membrane that forms part of the mitochondrial respiratory chain. Contains the 13 polypeptide subunits of cytochrome c oxidase, including cytochrome a and cytochrome a3. Catalyzes the oxidation of reduced cytochrome c by dioxygen (O2). [GOC:mtg_sensu, ISBN:0198547684]
Full description |

Standard name | GO_MITOCHONDRIAL_MATRIX
Systematic name | M17305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The gel-like material, with considerable fine structure, that lies in the matrix space, or lumen, of a mitochondrion. It contains the enzymes of the tricarboxylic acid cycle and, in some organisms, the enzymes concerned with fatty acid oxidation. [GOC:as, ISBN:0198506732]
Full description |

Standard name | GO_MITOCHONDRIAL_LARGE_RIBOSOMAL_SUBUNIT
Systematic name | M29409
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The larger of the two subunits of a mitochondrial ribosome. Two sites on the ribosomal large subunit are involved in translation: the aminoacyl site (A site) and peptidyl site (P site). [GOC:mcc]
Full description |

Standard name | GO_MITOCHONDRIAL_SMALL_RIBOSOMAL_SUBUNIT
Systematic name | M29410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The smaller of the two subunits of a mitochondrial ribosome. [GOC:mcc]
Full description |

Standard name | GO_SECONDARY_LYSOSOME
Systematic name | M25649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Vacuole formed by the fusion of a lysosome with an organelle (autosome) or with a primary phagosome. [GOC:jl, ISBN:0815316194]
Full description |

Standard name | GO_ENDOSOME
Systematic name | M5343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A vacuole to which materials ingested by endocytosis are delivered. [ISBN:0198506732, PMID:19696797]
Full description |

Standard name | GO_EARLY_ENDOSOME
Systematic name | M9432
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-bounded organelle that receives incoming material from primary endocytic vesicles that have been generated by clathrin-dependent and clathrin-independent endocytosis; vesicles fuse with the early endosome to deliver cargo for sorting into recycling or degradation pathways. [GOC:mah, NIF_Subcellular:nlx_subcell_20090701, PMID:19696797]
Full description |

Standard name | GO_LATE_ENDOSOME
Systematic name | M4109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A prelysosomal endocytic organelle differentiated from early endosomes by lower lumenal pH and different protein composition. Late endosomes are more spherical than early endosomes and are mostly juxtanuclear, being concentrated near the microtubule organizing center. [NIF_Subcellular:nlx_subcell_20090702, PMID:11964142, PMID:2557062]
Full description |

Standard name | GO_MULTIVESICULAR_BODY
Systematic name | M16981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A type of endosome in which regions of the limiting endosomal membrane invaginate to form internal vesicles; membrane proteins that enter the internal vesicles are sequestered from the cytoplasm. [PMID:11566881, PMID:16533950]
Full description |

Standard name | GO_VACUOLE
Systematic name | M5245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A closed structure, found only in eukaryotic cells, that is completely surrounded by unit membrane and contains liquid material. Cells contain one or several vacuoles, that may have different functions from each other. Vacuoles have a diverse array of functions. They can act as a storage organelle for nutrients or waste products, as a degradative compartment, as a cost-effective way of increasing cell size, and as a homeostatic regulator controlling both turgor pressure and pH of the cytosol. [GOC:mtg_sensu, ISBN:0198506732]
Full description |

Standard name | GO_VACUOLAR_MEMBRANE
Systematic name | M10681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding the vacuole and separating its contents from the cytoplasm of the cell. [GOC:ai]
Full description |

Standard name | GO_VACUOLAR_LUMEN
Systematic name | M17446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed within the vacuolar membrane. [ISBN:0198506732]
Full description |

Standard name | GO_AUTOPHAGOSOME
Systematic name | M17052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A double-membrane-bounded compartment that engulfs endogenous cellular material as well as invading microorganisms to target them to the lytic vacuole/lysosome for degradation as part of macroautophagy. [GOC:autophagy, ISBN:0198547684, PMID:11099404]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM
Systematic name | M17743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The irregular network of unit membranes, visible only by electron microscopy, that occurs in the cytoplasm of many eukaryotic cells. The membranes form a complex meshwork of tubular channels, which are often expanded into slitlike cavities called cisternae. The ER takes two forms, rough (or granular), with ribosomes adhering to the outer surface, and smooth (with no ribosomes attached). [ISBN:0198506732]
Full description |

Standard name | GO_SEC61_TRANSLOCON_COMPLEX
Systematic name | M34344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A translocon complex that contains a core heterotrimer of conserved alpha, beta and gamma subunits, and may contain additional proteins (translocon-associated proteins or TRAPs); in budding yeast the core proteins are Sec61p, Sbh1p, and Sss1p. The Sec61 translocon complex functions in cotranslational and posttranslational translocation events. [GOC:mah, PMID:18166647]
Full description |

Standard name | GO_SIGNAL_RECOGNITION_PARTICLE_RECEPTOR_COMPLEX
Systematic name | M25650
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transmembrane heterodimeric protein located in the membrane of the rough endoplasmic reticulum. Both subunits contain GTPase domains with which signal recognition particle interacts. In the presence of GTP and SRP receptor, SRP is released from the ribosome-nascent chain complex. [ISBN:0198506732]
Full description |

Standard name | GO_SIGNAL_RECOGNITION_PARTICLE_ENDOPLASMIC_RETICULUM_TARGETING
Systematic name | M25651
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein particle of 325 kDa composed of a 7S (300 nucleotide) RNA molecule and a complex of six different polypeptides. This binds both to the N-terminal signal peptide for proteins destined for the endoplasmic reticulum as they emerge from the large ribosomal subunit and also to the ribosome. This binding arrests further translation thereby preventing the proteins from being released into the cytosol. The SRP-ribosome complex then diffuses to the endoplasmic reticulum where it is bound to the signal recognition particle receptor, which allows resumption of protein synthesis and facilitates the passage of the growing polypeptide chain through the translocon. Through a process involving GTP hydrolysis, the SRP-SRP receptor complex dissociates and SRP returns to the cytosol. Of the six polypeptides of SRP the 54 kDa subunit (SRP54) is the central player. It contains an N-terminal GTPase domain and a C-terminal domain that binds directly to the signal peptide and the SRP RNA. Examples of this component are found in Mus musculus, Saccharomyces cerevisiae and Arabidopsis thaliana. [GOC:mtg_sensu, ISBN:0198506732]
Full description |

Standard name | GO_SIGNAL_PEPTIDASE_COMPLEX
Systematic name | M25652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that is located in the endoplasmic reticulum membrane and cleaves the signal sequence from precursor proteins following their transport out of the cytoplasmic space. [GOC:sgd_curators, PMID:1846444, PMID:7615509]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_LUMEN
Systematic name | M17362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membranes of the endoplasmic reticulum. [ISBN:0198547684]
Full description |

Standard name | GO_SMOOTH_ENDOPLASMIC_RETICULUM
Systematic name | M17440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The smooth endoplasmic reticulum (smooth ER or SER) has no ribosomes attached to it. The smooth ER is the recipient of the proteins synthesized in the rough ER. Those proteins to be exported are passed to the Golgi complex, the resident proteins are returned to the rough ER and the lysosomal proteins after phosphorylation of their mannose residues are passed to the lysosomes. Glycosylation of the glycoproteins also continues. The smooth ER is the site of synthesis of lipids, including the phospholipids. The membranes of the smooth ER also contain enzymes that catalyze a series of reactions to detoxify both lipid-soluble drugs and harmful products of metabolism. Large quantities of certain compounds such as phenobarbital cause an increase in the amount of the smooth ER. [ISBN:0198506732]
Full description |

Standard name | GO_ROUGH_ENDOPLASMIC_RETICULUM
Systematic name | M17154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The rough (or granular) endoplasmic reticulum (ER) has ribosomes adhering to the outer surface; the ribosomes are the site of translation of the mRNA for those proteins which are either to be retained within the cisternae (ER-resident proteins), the proteins of the lysosomes, or the proteins destined for export from the cell. Glycoproteins undergo their initial glycosylation within the cisternae. [ISBN:0198506732]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_GOLGI_INTERMEDIATE_COMPARTMENT
Systematic name | M17626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex system of membrane-bounded compartments located between endoplasmic reticulum (ER) and the Golgi complex, with a distinctive membrane protein composition; involved in ER-to-Golgi and Golgi-to-ER transport. [GOC:pr, PMID:16723730]
Full description |

Standard name | GO_GOLGI_APPARATUS
Systematic name | M845
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-bound cytoplasmic organelle of the endomembrane system that further processes the core oligosaccharides (e.g. N-glycans) added to proteins in the endoplasmic reticulum and packages them into membrane-bound vesicles. The Golgi apparatus operates at the intersection of the secretory, lysosomal, and endocytic pathways. [ISBN:0198506732]
Full description |

Standard name | GO_GOLGI_STACK
Systematic name | M17108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The set of thin, flattened membrane-bounded compartments, called cisternae, that form the central portion of the Golgi complex. The stack usually comprises cis, medial, and trans cisternae; the cis- and trans-Golgi networks are not considered part of the stack. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_GOLGI_LUMEN
Systematic name | M17733
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membranes of any cisterna or subcompartment of the Golgi apparatus, including the cis- and trans-Golgi networks. [GOC:mah]
Full description |

Standard name | GO_GOLGI_MEDIAL_CISTERNA
Systematic name | M25653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The middle Golgi cisterna (or cisternae). [ISBN:0815316194]
Full description |

Standard name | GO_GOLGI_ASSOCIATED_VESICLE
Systematic name | M13692
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any vesicle associated with the Golgi complex and involved in mediating transport within the Golgi or between the Golgi and other parts of the cell. [GOC:mah]
Full description |

Standard name | GO_CIS_GOLGI_NETWORK
Systematic name | M17593
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The network of interconnected tubular and cisternal structures located at the convex side of the Golgi apparatus, which abuts the endoplasmic reticulum. [ISBN:0198506732, ISBN:0815316194]
Full description |

Standard name | GO_TRANS_GOLGI_NETWORK
Systematic name | M12470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The network of interconnected tubular and cisternal structures located within the Golgi apparatus on the side distal to the endoplasmic reticulum, from which secretory vesicles emerge. The trans-Golgi network is important in the later stages of protein secretion where it is thought to play a key role in the sorting and targeting of secreted proteins to the correct destination. [GOC:vw, ISBN:0815316194]
Full description |

Standard name | GO_LIPID_DROPLET
Systematic name | M25654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An intracellular non-membrane-bounded organelle comprising a matrix of coalesced lipids surrounded by a phospholipid monolayer. May include associated proteins. [GOC:mah, GOC:tb]
Full description |

Standard name | GO_CENTROSOME
Systematic name | M13292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structure comprised of a core structure (in most organisms, a pair of centrioles) and peripheral material from which a microtubule-based structure, such as a spindle apparatus, is organized. Centrosomes occur close to the nucleus during interphase in many eukaryotic cells, though in animal cells it changes continually during the cell-division cycle. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_CENTRIOLE
Systematic name | M17001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cellular organelle, found close to the nucleus in many eukaryotic cells, consisting of a small cylinder with microtubular walls, 300-500 nm long and 150-250 nm in diameter. It contains nine short, parallel, peripheral microtubular fibrils, each fibril consisting of one complete microtubule fused to two incomplete microtubules. Cells usually have two centrioles, lying at right angles to each other. At division, each pair of centrioles generates another pair and the twin pairs form the pole of the mitotic spindle. [ISBN:0198547684]
Full description |

Standard name | GO_MICROTUBULE_ORGANIZING_CENTER
Systematic name | M11772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An intracellular structure that can catalyze gamma-tubulin-dependent microtubule nucleation and that can anchor microtubules by interacting with their minus ends, plus ends or sides. [GOC:vw, ISBN:0815316194, PMID:17072892, PMID:17245416, Wikipedia:Microtubule_organizing_center]
Full description |

Standard name | GO_ASTER
Systematic name | M25655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An array of microtubules emanating from a spindle pole MTOC that do not connect to kinetochores. [GOC:clt]
Full description |

Standard name | GO_SPINDLE
Systematic name | M1682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The array of microtubules and associated molecules that forms between opposite poles of a eukaryotic cell during mitosis or meiosis and serves to move the duplicated chromosomes apart. [ISBN:0198547684]
Full description |

Standard name | GO_POLAR_MICROTUBULE
Systematic name | M25656
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the spindle microtubules that come from each pole and overlap at the spindle midzone. This interdigitating structure consisting of antiparallel microtubules is responsible for pushing the poles of the spindle apart. [ISBN:0815316194]
Full description |

Standard name | GO_KINETOCHORE_MICROTUBULE
Systematic name | M25657
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the spindle microtubules that attach to the kinetochores of chromosomes by their plus ends, and maneuver the chromosomes during mitotic or meiotic chromosome segregation. [ISBN:0815316194]
Full description |

Standard name | GO_CHAPERONIN_CONTAINING_T_COMPLEX
Systematic name | M25658
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit ring-shaped complex that mediates protein folding in the cytosol without a cofactor. [GOC:sgd_curators, PMID:11580267]
Full description |

Standard name | GO_HEMOGLOBIN_COMPLEX
Systematic name | M17493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An iron-containing, oxygen carrying complex. In vertebrates it is made up of two pairs of associated globin polypeptide chains, each chain carrying a noncovalently bound heme prosthetic group. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_HETEROTRIMERIC_G_PROTEIN_COMPLEX
Systematic name | M17360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of a family of heterotrimeric GTP-binding and hydrolyzing proteins; they belong to a superfamily of GTPases that includes monomeric proteins such as EF-Tu and RAS. Heterotrimeric G-proteins consist of three subunits; the alpha subunit contains the guanine nucleotide binding site and possesses GTPase activity; the beta and gamma subunits are tightly associated and function as a beta-gamma heterodimer; extrinsic plasma membrane proteins (cytoplasmic face) that function as a complex to transduce signals from G protein-coupled receptors to an effector protein. [ISBN:0198547684]
Full description |

Standard name | GO_PROTEASOME_CORE_COMPLEX
Systematic name | M25659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit barrel shaped endoprotease complex, which is the core of the proteasome complex. [GOC:rb, PMID:10806206]
Full description |

Standard name | GO_RIBOSOME
Systematic name | M17089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An intracellular organelle, about 200 A in diameter, consisting of RNA and protein. It is the site of protein biosynthesis resulting from translation of messenger RNA (mRNA). It consists of two subunits, one large and one small, each containing only protein and RNA. Both the ribosome and its subunits are characterized by their sedimentation coefficients, expressed in Svedberg units (symbol: S). Hence, the prokaryotic ribosome (70S) comprises a large (50S) subunit and a small (30S) subunit, while the eukaryotic ribosome (80S) comprises a large (60S) subunit and a small (40S) subunit. Two sites on the ribosomal large subunit are involved in translation, namely the aminoacyl site (A site) and peptidyl site (P site). Ribosomes from prokaryotes, eukaryotes, mitochondria, and chloroplasts have characteristically distinct ribosomal proteins. [ISBN:0198506732]
Full description |

Standard name | GO_POLYSOME
Systematic name | M17567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiribosomal structure representing a linear array of ribosomes held together by messenger RNA. They represent the active complexes in cellular protein synthesis and are able to incorporate amino acids into polypeptides both in vivo and in vitro. [ISBN:0198506732, NIF_Subcellular:sao1038025871]
Full description |

Standard name | GO_MRNA_CLEAVAGE_AND_POLYADENYLATION_SPECIFICITY_FACTOR_COMPLEX
Systematic name | M29411
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit complex that binds to the canonical AAUAAA hexamer and to U-rich upstream sequence elements on the pre-mRNA, thereby stimulating the otherwise weakly active and nonspecific polymerase to elongate efficiently RNAs containing a poly(A) signal. [PMID:14749727]
Full description |

Standard name | GO_MRNA_CLEAVAGE_FACTOR_COMPLEX
Systematic name | M17100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any macromolecular complex involved in cleavage or polyadenylation of mRNA molecules. [GOC:mah, PMID:10357856]
Full description |

Standard name | GO_EUKARYOTIC_TRANSLATION_INITIATION_FACTOR_2_COMPLEX
Systematic name | M25660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Complex of three heterogeneous polypeptide chains, that form a ternary complex with initiator methionyl-tRNA and GTP. This ternary complex binds to free 40S subunit, which subsequently binds the 5' end of mRNA. [PMID:10216940]
Full description |

Standard name | GO_EUKARYOTIC_TRANSLATION_INITIATION_FACTOR_2B_COMPLEX
Systematic name | M25661
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit guanine nucleotide exchange factor which catalyzes the exchange of GDP bound to initiation factor eIF2 for GTP, generating active eIF2-GTP. In humans, it is composed of five subunits, alpha, beta, delta, gamma and epsilon. [PMID:9438375]
Full description |

Standard name | GO_EUKARYOTIC_TRANSLATION_INITIATION_FACTOR_3_COMPLEX
Systematic name | M11411
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex of several polypeptides that plays at least two important roles in protein synthesis: First, eIF3 binds to the 40S ribosome and facilitates loading of the Met-tRNA/eIF2.GTP ternary complex to form the 43S preinitiation complex. Subsequently, eIF3 apparently assists eIF4 in recruiting mRNAs to the 43S complex. The eIF3 complex contains five conserved core subunits, and may contain several additional proteins; the non-core subunits are thought to mediate association of the complex with specific sets of mRNAs. [PMID:15904532]
Full description |

Standard name | GO_NASCENT_POLYPEPTIDE_ASSOCIATED_COMPLEX
Systematic name | M29412
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterodimeric protein complex that can reversibly bind to ribosomes, and is located in direct proximity to newly synthesized polypeptide chains as they emerge from the ribosome. [PMID:12475173, PMID:7568149]
Full description |

Standard name | GO_AXONEMAL_DYNEIN_COMPLEX
Systematic name | M17767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A dynein complex found in eukaryotic cilia and flagella; the motor domain heads interact with adjacent microtubules to generate a sliding force which is converted to a bending motion. [GOC:cilia, GOC:hla, GOC:krc, ISBN:0815316194]
Full description |

Standard name | GO_MUSCLE_MYOSIN_COMPLEX
Systematic name | M17009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A filament of myosin found in a muscle cell of any type. [GOC:mah]
Full description |

Standard name | GO_TROPONIN_COMPLEX
Systematic name | M25662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex of accessory proteins (typically troponin T, troponin I and troponin C) found associated with actin in muscle thin filaments; involved in calcium regulation of muscle contraction. [ISBN:0815316194]
Full description |

Standard name | GO_STRIATED_MUSCLE_THIN_FILAMENT
Systematic name | M34345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Filaments formed of actin and associated proteins; attached to Z discs at either end of sarcomeres in myofibrils. [ISBN:0815316194]
Full description |

Standard name | GO_CYTOPLASMIC_DYNEIN_COMPLEX
Systematic name | M17475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any dynein complex with a homodimeric dynein heavy chain core that catalyzes movement along a microtubule. Cytoplasmic dynein complexes participate in many cytoplasmic transport activities in eukaryotes, such as mRNA localization, intermediate filament transport, nuclear envelope breakdown, apoptosis, transport of centrosomal proteins, mitotic spindle assembly, virus transport, kinetochore functions, and movement of signaling and spindle checkpoint proteins. Some complexes participate in intraflagellar transport. Subunits associated with the dynein heavy chain mediate association between dynein heavy chain and cargoes, and may include light chains and light intermediate chains. [GOC:cilia, GOC:hla, GOC:krc, GOC:mah, PMID:12600311]
Full description |

Standard name | GO_DYNACTIN_COMPLEX
Systematic name | M25663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A 20S multiprotein assembly of total mass about 1.2 MDa that activates dynein-based activity in vivo. A large structural component of the complex is an actin-like 40 nm filament composed of actin-related protein, to which other components attach. [ISBN:0198506732]
Full description |

Standard name | GO_KINESIN_COMPLEX
Systematic name | M11018
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any complex that includes a dimer of molecules from the kinesin superfamily, a group of related proteins that contain an extended region of predicted alpha-helical coiled coil in the main chain that likely produces dimerization. The native complexes of several kinesin family members have also been shown to contain additional peptides, often designated light chains as all of the noncatalytic subunits that are currently known are smaller than the chain that contains the motor unit. Kinesin complexes generally possess a force-generating enzymatic activity, or motor, which converts the free energy of the gamma phosphate bond of ATP into mechanical work. [GOC:mah, http://www.proweb.org/kinesin//KinesinMotility.html, http://www.proweb.org/kinesin//KinesinStructure.html]
Full description |

Standard name | GO_MICROTUBULE
Systematic name | M4855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the long, generally straight, hollow tubes of internal diameter 12-15 nm and external diameter 24 nm found in a wide variety of eukaryotic cells; each consists (usually) of 13 protofilaments of polymeric tubulin, staggered in such a manner that the tubulin monomers are arranged in a helical pattern on the microtubular surface, and with the alpha/beta axes of the tubulin subunits parallel to the long axis of the tubule; exist in equilibrium with pool of tubulin monomers and can be rapidly assembled or disassembled in response to physiological stimuli; concerned with force generation, e.g. in the spindle. [ISBN:0879693568]
Full description |

Standard name | GO_MICROTUBULE_ASSOCIATED_COMPLEX
Systematic name | M4679
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any multimeric complex connected to a microtubule. [GOC:jl]
Full description |

Standard name | GO_SPINDLE_MICROTUBULE
Systematic name | M483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any microtubule that is part of a mitotic or meiotic spindle; anchored at one spindle pole. [ISBN:0815316194]
Full description |

Standard name | GO_AXONEMAL_MICROTUBULE
Systematic name | M25664
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A microtubule in the axoneme of a eukaryotic cilium or flagellum; an axoneme contains nine modified doublet microtubules, which may or may not surround a pair of single microtubules. [GOC:cilia, ISBN:0815316194]
Full description |

Standard name | GO_CYTOPLASMIC_MICROTUBULE
Systematic name | M17714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any microtubule in the cytoplasm of a cell. [GOC:mah]
Full description |

Standard name | GO_NEUROFILAMENT
Systematic name | M25665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A type of intermediate filament found in the core of neuronal axons. Neurofilaments are heteropolymers composed of three type IV polypeptides: NF-L, NF-M, and NF-H (for low, middle, and high molecular weight). Neurofilaments are responsible for the radial growth of an axon and determine axonal diameter. [ISBN:0198506732, ISBN:0716731363, ISBN:0815316194]
Full description |

Standard name | GO_ACTIN_FILAMENT
Systematic name | M6458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A filamentous structure formed of a two-stranded helical polymer of the protein actin and associated proteins. Actin filaments are a major component of the contractile apparatus of skeletal muscle and the microfilaments of the cytoskeleton of eukaryotic cells. The filaments, comprising polymerized globular actin molecules, appear as flexible structures with a diameter of 5-9 nm. They are organized into a variety of linear bundles, two-dimensional networks, and three dimensional gels. In the cytoskeleton they are most highly concentrated in the cortex of the cell just beneath the plasma membrane. [GOC:mah, ISBN:0198506732, PMID:10666339]
Full description |

Standard name | GO_ARP2_3_PROTEIN_COMPLEX
Systematic name | M17329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A stable protein complex that contains two actin-related proteins, Arp2 and Arp3, and five novel proteins (ARPC1-5), and functions in the nucleation of branched actin filaments. [GOC:jl, GOC:vw, PMID:12479800]
Full description |

Standard name | GO_SODIUM_POTASSIUM_EXCHANGING_ATPASE_COMPLEX
Systematic name | M17799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Sodium:potassium-exchanging ATPases are tetrameric proteins, consisting of two large alpha subunits and two smaller beta subunits. The alpha subunits bear the active site and penetrate the membrane, while the beta subunits carry oligosaccharide groups and face the cell exterior. [ISBN:0198506732]
Full description |

Standard name | GO_VOLTAGE_GATED_CALCIUM_CHANNEL_COMPLEX
Systematic name | M17010
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that forms a transmembrane channel through which calcium ions may pass in response to changes in membrane potential. [GOC:mah]
Full description |

Standard name | GO_ACETYLCHOLINE_GATED_CHANNEL_COMPLEX
Systematic name | M25666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A homo- or hetero-pentameric protein complex that forms a transmembrane channel through which ions may pass in response to acetylcholine binding. [GOC:bf, GOC:mah, PMID:12381728, PMID:15579462]
Full description |

Standard name | GO_CAVEOLA
Systematic name | M25668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane raft that forms small pit, depression, or invagination that communicates with the outside of a cell and extends inward, indenting the cytoplasm and the cell membrane. Examples include flask-shaped invaginations of the plasma membrane in adipocytes associated with caveolin proteins, and minute pits or incuppings of the cell membrane formed during pinocytosis. Caveolae may be pinched off to form free vesicles within the cytoplasm. [GOC:mah, ISBN:0721662544, PMID:16645198]
Full description |

Standard name | GO_MICROVILLUS
Systematic name | M17255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Thin cylindrical membrane-covered projections on the surface of an animal cell containing a core bundle of actin filaments. Present in especially large numbers on the absorptive surface of intestinal cells. [ISBN:0815316194]
Full description |

Standard name | GO_BRUSH_BORDER
Systematic name | M19093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The dense covering of microvilli on the apical surface of a epithelial cells in tissues such as the intestine, kidney, and choroid plexus; the microvilli aid absorption by increasing the surface area of the cell. [GOC:sl, ISBN:0815316194]
Full description |

Standard name | GO_CLATHRIN_COATED_PIT
Systematic name | M25669
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A part of the endomembrane system in the form of an invagination of a membrane upon which a clathrin coat forms, and that can be converted by vesicle budding into a clathrin-coated vesicle. Coated pits form on the plasma membrane, where they are involved in receptor-mediated selective transport of many proteins and other macromolecules across the cell membrane, in the trans-Golgi network, and on some endosomes. [GOC:mah, ISBN:0198506732, NIF_Subcellular:sao1969557946, PMID:10559856, PMID:17284835]
Full description |

Standard name | GO_CELL_CELL_JUNCTION
Systematic name | M15597
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell junction that forms a connection between two or more cells in a multicellular organism; excludes direct cytoplasmic intercellular bridges, such as ring canals in insects. [GOC:aruk, GOC:bc, GOC:dgh, GOC:hb, GOC:mah, PMID:21422226, PMID:28096264]
Full description |

Standard name | GO_ADHERENS_JUNCTION
Systematic name | M9849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell-cell junction composed of the epithelial cadherin-catenin complex. The epithelial cadherins, or E-cadherins, of each interacting cell extend through the plasma membrane into the extracellular space and bind to each other. The E-cadherins bind to catenins on the cytoplasmic side of the membrane, where the E-cadherin-catenin complex binds to cytoskeletal components and regulatory and signaling molecules. [GOC:aruk, GOC:bc, GOC:mah, ISBN:0198506732, PMID:17854762, PMID:20571587, PMID:21422226, PMID:28096264]
Full description |

Standard name | GO_ZONULA_ADHERENS
Systematic name | M25670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell-cell adherens junction which forms a continuous belt near the apex of epithelial cells. [ISBN:0815316208]
Full description |

Standard name | GO_FASCIA_ADHERENS
Systematic name | M25671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell-cell junction that contains the transmembrane protein N-cadherin, which interacts with identical molecules from neighbouring cells to form a tight mechanical intercellular link; forms a large portion of the intercalated disc, the structure at which myofibrils terminate in cardiomyocytes. [GOC:aruk, GOC:bc, GOC:mtg_muscle, PMID:11732910]
Full description |

Standard name | GO_GAP_JUNCTION
Systematic name | M17818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell-cell junction composed of pannexins or innexins and connexins, two different families of channel-forming proteins. [GOC:mah, GOC:mtg_muscle, ISBN:0815332181, PMID:22366062, Wikipedia:Gap_junction]
Full description |

Standard name | GO_CONNEXIN_COMPLEX
Systematic name | M25672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An assembly of six molecules of connexin, made in the Golgi apparatus and subsequently transported to the plasma membrane, where docking of two connexons on apposed plasma membranes across the extracellular space forms a gap junction. [PMID:11146276]
Full description |

Standard name | GO_CILIUM
Systematic name | M17760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized eukaryotic organelle that consists of a filiform extrusion of the cell surface and of some cytoplasmic parts. Each cilium is largely bounded by an extrusion of the cytoplasmic (plasma) membrane, and contains a regular longitudinal array of microtubules, anchored to a basal body. [GOC:cilia, GOC:curators, GOC:kmv, GOC:vw, ISBN:0198547684, PMID:16824949, PMID:17009929, PMID:20144998]
Full description |

Standard name | GO_CELL_CORTEX
Systematic name | M8798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of a cell that lies just beneath the plasma membrane and often, but not always, contains a network of actin filaments and associated proteins. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_KINASE_COMPLEX
Systematic name | M17549
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex capable of phosphatidylinositol 3-kinase activity and containing subunits of any phosphatidylinositol 3-kinase (PI3K) enzyme. These complexes are divided in three classes (called I, II and III) that differ for their presence across taxonomic groups and for the type of their constituents. Catalytic subunits of phosphatidylinositol 3-kinase enzymes are present in all 3 classes; regulatory subunits of phosphatidylinositol 3-kinase enzymes are present in classes I and III; adaptor proteins have been observed in class II complexes and may be present in other classes too. [GOC:bf, PMID:24587488]
Full description |

Standard name | GO_MITOCHONDRIAL_ALPHA_KETOGLUTARATE_DEHYDROGENASE_COMPLEX
Systematic name | M25673
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Mitochondrial complex that possesses alpha-ketoglutarate dehydrogenase activity. [GOC:mah, GOC:mtg_sensu]
Full description |

Standard name | GO_CAMP_DEPENDENT_PROTEIN_KINASE_COMPLEX
Systematic name | M25674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An enzyme complex, composed of regulatory and catalytic subunits, that catalyzes protein phosphorylation. Inactive forms of the enzyme have two regulatory chains and two catalytic chains; activation by cAMP produces two active catalytic monomers and a regulatory dimer. [EC:2.7.11.11, ISBN:0198506732]
Full description |

Standard name | GO_CALCIUM_AND_CALMODULIN_DEPENDENT_PROTEIN_KINASE_COMPLEX
Systematic name | M29414
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An enzyme complex which in eukaryotes is composed of four different chains: alpha, beta, gamma, and delta. The different isoforms assemble into homo- or heteromultimeric holoenzymes composed of 8 to 12 subunits. Catalyzes the phosphorylation of proteins to O-phosphoproteins. [EC:2.7.11.17]
Full description |

Standard name | GO_CALCINEURIN_COMPLEX
Systematic name | M25675
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterodimeric calcium ion and calmodulin dependent protein phosphatase composed of catalytic and regulatory subunits; the regulatory subunit is very similar in sequence to calmodulin. [PMID:26794871]
Full description |

Standard name | GO_PHOSPHORYLASE_KINASE_COMPLEX
Systematic name | M25676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An enzyme complex that catalyzes the phosphorylation of phosphorylase b to form phosphorylase a. [EC:2.7.11.19]
Full description |

Standard name | GO_MITOCHONDRIAL_PYRUVATE_DEHYDROGENASE_COMPLEX
Systematic name | M34346
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Complex that carries out the oxidative decarboxylation of pyruvate to form acetyl-CoA in eukaryotes; includes subunits possessing three catalytic activities: pyruvate dehydrogenase (E1), dihydrolipoamide S-acetyltransferase (E2), and dihydrolipoamide dehydrogenase (E3). The This Eukaryotic form usually contains more subunits than its bacterial counterpart; for example, one known complex contains 30 E1 dimers, 60 E2 monomers, and 6 E3 dimers as well as a few copies of pyruvate dehydrogenase kinase and pyruvate dehydrogenase phosphatase. [GOC:mtg_sensu, ISBN:0471331309, ISBN:0716720094]
Full description |

Standard name | GO_TRANSCRIPTION_ELONGATION_FACTOR_COMPLEX
Systematic name | M17724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that interacts with RNA polymerase II to increase (positive transcription elongation factor) or reduce (negative transcription elongation factor) the rate of transcription elongation. [GOC:jl]
Full description |

Standard name | GO_CYCLIN_CDK_POSITIVE_TRANSCRIPTION_ELONGATION_FACTOR_COMPLEX
Systematic name | M25677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transcription elongation factor complex that facilitates the transition from abortive to productive elongation by phosphorylating the CTD domain of the large subunit of DNA-directed RNA polymerase II, holoenzyme. Contains a cyclin and a cyclin-dependent protein kinase catalytic subunit. [GOC:bhm, GOC:vw, PMID:10766736, PMID:16721054, PMID:17079683, PMID:19328067, PMID:7759473]
Full description |

Standard name | GO_SPECTRIN
Systematic name | M25678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Membrane associated dimeric protein (240 and 220 kDa) of erythrocytes. Forms a complex with ankyrin, actin and probably other components of the membrane cytoskeleton, so that there is a mesh of proteins underlying the plasma membrane, potentially restricting the lateral mobility of integral proteins. [GOC:curators, ISBN:0815316194]
Full description |

Standard name | GO_COP9_SIGNALOSOME
Systematic name | M17460
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that catalyzes the deneddylation of proteins, including the cullin component of SCF ubiquitin E3 ligase; deneddylation increases the activity of cullin family ubiquitin ligases. The signalosome is involved in many regulatory process, including some which control development, in many species; also regulates photomorphogenesis in plants; in many species its subunits are highly similar to those of the proteasome. [PMID:11019806, PMID:12186635, PMID:14570571]
Full description |

Standard name | GO_OLIGOSACCHARYLTRANSFERASE_COMPLEX
Systematic name | M25679
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that is found in the endoplasmic reticulum membrane of eukaryotes and transfers lipid-linked oligosaccharide precursor to asparagine residues on nascent proteins. In yeast, the complex includes at least nine different subunits, whereas in mammalian cells at least three different forms of the complex have been detected. [ISBN:0879695595, PMID:15835887]
Full description |

Standard name | GO_COHESIN_COMPLEX
Systematic name | M17737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that is required for sister chromatid cohesion in eukaryotes. The cohesin complex forms a molecular ring complex, and is composed of structural maintenance of chromosomes (SMC) and kleisin proteins. For example, in yeast, the complex is composed of the SMC proteins Smc1p and Smc3p, and the kleisin protein Scc1p. In vertebrates, the complex is composed of the SMC1 (SMC1A or SMC1B) and SMC3 heterodimer attached via their hinge domains to a kleisin (RAD21, REC8 or RAD21L) which links them, and one STAG protein (STAG1, STAG2 or STAG3). [GOC:jl, GOC:sp, GOC:vw, PMID:9887095]
Full description |

Standard name | GO_F_ACTIN_CAPPING_PROTEIN_COMPLEX
Systematic name | M25681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterodimer consisting of alpha and beta subunits that binds to and caps the barbed ends of actin filaments, thereby regulating the polymerization of actin monomers but not severing actin filaments. [GOC:go_curators, ISBN:0198599560]
Full description |

Standard name | GO_IKAPPAB_KINASE_COMPLEX
Systematic name | M17634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A trimeric protein complex that phosphorylates inhibitory-kappaB (I-kappaB) proteins. The complex is composed of two kinase subunits (alpha and beta) and a regulatory gamma subunit (also called NEMO). In a resting state, NF-kappaB dimers are bound to inhibitory IKB proteins, sequestering NF-kappaB in the cytoplasm. Phosphorylation of I-kappaB targets I-kappaB for ubiquitination and proteasomal degradation, thus releasing the NF-kappaB dimers, which can translocate to the nucleus to bind DNA and regulate transcription. [GOC:bf, GOC:ma, PMID:12055104, PMID:20300203]
Full description |

Standard name | GO_PROTEASOME_REGULATORY_PARTICLE_BASE_SUBCOMPLEX
Systematic name | M17087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The subcomplex of the proteasome regulatory particle that directly associates with the proteasome core complex. [GOC:mtg_sensu, GOC:rb]
Full description |

Standard name | GO_PROTEASOME_REGULATORY_PARTICLE_LID_SUBCOMPLEX
Systematic name | M25682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The subcomplex of the proteasome regulatory particle that forms the peripheral lid, which is added on top of the base subcomplex. [GOC:rb]
Full description |

Standard name | GO_EPSILON_DNA_POLYMERASE_COMPLEX
Systematic name | M25683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterotetrameric DNA polymerase complex that catalyzes processive DNA synthesis in the absence of PCNA, but is further stimulated in the presence of PCNA. The complex contains a large catalytic subunit and three small subunits, and is best characterized in Saccharomyces, in which the subunits are named Pol2p, Dpb2p, Dpb3p, and Dpb4p. Some evidence suggests that DNA polymerase epsilon is the leading strand polymerase; it is also involved in nucleotide-excision repair and mismatch repair. [PMID:15814431, PMID:9745046]
Full description |

Standard name | GO_NUCLEOID
Systematic name | M17028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of a virus, bacterial cell, mitochondrion or chloroplast to which the nucleic acid is confined. [GOC:bm, GOC:ma, ISBN:3540076689]
Full description |

Standard name | GO_EXTERNAL_SIDE_OF_PLASMA_MEMBRANE
Systematic name | M2251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The leaflet of the plasma membrane that faces away from the cytoplasm and any proteins embedded or anchored in it or attached to its surface. [GOC:dos, GOC:tb]
Full description |

Standard name | GO_BASAL_PLASMA_MEMBRANE
Systematic name | M17186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of the plasma membrane located at the basal end of the cell. Often used in reference to animal polarized epithelial membranes, where the basal membrane is the part attached to the extracellular matrix, or in plant cells, where the basal membrane is defined with respect to the zygotic axis. [GOC:go_curators]
Full description |

Standard name | GO_CELL_SURFACE
Systematic name | M11182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The external part of the cell wall and/or plasma membrane. [GOC:jl, GOC:mtg_sensu, GOC:sm]
Full description |

Standard name | GO_ENDOSOME_MEMBRANE
Systematic name | M29415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding an endosome. [GOC:mah]
Full description |

Standard name | GO_CHROMOCENTER
Systematic name | M17540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A region in which centric, heterochromatic portions of one or more chromosomes form a compact structure. [PMID:12384572, PMID:15053486, PMID:16831888]
Full description |

Standard name | GO_CYTOPLASMIC_STRESS_GRANULE
Systematic name | M17039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A dense aggregation in the cytosol composed of proteins and RNAs that appear when the cell is under stress. [GOC:ans, PMID:17284590, PMID:17601829, PMID:17967451, PMID:20368989]
Full description |

Standard name | GO_VESICLE_MEMBRANE
Systematic name | M8772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding any membrane-bounded vesicle in the cell. [GOC:mah, GOC:vesicle]
Full description |

Standard name | GO_ER_TO_GOLGI_TRANSPORT_VESICLE_MEMBRANE
Systematic name | M17451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a vesicle transporting substances from the endoplasmic reticulum to the Golgi. [GOC:ai, GOC:ascb_2009, GOC:dph, GOC:tb]
Full description |

Standard name | GO_TRANS_GOLGI_NETWORK_TRANSPORT_VESICLE_MEMBRANE
Systematic name | M17056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a vesicle transporting substances between the trans-Golgi network and other parts of the cell. [GOC:ai]
Full description |

Standard name | GO_JUNCTIONAL_SARCOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M25684
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The part of the sarcoplasmic reticulum membrane that contains calcium release channels, is devoted to calcium release and is juxtaposed to transverse tubule membrane. The junctional sarcoplasmic reticulum membrane consists of the junctional region of the terminal cisterna membrane. [GOC:mtg_muscle]
Full description |

Standard name | GO_INTERCALATED_DISC
Systematic name | M17058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex cell-cell junction at which myofibrils terminate in cardiomyocytes; mediates mechanical and electrochemical integration between individual cardiomyocytes. The intercalated disc contains regions of tight mechanical attachment (fasciae adherentes and desmosomes) and electrical coupling (gap junctions) between adjacent cells. [GOC:mtg_muscle, PMID:11732910]
Full description |

Standard name | GO_SPECTRIN_ASSOCIATED_CYTOSKELETON
Systematic name | M25685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The part of the cytoskeleton composed of spectrin, protein 4.1 and ankyrin. Spectrin-associated cytoskeleton is associated with the plasma membrane. [GOC:mtg_muscle, PMID:15970557]
Full description |

Standard name | GO_CAJAL_BODY
Systematic name | M17153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A class of nuclear body, first seen after silver staining by Ramon y Cajal in 1903, enriched in small nuclear ribonucleoproteins, and certain general RNA polymerase II transcription factors; ultrastructurally, they appear as a tangle of coiled, electron-dense threads roughly 0.5 micrometers in diameter; involved in aspects of snRNP biogenesis; the protein coilin serves as a marker for Cajal bodies. Some argue that Cajal bodies are the sites for preassembly of transcriptosomes, unitary particles involved in transcription and processing of RNA. [NIF_Subcellular:nlx_subcell_090901, PMID:10944589, PMID:11031238, PMID:7559785]
Full description |

Standard name | GO_ACTIN_CYTOSKELETON
Systematic name | M5272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The part of the cytoskeleton (the internal framework of a cell) composed of actin and associated proteins. Includes actin cytoskeleton-associated complexes. [GOC:jl, ISBN:0395825172, ISBN:0815316194]
Full description |

Standard name | GO_MICROTUBULE_CYTOSKELETON
Systematic name | M8300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The part of the cytoskeleton (the internal framework of a cell) composed of microtubules and associated proteins. [GOC:jl, ISBN:0395825172]
Full description |

Standard name | GO_LARGE_RIBOSOMAL_SUBUNIT
Systematic name | M17053
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The larger of the two subunits of a ribosome. Two sites on the ribosomal large subunit are involved in translation, namely the aminoacyl site (A site) and peptidyl site (P site). [ISBN:0198506732]
Full description |

Standard name | GO_SMALL_RIBOSOMAL_SUBUNIT
Systematic name | M17241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The smaller of the two subunits of a ribosome. [GOC:mah]
Full description |

Standard name | GO_DYSTROGLYCAN_COMPLEX
Systematic name | M25686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that includes alpha- and beta-dystroglycan, which are alternative products of the same gene; the laminin-binding component of the dystrophin-associated glycoprotein complex, providing a link between the subsarcolemmal cytoskeleton (in muscle cells) and the extracellular matrix. Alpha-dystroglycan is an extracellular protein binding to alpha-laminin and to beta-dystroglycan; beta-dystroglycan is a transmembrane protein which binds alpha-dystroglycan and dystrophin. [PMID:15117830, PMID:16710609]
Full description |

Standard name | GO_INCLUSION_BODY
Systematic name | M17131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A discrete intracellular part formed of aggregated molecules such as proteins or other biopolymers. [GOC:mah, PMID:11121744]
Full description |

Standard name | GO_AGGRESOME
Systematic name | M16980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An inclusion body formed by dynein-dependent retrograde transport of an aggregated protein on microtubules. [PMID:11121744]
Full description |

Standard name | GO_PREFOLDIN_COMPLEX
Systematic name | M25687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit chaperone that is capable of delivering unfolded proteins to cytosolic chaperonin, which it acts as a cofactor for. In humans, the complex is a heterohexamer of two PFD-alpha and four PFD-beta type subunits. In Saccharomyces cerevisiae, it also acts in the nucleus to regulate the rate of elongation by RNA polymerase II via a direct effect on histone dynamics. [GOC:jl, PMID:17384227, PMID:24068951, PMID:9630229]
Full description |

Standard name | GO_EUKARYOTIC_TRANSLATION_INITIATION_FACTOR_4F_COMPLEX
Systematic name | M25688
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The eukaryotic translation initiation factor 4F complex is composed of eIF4E, eIF4A and eIF4G; it is involved in the recognition of the mRNA cap, ATP-dependent unwinding of the 5'-terminal secondary structure and recruitment of the mRNA to the ribosome. [GOC:hb, PMID:8449919]
Full description |

Standard name | GO_BASOLATERAL_PLASMA_MEMBRANE
Systematic name | M3406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of the plasma membrane that includes the basal end and sides of the cell. Often used in reference to animal polarized epithelial membranes, where the basal membrane is the part attached to the extracellular matrix, or in plant cells, where the basal membrane is defined with respect to the zygotic axis. [GOC:go_curators]
Full description |

Standard name | GO_APICAL_PLASMA_MEMBRANE
Systematic name | M1446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of the plasma membrane located at the apical end of the cell. [GOC:curators]
Full description |

Standard name | GO_APICOLATERAL_PLASMA_MEMBRANE
Systematic name | M13985
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The apical end of the lateral plasma membrane of epithelial cells. [GOC:hb]
Full description |

Standard name | GO_LATERAL_PLASMA_MEMBRANE
Systematic name | M17364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane at the lateral side of the cell. In epithelial cells, lateral plasma membranes are on the sides of cells which lie at the interface of adjacent cells. [GOC:hb, GOC:mah, GOC:pr]
Full description |

Standard name | GO_CATENIN_COMPLEX
Systematic name | M25689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Complex of peripheral cytoplasmic proteins (alpha-, beta- and gamma-catenin) that interact with the cytoplasmic region of uvomorulin/E-cadherin to connect it to the actin cytoskeleton. [ISBN:0198599323]
Full description |

Standard name | GO_NUCLEAR_MATRIX
Systematic name | M17603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The dense fibrillar network lying on the inner side of the nuclear membrane. [ISBN:0582227089]
Full description |

Standard name | GO_MYOSIN_COMPLEX
Systematic name | M5442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex, formed of one or more myosin heavy chains plus associated light chains and other proteins, that functions as a molecular motor; uses the energy of ATP hydrolysis to move actin filaments or to move vesicles or other cargo on fixed actin filaments; has magnesium-ATPase activity and binds actin. Myosin classes are distinguished based on sequence features of the motor, or head, domain, but also have distinct tail regions that are believed to bind specific cargoes. [GOC:mah, Wikipedia:Myosin]
Full description |

Standard name | GO_MYOSIN_II_COMPLEX
Systematic name | M17709
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A myosin complex containing two class II myosin heavy chains, two myosin essential light chains and two myosin regulatory light chains. Also known as classical myosin or conventional myosin, the myosin II class includes the major muscle myosin of vertebrate and invertebrate muscle, and is characterized by alpha-helical coiled coil tails that self assemble to form a variety of filament structures. [Wikipedia:Myosin]
Full description |

Standard name | GO_UNCONVENTIONAL_MYOSIN_COMPLEX
Systematic name | M25690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A portmanteau term for myosins other than myosin II. [GOC:ma]
Full description |

Standard name | GO_PROTON_TRANSPORTING_TWO_SECTOR_ATPASE_COMPLEX
Systematic name | M18990
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large protein complex that catalyzes the synthesis or hydrolysis of ATP by a rotational mechanism, coupled to the transport of protons across a membrane. The complex comprises a membrane sector (F0, V0, or A0) that carries out proton transport and a cytoplasmic compartment sector (F1, V1, or A1) that catalyzes ATP synthesis or hydrolysis. Two major types have been characterized: V-type ATPases couple ATP hydrolysis to the transport of protons across a concentration gradient, whereas F-type ATPases, also known as ATP synthases, normally run in the reverse direction to utilize energy from a proton concentration or electrochemical gradient to synthesize ATP. A third type, A-type ATPases have been found in archaea, and are closely related to eukaryotic V-type ATPases but are reversible. [GOC:mah, ISBN:0716743663, PMID:16691483]
Full description |

Standard name | GO_VACUOLAR_PROTON_TRANSPORTING_V_TYPE_ATPASE_COMPLEX
Systematic name | M17156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A proton-transporting two-sector ATPase complex found in the vacuolar membrane, where it acts as a proton pump to mediate acidification of the vacuolar lumen. [GOC:mah, ISBN:0716743663, PMID:16449553]
Full description |

Standard name | GO_SWI_SNF_COMPLEX
Systematic name | M17713
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A SWI/SNF-type complex that contains 8 to 14 proteins, including both conserved (core) and nonconserved components; contains the ATPase product of the yeast SNF2 or mammalian SMARCA4/BAF190A/BRG1 gene, or an ortholog thereof. [GOC:bhm, PMID:12672490]
Full description |

Standard name | GO_SARCOPLASM
Systematic name | M17544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The cytoplasm of a muscle cell; includes the sarcoplasmic reticulum. [ISBN:0198547684]
Full description |

Standard name | GO_SIN3_COMPLEX
Systematic name | M17382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiprotein complex that functions broadly in eukaryotic organisms as a transcriptional repressor of protein-coding genes, through the gene-specific deacetylation of histones. Amongst its subunits, the Sin3 complex contains Sin3-like proteins, and a number of core proteins that are shared with the NuRD complex (including histone deacetylases and histone binding proteins). The Sin3 complex does not directly bind DNA itself, but is targeted to specific genes through protein-protein interactions with DNA-binding proteins. [PMID:10589671, PMID:11743021, PMID:12865422]
Full description |

Standard name | GO_NURD_COMPLEX
Systematic name | M25691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An approximately 2 MDa multi-subunit complex that exhibits ATP-dependent chromatin remodeling activity in addition to histone deacetylase (HDAC) activity, and has been shown to establish transcriptional repression of a number of target genes in vertebrates, invertebrates and fungi. Amongst its subunits, the NuRD complex contains histone deacetylases, histone binding proteins and Mi-2-like proteins. [PMID:10589671, PMID:11743021, PMID:17289569]
Full description |

Standard name | GO_NURF_COMPLEX
Systematic name | M25692
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An ISWI complex that contains an ATPase subunit of the ISWI family (SNF2L in mammals), a NURF301 homolog (BPTF in humans), and additional subunits, though the composition of these additional subunits varies slightly with species. NURF is involved in regulation of transcription from TRNA polymerase II promoters. [GOC:bf, GOC:krc, PMID:10779516, PMID:11279013, PMID:15284901, PMID:16568949, PMID:21810179]
Full description |

Standard name | GO_RNA_POLYMERASE_II_HOLOENZYME
Systematic name | M25693
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A nuclear DNA-directed RNA polymerase complex containing an RNA polymerase II core enzyme as well as additional proteins and transcription factor complexes, that are capable of promoter recognition and transcription initiation from an RNA polymerase II promoter in vivo. These additional components may include general transcription factor complexes TFIIA, TFIID, TFIIE, TFIIF, or TFIIH, as well as Mediator, SWI/SNF, GCN5, or SRBs and confer the ability to recognize promoters. [GOC:jl, GOC:krc, PMID:16858867, Wikipedia:Rna_polymerase_ii]
Full description |

Standard name | GO_MEDIATOR_COMPLEX
Systematic name | M17759
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that interacts with the carboxy-terminal domain of the largest subunit of RNA polymerase II and plays an active role in transducing the signal from a transcription factor to the transcriptional machinery. The mediator complex is required for activation of transcription of most protein-coding genes, but can also act as a transcriptional corepressor. The Saccharomyces complex contains several identifiable subcomplexes: a head domain comprising Srb2, -4, and -5, Med6, -8, and -11, and Rox3 proteins; a middle domain comprising Med1, -4, and -7, Nut1 and -2, Cse2, Rgr1, Soh1, and Srb7 proteins; a tail consisting of Gal11p, Med2p, Pgd1p, and Sin4p; and a regulatory subcomplex comprising Ssn2, -3, and -8, and Srb8 proteins. Metazoan mediator complexes have similar modular structures and include homologs of yeast Srb and Med proteins. [PMID:11454195, PMID:16168358, PMID:17870225]
Full description |

Standard name | GO_CDC73_PAF1_COMPLEX
Systematic name | M25694
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiprotein complex that associates with RNA polymerase II and general RNA polymerase II transcription factor complexes and may be involved in both transcriptional initiation and elongation. In Saccharomyces the complex contains Paf1p, Cdc73p, Ctr9p, Rtf1p, and Leo1p. [PMID:11884586]
Full description |

Standard name | GO_FLOTILLIN_COMPLEX
Systematic name | M25695
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains flotillin-1 and flotillin-2, and may contain associated proteins. Flotillins associate into membrane microdomains resembling caveolae. [PMID:17206938, PMID:17600709]
Full description |

Standard name | GO_NUCLEAR_BODY
Systematic name | M17188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Extra-nucleolar nuclear domains usually visualized by confocal microscopy and fluorescent antibodies to specific proteins. [GOC:ma, PMID:10330182]
Full description |

Standard name | GO_PML_BODY
Systematic name | M17259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A class of nuclear body; they react against SP100 auto-antibodies (PML, promyelocytic leukemia); cells typically contain 10-30 PML bodies per nucleus; alterations in the localization of PML bodies occurs after viral infection. [GOC:ma, PMID:10944585]
Full description |

Standard name | GO_NUCLEAR_SPECK
Systematic name | M17120
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A discrete extra-nucleolar subnuclear domain, 20-50 in number, in which splicing factors are seen to be localized by immunofluorescence microscopy. [http://www.cellnucleus.com/]
Full description |

Standard name | GO_TRANSCRIPTION_REPRESSOR_COMPLEX
Systematic name | M17288
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that possesses activity that prevents or downregulates transcription. [GOC:mah]
Full description |

Standard name | GO_AMINOACYL_TRNA_SYNTHETASE_MULTIENZYME_COMPLEX
Systematic name | M25697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multienzyme complex found in all multicellular eukaryotes composed of eight proteins with aminoacyl-tRNA synthetase activities (abbreviated as: ArgRS, AspRS, GluProRS, GlnRS, IleRS, LeuRS, LysRS, MetRS where RS is the enzyme, preceded by the amino acid it uses as a substrate) as well as three non-synthetase proteins (p43, p38, and p18) with diverse functions. Several of these subunits are known dimers, so the total polypeptide count in the multisynthetase complex is at least fifteen. All of the enzymes in this assembly catalyze the same reaction, the covalent attachment of an amino acid to either the 2'- or 3'-hydroxyl of the 3'-terminal adenosine of tRNA, but using different substrates. [GOC:jl, PMID:16169847]
Full description |

Standard name | GO_GOLGI_TRANSPORT_COMPLEX
Systematic name | M17585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit tethering complex of the CATCHR family (complexes associated with tethering containing helical rods) that has a role in tethering vesicles to the Golgi prior to fusion. Composed of 8 subunits COG1-8. [GOC:krc, PMID:11980916, PMID:20972446, PMID:9792665]
Full description |

Standard name | GO_NMDA_SELECTIVE_GLUTAMATE_RECEPTOR_COMPLEX
Systematic name | M17272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An assembly of four or five subunits which form a structure with an extracellular N-terminus and a large loop that together form the ligand binding domain. The C-terminus is intracellular. The ionotropic glutamate receptor complex itself acts as a ligand gated ion channel; on binding glutamate, charged ions pass through a channel in the center of the receptor complex. NMDA receptors are composed of assemblies of NR1 subunits (Figure 3) and NR2 subunits, which can be one of four separate gene products (NR2A-D). Expression of both subunits are required to form functional channels. The glutamate binding domain is formed at the junction of NR1 and NR2 subunits. NMDA receptors are permeable to calcium ions as well as being permeable to other ions. Thus NMDA receptor activation leads to a calcium influx into the post-synaptic cells, a signal thought to be crucial for the induction of NMDA-receptor dependent LTP and LTD. [http://www.bris.ac.uk/Depts/Synaptic/info/glutamate.html]
Full description |

Standard name | GO_HOST_CELLULAR_COMPONENT
Systematic name | M29417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any cellular component of a host cell. The host is an organism in which another organism, for instance a parasite or symbiont, spends part or all of its life cycle and from which it obtains nourishment and/or protection. [ISBN:0198506732]
Full description |

Standard name | GO_SCF_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M17110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex in which a cullin from the Cul1 subfamily and a RING domain protein form the catalytic core; substrate specificity is conferred by a Skp1 adaptor and an F-box protein. SCF complexes are involved in targeting proteins for degradation by the proteasome. The best characterized complexes are those from yeast and mammals (with core subunits named Cdc53/Cul1, Rbx1/Hrt1/Roc1). [PMID:15571813, PMID:15688063]
Full description |

Standard name | GO_PROTEASOME_CORE_COMPLEX_ALPHA_SUBUNIT_COMPLEX
Systematic name | M25698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The proteasome core subcomplex that constitutes the two outer rings of the proteasome core complex. An example of this component is found in Mus musculus. [GOC:jl, GOC:mtg_sensu, GOC:rb, PMID:10854779]
Full description |

Standard name | GO_PROTEASOME_CORE_COMPLEX_BETA_SUBUNIT_COMPLEX
Systematic name | M25699
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The proteasome core subcomplex that constitutes the two inner rings of the proteasome core complex. An example of this component is found in Mus musculus. [GOC:jl, GOC:mtg_sensu, GOC:rb, PMID:10854779]
Full description |

Standard name | GO_IMMUNOGLOBULIN_COMPLEX
Systematic name | M17554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that in its canonical form is composed of two identical immunoglobulin heavy chains and two identical immunoglobulin light chains, held together by disulfide bonds and sometimes complexed with additional proteins. An immunoglobulin complex may be embedded in the plasma membrane or present in the extracellular space, in mucosal areas or other tissues, or circulating in the blood or lymph. [GOC:add, GOC:jl, ISBN:0781765196]
Full description |

Standard name | GO_ORGANELLE_INNER_MEMBRANE
Systematic name | M17332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The inner, i.e. lumen-facing, lipid bilayer of an organelle envelope; usually highly selective to most ions and metabolites. [GOC:mah]
Full description |

Standard name | GO_OUTER_MEMBRANE
Systematic name | M7188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The external membrane of Gram-negative bacteria or certain organelles such as mitochondria and chloroplasts; freely permeable to most ions and metabolites. [GOC:go_curators]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_PLASMA_MEMBRANE
Systematic name | M17762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of a plasma membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:curators, GOC:dos]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_MEMBRANE
Systematic name | M17719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of a membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:dos, GOC:jl, GOC:mah]
Full description |

Standard name | GO_NUCLEAR_CYCLIN_DEPENDENT_PROTEIN_KINASE_HOLOENZYME_COMPLEX
Systematic name | M17127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Cyclin-dependent protein kinase (CDK) complex found in the nucleus. [GOC:krc]
Full description |

Standard name | GO_PROTEASOME_ACCESSORY_COMPLEX
Systematic name | M17780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex, that caps one or both ends of the proteasome core complex and regulates entry into, or exit from, the proteasome core complex. [GOC:mtg_sensu]
Full description |

Standard name | GO_CYTOSOLIC_LARGE_RIBOSOMAL_SUBUNIT
Systematic name | M17339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The large subunit of a ribosome located in the cytosol. [GOC:mtg_sensu]
Full description |

Standard name | GO_CYTOSOLIC_RIBOSOME
Systematic name | M17781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribosome located in the cytosol. [GOC:mtg_sensu]
Full description |

Standard name | GO_CYTOSOLIC_SMALL_RIBOSOMAL_SUBUNIT
Systematic name | M17218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The small subunit of a ribosome located in the cytosol. [GOC:mtg_sensu]
Full description |

Standard name | GO_TRAPP_COMPLEX
Systematic name | M25700
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large complex that acts as a tethering factor involved in transporting vesicles from the ER through the Golgi to the plasma membrane. A TRAPP (transport protein particle) complex has a core set of proteins which are joined by specific subunits depending on the cellular component where a given TRAPP complex is active. [GOC:bhm, GOC:vw, PMID:22669257]
Full description |

Standard name | GO_CCR4_NOT_COMPLEX
Systematic name | M17207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The Ccr4-Not complex is an eukaryotically conserved deadenylase that can initiate cytoplasmic mRNA decay, and reduce translation by releasing poly(A)-binding protein (Pab1/PABPC1). Ccr4-Not contains seven core subunits, including two poly(A)-specific exonucleases, Ccr4/CNOT6/CNOT6L and Caf1/Pop2/CNOT7/CNOT8. [GOC:sart, PMID:11113136, PMID:11239395, PMID:22785621, PMID:30601114]
Full description |

Standard name | GO_CCR4_NOT_CORE_COMPLEX
Systematic name | M25701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The core of the CCR4-NOT complex. In Saccharomyces the CCR4-NOT core complex comprises Ccr4p, Caf1p, Caf40p, Caf130p, Not1p, Not2p, Not3p, Not4p, and Not5p. [GOC:sart, PMID:11113136]
Full description |

Standard name | GO_LAMELLIPODIUM
Systematic name | M1730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A thin sheetlike process extended by the leading edge of a migrating cell or extending cell process; contains a dense meshwork of actin filaments. [ISBN:0815316194]
Full description |

Standard name | GO_CELL_SUBSTRATE_JUNCTION
Systematic name | M3539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell junction that forms a connection between a cell and the extracellular matrix. [GOC:aruk, GOC:bc, GOC:hb, GOC:mah, PMID:10419689, PMID:1643657, PMID:16805308, PMID:26923917, PMID:8314002]
Full description |

Standard name | GO_HEMIDESMOSOME
Systematic name | M25702
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell-substrate junction (attachment structure) found in epithelial cells that links intermediate filaments to extracellular matrices via transmembrane complexes. In vertebrates, hemidesmosomes mediate contact between the basal side of epithelial cells and the basal lamina. In C. elegans, hemidesmosomes connect epithelial cells to distinct extracellular matrices on both the apical and basal cell surfaces. [GOC:kmv, ISBN:0815316208, PMID:20205195]
Full description |

Standard name | GO_DESMOSOME
Systematic name | M17581
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell-cell junction in which: on the cytoplasmic surface of each interacting plasma membrane is a dense plaque composed of a mixture of intracellular anchor proteins; a bundle of keratin intermediate filaments is attached to the surface of each plaque; transmembrane adhesion proteins of the cadherin family bind to the plaques and interact through their extracellular domains to hold the adjacent membranes together by a Ca2+-dependent mechanism. [GOC:mah, GOC:mtg_muscle, ISBN:0815332181]
Full description |

Standard name | GO_MITOCHONDRIAL_CRISTA
Systematic name | M25703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the inward folds of the mitochondrial inner membrane. Their number, extent, and shape differ in mitochondria from different tissues and organisms. They appear to be devices for increasing the surface area of the mitochondrial inner membrane, where the enzymes of electron transport and oxidative phosphorylation are found. Their shape can vary with the respiratory state of the mitochondria. [ISBN:0198506732]
Full description |

Standard name | GO_MITOCHONDRIAL_TRICARBOXYLIC_ACID_CYCLE_ENZYME_COMPLEX
Systematic name | M25704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the heteromeric enzymes, located in the mitochondrion, that act in the tricarboxylic acid (TCA) cycle. [GOC:mah, GOC:mtg_sensu]
Full description |

Standard name | GO_MEMBRANE_COAT
Systematic name | M3007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of several different proteinaceous coats that can associate with membranes. Membrane coats include those formed by clathrin plus an adaptor complex, the COPI and COPII complexes, and possibly others. They are found associated with membranes on many vesicles as well as other membrane features such as pits and perhaps tubules. [GOC:mah]
Full description |

Standard name | GO_CLATHRIN_COAT
Systematic name | M17185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane coat found on coated pits and some coated vesicles; consists of polymerized clathrin triskelions, each comprising three clathrin heavy chains and three clathrin light chains, linked to the membrane via one of the AP adaptor complexes. [GOC:mah, PMID:11252894, PMID:9531549]
Full description |

Standard name | GO_AP_TYPE_MEMBRANE_COAT_ADAPTOR_COMPLEX
Systematic name | M17707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of several heterotetrameric complexes that link clathrin (or another coat-forming molecule, as hypothesized for AP-3 and AP-4) to a membrane surface; they are found on coated pits and coated vesicles, and mediate sorting of cargo proteins into vesicles. Each AP complex contains two large (a beta and one of either an alpha, gamma, delta, or epsilon) subunits (110-130 kDa), a medium (mu) subunit (approximately 50 kDa), and a small (sigma) subunit (15-20 kDa). [GOC:mah, PMID:10611976, PMID:15473838]
Full description |

Standard name | GO_VESICLE_COAT
Systematic name | M13876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane coat found on a coated vesicle. [GOC:mah]
Full description |

Standard name | GO_AP_1_ADAPTOR_COMPLEX
Systematic name | M25705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterotetrameric AP-type membrane coat adaptor complex that consists of beta1, gamma, mu1 and sigma1 subunits and links clathrin to the membrane surface of a vesicle; vesicles with AP-1-containing coats are normally found primarily in the trans-Golgi network. In at least humans, the AP-1 complex can be heterogeneric due to the existence of multiple subunit isoforms encoded by different genes (gamma1 and gamma2, mu1A and mu1B, and sigma1A, sigma1B and sigma1C). [GOC:mah, PMID:10611976, PMID:21097499]
Full description |

Standard name | GO_AP_3_ADAPTOR_COMPLEX
Systematic name | M25706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterotetrameric AP-type membrane coat adaptor complex that consists of beta3, delta, mu3 and sigma3 subunits and is found associated with endosomal membranes. AP-3 does not appear to associate with clathrin in all organisms. In at least humans, the AP-3 complex can be heterogeneric due to the existence of multiple subunit isoforms encoded by different genes (beta3A and beta3B, mu3A and mu3B, and sigma3A and sigma3B). [GOC:mah, PMID:10611976, PMID:21097499]
Full description |

Standard name | GO_AP_4_ADAPTOR_COMPLEX
Systematic name | M25707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An AP-type membrane coat adaptor complex that consists of beta4, epsilon, mu4 and sigma4 subunits and is found associated with membranes in the trans-Golgi network; it is not clear whether AP-4 forms clathrin coats in vivo. [GOC:mah, PMID:10611976]
Full description |

Standard name | GO_CLATHRIN_VESICLE_COAT
Systematic name | M17381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A clathrin coat found on a vesicle. [GOC:mah]
Full description |

Standard name | GO_COPI_VESICLE_COAT
Systematic name | M17078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | One of two multimeric complexes that forms a membrane vesicle coat. The mammalian COPI subunits are called alpha-, beta-, beta'-, gamma-, delta-, epsilon- and zeta-COP. Vesicles with COPI coats are found associated with Golgi membranes at steady state. [GOC:mah, PMID:11252894]
Full description |

Standard name | GO_COPII_VESICLE_COAT
Systematic name | M25708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | One of two multimeric complexes that forms a membrane vesicle coat. COPII is best characterized in S. cerevisiae, where the subunits are called Sar1p, Sec13p, Sec31p, Sec23p, and Sec24p. Vesicles with COPII coats are found associated with endoplasmic reticulum (ER) membranes at steady state. [GOC:ascb_2009, GOC:dph, GOC:mah, GOC:tb, PMID:11252894]
Full description |

Standard name | GO_CLATHRIN_COAT_OF_ENDOCYTIC_VESICLE
Systematic name | M17716
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A clathrin coat found on an endocytic vesicle. [GOC:mah]
Full description |

Standard name | GO_CLATHRIN_ADAPTOR_COMPLEX
Systematic name | M17816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane coat adaptor complex that links clathrin to a membrane. [GOC:mah]
Full description |

Standard name | GO_CLATHRIN_COAT_OF_COATED_PIT
Systematic name | M17412
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The coat found on coated pits and the coated vesicles derived from coated pits; comprises clathrin and the AP-2 adaptor complex. [GOC:mah]
Full description |

Standard name | GO_TRANSPORT_VESICLE
Systematic name | M7476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the vesicles of the constitutive secretory pathway, which carry cargo from the endoplasmic reticulum to the Golgi, between Golgi cisternae, from the Golgi to the ER (retrograde transport) or to destinations within or outside the cell. [GOC:mah, PMID:22160157]
Full description |

Standard name | GO_COPII_COATED_ER_TO_GOLGI_TRANSPORT_VESICLE
Systematic name | M25709
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A vesicle with a coat formed of the COPII coat complex proteins. The COPII coat complex is formed by the Sec23p/Sec24p and the Sec13p/Sec31p heterodimers. COPII-associated vesicles transport proteins from the rough endoplasmic reticulum to the Golgi apparatus (anterograde transport). [PMID:11252894, PMID:17499046, PMID:22160157, PMID:8004676, Wikipedia:COPII]
Full description |

Standard name | GO_COATED_VESICLE
Systematic name | M1314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Small membrane-bounded organelle formed by pinching off of a coated region of membrane. Some coats are made of clathrin, whereas others are made from other proteins. [ISBN:0815316194]
Full description |

Standard name | GO_CLATHRIN_COATED_VESICLE
Systematic name | M16844
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A vesicle with a coat formed of clathrin connected to the membrane via one of the clathrin adaptor complexes. [GOC:mah, PMID:11252894]
Full description |

Standard name | GO_COPI_COATED_VESICLE
Systematic name | M17353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A vesicle with a coat formed of the COPI coat complex proteins. COPI-coated vesicles are found associated with Golgi membranes at steady state, are involved in Golgi to endoplasmic reticulum (retrograde) vesicle transport, and possibly also in intra-Golgi transport. [GOC:mah, PMID:11252894]
Full description |

Standard name | GO_ENDOCYTIC_VESICLE
Systematic name | M17129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-bounded intracellular vesicle formed by invagination of the plasma membrane around an extracellular substance. Endocytic vesicles fuse with early endosomes to deliver the cargo for further sorting. [GOC:go_curators, PMID:19696797]
Full description |

Standard name | GO_TRANS_GOLGI_NETWORK_TRANSPORT_VESICLE
Systematic name | M2729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A vesicle that mediates transport between the trans-Golgi network and other parts of the cell. [GOC:mah]
Full description |

Standard name | GO_SECRETORY_GRANULE
Systematic name | M10712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A small subcellular vesicle, surrounded by a membrane, that is formed from the Golgi apparatus and contains a highly concentrated protein destined for secretion. Secretory granules move towards the periphery of the cell and upon stimulation, their membranes fuse with the cell membrane, and their protein load is exteriorized. Processing of the contained protein may take place in secretory granules. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_FILOPODIUM
Systematic name | M16974
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Thin, stiff, actin-based protrusion extended by the leading edge of a motile cell such as a crawling fibroblast or amoeba, or an axonal or dendritic growth cone, or a dendritic shaft. [GOC:mah, GOC:pr, ISBN:0815316194]
Full description |

Standard name | GO_INTEGRAL_COMPONENT_OF_SYNAPTIC_VESICLE_MEMBRANE
Systematic name | M25710
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the synaptic vesicle membrane consisting of the gene products and protein complexes having at least some part of their peptide sequence embedded in the hydrophobic region of the membrane. [GOC:dos, GOC:go_curators]
Full description |

Standard name | GO_DYNEIN_COMPLEX
Systematic name | M17577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of several large complexes that contain two or three dynein heavy chains and several light chains, and have microtubule motor activity. [ISBN:0815316194]
Full description |

Standard name | GO_EXTERNAL_ENCAPSULATING_STRUCTURE
Systematic name | M29420
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structure that lies outside the plasma membrane and surrounds the entire cell or cells. This does not include the periplasmic space. [GOC:go_curators]
Full description |

Standard name | GO_JUNCTIONAL_MEMBRANE_COMPLEX
Systematic name | M25711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Complex formed in muscle cells between the membrane of the sarcoplasmic reticulum and invaginations of the plasma membrane (T-tubules). [PMID:11535622]
Full description |

Standard name | GO_T_TUBULE
Systematic name | M17625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Invagination of the plasma membrane of a muscle cell that extends inward from the cell surface around each myofibril. The ends of T-tubules make contact with the sarcoplasmic reticulum membrane. [GOC:mtg_muscle, ISBN:0815316194]
Full description |

Standard name | GO_AXON
Systematic name | M17790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The long process of a neuron that conducts nerve impulses, usually away from the cell body to the terminals and varicosities, which are sites of storage and release of neurotransmitter. [GOC:nln, ISBN:0198506732]
Full description |

Standard name | GO_SITE_OF_POLARIZED_GROWTH
Systematic name | M2595
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any part of a cell where non-isotropic growth takes place. [GOC:mah]
Full description |

Standard name | GO_HOST_CELL_CYTOPLASM
Systematic name | M25712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The cytoplasm of a host cell. [GOC:mah]
Full description |

Standard name | GO_MIDBODY
Systematic name | M17533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A thin cytoplasmic bridge formed between daughter cells at the end of cytokinesis. The midbody forms where the contractile ring constricts, and may persist for some time before finally breaking to complete cytokinesis. [ISBN:0815316194]
Full description |

Standard name | GO_SMALL_NUCLEAR_RIBONUCLEOPROTEIN_COMPLEX
Systematic name | M5645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex composed of RNA of the small nuclear RNA (snRNA) class and protein, found in the nucleus of a eukaryotic cell. These are typically named after the snRNA(s) they contain, e.g. U1 snRNP or U4/U6 snRNP. Many, but not all, of these complexes are involved in splicing of nuclear mRNAs. [GOC:krc, GOC:mah, ISBN:0879695897]
Full description |

Standard name | GO_TRANSPORT_VESICLE_MEMBRANE
Systematic name | M17791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a transport vesicle. [GOC:mah]
Full description |

Standard name | GO_GOLGI_ASSOCIATED_VESICLE_MEMBRANE
Systematic name | M17169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a vesicle associated with the Golgi apparatus. [GOC:mah]
Full description |

Standard name | GO_COATED_VESICLE_MEMBRANE
Systematic name | M8393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a coated vesicle. [GOC:mah]
Full description |

Standard name | GO_COPI_COATED_VESICLE_MEMBRANE
Systematic name | M17242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a COPI-coated vesicle. [GOC:mah]
Full description |

Standard name | GO_CLATHRIN_COATED_VESICLE_MEMBRANE
Systematic name | M17518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a clathrin-coated vesicle. [GOC:mah]
Full description |

Standard name | GO_ENDOCYTIC_VESICLE_MEMBRANE
Systematic name | M17270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding an endocytic vesicle. [GOC:mah]
Full description |

Standard name | GO_SECRETORY_GRANULE_MEMBRANE
Systematic name | M17505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a secretory granule. [GOC:mah]
Full description |

Standard name | GO_CLATHRIN_COATED_ENDOCYTIC_VESICLE_MEMBRANE
Systematic name | M17741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a clathrin-coated endocytic vesicle. [GOC:mah]
Full description |

Standard name | GO_PHAGOCYTIC_VESICLE_MEMBRANE
Systematic name | M17608
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a phagocytic vesicle. [GOC:mah]
Full description |

Standard name | GO_SYNAPTIC_VESICLE_MEMBRANE
Systematic name | M25714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a synaptic vesicle. [GOC:mah]
Full description |

Standard name | GO_AXOLEMMA
Systematic name | M17604
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding an axon; it is a specialized trilaminar random mosaic of protein molecules floating within a fluid matrix of highly mobile phospholipid molecules, 7-8 nm in thickness. [http://www.medik.sk/clanky/bio_jun.htm, ISBN:0124325653]
Full description |

Standard name | GO_RIBONUCLEASE_P_COMPLEX
Systematic name | M25715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that catalyzes cleavage of the leader sequence of precursor tRNAs (pre-tRNAs), generating the mature 5' end of tRNAs. [GOC:mah, PMID:12045094]
Full description |

Standard name | GO_MULTIMERIC_RIBONUCLEASE_P_COMPLEX
Systematic name | M25716
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonuclease P complex that generally contains a single RNA molecule and several protein molecules. Examples of this complex are found in Archaeal species. [GOC:mah, PMID:11142368, PMID:12045094]
Full description |

Standard name | GO_PRERIBOSOME
Systematic name | M17276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any complex of pre-rRNAs, ribosomal proteins, and associated proteins formed during ribosome biogenesis. [PMID:10567516]
Full description |

Standard name | GO_90S_PRERIBOSOME
Systematic name | M16987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large ribonucleoprotein complex considered to be the earliest preribosomal complex. In S. cerevisiae, it has a size of 90S and consists of the 35S pre-rRNA, early-associating ribosomal proteins most of which are part of the small ribosomal subunit, the U3 snoRNA and associated proteins. [GOC:krc, GOC:vw, PMID:12150911, PMID:12957375, PMID:15120992]
Full description |

Standard name | GO_PRERIBOSOME_LARGE_SUBUNIT_PRECURSOR
Systematic name | M17563
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A preribosomal complex consisting of 27SA, 27SB, and/or 7S pre-rRNA, 5S rRNA, ribosomal proteins including late-associating large subunit proteins, and associated proteins; a precursor of the eukaryotic cytoplasmic large ribosomal subunit. [PMID:10567516]
Full description |

Standard name | GO_PRERIBOSOME_SMALL_SUBUNIT_PRECURSOR
Systematic name | M25717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A preribosomal complex consisting of 20S pre-rRNA, ribosomal proteins including late-associating small subunit proteins, and associated proteins; a precursor of the eukaryotic cytoplasmic small ribosomal subunit. [PMID:10567516]
Full description |

Standard name | GO_CORTICAL_CYTOSKELETON
Systematic name | M2926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the cytoskeleton that lies just beneath the plasma membrane. [GOC:mah]
Full description |

Standard name | GO_CORTICAL_ACTIN_CYTOSKELETON
Systematic name | M4106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the actin cytoskeleton, comprising filamentous actin and associated proteins, that lies just beneath the plasma membrane. [GOC:mah]
Full description |

Standard name | GO_ROUGH_ENDOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M17223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding the rough endoplasmic reticulum. [GOC:mah]
Full description |

Standard name | GO_SMOOTH_ENDOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M25718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding the smooth endoplasmic reticulum. [GOC:mah]
Full description |

Standard name | GO_MRE11_COMPLEX
Systematic name | M25719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Trimeric protein complex that possesses endonuclease activity; involved in meiotic recombination, DNA repair and checkpoint signaling. In Saccharomyces cerevisiae, the complex comprises Mre11p, Rad50p, and Xrs2p; complexes identified in other species generally contain proteins orthologous to the Saccharomyces cerevisiae proteins. [GOC:mah, GOC:vw, PMID:11988766, PMID:17674145]
Full description |

Standard name | GO_BETA_CATENIN_DESTRUCTION_COMPLEX
Systematic name | M17464
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cytoplasmic protein complex containing glycogen synthase kinase-3-beta (GSK-3-beta), the adenomatous polyposis coli protein (APC), and the scaffolding protein axin, among others; phosphorylates beta-catenin, targets it for degradation by the proteasome. [PMID:14600025]
Full description |

Standard name | GO_RNA_POLYMERASE_COMPLEX
Systematic name | M14723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any complex that possesses RNA polymerase activity; generally comprises a catalytic subunit and one or more additional subunits. [GOC:mah]
Full description |

Standard name | GO_MITOTIC_COHESIN_COMPLEX
Systematic name | M34347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cohesin complex that mediates sister chromatid cohesion during mitosis; has a subunit composition distinct from that of the meiotic cohesin complex. [GOC:mah, PMID:12750522]
Full description |

Standard name | GO_MEIOTIC_COHESIN_COMPLEX
Systematic name | M25721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cohesin complex that mediates sister chromatid cohesion during meiosis; has a subunit composition distinct from that of the mitotic cohesin complex. [GOC:mah, PMID:12750522]
Full description |

Standard name | GO_REPLISOME
Systematic name | M17657
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multi-component enzymatic machine at the replication fork which mediates DNA replication. Includes DNA primase, one or more DNA polymerases, DNA helicases, and other proteins. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_CHECKPOINT_CLAMP_COMPLEX
Systematic name | M25722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Conserved heterotrimeric complex of PCNA-like proteins that is loaded onto DNA at sites of DNA damage. [PMID:12531008]
Full description |

Standard name | GO_HOPS_COMPLEX
Systematic name | M17199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multimeric protein complex that associates with the vacuolar membrane, late endosomal (multivesicular body) and lysosomal membranes. HOPS is a tethering complex involved in vesicle fusion. [PMID:10944212, PMID:23645161]
Full description |

Standard name | GO_RETROMER_COMPLEX
Systematic name | M16994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A conserved hetero-pentameric membrane-associated complex involved in retrograde transport from endosomes to the Golgi apparatus. The budding yeast retromer comprises Vps35p, Vps29p, Vps26p, Vps5p, and Vps17p. The mammalian complex shows slight variation in composition compared to yeast, and comprises SNX1 or SNX2, SNX5 or SNX6, VPS26A or VPS26B, VPS29, and VPS35. [GOC:bf, PMID:26220253, PMID:27385586, PMID:9700157]
Full description |

Standard name | GO_STAGA_COMPLEX
Systematic name | M17502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large multiprotein complex that possesses histone acetyltransferase and is involved in regulation of transcription. The composition is similar to that of the SAGA complex; for example, the human complex contains the transcription-transformation cofactor TRRAP, hGCN5L acetylase, novel human ADA-like and SPT-like cofactors, and a subset of TAFs. [PMID:11564863]
Full description |

Standard name | GO_NADH_DEHYDROGENASE_COMPLEX
Systematic name | M8122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An integral membrane complex that possesses NADH oxidoreductase activity. The complex is one of the components of the electron transport chain. It catalyzes the transfer of a pair of electrons from NADH to a quinone. [GOC:mah]
Full description |

Standard name | GO_INTRACILIARY_TRANSPORT_PARTICLE
Systematic name | M17560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A nonmembrane-bound oligomeric protein complex that participates in bidirectional transport of molecules (cargo) along axonemal microtubules. [GOC:cilia, GOC:kmv, PMID:14570576, PMID:22118932, PMID:23945166]
Full description |

Standard name | GO_INTRACILIARY_TRANSPORT_PARTICLE_A
Systematic name | M25724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The smaller subcomplex of the intraciliary transport particle; characterized complexes have molecular weights of 710-760 kDa. [GOC:cilia, GOC:kmv, PMID:14570576]
Full description |

Standard name | GO_INTRACILIARY_TRANSPORT_PARTICLE_B
Systematic name | M17550
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The larger subcomplex of the intraciliary transport particle; characterized complexes have molecular weights around 550 kDa. [GOC:cilia, GOC:kmv, PMID:14570576, PMID:19253336]
Full description |

Standard name | GO_ISWI_TYPE_COMPLEX
Systematic name | M25725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any nuclear protein complex that contains an ATPase subunit of the imitation switch (ISWI) family. ISWI ATPases are involved in assembling chromatin and in sliding and spacing nucleosomes to regulate transcription of nuclear RNA polymerases I, II, and III and also DNA replication, recombination and repair. [GOC:krc, GOC:mah, PMID:15020051, PMID:15284901, PMID:16568949, PMID:21810179]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX
Systematic name | M18403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structure lying external to one or more cells, which provides structural support, biochemical or biomechanical cues for cells or tissues. [GOC:BHF, GOC:mah, GOC:rph, NIF_Subcellular:nlx_subcell_20090513, PMID:21123617, PMID:28089324]
Full description |

Standard name | GO_DENSE_CORE_GRANULE
Systematic name | M17823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Electron-dense organelle with a granular internal matrix; contains proteins destined to be secreted. [NIF_Subcellular:sao772007592, PMID:14690495]
Full description |

Standard name | GO_NUCLEAR_PORE_OUTER_RING
Systematic name | M25726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A subcomplex of the nuclear pore complex (NPC) that forms the outer rings of the core scaffold, a lattice-like structure that gives the NPC its shape and strength. In S. cerevisiae, the two outer rings each contain multiple copies of the following proteins: Nup133p, Nup120p, Nup145Cp, Nup85p, Nup84p, Seh1p, and Sec13p. In vertebrates, the two outer rings each contain multiple copies of the following proteins: Nup133, Nup160, Nup96, Nup75, Nup107, Seh1, Sec13, Nup43, Nup37, and ALADIN. Components are arranged in 8-fold symmetrical 'spokes' around the central transport channel. A single 'spoke', can be isolated and is sometimes referred to as the Nup84 complex (S. cerevisiae) or the Nup107-160 complex (vertebrates). [GOC:dgf, PMID:18046406, PMID:19524430, PMID:20947011, PMID:22419078]
Full description |

Standard name | GO_BLOC_COMPLEX
Systematic name | M17463
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of several protein complexes required for the biogenesis of specialized organelles of the endosomal-lysosomal system, such as melanosomes, platelet dense granules, and other related organelles; acronym for biogenesis of lysosomal-related organelles complex. [PMID:15102850, PMID:15261680]
Full description |

Standard name | GO_BLOC_1_COMPLEX
Systematic name | M17112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex required for the biogenesis of specialized organelles of the endosomal-lysosomal system, such as melanosomes and platelet dense granules. Many of the protein subunits are conserved between mouse and human; the mouse complex contains the Pallidin, Muted, Cappuccino, Dysbindin, Snapin, BLOS1, BLOS2, AND BLOS3 proteins. [PMID:15102850]
Full description |

Standard name | GO_PLATELET_DENSE_GRANULE_MEMBRANE
Systematic name | M25727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding the platelet dense granule. [GOC:mah]
Full description |

Standard name | GO_PLATELET_DENSE_GRANULE_LUMEN
Systematic name | M17369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membrane of the platelet dense granule. [GOC:mah]
Full description |

Standard name | GO_PLATELET_ALPHA_GRANULE
Systematic name | M17065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A secretory organelle found in blood platelets, which is unique in that it exhibits further compartmentalization and acquires its protein content via two distinct mechanisms: (1) biosynthesis predominantly at the megakaryocyte (MK) level (with some vestigial platelet synthesis) (e.g. platelet factor 4) and (2) endocytosis and pinocytosis at both the MK and circulating platelet levels (e.g. fibrinogen (Fg) and IgG). [PMID:8467233]
Full description |

Standard name | GO_PLATELET_ALPHA_GRANULE_MEMBRANE
Systematic name | M17081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding the platelet alpha granule. [GOC:mah, PMID:8467233]
Full description |

Standard name | GO_PLATELET_ALPHA_GRANULE_LUMEN
Systematic name | M17320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membrane of the platelet alpha granule. [GOC:mah, PMID:8467233]
Full description |

Standard name | GO_PLATELET_DENSE_TUBULAR_NETWORK
Systematic name | M17306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A network of membrane-bounded compartments found in blood platelets, where they regulate platelet activation by sequestering or releasing calcium. The dense tubular network exists as thin elongated membranes in resting platelets, and undergoes a major ultrastructural change, to a rounded vesicular form, upon addition of thrombin. [PMID:1322202]
Full description |

Standard name | GO_PLATELET_DENSE_TUBULAR_NETWORK_MEMBRANE
Systematic name | M25728
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding the platelet dense tubular network. [GOC:mah, PMID:1322202]
Full description |

Standard name | GO_PSEUDOPODIUM
Systematic name | M17624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A temporary protrusion or retractile process of a cell, associated with flowing movements of the protoplasm, and serving for locomotion and feeding. [ISBN:0198506732]
Full description |

Standard name | GO_SNARE_COMPLEX
Systematic name | M17219
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex involved in membrane fusion; a stable ternary complex consisting of a four-helix bundle, usually formed from one R-SNARE and three Q-SNAREs with an ionic layer sandwiched between hydrophobic layers. One well-characterized example is the neuronal SNARE complex formed of synaptobrevin 2, syntaxin 1a, and SNAP-25. [GOC:bhm, GOC:pr, PMID:10872468, PMID:19450911]
Full description |

Standard name | GO_SCAR_COMPLEX
Systematic name | M25729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A pentameric complex that includes orthologues of human PIR121, Nap1, Abi, SCAR, and HSPC300 and regulates actin polymerization and/or depolymerization through small GTPase mediated signal transduction. [GOC:hla, GOC:pg, PMID:12181570, PMID:24036345, PMID:24630101]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_PALMITOYLTRANSFERASE_COMPLEX
Systematic name | M25730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex of the endoplasmic reticulum that catalyzes S-palmitoylation, the addition of palmitate (C16:0) or other long-chain fatty acids to proteins at a cysteine residue. [GOC:jh]
Full description |

Standard name | GO_ANCHORED_COMPONENT_OF_MEMBRANE
Systematic name | M1242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of a membrane consisting of the gene products that are tethered to the membrane only by a covalently attached anchor, such as a lipid group that is embedded in the membrane. Gene products with peptide sequences that are embedded in the membrane are excluded from this grouping. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_PLASMA_MEMBRANE
Systematic name | M9232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the plasma membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_ENDOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M17144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the endoplasmic reticulum membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_GOLGI_MEMBRANE
Systematic name | M5356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the Golgi membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_NUCLEAR_INNER_MEMBRANE
Systematic name | M29423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the nuclear inner membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_PEROXISOMAL_MEMBRANE
Systematic name | M17174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the peroxisomal membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_EXTERNAL_SIDE_OF_PLASMA_MEMBRANE
Systematic name | M25731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of a plasma membrane consisting of gene products and protein complexes that are loosely bound to its external surface, but not integrated into the hydrophobic region. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_EXTERNAL_SIDE_OF_PLASMA_MEMBRANE
Systematic name | M17729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of a plasma membrane consisting of gene products and protein complexes that penetrate the external side of the plasma membrane only, either directly or via some covalently attached hydrophobic anchor. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_CYTOPLASMIC_SIDE_OF_PLASMA_MEMBRANE
Systematic name | M17565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of a plasma membrane consisting of gene products and protein complexes that are loosely bound to its cytoplasmic surface, but not integrated into the hydrophobic region. [GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_THE_CYTOPLASMIC_SIDE_OF_THE_PLASMA_MEMBRANE
Systematic name | M17521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of a plasma membrane consisting of gene products and protein complexes that have some covalently attached part (e.g. peptide sequence or GPI anchor) which is embedded in the cytoplasmic side of the plasma membrane only. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_PROTEIN_ACETYLTRANSFERASE_COMPLEX
Systematic name | M25732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex that catalyzes the transfer of an acetyl group to a protein acceptor molecule. [GOC:bf]
Full description |

Standard name | GO_CELL_LEADING_EDGE
Systematic name | M18018
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The area of a motile cell closest to the direction of movement. [GOC:pg]
Full description |

Standard name | GO_CELL_PROJECTION_MEMBRANE
Systematic name | M17141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a plasma membrane bounded cell surface projection. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_CELL_TRAILING_EDGE
Systematic name | M17418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The area of a motile cell opposite to the direction of movement. [GOC:pg]
Full description |

Standard name | GO_LEADING_EDGE_MEMBRANE
Systematic name | M17334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding the leading edge of a motile cell. [GOC:mah]
Full description |

Standard name | GO_LAMELLIPODIUM_MEMBRANE
Systematic name | M17447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a lamellipodium. [GOC:mah]
Full description |

Standard name | GO_DNA_REPLICATION_PREINITIATION_COMPLEX
Systematic name | M25733
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein-DNA complex assembled at eukaryotic DNA replication origins immediately prior to the initiation of DNA replication. The preinitiation complex is formed by the assembly of additional proteins onto an existing prereplicative complex. In budding yeast, the additional proteins might include Cdc45p, Sld2p, Sld3p, Dpb11p, DNA polymerases, and others; in fission yeast the GINS complex is present. [GOC:bf, GOC:hjd, GOC:jl, GOC:pr, GOC:rb, GOC:vw, PMID:12694535, PMID:15194812, PMID:17230184]
Full description |

Standard name | GO_DEATH_INDUCING_SIGNALING_COMPLEX
Systematic name | M25734
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex formed by the association of signaling proteins with a death receptor upon ligand binding. The complex includes procaspases and death domain-containing proteins in addition to the ligand-bound receptor, and may control the activation of caspases 8 and 10. [GOC:mtg_apoptosis, PMID:12628743, PMID:12655293, PMID:8521815]
Full description |

Standard name | GO_CD95_DEATH_INDUCING_SIGNALING_COMPLEX
Systematic name | M25735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex formed upon binding of Fas/CD95/APO-1 to its ligand. The complex includes FADD/Mort1, procaspase-8/10 and c-FLIP in addition to the ligand-bound receptor. [PMID:12628743, PMID:12655293]
Full description |

Standard name | GO_REPLICATION_FORK_PROTECTION_COMPLEX
Systematic name | M25736
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex conserved in eukaryotes and associated with the replication fork; the complex stabilizes stalled replication forks and is thought to be involved in coordinating leading- and lagging-strand synthesis and in replication checkpoint signaling. [PMID:15367656]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_ORGANELLE_MEMBRANE
Systematic name | M17067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the organelle membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_MITOCHONDRIAL_INNER_MEMBRANE
Systematic name | M17576
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the mitochondrial inner membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_MITOCHONDRIAL_OUTER_MEMBRANE
Systematic name | M17047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the mitochondrial outer membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_VACUOLAR_MEMBRANE
Systematic name | M25737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the vacuolar membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_ORGANELLE_MEMBRANE
Systematic name | M17367
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of an organelle membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_ENDOSOME_MEMBRANE
Systematic name | M25738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of an endosome membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_MITOCHONDRIAL_INNER_MEMBRANE
Systematic name | M25739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of mitochondrial inner membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_RNAI_EFFECTOR_COMPLEX
Systematic name | M17672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that mediates the effects of small interfering RNAs on gene expression. Most known examples contain one or more members of the Argonaute family of proteins. [GOC:mah, PMID:14704433]
Full description |

Standard name | GO_ANCHORED_COMPONENT_OF_EXTERNAL_SIDE_OF_PLASMA_MEMBRANE
Systematic name | M17023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the plasma membrane consisting of the gene products that are tethered to the external side of the membrane only by a covalently attached anchor, such as a lipid group embedded in the membrane. Gene products with peptide sequences that are embedded in the membrane are excluded from this grouping. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_UBIQUITIN_CONJUGATING_ENZYME_COMPLEX
Systematic name | M25740
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any complex that possesses ubiquitin conjugating enzyme activity. [GOC:mah]
Full description |

Standard name | GO_CTF18_RFC_LIKE_COMPLEX
Systematic name | M25741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heptameric complex related to replication factor C, which loads the DNA polymerase processivity factor proliferating cell nuclear antigen (PCNA) onto DNA and plays a vital role in chromosome cohesion. In Saccharomyces the subunits are known as Ctf18p, Rfc2p, Rfc3p, Rfc4p, Rfc5p, Dcc1p, and Ctf8p. [PMID:14614842]
Full description |

Standard name | GO_N_TERMINAL_PROTEIN_ACETYLTRANSFERASE_COMPLEX
Systematic name | M17435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex that catalyzes the transfer of an acetyl group to the N-terminal residue of a protein acceptor molecule. [GOC:mah]
Full description |

Standard name | GO_NATA_COMPLEX
Systematic name | M25742
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A conserved complex that catalyzes the transfer of an acetyl group to an N-terminal Ser, Ala, Gly, or Thr residue of a protein acceptor molecule. In Saccharomyces the complex includes Nat1p and Ard1p, and may contain additional proteins. [PMID:12890471]
Full description |

Standard name | GO_BOX_C_D_SNORNP_COMPLEX
Systematic name | M25743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex containing small nucleolar RNA of the box C/D type that can carry out ribose-2'-O-methylation of target RNAs. [ISBN:0879695897, PMID:17284456]
Full description |

Standard name | GO_BOX_H_ACA_SNORNP_COMPLEX
Systematic name | M25744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A box H/ACA RNP complex that is located in the nucleolus. [GOC:vw, ISBN:0879695897, PMID:17284456, PMID:20227365]
Full description |

Standard name | GO_M_BAND
Systematic name | M17208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The midline of aligned thick filaments in a sarcomere; location of specific proteins that link thick filaments. Depending on muscle type the M band consists of different numbers of M lines. [GOC:mtg_muscle, ISBN:0198506732, ISBN:0815316194]
Full description |

Standard name | GO_CULLIN_RING_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M17643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any ubiquitin ligase complex in which the catalytic core consists of a member of the cullin family and a RING domain protein; the core is associated with one or more additional proteins that confer substrate specificity. [PMID:15571813, PMID:15688063]
Full description |

Standard name | GO_CUL2_RING_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M25745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex in which a cullin from the Cul2 subfamily and a RING domain protein form the catalytic core; substrate specificity is conferred by an elongin-BC adaptor and a SOCS/BC box protein. [PMID:15571813, PMID:15688063]
Full description |

Standard name | GO_CUL3_RING_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M17683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex in which a cullin from the Cul3 subfamily and a RING domain protein form the catalytic core; substrate specificity is conferred by a BTB-domain-containing protein. [PMID:15571813, PMID:15688063]
Full description |

Standard name | GO_CUL4A_RING_E3_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M25746
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex in which a cullin from the Cul4A subfamily and a RING domain protein form the catalytic core; substrate specificity is conferred by an adaptor protein. [PMID:15571813, PMID:15688063]
Full description |

Standard name | GO_CUL4B_RING_E3_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M25747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex in which a cullin from the Cul4B subfamily and a RING domain protein form the catalytic core; substrate specificity is conferred by unknown subunits. [PMID:15571813, PMID:15688063]
Full description |

Standard name | GO_CUL5_RING_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M25748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex in which a cullin from the Cul5 subfamily and a RING domain protein form the catalytic core; substrate specificity is conferred by an elongin-BC adaptor and a SOCS/BC box protein. [PMID:15571813, PMID:15688063]
Full description |

Standard name | GO_MANNOSYLTRANSFERASE_COMPLEX
Systematic name | M34348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex that posseses mannosyltransferase activity. [GOC:mah]
Full description |

Standard name | GO_MOTILE_CILIUM
Systematic name | M17253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cilium which may have a variable arrangement of axonemal microtubules and also contains molecular motors. It may beat with a whip-like pattern that promotes cell motility or transport of fluids and other cells across a cell surface, such as on epithelial cells that line the lumenal ducts of various tissues; or they may display a distinct twirling motion that directs fluid flow asymmetrically across the cellular surface to affect asymmetric body plan organization. Motile cilia can be found in single as well as multiple copies per cell. [GOC:cilia, GOC:dgh, GOC:kmv, PMID:17009929, PMID:20144998, PMID:22118931]
Full description |

Standard name | GO_PCG_PROTEIN_COMPLEX
Systematic name | M17237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A chromatin-associated multiprotein complex containing Polycomb Group proteins. In Drosophila, Polycomb group proteins are involved in the long-term maintenance of gene repression, and PcG protein complexes associate with Polycomb group response elements (PREs) in target genes to regulate higher-order chromatin structure. [PMID:9372908]
Full description |

Standard name | GO_BRUSH_BORDER_MEMBRANE
Systematic name | M17764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding the brush border. [GOC:mah]
Full description |

Standard name | GO_FILOPODIUM_MEMBRANE
Systematic name | M17016
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a filopodium. [GOC:mah]
Full description |

Standard name | GO_MICROVILLUS_MEMBRANE
Systematic name | M17323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a microvillus. [GOC:mah]
Full description |

Standard name | GO_NUCLEOTIDE_ACTIVATED_PROTEIN_KINASE_COMPLEX
Systematic name | M25750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that possesses nucleotide-dependent protein kinase activity. The nucleotide can be AMP (in S. pombe and human) or ADP (in S. cerevisiae). [GOC:bhm, GOC:mah, GOC:vw]
Full description |

Standard name | GO_NEUROMUSCULAR_JUNCTION
Systematic name | M17676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The junction between the axon of a motor neuron and a muscle fiber. In response to the arrival of action potentials, the presynaptic button releases molecules of neurotransmitters into the synaptic cleft. These diffuse across the cleft and transmit the signal to the postsynaptic membrane of the muscle fiber, leading to a change in post-synaptic potential. [GOC:nln]
Full description |

Standard name | GO_CYTOSOLIC_PROTEASOME_COMPLEX
Systematic name | M17258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A proteasome complex found in the cytosol of a cell. [GOC:mah, GOC:mtg_sensu]
Full description |

Standard name | GO_SPINDLE_POLE_CENTROSOME
Systematic name | M25751
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A centrosome from which one pole of a mitotic or meiotic spindle is organized. [GOC:mah]
Full description |

Standard name | GO_NUCLEAR_PERICENTRIC_HETEROCHROMATIN
Systematic name | M25752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Nuclear heterochromatin that is located adjacent to the CENP-A rich centromere 'central core' and characterized by the modified histone H3K9me3. [GOC:mah, PMID:20206496, PMID:22729156, PMID:9413993]
Full description |

Standard name | GO_A_BAND
Systematic name | M17675
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The dark-staining region of a sarcomere, in which myosin thick filaments are present; the center is traversed by the paler H zone, which in turn contains the M line. [ISBN:0321204131]
Full description |

Standard name | GO_I_BAND
Systematic name | M16979
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A region of a sarcomere that appears as a light band on each side of the Z disc, comprising a region of the sarcomere where thin (actin) filaments are not overlapped by thick (myosin) filaments; contains actin, troponin, and tropomyosin; each sarcomere includes half of an I band at each end. [ISBN:0321204131]
Full description |

Standard name | GO_G_PROTEIN_BETA_GAMMA_SUBUNIT_COMPLEX
Systematic name | M29424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The heterodimer formed by the beta and gamma subunits of a heterotrimeric G protein, which dissociates from the alpha subunit upon guanine nuclotide exchange. [GOC:mah]
Full description |

Standard name | GO_HAPTOGLOBIN_HEMOGLOBIN_COMPLEX
Systematic name | M25753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex formed by the stable binding of a haptoglobin to hemoglobin. [GOC:mah]
Full description |

Standard name | GO_EARLY_ENDOSOME_MEMBRANE
Systematic name | M17311
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding an early endosome. [GOC:pz]
Full description |

Standard name | GO_LATE_ENDOSOME_MEMBRANE
Systematic name | M17059
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a late endosome. [GOC:pz]
Full description |

Standard name | GO_MICROBODY_MEMBRANE
Systematic name | M1503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a microbody. [GOC:mah]
Full description |

Standard name | GO_ENDOSOME_LUMEN
Systematic name | M17057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membrane of an endosome. [GOC:mah]
Full description |

Standard name | GO_LATE_ENDOSOME_LUMEN
Systematic name | M25754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membrane of a late endosome. [GOC:mah]
Full description |

Standard name | GO_MICROBODY_LUMEN
Systematic name | M17802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membranes of a microbody. [GOC:mah]
Full description |

Standard name | GO_TORC1_COMPLEX
Systematic name | M25755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains at least TOR (target of rapamycin) and Raptor (regulatory-associated protein of TOR), or orthologs of, in complex with other signaling components. Mediates the phosphorylation and activation of S6K. In Saccharomyces, the complex contains Kog1p, Lst8p, Tco89p, and either Tor1p or Tor2p. [GOC:jh, PMID:15780592, PMID:16469695, PMID:21548787]
Full description |

Standard name | GO_TORC2_COMPLEX
Systematic name | M25756
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains at least TOR (target of rapamycin) and Rictor (rapamycin-insensitive companion of TOR), or orthologs of, in complex with other signaling components. Mediates the phosphorylation and activation of PKB (also called AKT). In Saccharomyces, the complex contains Avo1p, Avo2p, Tsc11p, Lst8p, Bit61p, Slm1p, Slm2p, and Tor2p. [GOC:bf, GOC:jh, PMID:14736892, PMID:15780592, PMID:16469695, PMID:21548787]
Full description |

Standard name | GO_FILAMENTOUS_ACTIN
Systematic name | M17803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A two-stranded helical polymer of the protein actin. [GOC:mah]
Full description |

Standard name | GO_NUCLEAR_MEMBRANE
Systematic name | M17711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Either of the lipid bilayers that surround the nucleus and form the nuclear envelope; excludes the intermembrane space. [GOC:mah, GOC:pz]
Full description |

Standard name | GO_ORGANELLE_ENVELOPE_LUMEN
Systematic name | M17583
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region between the inner and outer lipid bilayers of an organelle envelope. [GOC:mah]
Full description |

Standard name | GO_ENVELOPE
Systematic name | M1100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multilayered structure surrounding all or part of a cell; encompasses one or more lipid bilayers, and may include a cell wall layer; also includes the space between layers. [GOC:mah, GOC:pz]
Full description |

Standard name | GO_VESICLE_LUMEN
Systematic name | M17194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membrane or protein that forms a vesicle. [GOC:mah, GOC:vesicles]
Full description |

Standard name | GO_ORGANELLE_SUBCOMPARTMENT
Systematic name | M17833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A compartment that consists of a lumen and an enclosing membrane, and is part of an organelle. [GOC:mah, GOC:pz]
Full description |

Standard name | GO_GOLGI_CISTERNA
Systematic name | M17235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the thin, flattened membrane-bounded compartments that form the central portion of the Golgi complex. [GOC:mah]
Full description |

Standard name | GO_EARLY_PHAGOSOME
Systematic name | M25757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-bounded intracellular vesicle as initially formed upon the ingestion of particulate material by phagocytosis. [GOC:mah, PMID:12388753]
Full description |

Standard name | GO_PHAGOLYSOSOME
Systematic name | M25758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-bounded intracellular vesicle formed by maturation of an early phagosome following the ingestion of particulate material by phagocytosis; during maturation, phagosomes acquire markers of late endosomes and lysosomes. [GOC:mah, PMID:12388753]
Full description |

Standard name | GO_INTEGRATOR_COMPLEX
Systematic name | M17630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that stably associates with the C-terminus of RNA polymerase II and mediates 3'-end processing of small nuclear RNAs generated by RNA polymerase II. [PMID:16239144]
Full description |

Standard name | GO_SMALL_SUBUNIT_PROCESSOME
Systematic name | M17415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large ribonucleoprotein complex that is an early preribosomal complex. In S. cerevisiae, it has a size of 80S and consists of the 35S pre-rRNA, early-associating ribosomal proteins most of which are part of the small ribosomal subunit, the U3 snoRNA and associated proteins. [GOC:krc, GOC:vw, PMID:12068309, PMID:12957375, PMID:15120992, PMID:15590835]
Full description |

Standard name | GO_GUANYL_NUCLEOTIDE_EXCHANGE_FACTOR_COMPLEX
Systematic name | M25759
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that stimulates the exchange of guanyl nucleotides associated with a GTPase. [GOC:mah]
Full description |

Standard name | GO_BLEB
Systematic name | M25760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell extension caused by localized decoupling of the cytoskeleton from the plasma membrane and characterized by rapid formation, rounded shape, and scarcity of organelles within the protrusion. Blebs are formed during apoptosis and other cellular processes, including cell locomotion, cell division, and as a result of physical or chemical stresses. [GOC:mtg_apoptosis, PMID:12083798, PMID:16624291, Wikipedia:Bleb_(cell_biology)]
Full description |

Standard name | GO_DENSE_CORE_GRANULE_MEMBRANE
Systematic name | M34349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a dense core granule. [GOC:mah]
Full description |

Standard name | GO_CHROMOSOME_PASSENGER_COMPLEX
Systematic name | M25761
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A eukaryotically conserved protein complex that localizes to kinetochores in early mitosis, the spindle mid-zone in anaphase B and to the telophase midbody. It has been proposed that the passenger complex coordinates various events based on its location to different structures during the course of mitosis. Complex members include the BIR-domain-containing protein Survivin, Aurora kinase, INCENP and Borealin. [GOC:vw, PMID:16824200, PMID:19570910]
Full description |

Standard name | GO_CELL_DIVISION_SITE
Systematic name | M17397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The eventual plane of cell division (also known as cell cleavage or cytokinesis) in a dividing cell. In Eukaryotes, the cleavage apparatus, composed of septin structures and the actomyosin contractile ring, forms along this plane, and the mitotic, or meiotic, spindle is aligned perpendicular to the division plane. In bacteria, the cell division site is generally located at mid-cell and is the site at which the cytoskeletal structure, the Z-ring, assembles. [GOC:bf, GOC:imk, GOC:krc, GOC:ns, PMID:12101122, PMID:15380095, PMID:16983191, PMID:18165305]
Full description |

Standard name | GO_CLEAVAGE_FURROW
Systematic name | M25762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The cleavage furrow is a plasma membrane invagination at the cell division site. The cleavage furrow begins as a shallow groove and eventually deepens to divide the cytoplasm. [GOC:vw, ISBN:0805319409]
Full description |

Standard name | GO_SEPTIN_CYTOSKELETON
Systematic name | M25763
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The part of the cytoskeleton (the internal framework of a cell) composed of septins and associated proteins. Includes septin cytoskeleton-associated complexes. [GOC:mah]
Full description |

Standard name | GO_SYMMETRIC_SYNAPSE
Systematic name | M25764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A synapse that lacks an electron dense postsynaptic specialization. In vertebtrates, these occur primarily on dendrite shafts and neuronal cell bodies and involve persynapses containing clusters of predominantly flattened or elongated vesicles and are typcially inhibitory. [GOC:dgh, GOC:ef]
Full description |

Standard name | GO_AMPA_GLUTAMATE_RECEPTOR_COMPLEX
Systematic name | M17189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An assembly of four or five subunits which form a structure with an extracellular N-terminus and a large loop that together form the ligand binding domain. The C-terminus is intracellular. The ionotropic glutamate receptor complex itself acts as a ligand gated ion channel; on binding glutamate, charged ions pass through a channel in the center of the receptor complex. The AMPA receptors mediate fast synaptic transmission in the CNS and are composed of subunits GluR1-4, products from separate genes. These subunits have an extracellular N-terminus and an intracellular C-terminus. [GOC:ef]
Full description |

Standard name | GO_MISMATCH_REPAIR_COMPLEX
Systematic name | M17469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any complex formed of proteins that act in mismatch repair. [GOC:mah]
Full description |

Standard name | GO_MUTLALPHA_COMPLEX
Systematic name | M25765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterodimer involved in the recognition of base-base and small insertion/deletion mismatches. In human the complex consists of two subunits, MLH1 and PMS2. [GOC:vk]
Full description |

Standard name | GO_PHOTORECEPTOR_CONNECTING_CILIUM
Systematic name | M17515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the photoreceptor cell cilium linking the photoreceptor inner and outer segments. It's considered to be equivalent to the ciliary transition zone. [GOC:cilia, PMID:15917207, PMID:22653444, PMID:8718680]
Full description |

Standard name | GO_STEREOCILIUM_BUNDLE
Systematic name | M17285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A bundle of cross-linked stereocilia, arranged around a kinocilium on the apical surface of a sensory hair cell (e.g. a neuromast, auditory or vestibular hair cell). Stereocilium bundles act as mechanosensory organelles by responding to fluid motion or fluid pressure changes. [GOC:ecd, PMID:15661519, PMID:7840137]
Full description |

Standard name | GO_STEREOCILIUM_TIP
Systematic name | M25766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A distinct compartment at the tip of a stereocilium, distal to the site of attachment to the apical cell surface. It consists of a dense matrix bridging the barbed ends of the stereocilium actin filaments with the overlying plasma membrane, is dynamic compared to the shaft, and is required for stereocilium elongation. [GOC:ecd, GOC:krc, PMID:17021180, PMID:27565685]
Full description |

Standard name | GO_ACTIN_FILAMENT_BUNDLE
Systematic name | M17227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An assembly of actin filaments that are on the same axis but may be oriented with the same or opposite polarities and may be packed with different levels of tightness. [GOC:mah]
Full description |

Standard name | GO_FILOPODIUM_TIP
Systematic name | M17468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The end of a filopodium distal to the body of the cell. [GOC:mah]
Full description |

Standard name | GO_CUTICULAR_PLATE
Systematic name | M25767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A dense network of actin filaments found beneath the apical cell surface of hair cells, and into which stereocilia are inserted. [PMID:12485990, PMID:2592408, PMID:8071151]
Full description |

Standard name | GO_CORTICAL_ENDOPLASMIC_RETICULUM
Systematic name | M25768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cortical network of highly dynamic tubules that are juxtaposed to the plasma membrane and undergo ring closure and tubule-branching movements. [GOC:se, PMID:10931860, PMID:17686782]
Full description |

Standard name | GO_GOLGI_CISTERNA_MEMBRANE
Systematic name | M17806
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding any of the thin, flattened compartments that form the central portion of the Golgi complex. [GOC:ecd, GOC:mah]
Full description |

Standard name | GO_GROWTH_CONE_MEMBRANE
Systematic name | M25769
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a growth cone. [GOC:mah]
Full description |

Standard name | GO_MULTIVESICULAR_BODY_MEMBRANE
Systematic name | M25770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a multivesicular body. [GOC:mah]
Full description |

Standard name | GO_RUFFLE_MEMBRANE
Systematic name | M17416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a ruffle. [GOC:mah]
Full description |

Standard name | GO_TRANS_GOLGI_NETWORK_MEMBRANE
Systematic name | M17785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding any of the compartments that make up the trans-Golgi network. [GOC:mah]
Full description |

Standard name | GO_NEURON_PROJECTION_MEMBRANE
Systematic name | M17629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a neuron projection. [GOC:mah]
Full description |

Standard name | GO_DENDRITE_MEMBRANE
Systematic name | M17494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a dendrite. [GOC:mah]
Full description |

Standard name | GO_DENDRITIC_SPINE_MEMBRANE
Systematic name | M25771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a dendritic spine. [GOC:mah]
Full description |

Standard name | GO_INSULIN_RESPONSIVE_COMPARTMENT
Systematic name | M25772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A small membrane-bounded vesicle that releases its contents by exocytosis in response to insulin stimulation; the contents are enriched in GLUT4, IRAP and VAMP2. [PMID:17644329]
Full description |

Standard name | GO_SUPER_ELONGATION_COMPLEX
Systematic name | M25773
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transcription elongation factor complex that increases the overall rate of RNA polymerase II transcription elongation by suppressing transient polymerase pausing. At minimum, the complex contains a transcription factor of the ELL family, an EAF protein, and an AFF family protein or distant relative and most likely also P-TEFb and AF9 or ENL. The complex is conserved from yeast to humans. In Schizosaccharomyces pombe it contains Ell1, Eaf1, and Ebp1, but it is absent from S. cerevisiae. [PMID:17150956, PMID:30102332]
Full description |

Standard name | GO_SMN_COMPLEX
Systematic name | M17107
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains the survival motor neuron (SMN) protein and at least eight additional integral components, including the Gemin2-8 and Unrip proteins; the complex is found in the cytoplasm and in nuclear Gems, and is involved in spliceosomal snRNP assembly in the cytoplasm and in pre-mRNA splicing in the nucleus. [PMID:16434402, PMID:17023415]
Full description |

Standard name | GO_CARBOXY_TERMINAL_DOMAIN_PROTEIN_KINASE_COMPLEX
Systematic name | M17579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that phosphorylates amino acid residues of RNA polymerase II C-terminal domain repeats; phosphorylation occurs mainly on Ser2 and Ser5. [PMID:15047695, PMID:16721054, PMID:17079683]
Full description |

Standard name | GO_PLASMA_MEMBRANE_BOUNDED_CELL_PROJECTION_CYTOPLASM
Systematic name | M25774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | All of the contents of a plasma membrane bounded cell projection, excluding the plasma membrane surrounding the projection. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_DENDRITE_CYTOPLASM
Systematic name | M17689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | All of the contents of a dendrite, excluding the surrounding plasma membrane. [GOC:mah]
Full description |

Standard name | GO_MYOSIN_FILAMENT
Systematic name | M17213
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A supramolecular fiber containing myosin heavy chains, plus associated light chains and other proteins, in which the myosin heavy chains are arranged into a filament. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_DNA_COMPLEX
Systematic name | M17281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A macromolecular complex containing both protein and DNA molecules. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_LIPID_COMPLEX
Systematic name | M17754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A macromolecular complex containing separate protein and lipid molecules. Separate in this context means not covalently bound to each other. [GOC:mah]
Full description |

Standard name | GO_PARANODAL_JUNCTION
Systematic name | M25776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A highly specialized cell-cell junction found in vertebrates, which forms between a neuron and a glial cell, and has structural similarity to Drosophila septate junctions. It flanks the node of Ranvier in myelinated nerve and electrically isolates the myelinated from unmyelinated nerve segments and physically separates the voltage-gated sodium channels at the node from the cluster of potassium channels underneath the myelin sheath. [PMID:11395001, PMID:14630217]
Full description |

Standard name | GO_SARCOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M17070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding the sarcoplasmic reticulum. [GOC:rph]
Full description |

Standard name | GO_SARCOPLASMIC_RETICULUM_LUMEN
Systematic name | M25777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membranes of the sarcoplasmic reticulum. [GOC:rph]
Full description |

Standard name | GO_DNA_RECOMBINASE_MEDIATOR_COMPLEX
Systematic name | M25778
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex containing accessory proteins which bind a recombinase (e.g. Rad51) and bind single-stranded DNA (ssDNA), and promote nucleation of the recombinase onto ssDNA through facilitating recombinase-RPA exchange. [GOC:elh, GOC:mah, GOC:vw, InterPro:IPR003488, PMID:12912992, PMID:32414915]
Full description |

Standard name | GO_WEIBEL_PALADE_BODY
Systematic name | M25779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large, elongated, rod-shaped secretory granule characteristic of vascular endothelial cells that contain a number of structurally and functionally distinct proteins, of which the best characterized are von Willebrand factor (VWF) and P-selectin. Weibel-Palade bodies are formed from the trans-Golgi network in a process that depends on VWF, which is densely packed in a highly organized manner, and on coat proteins that remain associated with the granules. Upon cell stimulation, regulated exocytosis releases the contained proteins to the cell surface, where they act in the recruitment of platelets and leukocytes and in inflammatory and vasoactive responses. [PMID:11935287, PMID:16087708]
Full description |

Standard name | GO_CIS_GOLGI_NETWORK_MEMBRANE
Systematic name | M25780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding any of the compartments that make up the cis-Golgi network. [GOC:mah]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_GOLGI_INTERMEDIATE_COMPARTMENT_MEMBRANE
Systematic name | M17564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding any of the compartments of the endoplasmic reticulum (ER)-Golgi intermediate compartment system. [GOC:mah, GOC:pr, PMID:16723730]
Full description |

Standard name | GO_MELANOSOME_MEMBRANE
Systematic name | M25781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a melanosome. [GOC:mah]
Full description |

Standard name | GO_INTERPHOTORECEPTOR_MATRIX
Systematic name | M34350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized extracellularc matrix that surrounds the photoreceptors of the retina and lies between them and the apical surface of the retinal pigment epithelium. The IPM has been implicated in several important activities required for photoreceptor function and maintenance. [http://www.glycoforum.gr.jp/science/hyaluronan/HA17/HA17E.html, PMID:1862095, PMID:2194288]
Full description |

Standard name | GO_PROTON_TRANSPORTING_V_TYPE_ATPASE_COMPLEX
Systematic name | M17752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A proton-transporting two-sector ATPase complex that couples ATP hydrolysis to the transport of protons across a concentration gradient. The resulting transmembrane electrochemical potential of H+ is used to drive a variety of (i) secondary active transport systems via H+-dependent symporters and antiporters and (ii) channel-mediated transport systems. The complex comprises a membrane sector (V0) that carries out proton transport and a cytoplasmic compartment sector (V1) that catalyzes ATP hydrolysis. V-type ATPases are found in the membranes of organelles such as vacuoles, endosomes, and lysosomes, and in the plasma membrane. [GOC:mah, ISBN:0716743663, PMID:16449553]
Full description |

Standard name | GO_PROTON_TRANSPORTING_TWO_SECTOR_ATPASE_COMPLEX_PROTON_TRANSPORTING_DOMAIN
Systematic name | M17136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that forms part of a proton-transporting two-sector ATPase complex and carries out proton transport across a membrane. The proton-transporting domain (F0, V0, or A0) includes integral and peripheral membrane proteins. [GOC:mah, PMID:10838056]
Full description |

Standard name | GO_PROTON_TRANSPORTING_TWO_SECTOR_ATPASE_COMPLEX_CATALYTIC_DOMAIN
Systematic name | M17347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that forms part of a proton-transporting two-sector ATPase complex and catalyzes ATP hydrolysis or synthesis. The catalytic domain (F1, V1, or A1) comprises a hexameric catalytic core and a central stalk, and is peripherally associated with the membrane when the two-sector ATPase is assembled. [GOC:mah, PMID:10838056]
Full description |

Standard name | GO_PROTON_TRANSPORTING_V_TYPE_ATPASE_V0_DOMAIN
Systematic name | M25782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that forms part of a proton-transporting V-type ATPase and mediates proton transport across a membrane. The V0 complex consists of at least four different subunits (a,c,d and e); six or more c subunits form a proton-binding rotor ring. [GOC:mah, ISBN:0716743663, PMID:16449553]
Full description |

Standard name | GO_PROTON_TRANSPORTING_V_TYPE_ATPASE_V1_DOMAIN
Systematic name | M25783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that forms part of a proton-transporting V-type ATPase and catalyzes ATP hydrolysis. The V1 complex consists of: (1) a globular headpiece with three alternating copies of subunits A and B that form a ring, (2) a central rotational stalk composed of single copies of subunits D and F, and (3) a peripheral stalk made of subunits C, E, G and H. Subunits A and B mediate the hydrolysis of ATP at three reaction sites associated with subunit A. [GOC:mah, ISBN:0716743663, PMID:16449553]
Full description |

Standard name | GO_DNA_HELICASE_COMPLEX
Systematic name | M17539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that possesses DNA helicase activity. [GOC:mah]
Full description |

Standard name | GO_CORVET_COMPLEX
Systematic name | M34351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multimeric protein complex that acts as an endosomal tethering complex (CORVET = class C core vacuole/endosome tethering) by cooperating with Rab GTPases to capture endosomal vesicles and trap them prior to the action of SNAREs; the complex is involved in endo-lysosomal biogenesis and required for transport between endosome and vacuole. The Saccharomyces cerevisiae complex contains Vps8p, Vps3p, Pep5p, Vps16p, Pep3p, and Vps33p. [PMID:17488625]
Full description |

Standard name | GO_NODE_OF_RANVIER
Systematic name | M17250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An axon part that is a gap in the myelin where voltage-gated sodium channels cluster and saltatory conduction is executed. [GOC:mh]
Full description |

Standard name | GO_PARANODE_REGION_OF_AXON
Systematic name | M17277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An axon part that is located adjacent to the nodes of Ranvier and surrounded by lateral loop portions of myelin sheath. [GOC:mah, GOC:mh, NIF_Subcellular:sao936144858]
Full description |

Standard name | GO_TRANSCRIPTION_FACTOR_TFTC_COMPLEX
Systematic name | M17338
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that does not contain either a TATA-binding protein (TBP) or a TBP-like factor, but is composed of several TAFIIs and other proteins, including a histone acetyltransferase. This complex is able to nucleate transcription initiation by RNA polymerase II, can mediate transcriptional activation, and has histone acetyltransferase activity. [PMID:10373431, PMID:9603525]
Full description |

Standard name | GO_EUKARYOTIC_48S_PREINITIATION_COMPLEX
Systematic name | M25784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex composed of the small ribosomal subunit, eIF3, eIF1A, methionyl-initiatior methionine and a capped mRNA. The complex is initially positioned at the 5'-end of the capped mRNA. [GOC:hjd, PMID:15145049]
Full description |

Standard name | GO_CHROMATOID_BODY
Systematic name | M17649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex found in the cytoplasm of male germ cells, composed of exceedingly thin filaments that are consolidated into a compact mass or into dense strands of varying thickness that branch to form an irregular network. Contains mRNAs, miRNAs, and protein components involved in miRNA processing (such as Argonaute proteins and the endonuclease Dicer) and in RNA decay (such as the decapping enzyme DCP1a and GW182). [PMID:17183363]
Full description |

Standard name | GO_HULC_COMPLEX
Systematic name | M25785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin-conjugating enzyme complex that contains two RING finger proteins, which have ubiquitin ligase activity, in addition to a protein with ubiquitin-conjugating enzyme activity; catalyzes the ubiquitination of histone H2B at lysine 119 (or the equivalent residue). In Schizosaccharomyces the subunits are Rhp1, Brl2/Rfp1 and Brl1/Rfp2. [GOC:mah, PMID:17363370, PMID:17374714]
Full description |

Standard name | GO_RDNA_HETEROCHROMATIN
Systematic name | M25786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A region of heterochromatin located at the rDNA repeats in a chromosome. [GOC:mah]
Full description |

Standard name | GO_ELONGATOR_HOLOENZYME_COMPLEX
Systematic name | M25787
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterohexameric protein complex that is involved in modification of wobble nucleosides in tRNA. The complex can associate physically with hyperphosphorylated RNA polymerase II; it contains two discrete heterotrimeric subcomplexes. [GOC:bhm, GOC:jh, GOC:mah, GOC:vw, PMID:11435442, PMID:11689709, PMID:15769872, PMID:17018299, PMID:18755837, PMID:23165209]
Full description |

Standard name | GO_HOST_CELL_PART
Systematic name | M25788
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any constituent part of a host cell. The host is defined as the larger of the organisms involved in a symbiotic interaction. [GOC:pamgo_curators]
Full description |

Standard name | GO_HOST_INTRACELLULAR_ORGANELLE
Systematic name | M25790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Organized structure of distinctive morphology and function, occurring within the host cell. Includes the nucleus, mitochondria, plastids, vacuoles, vesicles, ribosomes and the cytoskeleton. Excludes the plasma membrane. The host is defined as the larger of the organisms involved in a symbiotic interaction. [GOC:pamgo_curators]
Full description |

Standard name | GO_PHAGOPHORE_ASSEMBLY_SITE_MEMBRANE
Systematic name | M25791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cellular membrane associated with the phagophore assembly site. [GOC:mah, GOC:rph, PMID:16874040, PMID:17382324]
Full description |

Standard name | GO_VCP_NPL4_UFD1_AAA_ATPASE_COMPLEX
Systematic name | M25792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiprotein ATPase complex required for the efficient dislocation of ER-lumenal degradation substrates, and their subsequent proteolysis by the proteasome. In budding yeast, this complex includes Cdc48p, Npl4p and Ufd1p proteins. In mammals, this complex includes a hexamer of VCP/p97 (a cytosolic ATPase) and trimers of each of its cofactors UFD1L and NPL4 (NPLOC4) (e.g. a 6:3:3 stoichiometry). [PMID:11813000, PMID:16179952]
Full description |

Standard name | GO_LOW_DENSITY_LIPOPROTEIN_PARTICLE
Systematic name | M16983
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A lipoprotein particle, rich in cholesterol esters and low in triglycerides that is typically composed of APOB100 and APOE and has a density of 1.02-1.06 g/ml and a diameter of between 20-25 nm. LDL particles are formed from VLDL particles (via IDL) by the loss of triglyceride and gain of cholesterol ester. They transport endogenous cholesterol (and to some extent triglycerides) from peripheral tissues back to the liver. [GOC:BHF, GOC:expert_pt, GOC:mah, GOC:rl]
Full description |

Standard name | GO_INTERMEDIATE_DENSITY_LIPOPROTEIN_PARTICLE
Systematic name | M25793
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A triglyceride-rich lipoprotein particle that typically contains APOB100, APOE and APOCs and has a density of 1.006-1.019 g/ml and a diameter of between 25-30 nm. IDL particles are found in blood and are formed by the delipidation of very-low-density lipoprotein particles (VLDL). IDL particles are removed from blood by the liver, following binding to the APOE receptor, or are converted to low-density lipoprotein (LDL). [GOC:BHF, GOC:expert_pt, GOC:mah, GOC:rl]
Full description |

Standard name | GO_HIGH_DENSITY_LIPOPROTEIN_PARTICLE
Systematic name | M17271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A lipoprotein particle with a high density (typically 1.063-1.21 g/ml) and a diameter of 5-10 nm that contains APOAs and may contain APOCs and APOE; found in blood and carries lipids from body tissues to the liver as part of the reverse cholesterol transport process. [GOC:BHF, GOC:expert_pt, GOC:mah, GOC:pde, GOC:rl]
Full description |

Standard name | GO_SPHERICAL_HIGH_DENSITY_LIPOPROTEIN_PARTICLE
Systematic name | M25794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A mature high-density lipoprotein (HDL) particle, converted from discoidal HDL particles following the esterification of cholesterol in the particle by phosphatidylcholine-sterol O-acyltransferase (lecithin cholesterol acyltransferase; LCAT). [GOC:BHF, GOC:expert_pt, GOC:mah, GOC:rl]
Full description |

Standard name | GO_TRIGLYCERIDE_RICH_PLASMA_LIPOPROTEIN_PARTICLE
Systematic name | M25795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A plasma lipoprotein particle that has a hydrophobic core enriched in triglycerides surrounded by an amphipathic monolayer of phospholipids, cholesterol and apolipoproteins. Triglyceride-rich lipoprotein particles transport lipids, which are non-covalently associated with the particles, in the blood. [GOC:BHF, GOC:mah, GOC:rl]
Full description |

Standard name | GO_PWP2P_CONTAINING_SUBCOMPLEX_OF_90S_PRERIBOSOME
Systematic name | M25796
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that forms a subcomplex of the 90S preribosome and can interact directly with the 5' External Transcribed Spacer (ETS) of the full length pre-rRNA transcript. In S. cerevisiae, it sediments at 25-30 S and is composed of Pwp2p, Dip2p, Utp21p, Utp13p, Utp18p, and Utp6p. [GOC:krc, PMID:15231838]
Full description |

Standard name | GO_NUCLEAR_PERIPHERY
Systematic name | M17642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the nuclear lumen proximal to the inner nuclear membrane. [GOC:krc, GOC:mah]
Full description |

Standard name | GO_CENTRIOLAR_SATELLITE
Systematic name | M17813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A small (70-100 nm) cytoplasmic granule that contains a number of centrosomal proteins; centriolar satellites traffic toward microtubule minus ends and are enriched near the centrosome. [GOC:BHF, PMID:10579718, PMID:12403812]
Full description |

Standard name | GO_BBSOME
Systematic name | M25798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ciliary protein complex involved in cilium biogenesis. It consists of at least seven Bardet-Biedl syndrome (BBS) proteins and BBIP10. It moves in association with IFT trains through cilia (likely as an IFT-A/B adaptor or cargo), and is required for the integrity of IFT-A and IFT-B. [GOC:BHF, GOC:cilia, PMID:15231740, PMID:17574030, PMID:26498262]
Full description |

Standard name | GO_RNA_CAP_BINDING_COMPLEX
Systematic name | M16982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that binds to a specialized RNA cap structure at any time in the lifetime of the RNA. [GOC:mah]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_CHAPERONE_COMPLEX
Systematic name | M17527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that is located in the endoplasmic reticulum and is composed of chaperone proteins, including BiP, GRP94; CaBP1, protein disulfide isomerase (PDI), ERdj3, cyclophilin B, ERp72, GRP170, UDP-glucosyltransferase, and SDF2-L1. [PMID:12475965]
Full description |

Standard name | GO_CATION_CHANNEL_COMPLEX
Systematic name | M17419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An ion channel complex through which cations pass. [GOC:mah]
Full description |

Standard name | GO_CALCIUM_CHANNEL_COMPLEX
Systematic name | M17744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An ion channel complex through which calcium ions pass. [GOC:mah]
Full description |

Standard name | GO_POTASSIUM_CHANNEL_COMPLEX
Systematic name | M17240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An ion channel complex through which potassium ions pass. [GOC:mah]
Full description |

Standard name | GO_SODIUM_CHANNEL_COMPLEX
Systematic name | M17205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An ion channel complex through which sodium ions pass. [GOC:mah]
Full description |

Standard name | GO_CHLORIDE_CHANNEL_COMPLEX
Systematic name | M17409
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An ion channel complex through which chloride ions pass. [GOC:mah]
Full description |

Standard name | GO_METHYLTRANSFERASE_COMPLEX
Systematic name | M17425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that possesses methyltransferase activity. [GOC:mah]
Full description |

Standard name | GO_METHYLOSOME
Systematic name | M17804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large (20 S) protein complex that possesses protein arginine methyltransferase activity and modifies specific arginines to dimethylarginines in the arginine- and glycine-rich domains of several spliceosomal Sm proteins, thereby targeting these proteins to the survival of motor neurons (SMN) complex for assembly into small nuclear ribonucleoprotein (snRNP) core particles. Proteins found in the methylosome include the methyltransferase JBP1 (PRMT5), pICln (CLNS1A), MEP50 (WDR77), and unmethylated forms of SM proteins that have RG domains. [PMID:11713266, PMID:11756452]
Full description |

Standard name | GO_PICLN_SM_PROTEIN_COMPLEX
Systematic name | M25799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains pICln (CLNS1A) and several Sm proteins, including SmD1, SmD2, SmE, SmF, and SmG. [GOC:mah, PMID:11713266]
Full description |

Standard name | GO_SMN_SM_PROTEIN_COMPLEX
Systematic name | M17556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex formed by the association of several methylated Sm proteins with the SMN complex; the latter contains the survival motor neuron (SMN) protein and at least eight additional integral components, including the Gemin2-8 and unrip proteins; additional proteins, including galectin-1 and galectin-3, are also found in the SMN-SM complex. The SMN-Sm complex is involved in spliceosomal snRNP assembly in the cytoplasm. [GOC:vw, PMID:11522829, PMID:17401408]
Full description |

Standard name | GO_MICROTUBULE_ORGANIZING_CENTER_ATTACHMENT_SITE
Systematic name | M29425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A region of the nuclear envelope to which a microtubule organizing center (MTOC) attaches; protein complexes embedded in the nuclear envelope mediate direct or indirect linkages between the microtubule cytoskeleton and the nuclear envelope. [GOC:mah, PMID:18692466]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_KINASE_COMPLEX_CLASS_III
Systematic name | M25800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A phosphatidylinositol 3-kinase complex that contains a catalytic class III phosphoinositide 3-kinase (PI3K) subunit bound to a regulatory (adaptor) subunit. Additional adaptor proteins may be present. Class III PI3Ks have a substrate specificity restricted to phosphatidylinositol (PI). [GOC:bf, PMID:9255069]
Full description |

Standard name | GO_INTERCHROMATIN_GRANULE
Systematic name | M34352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A class of nuclear body measuring 20-25 nm in diameter and distributed throughout the interchromatin space, linked together by thin fibrils. They are believed to be storage centers for various snRNAs, snRNPs, serine/arginine-rich proteins and RNA polymerase II. A typical mammalian cell contains 25-50 clusters of interchromatin granules. Interchromatin granule clusters do not contain the heterogeneous nuclear RNA-binding proteins (hnRNPs). [GOC:bf, PMID:10984439]
Full description |

Standard name | GO_HISTONE_METHYLTRANSFERASE_COMPLEX
Systematic name | M17390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multimeric complex that is able to catalyze the addition of methyl groups to histone proteins. [GOC:bf]
Full description |

Standard name | GO_ESC_E_Z_COMPLEX
Systematic name | M17640
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multimeric protein complex that can methylate lysine-27 and lysine-9 residues of histone H3. In Drosophila the core subunits of the complex include ESC, E(Z), CAF1 (NURF-55) and SU(Z)12. In mammals the core subunits of the complex include EED, EZH2, SUZ12 and RBBP4. [GOC:bf, GOC:sp, PMID:12408863, PMID:12408864, PMID:20064375]
Full description |

Standard name | GO_PRC1_COMPLEX
Systematic name | M17402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiprotein complex that mediates monoubiquitination of lysine residues of histone H2A (lysine-118 in Drosophila or lysine-119 in mammals). The complex is required for stable long-term maintenance of transcriptionally repressed states and is involved in chromatin remodeling. [GOC:bf, PMID:10412979]
Full description |

Standard name | GO_EXON_EXON_JUNCTION_COMPLEX
Systematic name | M17292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multi-subunit complex deposited by the spliceosome upstream of messenger RNA exon-exon junctions. The exon-exon junction complex provides a binding platform for factors involved in mRNA export and nonsense-mediated mRNA decay. [PMID:11532962, PMID:11743026]
Full description |

Standard name | GO_CILIARY_ROOTLET
Systematic name | M25802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cytoskeleton-like structure, originating from the basal body at the proximal end of a cilium, and extending proximally toward the cell nucleus. Rootlets are typically 80-100 nm in diameter and contain cross striae distributed at regular intervals of approximately 55-70 nm. [GOC:cilia, PMID:12427867]
Full description |

Standard name | GO_TRANSCRIPTIONALLY_ACTIVE_CHROMATIN
Systematic name | M17525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The ordered and organized complex of DNA and protein that forms regions of the chromosome that are being actively transcribed. [GOC:sart, PMID:17965872]
Full description |

Standard name | GO_MICROTUBULE_PLUS_END
Systematic name | M17391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The growing (plus) end of a microtubule. In vitro, microtubules polymerize more quickly at the plus end than at the minus end. In vivo, microtubule growth occurs only at the plus end, and the plus end switches between periods of growth and shortening, a behavior known as dynamic instability. [GOC:bf, GOC:lb, PMID:12700769, PMID:16643273]
Full description |

Standard name | GO_AZUROPHIL_GRANULE_MEMBRANE
Systematic name | M25803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding an azurophil granule, a primary lysosomal granule found in neutrophil granulocytes that contains a wide range of hydrolytic enzymes and is released into the extracellular fluid. [GOC:bf, PMID:17152095]
Full description |

Standard name | GO_AZUROPHIL_GRANULE_LUMEN
Systematic name | M25804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membrane of an azurophil granule, a primary lysosomal granule found in neutrophil granulocytes that contains a wide range of hydrolytic enzymes and is released into the extracellular fluid. [GOC:bf, PMID:17152095]
Full description |

Standard name | GO_SPECIFIC_GRANULE_MEMBRANE
Systematic name | M25805
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a specific granule, a granule with a membranous, tubular internal structure, found primarily in mature neutrophil cells. Most are released into the extracellular fluid. Specific granules contain lactoferrin, lysozyme, vitamin B12 binding protein and elastase. [GOC:bf, PMID:7334549]
Full description |

Standard name | GO_SPECIFIC_GRANULE_LUMEN
Systematic name | M25806
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membrane of a specific granule, a granule with a membranous, tubular internal structure, found primarily in mature neutrophil cells. Most are released into the extracellular fluid. Specific granules contain lactoferrin, lysozyme, vitamin B12 binding protein and elastase. [GOC:bf, PMID:7334549]
Full description |

Standard name | GO_CD40_RECEPTOR_COMPLEX
Systematic name | M17111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains at least CD40 (a cell surface receptor of the tumour necrosis factor receptor (TNFR) superfamily), and other signaling molecules. [GOC:BHF, PMID:20614026, PMID:9221764]
Full description |

Standard name | GO_MON1_CCZ1_COMPLEX
Systematic name | M25807
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that functions as a guanine nucleotide exchange factor (GEF) and converts Rab-GDP to Rab-GTP. In S. cerevisiae, this complex consists of at least Mon1 and Ccz1, and serves as a GEF for the Rab Ypt7p. [GOC:rb, PMID:20797862]
Full description |

Standard name | GO_SPERM_FIBROUS_SHEATH
Systematic name | M25808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cytoskeletal structure surrounding the axoneme and outer dense fibers of the sperm flagellum. Consists of two longitudinal columns connected by closely arrayed semicircular ribs that assemble from distal to proximal throughout spermiogenesis. The fibrous sheath probably influences the degree of flexibility, plane of flagellar motion, and the shape of the flagellar beat. [GOC:BHF, GOC:cilia, GOC:krc, PMID:20731842, PMID:3282552]
Full description |

Standard name | GO_MYELIN_SHEATH_ABAXONAL_REGION
Systematic name | M25809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of the myelin sheath furthest from the axon. [GOC:BHF, PMID:20237282]
Full description |

Standard name | GO_MYELIN_SHEATH_ADAXONAL_REGION
Systematic name | M25810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of the myelin sheath nearest to the axon. [GOC:BHF, PMID:20237282]
Full description |

Standard name | GO_RIBONUCLEOPROTEIN_GRANULE
Systematic name | M17325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A non-membranous macromolecular complex containing proteins and translationally silenced mRNAs. RNA granules contain proteins that control the localization, stability, and translation of their RNA cargo. Different types of RNA granules (RGs) exist, depending on the cell type and cellular conditions. [GOC:go_curators, GOC:sp, PMID:16520386, PMID:20368989, PMID:21436445]
Full description |

Standard name | GO_SEH1_ASSOCIATED_COMPLEX
Systematic name | M25811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that associates dynamically with the vacuolar membrane, and is proposed to have a role in membrane-associated trafficking or regulatory processes. In S. cerevisiae the complex contains Seh1p, Sec13p, Npr2p, Npr3p, Iml1p, Mtc5p, Rtc1p, and Sea4p. [GOC:jh, PMID:21454883, PMID:23974112]
Full description |

Standard name | GO_SITE_OF_DOUBLE_STRAND_BREAK
Systematic name | M17800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A region of a chromosome at which a DNA double-strand break has occurred. DNA damage signaling and repair proteins accumulate at the lesion to respond to the damage and repair the DNA to form a continuous DNA helix. [GOC:bf, GOC:mah, GOC:vw, PMID:20096808, PMID:21035408]
Full description |

Standard name | GO_CILIARY_TRANSITION_ZONE
Systematic name | M17385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A region of the cilium between the basal body and proximal segment that is characterized by Y-shaped assemblages that connect axonemal microtubules to the ciliary membrane. The ciliary transition zone appears to function as a gate that controls ciliary membrane composition and separates the cytosol from the ciliary plasm. [GOC:cilia, GOC:kmv, PMID:21422230]
Full description |

Standard name | GO_ENDOLYSOSOME
Systematic name | M16986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An transient hybrid organelle formed by fusion of a late endosome with a lysosome, and in which active degradation takes place. [GOC:pde, PMID:21878991]
Full description |

Standard name | GO_ENDOLYSOSOME_MEMBRANE
Systematic name | M17477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding an endolysosome. An endolysosome is a transient hybrid organelle formed by fusion of a late endosome with a lysosome. [GOC:pde]
Full description |

Standard name | GO_ENDOLYSOSOME_LUMEN
Systematic name | M25813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membrane of an endolysosome. An endolysosome is a transient hybrid organelle formed by fusion of a late endosome with a lysosome. [GOC:pde]
Full description |

Standard name | GO_MKS_COMPLEX
Systematic name | M25814
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that is located at the ciliary transition zone and consists of several proteins some of which are membrane bound. Acts as an organiser of transition zone inner structure, specifically the Y-shaped links, in conjunction with the NPHP complex. The MKS complex also acts as part of the selective barrier that prevents diffusion of proteins between the ciliary cytoplasm and cellular cytoplasm as well as between the ciliary membrane and plasma membrane. [GOC:cilia, GOC:sp, PMID:21422230, PMID:21565611, PMID:21725307, PMID:22179047, PMID:25869670, PMID:26595381, PMID:26982032]
Full description |

Standard name | GO_FILTRATION_DIAPHRAGM
Systematic name | M25815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized cell-cell junction found between the cells of the excretory system, which provides a barrier for filtration of blood or hemolymph. [GOC:mtg_kidney_jan10, GOC:sart, PMID:18971929]
Full description |

Standard name | GO_CILIARY_BASAL_BODY
Systematic name | M17784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-tethered, short cylindrical array of microtubules and associated proteins found at the base of a eukaryotic cilium (also called flagellum) that is similar in structure to a centriole and derives from it. The cilium basal body is the site of assembly and remodelling of the cilium and serves as a nucleation site for axoneme growth. As well as anchoring the cilium, it is thought to provide a selective gateway regulating the entry of ciliary proteins and vesicles by intraflagellar transport. [GOC:cilia, GOC:clt, PMID:21750193]
Full description |

Standard name | GO_CATSPER_COMPLEX
Systematic name | M25816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A sperm-specific voltage-gated calcium channel that controls the intracellular calcium ion concentration and, thereby, the swimming behavior of sperm. Consists of a heteromeric tetramer surrounding a calcium ion- selective pore. May also contain additional auxiliary subunits. [GOC:sp, PMID:17478420, PMID:21224844, PMID:22354039]
Full description |

Standard name | GO_OUTER_DYNEIN_ARM
Systematic name | M25817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Outer arm structure present on the outer doublet microtubules of ciliary and flagellar axonemes. Outer dynein arms contain 2-3 heavy chains, two or more intermediate chains and a cluster of 4-8 light chains. Inner and outer dynein arms have different functions in the generation of microtubule-based motility. [GOC:BHF, GOC:vk, PMID:2557057, PMID:6218174]
Full description |

Standard name | GO_MYOFILAMENT
Systematic name | M17139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the smallest contractile units of a myofibril (striated muscle fiber). [Wikipedia:Myofilament]
Full description |

Standard name | GO_MICROTUBULE_MINUS_END
Systematic name | M25818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The end of a microtubule that does not preferentially grow (polymerize). [GOC:lb, PMID:23169647]
Full description |

Standard name | GO_ESCRT_COMPLEX
Systematic name | M17383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An endosomal sorting complex involved in membrane fission processes related to sorting of multivesicular bodies (MVB) in the endocytic pathway, cytokinesis and viral budding among other processes. [PMID:16689637, VZ:1536]
Full description |

Standard name | GO_GROWTH_FACTOR_COMPLEX
Systematic name | M29426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that has growth factor activity. [GOC:bhm]
Full description |

Standard name | GO_SOMATODENDRITIC_COMPARTMENT
Systematic name | M17678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of a neuron that includes the cell body (cell soma) and dendrite(s), but excludes the axon. [GOC:pad, GOC:PARL]
Full description |

Standard name | GO_DERLIN_1_RETROTRANSLOCATION_COMPLEX
Systematic name | M17821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that functions in the retrotranslocation step of ERAD (ER-associated protein degradation), and includes at its core Derlin-1 oligomers forming a retrotranslocation channel. [GOC:bf, GOC:PARL, PMID:15215856, PMID:16186510]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_RECEPTOR_DIMERIC_COMPLEX
Systematic name | M25819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains two G protein-coupled receptors. [GOC:al, GOC:bf, PMID:10713101]
Full description |

Standard name | GO_TOR_COMPLEX
Systematic name | M17653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains at least TOR (target of rapamycin) in complex with other signaling components. Mediates the phosphorylation and activation of downstream signaling components including PKB (AKT) or S6K. [Wikipedia:MTORC1, Wikipedia:MTORC2]
Full description |

Standard name | GO_HOST_CELL_NUCLEUS
Systematic name | M29427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-bounded organelle as it is found in the host cell in which chromosomes are housed and replicated. The host is defined as the larger of the organisms involved in a symbiotic interaction. [GOC:pamgo_curators]
Full description |

Standard name | GO_T_CELL_RECEPTOR_COMPLEX
Systematic name | M17113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains a disulfide-linked heterodimer of T cell receptor (TCR) chains, which are members of the immunoglobulin superfamily, and mediates antigen recognition, ultimately resulting in T cell activation. The TCR heterodimer is associated with the CD3 complex, which consists of the nonpolymorphic polypeptides gamma, delta, epsilon, zeta, and, in some cases, eta (an RNA splice variant of zeta) or Fc epsilon chains. [GOC:mah, ISBN:0781735149]
Full description |

Standard name | GO_ALPHA_BETA_T_CELL_RECEPTOR_COMPLEX
Systematic name | M25820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A T cell receptor complex in which the TCR heterodimer comprises alpha and beta chains, associated with the CD3 complex; recognizes a complex consisting of an antigen-derived peptide bound to a class I or class II MHC protein. [GOC:mah, ISBN:0781735149]
Full description |

Standard name | GO_NUCLEAR_OUTER_MEMBRANE_ENDOPLASMIC_RETICULUM_MEMBRANE_NETWORK
Systematic name | M17522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The continuous network of membranes encompassing the nuclear outer membrane and the endoplasmic reticulum membrane. [GOC:bf, GOC:jl, GOC:mah, GOC:mcc, GOC:pr, GOC:vw]
Full description |

Standard name | GO_PARASPECKLES
Systematic name | M25821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Discrete subnuclear bodies in the interchromatin nucleoplasmic space, often located adjacent to nuclear specks. 10-20 paraspeckles are typically found in human cell nuclei. [GOC:jl, PMID:11790299]
Full description |

Standard name | GO_SARCOLEMMA
Systematic name | M17632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The outer membrane of a muscle cell, consisting of the plasma membrane, a covering basement membrane (about 100 nm thick and sometimes common to more than one fiber), and the associated loose network of collagen fibers. [ISBN:0198506732]
Full description |

Standard name | GO_NUCLEAR_INCLUSION_BODY
Systematic name | M17134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An intranuclear focus at which aggregated proteins have been sequestered. [GOC:jl]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_ENDOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M25822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the endoplasmic reticulum membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:curators, GOC:dos]
Full description |

Standard name | GO_MCM_COMPLEX
Systematic name | M17187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A hexameric protein complex required for the initiation and regulation of DNA replication. [GOC:jl, PMID:11282021]
Full description |

Standard name | GO_IMMUNOGLOBULIN_COMPLEX_CIRCULATING
Systematic name | M29428
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An immunoglobulin complex that is secreted into extracellular space and found in mucosal areas or other tissues or circulating in the blood or lymph. In its canonical form, a circulating immunoglobulin complex is composed of two identical heavy chains and two identical light chains, held together by disulfide bonds. Some forms of are polymers of the basic structure and contain additional components such as J-chain and the secretory component. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_DNA_POLYMERASE_COMPLEX
Systematic name | M17064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that possesses DNA polymerase activity and is involved in template directed synthesis of DNA. [GOC:jl, PMID:12045093]
Full description |

Standard name | GO_MICROBODY
Systematic name | M17410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Cytoplasmic organelles, spherical or oval in shape, that are bounded by a single membrane and contain oxidative enzymes, especially those utilizing hydrogen peroxide (H2O2). [ISBN:0198506732]
Full description |

Standard name | GO_SPECIFIC_GRANULE
Systematic name | M17358
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Granule with a membranous, tubular internal structure, found primarily in mature neutrophil cells. Most are released into the extracellular fluid. Specific granules contain lactoferrin, lysozyme, vitamin B12 binding protein and elastase. [GOC:jl, ISBN:0721662544, PMID:7334549]
Full description |

Standard name | GO_AZUROPHIL_GRANULE
Systematic name | M25823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Primary lysosomal granule found in neutrophil granulocytes. Contains a wide range of hydrolytic enzymes and is released into the extracellular fluid. [GOC:jl, PMID:17152095]
Full description |

Standard name | GO_CHROMAFFIN_GRANULE
Systematic name | M25824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Specialized secretory vesicle found in the cells of adrenal glands and various other organs, which is concerned with the synthesis, storage, metabolism, and secretion of epinephrine and norepinephrine. [GOC:jl, PMID:19158310, PMID:1961743]
Full description |

Standard name | GO_CHROMAFFIN_GRANULE_MEMBRANE
Systematic name | M25825
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a chromaffin granule, a specialized secretory vesicle found in the cells of adrenal glands and various other organs, which is concerned with the synthesis, storage, metabolism, and secretion of epinephrine and norepinephrine. [GOC:jl]
Full description |

Standard name | GO_GLYCOGEN_GRANULE
Systematic name | M25826
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Cytoplasmic bead-like structures of animal cells, visible by electron microscope. Each granule is a functional unit with the biosynthesis and catabolism of glycogen being catalyzed by enzymes bound to the granule surface. [GOC:jl, PMID:12179957]
Full description |

Standard name | GO_ZYMOGEN_GRANULE
Systematic name | M17055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-bounded, cytoplasmic secretory granule found in enzyme-secreting cells and visible by light microscopy. Contain zymogen, an inactive enzyme precursor, often of a digestive enzyme. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_ZYMOGEN_GRANULE_MEMBRANE
Systematic name | M25827
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a zymogen granule. [GOC:jl]
Full description |

Standard name | GO_LAMELLAR_BODY
Systematic name | M17648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-bounded organelle, specialized for the storage and secretion of various substances (surfactant phospholipids, glycoproteins and acid phosphates) which are arranged in the form of tightly packed, concentric, membrane sheets or lamellae. Has some similar properties to, but is distinct from, a lysosome. [GOC:cjm, GOC:jl, PMID:12243725, Wikipedia:Lamellar_granule]
Full description |

Standard name | GO_MHC_PROTEIN_COMPLEX
Systematic name | M17090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transmembrane protein complex composed of an MHC alpha chain and, in most cases, either an MHC class II beta chain or an invariant beta2-microglobin chain, and with or without a bound peptide, lipid, or polysaccharide antigen. [GOC:add, GOC:jl, ISBN:0781735149, PMID:15928678, PMID:16153240]
Full description |

Standard name | GO_MHC_CLASS_I_PROTEIN_COMPLEX
Systematic name | M17828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transmembrane protein complex composed of a MHC class I alpha chain and an invariant beta2-microglobin chain, and with or without a bound peptide antigen. Class I here refers to classical class I molecules. [GOC:add, GOC:jl, ISBN:0120781859, ISBN:0781735149]
Full description |

Standard name | GO_MHC_CLASS_II_PROTEIN_COMPLEX
Systematic name | M17666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transmembrane protein complex composed of an MHC class II alpha and MHC class II beta chain, and with or without a bound peptide or polysaccharide antigen. [GOC:add, GOC:jl, ISBN:0120781859, PMID:15928678]
Full description |

Standard name | GO_PHOTORECEPTOR_OUTER_SEGMENT_MEMBRANE
Systematic name | M17198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The membrane surrounding the outer segment of a vertebrate photoreceptor. [GOC:jl]
Full description |

Standard name | GO_CHYLOMICRON
Systematic name | M17838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large lipoprotein particle (diameter 75-1200 nm) composed of a central core of triglycerides and cholesterol surrounded by a protein-phospholipid coating. The proteins include one molecule of apolipoprotein B-48 and may include a variety of apolipoproteins, including APOAs, APOCs and APOE. Chylomicrons are found in blood or lymph and carry lipids from the intestines into other body tissues. [GOC:jl, GOC:rl, PMID:10580165]
Full description |

Standard name | GO_MAST_CELL_GRANULE
Systematic name | M17768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Coarse, bluish-black staining cytoplasmic granules, bounded by a plasma membrane and found in mast cells and basophils. Contents include histamine, heparin, chondroitin sulfates, chymase and tryptase. [GOC:jl, http://www.ijp-online.com/archives/1969/001/02/r0000-0000tc.htm, PMID:12360215]
Full description |

Standard name | GO_ACTOMYOSIN
Systematic name | M17284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any complex of actin, myosin, and accessory proteins. [GOC:go_curators]
Full description |

Standard name | GO_MITOCHONDRIAL_INTERMEMBRANE_SPACE_PROTEIN_TRANSPORTER_COMPLEX
Systematic name | M25828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Soluble complex of the mitochondrial intermembrane space composed of various combinations of small Tim proteins; acts as a protein transporter to guide proteins to the Tim22 complex for insertion into the mitochondrial inner membrane. [PMID:12581629]
Full description |

Standard name | GO_PRESYNAPTIC_MEMBRANE
Systematic name | M17453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized area of membrane of the axon terminal that faces the plasma membrane of the neuron or muscle fiber with which the axon terminal establishes a synaptic junction; many synaptic junctions exhibit structural presynaptic characteristics, such as conical, electron-dense internal protrusions, that distinguish it from the remainder of the axon plasma membrane. [GOC:jl, ISBN:0815316194]
Full description |

Standard name | GO_GPI_ANCHOR_TRANSAMIDASE_COMPLEX
Systematic name | M25830
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An enzyme complex which in humans and yeast consists of at least five proteins; for example, the complex contains GAA1, GPI8, PIG-S, PIG-U, and PIG-T in human, and Gaa1p, Gab1p, Gpi8p, Gpi16p, and Gpi17p in yeast. Catalyzes the posttranslational attachment of the carboxy-terminus of a precursor protein to a GPI-anchor. [GOC:jl, GOC:rb, PMID:12802054]
Full description |

Standard name | GO_POLYSOMAL_RIBOSOME
Systematic name | M25831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribosome bound to mRNA that forms part of a polysome. [GOC:jl]
Full description |

Standard name | GO_MHC_CLASS_I_PEPTIDE_LOADING_COMPLEX
Systematic name | M25832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large, multisubunit complex which consists of the MHC class I-beta 2 microglobulin dimer, the transporter associated with antigen presentation (TAP), tapasin (an MHC-encoded membrane protein), the chaperone calreticulin and the thiol oxidoreductase ERp57. Functions in the assembly of peptides with newly synthesized MHC class I molecules. [GOC:jl, PMID:10631934]
Full description |

Standard name | GO_PLATELET_DENSE_GRANULE
Systematic name | M17822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Electron-dense granule occurring in blood platelets that stores and secretes adenosine nucleotides and serotonin. They contain a highly condensed core consisting of serotonin, histamine, calcium, magnesium, ATP, ADP, pyrophosphate and membrane lysosomal proteins. [GOC:jl, PMID:10403682, PMID:11487378]
Full description |

Standard name | GO_NEURON_PROJECTION
Systematic name | M15011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A prolongation or process extending from a nerve cell, e.g. an axon or dendrite. [GOC:jl, http://www.cogsci.princeton.edu/~wn/]
Full description |

Standard name | GO_NADPH_OXIDASE_COMPLEX
Systematic name | M25833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A enzyme complex of which the core is a heterodimer composed of a light (alpha) and heavy (beta) chain, and requires several other water-soluble proteins of cytosolic origin for activity. Functions in superoxide generation by the NADPH-dependent reduction of O2. [GOC:jl, PMID:11483596, PMID:12440767]
Full description |

Standard name | GO_COSTAMERE
Systematic name | M17296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Regular periodic sub membranous arrays of vinculin in skeletal and cardiac muscle cells, these arrays link Z-discs to the sarcolemma and are associated with links to extracellular matrix. [GOC:jl, GOC:mtg_muscle, ISBN:0198506732, PMID:6405378]
Full description |

Standard name | GO_GERM_CELL_NUCLEUS
Systematic name | M17165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The nucleus of a germ cell, a reproductive cell in multicellular organisms. [CL:0000586, GOC:go_curators]
Full description |

Standard name | GO_SYNAPTIC_CLEFT
Systematic name | M25834
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The narrow gap that separates the presynaptic and postsynaptic membranes, into which neurotransmitter is released. [GOC:jl, http://synapses.mcg.edu/anatomy/chemical/synapse.stm]
Full description |

Standard name | GO_H4_H2A_HISTONE_ACETYLTRANSFERASE_COMPLEX
Systematic name | M25835
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit complex that catalyzes the acetylation of histones H4 and H2A. [GOC:mah, GOC:rb]
Full description |

Standard name | GO_ATP_BINDING_CASSETTE_ABC_TRANSPORTER_COMPLEX
Systematic name | M25836
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex for the transport of metabolites into and out of the cell, typically comprised of four domains; two membrane-associated domains and two ATP-binding domains at the intracellular face of the membrane, that form a central pore through the plasma membrane. Each of the four core domains may be encoded as a separate polypeptide or the domains can be fused in any one of a number of ways into multidomain polypeptides. In Bacteria and Archaebacteria, ABC transporters also include substrate binding proteins to bind substrate external to the cytoplasm and deliver it to the transporter. [GOC:jl, GOC:mtg_sensu, PMID:11421269, PMID:15111107]
Full description |

Standard name | GO_AXON_INITIAL_SEGMENT
Systematic name | M17224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Portion of the axon proximal to the neuronal cell body, at the level of the axon hillock. The action potentials that propagate along the axon are generated at the level of this initial segment. [GOC:nln, GOC:sl, PMID:1754851, PMID:21551097]
Full description |

Standard name | GO_TERMINAL_BOUTON
Systematic name | M17765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Terminal inflated portion of the axon, containing the specialized apparatus necessary to release neurotransmitters. The axon terminus is considered to be the whole region of thickening and the terminal bouton is a specialized region of it. [GOC:dph, GOC:mc, GOC:nln, PMID:10218156, PMID:8409967]
Full description |

Standard name | GO_VARICOSITY
Systematic name | M25837
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Non-terminal inflated portion of the axon, containing the specialized apparatus necessary to release neurotransmitters. [GOC:nln]
Full description |

Standard name | GO_DENDRITIC_SHAFT
Systematic name | M17257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Cylindric portion of the dendrite, directly stemming from the perikaryon, and carrying the dendritic spines. [GOC:nln]
Full description |

Standard name | GO_LYSOSOMAL_LUMEN
Systematic name | M17005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed within the lysosomal membrane. [GOC:jl, PMID:15213228]
Full description |

Standard name | GO_AXON_HILLOCK
Systematic name | M25838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Portion of the neuronal cell soma from which the axon originates. [GOC:nln]
Full description |

Standard name | GO_PERIKARYON
Systematic name | M17691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the cell soma (neuronal cell body) that excludes the nucleus. [GOC:jl]
Full description |

Standard name | GO_MYELIN_SHEATH
Systematic name | M17315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An electrically insulating fatty layer that surrounds the axons of many neurons. It is an outgrowth of glial cells: Schwann cells supply the myelin for peripheral neurons while oligodendrocytes supply it to those of the central nervous system. [GOC:cjm, GOC:jl, NIF_Subcellular:sao593830697, Wikipedia:Myelin]
Full description |

Standard name | GO_COMPACT_MYELIN
Systematic name | M17251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the myelin sheath in which layers of cell membrane are tightly juxtaposed, completely excluding cytoplasm. The juxtaposed cytoplasmic surfaces form the major dense line, while the juxtaposed extracellular surfaces form the interperiod line visible in electron micrographs. [GOC:dgh, NIF_Subcellular:sao1123256993]
Full description |

Standard name | GO_SCHMIDT_LANTERMAN_INCISURE
Systematic name | M17528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Regions within compact myelin in which the cytoplasmic faces of the enveloping myelin sheath are not tightly juxtaposed, and include cytoplasm from the cell responsible for making the myelin. Schmidt-Lanterman incisures occur in the compact myelin internode, while lateral loops are analogous structures found in the paranodal region adjacent to the nodes of Ranvier. [GOC:dgh]
Full description |

Standard name | GO_RECEPTOR_COMPLEX
Systematic name | M17559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that undergoes combination with a hormone, neurotransmitter, drug or intracellular messenger to initiate a change in cell function. [GOC:go_curators]
Full description |

Standard name | GO_FANCONI_ANAEMIA_NUCLEAR_COMPLEX
Systematic name | M17146
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex composed of the Fanconi anaemia (FA) proteins including A, C, E, G and F (FANCA-F). Functions in the activation of the downstream protein FANCD2 by monoubiquitylation, and is essential for protection against chromosome breakage. [GOC:jl, PMID:12093742]
Full description |

Standard name | GO_LAMININ_COMPLEX
Systematic name | M25839
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A large, extracellular glycoprotein complex composed of three different polypeptide chains, alpha, beta and gamma. Provides an integral part of the structural scaffolding of basement membranes. [GOC:jl, http://www.sdbonline.org/fly/newgene/laminna1.htm, PMID:10842354]
Full description |

Standard name | GO_CONTRACTILE_FIBER
Systematic name | M6298
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Fibers, composed of actin, myosin, and associated proteins, found in cells of smooth or striated muscle. [GOC:go_curators, ISBN:0815316194]
Full description |

Standard name | GO_APICAL_JUNCTION_COMPLEX
Systematic name | M4718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A functional unit located near the cell apex at the points of contact between epithelial cells, which in vertebrates is composed of the tight junction, the zonula adherens, and desmosomes and in some invertebrates, such as Drosophila, is composed of the subapical complex (SAC), the zonula adherens and the septate junction. Functions in the regulation of cell polarity, tissue integrity and intercellular adhesion and permeability. [GOC:go_curators, GOC:kmv, PMID:12525486, PMID:15196556]
Full description |

Standard name | GO_TRNA_METHYLTRANSFERASE_COMPLEX
Systematic name | M34353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multimeric protein complex involved in the methylation of specific nucleotides in tRNA. [GOC:jl, PMID:24904644, PMID:9851972]
Full description |

Standard name | GO_NUCLEAR_REPLICATION_FORK
Systematic name | M12171
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The Y-shaped region of a nuclear replicating DNA molecule, resulting from the separation of the DNA strands and in which the synthesis of new strands takes place. Also includes associated protein complexes. [GOC:jl, GOC:mtg_sensu]
Full description |

Standard name | GO_HOST_CELL_NUCLEAR_PART
Systematic name | M29429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any constituent part of a host cell's nucleus, a membrane-bounded organelle of eukaryotic cells in which chromosomes are housed and replicated. The host is the larger of the organisms involved in a symbiotic interaction. [GOC:ecd]
Full description |

Standard name | GO_CYTOLYTIC_GRANULE
Systematic name | M25840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized secretory lysosome that is present in cells with cytolytic capability such as cytotoxic T lymphocytes and natural killer cells. Cytolytic granules mediate the storage and regulated excretion of lytic molecules for killing of target cells. [GOC:jl, PMID:11052265, PMID:12766758]
Full description |

Standard name | GO_SPANNING_COMPONENT_OF_PLASMA_MEMBRANE
Systematic name | M25841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the plasma membrane consisting of gene products and protein complexes that have some part that spans both leaflets of the membrane. [GOC:ecd]
Full description |

Standard name | GO_JUXTAPARANODE_REGION_OF_AXON
Systematic name | M25843
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A region of an axon near a node of Ranvier that is between the paranode and internode regions. [GOC:BHF, GOC:jl, PMID:10624965, PMID:14682359]
Full description |

Standard name | GO_ORGANELLE_MEMBRANE_CONTACT_SITE
Systematic name | M17202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A zone of apposition between the membranes of an organelle with another membrane, either another membrane of the same organelle, a membrane of another organelle, or the plasma membrane. Membrane contact sites (MCSs) are structured by bridging complexes. They are specialized for communication, including the efficient traffic of small molecules such as Ca2+ ions and lipids, as well as enzyme-substrate interactions. [GOC:jl, PMID:16806880]
Full description |

Standard name | GO_MITOCHONDRIA_ASSOCIATED_ENDOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M25844
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A zone of apposition between endoplasmic-reticulum and mitochondrial membranes, structured by bridging complexes. These contact sites are thought to facilitate inter-organelle calcium and phospholipid exchange. [GOC:jl, PMID:19556461, PMID:22078959, PMID:29626751, PMID:29684109]
Full description |

Standard name | GO_CELL_CELL_CONTACT_ZONE
Systematic name | M17008
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Extended zone of intimate apposition between two cells containing one or more types of intercellular junctions, e.g., the intercalated disk of muscle. [NIF_Subcellular:sao1299635018]
Full description |

Standard name | GO_DENDRITE_TERMINUS
Systematic name | M25846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A structure at the distal end of a dendrite adapted to carry out a specific function, e.g. dendriole. [GOC:jl, NIF_Subcellular:sao28175134]
Full description |

Standard name | GO_DENDRITIC_GROWTH_CONE
Systematic name | M25847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The migrating motile tip of a growing nerve cell dendrite. [GOC:jl]
Full description |

Standard name | GO_AXONAL_GROWTH_CONE
Systematic name | M17280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The migrating motile tip of a growing nerve cell axon. [GOC:jl, NIF_Subcellular:sao203987954]
Full description |

Standard name | GO_CELL_BODY
Systematic name | M17635
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of a cell bearing surface projections such as axons, dendrites, cilia, or flagella that includes the nucleus, but excludes all cell projections. [GOC:go_curators]
Full description |

Standard name | GO_CELL_BODY_MEMBRANE
Systematic name | M25848
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The plasma membrane of a cell that bears surface projections such as axons, dendrites, cilia, or flagella, excluding the plasma membrane on cell projections. [GOC:ecd]
Full description |

Standard name | GO_CEREBELLAR_MOSSY_FIBER
Systematic name | M25849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An axon arising from cerebellar projecting cells in the cochlea, vestibular nuclei, spinal cord, reticular formation, cerebellar nuclei and basilar pontine nuclei. Mossy fibers enter through all three cerebellar peduncles and send collaterals to the deep cerebellar nuclei, then branch in the white matter and terminate in the granule cell layer. Through this branching, a given mossy fiber can innervate several folia. Mossy fibers synapse on granule cells. The synaptic contacts are made at enlargements along the length of the mossy fiber called mossy fiber rosettes. The enlargements of the rosettes give the axons a mossy-looking appearance in Golgi stained preparations. [NIF_Subcellular:nlx_subcell_20090209]
Full description |

Standard name | GO_DENTATE_GYRUS_MOSSY_FIBER
Systematic name | M34354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Distinctive, unmyelinated axons produced by granule cells. [NIF_Subcellular:nlx_subcell_20090601, PMID:17765709]
Full description |

Standard name | GO_MAIN_AXON
Systematic name | M17647
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The main axonal trunk, as opposed to the collaterals; i.e., excluding collaterals, terminal, spines, or dendrites. [NIF_Subcellular:sao1596975044]
Full description |

Standard name | GO_CALYX_OF_HELD
Systematic name | M25850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The terminal specialization of a calyciferous axon which forms large synapses in the mammalian auditory central nervous system. [NIF_Subcellular:sao1684283879, PMID:11823805]
Full description |

Standard name | GO_NEURON_PROJECTION_TERMINUS
Systematic name | M17084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The specialized, terminal region of a neuron projection such as an axon or a dendrite. [GOC:jl]
Full description |

Standard name | GO_NEURON_SPINE
Systematic name | M17263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A small membranous protrusion, often ending in a bulbous head and attached to the neuron by a narrow stalk or neck. [ISBN:0198504888, NIF_Subcellular:sao1145756102]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_QUALITY_CONTROL_COMPARTMENT
Systematic name | M17616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A subcompartment of the endoplasmic reticulum in which proteins with improper or incorrect folding accumulate. Enzymes in this compartment direct proteins with major folding problems to translocation to the cytosol and degradation, and proteins with minor folding problems to the ER, to interact with chaperon proteins. [PMID:11408579]
Full description |

Standard name | GO_DENDRITIC_SPINE_NECK
Systematic name | M29431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Part of the dendritic spine that connects the dendritic shaft to the head of the dendritic spine. [GOC:nln]
Full description |

Standard name | GO_DENDRITIC_SPINE_HEAD
Systematic name | M25851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Distal part of the dendritic spine, that carries the post-synaptic density. [GOC:BHF, GOC:nln, GOC:rl]
Full description |

Standard name | GO_PINOSOME
Systematic name | M25852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-bounded, uncoated intracellular vesicle formed by the process of pinocytosis. [PMID:14731589, PMID:14732047]
Full description |

Standard name | GO_RIBOSOMAL_SUBUNIT
Systematic name | M17590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Either of the two subunits of a ribosome: the ribosomal large subunit or the ribosomal small subunit. [GOC:jl]
Full description |

Standard name | GO_NSL_COMPLEX
Systematic name | M25853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A histone acetyltransferase complex that catalyzes the acetylation of a histone H4 lysine residues at several positions. In human, it contains the catalytic subunit MOF, NSL1/KIAA1267, NSL2/KANSL2, NSL3/KANSL3, MCRS1, PHF20, OGT1, WDR5 and HCF1. [GOC:lb, PMID:20018852]
Full description |

Standard name | GO_NUCLEAR_PORE_CENTRAL_TRANSPORT_CHANNEL
Systematic name | M25854
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The central substructure of the nuclear pore complex (NPC), through which nucleocytoplasmic transport of RNAs, proteins and small molecules occurs. The central transport channel is filled with FG-nucleoporins, which form a selective barrier and provide a series of binding sites for transporter proteins. Characterized S. cerevisiae FG-nucleoporins include Nup159p, Nup145Np, Nup116p, Nup100p, Nsp1p, Nup57p, Nup49p, Nup42p, Nup53p, Nup59p/Asm4p, Nup60p and Nup1. Characterized vertebrate FG-nucleoporins include Nup214, Nup98, Nup62, Nup54, Nup58/45, NLP1, and Nup153. [GOC:dgf, PMID:18046406, PMID:19524430, PMID:20947011, PMID:22419078]
Full description |

Standard name | GO_NUCLEAR_PORE_NUCLEAR_BASKET
Systematic name | M25855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A filamentous, cage-like assembly on the nuclear face of the nuclear pore complex (NPC). In S. cerevisiae, Mlp1p and Mlp2p are two major components of the NPC nuclear basket. In vertebrates, Tpr is a major component. [GOC:dgf, PMID:18046406, PMID:19524430, PMID:20947011, PMID:22419078]
Full description |

Standard name | GO_MLL1_2_COMPLEX
Systematic name | M17422
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that can methylate lysine-4 of histone H3, and which contains either of the protein subunits MLL1 or MLL2 in human, or equivalent in other species. [GOC:sart, PMID:21875999]
Full description |

Standard name | GO_MLL3_4_COMPLEX
Systematic name | M25856
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that can methylate lysine-4 of histone H3, and which contains either of the protein subunits MLL3 or MLL4 in mammals, or equivalent in other species. [GOC:sart, PMID:21875999]
Full description |

Standard name | GO_AUTOLYSOSOME
Systematic name | M25857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A type of secondary lysosome in which a primary lysosome has fused with the outer membrane of an autophagosome. It is involved in the second step of autophagy in which it degrades contents with acidic lysosomal hydrolases. [GOC:sart, NIF_Subcellular:sao8444068431, PMID:19008921]
Full description |

Standard name | GO_DNA_PACKAGING_COMPLEX
Systematic name | M17506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that plays a role in the process of DNA packaging. [GOC:jl]
Full description |

Standard name | GO_PLASMA_MEMBRANE_RAFT
Systematic name | M17801
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane raft that is part of the plasma membrane. [GOC:jl]
Full description |

Standard name | GO_KERATIN_FILAMENT
Systematic name | M17671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A filament composed of acidic and basic keratins (types I and II), typically expressed in epithelial cells. The keratins are the most diverse classes of IF proteins, with a large number of keratin isoforms being expressed. Each type of epithelium always expresses a characteristic combination of type I and type II keratins. [ISBN:0716731363]
Full description |

Standard name | GO_INTERMEDIATE_FILAMENT_CYTOSKELETON
Systematic name | M17620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Cytoskeletal structure made from intermediate filaments, typically organized in the cytosol as an extended system that stretches from the nuclear envelope to the plasma membrane. Some intermediate filaments run parallel to the cell surface, while others traverse the cytosol; together they form an internal framework that helps support the shape and resilience of the cell. [ISBN:0716731363]
Full description |

Standard name | GO_PRONUCLEUS
Systematic name | M17231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The nucleus of either the ovum or the spermatozoon following fertilization. Thus, in the fertilized ovum, there are two pronuclei, one originating from the ovum, the other from the spermatozoon that brought about fertilization; they approach each other, but do not fuse until just before the first cleavage, when each pronucleus loses its membrane to release its contents. [ISBN:0198506732]
Full description |

Standard name | GO_INTERCELLULAR_BRIDGE
Systematic name | M17663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A direct connection between the cytoplasm of two cells that is formed following the completion of cleavage furrow ingression during cell division. They are usually present only briefly prior to completion of cytokinesis. However, in some cases, such as the bridges between germ cells during their development, they become stabilised. [PMID:9635420]
Full description |

Standard name | GO_APICAL_PART_OF_CELL
Systematic name | M17164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of a polarized cell that forms a tip or is distal to a base. For example, in a polarized epithelial cell, the apical region has an exposed surface and lies opposite to the basal lamina that separates the epithelium from other tissue. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_BASAL_PART_OF_CELL
Systematic name | M17798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of a cell situated near the base. For example, in a polarized epithelial cell, the basal surface rests on the basal lamina that separates the epithelium from other tissue. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_APICAL_CORTEX
Systematic name | M25858
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region that lies just beneath the plasma membrane on the apical edge of a cell. [GOC:bf]
Full description |

Standard name | GO_BASAL_CORTEX
Systematic name | M25859
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region that lies just beneath the plasma membrane on the basal edge of a cell. [GOC:bf]
Full description |

Standard name | GO_SYNAPSE
Systematic name | M17408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The junction between an axon of one neuron and a dendrite of another neuron, a muscle fiber or a glial cell. As the axon approaches the synapse it enlarges into a specialized structure, the presynaptic terminal bouton, which contains mitochondria and synaptic vesicles. At the tip of the terminal bouton is the presynaptic membrane; facing it, and separated from it by a minute cleft (the synaptic cleft) is a specialized area of membrane on the receiving cell, known as the postsynaptic membrane. In response to the arrival of nerve impulses, the presynaptic terminal bouton secretes molecules of neurotransmitters into the synaptic cleft. These diffuse across the cleft and transmit the signal to the postsynaptic membrane. [GOC:aruk, ISBN:0198506732, PMID:24619342, PMID:29383328, PMID:31998110]
Full description |

Standard name | GO_POSTSYNAPTIC_MEMBRANE
Systematic name | M17414
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized area of membrane facing the presynaptic membrane on the tip of the nerve ending and separated from it by a minute cleft (the synaptic cleft). Neurotransmitters cross the synaptic cleft and transmit the signal to the postsynaptic membrane. [ISBN:0198506732]
Full description |

Standard name | GO_TRICARBOXYLIC_ACID_CYCLE_ENZYME_COMPLEX
Systematic name | M17501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the heteromeric enzymes that act in the TCA cycle. [GOC:mah]
Full description |

Standard name | GO_DIHYDROLIPOYL_DEHYDROGENASE_COMPLEX
Systematic name | M25860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that possesses alpha-ketoglutarate dehydrogenase activity. [GOC:mah]
Full description |

Standard name | GO_OXOGLUTARATE_DEHYDROGENASE_COMPLEX
Systematic name | M25861
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex of multiple copies of three enzymatic components: oxoglutarate dehydrogenase (lipoamide) ; EC:1.2.4.2 (E1), dihydrolipoamide S-succinyltransferase ; EC:2.3.1.61 (E2) and dihydrolipoamide dehydrogenase ; EC:1.8.1.4 (E3); catalyzes the overall conversion of 2-oxoglutarate to succinyl-CoA and carbon dioxide (CO2). [MetaCyc:CPLX66-42, PMID:10848975]
Full description |

Standard name | GO_PYRUVATE_DEHYDROGENASE_COMPLEX
Systematic name | M25862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Complex that carries out the oxidative decarboxylation of pyruvate to form acetyl-CoA; comprises subunits possessing three catalytic activities: pyruvate dehydrogenase (E1), dihydrolipoamide S-acetyltransferase (E2), and dihydrolipoamide dehydrogenase (E3). [ISBN:0716720094]
Full description |

Standard name | GO_PROTON_TRANSPORTING_ATP_SYNTHASE_COMPLEX
Systematic name | M17808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A proton-transporting two-sector ATPase complex that catalyzes the phosphorylation of ADP to ATP during oxidative phosphorylation. The complex comprises a membrane sector (F0) that carries out proton transport and a cytoplasmic compartment sector (F1) that catalyzes ATP synthesis by a rotational mechanism; the extramembrane sector (containing 3 a and 3 b subunits) is connected via the d-subunit to the membrane sector by several smaller subunits. Within this complex, the g and e subunits and the 9-12 c subunits rotate by consecutive 120 degree angles and perform parts of ATP synthesis. This movement is driven by the hydrogen ion electrochemical potential gradient. [ISBN:0198547684, ISBN:0716743663]
Full description |

Standard name | GO_PROTON_TRANSPORTING_ATP_SYNTHASE_COMPLEX_CATALYTIC_CORE_F_1
Systematic name | M25863
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The sector of a hydrogen-transporting ATP synthase complex in which the catalytic activity resides; it comprises the catalytic core and central stalk, and is peripherally associated with a membrane, such as the plasma membrane or the mitochondrial inner membrane, when the entire ATP synthase is assembled. [GOC:mah, PMID:10838056]
Full description |

Standard name | GO_PROTON_TRANSPORTING_ATP_SYNTHASE_COMPLEX_COUPLING_FACTOR_F_O
Systematic name | M17436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | All non-F1 subunits of a hydrogen-transporting ATP synthase, including integral and peripheral membrane proteins. [PMID:10838056]
Full description |

Standard name | GO_RESPIRATORY_CHAIN_COMPLEX_II
Systematic name | M25864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A part of the respiratory chain, containing the four polypeptide subunits of succinate dehydrogenase, flavin-adenine dinucleotide and iron-sulfur. Catalyzes the oxidation of succinate by ubiquinone. Connects the TCA cycle with the respiratory chain. [ISBN:0198547684]
Full description |

Standard name | GO_RESPIRATORY_CHAIN_COMPLEX_III
Systematic name | M25865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that transfers electrons from ubiquinol to cytochrome c and translocates two protons across a membrane. The complex contains a core structure of three catalytic subunits: cytochrome b, the Rieske iron sulfur protein (ISP), and cytochrome c1, which are arranged in an integral membrane-bound dimeric complex; additional subunits are present, and vary among different species. [PMID:16228398, PMID:16352458, PMID:17200733]
Full description |

Standard name | GO_RESPIRATORY_CHAIN_COMPLEX_IV
Systematic name | M25866
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A part of the respiratory chain, containing the 13 polypeptide subunits of cytochrome c oxidase, including cytochrome a and cytochrome a3. Catalyzes the oxidation of reduced cytochrome c by dioxygen (O2). [ISBN:0198547684]
Full description |

Standard name | GO_MRNA_EDITING_COMPLEX
Systematic name | M25867
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that posttranscriptionally catalyzes insertion, deletion or substitution of nucleotides at multiple sites within nascent mRNA transcripts to produce mature mRNAs in eukaryotes. [http://www.ejbiotechnology.info/content/vol1/issue1/full/4/, PMID:11564867, PMID:12139607, PMID:24316715]
Full description |

Standard name | GO_CLATHRIN_COATED_ENDOCYTIC_VESICLE
Systematic name | M17327
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A clathrin-coated, membrane-bounded intracellular vesicle formed by invagination of the plasma membrane around an extracellular substance. [GOC:go_curators]
Full description |

Standard name | GO_PHAGOCYTIC_VESICLE
Systematic name | M16985
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane-bounded intracellular vesicle that arises from the ingestion of particulate material by phagocytosis. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_POLE_PLASM
Systematic name | M17510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Differentiated cytoplasm associated with a pole (animal, vegetal, anterior, or posterior) of an oocyte, egg or early embryo. [GOC:kmv, PMID:17113380]
Full description |

Standard name | GO_INTERCELLULAR_CANALICULUS
Systematic name | M29432
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An extremely narrow tubular channel located between adjacent cells. An instance of this is the secretory canaliculi occurring between adjacent parietal cells in the gastric mucosa of vertebrates. [ISBN:0721662544]
Full description |

Standard name | GO_ANCHORED_COMPONENT_OF_PLASMA_MEMBRANE
Systematic name | M6036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the plasma membrane consisting of the gene products that are tethered to the membrane only by a covalently attached anchor, such as a lipid group, that is embedded in the membrane. Gene products with peptide sequences that are embedded in the membrane are excluded from this grouping. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_LIPOPOLYSACCHARIDE_RECEPTOR_COMPLEX
Systematic name | M25868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiprotein complex that consists of at least three proteins, CD14, TLR4, and MD-2, each of which is glycosylated and which functions as a lipopolysaccharide (LPS) receptor that primes the innate immune response against bacterial pathogens. [PMID:11706042, PMID:9665271]
Full description |

Standard name | GO_PORE_COMPLEX
Systematic name | M17167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any small opening in a membrane that allows the passage of gases and/or liquids. [ISBN:0198506732]
Full description |

Standard name | GO_ACTIVIN_RECEPTOR_COMPLEX
Systematic name | M25869
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that acts as an activin receptor. Heterodimeric activin receptors, comprising one Type I activin receptor and one Type II receptor polypeptide, and heterotrimeric receptors have been observed. [PMID:8307945, PMID:8622651]
Full description |

Standard name | GO_SET1C_COMPASS_COMPLEX
Systematic name | M17247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A conserved protein complex that catalyzes methylation of histone H3. In Saccharomyces the complex contains Shg1p, Sdc1p, Swd1p, Swd2p, Swd3p, Spp1p, Bre2p, and the trithorax-related Set1p; in mammals it contains the catalytic subunit (SETD1A or SETD1B), WDR5, WDR82, RBBP5, ASH2L/ASH2, CXXC1/CFP1, HCFC1 and DPY30. [PMID:11687631, PMID:11742990, PMID:11805083, PMID:12488447, PMID:18508253, PMID:18838538]
Full description |

Standard name | GO_PERINUCLEAR_REGION_OF_CYTOPLASM
Systematic name | M7685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Cytoplasm situated near, or occurring around, the nucleus. [GOC:jid]
Full description |

Standard name | GO_HOLLIDAY_JUNCTION_RESOLVASE_COMPLEX
Systematic name | M25870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An endodeoxyribonuclease complex that resolves the 4-way DNA intermediates of a Holliday junction into two separate duplex DNA molecules. Can be branch-migration associated. [PMID:11207366, PMID:12374758]
Full description |

Standard name | GO_SIGNAL_RECOGNITION_PARTICLE
Systematic name | M25871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex of protein and RNA which facilitates translocation of proteins across membranes. [GOC:mlg]
Full description |

Standard name | GO_PIGMENT_GRANULE
Systematic name | M17718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A small, subcellular membrane-bounded vesicle containing pigment and/or pigment precursor molecules. Pigment granule biogenesis is poorly understood, as pigment granules are derived from multiple sources including the endoplasmic reticulum, coated vesicles, lysosomes, and endosomes. [GOC:jid, GOC:mh]
Full description |

Standard name | GO_PRESYNAPTIC_ACTIVE_ZONE
Systematic name | M17568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized region of the plasma membrane and cell cortex of a presynaptic neuron; encompasses a region of the plasma membrane where synaptic vesicles dock and fuse, and a specialized cortical cytoskeletal matrix. [GOC:dh, GOC:dl, GOC:ef, GOC:jid, GOC:pr, PMID:3152289]
Full description |

Standard name | GO_PRESYNAPTIC_ACTIVE_ZONE_MEMBRANE
Systematic name | M25872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The membrane portion of the presynaptic active zone; it is the site where docking and fusion of synaptic vesicles occurs for the release of neurotransmitters. [PMID:12812759, PMID:12923177, PMID:3152289]
Full description |

Standard name | GO_CYTOSKELETON_OF_PRESYNAPTIC_ACTIVE_ZONE
Systematic name | M25873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The specialized cytoskeletal matrix of the presynaptic active zone. It has specialized functions in organizing synaptic events such as immobilisation or translocation of synaptic vesicles, and assembling active zone components. It is believed to form a molecular scaffold that organizes neurotransmitter release sites. [GOC:dh, GOC:dl, GOC:ef, GOC:jid, NIF_Subcellular:sao1470121605, PMID:10944438]
Full description |

Standard name | GO_SPINDLE_MIDZONE
Systematic name | M17452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The area in the center of the spindle where the spindle microtubules from opposite poles overlap. [GOC:ai, PMID:15296749]
Full description |

Standard name | GO_CELL_TIP
Systematic name | M25874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region at the end of the longest axis of a cylindrical or elongated cell. [GOC:ai, GOC:mah]
Full description |

Standard name | GO_RECYCLING_ENDOSOME
Systematic name | M17771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An organelle consisting of a network of tubules that functions in targeting molecules, such as receptors transporters and lipids, to the plasma membrane. [GOC:dph, GOC:jid, GOC:kmv, GOC:rph, PMID:10930469, PMID:15601896, PMID:16246101, PMID:21556374, PMID:21562044]
Full description |

Standard name | GO_RECYCLING_ENDOSOME_MEMBRANE
Systematic name | M17582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a recycling endosome. [GOC:jid, GOC:rph, PMID:10930469, PMID:15601896, PMID:16246101]
Full description |

Standard name | GO_EXCITATORY_SYNAPSE
Systematic name | M17060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A synapse in which an action potential in the presynaptic cell increases the probability of an action potential occurring in the postsynaptic cell. [GOC:dph, GOC:ef]
Full description |

Standard name | GO_INHIBITORY_SYNAPSE
Systematic name | M17597
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A synapse in which an action potential in the presynaptic cell reduces the probability of an action potential occurring in the postsynaptic cell. [GOC:dph, GOC:ef]
Full description |

Standard name | GO_KINOCILIUM
Systematic name | M25875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A nonmotile primary cilium that is found at the apical surface of auditory receptor cells. The kinocilium is surrounded by actin-based stereocilia. [GOC:cilia, GOC:dph, PMID:15882574]
Full description |

Standard name | GO_CILIARY_MEMBRANE
Systematic name | M17659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a cilium. [GOC:cilia, GOC:dph, GOC:rph]
Full description |

Standard name | GO_STEREOCILIUM_MEMBRANE
Systematic name | M25876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding a stereocilium. [GOC:dph, GOC:rph]
Full description |

Standard name | GO_CLATHRIN_SCULPTED_VESICLE
Systematic name | M16978
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A clathrin-sculpted lipid bilayer membrane-enclosed vesicle after clathrin release. [GOC:dph]
Full description |

Standard name | GO_CLATHRIN_SCULPTED_GAMMA_AMINOBUTYRIC_ACID_TRANSPORT_VESICLE_MEMBRANE
Systematic name | M25877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a clathrin-sculpted gamma-aminobutyric acid transport vesicle. [GOC:dph]
Full description |

Standard name | GO_MICOS_COMPLEX
Systematic name | M25878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Mitochondrial inner membrane complex involved in maintenance of crista junctions, inner membrane architecture, and formation of contact sites to the outer membrane. In Saccharomyces cerevisiae the complex has six subunits: MIC10, MIC12, MIC19, MIC26, MIC27, and MIC60. [GOC:dph, PMID:21944719, PMID:21987634, PMID:22009199, PMID:24687277]
Full description |

Standard name | GO_MITOTIC_SPINDLE_ASTRAL_MICROTUBULE
Systematic name | M25879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of the mitotic spindle microtubules that radiate in all directions from the spindle poles and are thought to contribute to the forces that separate the poles and position them in relation to the rest of the cell. [GOC:dph]
Full description |

Standard name | GO_TRANSFERASE_COMPLEX_TRANSFERRING_PHOSPHORUS_CONTAINING_GROUPS
Systematic name | M17061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transferase complex capable of catalysis of the transfer of a phosphorus-containing group from one compound (donor) to another (acceptor). [GOC:bhm, GOC:dph]
Full description |

Standard name | GO_GATOR2_COMPLEX
Systematic name | M25880
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiprotein subcomplex of GATOR that regulates mTOR signaling by interacting with the Rag GTPases. In humans this complex consists of Mios, WDR24, WDR59, Seh1L, Sec13. [GOC:rb, PMID:23723238]
Full description |

Standard name | GO_INFLAMMASOME_COMPLEX
Systematic name | M17011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cytosolic protein complex that is capable of activating caspase-1. [GOC:dph, PMID:17599095]
Full description |

Standard name | GO_SPERM_HEAD
Systematic name | M25881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The part of the late spermatid or spermatozoon that contains the nucleus and acrosome. [PMID:22797892, PMID:24665388]
Full description |

Standard name | GO_COLLAGEN_CONTAINING_EXTRACELLULAR_MATRIX
Systematic name | M25882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An extracellular matrix consisting mainly of proteins (especially collagen) and glycosaminoglycans (mostly as proteoglycans) that provides not only essential physical scaffolding for the cellular constituents but can also initiate crucial biochemical and biomechanical cues required for tissue morphogenesis, differentiation and homeostasis. The components are secreted by cells in the vicinity and form a sheet underlying or overlying cells such as endothelial and epithelial cells. [GOC:BHF, GOC:rph, PMID:21123617]
Full description |

Standard name | GO_EXTRACELLULAR_MEMBRANE_BOUNDED_ORGANELLE
Systematic name | M25883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Organized structure of distinctive morphology and function, bounded by a lipid bilayer membrane and occurring outside the cell. [GOC:isa_complete]
Full description |

Standard name | GO_CYTOCHROME_COMPLEX
Systematic name | M16988
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex in which at least one of the proteins is a cytochrome, i.e. a heme-containing protein involved in catalysis of redox reactions. [GOC:mah]
Full description |

Standard name | GO_CLATHRIN_SCULPTED_MONOAMINE_TRANSPORT_VESICLE
Systematic name | M25884
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A clathrin-sculpted lipid bilayer membrane-enclosed vesicle after clathrin release and containing monoamines. [GOC:mg2]
Full description |

Standard name | GO_TIGHT_JUNCTION
Systematic name | M25885
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell-cell junction that seals cells together in an epithelium in a way that prevents even small molecules from leaking from one side of the sheet to the other. [ISBN:0815332181]
Full description |

Standard name | GO_ANCHORING_JUNCTION
Systematic name | M17561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell junction that mechanically attaches a cell (and its cytoskeleton) to neighboring cells or to the extracellular matrix. [ISBN:0815332181]
Full description |

Standard name | GO_SHELTERIN_COMPLEX
Systematic name | M25886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A nuclear telomere cap complex that is formed by the association of telomeric ssDNA- and dsDNA-binding proteins with telomeric DNA, and is involved in telomere protection and recruitment of telomerase. The complex is known to contain TERF1, TERF2, POT1, RAP1, TINF2 and ACD in mammalian cells, and Pot1, Tpz1, Rap1, Rif1, Rif2 and Taz1 in Saccharomyces. Taz1 and Rap1 (or their mammalian equivalents) form a dsDNA-binding subcomplex, Pot1 and Tpz1 form an ssDNA-binding subcomplex, and the two subcomplexes are bridged by Poz1, which acts as an effector molecule along with Ccq1. [GOC:expert_mf, GOC:mah, GOC:vw, PMID:18828880]
Full description |

Standard name | GO_EXOCYTIC_VESICLE
Systematic name | M17098
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transport vesicle that mediates transport from an intracellular compartment to the plasma membrane, and fuses with the plasma membrane to release various cargo molecules, such as proteins or hormones, by exocytosis. [GOC:kad, GOC:mah]
Full description |

Standard name | GO_TRANSCRIPTION_EXPORT_COMPLEX_2
Systematic name | M29434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that couples SAGA-dependent gene expression to mRNA export at the inner side of the nuclear pore complex (NPC). The TREX-2 complex is tethered to the inner side of the NPC via the nucleoporins Nup1 and Nup60; in S. cerevisiae it contains Sac3p, Thp1p, Sem1, Sus1p and Cdc31p. [GOC:dgf, GOC:mah, PMID:17786152, PMID:19289793, PMID:28334829]
Full description |

Standard name | GO_NONHOMOLOGOUS_END_JOINING_COMPLEX
Systematic name | M25887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that plays a role in DNA double-strand break repair via nonhomologous end joining. Such complexes typically contain a specialized DNA ligase (e.g. Lig4 in eukaryotes) and one or more proteins that bind to DNA ends. [GOC:mah, PMID:17072889, PMID:17938628]
Full description |

Standard name | GO_ELONGIN_COMPLEX
Systematic name | M25888
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transcription elongation factor complex that suppresses RNA polymerase II pausing, and may act by promoting proper alignment of the 3'-end of nascent transcripts with the polymerase catalytic site. Consists of a transcriptionally active Elongin A subunit (about 100 kDa) and two smaller Elongin B (about 18 kDa) and Elongin C (about 15 kDa) subunits. [PMID:12676794]
Full description |

Standard name | GO_SAGA_TYPE_COMPLEX
Systematic name | M17396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A histone acetyltransferase complex that acetylates nucleosomal H3 and H2B and is required for the expression of a subset of Pol II-transcribed genes. The budding yeast complex includes the acetyltransferase Gcn5p, several proteins of the Spt and Ada families, and several TBP-associate proteins (TAFs); analogous complexes in other species have analogous compositions, and usually contain homologs of the yeast proteins. [GOC:mah, PMID:10637607, PMID:17337012]
Full description |

Standard name | GO_RESPIRASOME
Systematic name | M25889
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The protein complexes that form the electron transport system (the respiratory chain), associated with a cell membrane, usually the plasma membrane (in prokaryotes) or the inner mitochondrial membrane (on eukaryotes). The respiratory chain complexes transfer electrons from an electron donor to an electron acceptor and are associated with a proton pump to create a transmembrane electrochemical gradient. [GOC:ecd, GOC:mah, ISBN:0198547684, Wikipedia:Respirasome]
Full description |

Standard name | GO_BRCA1_A_COMPLEX
Systematic name | M25890
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains the BRCA1-BARD1 heterodimer, RAP80/UIMC1, BRCC3/BRCC36, BRE/BRCC45, FAM175A/CCDC98/Abraxas and MERIT40/NBA1, and specifically recognizes and binds K63-linked polyubiquitin chains present on histone H2A and H2AX at DNA damage sites. [GOC:mah, PMID:19261749]
Full description |

Standard name | GO_BRISC_COMPLEX
Systematic name | M25892
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains the FAM175B/ABRO1, BRCC3/BRCC36, BRE/BRCC45 and MERIT40/NBA1 proteins, and specifically cleaves K63-linked polyubiquitin chains. [GOC:mah, PMID:19214193]
Full description |

Standard name | GO_RISC_LOADING_COMPLEX
Systematic name | M25893
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A trimeric protein complex required for the formation of a mature RNA-induced silencing complex (RISC). In humans the complex is composed of the endonuclease Dicer (DICER1), TRBP (TARBP2) and the Argonaute protein Ago2 (EIF2C2/AGO2). Within the complex, Dicer and TRBP are required to process precursor miRNAs (pre-miRNAs) to mature miRNAs and then load them onto Ago2. Ago2 bound to the mature miRNA constitutes the minimal RISC and may subsequently dissociate from Dicer and TRBP. This complex has endoribonuclease activity. [GOC:ab, GOC:BHF, GOC:nc, GOC:rph, PMID:18178619, PMID:19820710]
Full description |

Standard name | GO_HAUS_COMPLEX
Systematic name | M25894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that localizes to interphase centrosomes and to mitotic spindle tubules and regulates mitotic spindle assembly and centrosome integrity; in human, the complex consists of eight subunits, some of which are homologous to subunits of the Drosophila Augmin complex. [PMID:19427217]
Full description |

Standard name | GO_FHF_COMPLEX
Systematic name | M25895
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that is composed of AKTIP/FTS, FAM160A2/p107FHIP, and one or more members of the Hook family of proteins, HOOK1, HOOK2, and HOOK3. The complex is thought to promote vesicle trafficking and/or fusion, and associates with the homotypic vesicular sorting complex (the HOPS complex). [GOC:ab, GOC:mah, PMID:18799622]
Full description |

Standard name | GO_PRE_SNORNP_COMPLEX
Systematic name | M25896
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains a precursor small nucleolar RNA (pre-snoRNA) and associated proteins, and forms during small nucleolar ribonucleoprotein complex (snoRNP) assembly. Pre-snoRNP complexes may contain proteins not found in the corresponding mature snoRNP complexes. [GOC:BHF, GOC:mah, GOC:rl, PMID:17636026, PMID:17709390]
Full description |

Standard name | GO_GAMMA_SECRETASE_COMPLEX
Systematic name | M25897
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that has aspartic-type endopeptidase activity, and contains a catalytic subunit, presenilin (PS), that is a prototypical member of the GxGD-type aspartyl peptidases. The complex also contains additional subunits, including nicastrin, APH-1, PEN-2, and a regulatory subunit, CD147. Gamma-secretase cleaves several transmembrane proteins including the cell surface receptor Notch and the amyloid-beta precursor protein. [GOC:mah, PMID:15286082, PMID:15890777, PMID:17047368]
Full description |

Standard name | GO_H3_HISTONE_ACETYLTRANSFERASE_COMPLEX
Systematic name | M25898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multisubunit complex that catalyzes the acetylation of histone H3. [GOC:mah]
Full description |

Standard name | GO_TERTIARY_GRANULE
Systematic name | M25899
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A secretory granule that contains cathepsin and gelatinase and is readily exocytosed upon cell activation; found primarily in mature neutrophil cells. [GOC:BHF, GOC:mah, GOC:rl, PMID:12070036]
Full description |

Standard name | GO_TERTIARY_GRANULE_MEMBRANE
Systematic name | M25900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a tertiary granule. [GOC:BHF, GOC:mah, GOC:rl, PMID:12070036]
Full description |

Standard name | GO_SIN3_TYPE_COMPLEX
Systematic name | M17413
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any of a number of evolutionarily conserved histone deacetylase complexes (HDACs) containing a core consisting of a paired amphipathic helix motif protein (e.g. Sin3p in S. cerevisiae, Pst1 in S. pombe or Sin3A in mammals) at least one class I histone deacetylase (e.g. Rpd3p in S. cerevisiae, Clr6 in S. pombe, or HDAC1 and HDAC2 in mammals), and at least one WD40 repeat protein (e.g. Ume1p in S. cerevisiae, Prw1 in S. pombe, or RbAp46 and RbAp48 in mammals). These complexes also contain a variable number of other proteins that direct histone binding, DNA binding, or add other functionality to the complex. [PMID:15565322, PMID:18292778]
Full description |

Standard name | GO_CORE_MEDIATOR_COMPLEX
Systematic name | M25901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that interacts with the carboxy-terminal domain of the largest subunit of RNA polymerase II and plays an active role in transducing the signal from a transcription factor to the transcriptional machinery. The core mediator complex has a stimulatory effect on basal transcription, and contains most of the same subdomains as the larger form of mediator complex -- a head domain comprising proteins known in Saccharomyces as Srb2, -4, and -5, Med6, -8, and -11, and Rox3 proteins; a middle domain comprising Med1, -4, and -7, Nut1 and -2, Cse2, Rgr1, Soh1, and Srb7 proteins; and a tail consisting of Gal11p, Med2p, Pgd1p, and Sin4p -- but lacks the regulatory subcomplex comprising Ssn2, -3, and -8, and Srb8 proteins. Metazoan core mediator complexes have similar modular structures and include homologs of yeast Srb and Med proteins. [PMID:11454195, PMID:16168358, PMID:17870225]
Full description |

Standard name | GO_CELL_BODY_FIBER
Systematic name | M25902
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A neuron projection that is found in unipolar neurons and corresponds to the region between the cell body and the point at which the single projection branches. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_CRD_MEDIATED_MRNA_STABILITY_COMPLEX
Systematic name | M25903
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that binds to, and promotes stabilization of, mRNA molecules containing the coding region instability determinant (CRD). In human, it may consist of IGF2BP1, HNRNPU, SYNCRIP/HNRNPQ, YBX1, and DHX9. [GOC:mah, PMID:19029303]
Full description |

Standard name | GO_CONTRACTILE_RING
Systematic name | M25904
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cytoskeletal structure composed of filamentous protein that forms beneath the membrane of many cells or organelles, in the plane of cell or organelle division. Ring contraction is associated with centripetal growth of the membrane that divides the cytoplasm of the two daughter cells or organelles. [GOC:mah, ISBN:0123645859, ISBN:0792354923, PMID:10791428, PMID:17913889]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_EXIT_SITE
Systematic name | M25905
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An endoplasmic reticulum part at which COPII-coated vesicles are produced. [NIF_Subcellular:sao124393998, PMID:15623529, PMID:16957052]
Full description |

Standard name | GO_TRANSLATION_PREINITIATION_COMPLEX
Systematic name | M17745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains the small ribosomal subunit, a translation initiation ternary complex (i.e. an initiator tRNA, GTP, and an IF2 or eIF2 complex), and an mRNA. [GOC:hjd, GOC:mah]
Full description |

Standard name | GO_U2_TYPE_CATALYTIC_STEP_2_SPLICEOSOME
Systematic name | M25906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spliceosomal complex that contains the U2, U5 and U6 snRNPs bound to a splicing intermediate in which the first catalytic cleavage of the 5' splice site has occurred. The precise subunit composition differs significantly from that of the catalytic step 1, or activated, spliceosome, and includes many proteins in addition to those found in the U2, U5 and U6 snRNPs. [GOC:ab, GOC:krc, GOC:mah, ISBN:0879695897, ISBN:0879697393, PMID:18322460, PMID:19239890]
Full description |

Standard name | GO_PRESPLICEOSOME
Systematic name | M17478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spliceosomal complex that is formed by association of the 5' splice site and the branch point sequence with specific snRNPs. The prespliceosome includes many proteins in addition to those found in the bound snRNPs. Commitment to a given pair of 5' and 3' splice sites occurs at the time of prespliceosome formation. Prespliceosome complexes are not active for splicing, but are instead an early step in the assembly of a spliceosomal complex. [GOC:ab, GOC:krc, GOC:mah, PMID:17332742, PMID:19239890]
Full description |

Standard name | GO_PRECATALYTIC_SPLICEOSOME
Systematic name | M17178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spliceosomal complex that is formed by the recruitment of a preassembled U5-containing tri-snRNP to the prespliceosome. Although all 5 snRNPs are present, the precatalytic spliceosome is catalytically inactive. The precatalytic spliceosome includes many proteins in addition to those found in the associated snRNPs. [GOC:ab, GOC:krc, GOC:mah, PMID:18322460, PMID:19239890]
Full description |

Standard name | GO_CATALYTIC_STEP_1_SPLICEOSOME
Systematic name | M25907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spliceosomal complex that is formed by the displacement of the two snRNPs from the precatalytic spliceosome; three snRNPs including U5 remain associated with the mRNA. This complex, sometimes called the activated spliceosome, is the catalytically active form of the spliceosome, and includes many proteins in addition to those found in the associated snRNPs. [GOC:ab, GOC:krc, GOC:mah, PMID:18322460, PMID:19239890]
Full description |

Standard name | GO_CATALYTIC_STEP_2_SPLICEOSOME
Systematic name | M17484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spliceosomal complex that contains three snRNPs, including U5, bound to a splicing intermediate in which the first catalytic cleavage of the 5' splice site has occurred. The precise subunit composition differs significantly from that of the catalytic step 1, or activated, spliceosome, and includes many proteins in addition to those found in the associated snRNPs. [GOC:ab, GOC:krc, GOC:mah, ISBN:0879695897, ISBN:0879697393, PMID:18322460, PMID:19239890]
Full description |

Standard name | GO_POST_MRNA_RELEASE_SPLICEOSOMAL_COMPLEX
Systematic name | M25908
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spliceosomal complex that is formed following the release of the spliced product from the post-spliceosomal complex and contains the excised intron and three snRNPs, including U5. [GOC:ab, GOC:krc, GOC:mah, ISBN:0879695897, ISBN:0879697393, PMID:19239890]
Full description |

Standard name | GO_SMAD_PROTEIN_COMPLEX
Systematic name | M25909
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that consists of only SMAD proteins; may be homomeric or heteromeric. Heteromeric complexes act as transcription factors while homomeric complexes exist but are transcriptionally inactive. Hetero- versus homotrimerization is largely enthalpy driven. [GOC:bhm, GOC:mah, PMID:9670020]
Full description |

Standard name | GO_WASH_COMPLEX
Systematic name | M17688
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that localizes at the surface of endosomes, where it recruits and activates the Arp2/3 complex to induce actin polymerization. In human, the WASH complex is composed of F-actin-capping protein subunits alpha and beta, WASH1, FAM21, KIAA1033, KIAA0196 and CCDC53. [GOC:sp, PMID:19922875]
Full description |

Standard name | GO_HISTONE_PRE_MRNA_3_END_PROCESSING_COMPLEX
Systematic name | M25910
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein that binds to specific sites in, and is required for cleavage of, the 3'-end of histone pre-mRNAs. The complex contains the U7 snRNP and additional proteins, including the stem-loop binding protein (SLBP) and the exonuclease 3'hExo/Eri-1. [GOC:mah, PMID:19470752]
Full description |

Standard name | GO_TRANSLOCON_COMPLEX
Systematic name | M25911
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that constitutes a specific site of protein translocation across the endoplasmic reticulum, which involves the signal recognition particle receptor. The complex contains a core heterotrimer of alpha, beta and gamma subunits, and may contain additional proteins. [GOC:mah, PMID:10611978, PMID:18166647, PMID:8612571]
Full description |

Standard name | GO_INVADOPODIUM
Systematic name | M17290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell projection that emerges from the ECM-facing surface of a cell, is enriched in actin and associated cytoskeletal proteins, and displays localized proteolytic activity toward the substrate. [GOC:mah, PMID:16651416, PMID:19491051, PMID:19931459]
Full description |

Standard name | GO_INVADOPODIUM_MEMBRANE
Systematic name | M25912
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the plasma membrane surrounding an invadopodium. [GOC:mah]
Full description |

Standard name | GO_CLATHRIN_COMPLEX
Systematic name | M25913
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that consists of three clathrin heavy chains and three clathrin light chains, organized into a symmetrical three-legged structure called a triskelion. In clathrin-coated vesicles clathrin is the main component of the coat and forms a polymeric mechanical scaffold on the vesicle surface. [GOC:mah, PMID:16493411]
Full description |

Standard name | GO_INTEGRAL_COMPONENT_OF_CYTOPLASMIC_SIDE_OF_ENDOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M25914
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the endoplasmic reticulum membrane consisting of the gene products that penetrate only the cytoplasmic side of the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_EUKARYOTIC_TRANSLATION_INITIATION_FACTOR_3_COMPLEX_EIF3M
Systematic name | M25915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An eukaryotic translation initiation factor 3 complex that contains the PCI-domain protein eIF3m. [PMID:15904532, PMID:19061185]
Full description |

Standard name | GO_PI_BODY
Systematic name | M25916
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A P granule that contains the PIWIL2-TDRD1 module, a set of proteins that act in the primary piRNA pathway. The pi-body corresponds to the cementing material between mitochondria found in gonocytes. [GOC:sp, PMID:20011505]
Full description |

Standard name | GO_PIP_BODY
Systematic name | M25917
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A P granule that contains the PIWIL4-TDRD9 module, a set of proteins that act in the secondary piRNA pathway. [GOC:sp, PMID:20011505]
Full description |

Standard name | GO_NPBAF_COMPLEX
Systematic name | M17209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A SWI/SNF-type complex that is found in neural stem or progenitor cells, and in human contains actin and proteins encoded by the ARID1A/BAF250A or ARID1B/BAF250B, SMARCD1/BAF60A, SMARCD3/BAF60C, SMARCA2/BRM/BAF190B, SMARCA4/BRG1/BAF190A, SMARCB1/BAF47, SMARCC1/BAF155, SMARCE1/BAF57, SMARCC2/BAF170, PHF10/BAF45A, ACTL6A/BAF53A genes. The npBAF complex is essential for the self-renewal/proliferative capacity of the multipotent neural stem cells. [GOC:mah, GOC:ss, PMID:17640523]
Full description |

Standard name | GO_NBAF_COMPLEX
Systematic name | M17757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A SWI/SNF-type complex that is found in post-mitotic neurons, and in human contains actin and proteins encoded by the ARID1A/BAF250A or ARID1B/BAF250B, SMARCD1/BAF60A, SMARCD3/BAF60C, SMARCA2/BRM/BAF190B, SMARCA4/BRG1/BAF190A, SMARCB1/BAF47, SMARCC1/BAF155, SMARCE1/BAF57, SMARCC2/BAF170, DPF1/BAF45B, DPF3/BAF45C, ACTL6B/BAF53B genes. The nBAF complex along with CREST plays a role regulating the activity of genes essential for dendrite growth. [GOC:mah, GOC:ss, PMID:17640523]
Full description |

Standard name | GO_ENDOCYTIC_VESICLE_LUMEN
Systematic name | M17389
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the membrane of an endocytic vesicle. [GOC:pde]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_TUBULAR_NETWORK
Systematic name | M17015
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A subcompartment of the endoplasmic reticulum consisting of tubules having membranes with high curvature in cross-section. [GOC:vw, PMID:16469703, PMID:20434336]
Full description |

Standard name | GO_MMXD_COMPLEX
Systematic name | M25919
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains the proteins MMS19, MIP18 and XPD, localizes to mitotic spindle during mitosis, and is required for proper chromosome segregation. [GOC:sp, PMID:20797633]
Full description |

Standard name | GO_RAGULATOR_COMPLEX
Systematic name | M25920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A eukaryotically conserved protein complex; in humans, it is comprised of LAMTOR1, LAMTOR2, LAMTOR3, LAMTOR4, and LAMTOR5. The complex is anchored to lipid rafts in late endosome membranes via LAMTOR1, constitutes a guanine nucleotide exchange factor (GEF) for the Rag GTPases. [GOC:krc, GOC:lb, GOC:vw, PMID:19177150, PMID:20381137, PMID:22980980, PMID:29199950]
Full description |

Standard name | GO_PTW_PP1_PHOSPHATASE_COMPLEX
Systematic name | M25921
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein serine/threonine phosphatase complex that contains a catalytic subunit (PPP1CA, PPP1CB or PPP1CC) and the regulatory subunits PPP1R10 (PNUTS), TOX4 and WDR82, and plays a role in the control of chromatin structure and cell cycle progression during the transition from mitosis into interphase. [GOC:mah, PMID:20516061]
Full description |

Standard name | GO_ER_MEMBRANE_INSERTION_COMPLEX
Systematic name | M25922
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that is involved in the post-translational delivery of tail-anchored (TA) membrane proteins to the endoplasmic reticulum. TA membrane proteins, also called type II transmembrane proteins, contain a single C-terminal transmembrane region. Some ER membrane insertion complex subunits are conserved between different species such as mammals and budding yeast. [GOC:mah, PMID:20676083, PMID:20850366]
Full description |

Standard name | GO_MSL_COMPLEX
Systematic name | M25923
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A histone acetyltransferase complex that catalyzes the acetylation of a histone H4 lysine residue at position 16. In human, it contains the catalytic subunit MOF, and MSL1, MSL2 and MSL3. [PMID:16227571, PMID:20018852]
Full description |

Standard name | GO_ER_MEMBRANE_PROTEIN_COMPLEX
Systematic name | M25924
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transmembrane protein complex located in the ER that is involved in ER-mitochondrial membrane tethering, which is required to facilitate lipid transfer from the ER to the mitochondrial membrane. In S. cerevisiae, it has six members: EMC1, EMC2, AIM27, EMC4, KRE27, and EMC6. [GOC:dgf, GOC:krc, GOC:vw, PMID:19325107, PMID:25313861]
Full description |

Standard name | GO_IPAF_INFLAMMASOME_COMPLEX
Systematic name | M34355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that consists of three components, IPAF, NAIP and caspase-1, and includes among its functions the sensing of flagellin derived from Legionella pneumophila, Salmonella typhimurium, Pseudomonas aeruginosa and Shigella flexneri. [GOC:add, GOC:BHF, GOC:vp, PMID:20303873]
Full description |

Standard name | GO_NLRP3_INFLAMMASOME_COMPLEX
Systematic name | M25925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that consists of three components, NLRP3 (NALP3), PYCARD and caspase-1. It is activated upon exposure to whole pathogens, as well as a number of structurally diverse pathogen- and danger-associated molecular patterns (PAMPs and DAMPs) and environmental irritants. Whole pathogens demonstrated to activate the NLRP3 inflammasome complex include the fungi Candida albicans and Saccharomyces cerevisiae, bacteria that produce pore-forming toxins, including Listeria monocytogenes and Staphylococcus aureus, and viruses such as Sendai virus, adenovirus, and influenza virus. [GOC:add, GOC:BHF, GOC:vp, PMID:20303873]
Full description |

Standard name | GO_BLOOD_MICROPARTICLE
Systematic name | M17273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A phospholipid microvesicle that is derived from any of several cell types, such as platelets, blood cells, endothelial cells, or others, and contains membrane receptors as well as other proteins characteristic of the parental cell. Microparticles are heterogeneous in size, and are characterized as microvesicles free of nucleic acids. [GOC:BHF, GOC:mah, PMID:16373184]
Full description |

Standard name | GO_BOX_H_ACA_RNP_COMPLEX
Systematic name | M25926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex that contains an RNA of the box H/ACA type and the four core proteins dyskerin, NOP10, NHP2, and GAR1 (human protein nomenclature). RNA pseudouridylation (isomerization of uridine to pseudouridine) is the major, and most likely the ancestral, function of H/ACA RNPs. Pseudouridylation targets include both large and small ribosomal RNAs (rRNAs), and small nuclear RNA (U2 snRNA). In addition to these catalytic H/ACA RNPs, a less abundant but more diverse class of structural H/ACA RNPs exists, which does not have pseudouridylation activity. These include the vertebrate telomerase RNP complex. [GOC:BHF, GOC:BHF_telomerase, GOC:jbu, GOC:mah, GOC:vw, PMID:17284456, PMID:20227365]
Full description |

Standard name | GO_TRNA_SPLICING_LIGASE_COMPLEX
Systematic name | M25927
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that catalyzes the ligation of cleaved pre-tRNAs by directly joining spliced tRNA halves to mature-sized tRNAs by incorporating the precursor-derived splice junction phosphate into the mature tRNA as a canonical 3',5'-phosphodiester. [GOC:sp, PMID:21311021]
Full description |

Standard name | GO_MITOTIC_SPINDLE
Systematic name | M17132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spindle that forms as part of mitosis. Mitotic and meiotic spindles contain distinctive complements of proteins associated with microtubules. [GOC:mah, GOC:vw, PMID:11408572, PMID:18367542, PMID:8027178]
Full description |

Standard name | GO_MEIOTIC_SPINDLE
Systematic name | M25928
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spindle that forms as part of meiosis. Several proteins, such as budding yeast Spo21p, fission yeast Spo2 and Spo13, and C. elegans mei-1, localize specifically to the meiotic spindle and are absent from the mitotic spindle. [GOC:mah, GOC:vw, PMID:11408572, PMID:18367542, PMID:8027178]
Full description |

Standard name | GO_CUL4_RING_E3_UBIQUITIN_LIGASE_COMPLEX
Systematic name | M17638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ubiquitin ligase complex in which a cullin from the Cul4 family and a RING domain protein form the catalytic core; substrate specificity is conferred by an adaptor protein. [PMID:16792691, PMID:18223036, PMID:18552200]
Full description |

Standard name | GO_U2AF_COMPLEX
Systematic name | M25929
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterodimeric protein complex consisting of conserved large and small U2AF subunits that contributes to spliceosomal RNA splicing by binding to consensus sequences at the 3' splice site. U2AF is required to stabilize the association of the U2 snRNP with the branch point. [GOC:dos, GOC:mah, PMID:15231733, PMID:1538748, PMID:2963698, PMID:8657565]
Full description |

Standard name | GO_SPANNING_COMPONENT_OF_MEMBRANE
Systematic name | M25930
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of a membrane consisting of gene products and protein complexes that have some part that spans both leaflets of the membrane. [GOC:dos]
Full description |

Standard name | GO_CATION_TRANSPORTING_ATPASE_COMPLEX
Systematic name | M17038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Protein complex that carries out the reaction: ATP + H2O + cation(out) = ADP + phosphate + cation(in). [GOC:BHF]
Full description |

Standard name | GO_FLEMMING_BODY
Systematic name | M25931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell part that is the central region of the midbody characterized by a gap in alpha-tubulin staining. It is a dense structure of antiparallel microtubules from the central spindle in the middle of the intercellular bridge. [GOC:pm, PMID:18641129, PMID:22522702]
Full description |

Standard name | GO_RNA_POLYMERASE_II_TRANSCRIPTION_REPRESSOR_COMPLEX
Systematic name | M25932
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex, located in the nucleus, that possesses activity that prevents or downregulates transcription from a RNA polymerase II promoter. [GOC:tb]
Full description |

Standard name | GO_RNA_POLYMERASE_II_TRANSCRIPTION_REGULATOR_COMPLEX
Systematic name | M17103
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transcription factor complex that acts at a regulatory region of a gene transcribed by RNA polymerase II. [GOC:tb]
Full description |

Standard name | GO_RNA_POLYMERASE_III_TRANSCRIPTION_REGULATOR_COMPLEX
Systematic name | M25933
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transcription factor complex that acts at a regulatory region of a gene transcribed by RNA polymerase III. [GOC:tb]
Full description |

Standard name | GO_BOX_H_ACA_TELOMERASE_RNP_COMPLEX
Systematic name | M25934
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A box H/ACA ribonucleoprotein complex that contains the RNA component of vertebrate telomerase, the enzyme essential for the replication of chromosome termini in most eukaryotes. This ribonucleoprotein complex is a structural box H/ACA RNP, which does not have the catalytic pseudouridylation function shared by the majority of H/ACA RNPs present in the cell. [GOC:BHF, GOC:BHF_telomere, GOC:jbu, PMID:22527283]
Full description |

Standard name | GO_GLYCOPROTEIN_COMPLEX
Systematic name | M17092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex containing at least one glycosylated protein, may be held together by both covalent and noncovalent bonds. [GOC:pf, PMID:7693675, PMID:8662961]
Full description |

Standard name | GO_CENTRAL_REGION_OF_GROWTH_CONE
Systematic name | M29435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The center of the migrating motile tip of a growing nerve cell axon or dendrite. [GOC:sl, PMID:16260607]
Full description |

Standard name | GO_SITE_OF_DNA_DAMAGE
Systematic name | M25936
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A region of a chromosome at which DNA damage has occurred. DNA damage signaling and repair proteins accumulate at the lesion to respond to the damage and repair the DNA to form a continuous DNA helix. [GOC:pg]
Full description |

Standard name | GO_CILIARY_PLASM
Systematic name | M17731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | All of the contents of a cilium, excluding the plasma membrane surrounding the cilium. [GOC:BHF, GOC:cilia, GOC:dos, PMID:17895364]
Full description |

Standard name | GO_MPP7_DLG1_LIN7_COMPLEX
Systematic name | M25937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heterotrimeric protein complex formed by the association of MMP7, DLG1 and either LIN7A or LIN7C; regulates the stability and localization of DLG1 to cell junctions. [GOC:BHF, PMID:17237226]
Full description |

Standard name | GO_PERINUCLEAR_ENDOPLASMIC_RETICULUM
Systematic name | M17229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of endoplasmic reticulum, the intracellular network of tubules and cisternae, that occurs near the nucleus. The lumen of the perinuclear endoplasmic reticulum is contiguous with the nuclear envelope lumen (also called perinuclear space), the region between the inner and outer nuclear membranes. [GOC:bf, GOC:mah, GOC:mcc, GOC:pr, GOC:vw]
Full description |

Standard name | GO_SYNAPTIC_MEMBRANE
Systematic name | M17824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized area of membrane on either the presynaptic or the postsynaptic side of a synapse, the junction between a nerve fiber of one neuron and another neuron or muscle fiber or glial cell. [GOC:BHF, PMID:20410104]
Full description |

Standard name | GO_CYCLIN_A2_CDK2_COMPLEX
Systematic name | M34356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex consisting of cyclin A2 and cyclin-dependent kinase 2 (CDK2). Cyclins are characterized by periodicity in protein abundance throughout the cell cycle. Cyclin-dependent kinases represent a family of serine/threonine protein kinases that become active upon binding to a cyclin regulatory partner. [GOC:so, PMID:15935619]
Full description |

Standard name | GO_BCL_2_FAMILY_PROTEIN_COMPLEX
Systematic name | M25938
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that consists of members of the Bcl-2 family of anti- and proapoptotic regulators. Bcl-2 proteins respond to cues from various forms of intracellular stress, such as DNA damage or cytokine deprivation, and interact with opposing family members to determine whether or not the caspase proteolytic cascade should be unleashed. [GOC:so, PMID:14634621]
Full description |

Standard name | GO_NUCLEAR_STRESS_GRANULE
Systematic name | M25939
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A dense aggregation in the nucleus composed of proteins and RNAs that appear when the cell is under stress. [GOC:ans, PMID:10359787, PMID:12865437]
Full description |

Standard name | GO_AIM2_INFLAMMASOME_COMPLEX
Systematic name | M29436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that consists of AIM2, ASC, and caspase-1. AIM2 is a member of the HN-200 protein family that appears to be the sensor of cytosolic double-stranded DNA. [GOC:vp, PMID:20303873]
Full description |

Standard name | GO_TETRASPANIN_ENRICHED_MICRODOMAIN
Systematic name | M25940
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A pre-organized unit composed either of adhesion molecules (mainly integrins and members of the Ig superfamily), signaling receptors and/or enzyme-enriched plasma membrane domains that compartmentalizes cellular processes. Tetraspanin-enriched microdomains might be specially suited for the regulation of avidity of adhesion receptors and the compartmentalization of enzymatic activities. [GOC:ans, PMID:19709882, PMID:21930792]
Full description |

Standard name | GO_ALVEOLAR_LAMELLAR_BODY
Systematic name | M25941
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized secretory organelle found in type II pneumocytes and involved in the synthesis, secretion, and reutilization of pulmonary surfactant. [GOC:cjm, Wikipedia:Lamellar_granule]
Full description |

Standard name | GO_SPERM_CONNECTING_PIECE
Systematic name | M34357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The segment of the sperm flagellum that attaches to the implantation fossa of the nucleus in the sperm head; from the remnant of the centriole at this point, the axoneme extends throughout the length of the flagellum. [GOC:cjm, MP:0009830]
Full description |

Standard name | GO_SPERM_MIDPIECE
Systematic name | M17503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The highly organized segment of the sperm flagellum which begins at the connecting piece and is characterized by the presence of 9 outer dense fibers (ODFs) that lie outside each of the 9 outer axonemal microtubule doublets and by a sheath of mitochondria that encloses the ODFs and the axoneme; the midpiece terminates about one-fourth of the way down the sperm flagellum at the annulus, which marks the beginning of the principal piece. [GOC:cjm, MP:0009831]
Full description |

Standard name | GO_SPERM_ANNULUS
Systematic name | M25942
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The ring-like, filamentous structure located at the distal end of the midpiece of the sperm flagellum; the annulus is thought to form a diffusion barrier between the midpiece and the principal piece and serve as a stabilizing structure for tail rigidity. [GOC:cjm, MP:0009834]
Full description |

Standard name | GO_SPERM_PRINCIPAL_PIECE
Systematic name | M17483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The segment of the sperm flagellum where the mitochondrial sheath ends, and the outer dense fibers (ODFs) associated with outer axonemal doublets 3 and 8 are replaced by the 2 longitudinal columns of the fibrous sheath (FS) which run the length of the principal piece and are stabilized by circumferential ribs. The principal piece makes up ~2/3 of the length of the sperm flagellum and is defined by the presence of the FS and of only 7 (rather than 9) ODFs which taper and then terminate near the distal end of the principal piece. [GOC:cjm, MP:0009836]
Full description |

Standard name | GO_R2TP_COMPLEX
Systematic name | M25943
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A highly conserved protein complex comprised of two ATP-dependent DNA helicases (Rvb1p and Rvb2p in yeast, Pontin52 and Reptin52 in humans), Pih1p in yeast or PIH1D1 in humans, and Tah1 in yeast or RPAP3 in humans. The complex associates with Hsp90 and is thought to have a role in assembly of large protein or protein/nucleic acid complexes. In this role it is involved in multiple processes such as box C/D snoRNP biogenesis, phosphatidylinositol-3 kinase-related protein kinase (PIKK) signaling, RNA polymerase II assembly, and others. [GOC:mcc, PMID:15766533, PMID:21925213]
Full description |

Standard name | GO_RIPOPTOSOME
Systematic name | M25944
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex whose core components are the receptor-interacting serine/threonine-protein kinases RIPK1 and RIPK3 (also called RIP1 and RIP3). Formation of the ripoptosome can induce an extrinsic apoptotic signaling pathway or a necroptotic signaling pathway. The composition of this protein complex may depend on several factors including nature of the signal, cell type and more. [GOC:bhm, GOC:mtg_apoptosis, PMID:22265414, PMID:22274400]
Full description |

Standard name | GO_INO80_TYPE_COMPLEX
Systematic name | M17104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A chromatin remodeling protein complex initially purified from S. cerevisiae and containing more than 10 subunits, including the SWR1-related complexes. INO80 (inositol requiring 80)-type complexes have diverse functions, including promoting transcriptional activation and DNA repair. [GOC:rb, PMID:19355820]
Full description |

Standard name | GO_CIA_COMPLEX
Systematic name | M25945
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The cytosolic iron-sulfur protein assembly (CIA) complex mediates the incorporation of iron-sulfur clusters into apoproteins involved in DNA metabolism and genomic integrity. [GOC:sp, PMID:22678362]
Full description |

Standard name | GO_PHOTORECEPTOR_DISC_MEMBRANE
Systematic name | M17782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Stack of disc membranes located inside a photoreceptor outer segment, and containing densely packed molecules of photoreceptor proteins that traverse the lipid bilayer. Disc membranes arise as evaginations of the ciliary membrane during the development of the outer segment and may or may not remain contiguous with the ciliary membrane. [GOC:bj, GOC:krc, GOC:pde, PMID:11826267, PMID:19501669, PMID:2537204, PMID:26574505, PMID:6771304, PMID:7507907]
Full description |

Standard name | GO_GLIAL_CELL_PROJECTION
Systematic name | M17357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A prolongation or process extending from a glial cell. [GOC:mc]
Full description |

Standard name | GO_LEWY_BODY
Systematic name | M25946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Cytoplasmic, spherical inclusion commonly found in damaged neurons, and composed of abnormally phosphorylated, neurofilament proteins aggregated with ubiquitin and alpha-synuclein. [NIF_Subcellular:sao4933778419]
Full description |

Standard name | GO_NEUROFIBRILLARY_TANGLE
Systematic name | M25947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Intracellular mass of paired, helically wound protein filaments (also called PHF) lying in the cytoplasm of neuronal cell bodies and neuritic cell processes. Neurofibrillary tangles contain an abnormally phosphorylated form of a microtubule-associated protein, tau. The shape of these inclusions may resemble a flame or a star. [NIF_Subcellular:nlx_subcell_20090201, NIF_Subcellular:nlx_subcell_20090202, NIF_Subcellular:sao2409833926]
Full description |

Standard name | GO_TUBULAR_ENDOSOME
Systematic name | M25948
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A network of fine tubules in the vicinity of the Golgi complex and around the centriole. [NIF_Subcellular:sao1570660411, NIF_Subcellular:sao694815499, PMID:11896161]
Full description |

Standard name | GO_MICROTUBULE_BUNDLE
Systematic name | M25949
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An arrangement of closely apposed microtubules running parallel to each other. [NIF_Subcellular:sao1872343973]
Full description |

Standard name | GO_MITOTIC_SPINDLE_POLE
Systematic name | M25950
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Either of the ends of a mitotic spindle, a spindle that forms as part of mitosis, where spindle microtubules are organized; usually contains a microtubule organizing center and accessory molecules, spindle microtubules and astral microtubules. [GOC:vw]
Full description |

Standard name | GO_DENSE_BODY
Systematic name | M25951
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An electron dense body which may contain granules. [ISBN:0195065719, NIF_Subcellular:sao730872736]
Full description |

Standard name | GO_APICAL_DENDRITE
Systematic name | M17282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A dendrite that emerges near the apical pole of a neuron. In bipolar neurons, apical dendrites are located on the opposite side of the soma from the axon. [NIF_Subcellular:sao273773228]
Full description |

Standard name | GO_BASAL_DENDRITE
Systematic name | M25952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A dendrite that emerges near the basal pole of a neuron. In bipolar neurons, basal dendrites are either on the same side of the soma as the axon, or project toward the axon. [GOC:aruk, GOC:bc, NIF_Subcellular:sao1079900774, PMID:17046728, PMID:22683681]
Full description |

Standard name | GO_SORTING_ENDOSOME
Systematic name | M25953
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multivesicular body surrounded by and connected with multiple tubular compartments with associated vesicles. [NIF_Subcellular:sao1028571114]
Full description |

Standard name | GO_DENDRITIC_TREE
Systematic name | M25954
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The entire complement of dendrites for a neuron, consisting of each primary dendrite and all its branches. [GOC:aruk, GOC:bc, NIF_Subcellular:sao172297168]
Full description |

Standard name | GO_ASTROCYTE_PROJECTION
Systematic name | M25955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A prolongation or process extending from the soma of an astrocyte and wrapping around neurons. [NIF_Subcellular:sao1630537580]
Full description |

Standard name | GO_ASTROCYTE_END_FOOT
Systematic name | M25956
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Terminal process of astrocyte abutting non-neuronal surfaces in the brain. [NIF_Subcellular:sao388182739]
Full description |

Standard name | GO_RIBBON_SYNAPSE
Systematic name | M25957
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Type of synapse characterized by an electron-dense ribbon, lamella (bar) or spherical body in the presynaptic process cytoplasm. [NIF_Subcellular:sao1884931180, PMID:15626493]
Full description |

Standard name | GO_MULTIVESICULAR_BODY_LUMEN
Systematic name | M25958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The volume enclosed by the outermost membrane of a multivesicular body. [GOC:pde, PMID:21183070]
Full description |

Standard name | GO_GEMINI_OF_COILED_BODIES
Systematic name | M17140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Nuclear bodies frequently found near or associated with Cajal bodies (also called coiled bodies or CBs). Gemini of coiled bodies, or 'gems', are similar in size and shape to CBs, and often indistinguishable under the microscope. Unlike CBs, gems do not contain small nuclear ribonucleoproteins (snRNPs); they contain a protein called survivor of motor neurons (SMN) whose function relates to snRNP biogenesis. Gems are believed to assist CBs in snRNP biogenesis, and to play a role in the etiology of spinal muscular atrophy (SMA). [GOC:pr, PMID:11031238, PMID:9683623, Wikipedia:Cell_nucleus#Cajal_bodies_and_gems]
Full description |

Standard name | GO_CARDIAC_MYOFIBRIL
Systematic name | M25959
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cardiac myofibril is a myofibril specific to cardiac muscle cells. [GOC:cjm, GOC:devbiol]
Full description |

Standard name | GO_SPERM_PLASMA_MEMBRANE
Systematic name | M25960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A plasma membrane that is part of a sperm cell. [GOC:cjm]
Full description |

Standard name | GO_SPLICEOSOMAL_TRI_SNRNP_COMPLEX
Systematic name | M17317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spliceosomal snRNP complex containing U4 and U6 (or U4atac and U6atac) snRNAs and U5 snRNAs and associated proteins. [GOC:pr, ISBN:0879695897, PMID:9452384]
Full description |

Standard name | GO_CILIARY_TRANSITION_FIBER
Systematic name | M25961
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A nine-bladed, propeller-like protein complex that links the distal end of the basal body and the cilium to the plasma membrane. Functions in protein sorting and gating (i.e. active and passive transport of proteins in and out of the cilium). [GOC:cilia, GOC:kmv, GOC:krc, PMID:22653444, PMID:24231678, PMID:5064817, PMID:5335827]
Full description |

Standard name | GO_CILIARY_TIP
Systematic name | M17230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Part of the cilium where the axoneme ends. The ciliary tip has been implicated in ciliary assembly and disassembly, as well as signal transduction. [GOC:cilia, PMID:23970417]
Full description |

Standard name | GO_CILIARY_BASE
Systematic name | M17574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Area of the cilium (also called flagellum) where the basal body and the axoneme are anchored to the plasma membrane. The ciliary base encompasses the distal part of the basal body, transition fibers and transition zone and is structurally and functionally very distinct from the rest of the cilium. In this area proteins are sorted and filtered before entering the cilium, and many ciliary proteins localize specifically to this area. [GOC:cilia, GOC:krc, PMID:22653444]
Full description |

Standard name | GO_TRANSCRIPTION_PREINITIATION_COMPLEX
Systematic name | M25962
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein-DNA complex composed of proteins binding promoter DNA to form the transcriptional preinitiation complex (PIC), the formation of which is a prerequisite for transcription. [GOC:di, PMID:22751016]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_RECEPTOR_COMPLEX
Systematic name | M25963
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains G protein-coupled receptors. [GOC:bhm]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_KINASE_COMPLEX_CLASS_I
Systematic name | M25964
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A phosphatidylinositol 3-kinase complex that contains a catalytic and a regulatory subunit of a phosphatidylinositol 3-kinase (PI3K) enzyme, plus one or more adaptor proteins. Class I PI3Ks phosphorylate phosphatidylinositol [PI], phosphatidylinositol-4-phosphate [PI(4)P] and phosphatidylinositol-4,5-bisphosphate [PI(4,5)P2], and are divided into subclasses A and B according to the type of adaptor subunit with which they associate. The class I PI3K subfamily of genes comprises members in vertebrates, worm and fly, but none in yeast. [GOC:ha, PMID:24587488]
Full description |

Standard name | GO_9PLUS2_MOTILE_CILIUM
Systematic name | M25965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A motile cilium where the axoneme has a ring of nine outer microtubule doublets plus two central microtubules (and is therefore called a 9+2 axoneme). [GOC:cilia, PMID:22118931]
Full description |

Standard name | GO_NON_MOTILE_CILIUM
Systematic name | M25966
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cilium which may have a variable array of axonemal microtubules but does not contain molecular motors. [GOC:cilia, GOC:dgh, GOC:kmv, PMID:17009929, PMID:20144998, PMID:22118931]
Full description |

Standard name | GO_9PLUS0_NON_MOTILE_CILIUM
Systematic name | M25967
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A non-motile cilium where the axoneme has a ring of nine outer microtubule doublets but no central microtubules (and is therefore called a 9+0 axoneme). [GOC:cilia, PMID:22118931]
Full description |

Standard name | GO_PHOTORECEPTOR_CELL_CILIUM
Systematic name | M34358
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialised 9+0 non-motile cilium found in photoreceptor cells. A ciliary transition zone called 'photoreceptor connecting cilium' links the photoreceptor outer segment to the inner segment. [GOC:cilia, Wikipedia:Photoreceptor_cell#Histology]
Full description |

Standard name | GO_ATPASE_DEPENDENT_TRANSMEMBRANE_TRANSPORT_COMPLEX
Systematic name | M25968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A transmembrane protein complex that functions in ATPase dependent active transport across a membrane. [GOC:dos]
Full description |

Standard name | GO_DEUTEROSOME
Systematic name | M25969
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A spherical, electron dense, cytoplasmic structure that is involved in de novo assembly of centrioles. [GOC:cilia, GOC:dos, PMID:24075808, PMID:25047614, PMID:5661997]
Full description |

Standard name | GO_SIDE_OF_MEMBRANE
Systematic name | M17514
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cellular component consisting of one leaflet of a membrane bilayer and any proteins embedded or anchored in it or attached to its surface. [GOC:dos]
Full description |

Standard name | GO_LUMENAL_SIDE_OF_ENDOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M29437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The side (leaflet) of the plasma membrane that faces the lumen. [GOC:ab, GOC:dos]
Full description |

Standard name | GO_CYTOPLASMIC_SIDE_OF_ENDOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M25970
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The side (leaflet) of the plasma membrane that faces the cytoplasm. [GOC:ab, GOC:dos]
Full description |

Standard name | GO_CYTOPLASMIC_SIDE_OF_ROUGH_ENDOPLASMIC_RETICULUM_MEMBRANE
Systematic name | M25971
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The side (leaflet) of the rough endoplasmic reticulum membrane that faces the cytoplasm. [GOC:ab, GOC:dos]
Full description |

Standard name | GO_CYTOPLASMIC_SIDE_OF_MEMBRANE
Systematic name | M17080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The side of a membrane that faces the cytoplasm. [GOC:dos]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_SYNAPTIC_VESICLE_MEMBRANE
Systematic name | M25972
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the synaptic vesicle membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_MITOCHONDRIAL_MEMBRANE
Systematic name | M17617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the mitochondrial membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos]
Full description |

Standard name | GO_CYTOPLASMIC_SIDE_OF_LYSOSOMAL_MEMBRANE
Systematic name | M25973
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The side (leaflet) of the lysosomal membrane that faces the cytoplasm. [GOC:ab, GOC:dos]
Full description |

Standard name | GO_LUMENAL_SIDE_OF_MEMBRANE
Systematic name | M17168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any side (leaflet) of a membrane that faces the lumen of an organelle. [GOC:dos]
Full description |

Standard name | GO_MEMBRANE_REGION
Systematic name | M17755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane that is a part of a larger membrane. Examples include the apical region of the plasma membrane of an epithelial cell and the various regions of the endoplasmic reticulum membrane. [GOC:dos]
Full description |

Standard name | GO_PLASMA_MEMBRANE_REGION
Systematic name | M17628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A membrane that is a (regional) part of the plasma membrane. [GOC:dos]
Full description |

Standard name | GO_EXTERNAL_SIDE_OF_APICAL_PLASMA_MEMBRANE
Systematic name | M34359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The leaflet the apical region of the plasma membrane that faces away from the cytoplasm and any proteins embedded or anchored in it or attached to its surface. [GOC:ab, GOC:dos]
Full description |

Standard name | GO_PROTEIN_COMPLEX_INVOLVED_IN_CELL_ADHESION
Systematic name | M17195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that is capable of carrying out some part of the process of cell adhesion to the cell matrix or to another cell. [GOC:dos]
Full description |

Standard name | GO_COMPLEX_OF_COLLAGEN_TRIMERS
Systematic name | M17310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A complex of collagen trimers such as a fibril or collagen network. [GOC:dos]
Full description |

Standard name | GO_BASEMENT_MEMBRANE_COLLAGEN_TRIMER
Systematic name | M25974
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any collagen timer that is part of a basement membrane. [GOC:dos, PMID:21421911]
Full description |

Standard name | GO_PHOTORECEPTOR_RIBBON_SYNAPSE
Systematic name | M25975
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribbon synapse between a retinal photoreceptor cell (rod or cone) and a retinal bipolar cell. These contain a plate-like synaptic ribbon. [PMID:15626493]
Full description |

Standard name | GO_SCHAFFER_COLLATERAL_CA1_SYNAPSE
Systematic name | M25976
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A synapse between the Schaffer collateral axon of a CA3 pyramidal cell and a CA1 pyramidal cell. [PMID:16399689]
Full description |

Standard name | GO_HIPPOCAMPAL_MOSSY_FIBER_TO_CA3_SYNAPSE
Systematic name | M25977
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | One of the giant synapses that form between the mossy fiber axons of dentate gyrus granule cells and the large complex spines of CA3 pyramidal cells. It consists of a giant bouton known as the mossy fiber expansion, synapsed to the complex, multiheaded spine (thorny excresence) of a CA3 pyramidal cell. [DOI:10.1002/1096-9861, PMID:13869693, PMID:23264762]
Full description |

Standard name | GO_CHROMOSOMAL_REGION
Systematic name | M17130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any subdivision of a chromosome along its length. [GOC:dos]
Full description |

Standard name | GO_PARALLEL_FIBER_TO_PURKINJE_CELL_SYNAPSE
Systematic name | M25978
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An excitatory synapse formed by the parallel fibers of granule cells synapsing onto the dendrites of Purkinje cells. [PMID:16623829, PMID:3209740]
Full description |

Standard name | GO_GLYCINERGIC_SYNAPSE
Systematic name | M25979
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A synapse that uses glycine as a neurotransmitter. [GOC:dos]
Full description |

Standard name | GO_DOPAMINERGIC_SYNAPSE
Systematic name | M25980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A synapse that uses dopamine as a neurotransmitter. [GOC:dos]
Full description |

Standard name | GO_PRESYNAPSE
Systematic name | M17674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The part of a synapse that is part of the presynaptic cell. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPSE
Systematic name | M17177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The part of a synapse that is part of the post-synaptic cell. [GOC:dos]
Full description |

Standard name | GO_MEMBRANE_PROTEIN_COMPLEX
Systematic name | M17519
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that is part of a membrane. [GOC:dos]
Full description |

Standard name | GO_PLASMA_MEMBRANE_PROTEIN_COMPLEX
Systematic name | M17810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that is part of the plasma membrane. [GOC:dos]
Full description |

Standard name | GO_MITOCHONDRIAL_PROTEIN_COMPLEX
Systematic name | M17748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that is part of a mitochondrion. [GOC:dos]
Full description |

Standard name | GO_OUTER_MITOCHONDRIAL_MEMBRANE_PROTEIN_COMPLEX
Systematic name | M17210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that is part of the outer mitochondrial membrane. [GOC:dos]
Full description |

Standard name | GO_INNER_MITOCHONDRIAL_MEMBRANE_PROTEIN_COMPLEX
Systematic name | M17461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that is part of the inner mitochondrial membrane. [GOC:dos]
Full description |

Standard name | GO_PLASMA_MEMBRANE_SIGNALING_RECEPTOR_COMPLEX
Systematic name | M17073
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that is part of the plasma membrane and which functions as a signaling receptor. [GOC:dos]
Full description |

Standard name | GO_RESPIRATORY_CHAIN_COMPLEX
Systematic name | M25981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that is part of a respiratory chain. [GOC:dos]
Full description |

Standard name | GO_WHOLE_MEMBRANE
Systematic name | M25982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any lipid bilayer that completely encloses some structure, and all the proteins embedded in it or attached to it. Examples include the plasma membrane and most organelle membranes. [GOC:dos]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_TUBULAR_NETWORK_MEMBRANE
Systematic name | M25983
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The membrane of the endoplasmic reticulum tubular network. [PMID:16469703]
Full description |

Standard name | GO_ENDOPLASMIC_RETICULUM_SUBCOMPARTMENT
Systematic name | M17841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A distinct region of the endoplasmic reticulum. [GOC:dos]
Full description |

Standard name | GO_PRESYNAPTIC_ACTIVE_ZONE_CYTOPLASMIC_COMPONENT
Systematic name | M25984
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized region below the presynaptic membrane, characterized by electron-dense material, a specialized cytoskeletal matrix and accumulated (associated) synaptic vesicles. [GOC:dos]
Full description |

Standard name | GO_PRESYNAPTIC_ENDOCYTIC_ZONE
Systematic name | M25985
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A specialized region of the plasma membrane and underlying cytoplasm which surround the the active zone, into which synaptic vesicle membranes are recycled following exocytosis. It is especially enriched in endocytic proteins following intense activity. [PMID:17455288]
Full description |

Standard name | GO_PRESYNAPTIC_ENDOCYTIC_ZONE_MEMBRANE
Systematic name | M29438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of the presynaptic membrane that is part of the presynaptic endocytic zone - where synaptic vesicles are endocytosed and recycled following release. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_RECYCLING_ENDOSOME
Systematic name | M25986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A recycling endosome of the postsynapse. In postsynaptic terminals with dendritic spines, it is typically located at the base of a dendritic spine. It is involved in recycling of neurotransmitter receptors to the postsynaptic membrane. In some cases at least, this recycling is activated by postsynaptic signalling and so can play a role in long term potentiation. [PMID:20820847]
Full description |

Standard name | GO_POSTSYNAPTIC_DENSITY_MEMBRANE
Systematic name | M25987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The membrane component of the postsynaptic density. This is the region of the postsynaptic membrane in which the population of neurotransmitter receptors involved in synaptic transmission are concentrated. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_ENDOCYTIC_ZONE
Systematic name | M25988
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A stably positioned site of clathrin adjacent and physically attached to the postsynaptic specialization, which is the site of endocytosis of post-synaptic proteins. [PMID:17880892]
Full description |

Standard name | GO_POSTSYNAPTIC_ENDOCYTIC_ZONE_MEMBRANE
Systematic name | M29439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of the postsynaptic membrane that is part of the postsynaptic endocytic zone. This region of membrane is associated with stable clathrin puncta. [PMID:17880892]
Full description |

Standard name | GO_POSTSYNAPTIC_ENDOSOME
Systematic name | M25989
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An endosomal compartment that is part of the post-synapse. Only early and recycling endosomes are typically present in the postsynapse. [PMID:20820847]
Full description |

Standard name | GO_ACTIN_BASED_CELL_PROJECTION
Systematic name | M17655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell projection supported by an assembly of actin filaments, and which lacks microtubules. [PMID:15661519]
Full description |

Standard name | GO_CLUSTER_OF_ACTIN_BASED_CELL_PROJECTIONS
Systematic name | M17341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cell part consisting of multiple, closely packed actin-based cell projections. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_ACTIN_CYTOSKELETON
Systematic name | M25990
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The actin cytoskeleton that is part of a postsynapse. [GOC:dos]
Full description |

Standard name | GO_NEUROTRANSMITTER_RECEPTOR_COMPLEX
Systematic name | M25991
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that is capable of functioning as a neurotransmitter receptor. [GOC:dos]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_PRESYNAPTIC_MEMBRANE
Systematic name | M25992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the presynaptic membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:autophagy, GOC:mf]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_PRESYNAPTIC_MEMBRANE
Systematic name | M25993
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the presynaptic membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_POSTSYNAPTIC_MEMBRANE
Systematic name | M25994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the postsynaptic membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:autophagy, GOC:mf]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_POSTSYNAPTIC_SPECIALIZATION_MEMBRANE
Systematic name | M25995
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the postsynaptic specialization membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:autophagy, GOC:mf]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_POSTSYNAPTIC_MEMBRANE
Systematic name | M25996
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the postsynaptic membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_PRESYNAPTIC_ACTIVE_ZONE_MEMBRANE
Systematic name | M25997
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the presynaptic active zone membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_POSTSYNAPTIC_SPECIALIZATION_MEMBRANE
Systematic name | M25998
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the postsynaptic specialization membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_GLUTAMATERGIC_SYNAPSE
Systematic name | M25999
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A synapse that uses glutamate as a neurotransmitter. [GOC:dos]
Full description |

Standard name | GO_CHOLINERGIC_SYNAPSE
Systematic name | M26000
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A synapse that uses acetylcholine as a neurotransmitter. [GOC:dos]
Full description |

Standard name | GO_GABA_ERGIC_SYNAPSE
Systematic name | M26001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A synapse that uses GABA as a neurotransmitter. These synapses are typically inhibitory. [GOC:dos]
Full description |

Standard name | GO_NEURON_TO_NEURON_SYNAPSE
Systematic name | M26002
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A synapse in which pre and post-synaptic cells are neurons. [GOC:dos]
Full description |

Standard name | GO_ASYMMETRIC_GLUTAMATERGIC_EXCITATORY_SYNAPSE
Systematic name | M26003
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A neuron to neuron synapse with a postsynaptic density, that uses glutamate as a neurotransmitter and whose activity results in excitatory postsynaptic potentials. [GOC:dos]
Full description |

Standard name | GO_NEURONAL_DENSE_CORE_VESICLE
Systematic name | M26004
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A dense core vesicle (granule) that is part of a neuron. These vesicles typically contain neuropeptides. They can be found in all parts of neurons, including the soma, dendrites, axonal swellings (varicosities) and synaptic terminals. [GOC:dos, ISBN:978-0-07-181001-2, Wikipedia:Neuropeptide&oldid=713905176]
Full description |

Standard name | GO_ANCHORED_COMPONENT_OF_SYNAPTIC_VESICLE_MEMBRANE
Systematic name | M26005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the synaptic vesicle membrane consisting of the gene products that are tethered to the membrane only by a covalently attached anchor, such as a lipid group that is embedded in the membrane. Gene products with peptide sequences that are embedded in the membrane are excluded from this grouping. [GOC:dos]
Full description |

Standard name | GO_VESICLE_TETHERING_COMPLEX
Systematic name | M26006
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that plays a role in vesicle tethering. [GOC:dos, GOC:vw, PMID:27243008]
Full description |

Standard name | GO_ANCHORED_COMPONENT_OF_POSTSYNAPTIC_MEMBRANE
Systematic name | M26007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the postsynaptic membrane consisting of the gene products that are tethered to the membrane only by a covalently attached anchor, such as a lipid group that is embedded in the membrane. Gene products with peptide sequences that are embedded in the membrane are excluded from this grouping. [GOC:dos]
Full description |

Standard name | GO_ANCHORED_COMPONENT_OF_PRESYNAPTIC_MEMBRANE
Systematic name | M26008
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the presynaptic membrane consisting of the gene products that are tethered to the membrane only by a covalently attached anchor, such as a lipid group that is embedded in the membrane. Gene products with peptide sequences that are embedded in the membrane are excluded from this grouping. [GOC:dos]
Full description |

Standard name | GO_INTEGRAL_COMPONENT_OF_PRESYNAPTIC_ACTIVE_ZONE_MEMBRANE
Systematic name | M26009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the presynaptic active zone membrane consisting of the gene products and protein complexes having at least some part of their peptide sequence embedded in the hydrophobic region of the membrane. [GOC:dos]
Full description |

Standard name | GO_BORC_COMPLEX
Systematic name | M26010
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that is invovled in positioning of the lysosome within the cytoplasm and which is composed of BLOC1S1, BLOC1S2, BORCS5, BORCS6, BORCS7, BORCS8, KXD1 and SNAPIN. The BORC complex recruits ARL8 at the cytosolic face of lysosomes and couples them to microtubule plus-end-directed kinesin motors. [GOC:dos, GOC:li, PMID:25898167]
Full description |

Standard name | GO_SUPRAMOLECULAR_COMPLEX
Systematic name | M26011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cellular component that consists of an indeterminate number of proteins or macromolecular complexes, organized into a regular, higher-order structure such as a polymer, sheet, network or a fiber. [GOC:dos]
Full description |

Standard name | GO_SUPRAMOLECULAR_POLYMER
Systematic name | M29440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A polymeric supramolecular structure. [GOC:dos]
Full description |

Standard name | GO_SYNAPTONEMAL_STRUCTURE
Systematic name | M26012
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A proteinaceous scaffold found between homologous chromosomes during meiosis. [GOC:elh, GOC:vw]
Full description |

Standard name | GO_POSTSYNAPTIC_SPECIALIZATION_INTRACELLULAR_COMPONENT
Systematic name | M26013
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A network of proteins adjacent to the postsynaptic membrane. Its major components include the proteins that spatially and functionally organize neurotransmitter receptors in the adjacent membrane, such as anchoring and scaffolding molecules, signaling enzymes and cytoskeletal components. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_DENSITY_INTRACELLULAR_COMPONENT
Systematic name | M26014
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A network of proteins adjacent to the postsynaptic membrane forming an electron dense disc. Its major components include neurotransmitter receptors and the proteins that spatially and functionally organize neurotransmitter receptors in the adjacent membrane, such as anchoring and scaffolding molecules, signaling enzymes and cytoskeletal components. [GOC:dos]
Full description |

Standard name | GO_ANCHORED_COMPONENT_OF_SYNAPTIC_MEMBRANE
Systematic name | M26015
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the synaptic membrane consisting of the gene products that are tethered to the membrane only by a covalently attached anchor, such as a lipid group that is embedded in the membrane. Gene products with peptide sequences that are embedded in the membrane are excluded from this grouping. [GOC:dos]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_POSTSYNAPTIC_DENSITY_MEMBRANE
Systematic name | M26016
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the postsynaptic density membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_POSTSYNAPTIC_DENSITY_MEMBRANE
Systematic name | M26017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the postsynaptic density membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:autophagy, GOC:mf]
Full description |

Standard name | GO_INTRINSIC_COMPONENT_OF_SYNAPTIC_MEMBRANE
Systematic name | M26018
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the synaptic membrane consisting of the gene products and protein complexes having either part of their peptide sequence embedded in the hydrophobic region of the membrane or some other covalently attached group such as a GPI anchor that is similarly embedded in the membrane. [GOC:dos, GOC:mah]
Full description |

Standard name | GO_EXTRINSIC_COMPONENT_OF_SYNAPTIC_MEMBRANE
Systematic name | M26019
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The component of the synaptic membrane consisting of gene products and protein complexes that are loosely bound to one of its surfaces, but not integrated into the hydrophobic region. [GOC:dos]
Full description |

Standard name | GO_SECRETORY_VESICLE
Systematic name | M17119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A cytoplasmic, membrane bound vesicle that is capable of fusing to the plasma membrane to release its contents into the extracellular space. [GOC:dos]
Full description |

Standard name | GO_POLYMERIC_CYTOSKELETAL_FIBER
Systematic name | M26020
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A component of the cytoskeleton consisting of a homo or heteropolymeric fiber constructed from an indeterminate number of protein subunits. [GOC:dos]
Full description |

Standard name | GO_REGION_OF_CYTOSOL
Systematic name | M26021
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any (proper) part of the cytosol of a single cell of sufficient size to still be considered cytosol. [GOC:dos]
Full description |

Standard name | GO_PRESYNAPTIC_CYTOSOL
Systematic name | M26022
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of the cytosol consisting of all cytosol that is part of the presynapse. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_CYTOSOL
Systematic name | M26023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The region of the cytosol consisting of all cytosol that is part of the postsynapse. [GOC:dos]
Full description |

Standard name | GO_PERISYNAPTIC_SPACE
Systematic name | M34360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The extracellular region immediately adjacent to to a synapse. [GOC:dos]
Full description |

Standard name | GO_CYTOPLASMIC_REGION
Systematic name | M17085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any (proper) part of the cytoplasm of a single cell of sufficient size to still be considered cytoplasm. [GOC:dos]
Full description |

Standard name | GO_PRESYNAPTIC_CYTOSKELETON
Systematic name | M26024
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the cytoskeleton contained within the presynapse. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_CYTOSKELETON
Systematic name | M26025
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The portion of the cytoskeleton contained within the postsynapse. [GOC:dos, PMID:19889835]
Full description |

Standard name | GO_POSTSYNAPTIC_SPECIALIZATION_MEMBRANE
Systematic name | M26026
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The membrane component of the postsynaptic specialization. This is the region of the postsynaptic membrane in which the population of neurotransmitter receptors involved in synaptic transmission are concentrated. [GOC:dos]
Full description |

Standard name | GO_CELL_CORTEX_REGION
Systematic name | M17262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The complete extent of cell cortex that underlies some some region of the plasma membrane. [GOC:dos]
Full description |

Standard name | GO_FICOLIN_1_RICH_GRANULE
Systematic name | M26027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Highly exocytosable gelatinase-poor granules found in neutrophils and rich in ficolin-1. Ficolin-1 is released from neutrophil granules by stimulation with fMLP or PMA, and the majority becomes associated with the surface membrane of the cells and can be detected by flow cytometry. [GOC:mec, PMID:19741154]
Full description |

Standard name | GO_FICOLIN_1_RICH_GRANULE_MEMBRANE
Systematic name | M26028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The lipid bilayer surrounding a ficolin-1-rich granule. [GOC:mec, PMID:23650620]
Full description |

Standard name | GO_CHAPERONE_COMPLEX
Systematic name | M26029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex required for the non-covalent folding or unfolding, maturation, stabilization or assembly or disassembly of macromolecular structures. Usually active during or immediately after completion of translation. Many chaperone complexes contain heat shock proteins. [GOC:bhm, PMID:21855797]
Full description |

Standard name | GO_SUMO_LIGASE_COMPLEX
Systematic name | M29441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein ligase complex that enables protein sumoylation. Consists of a SUMO-protein transferase and other proteins that may confer substrate specificity of the complex. [PMID:16847351]
Full description |

Standard name | GO_CENTRIOLAR_SUBDISTAL_APPENDAGE
Systematic name | M26031
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which assembles on the mother centriole during cilium formation, adjacent and proximal to a centriolar distal appendage. In human, it contains ODF2, CNTRL, NIN, CCDC120c and CCDC68. [GOC:cilia, PMID:23213374, PMID:27818179, PMID:28422092]
Full description |

Standard name | GO_NEURON_PROJECTION_CYTOPLASM
Systematic name | M26032
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | All of the contents of a plasma membrane bounded neuron projection, excluding the plasma membrane surrounding the projection. [GOC:ha]
Full description |

Standard name | GO_SM_LIKE_PROTEIN_FAMILY_COMPLEX
Systematic name | M26033
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex containing members of the Like-Sm family of proteins, which includes both the Sm proteins and the Lsm proteins, and which generally form hexameric or heptameric ring structures which bind to RNA. While some of these ring complexes may form independently of RNA, many only form in association with their target RNA. In addition to Lsm-family proteins, many of these complexes contain additional protein members. Members of this family of complexes include the snRNPs which comprise the majority of the spliceosome. Others are involved in the 5' to 3' degradation pathways of mRNAs in the cytoplasm and of unspliced transcripts in the nucleus, as well as other diverse roles. [GOC:bhm, GOC:krc, PMID:19121818, PMID:27627834]
Full description |

Standard name | GO_LSM2_8_COMPLEX
Systematic name | M34361
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A heteroheptameric, nuclear protein complex composed of Lsm2, Lsm3, Lsm4, Lsm5, Lsm6, Lsm7, and Lsm8, or orthologs thereof, that selectively binds to snRNAs, in particular the U6 snRNA, and also to unspliced transcripts localized within the nucleus. [GOC:bhm, GOC:krc, PMID:19121818, PMID:23221597, PMID:27627834, PMID:28768202]
Full description |

Standard name | GO_KICSTOR_COMPLEX
Systematic name | M26035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that regulates the TORC1 signaling pathway in response to nutrients. The KICSTOR complex is composed of KPTN, ITFG2, C12orf66 and SZT2. [PMID:28199306]
Full description |

Standard name | GO_DISTAL_AXON
Systematic name | M26036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | That part of an axon close to and including the growth cone or the axon terminus. [GOC:aruk, GOC:bc, PMID:17202468]
Full description |

Standard name | GO_POSTSYNAPTIC_GOLGI_APPARATUS
Systematic name | M34362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The network of the Golgi apparatus structures located within the postsynapse. [GOC:aruk, GOC:bc, PMID:23838184]
Full description |

Standard name | GO_CATALYTIC_COMPLEX
Systematic name | M17467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of catalytic activity. [GOC:bhm, GOC:TermGenie, PMID:8077207]
Full description |

Standard name | GO_ENDORIBONUCLEASE_COMPLEX
Systematic name | M29442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of endoribonuclease activity. [GOC:bhm, GOC:TermGenie, PMID:18191223]
Full description |

Standard name | GO_H4_HISTONE_ACETYLTRANSFERASE_COMPLEX
Systematic name | M17054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of H4 histone acetyltransferase activity. [GOC:bhm, GOC:TermGenie, PMID:23775086]
Full description |

Standard name | GO_GABA_RECEPTOR_COMPLEX
Systematic name | M17014
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of GABA receptor activity. Upon binding of gamma-aminobutyric acid (GABA) it transmits the signal from one side of the membrane to the other to initiate a change in cell activity. Major inhibitory receptor in vertebrate brain. Also found in other vertebrate tissues, invertebrates and possibly in plants. Effective benzodiazepine receptor. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:18790874]
Full description |

Standard name | GO_PROTEIN_KINASE_COMPLEX
Systematic name | M17191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of protein kinase activity. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:24606918]
Full description |

Standard name | GO_PHOSPHATASE_COMPLEX
Systematic name | M29443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of phosphatase activity. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:24766807]
Full description |

Standard name | GO_CALCITONIN_FAMILY_RECEPTOR_COMPLEX
Systematic name | M26038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of calcitonin family receptor activity. Calcitonin family receptors may form dimers, trimers or tetramers; adrenomedullin and amylin receptors have only been observed as dimers so far. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:10871296, PMID:12037140, PMID:18687416]
Full description |

Standard name | GO_PEPTIDASE_INHIBITOR_COMPLEX
Systematic name | M26039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of peptidase inhibitor activity. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:20860624]
Full description |

Standard name | GO_AXON_CYTOPLASM
Systematic name | M17530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any cytoplasm that is part of a axon. [GO_REF:0000064, GOC:TermGenie, PMID:18667152]
Full description |

Standard name | GO_TERTIARY_GRANULE_LUMEN
Systematic name | M26040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any membrane-enclosed lumen that is part of a tertiary granule. [GO_REF:0000064, GOC:TermGenie, PMID:23650620]
Full description |

Standard name | GO_ATPASE_COMPLEX
Systematic name | M17442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of ATPase activity. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:9606181]
Full description |

Standard name | GO_ENDODEOXYRIBONUCLEASE_COMPLEX
Systematic name | M29444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of endodeoxyribonuclease activity. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:18413719]
Full description |

Standard name | GO_ENDONUCLEASE_COMPLEX
Systematic name | M26041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of endonuclease activity. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:18413719]
Full description |

Standard name | GO_EXORIBONUCLEASE_COMPLEX
Systematic name | M29445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of exoribonuclease activity. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:17174896]
Full description |

Standard name | GO_PEPTIDASE_COMPLEX
Systematic name | M26042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of peptidase activity. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:1689240]
Full description |

Standard name | GO_ENDOPEPTIDASE_COMPLEX
Systematic name | M26043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex which is capable of endopeptidase activity. [GO_REF:0000088, GOC:bhm, GOC:TermGenie, PMID:1689240]
Full description |

Standard name | GO_MITOTIC_SPINDLE_MIDZONE
Systematic name | M26044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The area in the center of the anaphase spindle consisting of microtubules, microtubule bundling factors and kinesin motors where the spindle microtubules from opposite poles overlap in an antiparallel manner. [GOC:mtg_cell_cycle, GOC:vw]
Full description |

Standard name | GO_PERICILIARY_MEMBRANE_COMPARTMENT
Systematic name | M26045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A plasma membrane region adjacent to the base of eukaryotic cilia and flagella that is enriched in endocytosis-associated proteins and vesicles and that appears to regulate ciliary membrane homeostasis. [GOC:cilia, GOC:dr, GOC:krc, PMID:22342749]
Full description |

Standard name | GO_SPERMATOPROTEASOME_COMPLEX
Systematic name | M26046
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A proteasome specifically found in mammalian testis. Contains the proteasome activator PA200 in the regulatory particle, and beta1i, beta2i, beta5i and/or alpha4s in the core (20S) subunit. Beta1i, beta2i and beta5i are inducible catalytic subunits, closely related to beta1, beta2 and beta5. Alpha4s is a sperm-specific 20S subunit, but unlike other alternative 20S subunits alpha4s lies in the outer alpha-ring and lacks catalytic activity. [GOC:sp, PMID:23706739]
Full description |

Standard name | GO_MESSENGER_RIBONUCLEOPROTEIN_COMPLEX
Systematic name | M26047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A ribonucleoprotein complex containing both protein and messenger RNA (mRNA) molecules. [GOC:bf, PMID:15574591, PMID:21915786]
Full description |

Standard name | GO_GATOR1_COMPLEX
Systematic name | M26048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex involved in regulation of non-nitrogen-starvation (NNS) autophagic process. In S. cerevisiae this complex contains Iml1p, Npr2p and Npr3p proteins. In humans the GATOR1 complex consists of DEPDC5, Nprl2, Nprl3. [GOC:rb, PMID:21900499, PMID:23723238, PMID:23974112, PMID:28199306]
Full description |

Standard name | GO_OXIDOREDUCTASE_COMPLEX
Systematic name | M17048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any protein complex that possesses oxidoreductase activity. [GOC:bhm, PMID:18982432]
Full description |

Standard name | GO_TRANSFERASE_COMPLEX
Systematic name | M17155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex capable of catalyzing the transfer of a group, e.g. a methyl group, glycosyl group, acyl group, phosphorus-containing, or other groups, from one compound (generally regarded as the donor) to another compound (generally regarded as the acceptor). [GOC:bhm, PMID:16540464]
Full description |

Standard name | GO_UNIPLEX_COMPLEX
Systematic name | M26049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A calcium channel complex in the mitochondrial inner membrane capable of highly-selective calcium channel activity. Its components include the EF-hand-containing proteins mitochondrial calcium uptake 1 (MICU1) and MICU2, the pore-forming subunit mitochondrial calcium uniporter (MCU) and its paralog MCUb, and the MCU regulator EMRE. [PMID:24231807]
Full description |

Standard name | GO_ATG1_ULK1_KINASE_COMPLEX
Systematic name | M26050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex consisting of Atg1 (or Atg1 homologs e.g. ULK1, ULK2 in mammals) and Atg13 along with other proteins that regulate its function (e.g. Atg17 in yeast or RB1CC1(FIP200) in mammals). This complex has serine/threonine protein kinase activity and is involved in autophagosome formation. [GOC:bhm, GOC:DOS, GOC:rb, PMID:15743910, PMID:19211835, PMID:19258318, PMID:19597335, PMID:22885598]
Full description |

Standard name | GO_TRANSPORTER_COMPLEX
Systematic name | M17513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex facilitating transport of molecules (proteins, small molecules, nucleic acids) into, out of or within a cell, or between cells. [GOC:bhm, PMID:15449578]
Full description |

Standard name | GO_DNA_REPAIR_COMPLEX
Systematic name | M17380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex involved in DNA repair processes including direct reversal, base excision repair, nucleotide excision repair, photoreactivation, bypass, double-strand break repair pathway, and mismatch repair pathway. [GOC:bhm, PMID:17217467, PMID:20551348, PMID:22749910, PMID:24192350]
Full description |

Standard name | GO_3M_COMPLEX
Systematic name | M26051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex, at least composed of CUL7, CCDC8 and OBSL1, that is required for maintaining microtubule and genome integrity. [PMID:24793695, PMID:24793696]
Full description |

Standard name | GO_L_TYPE_VOLTAGE_GATED_CALCIUM_CHANNEL_COMPLEX
Systematic name | M26052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A type of voltage-dependent calcium channel responsible for excitation-contraction coupling of skeletal, smooth, and cardiac muscle. 'L' stands for 'long-lasting' referring to the length of activation. [GOC:ame, PMID:12946355]
Full description |

Standard name | GO_PROXIMAL_DENDRITE
Systematic name | M29446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The dendrite of the dendritic tree that is closest to the neuronal cell body (the soma). [GOC:aruk, GOC:bc, PMID:16899232]
Full description |

Standard name | GO_HFE_TRANSFERRIN_RECEPTOR_COMPLEX
Systematic name | M26053
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex containing at least HFE and a transferrin receptor (either TFR1/TFRC or TFR2), proposed to play a role in the sensing of transferrin-bound Fe (Fe2-Tf) on the plasma membrane to regulate hepcidin transcription. [GOC:BHF, GOC:kom, PMID:25147378]
Full description |

Standard name | GO_LSM1_7_PAT1_COMPLEX
Systematic name | M26054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A conserved, heteroheptameric, cytoplasmic protein complex composed of Lsm1, Lsm2, Lsm3, Lsm4, Lsm5, Lsm6, Lsm7, and Pat1, or orthologs thereof, that shows a strong binding preference for oligoadenylated RNAs over polyadenylated RNAs. May bind further associated proteins. Facilitates the deadenylation-dependent decapping of mRNA in the P-body thereby regulating mRNA decay and subsequent degradation by the 5' to 3' pathway. [GOC:bhm, GOC:krc, PMID:19121818, PMID:23620288, PMID:24139796, PMID:27627834, PMID:28768202]
Full description |

Standard name | GO_MICROVESICLE
Systematic name | M26055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | An extracellular vesicle released from the plasma membrane and ranging in size from about 100 nm to 1000 nm. [GOC:vesicles, PMID:22418571, PMID:24009894, Wikipedia:Microvesicles]
Full description |

Standard name | GO_EARP_COMPLEX
Systematic name | M26056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A quatrefoil tethering complex required for endocytic recycling. [PMID:25799061]
Full description |

Standard name | GO_MICROTUBULE_END
Systematic name | M17598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | Any end of a microtubule. Microtubule ends differ in that the so-called microtubule plus-end is the one that preferentially grows by polymerization, with respect to the minus-end. [GOC:pr]
Full description |

Standard name | GO_RIBONUCLEOPROTEIN_COMPLEX
Systematic name | M17739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A macromolecular complex containing both protein and RNA molecules. [GOC:vesicles]
Full description |

Standard name | GO_BETA_CATENIN_TCF_COMPLEX
Systematic name | M26057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A protein complex that contains beta-catenin and a member of the T-cell factor (TCF)/lymphoid enhancer binding factor (LEF) family of transcription factors. [GOC:bf, GOC:PARL, PMID:11751639, PMID:16936075, PMID:20123964, PMID:21075118, PMID:9419974]
Full description |

Standard name | GO_WNT_SIGNALOSOME
Systematic name | M17654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | A multiprotein protein complex containing membrane-localized Wnt receptors and cytosolic protein complexes, which is capable of transmitting the Wnt signal. Contains at least a Wnt protein, LRP5 or LRP6, a member of the Frizzled (Fz) family, Axin and and a Dishevelled (DVL) protein. [GOC:bf, GOC:PARL, PMID:22899650, PMID:25336320]
Full description |

Standard name | GO_SPERM_HEAD_PLASMA_MEMBRANE
Systematic name | M34363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:CC
Brief description | The plasma membrane that is part of the head section of a sperm cell. [PMID:24478030]
Full description |

Standard name | GO_SINGLE_STRANDED_DNA_ENDODEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M26058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within a single-stranded deoxyribonucleic acid molecule by creating internal breaks. [GOC:mah]
Full description |

Standard name | GO_MANNOSYLTRANSFERASE_ACTIVITY
Systematic name | M18522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a mannosyl group to an acceptor molecule, typically another carbohydrate or a lipid. [GOC:ai, GOC:cjm]
Full description |

Standard name | GO_PEPTIDYLTRANSFERASE_ACTIVITY
Systematic name | M26059
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: peptidyl-tRNA(1) + aminoacyl-tRNA(2) = tRNA(1) + peptidylaminoacyl-tRNA(2). [EC:2.3.2.12, PMID:11433365, PMID:9242921]
Full description |

Standard name | GO_TRNA_BINDING
Systematic name | M18164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with transfer RNA. [GOC:ai]
Full description |

Standard name | GO_L_ORNITHINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of L-ornithine from one side of a membrane to the other. L-ornithine is 2,5-diaminopentanoic acid. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_SULFUR_AMINO_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of sulfur amino acids from one side of a membrane to the other. Sulphur amino acids contain sulfur in the form of cystine, methionine or their derivatives. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_SUCCINATE_DEHYDROGENASE_ACTIVITY
Systematic name | M26062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: succinate + acceptor = fumarate + reduced acceptor. [GOC:kd]
Full description |

Standard name | GO_MICROFILAMENT_MOTOR_ACTIVITY
Systematic name | M18569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of movement along a microfilament, coupled to the hydrolysis of a nucleoside triphosphate (usually ATP). [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_SNARE_BINDING
Systematic name | M18857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a SNARE (soluble N-ethylmaleimide-sensitive factor attached protein receptor) protein. [PMID:12642621]
Full description |

Standard name | GO_RDNA_BINDING
Systematic name | M26063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with DNA sequences encoding ribosomal RNA. [GOC:mah]
Full description |

Standard name | GO_DNA_SECONDARY_STRUCTURE_BINDING
Systematic name | M17955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with DNA containing secondary structure elements such as four-way junctions, bubbles, loops, Y-form DNA, or double-strand/single-strand junctions. [GOC:krc]
Full description |

Standard name | GO_3_KETO_STEROL_REDUCTASE_ACTIVITY
Systematic name | M26064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a 3-beta-hydroxyl sterol + NADP+ = a 3-keto sterol + NADPH + H(+). [EC:1.1.1.270, GOC:mah, MetaCyc:1.1.1.270-RXN, MetaCyc:RXN3O-4110, MetaCyc:RXN66-19, MetaCyc:RXN66-24, MetaCyc:RXN66-314, MetaCyc:RXN66-319, PMID:9811880]
Full description |

Standard name | GO_PEROXISOME_TARGETING_SEQUENCE_BINDING
Systematic name | M26065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a peroxisomal targeting sequence, any of several sequences of amino acids within a protein that can act as a signal for the localization of the protein into the peroxisome. [GOC:mah, ISBN:0879693568]
Full description |

Standard name | GO_MAGNESIUM_ION_BINDING
Systematic name | M17953
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with magnesium (Mg) ions. [GOC:ai]
Full description |

Standard name | GO_ENDOPOLYPHOSPHATASE_ACTIVITY
Systematic name | M34364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: polyphosphate + n H2O = (n+1) oligophosphate. The product contains 4 or 5 phosphate residues. [EC:3.6.1.10]
Full description |

Standard name | GO_RNA_CAP_BINDING
Systematic name | M18244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a 7-methylguanosine (m7G) group or derivative located at the 5' end of an RNA molecule. [GOC:krc]
Full description |

Standard name | GO_RNA_7_METHYLGUANOSINE_CAP_BINDING
Systematic name | M26066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the 7-methylguanosine group added cotranscriptionally to the 5' end of RNA molecules transcribed by polymerase II. [GOC:krc]
Full description |

Standard name | GO_FOUR_WAY_JUNCTION_DNA_BINDING
Systematic name | M18636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with DNA containing four-way junctions, also known as Holliday junctions, a structure where two DNA double strands are held together by reciprocal exchange of two of the four strands, one strand each from the two original helices. [GOC:krc, ISBN:0815332181, PMID:15563464]
Full description |

Standard name | GO_Y_FORM_DNA_BINDING
Systematic name | M26067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with segment of DNA shaped like a Y. This shape occurs when DNA contains a region of paired double-stranded DNA on one end and a region of unpaired DNA strands on the opposite end. [GOC:elh, PMID:16781730]
Full description |

Standard name | GO_BUBBLE_DNA_BINDING
Systematic name | M26068
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with DNA that contains a bubble. A bubble occurs when DNA contains a region of unpaired, single-stranded DNA flanked on both sides by regions of paired, double-stranded DNA. [GOC:elh, GOC:vw, PMID:16781730]
Full description |

Standard name | GO_ADENYL_NUCLEOTIDE_EXCHANGE_FACTOR_ACTIVITY
Systematic name | M26070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stimulates the hydrolysis and exchange of adenyl nucleotides by other proteins. [GOC:kd]
Full description |

Standard name | GO_INOSITOL_HEXAKISPHOSPHATE_KINASE_ACTIVITY
Systematic name | M26071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + 1D-myo-inositol 1,2,3,4,5,6-hexakisphosphate = ADP + diphospho-1D-myo-inositol-pentakisphosphate. The isomeric configuration of diphospho-1D-myo-inositol-pentakisphosphate (PP-IP5) is unknown. [GOC:elh, GOC:vw, PMID:16429326]
Full description |

Standard name | GO_INOSITOL_HEXAKISPHOSPHATE_5_KINASE_ACTIVITY
Systematic name | M34365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + 1D-myo-inositol 1,2,3,4,5,6-hexakisphosphate = ADP + 5-diphospho-1D-myo-inositol (1,2,3,4,6)pentakisphosphate. [MetaCyc:2.7.1.152-RXN]
Full description |

Standard name | GO_TRANSLATION_REPRESSOR_ACTIVITY_MRNA_REGULATORY_ELEMENT_BINDING
Systematic name | M26072
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Antagonizes the ribosome-mediated translation of mRNA into a polypeptide via direct binding (through a selective and non-covalent interaction) to nucleic acid. [GOC:clt, GOC:vw, PMID:29061112, PMID:7523370]
Full description |

Standard name | GO_RNA_POLYMERASE_II_CORE_PROMOTER_SEQUENCE_SPECIFIC_DNA_BINDING
Systematic name | M18499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a DNA sequence that is part of the core promoter of a RNA polymerase II-transcribed gene. [GOC:pg, GOC:txnOH, PMID:12381658]
Full description |

Standard name | GO_CIS_REGULATORY_REGION_SEQUENCE_SPECIFIC_DNA_BINDING
Systematic name | M34366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a specific upstream regulatory DNA sequence (transcription factor recognition sequence or binding site) located in cis relative to the transcription start site (i.e., on the same strand of DNA) of a gene transcribed by some RNA polymerase. The proximal promoter is in cis with and relatively close to the core promoter. [GOC:txnOH-2018]
Full description |

Standard name | GO_RNA_POLYMERASE_III_GENERAL_TRANSCRIPTION_INITIATION_FACTOR_ACTIVITY
Systematic name | M26074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | An activity that contributes to transcription start site selection and transcription initiation of genes transcribed by RNA polymerase III. Factors required for RNA polymerase III transcription initiation include TFIIIA, TFIIIB and TFIIIC. [GOC:txnOH-2018, PMID:12381659, Wikipedia:RNA_polymerase_III]
Full description |

Standard name | GO_RNA_POLYMERASE_III_TRANSCRIPTION_REGULATORY_REGION_SEQUENCE_SPECIFIC_DNA_BINDING
Systematic name | M26076
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a DNA region that controls the transcription of a gene by RNA polymerase III. Binding may occur as a sequence specific interaction or as an interaction observed only once a factor has been recruited to the DNA by other factors. [GOC:txnOH, GOC:vw, PMID:12381659]
Full description |

Standard name | GO_RNA_POLYMERASE_I_CORE_BINDING
Systematic name | M26079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with RNA polymerase I core enzyme, a multisubunit eukaryotic nuclear RNA polymerase typically composed of seventeen subunits. [GOC:txnOH]
Full description |

Standard name | GO_CORE_PROMOTER_SEQUENCE_SPECIFIC_DNA_BINDING
Systematic name | M19190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a sequence of DNA that is part of a core promoter region. The core promoter is composed of the transcription start site and binding sites for the RNA polymerase and the basal transcription machinery. The transcribed region might be described as a gene, cistron, or operon. [GOC:pg, GOC:txnOH]
Full description |

Standard name | GO_REGULATORY_REGION_NUCLEIC_ACID_BINDING
Systematic name | M18115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a nucleic acid region that regulates a nucleic acid-based process. Such processes include transcription, DNA replication, and DNA repair. [GOC:txnOH]
Full description |

Standard name | GO_RNA_POLYMERASE_II_TRANSCRIPTION_FACTOR_BINDING
Systematic name | M19139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an RNA polymerase II transcription factor, any protein required to initiate or regulate transcription by RNA polymerase II. [GOC:txnOH]
Full description |

Standard name | GO_RNA_POLYMERASE_II_GENERAL_TRANSCRIPTION_INITIATION_FACTOR_BINDING
Systematic name | M26083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a basal RNA polymerase II transcription factor, any of the factors involved in formation of the preinitiation complex (PIC) by RNA polymerase II and defined as a basal or general transcription factor. [GOC:txnOH, PMID:16858867]
Full description |

Standard name | GO_TFIID_CLASS_TRANSCRIPTION_FACTOR_COMPLEX_BINDING
Systematic name | M26084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a general RNA polymerase II transcription factor belonging to the TFIID complex, one of the factors involved in formation of the preinitiation complex (PIC) by RNA polymerase II. [GOC:krc, PMID:16858867]
Full description |

Standard name | GO_BASAL_TRANSCRIPTION_MACHINERY_BINDING
Systematic name | M18809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the basal transcription machinery which is composed of the RNA polymerase core enzyme and the basal transcription factor(s), the minimal set of factors required for formation of the preinitiation complex (PIC) by the RNA polymerase. [GOC:txnOH]
Full description |

Standard name | GO_RNA_POLYMERASE_II_ACTIVATING_TRANSCRIPTION_FACTOR_BINDING
Systematic name | M18891
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an RNA polymerase II transcription activating factor, a protein involved in positive regulation of transcription. [GOC:txnOH]
Full description |

Standard name | GO_RNA_POLYMERASE_II_REPRESSING_TRANSCRIPTION_FACTOR_BINDING
Systematic name | M18294
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an RNA polymerase II transcription repressing factor, a protein involved in negative regulation of transcription. [GOC:txnOH]
Full description |

Standard name | GO_INTRONIC_TRANSCRIPTION_REGULATORY_REGION_SEQUENCE_SPECIFIC_DNA_BINDING
Systematic name | M34367
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an intronic DNA sequence that regulates the transcription of the transcript it is contained within. [GOC:txnOH]
Full description |

Standard name | GO_RNA_POLYMERASE_II_INTRONIC_TRANSCRIPTION_REGULATORY_REGION_SEQUENCE_SPECIFIC_DNA_BINDING
Systematic name | M26086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an RNA polymerase II intronic DNA sequence that regulates the transcription of the transcript it is contained within. [GOC:txnOH]
Full description |

Standard name | GO_RNA_POLYMERASE_I_TRANSCRIPTION_REGULATORY_REGION_SEQUENCE_SPECIFIC_DNA_BINDING
Systematic name | M34368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a specific sequence of DNA that is part of a regulatory region that controls the transcription of a gene or cistron by RNA polymerase I. [GOC:txnOH]
Full description |

Standard name | GO_RNA_POLYMERASE_I_GENERAL_TRANSCRIPTION_INITIATION_FACTOR_ACTIVITY
Systematic name | M34369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | An activity that contributes to transcription start site selection and transcription initiation of genes transcribed by RNA polymerase I. Factors required for RNA polymerase I transcription initiation include upstream activation factor (UAF), core factor (CF), TATA binding protein (TBP) and RRN3. [GOC:txnOH-2018, PMID:11500378, PMID:28340337, PMID:28842442]
Full description |

Standard name | GO_DNA_BINDING_TRANSCRIPTION_ACTIVATOR_ACTIVITY
Systematic name | M26087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a specific double-stranded genomic DNA sequence in order to activate or increase the frequency, rate or extent of transcription by a RNA polymerase. [GOC:txnOH-2018]
Full description |

Standard name | GO_DNA_BINDING_TRANSCRIPTION_REPRESSOR_ACTIVITY
Systematic name | M29448
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a specific double-stranded genomic DNA sequence in order to stop, prevent, or reduce the frequency, rate or extent of transcription by a RNA polymerase. [GOC:txnOH-2018]
Full description |

Standard name | GO_TRANSCRIPTION_COFACTOR_BINDING
Systematic name | M18371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a transcription cofactor, any protein involved in regulation of transcription via protein-protein interactions with transcription factors and other transcription regulatory proteins. Cofactors do not bind DNA directly, but rather mediate protein-protein interactions between regulatory transcription factors and the basal transcription machinery. [GOC:krc]
Full description |

Standard name | GO_TRANSCRIPTION_COREPRESSOR_BINDING
Systematic name | M26088
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a transcription corepressor, any protein involved in negative regulation of transcription via protein-protein interactions with transcription factors and other proteins that negatively regulate transcription. Transcription corepressors do not bind DNA directly, but rather mediate protein-protein interactions between repressing transcription factors and the basal transcription machinery. [GOC:krc]
Full description |

Standard name | GO_TRANSCRIPTION_COACTIVATOR_BINDING
Systematic name | M18770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a transcription coactivator, any protein involved in positive regulation of transcription via protein-protein interactions with transcription factors and other proteins that positively regulate transcription. Transcription coactivators do not bind DNA directly, but rather mediate protein-protein interactions between activating transcription factors and the basal transcription machinery. [GOC:krc]
Full description |

Standard name | GO_RNA_POLYMERASE_II_TRANSCRIPTION_COFACTOR_BINDING
Systematic name | M34370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a transcription cofactor for RNA polymerase II, any protein involved in regulation of transcription via protein-protein interactions with RNA polymerase II transcription factors and other transcription regulatory proteins. Cofactors do not bind DNA directly, but rather mediate protein-protein interactions between regulatory transcription factors and the basal transcription machinery of RNA polymerase II. [GOC:krc]
Full description |

Standard name | GO_RNA_POLYMERASE_II_TRANSCRIPTION_COACTIVATOR_BINDING
Systematic name | M34371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an RNA polymerase II transcription coactivator, any protein involved in positive regulation of transcription of RNA polymerase II via protein-protein interactions with transcription factors and other proteins that positively regulate transcription. Transcription coactivators do not bind DNA directly, but rather mediate protein-protein interactions between activating transcription factors and the basal transcription machinery of RNA polymerase II. [GOC:krc]
Full description |

Standard name | GO_N_ACETYLGLUCOSAMINE_6_O_SULFOTRANSFERASE_ACTIVITY
Systematic name | M26090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 3'-phosphoadenosine 5'-phosphosulfate + N-acetyl-D-glucosamine = adenosine 3',5'-bisphosphate + N-acetyl-D-glucosamine 6-sulfate. [GOC:ai, GOC:hjd]
Full description |

Standard name | GO_LIPOPOLYSACCHARIDE_BINDING
Systematic name | M18548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with lipopolysaccharide. [PMID:11079463]
Full description |

Standard name | GO_N_ACETYLGALACTOSAMINE_4_O_SULFOTRANSFERASE_ACTIVITY
Systematic name | M26091
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 3'-phosphoadenosine 5'-phosphosulfate + N-acetyl-D-galactosamine = adenosine 3',5'-bisphosphate + N-acetyl-D-galactosamine 4-sulfate. [EC:2.8.2.-, GOC:ai]
Full description |

Standard name | GO_AMYLOID_BETA_BINDING
Systematic name | M26092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with amyloid-beta peptide/protein and/or its precursor. [GOC:hjd]
Full description |

Standard name | GO_TRACE_AMINE_RECEPTOR_ACTIVITY
Systematic name | M26094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a trace amine to initiate a change in cell activity. Trace amines are biogenic amines that are synthesized from aromatic amino acids and are substrates for monoamine oxidase, and are therefore detectable only at trace levels in mammals. [GOC:mah, PMID:19325074]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_ADENOSINE_RECEPTOR_ACTIVITY
Systematic name | M26096
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with adenosine and transmitting the signal across the membrane by activating an associated G-protein; promotes the exchange of GDP for GTP on the alpha subunit of a heterotrimeric G-protein complex. [GOC:bf, GOC:mah, PMID:9755289]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_CHEMOATTRACTANT_RECEPTOR_ACTIVITY
Systematic name | M19026
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a chemoattractant and transmitting the signal across the membrane by activating an associated G-protein; promotes the exchange of GDP for GTP on the alpha subunit of a heterotrimeric G-protein complex. [GOC:bf, GOC:mah]
Full description |

Standard name | GO_PEPTIDE_RECEPTOR_ACTIVITY
Systematic name | M14461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an extracellular or intracellular peptide to initiate a change in cell activity. [GOC:jl]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_RECEPTOR_BINDING
Systematic name | M14760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a G protein-coupled receptor. [GOC:ceb, GOC:dph]
Full description |

Standard name | GO_ALPHA_N_ACETYLGALACTOSAMINIDE_ALPHA_2_6_SIALYLTRANSFERASE_ACTIVITY
Systematic name | M26097
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: CMP-N-acetylneuraminate + glycano-(1->3)-(N-acetyl-alpha-D-galactosaminyl)-glycoprotein = CMP + glycano-[(2->6)-alpha-N-acetylneuraminyl]-(N-acetyl-D-galactosaminyl)-glycoprotein. [EC:2.4.99.3]
Full description |

Standard name | GO_ATPASE_ACTIVATOR_ACTIVITY
Systematic name | M18050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and increases the ATP hydrolysis activity of an ATPase. [GOC:ajp]
Full description |

Standard name | GO_LIPID_KINASE_ACTIVITY
Systematic name | M1826
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the phosphorylation of a simple or complex lipid. [GOC:hjd]
Full description |

Standard name | GO_RETINAL_DEHYDROGENASE_ACTIVITY
Systematic name | M26099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: retinal + NAD+ + H2O = retinoate + NADH. Acts on both 11-trans and 13-cis forms of retinal. [EC:1.2.1.36]
Full description |

Standard name | GO_PHOSPHOTYROSINE_RESIDUE_BINDING
Systematic name | M26100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a phosphorylated tyrosine residue within a protein. [PMID:14636584]
Full description |

Standard name | GO_PHOSPHATIDYLSERINE_BINDING
Systematic name | M18494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylserine, a class of glycophospholipids in which a phosphatidyl group is esterified to the hydroxyl group of L-serine. [ISBN:0198506732, PMID:12000961]
Full description |

Standard name | GO_OPSONIN_BINDING
Systematic name | M19126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an opsonin, such as a complement component or antibody, deposited on the surface of a bacteria, virus, immune complex, or other particulate material. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_COMPLEMENT_BINDING
Systematic name | M17970
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any component or product of the complement cascade. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_COMPLEMENT_COMPONENT_C1Q_COMPLEX_BINDING
Systematic name | M26101
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the C1q complex, a component of the classical complement cascade. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_COMPLEMENT_COMPONENT_C3B_BINDING
Systematic name | M26102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the C3b product of the complement cascade. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_LIPOPOLYSACCHARIDE_IMMUNE_RECEPTOR_ACTIVITY
Systematic name | M26103
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a lipopolysaccharide and transmitting the signal across the cell membrane to initiate an innate immune response. Lipopolysaccharides (LPS) are major components of the outer membrane of Gram-negative bacteria, making them prime targets for recognition by the immune system. [PMID:14609719, PMID:15379975]
Full description |

Standard name | GO_G_PROTEIN_ALPHA_SUBUNIT_BINDING
Systematic name | M17901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a G-protein alpha subunit. The alpha subunit binds a guanine nucleotide. [GOC:hjd]
Full description |

Standard name | GO_FIBRONECTIN_BINDING
Systematic name | M18468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a fibronectin, a group of related adhesive glycoproteins of high molecular weight found on the surface of animal cells, connective tissue matrices, and in extracellular fluids. [GOC:hjd]
Full description |

Standard name | GO_RETINOIC_ACID_BINDING
Systematic name | M18010
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with retinoic acid, 3,7-dimethyl-9-(2,6,-trimethyl-1-cyclohexen-1-yl)-2,4,6,8-nonatetraenoic acid. [GOC:hjd]
Full description |

Standard name | GO_PROTEASE_BINDING
Systematic name | M18192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any protease or peptidase. [GOC:hjd]
Full description |

Standard name | GO_P53_BINDING
Systematic name | M19005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with one of the p53 family of proteins. [GOC:hjd]
Full description |

Standard name | GO_NUCLEOBASE_BINDING
Systematic name | M26104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a nucleobase, any of a class of pyrmidines or purines, organic nitrogenous bases. [GOC:hjd]
Full description |

Standard name | GO_G_QUADRUPLEX_RNA_BINDING
Systematic name | M26105
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with G-quadruplex RNA structures, in which groups of four guanines adopt a flat, cyclic hydrogen-bonding arrangement known as a guanine tetrad. [PMID:18294969, PMID:18568163, PMID:19330720]
Full description |

Standard name | GO_AMINOACYL_TRNA_EDITING_ACTIVITY
Systematic name | M18300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The hydrolysis of an incorrectly aminoacylated tRNA. [GOC:hjd, PMID:14663147, PMID:16087889]
Full description |

Standard name | GO_DYSTROGLYCAN_BINDING
Systematic name | M26106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with dystroglycan. Dystroglycan is glycoprotein found in non-muscle tissues as well as in muscle tissues, often in association with dystrophin. The native dystroglycan cleaved into two non-covalently associated subunits, alpha (N-terminal) and beta (C-terminal). [GOC:hjd]
Full description |

Standard name | GO_DNA_HELICASE_ACTIVITY
Systematic name | M19136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate; this reaction drives the unwinding of the DNA helix. [EC:3.6.4.12, GOC:jl]
Full description |

Standard name | GO_MINOR_GROOVE_OF_ADENINE_THYMINE_RICH_DNA_BINDING
Systematic name | M26107
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the structure formed by the minor groove of adenine-thymine-rich DNA regions. Examples of proteins having this function are AT-rich interaction domain (ARID)-containing proteins. [GOC:jl, PMID:10545119, PMID:15802641, PMID:26223912, PMID:2670564]
Full description |

Standard name | GO_CHROMATIN_BINDING
Systematic name | M17106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with chromatin, the network of fibers of DNA, protein, and sometimes RNA, that make up the chromosomes of the eukaryotic nucleus during interphase. [GOC:jl, ISBN:0198506732, PMID:20404130]
Full description |

Standard name | GO_DAMAGED_DNA_BINDING
Systematic name | M968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with damaged DNA. [GOC:jl]
Full description |

Standard name | GO_DNA_REPLICATION_ORIGIN_BINDING
Systematic name | M26108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the DNA replication origin, a unique DNA sequence of a replicon at which DNA replication is initiated and proceeds bidirectionally or unidirectionally. [GOC:curators]
Full description |

Standard name | GO_DNA_CLAMP_LOADER_ACTIVITY
Systematic name | M26109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate, to drive the opening of the ring structure of the PCNA complex, or any of the related sliding clamp complexes, and their closing around the DNA duplex. [GOC:mah, GOC:vw, PMID:16082778]
Full description |

Standard name | GO_DOUBLE_STRANDED_TELOMERIC_DNA_BINDING
Systematic name | M26110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with double-stranded telomere-associated DNA. [GOC:jl, ISBN:0321000382]
Full description |

Standard name | GO_SINGLE_STRANDED_DNA_BINDING
Systematic name | M16628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with single-stranded DNA. [GOC:elh, GOC:vw, PMID:22976174]
Full description |

Standard name | GO_DNA_BINDING_TRANSCRIPTION_FACTOR_ACTIVITY
Systematic name | M26112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a specific double-stranded genomic DNA sequence (sometimes referred to as a motif) within the regulatory region of a gene to modulate transcription. Regulatory regions include promoters (proximal and distal) and enhancers. Genes are transcriptional units, and include bacterial operons. [GOC:txnOH-2018]
Full description |

Standard name | GO_STEROID_HORMONE_RECEPTOR_ACTIVITY
Systematic name | M18238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a steroid hormone and transmitting the signal within the cell to initiate a change in cell activity or function. [GOC:signaling, PMID:14708019]
Full description |

Standard name | GO_TRANSCRIPTION_COREGULATOR_ACTIVITY
Systematic name | M26113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A protein or a member of a complex that interacts specifically and non-covalently with a DNA-bound DNA-binding transcription factor to either activate or repress the transcription of specific genes. Coregulators often act by altering chromatin structure and modifications. For example, one class of transcription coregulators modifies chromatin structure through covalent modification of histones. A second ATP-dependent class modifies the conformation of chromatin. A third class modulates interactions of DNA-binding transcription factor with other transcription coregulators. [GOC:txnOH-2018, PMID:10213677, PMID:16858867, PMID:24203923, PMID:25957681, Wikipedia:Transcription_coregulator]
Full description |

Standard name | GO_TRANSCRIPTION_COACTIVATOR_ACTIVITY
Systematic name | M19071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A protein or a member of a complex that interacts specifically and non-covalently with a DNA-bound DNA-binding transcription factor to activate the transcription of specific genes. Coactivators often act by altering chromatin structure and modifications. For example, one class of transcription coregulators modifies chromatin structure through covalent modification of histones. A second ATP-dependent class modifies the conformation of chromatin. Another type of coregulator activity is the bridging of a DNA-binding transcription factor to the basal transcription machinery. The Mediator complex, which bridges transcription factors and RNA polymerase, is also a transcription coactivator. [GOC:txnOH-2018, PMID:10213677, PMID:16858867]
Full description |

Standard name | GO_TRANSCRIPTION_COREPRESSOR_ACTIVITY
Systematic name | M19029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A protein or a member of a complex that interacts specifically and non-covalently with a DNA-bound DNA-binding transcription factor to repress the transcription of specific genes. Corepressors often act by altering chromatin structure and modifications. For example, one class of transcription coregulators modifies chromatin structure through covalent modification of histones. A second ATP-dependent class modifies the conformation of chromatin. A third class occludes DNA-binding transcription factor protein-protein interaction domains. A fourth class of corepressors prevents interactions of DNA bound DNA-binding transcription factor with coactivators. [GOC:txnOH-2018, PMID:10213677, PMID:16858867]
Full description |

Standard name | GO_TELOMERASE_ACTIVITY
Systematic name | M26114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: deoxynucleoside triphosphate + DNA(n) = diphosphate + DNA(n+1). Catalyzes extension of the 3'- end of a DNA strand by one deoxynucleotide at a time using an internal RNA template that encodes the telomeric repeat sequence. [GOC:krc, PMID:28732250]
Full description |

Standard name | GO_RNA_BINDING
Systematic name | M19517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an RNA molecule or a portion thereof. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_RNA_HELICASE_ACTIVITY
Systematic name | M18722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate; this reaction drives the unwinding of an RNA helix. [EC:3.6.4.13, GOC:jl]
Full description |

Standard name | GO_DOUBLE_STRANDED_RNA_BINDING
Systematic name | M8891
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with double-stranded RNA. [GOC:jl]
Full description |

Standard name | GO_DOUBLE_STRANDED_RNA_ADENOSINE_DEAMINASE_ACTIVITY
Systematic name | M26115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: adenosine + H2O = inosine + NH3, in a double-stranded RNA molecule. [GOC:mah]
Full description |

Standard name | GO_SINGLE_STRANDED_RNA_BINDING
Systematic name | M18205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with single-stranded RNA. [GOC:jl]
Full description |

Standard name | GO_MRNA_BINDING
Systematic name | M18154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with messenger RNA (mRNA), an intermediate molecule between DNA and protein. mRNA includes UTR and coding sequences, but does not contain introns. [GOC:kmv, GOC:pr, SO:0000234]
Full description |

Standard name | GO_MRNA_3_UTR_BINDING
Systematic name | M19212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the 3' untranslated region of an mRNA molecule. [GOC:mah]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_RIBOSOME
Systematic name | M13114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of the ribosome. [GOC:mah]
Full description |

Standard name | GO_TRANSLATION_INITIATION_FACTOR_ACTIVITY
Systematic name | M11538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Functions in the initiation of ribosome-mediated translation of mRNA into a polypeptide. [ISBN:0198506732]
Full description |

Standard name | GO_TRANSLATION_ELONGATION_FACTOR_ACTIVITY
Systematic name | M18250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Functions in chain elongation during polypeptide synthesis at the ribosome. [ISBN:0198506732]
Full description |

Standard name | GO_PROTEIN_DISULFIDE_ISOMERASE_ACTIVITY
Systematic name | M26116
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the rearrangement of both intrachain and interchain disulfide bonds in proteins. [EC:5.3.4.1, GOC:vw, Wikipedia:Protein_disulfide-isomerase#Function]
Full description |

Standard name | GO_MOTOR_ACTIVITY
Systematic name | M13226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the generation of force resulting either in movement along a microfilament or microtubule, or in torque resulting in membrane scission, coupled to the hydrolysis of a nucleoside triphosphate. [GOC:mah, GOC:vw, ISBN:0815316194, PMID:11242086]
Full description |

Standard name | GO_MICROTUBULE_MOTOR_ACTIVITY
Systematic name | M18964
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of movement along a microtubule, coupled to the hydrolysis of a nucleoside triphosphate (usually ATP). [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_ACTIN_BINDING
Systematic name | M14799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with monomeric or multimeric forms of actin, including actin filaments. [GOC:clt]
Full description |

Standard name | GO_ACTIN_MONOMER_BINDING
Systematic name | M18950
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with monomeric actin, also known as G-actin. [GOC:ai]
Full description |

Standard name | GO_LYSOZYME_ACTIVITY
Systematic name | M18340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of the beta-(1->4) linkages between N-acetylmuramic acid and N-acetyl-D-glucosamine residues in a peptidoglycan. [EC:3.2.1.17, PMID:22748813]
Full description |

Standard name | GO_PROTEIN_GLUTAMINE_GAMMA_GLUTAMYLTRANSFERASE_ACTIVITY
Systematic name | M26117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: protein glutamine + alkylamine = protein N5-alkylglutamine + NH3. This reaction is the formation of the N6-(L-isoglutamyl)-L-lysine isopeptide, resulting in cross-linking polypeptide chains; the gamma-carboxamide groups of peptidyl-glutamine residues act as acyl donors, and the 6-amino-groups of peptidyl-lysine residues act as acceptors, to give intra- and intermolecular N6-(5-glutamyl)lysine cross-links. [EC:2.3.2.13, RESID:AA0124]
Full description |

Standard name | GO_ANTIGEN_BINDING
Systematic name | M18965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an antigen, any substance which is capable of inducing a specific immune response and of reacting with the products of that response, the specific antibody or specifically sensitized T-lymphocytes, or both. Binding may counteract the biological activity of the antigen. [GOC:jl, ISBN:0198506732, ISBN:0721662544]
Full description |

Standard name | GO_ALPHA_N_ACETYLNEURAMINATE_ALPHA_2_8_SIALYLTRANSFERASE_ACTIVITY
Systematic name | M26118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: CMP-N-acetylneuraminate + alpha-N-acetylneuraminyl-(2->3)-beta-D-galactosyl-R = CMP + alpha-N-acetylneuraminyl-(2->8)-alpha-N-acetylneuraminyl-(2->3)-beta-D-galactosyl-R. [EC:2.4.99.8]
Full description |

Standard name | GO_BETA_N_ACETYLGLUCOSAMINYLGLYCOPEPTIDE_BETA_1_4_GALACTOSYLTRANSFERASE_ACTIVITY
Systematic name | M26119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: UDP-galactose + N-acetyl-beta-D-glucosaminylglycopeptide = UDP + beta-D-galactosyl-(1->4)-N-acetyl-beta-D-glucosaminylglycopeptide. [EC:2.4.1.38]
Full description |

Standard name | GO_1_ACYLGLYCEROL_3_PHOSPHATE_O_ACYLTRANSFERASE_ACTIVITY
Systematic name | M34372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acyl-CoA + 1-acyl-sn-glycerol-3-phosphate = CoA + 1,2-diacyl-sn-glycerol-3-phosphate. [EC:2.3.1.51, GOC:ab]
Full description |

Standard name | GO_2_ACYLGLYCEROL_O_ACYLTRANSFERASE_ACTIVITY
Systematic name | M26120
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acyl-CoA + 2-acylglycerol = CoA + diacylglycerol. [EC:2.3.1.22]
Full description |

Standard name | GO_1_ALKYL_2_ACETYLGLYCEROPHOSPHOCHOLINE_ESTERASE_ACTIVITY
Systematic name | M26121
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 2-acetyl-1-alkyl-sn-glycero-3-phosphocholine + H2O = 1-alkyl-sn-glycero-3-phosphocholine + acetate. [EC:3.1.1.47]
Full description |

Standard name | GO_3_BETA_HYDROXY_DELTA5_STEROID_DEHYDROGENASE_ACTIVITY
Systematic name | M26122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a 3-beta-hydroxy-delta(5)-steroid + NAD+ = a 3-oxo-delta(5)-steroid + NADH + H(+). [EC:1.1.1.145]
Full description |

Standard name | GO_3_HYDROXYACYL_COA_DEHYDROGENASE_ACTIVITY
Systematic name | M26123
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: (S)-3-hydroxyacyl-CoA + NAD+ = 3-oxoacyl-CoA + NADH + H(+). [EC:1.1.1.35]
Full description |

Standard name | GO_DNA_DIRECTED_DNA_POLYMERASE_ACTIVITY
Systematic name | M355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: deoxynucleoside triphosphate + DNA(n) = diphosphate + DNA(n+1); the synthesis of DNA from deoxyribonucleotide triphosphates in the presence of a DNA template and a 3'hydroxyl group. [EC:2.7.7.7, GOC:vw, ISBN:0198547684]
Full description |

Standard name | GO_DNA_APURINIC_OR_APYRIMIDINIC_SITE_ENDONUCLEASE_ACTIVITY
Systematic name | M26124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of the C-O-P bond in the AP site created when DNA glycosylase removes a damaged base, involved in the DNA base excision repair pathway (BER). [Wikipedia:AP_endonuclease]
Full description |

Standard name | GO_DNA_TOPOISOMERASE_ACTIVITY
Systematic name | M26125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transient cleavage and passage of individual DNA strands or double helices through one another, resulting a topological transformation in double-stranded DNA. [GOC:mah, PMID:8811192]
Full description |

Standard name | GO_GTPASE_ACTIVITY
Systematic name | M17896
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: GTP + H2O = GDP + phosphate. [ISBN:0198547684, PMID:26832457, PMID:27218782]
Full description |

Standard name | GO_N_ACETYLLACTOSAMINE_SYNTHASE_ACTIVITY
Systematic name | M26127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: UDP-galactose + N-acetyl-D-glucosamine = UDP + N-acetyllactosamine. [EC:2.4.1.90]
Full description |

Standard name | GO_NADPLUS_ADP_RIBOSYLTRANSFERASE_ACTIVITY
Systematic name | M26128
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NAD+ + (ADP-D-ribosyl)(n)-acceptor = nicotinamide + (ADP-D-ribosyl)(n+1)-acceptor. [EC:2.4.2.30]
Full description |

Standard name | GO_NADPLUS_KINASE_ACTIVITY
Systematic name | M26129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + NAD(+) = ADP + 2 H(+) + NADP(+). [EC:2.7.1.23, RHEA:18629]
Full description |

Standard name | GO_NADPLUS_NUCLEOSIDASE_ACTIVITY
Systematic name | M34373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NAD+ + H2O = nicotinamide + ADP-ribose. [GOC:dph, GOC:pad, GOC:PARL, GOC:pde, PMID:11866528, PMID:7805847]
Full description |

Standard name | GO_NADH_DEHYDROGENASE_ACTIVITY
Systematic name | M26130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NADH + H+ + acceptor = NAD+ + reduced acceptor. [EC:1.6.99.3]
Full description |

Standard name | GO_NAD_P_PLUS_PROTEIN_ARGININE_ADP_RIBOSYLTRANSFERASE_ACTIVITY
Systematic name | M26131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NAD(P)+ + L-arginine = nicotinamide + N2-(ADP-D-ribosyl)-L-arginine. [EC:2.4.2.31]
Full description |

Standard name | GO_NADPH_HEMOPROTEIN_REDUCTASE_ACTIVITY
Systematic name | M26132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NADPH + H+ + n oxidized hemoprotein = NADP+ + n reduced hemoprotein. [EC:1.6.2.4]
Full description |

Standard name | GO_RNA_DIRECTED_DNA_POLYMERASE_ACTIVITY
Systematic name | M18385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: deoxynucleoside triphosphate + DNA(n) = diphosphate + DNA(n+1). Catalyzes RNA-template-directed extension of the 3'- end of a DNA strand by one deoxynucleotide at a time. [EC:2.7.7.49]
Full description |

Standard name | GO_ACETYL_COA_HYDROLASE_ACTIVITY
Systematic name | M29449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acetyl-CoA + H(2)O = acetate + CoA + H(+). [EC:3.1.2.1, RHEA:20289]
Full description |

Standard name | GO_ACETYL_COA_C_ACYLTRANSFERASE_ACTIVITY
Systematic name | M26133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acyl-CoA + acetyl-CoA = CoA + 3-oxoacyl-CoA. [EC:2.3.1.16]
Full description |

Standard name | GO_ACID_PHOSPHATASE_ACTIVITY
Systematic name | M19037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an orthophosphoric monoester + H2O = an alcohol + phosphate, with an acid pH optimum. [EC:3.1.3.2]
Full description |

Standard name | GO_ACYL_COA_DEHYDROGENASE_ACTIVITY
Systematic name | M19207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acyl-CoA + acceptor = 2,3-dehydroacyl-CoA + reduced acceptor. [EC:1.3.99.3]
Full description |

Standard name | GO_ACYL_COA_LIGASE_ACTIVITY
Systematic name | M26134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a long-chain carboxylic acid + CoA = AMP + diphosphate + an acyl-CoA; long-chain carboxylic acids have chain lengths of C13 to C22. [EC:6.2.1.3, GOC:mah]
Full description |

Standard name | GO_ACYL_COA_OXIDASE_ACTIVITY
Systematic name | M26135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acyl-CoA + O2 = trans-2,3-dehydroacyl-CoA + hydrogen peroxide. [EC:1.3.3.6]
Full description |

Standard name | GO_ADENOSINE_DEAMINASE_ACTIVITY
Systematic name | M18421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: adenosine + H2O = inosine + NH3. [EC:3.5.4.4]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_ACTIVITY
Systematic name | M26136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP = 3',5'-cyclic AMP + diphosphate. [EC:4.6.1.1]
Full description |

Standard name | GO_ADENYLATE_KINASE_ACTIVITY
Systematic name | M26137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + AMP = 2 ADP. [EC:2.7.4.3]
Full description |

Standard name | GO_ALCOHOL_DEHYDROGENASE_ACTIVITY_ZINC_DEPENDENT
Systematic name | M26139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an alcohol + NAD+ = an aldehyde or ketone + NADH + H+, requiring the presence of zinc. [EC:1.1.1.1, GOC:mah]
Full description |

Standard name | GO_3_CHLOROALLYL_ALDEHYDE_DEHYDROGENASE_ACTIVITY
Systematic name | M26140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 3-chloroallyl aldehyde + H2O = 2 H+ + 2 e- + 3-chloroacrylic acid. [UM-BBD_enzymeID:e0432]
Full description |

Standard name | GO_ALDEHYDE_DEHYDROGENASE_NAD_P_PLUS_ACTIVITY
Systematic name | M26141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an aldehyde + NAD(P)+ + H2O = an acid + NAD(P)H + H+. [EC:1.2.1.5]
Full description |

Standard name | GO_ALDITOL_NADPPLUS_1_OXIDOREDUCTASE_ACTIVITY
Systematic name | M26142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an alditol + NADP+ = an aldose + NADPH + H+. [EC:1.1.1.21]
Full description |

Standard name | GO_ALDO_KETO_REDUCTASE_NADP_ACTIVITY
Systematic name | M17244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an alcohol + NADP+ = an aldehyde or a ketone + NADPH + H+. [GOC:ai]
Full description |

Standard name | GO_AMINOACYLASE_ACTIVITY
Systematic name | M26143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an N-acyl-L-amino acid + H2O = a carboxylate + an L-amino acid. [EC:3.5.1.14]
Full description |

Standard name | GO_ARYL_SULFOTRANSFERASE_ACTIVITY
Systematic name | M18102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 3'-phosphoadenosine 5'-phosphosulfate + a phenol = adenosine 3',5'-bisphosphate + an aryl sulfate. [EC:2.8.2.1]
Full description |

Standard name | GO_ARYLESTERASE_ACTIVITY
Systematic name | M26144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a phenyl acetate + H2O = a phenol + acetate. [EC:3.1.1.2]
Full description |

Standard name | GO_ARYLSULFATASE_ACTIVITY
Systematic name | M19040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a phenol sulfate + H2O = a phenol + sulfate. [EC:3.1.6.1]
Full description |

Standard name | GO_CARBONATE_DEHYDRATASE_ACTIVITY
Systematic name | M10556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: H2CO3 = CO2 + H2O. [EC:4.2.1.1]
Full description |

Standard name | GO_CARBONYL_REDUCTASE_NADPH_ACTIVITY
Systematic name | M26145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: R-CHOH-R' + NADP+ = R-CO-R' + NADPH + H+. [EC:1.1.1.184]
Full description |

Standard name | GO_CYCLIC_NUCLEOTIDE_PHOSPHODIESTERASE_ACTIVITY
Systematic name | M17849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a nucleoside cyclic phosphate + H2O = a nucleoside phosphate. [GOC:mah]
Full description |

Standard name | GO_3_5_CYCLIC_AMP_PHOSPHODIESTERASE_ACTIVITY
Systematic name | M17887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: adenosine 3',5'-cyclic phosphate + H2O = adenosine 5'-phosphate. [GOC:ai]
Full description |

Standard name | GO_CYTIDINE_DEAMINASE_ACTIVITY
Systematic name | M26146
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: cytidine + H2O = uridine + NH3. [EC:3.5.4.5]
Full description |

Standard name | GO_CYTOCHROME_B5_REDUCTASE_ACTIVITY_ACTING_ON_NAD_P_H
Systematic name | M26147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NAD(P)H + H+ + 2 ferricytochrome b(5) = NAD(P)+ + 2 ferrocytochrome b(5). [EC:1.6.2.2, ISBN:0198547684]
Full description |

Standard name | GO_DIACYLGLYCEROL_KINASE_ACTIVITY
Systematic name | M18011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NTP + 1,2-diacylglycerol = NDP + 1,2-diacylglycerol-3-phosphate. [EC:2.7.1.107, GOC:elh]
Full description |

Standard name | GO_DIACYLGLYCEROL_O_ACYLTRANSFERASE_ACTIVITY
Systematic name | M34374
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acyl-CoA + 1,2-diacylglycerol = CoA + triacylglycerol. [EC:2.3.1.20]
Full description |

Standard name | GO_DOLICHYL_PHOSPHATE_MANNOSE_PROTEIN_MANNOSYLTRANSFERASE_ACTIVITY
Systematic name | M26148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: dolichyl phosphate D-mannose + protein = dolichyl phosphate + O-D-mannosylprotein. [EC:2.4.1.109, GOC:pr]
Full description |

Standard name | GO_ENDOPEPTIDASE_ACTIVITY
Systematic name | M6078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of internal, alpha-peptide bonds in a polypeptide chain. [http://merops.sanger.ac.uk/about/glossary.htm#ENDOPEPTIDASE]
Full description |

Standard name | GO_ATP_DEPENDENT_PEPTIDASE_ACTIVITY
Systematic name | M26149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate, to drive the hydrolysis of peptide bonds. [GOC:mah]
Full description |

Standard name | GO_AMINOPEPTIDASE_ACTIVITY
Systematic name | M18202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of N-terminal amino acid residues from in a polypeptide chain. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_CARBOXYPEPTIDASE_ACTIVITY
Systematic name | M18129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of the terminal or penultimate peptide bond at the C-terminal end of a peptide or polypeptide. [ISBN:0198506732]
Full description |

Standard name | GO_METALLOCARBOXYPEPTIDASE_ACTIVITY
Systematic name | M18179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of C-terminal amino acid residues from a polypeptide chain by a mechanism in which water acts as a nucleophile, one or two metal ions hold the water molecule in place, and charged amino acid side chains are ligands for the metal ions. [http://merops.sanger.ac.uk/about/glossary.htm#CARBOXYPEPTIDASE, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE, ISBN:0198506732]
Full description |

Standard name | GO_SERINE_TYPE_CARBOXYPEPTIDASE_ACTIVITY
Systematic name | M18236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a peptide bond not more than three residues from the C-terminus of a polypeptide chain by a catalytic mechanism that involves a catalytic triad consisting of a serine nucleophile that is activated by a proton relay involving an acidic residue (e.g. aspartate or glutamate) and a basic residue (usually histidine). [http://merops.sanger.ac.uk/about/glossary.htm#CARBOXYPEPTIDASE, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE, ISBN:0716720094]
Full description |

Standard name | GO_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY
Systematic name | M5822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of internal, alpha-peptide bonds in a polypeptide chain by a mechanism in which the sulfhydryl group of a cysteine residue at the active center acts as a nucleophile. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE, http://merops.sanger.ac.uk/about/glossary.htm#ENDOPEPTIDASE]
Full description |

Standard name | GO_CALCIUM_DEPENDENT_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY
Systematic name | M19063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of nonterminal peptide bonds in a polypeptide chain by a mechanism using a cysteine residue at the enzyme active center, and requiring the presence of calcium. [GOC:mah]
Full description |

Standard name | GO_METALLOENDOPEPTIDASE_ACTIVITY
Systematic name | M6339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of internal, alpha-peptide bonds in a polypeptide chain by a mechanism in which water acts as a nucleophile, one or two metal ions hold the water molecule in place, and charged amino acid side chains are ligands for the metal ions. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE, http://merops.sanger.ac.uk/about/glossary.htm#ENDOPEPTIDASE]
Full description |

Standard name | GO_THREONINE_TYPE_ENDOPEPTIDASE_ACTIVITY
Systematic name | M34375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of internal peptide bonds in a polypeptide chain by a mechanism in which the hydroxyl group of a threonine residue at the active center acts as a nucleophile. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE, http://merops.sanger.ac.uk/about/glossary.htm#ENDOPEPTIDASE]
Full description |

Standard name | GO_ENOYL_COA_HYDRATASE_ACTIVITY
Systematic name | M26150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: (3S)-3-hydroxyacyl-CoA = trans-2-enoyl-CoA + H2O. [EC:4.2.1.17]
Full description |

Standard name | GO_EPOXIDE_HYDROLASE_ACTIVITY
Systematic name | M26151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an epoxide + H2O = a glycol. [EC:3.3.2.10]
Full description |

Standard name | GO_ESTRADIOL_17_BETA_DEHYDROGENASE_ACTIVITY
Systematic name | M18313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: estradiol-17-beta + NADP+ = estrone + NADPH + H+. [EC:1.1.1.62]
Full description |

Standard name | GO_EXOPOLYPHOSPHATASE_ACTIVITY
Systematic name | M26152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: polyphosphate(n) + H2O = polyphosphate(n-1) + phosphate. [EC:3.6.1.11]
Full description |

Standard name | GO_FATTY_ACID_SYNTHASE_ACTIVITY
Systematic name | M26153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acetyl-CoA + n malonyl-CoA + 2n NADPH + 2n H+ = long-chain fatty acid + n+1 CoA + n CO2 + 2n NADP+. [EC:2.3.1.85]
Full description |

Standard name | GO_FATTY_ACYL_COA_SYNTHASE_ACTIVITY
Systematic name | M29450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acetyl-CoA + n malonyl-CoA + 2n NADH + 2n NADPH + 4n H+ = a long-chain acyl-CoA + n CoA + n CO2 + 2n NAD+ + 2n NADP+. [EC:2.3.1.86]
Full description |

Standard name | GO_FRUCTOSE_2_6_BISPHOSPHATE_2_PHOSPHATASE_ACTIVITY
Systematic name | M26154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: D-fructose 2,6-bisphosphate + H2O = D-fructose-6-phosphate + phosphate. [EC:3.1.3.46]
Full description |

Standard name | GO_GLUTATHIONE_TRANSFERASE_ACTIVITY
Systematic name | M11836
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: R-X + glutathione = H-X + R-S-glutathione. R may be an aliphatic, aromatic or heterocyclic group; X may be a sulfate, nitrile or halide group. [EC:2.5.1.18]
Full description |

Standard name | GO_GLYCOLIPID_MANNOSYLTRANSFERASE_ACTIVITY
Systematic name | M34376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an alpha-D-mannosyl residue from GDP-mannose into lipid-linked oligosaccharide, forming an alpha-D-mannosyl-D-mannose linkage. [GOC:ai]
Full description |

Standard name | GO_GUANYLATE_CYCLASE_ACTIVITY
Systematic name | M26155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: GTP = 3',5'-cyclic GMP + diphosphate. [EC:4.6.1.2]
Full description |

Standard name | GO_GUANYLATE_KINASE_ACTIVITY
Systematic name | M26156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + GMP = ADP + GDP. [EC:2.7.4.8]
Full description |

Standard name | GO_HELICASE_ACTIVITY
Systematic name | M18442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate, to drive the unwinding of a DNA or RNA helix. [GOC:jl]
Full description |

Standard name | GO_HEXOKINASE_ACTIVITY
Systematic name | M26157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + D-hexose = ADP + D-hexose 6-phosphate. [EC:2.7.1.1]
Full description |

Standard name | GO_HYALURONONGLUCOSAMINIDASE_ACTIVITY
Systematic name | M26158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the random hydrolysis of (1->4) linkages between N-acetyl-beta-D-glucosamine and D-glucuronate residues in hyaluronate. [EC:3.2.1.35]
Full description |

Standard name | GO_1_PHOSPHATIDYLINOSITOL_4_KINASE_ACTIVITY
Systematic name | M26159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-phosphatidyl-1D-myo-inositol + ATP = 1-phosphatidyl-1D-myo-inositol 4-phosphate + ADP + 2 H(+). [EC:2.7.1.67, RHEA:19877]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_4_5_BISPHOSPHATE_5_PHOSPHATASE_ACTIVITY
Systematic name | M26160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-phosphatidyl-1D-myo-inositol 4,5-bisphosphate + H(2)O = 1-phosphatidyl-1D-myo-inositol 4-phosphate + phosphate. [EC:3.1.3.36, RHEA:22764]
Full description |

Standard name | GO_INOSITOL_POLYPHOSPHATE_5_PHOSPHATASE_ACTIVITY
Systematic name | M26161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reactions: D-myo-inositol 1,4,5-trisphosphate + H2O = myo-inositol 1,4-bisphosphate + phosphate, and 1D-myo-inositol 1,3,4,5-tetrakisphosphate + H2O = 1D-myo-inositol 1,3,4-trisphosphate + phosphate. [EC:3.1.3.56]
Full description |

Standard name | GO_ISOCITRATE_DEHYDROGENASE_ACTIVITY
Systematic name | M26162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: isocitrate + acceptor = 2-oxoglutarate + CO2 + reduced acceptor. [EC:1.1.1.41, EC:1.1.1.42]
Full description |

Standard name | GO_LACTATE_DEHYDROGENASE_ACTIVITY
Systematic name | M26163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: lactate + NAD+ = H+ + NADH + pyruvate. [GOC:ai, GOC:bf]
Full description |

Standard name | GO_L_LACTATE_DEHYDROGENASE_ACTIVITY
Systematic name | M34377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: (S)-lactate + NAD+ = pyruvate + NADH + H+. [EC:1.1.1.27, RHEA:23444]
Full description |

Standard name | GO_LEUKOTRIENE_C4_SYNTHASE_ACTIVITY
Systematic name | M34378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: leukotriene C(4) = glutathione + leukotriene A(4). [EC:4.4.1.20, RHEA:17617]
Full description |

Standard name | GO_LIPOPROTEIN_LIPASE_ACTIVITY
Systematic name | M34379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: triacylglycerol + H2O = diacylglycerol + a carboxylate, where the triacylglycerol is part of a lipoprotein. [EC:3.1.1.34, GOC:bf]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACID_COA_LIGASE_ACTIVITY
Systematic name | M18624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a long-chain fatty acid + CoA = AMP + diphosphate + an acyl-CoA; a long-chain fatty acid is a fatty acid with a chain length between C13 and C22. [EC:6.2.1.3]
Full description |

Standard name | GO_LYSINE_N_ACETYLTRANSFERASE_ACTIVITY_ACTING_ON_ACETYL_PHOSPHATE_AS_DONOR
Systematic name | M26165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acetyl phosphate + L-lysine = phosphate + N6-acetyl-L-lysine. [EC:2.3.1.32]
Full description |

Standard name | GO_MONOOXYGENASE_ACTIVITY
Systematic name | M19831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the incorporation of one atom from molecular oxygen into a compound and the reduction of the other atom of oxygen to water. [ISBN:0198506732]
Full description |

Standard name | GO_N_N_DIMETHYLANILINE_MONOOXYGENASE_ACTIVITY
Systematic name | M26166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: N,N-dimethylaniline + NADPH + H+ + O2 = N,N-dimethylaniline N-oxide + NADP+ + H2O. [EC:1.14.13.8]
Full description |

Standard name | GO_NUCLEASE_ACTIVITY
Systematic name | M10734
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within nucleic acids. [ISBN:0198547684]
Full description |

Standard name | GO_ENDONUCLEASE_ACTIVITY
Systematic name | M10284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within nucleic acids by creating internal breaks. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_ENDODEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M16353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within deoxyribonucleic acid by creating internal breaks. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_ENDORIBONUCLEASE_ACTIVITY
Systematic name | M12611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within ribonucleic acid by creating internal breaks. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_RNA_DNA_HYBRID_RIBONUCLEASE_ACTIVITY
Systematic name | M18084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the endonucleolytic cleavage of RNA in RNA-DNA hybrids to 5'-phosphomonoesters. [EC:3.1.26.4]
Full description |

Standard name | GO_RIBONUCLEASE_P_ACTIVITY
Systematic name | M19004
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the endonucleolytic cleavage of RNA, removing 5' extra nucleotides from tRNA precursor. [EC:3.1.26.5]
Full description |

Standard name | GO_EXONUCLEASE_ACTIVITY
Systematic name | M15530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within nucleic acids by removing nucleotide residues from the 3' or 5' end. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_PHOSPHODIESTERASE_I_ACTIVITY
Systematic name | M26167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the sequential hydrolytic removal of 5'-nucleotides from the 3'-hydroxy termini of 3'-hydroxy-terminated oligonucleotides. [EC:3.1.4.1]
Full description |

Standard name | GO_EXODEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M19160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the sequential cleavage of mononucleotides from a free 5' or 3' terminus of a DNA molecule. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_DEOXYRIBONUCLEASE_I_ACTIVITY
Systematic name | M26168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the endonucleolytic cleavage of DNA to 5'-phosphodinucleotide and 5'-phosphooligonucleotide end products. [EC:3.1.21.1]
Full description |

Standard name | GO_EXORIBONUCLEASE_ACTIVITY
Systematic name | M26169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the sequential cleavage of mononucleotides from a free 5' or 3' terminus of an RNA molecule. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_POLY_A_SPECIFIC_RIBONUCLEASE_ACTIVITY
Systematic name | M18972
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the exonucleolytic cleavage of poly(A) to 5'-AMP. [EC:3.1.13.4, ISBN:0198547684]
Full description |

Standard name | GO_DEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M3657
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within deoxyribonucleic acid. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_RIBONUCLEASE_ACTIVITY
Systematic name | M10307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of phosphodiester bonds in chains of RNA. [GOC:mah, ISBN:0198547684]
Full description |

Standard name | GO_TRNA_SPECIFIC_RIBONUCLEASE_ACTIVITY
Systematic name | M18798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of phosphodiester bonds in tRNA molecules. [GOC:mah]
Full description |

Standard name | GO_NUCLEOSIDE_DIPHOSPHATE_KINASE_ACTIVITY
Systematic name | M18187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + nucleoside diphosphate = ADP + nucleoside triphosphate. [EC:2.7.4.6]
Full description |

Standard name | GO_NUCLEOTIDE_DIPHOSPHATASE_ACTIVITY
Systematic name | M26170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a dinucleotide + H2O = 2 mononucleotides. [EC:3.6.1.9]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_HYDROLYZING_O_GLYCOSYL_COMPOUNDS
Systematic name | M19171
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any O-glycosyl bond. [GOC:mah]
Full description |

Standard name | GO_BETA_N_ACETYLHEXOSAMINIDASE_ACTIVITY
Systematic name | M26171
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of terminal non-reducing N-acetyl-D-hexosamine residues in N-acetyl-beta-D-hexosaminides. [EC:3.2.1.52]
Full description |

Standard name | GO_BETA_GALACTOSIDASE_ACTIVITY
Systematic name | M26172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of terminal, non-reducing beta-D-galactose residues in beta-D-galactosides. [EC:3.2.1.23]
Full description |

Standard name | GO_MANNOSYL_OLIGOSACCHARIDE_1_2_ALPHA_MANNOSIDASE_ACTIVITY
Systematic name | M26173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of the terminal (1->2)-linked alpha-D-mannose residues in an oligo-mannose oligosaccharide. [GOC:bf, PMID:25092655]
Full description |

Standard name | GO_OLIGOSACCHARYL_TRANSFERASE_ACTIVITY
Systematic name | M26174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a oligosaccharyl group to an acceptor molecule, typically another carbohydrate or a lipid. [GOC:ai]
Full description |

Standard name | GO_DOLICHYL_DIPHOSPHOOLIGOSACCHARIDE_PROTEIN_GLYCOTRANSFERASE_ACTIVITY
Systematic name | M34380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: dolichyl diphosphooligosaccharide + protein L-asparagine = dolichyl diphosphate + a glycoprotein with the oligosaccharide chain attached by glycosylamine linkage to protein L-asparagine. [RHEA:22980]
Full description |

Standard name | GO_PEPTIDE_ALPHA_N_ACETYLTRANSFERASE_ACTIVITY
Systematic name | M26175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acetyl-CoA + peptide = CoA + N-alpha-acetylpeptide. This reaction is the acetylation of the N-terminal amino acid residue of a peptide or protein. [GOC:mah, PMID:30054468]
Full description |

Standard name | GO_GLUTATHIONE_PEROXIDASE_ACTIVITY
Systematic name | M18209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 2 glutathione + hydrogen peroxide = oxidized glutathione + 2 H2O. [EC:1.11.1.9]
Full description |

Standard name | GO_PHOSPHOLIPASE_ACTIVITY
Systematic name | M19165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a glycerophospholipid. [ISBN:0198506732]
Full description |

Standard name | GO_LYSOPHOSPHOLIPASE_ACTIVITY
Systematic name | M18143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 2-lysophosphatidylcholine + H2O = glycerophosphocholine + a carboxylate. [EC:3.1.1.5]
Full description |

Standard name | GO_PHOSPHOLIPASE_A2_ACTIVITY
Systematic name | M18817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: phosphatidylcholine + H2O = 1-acylglycerophosphocholine + a carboxylate. [EC:3.1.1.4]
Full description |

Standard name | GO_PHOSPHOLIPASE_C_ACTIVITY
Systematic name | M18931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a phospholipid + H2O = 1,2-diacylglycerol + a phosphatidate. [EC:3.1.4.3, GOC:mah]
Full description |

Standard name | GO_PHOSPHOLIPASE_D_ACTIVITY
Systematic name | M26176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a phosphatidylcholine + H2O = choline + a phosphatidate. [EC:3.1.4.4]
Full description |

Standard name | GO_1_4_ALPHA_OLIGOGLUCAN_PHOSPHORYLASE_ACTIVITY
Systematic name | M26177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1,4-alpha-D-glucosyl(n) + phosphate = 1,4-alpha-D-glucosyl(n-1) + alpha-D-glucose 1-phosphate. The name should be qualified in each instance by adding the name of the natural substrate, e.g. maltodextrin phosphorylase, starch phosphorylase, glycogen phosphorylase. [EC:2.4.1.1]
Full description |

Standard name | GO_POLYNUCLEOTIDE_ADENYLYLTRANSFERASE_ACTIVITY
Systematic name | M26178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the template-independent extension of the 3'- end of an RNA or DNA strand by addition of one adenosine molecule at a time. Cannot initiate a chain 'de novo'. The primer, depending on the source of the enzyme, may be an RNA or DNA fragment, or oligo(A) bearing a 3'-OH terminal group. [EC:2.7.7.19]
Full description |

Standard name | GO_POLYPEPTIDE_N_ACETYLGALACTOSAMINYLTRANSFERASE_ACTIVITY
Systematic name | M18551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: UDP-N-acetyl-D-galactosamine + polypeptide = UDP + N-acetyl-D-galactosaminyl-polypeptide. This reaction is the modification of serine or threonine residues in polypeptide chains by the transfer of a N-acetylgalactose from UDP-N-acetylgalactose to the hydroxyl group of the amino acid; it is the first step in O-glycan biosynthesis. [EC:2.4.1.41, ISBN:0879695595]
Full description |

Standard name | GO_PROCOLLAGEN_PROLINE_4_DIOXYGENASE_ACTIVITY
Systematic name | M26179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: procollagen L-proline + 2-oxoglutarate + O2 = procollagen trans-4-hydroxy-L-proline + succinate + CO2. [EC:1.14.11.2]
Full description |

Standard name | GO_PRENYLTRANSFERASE_ACTIVITY
Systematic name | M18062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a prenyl group from one compound (donor) to another (acceptor). [GOC:mah]
Full description |

Standard name | GO_PROTEIN_GERANYLGERANYLTRANSFERASE_ACTIVITY
Systematic name | M26180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the covalent addition of a geranylgeranyl (20-carbon isoprenoid) group via thioether linkages to a cysteine residue at or near the C terminus of a protein. [PMID:8621375]
Full description |

Standard name | GO_PROTEIN_ARGININE_DEIMINASE_ACTIVITY
Systematic name | M26181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: protein L-arginine + H2O = protein L-citrulline + NH3. This reaction is calcium-dependent. [PMID:27393304]
Full description |

Standard name | GO_PROTEIN_KINASE_ACTIVITY
Systematic name | M18091
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the phosphorylation of an amino acid residue in a protein, usually according to the reaction: a protein + ATP = a phosphoprotein + ADP. [MetaCyc:PROTEIN-KINASE-RXN]
Full description |

Standard name | GO_PROTEIN_SERINE_THREONINE_KINASE_ACTIVITY
Systematic name | M18940
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reactions: ATP + protein serine = ADP + protein serine phosphate, and ATP + protein threonine = ADP + protein threonine phosphate. [GOC:bf, RHEA:17989, RHEA:46608]
Full description |

Standard name | GO_TRANSMEMBRANE_RECEPTOR_PROTEIN_SERINE_THREONINE_KINASE_ACTIVITY
Systematic name | M19094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a signal and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity by catalysis of the reaction: ATP protein serine = ADP + protein serine phosphate, and ATP + protein threonine = ADP + protein threonine phosphate. [EC:2.7.11.30]
Full description |

Standard name | GO_AMP_ACTIVATED_PROTEIN_KINASE_ACTIVITY
Systematic name | M26182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a protein = ADP + a phosphoprotein. This reaction requires the presence of AMP. [GOC:mah]
Full description |

Standard name | GO_CALMODULIN_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M18568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reactions: ATP + a protein serine = ADP + protein serine phosphate; and ATP + a protein threonine = ADP + protein threonine phosphate. These reactions require the presence of calcium-bound calmodulin. [GOC:mah, PMID:11264466]
Full description |

Standard name | GO_PHOSPHORYLASE_KINASE_ACTIVITY
Systematic name | M26183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 4 ATP + 2 phosphorylase b = 4 ADP + phosphorylase a. [EC:2.7.11.19]
Full description |

Standard name | GO_CYCLIC_NUCLEOTIDE_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M26184
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a protein = ADP + a phosphoprotein. This reaction requires the presence of a cyclic nucleotide. [GOC:mah]
Full description |

Standard name | GO_CAMP_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M26185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a protein = ADP + a phosphoprotein. This reaction requires the presence of cAMP. [EC:2.7.11.11]
Full description |

Standard name | GO_PROTEIN_KINASE_C_ACTIVITY
Systematic name | M18716
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a protein = ADP + a phosphoprotein. This reaction requires diacylglycerol. [EC:2.7.11.13]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_RECEPTOR_KINASE_ACTIVITY
Systematic name | M26186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + G protein-coupled receptor = ADP + G protein-coupled receptor phosphate. [GOC:dph]
Full description |

Standard name | GO_NF_KAPPAB_INDUCING_KINASE_ACTIVITY
Systematic name | M26187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the phosphorylation of the alpha or beta subunit of the inhibitor of kappaB kinase complex (IKK). [PMID:20685151]
Full description |

Standard name | GO_JUN_KINASE_KINASE_KINASE_ACTIVITY
Systematic name | M26188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: JNKK + ATP = JNKK phosphate + ADP. This reaction is the phosphorylation and activation of JUN kinase kinases (JNKKs). [GOC:bf]
Full description |

Standard name | GO_MAP_KINASE_ACTIVITY
Systematic name | M4513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: protein + ATP = protein phosphate + ADP. This reaction is the phosphorylation of proteins. Mitogen-activated protein kinase; a family of protein kinases that perform a crucial step in relaying signals from the plasma membrane to the nucleus. They are activated by a wide range of proliferation- or differentiation-inducing signals; activation is strong with agonists such as polypeptide growth factors and tumor-promoting phorbol esters, but weak (in most cell backgrounds) by stress stimuli. [GOC:ma, ISBN:0198547684]
Full description |

Standard name | GO_MAP_KINASE_KINASE_ACTIVITY
Systematic name | M18962
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the concomitant phosphorylation of threonine (T) and tyrosine (Y) residues in a Thr-Glu-Tyr (TEY) thiolester sequence in a MAP kinase (MAPK) substrate. [ISBN:0198547684]
Full description |

Standard name | GO_MAP_KINASE_KINASE_KINASE_ACTIVITY
Systematic name | M18500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the phosphorylation and activation of a MAP kinase kinase; each MAP kinase kinase can be phosphorylated by any of several MAP kinase kinase kinases. [PMID:9561267]
Full description |

Standard name | GO_RIBOSOMAL_PROTEIN_S6_KINASE_ACTIVITY
Systematic name | M26189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ribosomal protein S6 + ATP = ribosomal protein S6 phosphate + ATP. [GOC:mah, PMID:9822608]
Full description |

Standard name | GO_PROTEIN_SERINE_THREONINE_TYROSINE_KINASE_ACTIVITY
Systematic name | M5810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reactions: ATP + a protein serine = ADP + protein serine phosphate; ATP + a protein threonine = ADP + protein threonine phosphate; and ATP + a protein tyrosine = ADP + protein tyrosine phosphate. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_TYROSINE_KINASE_ACTIVITY
Systematic name | M6622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a protein tyrosine = ADP + protein tyrosine phosphate. [EC:2.7.10]
Full description |

Standard name | GO_TRANSMEMBRANE_RECEPTOR_PROTEIN_TYROSINE_KINASE_ACTIVITY
Systematic name | M5106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a signal and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity by catalysis of the reaction: ATP + a protein-L-tyrosine = ADP + a protein-L-tyrosine phosphate. [EC:2.7.10.1, GOC:mah]
Full description |

Standard name | GO_NON_MEMBRANE_SPANNING_PROTEIN_TYROSINE_KINASE_ACTIVITY
Systematic name | M18321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + protein L-tyrosine = ADP + protein L-tyrosine phosphate by a non-membrane spanning protein. [EC:2.7.10.2]
Full description |

Standard name | GO_PROTEIN_LYSINE_6_OXIDASE_ACTIVITY
Systematic name | M26190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: peptidyl-L-lysyl-peptide + H2O + O2 = peptidyl-allysyl-peptide + NH3 + hydrogen peroxide. [EC:1.4.3.13]
Full description |

Standard name | GO_PHOSPHOPROTEIN_PHOSPHATASE_ACTIVITY
Systematic name | M26191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a phosphoprotein + H2O = a protein + phosphate. Together with protein kinases, these enzymes control the state of phosphorylation of cell proteins and thereby provide an important mechanism for regulating cellular activity. [EC:3.1.3.16, ISBN:0198547684]
Full description |

Standard name | GO_PROTEIN_SERINE_THREONINE_PHOSPHATASE_ACTIVITY
Systematic name | M18297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: protein serine phosphate + H2O = protein serine + phosphate, and protein threonine phosphate + H2O = protein threonine + phosphate. [GOC:bf]
Full description |

Standard name | GO_CALCIUM_DEPENDENT_PROTEIN_SERINE_THREONINE_PHOSPHATASE_ACTIVITY
Systematic name | M26192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reactions: protein serine phosphate + H2O = protein serine + phosphate; and protein threonine phosphate + H2O = protein threonine + phosphate. These reactions require the presence of calcium ions. [EC:3.1.3.16, GOC:mah]
Full description |

Standard name | GO_MAGNESIUM_DEPENDENT_PROTEIN_SERINE_THREONINE_PHOSPHATASE_ACTIVITY
Systematic name | M26193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reactions: protein serine phosphate + H2O = protein serine + phosphate; and protein threonine phosphate + H2O = protein threonine + phosphate. These reactions require the presence of magnesium. [EC:3.1.3.16]
Full description |

Standard name | GO_PROTEIN_TYROSINE_PHOSPHATASE_ACTIVITY
Systematic name | M18580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: protein tyrosine phosphate + H2O = protein tyrosine + phosphate. [EC:3.1.3.48]
Full description |

Standard name | GO_NON_MEMBRANE_SPANNING_PROTEIN_TYROSINE_PHOSPHATASE_ACTIVITY
Systematic name | M26194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: non-membrane spanning protein tyrosine phosphate + H2O = non-membrane spanning protein tyrosine + phosphate. [EC:3.1.3.48]
Full description |

Standard name | GO_PYRUVATE_DEHYDROGENASE_ACTIVITY
Systematic name | M26195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the oxidative decarboxylation of pyruvate. [ISBN:0716720094]
Full description |

Standard name | GO_RETINOL_DEHYDROGENASE_ACTIVITY
Systematic name | M18927
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: retinol + NAD+ = retinal + NADH + H+. [EC:1.1.1.105]
Full description |

Standard name | GO_RIBOSE_PHOSPHATE_DIPHOSPHOKINASE_ACTIVITY
Systematic name | M26196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: D-ribose 5-phosphate + ATP = 5-phospho-alpha-D-ribose 1-diphosphate + AMP + 2 H(+). [EC:2.7.6.1, RHEA:15609]
Full description |

Standard name | GO_SPHINGOMYELIN_PHOSPHODIESTERASE_ACTIVITY
Systematic name | M26197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: H(2)O + sphingomyelin = ceramide + choline phosphate + H(+). [EC:3.1.4.12, RHEA:19253]
Full description |

Standard name | GO_STEROL_ESTERASE_ACTIVITY
Systematic name | M26198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a steryl ester + H2O = a sterol + a fatty acid. [EC:3.1.1.13]
Full description |

Standard name | GO_SUPEROXIDE_DISMUTASE_ACTIVITY
Systematic name | M34381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 2 superoxide + 2 H+ = O2 + hydrogen peroxide. [EC:1.15.1.1, GOC:vw, PMID:15064408]
Full description |

Standard name | GO_THIOREDOXIN_DISULFIDE_REDUCTASE_ACTIVITY
Systematic name | M26199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NADP(+) + thioredoxin = H(+) + NADPH + thioredoxin disulfide. [EC:1.8.1.9, RHEA:20345]
Full description |

Standard name | GO_TRIGLYCERIDE_LIPASE_ACTIVITY
Systematic name | M18118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: triacylglycerol + H2O = diacylglycerol + a carboxylate. [EC:3.1.1.3]
Full description |

Standard name | GO_ENZYME_INHIBITOR_ACTIVITY
Systematic name | M18617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and stops, prevents or reduces the activity of an enzyme. [GOC:ai, GOC:ebc]
Full description |

Standard name | GO_PHOSPHOLIPASE_INHIBITOR_ACTIVITY
Systematic name | M18365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a phospholipase, an enzyme that catalyzes of the hydrolysis of a phospholipid. [GOC:ai, GOC:rl]
Full description |

Standard name | GO_CYCLIN_DEPENDENT_PROTEIN_SERINE_THREONINE_KINASE_INHIBITOR_ACTIVITY
Systematic name | M18246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a cyclin-dependent protein serine/threonine kinase. [GOC:mah, GOC:pr]
Full description |

Standard name | GO_CAMP_DEPENDENT_PROTEIN_KINASE_INHIBITOR_ACTIVITY
Systematic name | M26200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a cAMP-dependent protein kinase. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_SERINE_THREONINE_PHOSPHATASE_INHIBITOR_ACTIVITY
Systematic name | M18103
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a serine/threonine protein phosphatase, an enzyme that catalyzes the reaction: protein serine/threonine phosphate + H2O = protein serine/threonine + phosphate. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_SERINE_TYPE_ENDOPEPTIDASE_INHIBITOR_ACTIVITY
Systematic name | M18439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of serine-type endopeptidases, enzymes that catalyze the hydrolysis of nonterminal peptide bonds in a polypeptide chain; a serine residue (and a histidine residue) are at the active center of the enzyme. [GOC:ai]
Full description |

Standard name | GO_CYSTEINE_TYPE_ENDOPEPTIDASE_INHIBITOR_ACTIVITY
Systematic name | M19182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a cysteine-type endopeptidase, any enzyme that hydrolyzes peptide bonds in polypeptides by a mechanism in which the sulfhydryl group of a cysteine residue at the active center acts as a nucleophile. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_COMPLEMENT_RECEPTOR_ACTIVITY
Systematic name | M26201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with any component or product of the complement cascade and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:add, GOC:ai, GOC:pg, GOC:signaling, ISBN:0781735149, PMID:11884446]
Full description |

Standard name | GO_CYTOKINE_RECEPTOR_ACTIVITY
Systematic name | M3179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a cytokine and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:add, GOC:mah]
Full description |

Standard name | GO_CILIARY_NEUROTROPHIC_FACTOR_RECEPTOR_ACTIVITY
Systematic name | M34382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with ciliary neurotrophic factor (CNTF) and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_INTERFERON_RECEPTOR_ACTIVITY
Systematic name | M26205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an interferon and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:ai, GOC:signaling, PMID:9607096]
Full description |

Standard name | GO_INTERLEUKIN_1_RECEPTOR_ACTIVITY
Systematic name | M26206
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with interleukin-1 to initiate a change in cell activity. Interleukin-1 is produced mainly by activated macrophages and is involved in the inflammatory response. [GOC:jl]
Full description |

Standard name | GO_ONCOSTATIN_M_RECEPTOR_ACTIVITY
Systematic name | M34383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with oncostatin-M and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_RECEPTOR_ACTIVITY
Systematic name | M19267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an extracellular signal and transmitting the signal across the membrane by activating an associated G-protein; promotes the exchange of GDP for GTP on the alpha subunit of a heterotrimeric G-protein complex. [GOC:bf, http://www.iuphar-db.org, Wikipedia:GPCR]
Full description |

Standard name | GO_ADRENERGIC_RECEPTOR_ACTIVITY
Systematic name | M18081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with epinephrine or norepinephrine and transmitting the signal across the membrane by activating the alpha-subunit of an associated heterotrimeric G-protein complex. [GOC:bf, GOC:mah, IUPHAR_GPCR:1274]
Full description |

Standard name | GO_ALPHA_ADRENERGIC_RECEPTOR_ACTIVITY
Systematic name | M26207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with epinephrine or norepinephrine to initiate a change in cell activity via activation of a G protein, with pharmacological characteristics of alpha-adrenergic receptors. [GOC:mah, IUPHAR_GPCR:1274]
Full description |

Standard name | GO_DOPAMINE_NEUROTRANSMITTER_RECEPTOR_ACTIVITY
Systematic name | M26208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with the neurotransmitter dopamine to initiate a change in cell activity. [GOC:PARL, IUPHAR_GPCR:1282, PMID:21711983]
Full description |

Standard name | GO_ICOSANOID_RECEPTOR_ACTIVITY
Systematic name | M18247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an icosanoid to initiate a change in cell activity. [GOC:dph]
Full description |

Standard name | GO_PROSTANOID_RECEPTOR_ACTIVITY
Systematic name | M26209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a prostanoid, any compound based on or derived from the prostanoate structure, to initiate a change in cell activity. [ISBN:0198506732]
Full description |

Standard name | GO_PROSTAGLANDIN_E_RECEPTOR_ACTIVITY
Systematic name | M26210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with prostaglandin E (PGE(2)) to initiate a change in cell activity. [ISBN:0198506732]
Full description |

Standard name | GO_HISTAMINE_RECEPTOR_ACTIVITY
Systematic name | M26212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with histamine to initiate a change in cell activity. Histamine is a physiologically active amine, found in plant and animal tissue and released from mast cells as part of an allergic reaction in humans. [GOC:ai]
Full description |

Standard name | GO_IONOTROPIC_GLUTAMATE_RECEPTOR_ACTIVITY
Systematic name | M10552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transmembrane transfer of an ion by a channel that opens when glutamate has been bound by the channel complex or one of its constituent parts. [ISBN:0198506732]
Full description |

Standard name | GO_NMDA_GLUTAMATE_RECEPTOR_ACTIVITY
Systematic name | M26214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | An cation channel that opens in response to binding by extracellular glutmate, but only if glycine is also bound and the membrane is depolarized. Voltage gating is indirect, due to ejection of bound magnesium from the pore at permissive voltages. [GOC:mah, PMID:10049997]
Full description |

Standard name | GO_MELANOCORTIN_RECEPTOR_ACTIVITY
Systematic name | M26215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with melanocortin to initiate a change in cell activity. [GOC:ai]
Full description |

Standard name | GO_N_FORMYL_PEPTIDE_RECEPTOR_ACTIVITY
Systematic name | M26216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an N-formyl peptide to initiate a change in cell activity. [GOC:ai]
Full description |

Standard name | GO_NEUROPEPTIDE_Y_RECEPTOR_ACTIVITY
Systematic name | M26217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with neuropeptide Y to initiate a change in cell activity. [PMID:9315606]
Full description |

Standard name | GO_OLFACTORY_RECEPTOR_ACTIVITY
Systematic name | M17885
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an odorant and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity in response to detection of smell. [GOC:bf, GOC:dph, GOC:sart, PMID:19135896, PMID:21041441]
Full description |

Standard name | GO_OPIOID_RECEPTOR_ACTIVITY
Systematic name | M26218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an opioid (any narcotic derived from or resembling opium), and transmitting the signal across the membrane by activating an associated G-protein. [GOC:ai, GOC:bf, PMID:20494127]
Full description |

Standard name | GO_SOMATOSTATIN_RECEPTOR_ACTIVITY
Systematic name | M26219
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with somatostatin to initiate a change in cell activity. Somatostatin is a peptide hormone that regulates the endocrine system by signaling via G protein-coupled somatostatin receptors. Somatostatin has two active forms produced by proteolytic cleavage: a 14 amino acid peptide (SST-14) and a 28 amino acid peptide (SST-28). [GOC:ai, GOC:bf, Wikipedia:Somatostatin]
Full description |

Standard name | GO_VASOPRESSIN_RECEPTOR_ACTIVITY
Systematic name | M26220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with vasopressin to initiate a change in cell activity. [GOC:ai]
Full description |

Standard name | GO_EPHRIN_RECEPTOR_ACTIVITY
Systematic name | M19086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an ephrin to initiate a change in cell activity. [GOC:mah, PMID:9530499]
Full description |

Standard name | GO_GPI_LINKED_EPHRIN_RECEPTOR_ACTIVITY
Systematic name | M26221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a GPI-anchored ephrin to initiate a change in cell activity. [GOC:mah, PMID:9530499]
Full description |

Standard name | GO_FIBROBLAST_GROWTH_FACTOR_ACTIVATED_RECEPTOR_ACTIVITY
Systematic name | M26222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a fibroblast growth factor and transmitting the signal across the plasma membrane to initiate a change in cell activity. [GOC:mah]
Full description |

Standard name | GO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_ACTIVATED_RECEPTOR_ACTIVITY
Systematic name | M26223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a vascular endothelial growth factor (VEGF) and transmitting the signal across the plasma membrane to initiate a change in cell activity. [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA_ACTIVATED_RECEPTOR_ACTIVITY
Systematic name | M29453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a transforming growth factor beta (TGFbeta) and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity by catalysis of the reaction: ATP protein serine = ADP + protein serine phosphate, and ATP + protein threonine = ADP + protein threonine phosphate. [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA_RECEPTOR_ACTIVITY_TYPE_I
Systematic name | M26224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a complex of transforming growth factor beta and a type II TGF-beta receptor to initiate a change in cell activity; upon binding, acts as a downstream transducer of TGF-beta signals. [GOC:mah, Reactome:R-HSA-170846]
Full description |

Standard name | GO_TUMOR_NECROSIS_FACTOR_ACTIVATED_RECEPTOR_ACTIVITY
Systematic name | M26226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with tumor necrosis factor, a proinflammatory cytokine produced by monocytes and macrophages, to initiate a change in cell function. [GOC:jl, http://lookwayup.com/]
Full description |

Standard name | GO_DEATH_RECEPTOR_ACTIVITY
Systematic name | M19031
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an extracellular messenger (called a death ligand), and transmitting the signal from one side of the plasma membrane to the other to initiate apoptotic or necrotic cell death. [GOC:bf, GOC:BHF, GOC:ecd, GOC:mtg_apoptosis, GOC:rl, PMID:10209153]
Full description |

Standard name | GO_LOW_DENSITY_LIPOPROTEIN_PARTICLE_RECEPTOR_ACTIVITY
Systematic name | M26227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a low-density lipoprotein particle and delivering the low-density lipoprotein particle into the cell via endocytosis. [GOC:bf, ISBN:0198506732]
Full description |

Standard name | GO_NETRIN_RECEPTOR_ACTIVITY
Systematic name | M26228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a netrin signal and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:dph, GOC:signaling, PMID:15960985]
Full description |

Standard name | GO_SCAVENGER_RECEPTOR_ACTIVITY
Systematic name | M18245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with any modified low-density lipoprotein (LDL) or other polyanionic ligand and delivering the ligand into the cell via endocytosis. Ligands include acetylated and oxidized LDL, Gram-positive and Gram-negative bacteria, apoptotic cells, amyloid-beta fibrils, and advanced glycation end products (AGEs). [GOC:bf, PMID:11790542, PMID:12379907, PMID:12621157, PMID:20981357]
Full description |

Standard name | GO_SIGNAL_SEQUENCE_BINDING
Systematic name | M17958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a signal sequence, a specific peptide sequence found on protein precursors or mature proteins that dictates where the mature protein is localized. [GOC:ai]
Full description |

Standard name | GO_NUCLEAR_EXPORT_SIGNAL_RECEPTOR_ACTIVITY
Systematic name | M26229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a nuclear export signal (NES) on a cargo to be transported, to mediate transport of a the cargo through the nuclear pore, from the nuclear lumen to the cytoplasm. The cargo can be either a RNA or a protein. [GOC:bf, GOC:mah, GOC:pg, GOC:vw, PMID:11743003, PMID:25802992, PMID:28713609, Wikipedia:Nuclear_transport]
Full description |

Standard name | GO_TRANSMEMBRANE_RECEPTOR_PROTEIN_TYROSINE_KINASE_ADAPTOR_ACTIVITY
Systematic name | M26230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding activity of a molecule that brings together a transmembrane receptor protein tyrosine kinase and one or more other molecules, permitting them to function in a coordinated way. [GOC:mtg_MIT_16mar07, PMID:10502414, PMID:20565848]
Full description |

Standard name | GO_MAP_KINASE_SCAFFOLD_ACTIVITY
Systematic name | M26232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding activity of a molecule that functions as a physical support for the assembly of a multiprotein mitogen-activated protein kinase (MAPK) complex. Binds multiple kinases of the MAPKKK cascade, and also upstream signaling proteins, permitting those molecules to function in a coordinated way. Bringing together multiple enzymes and their substrates enables the signal to be transduced quickly and efficiently. [PMID:12511654, PMID:15213240, PMID:9405336]
Full description |

Standard name | GO_PROTEIN_KINASE_C_BINDING
Systematic name | M17890
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with protein kinase C. [GOC:jl]
Full description |

Standard name | GO_GUANYL_NUCLEOTIDE_EXCHANGE_FACTOR_ACTIVITY
Systematic name | M17485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stimulates the exchange of guanyl nucleotides associated with a GTPase. Under normal cellular physiological conditions, the concentration of GTP is higher than that of GDP, favoring the replacement of GDP by GTP in association with the GTPase. [GOC:kd, GOC:mah]
Full description |

Standard name | GO_ARF_GUANYL_NUCLEOTIDE_EXCHANGE_FACTOR_ACTIVITY
Systematic name | M18832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stimulates the exchange of guanyl nucleotides associated with the GTPase ARF. Under normal cellular physiological conditions, the concentration of GTP is higher than that of GDP, favoring the replacement of GDP by GTP in association with the GTPase. [GOC:mah]
Full description |

Standard name | GO_RAS_GUANYL_NUCLEOTIDE_EXCHANGE_FACTOR_ACTIVITY
Systematic name | M18093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stimulates the exchange of guanyl nucleotides associated with a GTPase of the Ras superfamily. Under normal cellular physiological conditions, the concentration of GTP is higher than that of GDP, favoring the replacement of GDP by GTP in association with the GTPase. [GOC:mah]
Full description |

Standard name | GO_RHO_GUANYL_NUCLEOTIDE_EXCHANGE_FACTOR_ACTIVITY
Systematic name | M4477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stimulates the exchange of guanyl nucleotides associated with a GTPase of the Rho family. Under normal cellular physiological conditions, the concentration of GTP is higher than that of GDP, favoring the replacement of GDP by GTP in association with the GTPase. [GOC:mah]
Full description |

Standard name | GO_GDP_DISSOCIATION_INHIBITOR_ACTIVITY
Systematic name | M18314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Prevents the dissociation of GDP from a GTPase, thereby preventing GTP from binding. [GOC:mah]
Full description |

Standard name | GO_GTPASE_INHIBITOR_ACTIVITY
Systematic name | M18132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of any enzyme that catalyzes the hydrolysis of GTP to GDP and orthophosphate. [GOC:ai]
Full description |

Standard name | GO_SIGNALING_RECEPTOR_BINDING
Systematic name | M15583
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with one or more specific sites on a receptor molecule, a macromolecule that undergoes combination with a hormone, neurotransmitter, drug or intracellular messenger to initiate a change in cell function. [GOC:bf, GOC:ceb, ISBN:0198506732]
Full description |

Standard name | GO_FIBROBLAST_GROWTH_FACTOR_RECEPTOR_BINDING
Systematic name | M17945
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the fibroblast growth factor receptor (FGFR). [GOC:ceb]
Full description |

Standard name | GO_TYPE_1_FIBROBLAST_GROWTH_FACTOR_RECEPTOR_BINDING
Systematic name | M34384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the type 1 fibroblast growth factor receptor (FGFR1). [GOC:ceb, GOC:fb_curators]
Full description |

Standard name | GO_FRIZZLED_BINDING
Systematic name | M19010
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a frizzled (fz) receptor. [GOC:ceb]
Full description |

Standard name | GO_TYPE_2_FIBROBLAST_GROWTH_FACTOR_RECEPTOR_BINDING
Systematic name | M34385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the type 2 fibroblast growth factor receptor (FGFR2). [GOC:fb_curators]
Full description |

Standard name | GO_NOTCH_BINDING
Systematic name | M19041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the Notch (N) protein, a surface receptor. [GOC:ceb]
Full description |

Standard name | GO_PATCHED_BINDING
Systematic name | M26234
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the patched (ptc) protein, a receptor for hedgehog proteins. [GOC:ceb, PMID:11731473]
Full description |

Standard name | GO_TYPE_II_TRANSFORMING_GROWTH_FACTOR_BETA_RECEPTOR_BINDING
Systematic name | M26235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a type II transforming growth factor beta receptor. [GOC:ceb, GOC:mah, PMID:11252892]
Full description |

Standard name | GO_DEATH_RECEPTOR_BINDING
Systematic name | M18625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any member of the death receptor (DR) family. The DR family falls within the tumor necrosis factor receptor superfamily and is characterized by a cytoplasmic region of ~80 residues termed the death domain (DD). [GOC:ceb, GOC:rl, PMID:15654015]
Full description |

Standard name | GO_CYTOKINE_ACTIVITY
Systematic name | M14581
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The activity of a soluble extracellular gene product that interacts with a receptor to effect a change in the activity of the receptor to control the survival, growth, differentiation and effector function of tissues and cells. [ISBN:0198599471, PMID:11530802]
Full description |

Standard name | GO_CYTOKINE_RECEPTOR_BINDING
Systematic name | M8501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a cytokine receptor. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_CILIARY_NEUROTROPHIC_FACTOR_RECEPTOR_BINDING
Systematic name | M26236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the ciliary neurotrophic factor receptor. [GOC:ai]
Full description |

Standard name | GO_GROWTH_HORMONE_RECEPTOR_BINDING
Systematic name | M26237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the growth hormone receptor. [GOC:ai]
Full description |

Standard name | GO_TYPE_I_INTERFERON_RECEPTOR_BINDING
Systematic name | M18767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an interferon-type I receptor, a heterodimeric complex composed of an alpha subunit (IFNAR1) and a beta subunit (IFNAR2). [GOC:ai, GOC:signaling, PMID:17502368]
Full description |

Standard name | GO_INTERLEUKIN_2_RECEPTOR_BINDING
Systematic name | M26238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the interleukin-2 receptor. [GOC:ai]
Full description |

Standard name | GO_INTERLEUKIN_6_RECEPTOR_BINDING
Systematic name | M26239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the interleukin-6 receptor. [GOC:ai]
Full description |

Standard name | GO_INTERLEUKIN_12_RECEPTOR_BINDING
Systematic name | M26240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the interleukin-12 receptor. [GOC:ai]
Full description |

Standard name | GO_INTERLEUKIN_1_RECEPTOR_BINDING
Systematic name | M18352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the interleukin-1 receptor. [GOC:go_curators]
Full description |

Standard name | GO_EPIDERMAL_GROWTH_FACTOR_RECEPTOR_BINDING
Systematic name | M18094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the epidermal growth factor receptor. [GOC:ai]
Full description |

Standard name | GO_INSULIN_RECEPTOR_BINDING
Systematic name | M18176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the insulin receptor. [GOC:ai]
Full description |

Standard name | GO_INSULIN_LIKE_GROWTH_FACTOR_RECEPTOR_BINDING
Systematic name | M12952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the insulin-like growth factor receptor. [GOC:jl]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA_RECEPTOR_BINDING
Systematic name | M18528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the transforming growth factor beta receptor. [GOC:ai]
Full description |

Standard name | GO_PLATELET_DERIVED_GROWTH_FACTOR_RECEPTOR_BINDING
Systematic name | M19153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the platelet-derived growth factor receptor. [GOC:ai]
Full description |

Standard name | GO_NERVE_GROWTH_FACTOR_RECEPTOR_BINDING
Systematic name | M34386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the nerve growth factor receptor. [GOC:ai, PMID:15654015]
Full description |

Standard name | GO_TUMOR_NECROSIS_FACTOR_RECEPTOR_BINDING
Systematic name | M18993
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the tumor necrosis factor receptor. [GOC:ai]
Full description |

Standard name | GO_NEUROTROPHIN_RECEPTOR_BINDING
Systematic name | M19019
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a neurotrophin receptor. [GOC:ai]
Full description |

Standard name | GO_NEUROTROPHIN_TRK_RECEPTOR_BINDING
Systematic name | M26241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a neurotrophin TRK receptor. [GOC:ai]
Full description |

Standard name | GO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_RECEPTOR_BINDING
Systematic name | M26242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any vascular endothelial growth factor receptor. [GOC:ai]
Full description |

Standard name | GO_INTEGRIN_BINDING
Systematic name | M8623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an integrin. [GOC:ceb]
Full description |

Standard name | GO_HORMONE_ACTIVITY
Systematic name | M18237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action characteristic of a hormone, any substance formed in very small amounts in one specialized organ or group of cells and carried (sometimes in the bloodstream) to another organ or group of cells in the same organism, upon which it has a specific regulatory action. The term was originally applied to agents with a stimulatory physiological action in vertebrate animals (as opposed to a chalone, which has a depressant action). Usage is now extended to regulatory compounds in lower animals and plants, and to synthetic substances having comparable effects; all bind receptors and trigger some biological process. [GOC:dph, GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_NEUROPEPTIDE_HORMONE_ACTIVITY
Systematic name | M18214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action characteristic of a neuropeptide hormone, any peptide hormone that acts in the central nervous system. A neuropeptide is any of several types of molecules found in brain tissue, composed of short chains of amino acids; they include endorphins, enkephalins, vasopressin, and others. They are often localized in axon terminals at synapses and are classified as putative neurotransmitters, although some are also hormones. [GOC:mah]
Full description |

Standard name | GO_STRUCTURAL_MOLECULE_ACTIVITY
Systematic name | M19177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of a complex or its assembly within or outside a cell. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_CYTOSKELETON
Systematic name | M18984
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of a cytoskeletal structure. [GOC:mah]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX_STRUCTURAL_CONSTITUENT
Systematic name | M12927
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of the extracellular matrix. [GOC:mah]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_EYE_LENS
Systematic name | M18222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of the lens of an eye. [GOC:mah]
Full description |

Standard name | GO_TRANSPORTER_ACTIVITY
Systematic name | M19156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the directed movement of substances (such as macromolecules, small molecules, ions) into, out of or within a cell, or between cells. [GOC:ai, GOC:dgf]
Full description |

Standard name | GO_INTRACELLULAR_LIGAND_GATED_ION_CHANNEL_ACTIVITY
Systematic name | M18812
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an ion by a channel that opens when a specific intracellular ligand has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_INTRACELLULAR_CAMP_ACTIVATED_CATION_CHANNEL_ACTIVITY
Systematic name | M26243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a cation by a channel that opens when intracellular cAMP has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport]
Full description |

Standard name | GO_INTRACELLULAR_CGMP_ACTIVATED_CATION_CHANNEL_ACTIVITY
Systematic name | M26244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a cation by a channel that opens when intracellular cGMP has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport]
Full description |

Standard name | GO_VOLUME_SENSITIVE_ANION_CHANNEL_ACTIVITY
Systematic name | M26245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an anion by a volume-sensitive channel. An anion is a negatively charged ion. A volume-sensitive channel is a channel that responds to changes in the volume of a cell. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CALCIUM_ACTIVATED_CATION_CHANNEL_ACTIVITY
Systematic name | M18125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the calcium concentration-regulatable energy-independent passage of cations across a lipid bilayer down a concentration gradient. [GOC:dph, GOC:mtg_transport]
Full description |

Standard name | GO_INTRACELLULAR_CALCIUM_ACTIVATED_CHLORIDE_CHANNEL_ACTIVITY
Systematic name | M18458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of chloride by a channel that opens in response to stimulus by a calcium ion or ions. Transport by a channel involves catalysis of facilitated diffusion of a solute (by an energy-independent process) involving passage through a transmembrane aqueous pore or channel, without evidence for a carrier-mediated mechanism. [GOC:mtg_transport]
Full description |

Standard name | GO_EXTRACELLULAR_LIGAND_GATED_ION_CHANNEL_ACTIVITY
Systematic name | M18911
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an ion by a channel that opens when a specific extracellular ligand has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_EXCITATORY_EXTRACELLULAR_LIGAND_GATED_ION_CHANNEL_ACTIVITY
Systematic name | M18473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an ion by a channel that opens when a specific extracellular ligand has been bound by the channel complex or one of its constituent parts, where channel opening contributes to an increase in membrane potential. [GOC:mah, ISBN:0323037070]
Full description |

Standard name | GO_INHIBITORY_EXTRACELLULAR_LIGAND_GATED_ION_CHANNEL_ACTIVITY
Systematic name | M26246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an ion by a channel that opens when a specific extracellular inhibitory ligand has been bound by the channel complex or one of its constituent parts. Inhibitory ligands, such as GABA or glycine, open chloride-selective channels. [GOC:mah, ISBN:0323037070]
Full description |

Standard name | GO_INWARD_RECTIFIER_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M19001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a potassium ion by an inwardly-rectifying voltage-gated channel. An inwardly rectifying current-voltage relation is one where at any given driving force the inward flow of K+ ions exceeds the outward flow for the opposite driving force. The inward-rectification is due to a voltage-dependent block of the channel pore by a specific ligand or ligands, and as a result the macroscopic conductance depends on the difference between membrane voltage and the K+ equilibrium potential rather than on membrane voltage itself. [GOC:cb, GOC:mah, PMID:14977398]
Full description |

Standard name | GO_GAP_JUNCTION_CHANNEL_ACTIVITY
Systematic name | M19052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A wide pore channel activity that enables a direct cytoplasmic connection from one cell to an adjacent cell. The gap junction can pass large solutes as well as electrical signals between cells. Gap junctions consist of two gap junction hemi-channels, or connexons, one contributed by each membrane through which the gap junction passes. [GOC:dgh, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_VOLTAGE_GATED_ION_CHANNEL_ACTIVITY
Systematic name | M17888
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an ion by a voltage-gated channel. An ion is an atom or group of atoms carrying an electric charge by virtue of having gained or lost one or more electrons. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:mtg_transport, ISBN:0198506732, ISBN:0815340729]
Full description |

Standard name | GO_VOLTAGE_GATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M19157
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a calcium ion by a voltage-gated channel. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:mtg_transport, GOC:tb, ISBN:0815340729]
Full description |

Standard name | GO_CALCIUM_CHANNEL_REGULATOR_ACTIVITY
Systematic name | M19200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a calcium channel. [GOC:mah]
Full description |

Standard name | GO_VOLTAGE_GATED_CHLORIDE_CHANNEL_ACTIVITY
Systematic name | M18444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a chloride ion by a voltage-gated channel. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_VOLTAGE_GATED_SODIUM_CHANNEL_ACTIVITY
Systematic name | M18754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a sodium ion by a voltage-gated channel. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_VOLTAGE_GATED_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M18703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a potassium ion by a voltage-gated channel. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_DELAYED_RECTIFIER_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M18859
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a potassium ion by a delayed rectifying voltage-gated channel. A delayed rectifying current-voltage relation is one where channel activation kinetics are time-dependent, and inactivation is slow. [GOC:mah, PMID:11343411, PMID:2462513]
Full description |

Standard name | GO_ANION_CHANNEL_ACTIVITY
Systematic name | M18341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the energy-independent passage of anions across a lipid bilayer down a concentration gradient. [GOC:dph, GOC:mtg_transport, GOC:pr, ISBN:0815340729]
Full description |

Standard name | GO_CATION_CHANNEL_ACTIVITY
Systematic name | M19194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the energy-independent passage of cations across a lipid bilayer down a concentration gradient. [GOC:def, GOC:dph, GOC:mtg_transport, GOC:pr, ISBN:0815340729]
Full description |

Standard name | GO_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M18977
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the facilitated diffusion of a potassium ion (by an energy-independent process) involving passage through a transmembrane aqueous pore or channel without evidence for a carrier-mediated mechanism. [GOC:BHF, GOC:mtg_transport, GOC:pr, ISBN:0815340729]
Full description |

Standard name | GO_SODIUM_CHANNEL_ACTIVITY
Systematic name | M19217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the facilitated diffusion of a sodium ion (by an energy-independent process) involving passage through a transmembrane aqueous pore or channel without evidence for a carrier-mediated mechanism. [GOC:BHF, GOC:mtg_transport, GOC:pr, ISBN:0815340729]
Full description |

Standard name | GO_AMINO_ACID_SODIUM_SYMPORTER_ACTIVITY
Systematic name | M26248
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: amino acid(out) + Na+(out) = amino acid(in) + Na+(in). [GOC:ai]
Full description |

Standard name | GO_L_HISTIDINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34387
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of L-histidine from one side of a membrane to the other. L-histidine is 2-amino-3-(1H-imidazol-4-yl)propanoic acid. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_DICARBOXYLIC_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of dicarboxylic acids from one side of a membrane to the other. A dicarboxylic acid is an organic acid with two COOH groups. [GOC:ai]
Full description |

Standard name | GO_INORGANIC_PHOSPHATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a inorganic phosphate from one side of a membrane to the other, up its concentration gradient. The transporter binds the solute and undergoes a series of conformational changes. Transport works equally well in either direction and is driven by a chemiosmotic source of energy. Secondary active transporters include symporters and antiporters. [GOC:mtg_transport]
Full description |

Standard name | GO_LIPID_TRANSPORTER_ACTIVITY
Systematic name | M17918
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the directed movement of lipids into, out of or within a cell, or between cells. [GOC:ai]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACID_TRANSPORTER_ACTIVITY
Systematic name | M26251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of long-chain fatty acids from one side of a membrane to the other. A long-chain fatty acid is a fatty acid with a chain length between C13 and C22. [ISBN:0198506732, RHEA:15181]
Full description |

Standard name | GO_NEUROTRANSMITTER_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M19111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the directed movement of a neurotransmitter into, out of or within a cell, or between cells. Neurotransmitters are any chemical substance that is capable of transmitting (or inhibiting the transmission of) a nerve impulse from a neuron to another cell. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOSIDE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a nucleoside, a nucleobase linked to either beta-D-ribofuranose (ribonucleoside) or 2-deoxy-beta-D-ribofuranose, (a deoxyribonucleotide) from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_NUCLEOTIDE_SUGAR_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a nucleotide-sugar from one side of a membrane to the other. A nucleotide-sugar is any nucleotide in which the distal phosphoric residue of a nucleoside 5'-diphosphate is in glycosidic linkage with a monosaccharide or monosaccharide derivative. [GOC:ai, GOC:mtg_transport, ISBN:0815340729, PMID:15034926]
Full description |

Standard name | GO_ORGANIC_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of organic acids from one side of a membrane to the other. Organic acids are acidic compound containing carbon in covalent linkage. [ISBN:0198506732]
Full description |

Standard name | GO_ORGANIC_ACID_SODIUM_SYMPORTER_ACTIVITY
Systematic name | M18672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: organic acid(out) + Na+(out) = organic acid(in) + Na+(in). [TC:2.A.28.1.1]
Full description |

Standard name | GO_OXYGEN_CARRIER_ACTIVITY
Systematic name | M26254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the directed movement of oxygen into, out of or within a cell, or between cells. [GOC:ai]
Full description |

Standard name | GO_PURINE_NUCLEOBASE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of purine nucleobases, one of the two classes of nitrogen-containing ring compounds found in DNA and RNA, from one side of a membrane to the other. [ISBN:0198506732]
Full description |

Standard name | GO_ATP_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26256
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of ATP, adenosine triphosphate, from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_CARBOHYDRATE_PROTON_SYMPORTER_ACTIVITY
Systematic name | M26257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: carbohydrate(out) + H+(out) = carbohydrate(in) + H+(in). [TC:2.A.1.1]
Full description |

Standard name | GO_WATER_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of water (H2O) from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_COPPER_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of copper (Cu) ions from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_IRON_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of iron (Fe) ions from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_MANGANESE_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of manganese (Mn) ions from one side of a membrane to the other. [GOC:dgf]
Full description |

Standard name | GO_ZINC_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of zinc (Zn) ions from one side of a membrane to the other. [GOC:dgf]
Full description |

Standard name | GO_CALCIUM_TRANSMEMBRANE_TRANSPORTER_ACTIVITY_PHOSPHORYLATIVE_MECHANISM
Systematic name | M26262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: ATP + H2O + Ca2+(cis) = ADP + phosphate + Ca2+(trans). [EC:7.2.2.10]
Full description |

Standard name | GO_CARBOHYDRATE_CATION_SYMPORTER_ACTIVITY
Systematic name | M26263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: sugar(out) + cation(out) = sugar(in) + cation(in). [GOC:ai]
Full description |

Standard name | GO_GLUCOSE_SODIUM_SYMPORTER_ACTIVITY
Systematic name | M26264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: glucose(out) + Na+(out) = glucose(in) + Na+(in). [TC:2.A.21.3.-]
Full description |

Standard name | GO_AMINO_ACID_CATION_SYMPORTER_ACTIVITY
Systematic name | M26265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: amino acid(out) + cation(out) = amino acid(in) + cation(in). [GOC:ai]
Full description |

Standard name | GO_SODIUM_PHOSPHATE_SYMPORTER_ACTIVITY
Systematic name | M26267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: Na+(out) + phosphate(out) = Na+(in) + phosphate(in). [GOC:ai]
Full description |

Standard name | GO_INORGANIC_ANION_EXCHANGER_ACTIVITY
Systematic name | M18926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: inorganic anion A(out) + inorganic anion B(in) = inorganic anion A(in) + inorganic anion B(out). [GOC:mah]
Full description |

Standard name | GO_UDP_N_ACETYLGLUCOSAMINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a UDP-N-acetylglucosamine from one side of a membrane to the other. N-acetylglucosamine is a substance composed of N-acetylglucosamine, a common structural unit of oligosaccharides, in glycosidic linkage with uridine diphosphate. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_SNAP_RECEPTOR_ACTIVITY
Systematic name | M18317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Acting as a marker to identify a membrane and interacting selectively with one or more SNAREs on another membrane to mediate membrane fusion. [GOC:mah, PMID:14570579]
Full description |

Standard name | GO_STEROID_BINDING
Systematic name | M18012
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a steroid, any of a large group of substances that have in common a ring system based on 1,2-cyclopentanoperhydrophenanthrene. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_VITAMIN_D_BINDING
Systematic name | M26268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with vitamin D, any of a group of related, fat-soluble compounds that are derived from delta-5,7 steroids and play a central role in calcium metabolism. Specific forms of vitamin D include calciferol (ergocalciferol; vitamin D2) and cholecalciferol (calciol; vitamin D3). [GOC:mah, ISBN:0471331309]
Full description |

Standard name | GO_11_CIS_RETINAL_BINDING
Systematic name | M26269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with 11-cis retinal, an isomer of retinal that plays an important role in the visual process in most vertebrates. 11-cis retinal combines with opsin in the rods (scotopsin) to form rhodopsin or visual purple. Retinal is one of the three compounds that makes up vitamin A. [PMID:24403072]
Full description |

Standard name | GO_FATTY_ACID_BINDING
Systematic name | M18199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with fatty acids, aliphatic monocarboxylic acids liberated from naturally occurring fats and oils by hydrolysis. [ISBN:0198506732]
Full description |

Standard name | GO_IRON_ION_BINDING
Systematic name | M18915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with iron (Fe) ions. [GOC:ai]
Full description |

Standard name | GO_COPPER_ION_BINDING
Systematic name | M18426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with copper (Cu) ions. [GOC:ai]
Full description |

Standard name | GO_CALCIUM_ION_BINDING
Systematic name | M98
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with calcium ions (Ca2+). [GOC:ai]
Full description |

Standard name | GO_CALMODULIN_BINDING
Systematic name | M9182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with calmodulin, a calcium-binding protein with many roles, both in the calcium-bound and calcium-free states. [GOC:krc]
Full description |

Standard name | GO_COLLAGEN_BINDING
Systematic name | M7392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with collagen, a group of fibrous proteins of very high tensile strength that form the main component of connective tissue in animals. Collagen is highly enriched in glycine (some regions are 33% glycine) and proline, occurring predominantly as 3-hydroxyproline (about 20%). [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_INSULIN_LIKE_GROWTH_FACTOR_BINDING
Systematic name | M18333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an insulin-like growth factor, any member of a group of polypeptides that are structurally homologous to insulin and share many of its biological activities, but are immunologically distinct from it. [ISBN:0198506732]
Full description |

Standard name | GO_LAMIN_BINDING
Systematic name | M18450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with lamin; any of a group of intermediate-filament proteins that form the fibrous matrix on the inner surface of the nuclear envelope. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_PROFILIN_BINDING
Systematic name | M26270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with profilin, an actin-binding protein that forms a complex with G-actin and prevents it from polymerizing to form F-actin. [ISBN:0721662544]
Full description |

Standard name | GO_TROPOMYOSIN_BINDING
Systematic name | M18336
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with tropomyosin, a protein associated with actin filaments both in cytoplasm and, in association with troponin, in the thin filament of striated muscle. [GOC:curators, ISBN:0815316194]
Full description |

Standard name | GO_MACROLIDE_BINDING
Systematic name | M18331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a macrolide, any of a large group of structurally related antibiotics produced by Streptomyces species. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_FK506_BINDING
Systematic name | M34389
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the 23-membered macrolide lactone FK506. [GOC:jl]
Full description |

Standard name | GO_GLUCOSE_BINDING
Systematic name | M18304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the D- or L-enantiomer of glucose. [GOC:jl]
Full description |

Standard name | GO_MANNOSE_BINDING
Systematic name | M18293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with mannose, a monosaccharide hexose, stereoisomeric with glucose, that occurs naturally only in polymerized forms called mannans. [GOC:jl, ISBN:0192800981]
Full description |

Standard name | GO_GLYCOSAMINOGLYCAN_BINDING
Systematic name | M14266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any glycan (polysaccharide) containing a substantial proportion of aminomonosaccharide residues. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_HYALURONIC_ACID_BINDING
Systematic name | M18882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with hyaluronic acid, a polymer composed of repeating dimeric units of glucuronic acid and N-acetyl glucosamine. [GOC:jl]
Full description |

Standard name | GO_FOLIC_ACID_BINDING
Systematic name | M18301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with folic acid, pteroylglutamic acid. Folic acid is widely distributed as a member of the vitamin B complex and is essential for the synthesis of purine and pyrimidines. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHOLIPID_BINDING
Systematic name | M19021
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phospholipids, a class of lipids containing phosphoric acid as a mono- or diester. [ISBN:0198506732]
Full description |

Standard name | GO_CALCIUM_DEPENDENT_PHOSPHOLIPID_BINDING
Systematic name | M19226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phospholipids, a class of lipids containing phosphoric acid as a mono- or diester, in the presence of calcium. [GOC:jl]
Full description |

Standard name | GO_1_PHOSPHATIDYLINOSITOL_BINDING
Systematic name | M18814
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylinositol, any glycophospholipid with its sn-glycerol 3-phosphate residue is esterified to the 1-hydroxyl group of 1D-myo-inositol. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_4_5_BISPHOSPHATE_BINDING
Systematic name | M18061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylinositol-4,5-bisphosphate, a derivative of phosphatidylinositol in which the inositol ring is phosphorylated at the 4' and 5' positions. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_4_5_TRISPHOSPHATE_BINDING
Systematic name | M19183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylinositol-3,4,5-trisphosphate, a derivative of phosphatidylinositol in which the inositol ring is phosphorylated at the 3', 4' and 5' positions. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_PHOSPHOLIPID_TRANSPORTER_ACTIVITY
Systematic name | M18802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the directed movement of phospholipids into, out of or within a cell, or between cells. Phospholipids are a class of lipids containing phosphoric acid as a mono- or diester. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_ODORANT_BINDING
Systematic name | M19181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an odorant, any substance capable of stimulating the sense of smell. [GOC:jl, ISBN:0721662544]
Full description |

Standard name | GO_CHEMOKINE_ACTIVITY
Systematic name | M14051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The function of a family of small chemotactic cytokines; their name is derived from their ability to induce directed chemotaxis in nearby responsive cells. All chemokines possess a number of conserved cysteine residues involved in intramolecular disulfide bond formation. Some chemokines are considered pro-inflammatory and can be induced during an immune response to recruit cells of the immune system to a site of infection, while others are considered homeostatic and are involved in controlling the migration of cells during normal processes of tissue maintenance or development. Chemokines are found in all vertebrates, some viruses and some bacteria. [GOC:BHF, GOC:rl, PMID:12183377, Wikipedia:Chemokine]
Full description |

Standard name | GO_BETA_CATENIN_BINDING
Systematic name | M17855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the beta subunit of the catenin complex. [GOC:bf]
Full description |

Standard name | GO_MICROTUBULE_BINDING
Systematic name | M9078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with microtubules, filaments composed of tubulin monomers. [GOC:krc]
Full description |

Standard name | GO_PROTEIN_C_TERMINUS_BINDING
Systematic name | M19293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein C-terminus, the end of any peptide chain at which the 1-carboxyl function of a constituent amino acid is not attached in peptide linkage to another amino-acid residue. [ISBN:0198506732]
Full description |

Standard name | GO_MONOCARBOXYLIC_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18805
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of monocarboxylic acids from one side of a membrane to the other. A monocarboxylic acid is an organic acid with one COOH group. [GOC:ai]
Full description |

Standard name | GO_HIGH_DENSITY_LIPOPROTEIN_PARTICLE_BINDING
Systematic name | M26272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with high-density lipoprotein particle, a lipoprotein particle with a high density (typically 1.063-1.21 g/ml) and a diameter of 5-10 nm that contains APOAs and may contain APOCs and APOE. [GOC:mah]
Full description |

Standard name | GO_AXON_GUIDANCE_RECEPTOR_ACTIVITY
Systematic name | M26273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an extracellular messenger and transmitting the signal from one side of the membrane to the other to results in a change in cellular activity involved in axon guidance. [GOC:dph, GOC:signaling, GOC:tb, PMID:15107857, PMID:15339666]
Full description |

Standard name | GO_ENZYME_ACTIVATOR_ACTIVITY
Systematic name | M18481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and increases the activity of an enzyme. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_CALCIUM_SENSITIVE_GUANYLATE_CYCLASE_ACTIVATOR_ACTIVITY
Systematic name | M26274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and increases the activity of guanylate cyclase in response to a change in calcium ion concentration. [GOC:mah]
Full description |

Standard name | GO_CHITIN_BINDING
Systematic name | M26275
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with chitin, a linear polysaccharide consisting of beta-(1->4)-linked N-acetyl-D-glucosamine residues. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_GLUTAMATE_RECEPTOR_ACTIVITY
Systematic name | M18783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with glutamate and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:ai, GOC:signaling]
Full description |

Standard name | GO_TRANSLATION_TERMINATION_FACTOR_ACTIVITY
Systematic name | M26276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Functions in the termination of translation. [GOC:ma]
Full description |

Standard name | GO_N_ACETYLTRANSFERASE_ACTIVITY
Systematic name | M19169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acetyl group to a nitrogen atom on the acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_PHOSPHORIC_DIESTER_HYDROLASE_ACTIVITY
Systematic name | M18226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a phosphodiester to give a phosphomonoester and a free hydroxyl group. [EC:3.1.4, GOC:curators]
Full description |

Standard name | GO_GROWTH_FACTOR_ACTIVITY
Systematic name | M11386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The function that stimulates a cell to grow or proliferate. Most growth factors have other actions besides the induction of cell growth or proliferation. [ISBN:0815316194]
Full description |

Standard name | GO_CYTOSKELETAL_PROTEIN_BINDING
Systematic name | M18503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any protein component of any cytoskeleton (actin, microtubule, or intermediate filament cytoskeleton). [GOC:mah]
Full description |

Standard name | GO_CYTOSKELETAL_ANCHOR_ACTIVITY
Systematic name | M18023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding activity of a protein that brings together a cytoskeletal protein (either a microtubule or actin filament, spindle pole body, or protein directly bound to them) and one or more other molecules, permitting them to function in a coordinated way. [GOC:mtg_MIT_16mar07, PMID:30323238]
Full description |

Standard name | GO_DNA_DEPENDENT_ATPASE_ACTIVITY
Systematic name | M18727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate; this reaction requires the presence of single- or double-stranded DNA, and it drives another reaction. [GOC:jl]
Full description |

Standard name | GO_5S_RRNA_BINDING
Systematic name | M26277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with 5S ribosomal RNA, the smallest RNA constituent of a ribosome. [GOC:jl, ISBN:0321000382]
Full description |

Standard name | GO_ALCOHOL_DEHYDROGENASE_NADPPLUS_ACTIVITY
Systematic name | M26278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an alcohol + NADP+ = an aldehyde + NADPH + H+. [EC:1.1.1.2]
Full description |

Standard name | GO_ACETYLESTERASE_ACTIVITY
Systematic name | M34390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an acetic ester + H2O = an alcohol + acetate. [EC:3.1.1.6]
Full description |

Standard name | GO_PRIMARY_AMINE_OXIDASE_ACTIVITY
Systematic name | M26279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a primary amine + H2O + O2 = an aldehyde + NH3 + hydrogen peroxide. [EC:1.4.3.21, EC:1.4.3.22, EC:1.4.3.4, MetaCyc:RXN-9597]
Full description |

Standard name | GO_TRANSCRIPTION_FACTOR_BINDING
Systematic name | M18797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a transcription factor, a protein required to initiate or regulate transcription. [ISBN:0198506732]
Full description |

Standard name | GO_TRANSLATION_FACTOR_ACTIVITY_RNA_BINDING
Systematic name | M14882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Functions during translation by interacting selectively and non-covalently with RNA during polypeptide synthesis at the ribosome. [GOC:ai, GOC:vw]
Full description |

Standard name | GO_PROTEIN_TYROSINE_SERINE_THREONINE_PHOSPHATASE_ACTIVITY
Systematic name | M18402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reactions: protein serine + H2O = protein serine + phosphate; protein threonine phosphate + H2O = protein threonine + phosphate; and protein tyrosine phosphate + H2O = protein tyrosine + phosphate. [GOC:mah]
Full description |

Standard name | GO_NUCLEAR_LOCALIZATION_SEQUENCE_BINDING
Systematic name | M18380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a nuclear localization sequence, a specific peptide sequence that acts as a signal to localize the protein within the nucleus. [GOC:ai]
Full description |

Standard name | GO_CAMP_RESPONSE_ELEMENT_BINDING_PROTEIN_BINDING
Systematic name | M26280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a cAMP response element binding protein (a CREB protein). [GOC:mah]
Full description |

Standard name | GO_OXYSTEROL_BINDING
Systematic name | M26281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with oxysterol, an oxidized form of cholesterol. [GOC:curators]
Full description |

Standard name | GO_POLY_A_BINDING
Systematic name | M18049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a sequence of adenylyl residues in an RNA molecule, such as the poly(A) tail, a sequence of adenylyl residues at the 3' end of eukaryotic mRNA. [GOC:jl]
Full description |

Standard name | GO_DRUG_BINDING
Systematic name | M18602
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a drug, any naturally occurring or synthetic substance, other than a nutrient, that, when administered or applied to an organism, affects the structure or functioning of the organism; in particular, any such substance used in the diagnosis, prevention, or treatment of disease. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_SULFOTRANSFERASE_ACTIVITY
Systematic name | M5179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a sulfate group from 3'-phosphoadenosine 5'-phosphosulfate to the hydroxyl group of an acceptor, producing the sulfated derivative and 3'-phosphoadenosine 5'-phosphate. [EC:2.8.2, GOC:curators]
Full description |

Standard name | GO_PROTEIN_PHOSPHATASE_1_BINDING
Systematic name | M18695
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the enzyme protein phosphatase 1. [GOC:jl]
Full description |

Standard name | GO_C_METHYLTRANSFERASE_ACTIVITY
Systematic name | M34391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group to the carbon atom of an acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_N_METHYLTRANSFERASE_ACTIVITY
Systematic name | M18119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group to the nitrogen atom of an acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_O_METHYLTRANSFERASE_ACTIVITY
Systematic name | M18335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group to the oxygen atom of an acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_S_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group to the sulfur atom of an acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_RNA_METHYLTRANSFERASE_ACTIVITY
Systematic name | M17928
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group from a donor to a nucleoside residue in an RNA molecule. [GOC:mah]
Full description |

Standard name | GO_MRNA_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group from S-adenosyl-L-methionine to a nucleoside residue in an mRNA molecule. [GOC:mah]
Full description |

Standard name | GO_TRNA_METHYLTRANSFERASE_ACTIVITY
Systematic name | M19112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group from a donor to a nucleoside residue in a tRNA molecule. [GOC:mah]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_BINDING
Systematic name | M26284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the enzyme adenylate cyclase. [GOC:jl]
Full description |

Standard name | GO_RNA_DEPENDENT_ATPASE_ACTIVITY
Systematic name | M29454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate; this reaction requires the presence of RNA, and it drives another reaction. [GOC:jl]
Full description |

Standard name | GO_POLY_PYRIMIDINE_TRACT_BINDING
Systematic name | M18112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any stretch of pyrimidines (cytosine or uracil) in an RNA molecule. [GOC:jl]
Full description |

Standard name | GO_NEUROPEPTIDE_RECEPTOR_ACTIVITY
Systematic name | M726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a neuropeptide to initiate a change in cell activity. [GOC:ai]
Full description |

Standard name | GO_EUKARYOTIC_INITIATION_FACTOR_4E_BINDING
Systematic name | M26285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with eukaryotic initiation factor 4E, a polypeptide factor involved in the initiation of ribosome-mediated translation. [ISBN:0198506732]
Full description |

Standard name | GO_METALLOENDOPEPTIDASE_INHIBITOR_ACTIVITY
Systematic name | M19121
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of metalloendopeptidases, enzymes that catalyze the hydrolysis of nonterminal peptide bonds in a polypeptide chain and contain a chelated metal ion at their active sites which is essential to their catalytic activity. [GOC:ai]
Full description |

Standard name | GO_UDP_GLYCOSYLTRANSFERASE_ACTIVITY
Systematic name | M18680
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a glycosyl group from a UDP-sugar to a small hydrophobic molecule. [InterPro:IPR004224, PMID:11846783]
Full description |

Standard name | GO_PHOSPHATIDATE_PHOSPHATASE_ACTIVITY
Systematic name | M19108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a 1,2-diacylglycerol 3-phosphate + H2O = a 1,2-diacyl-sn-glycerol + phosphate. [EC:3.1.3.4, GOC:pr]
Full description |

Standard name | GO_FERROUS_IRON_BINDING
Systematic name | M18571
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with ferrous iron, Fe(II). [GOC:ai]
Full description |

Standard name | GO_FERRIC_IRON_BINDING
Systematic name | M26286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with ferric iron, Fe(III). [GOC:ai]
Full description |

Standard name | GO_HEPARIN_BINDING
Systematic name | M15815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with heparin, any member of a group of glycosaminoglycans found mainly as an intracellular component of mast cells and which consist predominantly of alternating alpha-(1->4)-linked D-galactose and N-acetyl-D-glucosamine-6-sulfate residues. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_AMINE_RECEPTOR_ACTIVITY
Systematic name | M18316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an extracellular amine and transmitting the signal across the membrane by activating an associated G-protein; promotes the exchange of GDP for GTP on the alpha subunit of a heterotrimeric G-protein complex. [GOC:bf, GOC:dph]
Full description |

Standard name | GO_PEPTIDASE_ACTIVITY
Systematic name | M18200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a peptide bond. A peptide bond is a covalent bond formed when the carbon atom from the carboxyl group of one amino acid shares electrons with the nitrogen atom from the amino group of a second amino acid. [GOC:jl, ISBN:0815332181]
Full description |

Standard name | GO_CYSTEINE_TYPE_PEPTIDASE_ACTIVITY
Systematic name | M1297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of peptide bonds in a polypeptide chain by a mechanism in which the sulfhydryl group of a cysteine residue at the active center acts as a nucleophile. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE]
Full description |

Standard name | GO_METALLOEXOPEPTIDASE_ACTIVITY
Systematic name | M18163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a peptide bond not more than three residues from the N- or C-terminus of a polypeptide chain by a mechanism in which water acts as a nucleophile, one or two metal ions hold the water molecule in place, and charged amino acid side chains are ligands for the metal ions. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE, http://merops.sanger.ac.uk/about/glossary.htm#EXOPEPTIDASE]
Full description |

Standard name | GO_METALLOPEPTIDASE_ACTIVITY
Systematic name | M10611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of peptide bonds by a mechanism in which water acts as a nucleophile, one or two metal ions hold the water molecule in place, and charged amino acid side chains are ligands for the metal ions. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE]
Full description |

Standard name | GO_EXOPEPTIDASE_ACTIVITY
Systematic name | M18845
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a peptide bond not more than three residues from the N- or C-terminus of a polypeptide chain, in a reaction that requires a free N-terminal amino group, C-terminal carboxyl group or both. [http://merops.sanger.ac.uk/about/glossary.htm#EXOPEPTIDASE]
Full description |

Standard name | GO_DIPEPTIDYL_PEPTIDASE_ACTIVITY
Systematic name | M18309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of N-terminal dipeptides from a polypeptide chain. [GOC:mb]
Full description |

Standard name | GO_OMEGA_PEPTIDASE_ACTIVITY
Systematic name | M18512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of non-standard peptide bonds releasing substituted amino acids such as pyroglutamate or cleave isopeptide bonds, such as many deubiquitinating enzymes. [EC:3.4.19.-, PMID:20157488, PMID:9920379]
Full description |

Standard name | GO_TRNA_SPECIFIC_ADENOSINE_DEAMINASE_ACTIVITY
Systematic name | M26287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: adenosine + H2O = inosine + NH3, in a tRNA molecule. [GOC:mah]
Full description |

Standard name | GO_NUCLEOTIDASE_ACTIVITY
Systematic name | M18344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a nucleotide + H2O = a nucleoside + phosphate. [EC:3.1.3.31]
Full description |

Standard name | GO_ZINC_ION_BINDING
Systematic name | M18582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with zinc (Zn) ions. [GOC:ai]
Full description |

Standard name | GO_SECONDARY_ACTIVE_SULFATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the secondary active transfer of sulfate from one side of a membrane to the other. Secondary active transport is the transfer of a solute across a membrane, up its concentration gradient. The transporter binds the solute and undergoes a series of conformational changes. Transport works equally well in either direction and is driven by a chemiosmotic source of energy. Secondary active transporters include symporters and antiporters. [GOC:mtg_transport]
Full description |

Standard name | GO_CALCIUM_POTASSIUM_SODIUM_ANTIPORTER_ACTIVITY
Systematic name | M26289
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: Ca2+(in) + K+(in) + Na+(out) = Ca2+(out) + K+(out) + Na+(in). [TC:2.A.19.4.1]
Full description |

Standard name | GO_PROTEIN_METHYLTRANSFERASE_ACTIVITY
Systematic name | M18389
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group (CH3-) to a protein. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_LIPID_BINDING
Systematic name | M18981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a lipid. [GOC:ai]
Full description |

Standard name | GO_3_5_EXODEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M26290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the sequential cleavage of mononucleotides from a free 3' terminus of a DNA molecule. [GOC:mah]
Full description |

Standard name | GO_SINGLE_STRANDED_DNA_EXODEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M26291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the sequential cleavage of mononucleotides from a free 5' or 3' terminus of a single-stranded DNA molecule. [GOC:mah]
Full description |

Standard name | GO_DNA_BINDING_BENDING
Systematic name | M17927
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The activity of binding selectively and non-covalently to and distorting the original structure of DNA, typically a straight helix, into a bend, or increasing the bend if the original structure was intrinsically bent due to its sequence. [GOC:krc, GOC:vw, PMID:10710711, PMID:19037758]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_MUSCLE
Systematic name | M15145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of a muscle fiber. [GOC:mah]
Full description |

Standard name | GO_VOLTAGE_GATED_ANION_CHANNEL_ACTIVITY
Systematic name | M17947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an anion by a voltage-gated channel. An anion is a negatively charged ion. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:mtg_transport, GOC:vw, ISBN:0815340729]
Full description |

Standard name | GO_SINGLE_STRANDED_DNA_3_5_EXODEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M26292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the sequential cleavage of mononucleotides from a free 3' terminus of a single-stranded DNA molecule. [GOC:mah, PMID:22562358]
Full description |

Standard name | GO_7S_RNA_BINDING
Systematic name | M26293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with 7S RNA, the RNA component of the signal recognition particle (SRP). [GOC:jl, PMID:6181418]
Full description |

Standard name | GO_PROTEIN_PRENYLTRANSFERASE_ACTIVITY
Systematic name | M26294
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the covalent addition of an isoprenoid group such as a farnesyl or geranylgeranyl group via thioether linkages to a cysteine residue in a protein. [GOC:mah]
Full description |

Standard name | GO_CATION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of cation from one side of a membrane to the other. [GOC:dgf, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_METHYL_CPG_BINDING
Systematic name | M18943
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a methylated cytosine/guanine dinucleotide. [GOC:jl, PMID:11746232]
Full description |

Standard name | GO_PROTEIN_TYROSINE_THREONINE_PHOSPHATASE_ACTIVITY
Systematic name | M34393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reactions: protein threonine phosphate + H2O = protein threonine + phosphate; and protein tyrosine phosphate + H2O = protein tyrosine + phosphate. [GOC:mah]
Full description |

Standard name | GO_HIGH_VOLTAGE_GATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M19060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a calcium ion by a high voltage-gated channel. A high voltage-gated channel is a channel whose open state is dependent on high voltage across the membrane in which it is embedded. [GOC:mtg_transport, ISBN:0815340729, PMID:16382099]
Full description |

Standard name | GO_RNA_POLYMERASE_II_CTD_HEPTAPEPTIDE_REPEAT_KINASE_ACTIVITY
Systematic name | M26295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + (DNA-directed RNA polymerase II) = ADP + phospho-(DNA-directed RNA polymerase II); phosphorylation occurs on residues in the carboxy-terminal domain (CTD) repeats. [EC:2.7.11.23, GOC:mah]
Full description |

Standard name | GO_SIALYLTRANSFERASE_ACTIVITY
Systematic name | M26296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of sialic acid to an acceptor molecule, typically the terminal portions of the sialylated glycolipids (gangliosides) or to the N- or O-linked sugar chains of glycoproteins. [GOC:cjm, PMID:26192491, Wikipedia:Sialyltransferase]
Full description |

Standard name | GO_O_ACYLTRANSFERASE_ACTIVITY
Systematic name | M18606
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acyl group to an oxygen atom on the acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_ACETYLGLUCOSAMINYLTRANSFERASE_ACTIVITY
Systematic name | M18865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an N-acetylglucosaminyl residue from UDP-N-acetyl-glucosamine to a sugar. [ISBN:0198506732]
Full description |

Standard name | GO_ACETYLGALACTOSAMINYLTRANSFERASE_ACTIVITY
Systematic name | M17878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an N-acetylgalactosaminyl residue from UDP-N-acetyl-galactosamine to an oligosaccharide. [ISBN:0198506732]
Full description |

Standard name | GO_GALACTOSYLTRANSFERASE_ACTIVITY
Systematic name | M18584
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a galactosyl group to an acceptor molecule, typically another carbohydrate or a lipid. [ISBN:0198506732]
Full description |

Standard name | GO_THIOREDOXIN_PEROXIDASE_ACTIVITY
Systematic name | M26297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: thioredoxin + hydrogen peroxide = thioredoxin disulfide + H2O. [MetaCyc:RXN0-267]
Full description |

Standard name | GO_MECHANOSENSITIVE_ION_CHANNEL_ACTIVITY
Systematic name | M26298
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an ion by a channel that opens in response to a mechanical stress. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_ARACHIDONIC_ACID_MONOOXYGENASE_ACTIVITY
Systematic name | M19168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the incorporation of one atom from molecular oxygen into arachidonic acid and the reduction of the other atom of oxygen to water. [GOC:mah]
Full description |

Standard name | GO_ARACHIDONIC_ACID_EPOXYGENASE_ACTIVITY
Systematic name | M34394
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an NADPH- and oxygen-dependent reaction that converts arachidonic acid to a cis-epoxyeicosatrienoic acid. [http://lipidlibrary.aocs.org/Lipids/eic_hete/index.htm, PMID:10681399]
Full description |

Standard name | GO_STEROID_HYDROXYLASE_ACTIVITY
Systematic name | M18916
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the formation of a hydroxyl group on a steroid by incorporation of oxygen from O2. [ISBN:0721662544]
Full description |

Standard name | GO_RETINOIC_ACID_4_HYDROXYLASE_ACTIVITY
Systematic name | M29455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the conversion of retinoic acid to 4-hydroxy-retinoic acid. [PMID:19519282, PMID:9250660]
Full description |

Standard name | GO_3_5_EXONUCLEASE_ACTIVITY
Systematic name | M18526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within nucleic acids by removing nucleotide residues from the 3' end. [GOC:ai]
Full description |

Standard name | GO_5_3_EXONUCLEASE_ACTIVITY
Systematic name | M17852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within nucleic acids by removing nucleotide residues from the 5' end. [GOC:ai]
Full description |

Standard name | GO_COA_TRANSFERASE_ACTIVITY
Systematic name | M29456
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a coenzyme A (CoA) group from one compound (donor) to another (acceptor). [GOC:jl]
Full description |

Standard name | GO_FUCOSYLTRANSFERASE_ACTIVITY
Systematic name | M18847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a fucosyl group to an acceptor molecule, typically another carbohydrate or a lipid. [GOC:ai]
Full description |

Standard name | GO_RNA_POLYMERASE_II_CTD_HEPTAPEPTIDE_REPEAT_PHOSPHATASE_ACTIVITY
Systematic name | M26299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: phospho-(DNA-directed RNA polymerase II) + H2O = (DNA-directed RNA polymerase II) + phosphate. [PMID:22622228]
Full description |

Standard name | GO_BETA_GLUCOSIDASE_ACTIVITY
Systematic name | M26300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of terminal, non-reducing beta-D-glucose residues with release of beta-D-glucose. [EC:3.2.1.21]
Full description |

Standard name | GO_PHOSPHATIDYLETHANOLAMINE_BINDING
Systematic name | M26301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylethanolamine, any of a class of glycerophospholipids in which a phosphatidyl group is esterified to the hydroxyl group of ethanolamine. [ISBN:0198506732]
Full description |

Standard name | GO_SELENIUM_BINDING
Systematic name | M26302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with selenium (Se). [GOC:ai]
Full description |

Standard name | GO_JUN_KINASE_BINDING
Systematic name | M26303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with JUN kinase, an enzyme that catalyzes the phosphorylation and activation of members of the JUN family. [GOC:jl]
Full description |

Standard name | GO_PHOSPHOFRUCTOKINASE_ACTIVITY
Systematic name | M26304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphate group, usually from ATP, to a phosphofructose substrate molecule. [GOC:jl]
Full description |

Standard name | GO_HEPARAN_SULFATE_GLUCOSAMINE_3_SULFOTRANSFERASE_1_ACTIVITY
Systematic name | M26305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 3'-phosphoadenylyl sulfate + [heparan sulfate]-glucosamine = adenosine 3',5'-bisphosphate + [heparan sulfate]-glucosamine 3-sulfate. The [heparan sulfate]-glucosamine 3-sulfate has a substrate consensus sequence of Glc(N2S>NAc)+/-6S GlcA GlcN2S*+/-6S GlcA>IdoA+/-2S Glc(N2S/NAc)+/-6S. [EC:2.8.2.23]
Full description |

Standard name | GO_HISTONE_ARGININE_N_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + (histone)-arginine = S-adenosyl-L-homocysteine + (histone)-N-methyl-arginine. [PMID:8002954]
Full description |

Standard name | GO_PALMITOYL_PROTEIN_HYDROLASE_ACTIVITY
Systematic name | M26307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: palmitoyl-protein + H2O = palmitate + protein. [EC:3.1.2.22]
Full description |

Standard name | GO_SULFURIC_ESTER_HYDROLASE_ACTIVITY
Systematic name | M18875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: RSO-R' + H2O = RSOOH + R'H. This reaction is the hydrolysis of any sulfuric ester bond, any ester formed from sulfuric acid, O=SO(OH)2. [GOC:ai]
Full description |

Standard name | GO_TRANSLATION_ACTIVATOR_ACTIVITY
Systematic name | M26309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Any of a group of soluble proteins functioning in the activation of ribosome-mediated translation of mRNA into a polypeptide. [GOC:ai]
Full description |

Standard name | GO_UDP_GALACTOSE_BETA_N_ACETYLGLUCOSAMINE_BETA_1_3_GALACTOSYLTRANSFERASE_ACTIVITY
Systematic name | M26310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: UDP-galactose + N-acetylglucosamine = galactose-beta-1,3-N-acetylglucosamine + UDP. [PMID:10212226]
Full description |

Standard name | GO_BENZODIAZEPINE_RECEPTOR_ACTIVITY
Systematic name | M26311
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with benzodiazepines, a class of drugs with hypnotic, anxiolytic, anticonvulsive, amnestic and myorelaxant properties, to initiate a change in cell activity. [GOC:jl]
Full description |

Standard name | GO_MONOAMINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of monoamines, organic compounds that contain one amino group that is connected to an aromatic ring by an ethylene group (-CH2-CH2-), from one side of a membrane to the other. [GOC:mah]
Full description |

Standard name | GO_BILE_ACID_SODIUM_SYMPORTER_ACTIVITY
Systematic name | M29457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: bile acid(out) + Na+(out) = bile acid(in) + Na+(in). [TC:2.A.28.-.-]
Full description |

Standard name | GO_ANION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a negatively charged ion from one side of a membrane to the other. [GOC:dgf, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_ORGANIC_ANION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of organic anions from one side of a membrane to the other. Organic anions are atoms or small molecules with a negative charge which contain carbon in covalent linkage. [GOC:ai]
Full description |

Standard name | GO_AMMONIUM_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of ammonium from one side of a membrane to the other. Ammonium is the cation NH4+ which is formed from N2 by root-nodule bacteria in leguminous plants and is an excretory product in ammonotelic animals. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHATIDYLCHOLINE_TRANSPORTER_ACTIVITY
Systematic name | M26314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the directed movement of phosphatidylcholine into, out of or within a cell, or between cells. Phosphatidylcholine refers to a class of glycerophospholipids in which the phosphatidyl group is esterified to the hydroxyl group of choline. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_TRANSFER_ACTIVITY
Systematic name | M26315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Removes phosphatidylinositol from a membrane or a monolayer lipid particle, transports it through the aqueous phase while protected in a hydrophobic pocket, and brings it to an acceptor membrane or lipid particle. [GOC:krc, PMID:20823909, PMID:24220498, PMID:25797198]
Full description |

Standard name | GO_TASTE_RECEPTOR_ACTIVITY
Systematic name | M18738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with soluble compounds to initiate a change in cell activity. These receptors are responsible for the sense of taste. [GOC:dph]
Full description |

Standard name | GO_N_ACETYLLACTOSAMINIDE_BETA_1_3_N_ACETYLGLUCOSAMINYLTRANSFERASE_ACTIVITY
Systematic name | M26316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: UDP-N-acetyl-D-glucosamine + beta-D-galactosyl-1,4-N-acetyl-D-glucosaminyl-R = UDP + N-acetyl-beta-D-glucosaminyl-1,3-beta-D-galactosyl-1,4-N-acetyl-D-glucosaminyl-R. [EC:2.4.1.149]
Full description |

Standard name | GO_RAN_GTPASE_BINDING
Systematic name | M18194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with Ran, a conserved Ras-like GTP-binding protein, implicated in nucleocytoplasmic transport, cell cycle progression, spindle assembly, nuclear organization and nuclear envelope (NE) assembly. [GOC:rn, PMID:12787777, PMID:14726649]
Full description |

Standard name | GO_PROTON_EXPORTING_ATPASE_ACTIVITY_PHOSPHORYLATIVE_MECHANISM
Systematic name | M26317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of protons from one side of a membrane to the other according to the reaction: ATP + H2O + H+(in) -> ADP + phosphate + H+(out). These transporters use a phosphorylative mechanism, which have a phosphorylated intermediate state during the ion transport cycle. [EC:7.1.2.1]
Full description |

Standard name | GO_SODIUM_TRANSMEMBRANE_TRANSPORTER_ACTIVITY_PHOSPHORYLATIVE_MECHANISM
Systematic name | M29458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: ATP + H2O + Na+(in) -> ADP + phosphate + Na+(out); by a phosphorylative mechanism. [EC:7.2.2.3]
Full description |

Standard name | GO_ATPASE_COUPLED_XENOBIOTIC_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O + xenobiotic(in) = ADP + phosphate + xenobiotic(out). [EC:7.6.2.2]
Full description |

Standard name | GO_MICROTUBULE_SEVERING_ATPASE_ACTIVITY
Systematic name | M18318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate. Catalysis of the severing of a microtubule at a specific spot along its length, coupled to the hydrolysis of ATP. [EC:5.6.1.1, PMID:10910766]
Full description |

Standard name | GO_ATP_DEPENDENT_MICROTUBULE_MOTOR_ACTIVITY_MINUS_END_DIRECTED
Systematic name | M26318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of movement along a microtubule toward the minus end, coupled to the hydrolysis of ATP. [EC:5.6.1.4, GOC:mah, GOC:vw]
Full description |

Standard name | GO_ATP_DEPENDENT_MICROTUBULE_MOTOR_ACTIVITY_PLUS_END_DIRECTED
Systematic name | M26319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of movement along a microtubule toward the plus end, coupled to the hydrolysis of ATP. [EC:5.6.1.3, GOC:vw]
Full description |

Standard name | GO_CAMP_DEPENDENT_PROTEIN_KINASE_REGULATOR_ACTIVITY
Systematic name | M26320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulation of the activity of the enzyme cAMP-dependent protein kinase. [GOC:ai]
Full description |

Standard name | GO_UBIQUITIN_LIKE_MODIFIER_ACTIVATING_ENZYME_ACTIVITY
Systematic name | M26321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the activation of small proteins, such as ubiquitin or ubiquitin-like proteins, through the formation of an ATP-dependent high-energy thiolester bond. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_S_ADENOSYLMETHIONINE_DEPENDENT_METHYLTRANSFERASE_ACTIVITY
Systematic name | M18785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group from S-adenosyl-L-methionine to a substrate. [GOC:mah]
Full description |

Standard name | GO_CROSSOVER_JUNCTION_ENDODEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M26323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the endonucleolytic cleavage at a junction such as a reciprocal single-stranded crossover between two homologous DNA duplexes (Holliday junction). [EC:3.1.22.4]
Full description |

Standard name | GO_PHOSPHOLIPASE_A1_ACTIVITY
Systematic name | M26325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: phosphatidylcholine + H2O = 2-acylglycerophosphocholine + a carboxylate. [EC:3.1.1.32]
Full description |

Standard name | GO_DNA_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group to a DNA molecule. [GOC:jl, ISBN:0198506732, PMID:7862522]
Full description |

Standard name | GO_ELECTRON_TRANSFER_ACTIVITY
Systematic name | M5558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Any molecular entity that serves as an electron acceptor and electron donor in an electron transport chain. An electron transport chain is a process in which a series of electron carriers operate together to transfer electrons from donors to any of several different terminal electron acceptors to generate a transmembrane electrochemical gradient. [ISBN:0198506732]
Full description |

Standard name | GO_BIOTIN_BINDING
Systematic name | M26328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with biotin (cis-tetrahydro-2-oxothieno(3,4-d)imidazoline-4-valeric acid), the (+) enantiomer of which is very widely distributed in cells and serves as a carrier in a number of enzymatic beta-carboxylation reactions. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_FOUR_WAY_JUNCTION_HELICASE_ACTIVITY
Systematic name | M26329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate, where this reaction drives the unwinding of the DNA helix of DNA containing four-way junctions, including Holliday junctions. [GOC:al, PMID:22723423, PMID:9442895]
Full description |

Standard name | GO_PYROPHOSPHATE_HYDROLYSIS_DRIVEN_PROTON_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M29459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transport of one proton (H+), driven by the hydrolysis of pyrophosphate, and generating a proton motive force. [GOC:mtg_transport, ISBN:0815340729, Wikipedia:Proton-pumping_pyrophosphatase]
Full description |

Standard name | GO_PHOTORECEPTOR_ACTIVITY
Systematic name | M18022
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The function of absorbing and responding to incidental electromagnetic radiation, particularly visible light. The response may involve a change in conformation. [GOC:ai, GOC:go_curators]
Full description |

Standard name | GO_CYCLASE_ACTIVITY
Systematic name | M17913
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of a ring closure reaction. [ISBN:0198547684]
Full description |

Standard name | GO_PSEUDOURIDINE_SYNTHASE_ACTIVITY
Systematic name | M18210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: RNA uridine = RNA pseudouridine. Conversion of uridine in an RNA molecule to pseudouridine by rotation of the C1'-N-1 glycosidic bond of uridine in RNA to a C1'-C5. [GOC:mah]
Full description |

Standard name | GO_FMN_BINDING
Systematic name | M18037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with flavin mono nucleotide. Flavin mono nucleotide (FMN) is the coenzyme or the prosthetic group of various flavoprotein oxidoreductase enzymes. [GOC:tb]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_5_PHOSPHATE_BINDING
Systematic name | M18014
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylinositol-5-phosphate, a derivative of phosphatidylinositol in which the inositol ring is phosphorylated at the 5' position. [GOC:bf, GOC:tair_curators]
Full description |

Standard name | GO_DOUBLE_STRANDED_METHYLATED_DNA_BINDING
Systematic name | M26330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with double-stranded methylated DNA. Methylation of cytosine or adenine in DNA is an important mechanism for establishing stable heritable epigenetic marks. [GOC:imk, PMID:17242155]
Full description |

Standard name | GO_H3_HISTONE_ACETYLTRANSFERASE_ACTIVITY
Systematic name | M29460
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acetyl-CoA + histone H3 = CoA + acetyl-histone H3. [EC:2.3.1.48]
Full description |

Standard name | GO_H4_HISTONE_ACETYLTRANSFERASE_ACTIVITY
Systematic name | M18323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acetyl-CoA + histone H4 = CoA + acetyl-histone H4. [EC:2.3.1.48]
Full description |

Standard name | GO_CYCLASE_REGULATOR_ACTIVITY
Systematic name | M26331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of an enzyme that catalyzes a ring closure reaction. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_ADENYLATE_CYCLASE_ACTIVATOR_ACTIVITY
Systematic name | M26332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Increases the activity of the enzyme that catalyzes the reaction: ATP = 3',5'-cyclic AMP + diphosphate. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_CALCIUM_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M18871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a protein + ATP = a phosphoprotein + ADP. This reaction requires the presence of calcium. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_ANAPHASE_PROMOTING_COMPLEX_BINDING
Systematic name | M26333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an anaphase-promoting complex. A ubiquitin ligase complex that degrades mitotic cyclins and anaphase inhibitory protein, thereby triggering sister chromatid separation and exit from mitosis. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_GLUCURONOSYLTRANSFERASE_ACTIVITY
Systematic name | M18654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: UDP-glucuronate + acceptor = UDP + acceptor beta-D-glucuronoside. [EC:2.4.1.17]
Full description |

Standard name | GO_CORECEPTOR_ACTIVITY
Systematic name | M18700
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an extracellular or intracellular messenger, and in cooperation with a nearby primary receptor, initiating a change in cell activity. [GOC:go_curators]
Full description |

Standard name | GO_PROTEIN_DISULFIDE_OXIDOREDUCTASE_ACTIVITY
Systematic name | M18541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a protein with reduced sulfide groups = a protein with oxidized disulfide bonds. [MetaCyc:DISULFOXRED-RXN]
Full description |

Standard name | GO_DISULFIDE_OXIDOREDUCTASE_ACTIVITY
Systematic name | M18223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: substrate with reduced sulfide groups = substrate with oxidized disulfide bonds. [MetaCyc:DISULFOXRED-RXN]
Full description |

Standard name | GO_PEPTIDE_DISULFIDE_OXIDOREDUCTASE_ACTIVITY
Systematic name | M26334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a peptide with reduced sulfide groups = a peptide with oxidized disulfide bonds. [GOC:mah, MetaCyc:DISULFOXRED-RXN]
Full description |

Standard name | GO_GLUTATHIONE_DISULFIDE_OXIDOREDUCTASE_ACTIVITY
Systematic name | M26335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 2 glutathione + electron acceptor = glutathione disulfide + electron donor. [GOC:mah]
Full description |

Standard name | GO_THROMBIN_ACTIVATED_RECEPTOR_ACTIVITY
Systematic name | M26336
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A G protein-coupled receptor activity that is activated by cleavage by thrombin, which exposes a tethered ligand corresponding to the new N-terminus, which binds to the receptor and activates it. [GOC:ai, GOC:pg, PMID:20423334]
Full description |

Standard name | GO_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of an ion from one side of a membrane to the other. [GOC:dgf, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_MONOVALENT_INORGANIC_CATION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M12686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a inorganic cations with a valency of one from one side of a membrane to the other. Inorganic cations are atoms or small molecules with a positive charge that do not contain carbon in covalent linkage. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_PROTON_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M14042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a proton from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_POTASSIUM_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of potassium ions (K+) from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_SODIUM_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M19223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of sodium ions (Na+) from one side of a membrane to the other. [GOC:ai, GOC:BHF]
Full description |

Standard name | GO_CALCIUM_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of calcium (Ca) ions from one side of a membrane to the other. [GOC:dgf]
Full description |

Standard name | GO_MAGNESIUM_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of magnesium (Mg) ions from one side of a membrane to the other. [GOC:dgf]
Full description |

Standard name | GO_ORGANIC_CATION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of organic cations from one side of a membrane to the other. Organic cations are atoms or small molecules with a positive charge that contain carbon in covalent linkage. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_INORGANIC_ANION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of inorganic anions from one side of a membrane to the other. Inorganic anions are atoms or small molecules with a negative charge which do not contain carbon in covalent linkage. [GOC:ai]
Full description |

Standard name | GO_BICARBONATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of bicarbonate from one side of a membrane to the other. Bicarbonate is the hydrogencarbonate ion, HCO3-. [GOC:ai]
Full description |

Standard name | GO_CHLORIDE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of chloride ions from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_PHOSPHATE_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of phosphate (PO4 3-) ions from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_SULFATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of sulfate ions, SO4(2-), from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_BILE_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of bile acid from one side of a membrane to the other. Bile acids are any of a group of steroid carboxylic acids occurring in bile, where they are present as the sodium salts of their amides with glycine or taurine. [GOC:ai]
Full description |

Standard name | GO_LACTATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of lactate from one side of a membrane to the other. Lactate is 2-hydroxypropanoate, CH3-CHOH-COOH; L(+)-lactate is formed by anaerobic glycolysis in animal tissues, and DL-lactate is found in sour milk, molasses and certain fruit juices. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_SIALIC_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of sialic acid from one side of a membrane to the other. [GOC:jl, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_SUCCINATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of succinate, the dianion of ethane dicarboxylic acid, from one side of a membrane to the other. [ISBN:0198506732]
Full description |

Standard name | GO_CARBOHYDRATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of carbohydrate from one side of a membrane to the other. [GOC:jl, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_HEXOSE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a hexose sugar, a monosaccharide with 6 carbon atoms, from one side of a membrane to the other. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOTIDE_SUGAR_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M29462
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a pyrimidine nucleotide-sugar from one side of a membrane to the other. Pyrimidine nucleotide-sugars are pyrimidine nucleotides in glycosidic linkage with a monosaccharide or monosaccharide derivative. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_POLYOL_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a polyol from one side of a membrane to the other. A polyol is any polyhydric alcohol. [ISBN:0198506732]
Full description |

Standard name | GO_GLYCEROL_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of glycerol from one side of a membrane to the other. Glycerol is 1,2,3-propanetriol, a sweet, hygroscopic, viscous liquid, widely distributed in nature as a constituent of many lipids. [GOC:ai]
Full description |

Standard name | GO_AMINO_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of amino acids from one side of a membrane to the other. Amino acids are organic molecules that contain an amino group and a carboxyl group. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_ACIDIC_AMINO_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of acidic amino acids from one side of a membrane to the other. Acidic amino acids have side chains with a negative charge at pH 7.3. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_AROMATIC_AMINO_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of aromatic amino acids from one side of a membrane to the other. Aromatic amino acids have an aromatic ring. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_BASIC_AMINO_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of basic amino acids from one side of a membrane to the other. Basic amino acids have side chains with a positive charge at pH 7.3. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_NEUTRAL_AMINO_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of neutral amino acids from one side of a membrane to the other. Neutral amino acids have side chains with no charge at pH 7.3. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_L_AMINO_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18123
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of an L-amino acid from one side of a membrane to the other. L-amino acids are the L-enantiomers of amino acids. [GOC:ai, GOC:jsg, GOC:mah, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_L_ALANINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of L-alanine from one side of a membrane to the other. L-alanine is the L-enantiomer of 2-aminopropanoic acid. [GOC:go_curators, GOC:jsg, GOC:mah, GOC:mtg_transport, ISBN:0198506732, ISBN:0815340729]
Full description |

Standard name | GO_ARGININE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the stereospecific transfer of arginine, 2-amino-5-guanidinopentanoic acid, across a biological membrane. [GOC:go_curators, GOC:mtg_transport, ISBN:0198506732, ISBN:0815340729]
Full description |

Standard name | GO_L_ASPARTATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of L-aspartate from one side of a membrane to the other. L-aspartate is the anion derived from aspartic acid. [GOC:go_curators, GOC:mtg_transport, ISBN:0198506732, ISBN:0815340729]
Full description |

Standard name | GO_GAMMA_AMINOBUTYRIC_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of gamma-aminobutyric acid from one side of a membrane to the other. Gamma-aminobutyric acid is 4-aminobutyrate (GABA). [GOC:go_curators, GOC:mtg_transport, ISBN:0198506732, ISBN:0815340729]
Full description |

Standard name | GO_L_GLUTAMINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of L-glutamine from one side of a membrane to the other. L-glutamine is 2-amino-4-carbamoylbutanoic acid. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_GLYCINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26358
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of glycine from one side of a membrane to the other. Glycine is aminoethanoic acid. [GOC:ai]
Full description |

Standard name | GO_L_LYSINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of L-lysine from one side of a membrane to the other. L-lysine is 2,6-diaminohexanoic acid. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_L_LEUCINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of L-leucine from one side of a membrane to the other. L-leucine is 2-amino-4-methylpentanoic acid. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_L_PROLINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of L-proline from one side of a membrane to the other. L-proline is pyrrolidine-2-carboxylic acid. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_L_SERINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26361
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of L-serine from one side of a membrane to the other. L-serine is the L-enantiomer of 2-amino-3-hydroxypropanoic acid. [GOC:ai, GOC:jsg, GOC:mah, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_UREA_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of urea from one side of a membrane to the other. Urea is the water soluble compound H2N-CO-NH2. [ISBN:0198506732]
Full description |

Standard name | GO_NUCLEOBASE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a nucleobase, any nitrogenous base that is a constituent of a nucleoside, nucleotide, or nucleic acidfrom one side of a membrane to the other. [ISBN:0198506732]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOSIDE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a pyrimidine nucleoside, a pyrimidine base covalently bonded to a ribose or deoxyribose sugar from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_NUCLEOTIDE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a nucleotide, any compound consisting of a nucleoside that is esterified with (ortho)phosphate, from one side of a membrane to the other. [ISBN:0198506732]
Full description |

Standard name | GO_CHOLINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of choline from one side of a membrane to the other. Choline (2-hydroxyethyltrimethylammonium) is an amino alcohol that occurs widely in living organisms as a constituent of certain types of phospholipids and in the neurotransmitter acetylcholine. [GOC:ai]
Full description |

Standard name | GO_HEME_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of heme from one side of a membrane to the other. [PMID:29549126]
Full description |

Standard name | GO_FATTY_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of fatty acids from one side of a membrane to the other. Fatty acids are aliphatic monocarboxylic acids liberated from naturally occurring fats and oils by hydrolysis. [ISBN:0198506732]
Full description |

Standard name | GO_STEROL_TRANSPORTER_ACTIVITY
Systematic name | M18414
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the directed movement of sterols into, out of or within a cell, or between cells. Sterol are steroids with one or more hydroxyl groups and a hydrocarbon side-chain in the molecule. [GOC:ai]
Full description |

Standard name | GO_PROTON_CHANNEL_ACTIVITY
Systematic name | M26371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the facilitated diffusion of a hydrogen ion (by an energy-independent process) involving passage through a transmembrane aqueous pore or channel without evidence for a carrier-mediated mechanism. [GOC:mtg_transport, GOC:pr, ISBN:0815340729]
Full description |

Standard name | GO_GLYCEROL_CHANNEL_ACTIVITY
Systematic name | M34403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the facilitated diffusion of glycerol (by an energy-independent process) involving passage through a transmembrane aqueous pore or channel without evidence for a carrier-mediated mechanism. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_CALCIUM_ACTIVATED_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M18059
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the calcium concentration-regulatable energy-independent passage of potassium ions across a lipid bilayer down a concentration gradient. [GOC:dph, GOC:mtg_transport]
Full description |

Standard name | GO_OUTWARD_RECTIFIER_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M26372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a potassium ion by an outwardly-rectifying voltage-gated channel. An outwardly rectifying current-voltage relation is one where at any given driving force the outward flow of K+ ions exceeds the inward flow for the opposite driving force. [GOC:mah]
Full description |

Standard name | GO_ATP_ACTIVATED_INWARD_RECTIFIER_POTASSIUM_CHANNEL_ACTIVITY
Systematic name | M34404
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a potassium ion by an inwardly-rectifying voltage-gated channel, where the inward rectification is due to a voltage-dependent block of the channel pore by ATP. An inwardly rectifying current-voltage relation is one where at any given driving force the inward flow of K+ ions exceeds the outward flow for the opposite driving force. [GOC:cb, GOC:mah]
Full description |

Standard name | GO_LIGAND_GATED_ION_CHANNEL_ACTIVITY
Systematic name | M26373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an ion by a channel that opens when a specific ligand has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_KAINATE_SELECTIVE_GLUTAMATE_RECEPTOR_ACTIVITY
Systematic name | M26374
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | An ionotropic glutamate receptor activity that exhibits fast gating by glutamate, acts by opening a cation channel permeable to sodium and potassium, and for which kainate is an agonist. [GOC:mah, PMID:10049997, PMID:8804111]
Full description |

Standard name | GO_CALCIUM_RELEASE_CHANNEL_ACTIVITY
Systematic name | M26375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a calcium ion from intracellular stores by a channel that opens when a specific intracellular ligand has been bound by the channel complex or one of its constituent parts. [GOC:mah]
Full description |

Standard name | GO_STORE_OPERATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M18870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A ligand-gated ion channel activity which transports calcium in response to emptying of intracellular calcium stores. [GOC:dph, GOC:tb, PMID:15788710]
Full description |

Standard name | GO_LIGAND_GATED_SODIUM_CHANNEL_ACTIVITY
Systematic name | M26376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a sodium ion by a channel that opens when a specific ligand has been bound by the channel complex or one of its constituent parts. [GOC:mah]
Full description |

Standard name | GO_PORIN_ACTIVITY
Systematic name | M26377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of substances, sized less than 1000 Da, from one side of a membrane to the other. The transmembrane portions of porins consist exclusively of beta-strands which form a beta-barrel. They are found in the outer membranes of Gram-negative bacteria, mitochondria, plastids and possibly acid-fast Gram-positive bacteria. [GOC:mtg_transport, ISBN:0815340729, PMID:10839820, TC:1.B.1.-.-]
Full description |

Standard name | GO_SECONDARY_ACTIVE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute from one side of a membrane to the other, up its concentration gradient. The transporter binds the solute and undergoes a series of conformational changes. Transport works equally well in either direction and is driven by a chemiosmotic source of energy, not direct ATP coupling. Secondary active transporters include symporters and antiporters. [GOC:mtg_transport, ISBN:0198506732, ISBN:0815340729, PMID:10839820]
Full description |

Standard name | GO_SYMPORTER_ACTIVITY
Systematic name | M19009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the active transport of a solute across a membrane by a mechanism whereby two or more species are transported together in the same direction in a tightly coupled process not directly linked to a form of energy other than chemiosmotic energy. [GOC:mtg_transport, ISBN:0815340729, PMID:10839820]
Full description |

Standard name | GO_SOLUTE_CATION_SYMPORTER_ACTIVITY
Systematic name | M18800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: solute(out) + cation(out) = solute(in) + cation(in). [GOC:ai]
Full description |

Standard name | GO_SOLUTE_PROTON_SYMPORTER_ACTIVITY
Systematic name | M18848
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: solute(out) + H+(out) = solute(in) + H+(in). [GOC:ai]
Full description |

Standard name | GO_ANION_CATION_SYMPORTER_ACTIVITY
Systematic name | M18063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: anion(out) + cation(out) = anion(in) + cation(in). [TC:2.A.1.14.-]
Full description |

Standard name | GO_ANTIPORTER_ACTIVITY
Systematic name | M7104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the active transport of a solute across a membrane by a mechanism whereby two or more species are transported in opposite directions in a tightly coupled process not directly linked to a form of energy other than chemiosmotic energy. The reaction is: solute A(out) + solute B(in) = solute A(in) + solute B(out). [GOC:mtg_transport, ISBN:0815340729, PMID:10839820]
Full description |

Standard name | GO_SOLUTE_CATION_ANTIPORTER_ACTIVITY
Systematic name | M18652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: solute(out) + cation(in) = solute(in) + cation(out). [GOC:ai]
Full description |

Standard name | GO_SOLUTE_PROTON_ANTIPORTER_ACTIVITY
Systematic name | M18140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: solute(out) + H+(in) = solute(in) + H+(out). [GOC:ai]
Full description |

Standard name | GO_SODIUM_INDEPENDENT_ORGANIC_ANION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of organic anions from one side of a membrane to the other, in a sodium independent manner. [GOC:go_curators]
Full description |

Standard name | GO_THYROID_HORMONE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of thyroid hormones from one side of a membrane to the other. Thyroid hormone are any of the compounds secreted by the thyroid gland, largely thyroxine and triiodothyronine. [GOC:ai]
Full description |

Standard name | GO_SECONDARY_ACTIVE_MONOCARBOXYLATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the movement of a monocarboxylate, any compound containing a single carboxyl group (COOH or COO-), by uniport, symport or antiport across a membrane by a carrier-mediated mechanism. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_CALCIUM_CATION_ANTIPORTER_ACTIVITY
Systematic name | M26381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: Ca2+(in) + cation(out) = Ca2+(out) + cation(in). [TC:2.A.19.-.-]
Full description |

Standard name | GO_SOLUTE_SODIUM_SYMPORTER_ACTIVITY
Systematic name | M19106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: solute(out) + Na+(out) = solute(in) + Na+(in). [GOC:ai]
Full description |

Standard name | GO_ANION_SODIUM_SYMPORTER_ACTIVITY
Systematic name | M26382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: monovalent anion(out) + Na+(out) = monovalent anion(in) + Na+(in). [TC:2.A.21.5.-]
Full description |

Standard name | GO_CATION_CHLORIDE_SYMPORTER_ACTIVITY
Systematic name | M26383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: cation(out) + Cl-(out) = cation(in) + Cl-(in). [TC:2.A.30.-.-]
Full description |

Standard name | GO_SODIUM_CHLORIDE_SYMPORTER_ACTIVITY
Systematic name | M26384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: Na+(out) + Cl-(out) = Na+(in) + Cl-(in). [TC:2.A.30.4.-]
Full description |

Standard name | GO_POTASSIUM_CHLORIDE_SYMPORTER_ACTIVITY
Systematic name | M26385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: K+(out) + Cl-(out) = K+(in) + Cl-(in). [TC:2.A.30.5.-]
Full description |

Standard name | GO_SODIUM_PROTON_ANTIPORTER_ACTIVITY
Systematic name | M29463
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: Na+(out) + H+(in) = Na+(in) + H+(out). [TC:2.A.35.1.1, TC:2.A.36.-.-]
Full description |

Standard name | GO_PRIMARY_ACTIVE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute from one side of a membrane to the other, up the solute's concentration gradient, by binding the solute and undergoing a series of conformational changes. Transport works equally well in either direction and is powered by a primary energy source, directly using ATP. Primary energy sources known to be coupled to transport are chemical, electrical and solar sources. [GOC:mtg_transport, ISBN:0815340729, TC:3.-.-.-.-]
Full description |

Standard name | GO_P_P_BOND_HYDROLYSIS_DRIVEN_PROTEIN_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26387
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Primary active carrier-mediated transport of a protein across a membrane, driven by the hydrolysis of the diphosphate bond of inorganic pyrophosphate, ATP, or another nucleoside triphosphate. The transport protein may or may not be transiently phosphorylated, but the substrate is not phosphorylated. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_POTASSIUM_CHANNEL_REGULATOR_ACTIVITY
Systematic name | M18909
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates potassium channel activity via direct interaction interaction with a potassium channel (binding or modification). [GOC:dos, GOC:mah]
Full description |

Standard name | GO_ACETYLCHOLINE_RECEPTOR_ACTIVITY
Systematic name | M18124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with acetylcholine and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:jl, GOC:signaling]
Full description |

Standard name | GO_CHOLESTEROL_BINDING
Systematic name | M34406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with cholesterol (cholest-5-en-3-beta-ol); the principal sterol of vertebrates and the precursor of many steroids, including bile acids and steroid hormones. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_CATION_CATION_ANTIPORTER_ACTIVITY
Systematic name | M18191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: cation A(out) + cation B(in) = cation A(in) + cation B(out). [GOC:ai]
Full description |

Standard name | GO_C4_DICARBOXYLATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of C4-dicarboxylate from one side of a membrane to the other. [GOC:krc]
Full description |

Standard name | GO_EFFLUX_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26389
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a specific substance or related group of substances from the inside of the cell to the outside of the cell across a membrane. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_ORGANOPHOSPHATE_ESTER_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of organophosphate esters from one side of a membrane to the other. Organophosphate esters are small organic molecules containing phosphate ester bonds. [GOC:mcc]
Full description |

Standard name | GO_DNA_TRANSLOCASE_ACTIVITY
Systematic name | M26390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate, to drive movement along a single- or double-stranded DNA molecule. [GOC:mah, PMID:16428451, PMID:17631491]
Full description |

Standard name | GO_TUBULIN_BINDING
Systematic name | M7422
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with monomeric or multimeric forms of tubulin, including microtubules. [GOC:clt]
Full description |

Standard name | GO_TOXIC_SUBSTANCE_BINDING
Systematic name | M18310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a toxic substance, a poisonous substance that causes damage to biological systems. [GOC:bf, GOC:curators, GOC:jl, GOC:pr]
Full description |

Standard name | GO_FATTY_ACID_LIGASE_ACTIVITY
Systematic name | M18978
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the ligation of a fatty acid to an acceptor, coupled to the hydrolysis of ATP. [EC:6.2.1.3, GOC:cjk, GOC:mah]
Full description |

Standard name | GO_QUATERNARY_AMMONIUM_GROUP_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of quaternary ammonium groups from one side of a membrane to the other. Quaternary ammonium groups are any compound that can be regarded as derived from ammonium hydroxide or an ammonium salt by replacement of all four hydrogen atoms of the NH4+ ion by organic groups. [ISBN:0198506732]
Full description |

Standard name | GO_BRANCHED_CHAIN_AMINO_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34407
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of branched-chain amino acids from one side of a membrane to the other. Branched-chain amino acids are amino acids with a branched carbon skeleton without rings. [GOC:ai, GOC:bf, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY_PHOSPHORYLATIVE_MECHANISM
Systematic name | M18135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: ATP + H2O = ADP + phosphate, to directly drive the transport of ions across a membrane. The reaction is characterized by the transient formation of a high-energy aspartyl-phosphoryl-enzyme intermediate. [PMID:10322420, PMID:10600683]
Full description |

Standard name | GO_MANNOSIDASE_ACTIVITY
Systematic name | M18069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of mannosyl compounds, substances containing a group derived from a cyclic form of mannose or a mannose derivative. [GOC:ai]
Full description |

Standard name | GO_MANNOSYL_OLIGOSACCHARIDE_MANNOSIDASE_ACTIVITY
Systematic name | M26392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of the terminal alpha-D-mannose residues in oligo-mannose oligosaccharides. [EC:3.2.1.-, GOC:ai]
Full description |

Standard name | GO_GALACTOSIDASE_ACTIVITY
Systematic name | M26393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of galactosyl compounds, substances containing a group derived from a cyclic form of galactose or a galactose derivative. [GOC:ai]
Full description |

Standard name | GO_GLUCOSIDASE_ACTIVITY
Systematic name | M18136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of glucosyl compounds, substances containing a group derived from a cyclic form of glucose or a glucose derivative. [ISBN:0198506732]
Full description |

Standard name | GO_HEXOSAMINIDASE_ACTIVITY
Systematic name | M19210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of hexosamine or N-acetylhexosamine residues (e.g. N-acetylglucosamine) residues from gangliosides or other glycoside oligosaccharides. [ISBN:0721662544]
Full description |

Standard name | GO_NUCLEOBASE_CONTAINING_COMPOUND_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M1331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of nucleobases, nucleosides, nucleotides and nucleic acids from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_MORPHOGEN_ACTIVITY
Systematic name | M26395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Acts as a trigger for a pattern specification process when present at a specific concentration within a gradient. [GOC:go_curators]
Full description |

Standard name | GO_CYCLOSPORIN_A_BINDING
Systematic name | M26396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with cyclosporin A, a cyclic undecapeptide that contains several N-methylated and unusual amino acids. [GOC:mb]
Full description |

Standard name | GO_PEPTIDOGLYCAN_IMMUNE_RECEPTOR_ACTIVITY
Systematic name | M26397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a peptidoglycan and transmitting the signal to initiate an innate immune response. [PMID:14698226]
Full description |

Standard name | GO_AMYLASE_ACTIVITY
Systematic name | M26398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of amylose or an amylose derivative. [GOC:ai]
Full description |

Standard name | GO_GLIAL_CELL_DERIVED_NEUROTROPHIC_FACTOR_RECEPTOR_ACTIVITY
Systematic name | M29464
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with glial cell line-derived neurotrophic factor and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:mah, GOC:signaling]
Full description |

Standard name | GO_NAD_P_H_OXIDASE_H_2_O_2_FORMING_ACTIVITY
Systematic name | M26399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NAD(P)H + H+ + O2 = NAD(P)+ + hydrogen peroxide. [EC:1.6.3.1, PMID:10401672, PMID:10601291, PMID:11822874, RHEA:11260]
Full description |

Standard name | GO_SUPEROXIDE_GENERATING_NADPH_OXIDASE_ACTIVITY
Systematic name | M18626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NAD(P)H + O2 = NAD(P)H + O2-. [GOC:ai, PMID:10806195]
Full description |

Standard name | GO_SUPEROXIDE_GENERATING_NADPH_OXIDASE_ACTIVATOR_ACTIVITY
Systematic name | M26400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Increases the activity of the enzyme superoxide-generating NADPH oxidase. [GOC:ai]
Full description |

Standard name | GO_AMP_BINDING
Systematic name | M26401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with AMP, adenosine monophosphate. [GOC:go_curators]
Full description |

Standard name | GO_ANTIOXIDANT_ACTIVITY
Systematic name | M15021
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Inhibition of the reactions brought about by dioxygen (O2) or peroxides. Usually the antioxidant is effective because it can itself be more easily oxidized than the substance protected. The term is often applied to components that can trap free radicals, thereby breaking the chain reaction that normally leads to extensive biological damage. [ISBN:0198506732]
Full description |

Standard name | GO_STEROID_DEHYDROGENASE_ACTIVITY
Systematic name | M8055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which one substrate is a sterol derivative. [GOC:mah]
Full description |

Standard name | GO_CHANNEL_REGULATOR_ACTIVITY
Systematic name | M18217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a channel. A channel catalyzes energy-independent facilitated diffusion, mediated by passage of a solute through a transmembrane aqueous pore or channel. [GOC:mah]
Full description |

Standard name | GO_CHANNEL_INHIBITOR_ACTIVITY
Systematic name | M18518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents, or reduces the activity of a channel via direct interaction with the channel. A channel catalyzes energy-independent facilitated diffusion, mediated by passage of a solute through a transmembrane aqueous pore or channel. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_ARGININE_N_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26404
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + (protein)-arginine = S-adenosyl-L-homocysteine + (protein)-N-methyl-arginine. [GOC:mah, PMID:12351636]
Full description |

Standard name | GO_LYSINE_N_METHYLTRANSFERASE_ACTIVITY
Systematic name | M19077
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group from S-adenosyl-L-methionine to the epsilon-amino group of a lysine residue. [GOC:mah]
Full description |

Standard name | GO_COA_HYDROLASE_ACTIVITY
Systematic name | M18080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: X-CoA + H2O = X + CoA; X may be any group. [GOC:ai]
Full description |

Standard name | GO_PALMITOYL_COA_HYDROLASE_ACTIVITY
Systematic name | M18521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: palmitoyl-CoA + H2O = CoA + palmitate. [EC:3.1.2.2]
Full description |

Standard name | GO_LIPASE_ACTIVITY
Systematic name | M18934
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a lipid or phospholipid. [GOC:mah]
Full description |

Standard name | GO_KINASE_ACTIVITY
Systematic name | M18231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphate group, usually from ATP, to a substrate molecule. [ISBN:0198506732]
Full description |

Standard name | GO_1_PHOSPHATIDYLINOSITOL_3_KINASE_ACTIVITY
Systematic name | M29465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-phosphatidyl-1D-myo-inositol + ATP = a 1-phosphatidyl-1D-myo-inositol 3-phosphate + ADP + 2 H(+). [EC:2.7.1.137, RHEA:12709]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_PHOSPHATE_KINASE_ACTIVITY
Systematic name | M18774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a phosphatidylinositol phosphate = ADP + a phosphatidylinositol bisphosphate. [EC:2.7.1.-, PMID:9759495]
Full description |

Standard name | GO_1_PHOSPHATIDYLINOSITOL_4_PHOSPHATE_5_KINASE_ACTIVITY
Systematic name | M26405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-phosphatidyl-1D-myo-inositol 4-phosphate + ATP = 1-phosphatidyl-1D-myo-inositol 4,5-bisphosphate + ADP + 2 H(+). [EC:2.7.1.68, RHEA:14425]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_4_5_TRISPHOSPHATE_3_PHOSPHATASE_ACTIVITY
Systematic name | M34408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: phosphatidylinositol-3,4,5-trisphosphate + H2O = phosphatidylinositol-4,5-bisphosphate + phosphate. [EC:3.1.3.67]
Full description |

Standard name | GO_ACTIVIN_RECEPTOR_ACTIVITY_TYPE_I
Systematic name | M29466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with activin-bound type II activin receptor to initiate a change in cell activity; upon binding, acts as a downstream transducer of activin signals. [GOC:mah, PMID:8622651]
Full description |

Standard name | GO_CARNITINE_O_ACYLTRANSFERASE_ACTIVITY
Systematic name | M26406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acyl group to an oxygen atom on the carnitine molecule. [GOC:ai]
Full description |

Standard name | GO_ACETYLTRANSFERASE_ACTIVITY
Systematic name | M18150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acetyl group to an acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_C_ACYLTRANSFERASE_ACTIVITY
Systematic name | M19023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acyl group to a carbon atom on the acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_PALMITOYLTRANSFERASE_ACTIVITY
Systematic name | M18378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a palmitoyl (CH3-[CH2]14-CO-) group to an acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_N_ACYLTRANSFERASE_ACTIVITY
Systematic name | M18692
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acyl group to a nitrogen atom on the acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_ACYLGLYCEROL_O_ACYLTRANSFERASE_ACTIVITY
Systematic name | M17969
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acyl group to an oxygen atom on the acylglycerol molecule. [GOC:ai]
Full description |

Standard name | GO_O_ACETYLTRANSFERASE_ACTIVITY
Systematic name | M26407
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acetyl group to an oxygen atom on the acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_O_PALMITOYLTRANSFERASE_ACTIVITY
Systematic name | M26408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a palmitoyl group to an oxygen atom on the acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_S_ACYLTRANSFERASE_ACTIVITY
Systematic name | M18040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acyl group to a sulfur atom on the acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_TRNA_GUANINE_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26409
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + tRNA = S-adenosyl-L-homocysteine + tRNA containing methylguanine. [GOC:go-curators]
Full description |

Standard name | GO_TRNA_ADENINE_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + tRNA = S-adenosyl-L-homocysteine + tRNA containing methyladenine. [GOC:go-curators]
Full description |

Standard name | GO_TRNA_CYTOSINE_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26411
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + tRNA = S-adenosyl-L-homocysteine + tRNA containing methylcytosine. [GOC:go-curators]
Full description |

Standard name | GO_RRNA_ADENINE_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26413
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + rRNA = S-adenosyl-L-homocysteine + rRNA containing methyladenine. [GOC:go-curators]
Full description |

Standard name | GO_RRNA_CYTOSINE_METHYLTRANSFERASE_ACTIVITY
Systematic name | M34409
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + rRNA = S-adenosyl-L-homocysteine + rRNA containing methylcytosine. [GOC:go-curators]
Full description |

Standard name | GO_RRNA_GUANINE_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26414
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + rRNA = S-adenosyl-L-homocysteine + rRNA containing methylguanine. [EC:2.1.1.-]
Full description |

Standard name | GO_C_ACETYLTRANSFERASE_ACTIVITY
Systematic name | M26415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acetyl group to a carbon atom on the acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_C_PALMITOYLTRANSFERASE_ACTIVITY
Systematic name | M26416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a palmitoyl group to a carbon atom on the acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY
Systematic name | M3466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction, a reversible chemical reaction in which the oxidation state of an atom or atoms within a molecule is altered. One substrate acts as a hydrogen or electron donor and becomes oxidized, while the other acts as hydrogen or electron acceptor and becomes reduced. [GOC:go_curators]
Full description |

Standard name | GO_C_X_C_CHEMOKINE_RECEPTOR_ACTIVITY
Systematic name | M26417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a C-X-C chemokine and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. A C-X-C chemokine has a single amino acid between the first two cysteines of the characteristic four cysteine motif. [GOC:signaling, PMID:8662823]
Full description |

Standard name | GO_PROTEIN_HORMONE_RECEPTOR_ACTIVITY
Systematic name | M18751
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a protein hormone to initiate a change in cell activity. [GOC:mah]
Full description |

Standard name | GO_NUCLEOTIDE_RECEPTOR_ACTIVITY
Systematic name | M26418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a nucleotide and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. A nucleotide is a compound that consists of a nucleoside esterified with a phosphate molecule. [GOC:signaling, ISBN:0198506732]
Full description |

Standard name | GO_PHEROMONE_RECEPTOR_ACTIVITY
Systematic name | M26419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a pheromone to initiate a change in cell activity. A pheromone is a substance used in olfactory communication between organisms of the same species eliciting a change in sexual or social behavior. [GOC:hjd, ISBN:0198506732]
Full description |

Standard name | GO_PEPTIDASE_ACTIVATOR_ACTIVITY
Systematic name | M18278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and increases the activity of a peptidase, any enzyme that catalyzes the hydrolysis peptide bonds. [GOC:ai]
Full description |

Standard name | GO_PEPTIDASE_ACTIVATOR_ACTIVITY_INVOLVED_IN_APOPTOTIC_PROCESS
Systematic name | M18614
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Increases the activity of a peptidase that is involved in the apoptotic process. [GOC:BHF, GOC:mah, GOC:mtg_apoptosis, GOC:rl]
Full description |

Standard name | GO_METALLOCHAPERONE_ACTIVITY
Systematic name | M26420
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Directly binding to and delivering metal ions to a target protein. [PMID:11739376]
Full description |

Standard name | GO_CYCLIN_DEPENDENT_PROTEIN_SERINE_THREONINE_KINASE_REGULATOR_ACTIVITY
Systematic name | M18723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a cyclin-dependent protein serine/threonine kinase, enzymes of the protein kinase family that are regulated through association with cyclins and other proteins. [GOC:pr, GOC:rn, PMID:7877684, PMID:9442875]
Full description |

Standard name | GO_GLYCINE_BINDING
Systematic name | M18173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with glycine, aminoethanoic acid. [GOC:ai]
Full description |

Standard name | GO_GLUTAMATE_BINDING
Systematic name | M26422
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with glutamate, the anion of 2-aminopentanedioic acid. [GOC:ai]
Full description |

Standard name | GO_AMINO_ACID_BINDING
Systematic name | M17897
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an amino acid, organic acids containing one or more amino substituents. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_CH_OH_GROUP_OF_DONORS
Systematic name | M15309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a CH-OH group act as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_MALATE_DEHYDROGENASE_ACTIVITY
Systematic name | M26423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reversible conversion of pyruvate or oxaloacetate to malate. [GOC:mah, ISBN:0582227089]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_THE_ALDEHYDE_OR_OXO_GROUP_OF_DONORS_NAD_OR_NADP_AS_ACCEPTOR
Systematic name | M5430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which an aldehyde or ketone (oxo) group acts as a hydrogen or electron donor and reduces NAD or NADP. [GOC:jl]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_THE_ALDEHYDE_OR_OXO_GROUP_OF_DONORS_DISULFIDE_AS_ACCEPTOR
Systematic name | M26424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which an aldehyde or ketone (oxo) group acts as a hydrogen or electron donor and reduces a disulfide. [GOC:jl]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_THE_CH_CH_GROUP_OF_DONORS
Systematic name | M10741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a CH-CH group acts as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_THE_CH_CH_GROUP_OF_DONORS_NAD_OR_NADP_AS_ACCEPTOR
Systematic name | M18730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a CH-CH group acts as a hydrogen or electron donor and reduces NAD or NADP. [GOC:jl]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_THE_CH_CH_GROUP_OF_DONORS_OXYGEN_AS_ACCEPTOR
Systematic name | M26425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a CH-CH group acts as a hydrogen or electron donor and reduces oxygen. [GOC:jl]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_THE_CH_NH2_GROUP_OF_DONORS
Systematic name | M18746
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a CH-NH2 group acts as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_THE_CH_NH2_GROUP_OF_DONORS_OXYGEN_AS_ACCEPTOR
Systematic name | M18823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a CH-NH2 group acts as a hydrogen or electron donor and reduces an oxygen molecule. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_THE_CH_NH_GROUP_OF_DONORS
Systematic name | M15811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a CH-NH group acts as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_THE_CH_NH_GROUP_OF_DONORS_NAD_OR_NADP_AS_ACCEPTOR
Systematic name | M18622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a CH-NH group acts as a hydrogen or electron donor and reduces NAD or NADP. [GOC:jl]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_NAD_P_H
Systematic name | M15170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which NADH or NADPH acts as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_NAD_P_H_HEME_PROTEIN_AS_ACCEPTOR
Systematic name | M26427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which NADH or NADPH acts as a hydrogen or electron donor and reduces a heme protein. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_NAD_P_H_QUINONE_OR_SIMILAR_COMPOUND_AS_ACCEPTOR
Systematic name | M19066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which NADH or NADPH acts as a hydrogen or electron donor and reduces a quinone or a similar acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_OTHER_NITROGENOUS_COMPOUNDS_AS_DONORS
Systematic name | M26428
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a nitrogenous group, excluding NH and NH2 groups, acts as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_A_SULFUR_GROUP_OF_DONORS
Systematic name | M4191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a sulfur-containing group acts as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_A_SULFUR_GROUP_OF_DONORS_NAD_P_AS_ACCEPTOR
Systematic name | M26429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a sulfur-containing group acts as a hydrogen or electron donor and reduces NAD or NADP. [GOC:jl]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_A_SULFUR_GROUP_OF_DONORS_OXYGEN_AS_ACCEPTOR
Systematic name | M26430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a sulfur-containing group acts as a hydrogen or electron donor and reduces oxygen. [GOC:jl]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_A_SULFUR_GROUP_OF_DONORS_DISULFIDE_AS_ACCEPTOR
Systematic name | M18370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a sulfur-containing group acts as a hydrogen or electron donor and reduces disulfide. [GOC:jl]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_A_HEME_GROUP_OF_DONORS
Systematic name | M17899
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a heme group acts as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_DIPHENOLS_AND_RELATED_SUBSTANCES_AS_DONORS
Systematic name | M26431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a diphenol or related substance acts as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_PEROXIDE_AS_ACCEPTOR
Systematic name | M15214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which the peroxide group acts as a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_SINGLE_DONORS_WITH_INCORPORATION_OF_MOLECULAR_OXYGEN
Systematic name | M18671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which hydrogen or electrons are transferred from one donor, and molecular oxygen is incorporated into a donor. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_PAIRED_DONORS_WITH_INCORPORATION_OR_REDUCTION_OF_MOLECULAR_OXYGEN
Systematic name | M10622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which hydrogen or electrons are transferred from each of two donors, and molecular oxygen is reduced or incorporated into a donor. [GOC:mah]
Full description |

Standard name | GO_2_OXOGLUTARATE_DEPENDENT_DIOXYGENASE_ACTIVITY
Systematic name | M8499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: A + 2-oxoglutarate + O2 = B + succinate + CO2. This is an oxidation-reduction (redox) reaction in which hydrogen or electrons are transferred from 2-oxoglutarate and one other donor, and one atom of oxygen is incorporated into each donor. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_PAIRED_DONORS_WITH_INCORPORATION_OR_REDUCTION_OF_MOLECULAR_OXYGEN_NAD_P_H_AS_ONE_DONOR_AND_INCORPORATION_OF_ONE_ATOM_OF_OXYGEN
Systematic name | M19163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which hydrogen or electrons are transferred from NADH or NADPH and one other donor, and one atom of oxygen is incorporated into one donor. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_PAIRED_DONORS_WITH_INCORPORATION_OR_REDUCTION_OF_MOLECULAR_OXYGEN_REDUCED_FLAVIN_OR_FLAVOPROTEIN_AS_ONE_DONOR_AND_INCORPORATION_OF_ONE_ATOM_OF_OXYGEN
Systematic name | M19039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which hydrogen or electrons are transferred from reduced flavin or flavoprotein and one other donor, and one atom of oxygen is incorporated into one donor. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_PAIRED_DONORS_WITH_INCORPORATION_OR_REDUCTION_OF_MOLECULAR_OXYGEN_REDUCED_IRON_SULFUR_PROTEIN_AS_ONE_DONOR_AND_INCORPORATION_OF_ONE_ATOM_OF_OXYGEN
Systematic name | M26433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which hydrogen or electrons are transferred from reduced iron-sulfur protein and one other donor, and one atom of oxygen is incorporated into one donor. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_PAIRED_DONORS_WITH_INCORPORATION_OR_REDUCTION_OF_MOLECULAR_OXYGEN_REDUCED_PTERIDINE_AS_ONE_DONOR_AND_INCORPORATION_OF_ONE_ATOM_OF_OXYGEN
Systematic name | M26434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which hydrogen or electrons are transferred from reduced pteridine and one other donor, and one atom of oxygen is incorporated into one donor. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_PAIRED_DONORS_WITH_INCORPORATION_OR_REDUCTION_OF_MOLECULAR_OXYGEN_REDUCED_ASCORBATE_AS_ONE_DONOR_AND_INCORPORATION_OF_ONE_ATOM_OF_OXYGEN
Systematic name | M26435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which hydrogen or electrons are transferred from reduced ascorbate and one other donor, and one atom of oxygen is incorporated into one donor. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_PAIRED_DONORS_WITH_OXIDATION_OF_A_PAIR_OF_DONORS_RESULTING_IN_THE_REDUCTION_OF_MOLECULAR_OXYGEN_TO_TWO_MOLECULES_OF_WATER
Systematic name | M26436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which hydrogen or electrons are transferred from each of two donors, and molecular oxygen is reduced to two molecules of water. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_OXIDIZING_METAL_IONS
Systematic name | M18471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction in which the oxidation state of metal ion is altered. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_OXIDIZING_METAL_IONS_NAD_OR_NADP_AS_ACCEPTOR
Systematic name | M18474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction in which the oxidation state of metal ion is altered and NAD+ or NADP+ acts as an electron acceptor. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_OXIDIZING_METAL_IONS_OXYGEN_AS_ACCEPTOR
Systematic name | M26437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction in which the oxidation state of metal ion is altered and oxygen acts as an electron acceptor. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_CH_OR_CH2_GROUPS
Systematic name | M26438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which a CH2 group acts as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_ONE_CARBON_GROUPS
Systematic name | M18995
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a one-carbon group from one compound (donor) to another (acceptor). [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_HYDROXYMETHYL_FORMYL_AND_RELATED_TRANSFERASE_ACTIVITY
Systematic name | M26439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a hydroxymethyl- or formyl group from one compound (donor) to another (acceptor). [EC:2.1.2, GOC:mah]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_ALDEHYDE_OR_KETONIC_GROUPS
Systematic name | M34410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an aldehyde or ketonic group from one compound (donor) to another (acceptor). [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_ACYL_GROUPS
Systematic name | M18399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acyl group from one compound (donor) to another (acceptor). [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_AMINO_ACYL_GROUPS
Systematic name | M18564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an amino-acyl group from one compound (donor) to another (acceptor). [GOC:jl]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_GLYCOSYL_GROUPS
Systematic name | M18527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a glycosyl group from one compound (donor) to another (acceptor). [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_HEXOSYL_GROUPS
Systematic name | M18100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a hexosyl group from one compound (donor) to another (acceptor). [GOC:jl]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_PENTOSYL_GROUPS
Systematic name | M19109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a pentosyl group from one compound (donor) to another (acceptor). [GOC:jl]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_ALKYL_OR_ARYL_OTHER_THAN_METHYL_GROUPS
Systematic name | M3387
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an alkyl or aryl (but not methyl) group from one compound (donor) to another (acceptor). [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_NITROGENOUS_GROUPS
Systematic name | M18611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a nitrogenous group from one compound (donor) to another (acceptor). [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_PHOSPHORUS_CONTAINING_GROUPS
Systematic name | M19204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphorus-containing group from one compound (donor) to another (acceptor). [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHOTRANSFERASE_ACTIVITY_NITROGENOUS_GROUP_AS_ACCEPTOR
Systematic name | M18853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphorus-containing group from one compound (donor) to a nitrogenous group (acceptor). [GOC:jl]
Full description |

Standard name | GO_PHOSPHOTRANSFERASE_ACTIVITY_PHOSPHATE_GROUP_AS_ACCEPTOR
Systematic name | M18585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphorus-containing group from one compound (donor) to a phosphate group (acceptor). [GOC:jl]
Full description |

Standard name | GO_DIPHOSPHOTRANSFERASE_ACTIVITY
Systematic name | M26440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a diphosphate group from one compound (donor) to a another (acceptor). [GOC:jl, PMID:1651917]
Full description |

Standard name | GO_NUCLEOTIDYLTRANSFERASE_ACTIVITY
Systematic name | M5310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a nucleotidyl group to a reactant. [ISBN:0198506732]
Full description |

Standard name | GO_PHOSPHOTRANSFERASE_ACTIVITY_FOR_OTHER_SUBSTITUTED_PHOSPHATE_GROUPS
Systematic name | M18376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a substituted phosphate group, other than diphosphate or nucleotidyl residues, from one compound (donor) to a another (acceptor). [GOC:jl]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_SULFUR_CONTAINING_GROUPS
Systematic name | M19961
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a sulfur-containing group from one compound (donor) to another (acceptor). [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_SULFURTRANSFERASE_ACTIVITY
Systematic name | M26441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of sulfur atoms from one compound (donor) to another (acceptor). [GOC:ai, ISBN:0721662544]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_ACTING_ON_ESTER_BONDS
Systematic name | M18252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any ester bond. [GOC:jl]
Full description |

Standard name | GO_THIOLESTER_HYDROLASE_ACTIVITY
Systematic name | M18174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: RCO-SR' + H2O = RCOOH + HSR'. This reaction is the hydrolysis of a thiolester bond, an ester formed from a carboxylic acid and a thiol (i.e., RCO-SR'), such as that found in acetyl-coenzyme A. [EC:3.1.2]
Full description |

Standard name | GO_PHOSPHATASE_ACTIVITY
Systematic name | M26442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of phosphoric monoesters, releasing inorganic phosphate. [GOC:curators, GOC:pg]
Full description |

Standard name | GO_EXONUCLEASE_ACTIVITY_ACTIVE_WITH_EITHER_RIBO_OR_DEOXYRIBONUCLEIC_ACIDS_AND_PRODUCING_5_PHOSPHOMONOESTERS
Systematic name | M19142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within nucleic acids by removing nucleotide residues from the 3' or 5' end to yield 5' phosphomonoesters. [GOC:mah]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_ACTING_ON_GLYCOSYL_BONDS
Systematic name | M18428
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any glycosyl bond. [GOC:jl]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_HYDROLYZING_N_GLYCOSYL_COMPOUNDS
Systematic name | M5449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any N-glycosyl bond. [GOC:jl]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_ACTING_ON_ETHER_BONDS
Systematic name | M19206
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any ether or thioether bond, -O- or -S- respectively. [GOC:ai, GOC:jl]
Full description |

Standard name | GO_DIPEPTIDASE_ACTIVITY
Systematic name | M18271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a dipeptide. [PMID:19879002]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_ACTING_ON_CARBON_NITROGEN_BUT_NOT_PEPTIDE_BONDS
Systematic name | M19151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any carbon-nitrogen bond, C-N, with the exception of peptide bonds. [GOC:jl]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_ACTING_ON_CARBON_NITROGEN_BUT_NOT_PEPTIDE_BONDS_IN_LINEAR_AMIDES
Systematic name | M18959
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any non-peptide carbon-nitrogen bond in a linear amide. [GOC:ai]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_ACTING_ON_CARBON_NITROGEN_BUT_NOT_PEPTIDE_BONDS_IN_CYCLIC_AMIDES
Systematic name | M26443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any non-peptide carbon-nitrogen bond in a cyclic amide. [GOC:ai]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_ACTING_ON_CARBON_NITROGEN_BUT_NOT_PEPTIDE_BONDS_IN_LINEAR_AMIDINES
Systematic name | M18089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any non-peptide carbon-nitrogen bond in a linear amidine, a compound of the form R-C(=NH)-NH2. [ISBN:0198506732]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_ACTING_ON_CARBON_NITROGEN_BUT_NOT_PEPTIDE_BONDS_IN_CYCLIC_AMIDINES
Systematic name | M17851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any non-peptide carbon-nitrogen bond in a cyclic amidine, a compound of the form R-C(=NH)-NH2. [ISBN:0198506732]
Full description |

Standard name | GO_HYDROLASE_ACTIVITY_ACTING_ON_ACID_ANHYDRIDES
Systematic name | M18283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any acid anhydride. [GOC:jl]
Full description |

Standard name | GO_LYASE_ACTIVITY
Systematic name | M4469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of C-C, C-O, C-N and other bonds by other means than by hydrolysis or oxidation, or conversely adding a group to a double bond. They differ from other enzymes in that two substrates are involved in one reaction direction, but only one in the other direction. When acting on the single substrate, a molecule is eliminated and this generates either a new double bond or a new ring. [ISBN:0198547684]
Full description |

Standard name | GO_CARBON_CARBON_LYASE_ACTIVITY
Systematic name | M18396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of C-C bonds by other means than by hydrolysis or oxidation, or conversely adding a group to a double bond. [GOC:jl]
Full description |

Standard name | GO_CARBOXY_LYASE_ACTIVITY
Systematic name | M18027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the nonhydrolytic addition or removal of a carboxyl group to or from a compound. [GOC:curators]
Full description |

Standard name | GO_ALDEHYDE_LYASE_ACTIVITY
Systematic name | M26444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of a C-C bond in a molecule containing a hydroxyl group and a carbonyl group to form two smaller molecules, each being an aldehyde or a ketone. [GOC:curators]
Full description |

Standard name | GO_OXO_ACID_LYASE_ACTIVITY
Systematic name | M26445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of a C-C bond by other means than by hydrolysis or oxidation, of a 3-hydroxy acid. [EC:4.1.3, GOC:jl]
Full description |

Standard name | GO_CARBON_OXYGEN_LYASE_ACTIVITY
Systematic name | M400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the breakage of a carbon-oxygen bond. [EC:4.2.-.-]
Full description |

Standard name | GO_HYDRO_LYASE_ACTIVITY
Systematic name | M15220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of a carbon-oxygen bond by elimination of water. [EC:4.2.1]
Full description |

Standard name | GO_CARBON_NITROGEN_LYASE_ACTIVITY
Systematic name | M26446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the release of ammonia or one of its derivatives, with the formation of a double bond or ring. Enzymes with this activity may catalyze the actual elimination of the ammonia, amine or amide, e.g. CH-CH(-NH-R) = C=CH- + NH2-R. Others, however, catalyze elimination of another component, e.g. water, which is followed by spontaneous reactions that lead to breakage of the C-N bond, e.g. L-serine ammonia-lyase (EC:4.3.1.17), so that the overall reaction is C(-OH)-CH(-NH2) = CH2-CO- + NH3, i.e. an elimination with rearrangement. The sub-subclasses of EC:4.3 are the ammonia-lyases (EC:4.3.1), lyases acting on amides, amidines, etc. (EC:4.3.2), the amine-lyases (EC:4.3.3), and other carbon-nitrogen lyases (EC:4.3.99). [EC:4.3.-.-]
Full description |

Standard name | GO_AMMONIA_LYASE_ACTIVITY
Systematic name | M26447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the release of ammonia by the cleavage of a carbon-nitrogen bond or the reverse reaction with ammonia as a substrate. [EC:4.3.-.-, GOC:krc]
Full description |

Standard name | GO_AMIDINE_LYASE_ACTIVITY
Systematic name | M26448
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the release of amides or amidines by the cleavage of a carbon-nitrogen bond or the reverse reaction with an amide or amidine as a substrate. [EC:4.3.-.-, GOC:krc]
Full description |

Standard name | GO_CARBON_SULFUR_LYASE_ACTIVITY
Systematic name | M18648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the elimination of hydrogen sulfide or substituted H2S. [EC:4.4.-.-]
Full description |

Standard name | GO_PHOSPHORUS_OXYGEN_LYASE_ACTIVITY
Systematic name | M26449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of a phosphorus-oxygen bond by other means than by hydrolysis or oxidation, or conversely adding a group to a double bond. [GOC:jl]
Full description |

Standard name | GO_ISOMERASE_ACTIVITY
Systematic name | M19150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the geometric or structural changes within one molecule. Isomerase is the systematic name for any enzyme of EC class 5. [ISBN:0198506732]
Full description |

Standard name | GO_RACEMASE_AND_EPIMERASE_ACTIVITY
Systematic name | M18025
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of a reaction that alters the configuration of one or more chiral centers in a molecule. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_RACEMASE_AND_EPIMERASE_ACTIVITY_ACTING_ON_CARBOHYDRATES_AND_DERIVATIVES
Systematic name | M26450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of a reaction that alters the configuration of one or more chiral centers in a carbohydrate molecule. [GOC:mah]
Full description |

Standard name | GO_CIS_TRANS_ISOMERASE_ACTIVITY
Systematic name | M18178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of a reaction that interconverts cis and trans isomers. Atoms or groups are termed cis or trans to one another when they lie respectively on the same or on opposite sides of a reference plane identifiable as common among stereoisomers. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_INTRAMOLECULAR_OXIDOREDUCTASE_ACTIVITY
Systematic name | M19024
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which the hydrogen donor and acceptor are the same molecule, and no oxidized product appears. [EC:5.3.-.-]
Full description |

Standard name | GO_INTRAMOLECULAR_OXIDOREDUCTASE_ACTIVITY_INTERCONVERTING_ALDOSES_AND_KETOSES
Systematic name | M19174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which the hydrogen donor and acceptor, which is an aldose or a ketose, are the same molecule, and no oxidized product appears. [GOC:jl]
Full description |

Standard name | GO_INTRAMOLECULAR_OXIDOREDUCTASE_ACTIVITY_TRANSPOSING_C_C_BONDS
Systematic name | M18866
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which the hydrogen donor and acceptor are the same molecule, one or more carbon-carbon double bonds in the molecule are rearranged, and no oxidized product appears. [EC:5.3.3, GOC:mah]
Full description |

Standard name | GO_INTRAMOLECULAR_TRANSFERASE_ACTIVITY
Systematic name | M18435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a functional group from one position to another within a single molecule. [GOC:mah]
Full description |

Standard name | GO_INTRAMOLECULAR_TRANSFERASE_ACTIVITY_PHOSPHOTRANSFERASES
Systematic name | M18764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphate group from one position to another within a single molecule. [GOC:mah]
Full description |

Standard name | GO_LIGASE_ACTIVITY
Systematic name | M819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the joining of two molecules, or two groups within a single molecule, using the energy from the hydrolysis of ATP, a similar triphosphate, or a pH gradient. [EC:6, GOC:mah]
Full description |

Standard name | GO_LIGASE_ACTIVITY_FORMING_CARBON_OXYGEN_BONDS
Systematic name | M19098
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the joining of two molecules via a carbon-oxygen bond, with the concomitant hydrolysis of the diphosphate bond in ATP or a similar triphosphate. [EC:6.1, GOC:mah]
Full description |

Standard name | GO_LIGASE_ACTIVITY_FORMING_CARBON_SULFUR_BONDS
Systematic name | M18291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the joining of two molecules via a carbon-sulfur bond, with the concomitant hydrolysis of the diphosphate bond in ATP or a similar triphosphate. [EC:6.2, GOC:mah]
Full description |

Standard name | GO_ACID_THIOL_LIGASE_ACTIVITY
Systematic name | M19175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the joining of an acid and a thiol via a carbon-sulfur bond, with the concomitant hydrolysis of the diphosphate bond in ATP or a similar triphosphate. [EC:6.2.1, GOC:mah]
Full description |

Standard name | GO_LIGASE_ACTIVITY_FORMING_CARBON_NITROGEN_BONDS
Systematic name | M14478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the joining of two molecules, or two groups within a single molecule, via a carbon-nitrogen bond, with the concomitant hydrolysis of the diphosphate bond in ATP or a similar triphosphate. [GOC:mah]
Full description |

Standard name | GO_ACID_AMINO_ACID_LIGASE_ACTIVITY
Systematic name | M14561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the ligation of an acid to an amino acid via a carbon-nitrogen bond, with the concomitant hydrolysis of the diphosphate bond in ATP or a similar triphosphate. [GOC:jl, GOC:mah]
Full description |

Standard name | GO_CARBON_NITROGEN_LIGASE_ACTIVITY_WITH_GLUTAMINE_AS_AMIDO_N_DONOR
Systematic name | M18621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of the amide nitrogen of glutamine to a substrate. Usually composed of two subunits or domains, one that first hydrolyzes glutamine, and then transfers the resulting ammonia to the second subunit (or domain), where it acts as a source of nitrogen. [PMID:12360532]
Full description |

Standard name | GO_LIGASE_ACTIVITY_FORMING_CARBON_CARBON_BONDS
Systematic name | M26451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the joining of two molecules via a carbon-carbon bond, with the concomitant hydrolysis of the diphosphate bond in ATP or a similar triphosphate. [EC:6.4, GOC:jl, GOC:mah]
Full description |

Standard name | GO_LIGASE_ACTIVITY_FORMING_PHOSPHORIC_ESTER_BONDS
Systematic name | M26452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the joining of two molecules, or two groups within a single molecule, via a phosphoric ester bond, with the concomitant hydrolysis of the diphosphate bond in ATP or a similar triphosphate. [EC:6.5, GOC:mah]
Full description |

Standard name | GO_ATPASE_ACTIVITY
Systematic name | M19090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate + 2 H+. May or may not be coupled to another reaction. [EC:3.6.1.3, GOC:jl]
Full description |

Standard name | GO_ENDODEOXYRIBONUCLEASE_ACTIVITY_PRODUCING_5_PHOSPHOMONOESTERS
Systematic name | M17920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within deoxyribonucleic acids by creating internal breaks to yield 5'-phosphomonoesters. [GOC:ai]
Full description |

Standard name | GO_ENDODEOXYRIBONUCLEASE_ACTIVITY_PRODUCING_3_PHOSPHOMONOESTERS
Systematic name | M26453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within deoxyribonucleic acids by creating internal breaks to yield 3'-phosphomonoesters. [GOC:ai]
Full description |

Standard name | GO_ENDORIBONUCLEASE_ACTIVITY_PRODUCING_5_PHOSPHOMONOESTERS
Systematic name | M18142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within ribonucleic acids by creating internal breaks to yield 5'-phosphomonoesters. [GOC:ai]
Full description |

Standard name | GO_ENDORIBONUCLEASE_ACTIVITY_PRODUCING_3_PHOSPHOMONOESTERS
Systematic name | M26454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within ribonucleic acids by creating internal breaks to yield 3'-phosphomonoesters. [GOC:ai]
Full description |

Standard name | GO_ENDONUCLEASE_ACTIVITY_ACTIVE_WITH_EITHER_RIBO_OR_DEOXYRIBONUCLEIC_ACIDS_AND_PRODUCING_5_PHOSPHOMONOESTERS
Systematic name | M8317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within nucleic acids by creating internal breaks to yield 5'-phosphomonoesters. [GOC:mah]
Full description |

Standard name | GO_ENDONUCLEASE_ACTIVITY_ACTIVE_WITH_EITHER_RIBO_OR_DEOXYRIBONUCLEIC_ACIDS_AND_PRODUCING_3_PHOSPHOMONOESTERS
Systematic name | M17986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of ester linkages within nucleic acids by creating internal breaks to yield 3'-phosphomonoesters. [GOC:mah]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_THE_ALDEHYDE_OR_OXO_GROUP_OF_DONORS
Systematic name | M9511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which an aldehyde or ketone (oxo) group acts as a hydrogen or electron donor and reduces a hydrogen or electron acceptor. [GOC:ai]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_ACETYLCHOLINE_RECEPTOR_ACTIVITY
Systematic name | M26455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with acetylcholine and transmitting the signal across the membrane by activating an associated G-protein; promotes the exchange of GDP for GTP on the alpha subunit of a heterotrimeric G-protein complex. [GOC:bf, GOC:fj, GOC:mah]
Full description |

Standard name | GO_GABA_RECEPTOR_ACTIVITY
Systematic name | M18726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with gamma-aminobutyric acid (GABA), and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. (GABA, 4-aminobutyrate) is an amino acid which acts as a neurotransmitter in some organisms. [GOC:jl, GOC:signaling, PMID:10637650]
Full description |

Standard name | GO_RETINAL_BINDING
Systematic name | M18525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with retinal, one of the forms of vitamin A. Retinal plays an important role in the visual process in most vertebrates, combining with opsins to form visual pigments in the retina. [ISBN:0198506732]
Full description |

Standard name | GO_NUCLEAR_RECEPTOR_BINDING
Systematic name | M26456
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently, in a ligand dependent manner, with a nuclear receptor protein. [GOC:mah, PMID:7776974]
Full description |

Standard name | GO_SUMO_SPECIFIC_PROTEASE_ACTIVITY
Systematic name | M26457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of peptide or isopeptide bonds within SUMO, or between the SUMO and a larger protein to which it has been conjugated. [GOC:rn, PMID:10094048, PMID:11031248, PMID:11265250]
Full description |

Standard name | GO_GALACTOSIDE_BINDING
Systematic name | M29468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any glycoside in which the sugar group is galactose. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_ACTIVIN_ACTIVATED_RECEPTOR_ACTIVITY
Systematic name | M26459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with activin and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. Activin is one of two gonadal glycoproteins related to transforming growth factor beta. [GOC:mah, GOC:signaling, ISBN:0198506732]
Full description |

Standard name | GO_MYOSIN_BINDING
Systematic name | M18958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any part of a myosin complex; myosins are any of a superfamily of molecular motor proteins that bind to actin and use the energy of ATP hydrolysis to generate force and movement along actin filaments. [GOC:mah, http://www.mrc-lmb.cam.ac.uk/myosin/Review/Reviewframeset.html]
Full description |

Standard name | GO_TBP_CLASS_PROTEIN_BINDING
Systematic name | M19065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a member of the class of TATA-binding proteins (TBP), including any of the TBP-related factors (TRFs). [GOC:jl, GOC:txnOH, http://www.mblab.gla.ac.uk/, PMID:16858867]
Full description |

Standard name | GO_RAP_GUANYL_NUCLEOTIDE_EXCHANGE_FACTOR_ACTIVITY
Systematic name | M26460
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stimulates the exchange of guanyl nucleotides associated with a GTPase of the Rap family. Under normal cellular physiological conditions, the concentration of GTP is higher than that of GDP, favoring the replacement of GDP by GTP in association with the GTPase. [GOC:mah]
Full description |

Standard name | GO_N_ACYLSPHINGOSINE_AMIDOHYDROLASE_ACTIVITY
Systematic name | M26461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: N-acylsphingosine + H2O = a fatty acid + sphingosine. [EC:3.5.1.23]
Full description |

Standard name | GO_PEPTIDE_HORMONE_BINDING
Systematic name | M18708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any peptide with hormonal activity in animals. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_RHO_GTPASE_BINDING
Systematic name | M18110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with Rho protein, any member of the Rho subfamily of the Ras superfamily of monomeric GTPases. Proteins in the Rho subfamily are involved in relaying signals from cell-surface receptors to the actin cytoskeleton. [ISBN:0198547684, PMID:12581856]
Full description |

Standard name | GO_GTP_RHO_BINDING
Systematic name | M18858
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the GTP-bound form of the Rho protein. [GOC:mah]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_NUCLEAR_PORE
Systematic name | M18343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of the nuclear pore complex, a protein-lined channel in the nuclear envelope that allows the transfer of macromolecules. [GOC:mah, PMID:25802992]
Full description |

Standard name | GO_SNRNA_BINDING
Systematic name | M18827
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a small nuclear RNA (snRNA). [GOC:mah]
Full description |

Standard name | GO_U6_SNRNA_BINDING
Systematic name | M26462
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the U6 small nuclear RNA (U6 snRNA). [GOC:mah]
Full description |

Standard name | GO_SYNTAXIN_1_BINDING
Systematic name | M17876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the SNAP receptor syntaxin-1. [GOC:ai]
Full description |

Standard name | GO_SODIUM_CHANNEL_REGULATOR_ACTIVITY
Systematic name | M18967
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a sodium channel. [GOC:mah]
Full description |

Standard name | GO_CHLORIDE_CHANNEL_REGULATOR_ACTIVITY
Systematic name | M19125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a chloride channel. [GOC:mah]
Full description |

Standard name | GO_4_GALACTOSYL_N_ACETYLGLUCOSAMINIDE_3_ALPHA_L_FUCOSYLTRANSFERASE_ACTIVITY
Systematic name | M34411
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: GDP-beta-L-fucose + beta-D-galactosyl-(1,4)-N-acetyl-D-glucosaminyl-R = GDP + 1,4-beta-D-galactosyl-(1,4)-[alpha-L-fucosyl-(1,3)]-N-acetyl-D-glucosaminyl-R. [EC:2.4.1.152, RHEA:14257]
Full description |

Standard name | GO_AU_RICH_ELEMENT_BINDING
Systematic name | M18717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a region of RNA containing frequent adenine and uridine bases. [GOC:bf, GOC:mah, PMID:7892223, PMID:8578590]
Full description |

Standard name | GO_NUCLEOSIDE_DIPHOSPHATASE_ACTIVITY
Systematic name | M18148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a nucleoside diphosphate + H2O = a nucleotide + phosphate. [EC:3.6.1.6]
Full description |

Standard name | GO_RAB_GUANYL_NUCLEOTIDE_EXCHANGE_FACTOR_ACTIVITY
Systematic name | M19195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stimulates the exchange of guanyl nucleotides associated with a GTPase of the Rab family. Under normal cellular physiological conditions, the concentration of GTP is higher than that of GDP, favoring the replacement of GDP by GTP in association with the GTPase. [GOC:mah]
Full description |

Standard name | GO_SINGLE_STRANDED_DNA_HELICASE_ACTIVITY
Systematic name | M29470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate, in the presence of single-stranded DNA; drives the unwinding of a DNA helix. [GOC:jl]
Full description |

Standard name | GO_SH3_DOMAIN_BINDING
Systematic name | M7113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a SH3 domain (Src homology 3) of a protein, small protein modules containing approximately 50 amino acid residues found in a great variety of intracellular or membrane-associated proteins. [GOC:go_curators, Pfam:PF00018]
Full description |

Standard name | GO_PHOSPHOLIPID_SCRAMBLASE_ACTIVITY
Systematic name | M26463
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the movement of phospholipids from one membrane bilayer leaflet to the other, by an ATP-independent mechanism. [GOC:cjm, PMID:20043909, PMID:20302864]
Full description |

Standard name | GO_FIBROBLAST_GROWTH_FACTOR_BINDING
Systematic name | M18407
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a fibroblast growth factor. [PMID:9806903]
Full description |

Standard name | GO_RAB_GTPASE_BINDING
Systematic name | M18429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with Rab protein, any member of the Rab subfamily of the Ras superfamily of monomeric GTPases. [GOC:mah]
Full description |

Standard name | GO_WNT_PROTEIN_BINDING
Systematic name | M18099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with Wnt-protein, a secreted growth factor involved in signaling. [GOC:jl]
Full description |

Standard name | GO_DEAD_H_BOX_RNA_HELICASE_BINDING
Systematic name | M26464
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the enzyme DEAD/H-box RNA helicase. [GOC:jl]
Full description |

Standard name | GO_SODIUM_DICARBOXYLATE_SYMPORTER_ACTIVITY
Systematic name | M26465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: dicarboxylate(out) + Na+(out) = dicarboxylate(in) + Na+(in). [GOC:ai]
Full description |

Standard name | GO_SEMAPHORIN_RECEPTOR_ACTIVITY
Systematic name | M26466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a semaphorin, and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:mah, GOC:signaling, PMID:15239958]
Full description |

Standard name | GO_RAL_GTPASE_BINDING
Systematic name | M18677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with Ral protein, any member of the Ral subfamily of the Ras superfamily of monomeric GTPases. [GOC:mah]
Full description |

Standard name | GO_ARYL_HYDROCARBON_RECEPTOR_BINDING
Systematic name | M26467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an aryl hydrocarbon receptor. [GOC:ai]
Full description |

Standard name | GO_VINCULIN_BINDING
Systematic name | M26468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with vinculin, a protein found in muscle, fibroblasts, and epithelial cells that binds actin and appears to mediate attachment of actin filaments to integral proteins of the plasma membrane. [ISBN:0721662544]
Full description |

Standard name | GO_CDP_ALCOHOL_PHOSPHATIDYLTRANSFERASE_ACTIVITY
Systematic name | M26469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: CDP + alcohol = CMP + phosphatidyl alcohol. [GOC:ai]
Full description |

Standard name | GO_SERINE_HYDROLASE_ACTIVITY
Systematic name | M4452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a substrate by a catalytic mechanism that involves a catalytic triad consisting of a serine nucleophile that is activated by a proton relay involving an acidic residue (e.g. aspartate or glutamate) and a basic residue (usually histidine). [Wikipedia:Serine_hydrolase]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_N_ACETYLGLUCOSAMINYLTRANSFERASE_ACTIVITY
Systematic name | M26470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: UDP-N-acetyl-D-glucosamine + phosphatidylinositol = UDP + N-acetyl-D-glucosaminylphosphatidylinositol. [EC:2.4.1.198]
Full description |

Standard name | GO_HISTONE_LYSINE_N_METHYLTRANSFERASE_ACTIVITY
Systematic name | M18791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + histone L-lysine = S-adenosyl-L-homocysteine + histone N6-methyl-L-lysine. The methylation of peptidyl-lysine in histones forms N6-methyl-L-lysine, N6,N6-dimethyl-L-lysine and N6,N6,N6-trimethyl-L-lysine derivatives. [EC:2.1.1.43, RESID:AA0074, RESID:AA0075, RESID:AA0076]
Full description |

Standard name | GO_ALCOHOL_DEHYDROGENASE_NAD_P_PLUS_ACTIVITY
Systematic name | M29471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an alcohol + NAD(P)+ = an aldehyde + NAD(P)H + H+. [EC:1.1.1.71]
Full description |

Standard name | GO_ALKANE_1_MONOOXYGENASE_ACTIVITY
Systematic name | M34412
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: octane + reduced rubredoxin + O2 = 1-octanol + oxidized rubredoxin + H2O. [EC:1.14.15.3]
Full description |

Standard name | GO_3_HYDROXYACYL_COA_DEHYDRATASE_ACTIVITY
Systematic name | M26471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: alkene-CoA + H2O = alcohol-CoA. Substrates are crotonoyl-CoA (producing 3-hydroxyacyl-CoA) and 2,3-didehydro-pimeloyl-CoA (producing 3-hydroxypimeloyl-CoA). [UM-BBD_ruleID:bt0291]
Full description |

Standard name | GO_GUANYL_NUCLEOTIDE_BINDING
Systematic name | M4392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with guanyl nucleotides, any compound consisting of guanosine esterified with (ortho)phosphate. [ISBN:0198506732]
Full description |

Standard name | GO_GDP_BINDING
Systematic name | M18225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with GDP, guanosine 5'-diphosphate. [GOC:ai]
Full description |

Standard name | GO_PYRIMIDINE_NUCLEOTIDE_BINDING
Systematic name | M29472
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with pyrimidine nucleotide, any compound consisting of a pyrimidine nucleoside esterified with (ortho)phosphate. [GOC:ai]
Full description |

Standard name | GO_DNA_N_GLYCOSYLASE_ACTIVITY
Systematic name | M18043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of damaged bases by cleaving the N-C1' glycosidic bond between the target damaged DNA base and the deoxyribose sugar. The reaction releases a free base and leaves an apurinic/apyrimidinic (AP) site. [GOC:elh, PMID:11554296]
Full description |

Standard name | GO_MYRISTOYLTRANSFERASE_ACTIVITY
Systematic name | M34413
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a myristoyl (CH3-[CH2]12-CO-) group to an acceptor molecule. [GOC:ai]
Full description |

Standard name | GO_TRANSMEMBRANE_RECEPTOR_PROTEIN_PHOSPHATASE_ACTIVITY
Systematic name | M18781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a signal and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity by catalysis of the reaction: a phosphoprotein + H2O = a protein + phosphate. [GOC:hjd]
Full description |

Standard name | GO_TRANSMEMBRANE_RECEPTOR_PROTEIN_KINASE_ACTIVITY
Systematic name | M14378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a signal and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity by catalysis of the reaction: a protein + ATP = a phosphoprotein + ADP. [GOC:mah]
Full description |

Standard name | GO_CARBOHYDRATE_KINASE_ACTIVITY
Systematic name | M18440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphate group, usually from ATP, to a carbohydrate substrate molecule. [GOC:jl]
Full description |

Standard name | GO_CARBOHYDRATE_PHOSPHATASE_ACTIVITY
Systematic name | M18051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: carbohydrate phosphate + H2O = carbohydrate + phosphate. [GOC:mah]
Full description |

Standard name | GO_NUCLEOBASE_CONTAINING_COMPOUND_KINASE_ACTIVITY
Systematic name | M19155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphate group, usually from ATP or GTP, to a nucleobase, nucleoside, nucleotide or polynucleotide substrate. [GOC:jl]
Full description |

Standard name | GO_NUCLEOSIDE_KINASE_ACTIVITY
Systematic name | M18405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + nucleoside = ADP + nucleoside monophosphate. [GOC:ai]
Full description |

Standard name | GO_KINASE_REGULATOR_ACTIVITY
Systematic name | M7387
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a kinase, an enzyme which catalyzes of the transfer of a phosphate group, usually from ATP, to a substrate molecule. [GOC:ai]
Full description |

Standard name | GO_PHOSPHATASE_REGULATOR_ACTIVITY
Systematic name | M19186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a phosphatase, an enzyme which catalyzes of the removal of a phosphate group from a substrate molecule. [GOC:ai]
Full description |

Standard name | GO_KINASE_ACTIVATOR_ACTIVITY
Systematic name | M12088
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and increases the activity of a kinase, an enzyme which catalyzes of the transfer of a phosphate group, usually from ATP, to a substrate molecule. [GOC:ai]
Full description |

Standard name | GO_KINASE_INHIBITOR_ACTIVITY
Systematic name | M4920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a kinase, an enzyme which catalyzes of the transfer of a phosphate group, usually from ATP, to a substrate molecule. [GOC:mah]
Full description |

Standard name | GO_PHOSPHATASE_ACTIVATOR_ACTIVITY
Systematic name | M18197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Increases the activity of a phosphatase, an enzyme which catalyzes of the removal of a phosphate group from a substrate molecule. [GOC:ai]
Full description |

Standard name | GO_PHOSPHATASE_INHIBITOR_ACTIVITY
Systematic name | M17952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a phosphatase, an enzyme which catalyzes of the removal of a phosphate group from a substrate molecule. [GOC:ai]
Full description |

Standard name | GO_DEACETYLASE_ACTIVITY
Systematic name | M18992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of an acetyl group or groups from a substrate molecule. [GOC:jl]
Full description |

Standard name | GO_INTERMEDIATE_FILAMENT_BINDING
Systematic name | M18545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an intermediate filament, a distinct elongated structure, characteristically 10 nm in diameter, that occurs in the cytoplasm of higher eukaryotic cells. Intermediate filaments form a fibrous system, composed of chemically heterogeneous subunits and involved in mechanically integrating the various components of the cytoplasmic space. [ISBN:0198506732]
Full description |

Standard name | GO_CENTROMERIC_DNA_BINDING
Systematic name | M26472
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a centromere, a region of chromosome where the spindle fibers attach during mitosis and meiosis. [GOC:jl, SO:0000577]
Full description |

Standard name | GO_CYCLOHYDROLASE_ACTIVITY
Systematic name | M26473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of any non-peptide carbon-nitrogen bond in a cyclic amidine, a compound of the form R-C(=NH)-NH2, in a reaction that involves the opening of a ring. [GOC:mah]
Full description |

Standard name | GO_DEAMINASE_ACTIVITY
Systematic name | M19047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of an amino group from a substrate, producing ammonia (NH3). [GOC:jl]
Full description |

Standard name | GO_OXALATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of oxalate from one side of a membrane to the other. Oxalate, or ethanedioic acid, occurs in many plants and is highly toxic to animals. [ISBN:0198506732]
Full description |

Standard name | GO_TOXIN_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a toxin from one side of a membrane to the other. A toxin is a poisonous compound (typically a protein) that is produced by cells or organisms and that can cause disease when introduced into the body or tissues of an organism. [ISBN:0198506732]
Full description |

Standard name | GO_IMMUNOGLOBULIN_RECEPTOR_ACTIVITY
Systematic name | M26476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with the Fc region of an immunoglobulin protein and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:signaling, ISBN:0198547684]
Full description |

Standard name | GO_UBIQUITIN_LIKE_PROTEIN_SPECIFIC_PROTEASE_ACTIVITY
Systematic name | M19020
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of peptide or isopeptide bonds within small proteins such as ubiquitin or ubiquitin-like proteins (e.g. APG8, ISG15, NEDD8, SUMO), or between the small protein and a larger protein to which it has been conjugated. [GOC:ma, GOC:mah]
Full description |

Standard name | GO_NEDD8_SPECIFIC_PROTEASE_ACTIVITY
Systematic name | M26477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of NEDD8, a small ubiquitin-related modifier, from previously neddylated substrates. [GOC:mah]
Full description |

Standard name | GO_UBIQUITIN_LIKE_PROTEIN_TRANSFERASE_ACTIVITY
Systematic name | M17834
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a ubiquitin-like from one protein to another via the reaction X-ULP + Y --> Y-ULP + X, where both X-ULP and Y-ULP are covalent linkages. ULP represents a ubiquitin-like protein. [GOC:mah, GOC:rn, PMID:10806345, PMID:10884686]
Full description |

Standard name | GO_NEDD8_TRANSFERASE_ACTIVITY
Systematic name | M26478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of NEDD8 from one protein to another via the reaction X-NEDD8 + Y --> Y-NEDD8 + X, where both X-NEDD8 and Y-NEDD8 are covalent linkages. [GOC:mah]
Full description |

Standard name | GO_SUMO_TRANSFERASE_ACTIVITY
Systematic name | M18557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of SUMO from one protein to another via the reaction X-SUMO + Y --> Y-SUMO + X, where both X-SUMO and Y-SUMO are covalent linkages. [GOC:rn, PMID:11031248, PMID:11265250]
Full description |

Standard name | GO_PROCOLLAGEN_PROLINE_DIOXYGENASE_ACTIVITY
Systematic name | M26479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: procollagen L-proline + 2-oxoglutarate + O2 = procollagen trans-hydroxy-L-proline + succinate + CO2. [EC:1.14.11.2, EC:1.14.11.7, GOC:mah]
Full description |

Standard name | GO_OXYGEN_BINDING
Systematic name | M16305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with oxygen (O2). [GOC:jl]
Full description |

Standard name | GO_ASPARTIC_TYPE_ENDOPEPTIDASE_INHIBITOR_ACTIVITY
Systematic name | M29473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of aspartic-type endopeptidases, enzymes that catalyze the hydrolysis of nonterminal peptide bonds in a polypeptide chain; the optimum reaction pH is below 5 due to an aspartic residue involved in the catalytic process. [GOC:ai]
Full description |

Standard name | GO_PHOSPHOLIPASE_A2_INHIBITOR_ACTIVITY
Systematic name | M26480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of the enzyme phospholipase A2. [GOC:ai]
Full description |

Standard name | GO_GROWTH_FACTOR_BINDING
Systematic name | M6854
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any growth factor, proteins or polypeptides that stimulate a cell or organism to grow or proliferate. [GOC:curators]
Full description |

Standard name | GO_ISOPRENOID_BINDING
Systematic name | M18637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any isoprenoid compound, isoprene (2-methylbuta-1,3-diene) or compounds containing or derived from linked isoprene (3-methyl-2-butenylene) residues. [GOC:jl]
Full description |

Standard name | GO_RETINOL_BINDING
Systematic name | M18925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with retinol, vitamin A1, 2,6,6-trimethyl-1-(9'-hydroxy-3',7'-dimethylnona-1',3',5',7'-tetraenyl)cyclohex-1-ene, one of the three components that makes up vitamin A. Retinol is an intermediate in the vision cycle and it also plays a role in growth and differentiation. [GOC:curators]
Full description |

Standard name | GO_VITAMIN_BINDING
Systematic name | M18676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a vitamin, one of a number of unrelated organic substances that occur in many foods in small amounts and that are necessary in trace amounts for the normal metabolic functioning of the body. [GOC:ai]
Full description |

Standard name | GO_RRNA_BINDING
Systematic name | M18668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with ribosomal RNA. [GOC:jl]
Full description |

Standard name | GO_CALCIUM_CHANNEL_INHIBITOR_ACTIVITY
Systematic name | M26481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents, or reduces the activity of a calcium channel. [GOC:mah]
Full description |

Standard name | GO_IGE_BINDING
Systematic name | M26482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an immunoglobulin of the IgE isotype. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_IGG_BINDING
Systematic name | M18986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an immunoglobulin of an IgG isotype. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_IMMUNOGLOBULIN_BINDING
Systematic name | M17868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an immunoglobulin. [GOC:ma]
Full description |

Standard name | GO_CHLORIDE_CHANNEL_INHIBITOR_ACTIVITY
Systematic name | M26483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents, or reduces the activity of a chloride channel. [GOC:mah]
Full description |

Standard name | GO_POTASSIUM_CHANNEL_INHIBITOR_ACTIVITY
Systematic name | M26484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents, or reduces the activity of a potassium channel. [GOC:mah]
Full description |

Standard name | GO_SODIUM_CHANNEL_INHIBITOR_ACTIVITY
Systematic name | M26485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents, or reduces the activity of a sodium channel. [GOC:mah]
Full description |

Standard name | GO_KINESIN_BINDING
Systematic name | M18710
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently and stoichiometrically with kinesin, a member of a superfamily of microtubule-based motor proteins that perform force-generating tasks such as organelle transport and chromosome segregation. [GOC:curators, PMID:8606779]
Full description |

Standard name | GO_KINASE_BINDING
Systematic name | M18835
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a kinase, any enzyme that catalyzes the transfer of a phosphate group. [GOC:jl]
Full description |

Standard name | GO_PHOSPHATASE_BINDING
Systematic name | M18384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any phosphatase. [GOC:jl]
Full description |

Standard name | GO_PROTEIN_PHOSPHATASE_BINDING
Systematic name | M17974
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any protein phosphatase. [GOC:jl]
Full description |

Standard name | GO_PROTEIN_DOMAIN_SPECIFIC_BINDING
Systematic name | M7630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a specific domain of a protein. [GOC:go_curators]
Full description |

Standard name | GO_SYNTAXIN_BINDING
Systematic name | M17960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a syntaxin, a SNAP receptor involved in the docking of synaptic vesicles at the presynaptic zone of a synapse. [ISBN:0198506732]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_MYELIN_SHEATH
Systematic name | M26486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of the myelin sheath of a nerve. [GOC:mah]
Full description |

Standard name | GO_CYTOKINE_BINDING
Systematic name | M18255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a cytokine, any of a group of proteins that function to control the survival, growth and differentiation of tissues and cells, and which have autocrine and paracrine activity. [GOC:ai, GOC:bf, ISBN:0198599471]
Full description |

Standard name | GO_CHEMOKINE_BINDING
Systematic name | M18707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a chemokine. Chemokines are a family of small chemotactic cytokines; their name is derived from their ability to induce directed chemotaxis in nearby responsive cells. All chemokines possess a number of conserved cysteine residues involved in intramolecular disulfide bond formation. Some chemokines are considered pro-inflammatory and can be induced during an immune response to recruit cells of the immune system to a site of infection, while others are considered homeostatic and are involved in controlling the migration of cells during normal processes of tissue maintenance or development. Chemokines are found in all vertebrates, some viruses and some bacteria. [GOC:ai, GOC:BHF, GOC:rl, PMID:12183377, Wikipedia:Chemokine]
Full description |

Standard name | GO_C_C_CHEMOKINE_BINDING
Systematic name | M26487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a C-C chemokine; C-C chemokines do not have an amino acid between the first two cysteines of the characteristic four-cysteine motif. [GOC:ai]
Full description |

Standard name | GO_C_X_C_CHEMOKINE_BINDING
Systematic name | M26488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a C-X-C chemokine; C-X-C chemokines have a single amino acid between the first two cysteines of the characteristic four cysteine motif. [GOC:ai]
Full description |

Standard name | GO_C_X3_C_CHEMOKINE_BINDING
Systematic name | M26489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a C-X3-C chemokine; C-X3-C chemokines have three amino acids between the first two cysteines of the characteristic four-cysteine motif. [GOC:ai]
Full description |

Standard name | GO_INTERLEUKIN_1_BINDING
Systematic name | M26490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with interleukin-1. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_DIACYLGLYCEROL_BINDING
Systematic name | M18364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with diacylglycerol, a diester of glycerol and two fatty acids. [GOC:ma]
Full description |

Standard name | GO_PASSIVE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a single solute from one side of a membrane to the other by a mechanism involving conformational change, either by facilitated diffusion or in a membrane potential dependent process if the solute is charged. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_ACTIVE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a specific substance or related group of substances from one side of a membrane to the other, up the solute's concentration gradient. The transporter binds the solute and undergoes a series of conformational changes. Transport works equally well in either direction. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_POTASSIUM_ION_ANTIPORTER_ACTIVITY
Systematic name | M26491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the active transport of a potassium ion across a membrane by a mechanism whereby two or more species are transported in opposite directions in a tightly coupled process not directly linked to a form of energy other than chemiosmotic energy. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_WIDE_PORE_CHANNEL_ACTIVITY
Systematic name | M18665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transport of a solute across a membrane via a large pore, un-gated channel. Examples include gap junctions, which transport substances from one cell to another; and porins which transport substances in and out of bacteria, mitochondria and chloroplasts. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_TRANSMITTER_GATED_CHANNEL_ACTIVITY
Systematic name | M17983
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a solute by a channel that opens when a specific neurotransmitter has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_GATED_CHANNEL_ACTIVITY
Systematic name | M18082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a solute by a channel that opens in response to a specific stimulus. [GOC:mtg_transport]
Full description |

Standard name | GO_ION_GATED_CHANNEL_ACTIVITY
Systematic name | M29475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a solute by a channel that opens in response to a specific ion stimulus. [GOC:mtg_transport]
Full description |

Standard name | GO_POTASSIUM_ION_LEAK_CHANNEL_ACTIVITY
Systematic name | M26492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transport of a potassium ion across a membrane via a narrow pore channel that is open even in an unstimulated or 'resting' state. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_NARROW_PORE_CHANNEL_ACTIVITY
Systematic name | M17932
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transport of a solute across a membrane via a narrow pore channel that may be gated or ungated. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_VOLTAGE_GATED_CATION_CHANNEL_ACTIVITY
Systematic name | M17981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a cation by a voltage-gated channel. A cation is a positively charged ion. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_ACETYLCHOLINE_GATED_CATION_SELECTIVE_CHANNEL_ACTIVITY
Systematic name | M26493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Selectively enables the transmembrane transfer of a cation by a channel that opens upon binding acetylcholine. [GOC:mah, PMID:2466967]
Full description |

Standard name | GO_GLUTAMATE_GATED_CALCIUM_ION_CHANNEL_ACTIVITY
Systematic name | M26494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a calcium ion by a channel that opens when glutamate has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_SEROTONIN_GATED_CATION_SELECTIVE_CHANNEL_ACTIVITY
Systematic name | M26495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a cation by a channel that opens when serotonin has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_GABA_GATED_CHLORIDE_ION_CHANNEL_ACTIVITY
Systematic name | M26496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a chloride ion by a channel that opens when GABA has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_ACTIVE_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M17881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of an ion from one side of a membrane to the other up the solute's concentration gradient. This is carried out by binding the solute and undergoing a series of conformational changes. Transport works equally well in either direction. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_ALANINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of alanine from one side of a membrane to the other. Alanine is 2-aminopropanoic acid. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_MACROMOLECULE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a macromolecule from one side of a membrane to the other. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_SERINE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of serine from one side of a membrane to the other. Serine is 2-amino-3-hydroxypropanoic acid. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_MHC_PROTEIN_COMPLEX_BINDING
Systematic name | M17871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the major histocompatibility complex. [GOC:mtg_signal, GOC:vw]
Full description |

Standard name | GO_MHC_CLASS_I_PROTEIN_COMPLEX_BINDING
Systematic name | M29476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the class I major histocompatibility complex. [GOC:mtg_signal, GOC:vw]
Full description |

Standard name | GO_MHC_CLASS_II_PROTEIN_COMPLEX_BINDING
Systematic name | M18505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the class II major histocompatibility complex. [GOC:mtg_signal, GOC:vw]
Full description |

Standard name | GO_MHC_CLASS_IB_PROTEIN_BINDING
Systematic name | M26499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with major histocompatibility complex class Ib molecules. [GOC:mtg_signal, GOC:vw]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX_STRUCTURAL_CONSTITUENT_CONFERRING_TENSILE_STRENGTH
Systematic name | M26500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A constituent of the extracellular matrix that enables the matrix to resist longitudinal stress. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX_STRUCTURAL_CONSTITUENT_CONFERRING_COMPRESSION_RESISTANCE
Systematic name | M26501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A constituent of the extracellular matrix that enables the matrix to resist compressive forces; often a proteoglycan. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX_CONSTITUENT_CONFERRING_ELASTICITY
Systematic name | M26502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A component of the extracellular matrix that enables the matrix to recoil after transient stretching. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_MANGANESE_ION_BINDING
Systematic name | M18243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with manganese (Mn) ions. [GOC:ai]
Full description |

Standard name | GO_BENZODIAZEPINE_RECEPTOR_BINDING
Systematic name | M26503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the peripheral benzodiazepine receptor (PBR). [GOC:ceb, GOC:mah, PMID:9915832]
Full description |

Standard name | GO_SIGNALING_RECEPTOR_COMPLEX_ADAPTOR_ACTIVITY
Systematic name | M18838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding activity of a molecule that provides a physical support for the assembly of a multiprotein receptor signaling complex. [GOC:mah]
Full description |

Standard name | GO_PDZ_DOMAIN_BINDING
Systematic name | M6526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a PDZ domain of a protein, a domain found in diverse signaling proteins. [GOC:go_curators, Pfam:PF00595]
Full description |

Standard name | GO_LOW_DENSITY_LIPOPROTEIN_PARTICLE_BINDING
Systematic name | M18096
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a low-density lipoprotein particle, a lipoprotein particle that is rich in cholesterol esters and low in triglycerides, is typically composed of APOB100 and APOE, and has a density of 1.02-1.06 g/ml and a diameter of between 20-25 nm. [GOC:mah]
Full description |

Standard name | GO_SEMAPHORIN_RECEPTOR_BINDING
Systematic name | M19120
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with semaphorin receptors. [GOC:ceb, PMID:12001990]
Full description |

Standard name | GO_LIPOPROTEIN_PARTICLE_RECEPTOR_ACTIVITY
Systematic name | M18721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a lipoprotein particle and delivering the lipoprotein particle into the cell via endocytosis. A lipoprotein particle, also known as a lipoprotein, is a clathrate complex consisting of a lipid enwrapped in a protein host without covalent binding in such a way that the complex has a hydrophilic outer surface consisting of all the protein and the polar ends of any phospholipids. [GOC:bf, GOC:mah, PMID:12827279]
Full description |

Standard name | GO_ENZYME_REGULATOR_ACTIVITY
Systematic name | M18829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and modulates the activity of an enzyme. [GOC:dph, GOC:mah, GOC:tb]
Full description |

Standard name | GO_NITRIC_OXIDE_SYNTHASE_REGULATOR_ACTIVITY
Systematic name | M26505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of nitric oxide synthase. [GOC:mah]
Full description |

Standard name | GO_CARBOHYDRATE_BINDING
Systematic name | M9636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any carbohydrate, which includes monosaccharides, oligosaccharides and polysaccharides as well as substances derived from monosaccharides by reduction of the carbonyl group (alditols), by oxidation of one or more hydroxy groups to afford the corresponding aldehydes, ketones, or carboxylic acids, or by replacement of one or more hydroxy group(s) by a hydrogen atom. Cyclitols are generally not regarded as carbohydrates. [GOC:mah]
Full description |

Standard name | GO_POLYSACCHARIDE_BINDING
Systematic name | M19396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any polysaccharide, a polymer of many (typically more than 10) monosaccharide residues linked glycosidically. [GOC:mah]
Full description |

Standard name | GO_GUANYLATE_CYCLASE_REGULATOR_ACTIVITY
Systematic name | M26506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of guanylate cyclase. [GOC:mah]
Full description |

Standard name | GO_LIM_DOMAIN_BINDING
Systematic name | M26507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a LIM domain (for Lin-11 Isl-1 Mec-3) of a protein, a domain with seven conserved cysteine residues and a histidine, that binds two zinc ions and acts as an interface for protein-protein interactions. [GOC:go_curators, Pfam:PF00412]
Full description |

Standard name | GO_LRR_DOMAIN_BINDING
Systematic name | M18561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a LRR domain (leucine rich repeats) of a protein. [GOC:go_curators, Pfam:PF00560]
Full description |

Standard name | GO_CLATHRIN_BINDING
Systematic name | M18189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a clathrin heavy or light chain, the main components of the coat of coated vesicles and coated pits, and which also occurs in synaptic vesicles. [GOC:jl, GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_SKIN_EPIDERMIS
Systematic name | M26508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of an epidermal cutaneous structure. [GOC:mah]
Full description |

Standard name | GO_TESTOSTERONE_DEHYDROGENASE_NAD_P_ACTIVITY
Systematic name | M29477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: testosterone + NAD(P)+ = androst-4-ene-3,17-dione + NAD(P)H + H+. [EC:1.1.1.51]
Full description |

Standard name | GO_ESTROGEN_RECEPTOR_ACTIVITY
Systematic name | M26509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with estrogen and transmitting the signal within the cell to trigger a change in cell activity or function. [GOC:signaling, PMID:17615392]
Full description |

Standard name | GO_PROTEIN_SERINE_THREONINE_KINASE_INHIBITOR_ACTIVITY
Systematic name | M18368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a protein serine/threonine kinase. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_TYROSINE_KINASE_ACTIVATOR_ACTIVITY
Systematic name | M19229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Increases the activity of a protein tyrosine kinase, an enzyme which phosphorylates a tyrosyl phenolic group on a protein. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_TRANSMEMBRANE_RECEPTOR_PROTEIN_TYROSINE_KINASE_ACTIVATOR_ACTIVITY
Systematic name | M26510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and increases the activity of a transmembrane receptor protein tyrosine kinase. [GOC:mah]
Full description |

Standard name | GO_ADP_RIBOSYLATION_FACTOR_BINDING
Systematic name | M26511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with ARF, ADP-ribosylation factor, a small monomeric cytosolic GTPase that, when bound to GTP, binds to the membranes of cells. [ISBN:0198506732]
Full description |

Standard name | GO_ESTROGEN_RECEPTOR_BINDING
Systematic name | M18031
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an estrogen receptor. [GOC:ai]
Full description |

Standard name | GO_CYCLIN_BINDING
Systematic name | M17994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with cyclins, proteins whose levels in a cell varies markedly during the cell cycle, rising steadily until mitosis, then falling abruptly to zero. As cyclins reach a threshold level, they are thought to drive cells into G2 phase and thus to mitosis. [GOC:ai]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_TOOTH_ENAMEL
Systematic name | M26512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of tooth enamel. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_PHOSPHATASE_2B_BINDING
Systematic name | M26513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the enzyme protein phosphatase 2B. [GOC:jl]
Full description |

Standard name | GO_INTERLEUKIN_17_RECEPTOR_ACTIVITY
Systematic name | M26514
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with any member of the interleukin-17 family of cytokines and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:add, GOC:jl, GOC:signaling]
Full description |

Standard name | GO_TRANSLATION_REPRESSOR_ACTIVITY
Systematic name | M18886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Antagonizes ribosome-mediated translation of mRNA into a polypeptide. [GOC:ai, GOC:clt]
Full description |

Standard name | GO_NUCLEAR_RECEPTOR_TRANSCRIPTION_COACTIVATOR_ACTIVITY
Systematic name | M26515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The function of a transcription cofactor that activates transcription in conjuction with a ligand-dependent nuclear receptor from a RNA polymerase II promoter; does not bind DNA itself. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_HEMOGLOBIN_BINDING
Systematic name | M26516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with hemoglobin, an oxygen carrying, conjugated protein containing four heme groups and globin. [GOC:jl]
Full description |

Standard name | GO_ANKYRIN_BINDING
Systematic name | M18041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with ankyrin, a 200 kDa cytoskeletal protein that attaches other cytoskeletal proteins to integral membrane proteins. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_SPECTRIN_BINDING
Systematic name | M18603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with spectrin, a protein that is the major constituent of the erythrocyte cytoskeletal network. It associates with band 4.1 (see band protein) and actin to form the cytoskeletal superstructure of the erythrocyte plasma membrane. It is composed of nonhomologous chains, alpha and beta, which aggregate side-to-side in an antiparallel fashion to form dimers, tetramers, and higher polymers. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_SNORNA_BINDING
Systematic name | M19222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with small nucleolar RNA. [GOC:mah]
Full description |

Standard name | GO_TRIPLET_CODON_AMINO_ACID_ADAPTOR_ACTIVITY
Systematic name | M34414
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The codon binding activity of a tRNA that positions an activated amino acid, mediating its insertion at the correct point in the sequence of a nascent polypeptide chain during protein synthesis. [GOC:hjd, GOC:mtg_MIT_16mar07, ISBN:0198506732]
Full description |

Standard name | GO_HSP70_PROTEIN_BINDING
Systematic name | M18826
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with Hsp70 proteins, any of a group of heat shock proteins around 70kDa in size. [ISBN:0198506732]
Full description |

Standard name | GO_RECEPTOR_REGULATOR_ACTIVITY
Systematic name | M19073
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The function of interacting (directly or indirectly) with receptors such that the proportion of receptors in the active form is changed. [GOC:ceb]
Full description |

Standard name | GO_RECEPTOR_INHIBITOR_ACTIVITY
Systematic name | M19117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The function of interacting (directly or indirectly) with receptors such that the proportion of receptors in the active form is decreased. [GOC:ceb]
Full description |

Standard name | GO_ACETYLCHOLINE_RECEPTOR_INHIBITOR_ACTIVITY
Systematic name | M26518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting (directly or indirectly) with acetylcholine receptors such that the proportion of receptors in the active form is decreased. [GOC:mah]
Full description |

Standard name | GO_CYCLIC_NUCLEOTIDE_BINDING
Systematic name | M18452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a cyclic nucleotide, a nucleotide in which the phosphate group is in diester linkage to two positions on the sugar residue. [GOC:ai]
Full description |

Standard name | GO_CAMP_BINDING
Systematic name | M18253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with cAMP, the nucleotide cyclic AMP (adenosine 3',5'-cyclophosphate). [GOC:ai]
Full description |

Standard name | GO_CGMP_BINDING
Systematic name | M18599
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with cGMP, the nucleotide cyclic GMP (guanosine 3',5'-cyclophosphate). [GOC:ai]
Full description |

Standard name | GO_ADENYL_NUCLEOTIDE_BINDING
Systematic name | M19102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with adenyl nucleotides, any compound consisting of adenosine esterified with (ortho)phosphate. [ISBN:0198506732]
Full description |

Standard name | GO_NEUROTRANSMITTER_RECEPTOR_ACTIVITY
Systematic name | M18960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a neurotransmitter and transmitting the signal to initiate a change in cell activity. [GOC:jl, GOC:signaling]
Full description |

Standard name | GO_U1_SNRNA_BINDING
Systematic name | M26520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the U1 small nuclear RNA (U1 snRNA). [GOC:mah]
Full description |

Standard name | GO_U2_SNRNA_BINDING
Systematic name | M29478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the U2 small nuclear RNA (U2 snRNA). [GOC:jl]
Full description |

Standard name | GO_U4_SNRNA_BINDING
Systematic name | M26521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the U4 small nuclear RNA (U4 snRNA). [GOC:jl]
Full description |

Standard name | GO_PRE_MRNA_5_SPLICE_SITE_BINDING
Systematic name | M34415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the pre-mRNA 5' splice site sequence. [GOC:jl]
Full description |

Standard name | GO_PRE_MRNA_3_SPLICE_SITE_BINDING
Systematic name | M26523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the pre-mRNA 3' splice site sequence. [GOC:jl]
Full description |

Standard name | GO_PROTEIN_MACROMOLECULE_ADAPTOR_ACTIVITY
Systematic name | M5345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding activity of a protein that brings together two macromolecules in contact, permitting those molecules to function in a coordinated way. The adaptor can bring together two proteins, or a protein and another macromolecule such as a lipid or a nucleic acid. [GOC:bf, GOC:mah, GOC:vw]
Full description |

Standard name | GO_RAC_GUANYL_NUCLEOTIDE_EXCHANGE_FACTOR_ACTIVITY
Systematic name | M18019
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stimulates the exchange of guanyl nucleotides associated with a GTPase of the Rac family. Under normal cellular physiological conditions, the concentration of GTP is higher than that of GDP, favoring the replacement of GDP by GTP in association with the GTPase. [GOC:mah]
Full description |

Standard name | GO_GTPASE_REGULATOR_ACTIVITY
Systematic name | M5352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the rate of GTP hydrolysis by a GTPase. [GOC:mah]
Full description |

Standard name | GO_GTP_DEPENDENT_PROTEIN_BINDING
Systematic name | M19028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any protein or protein complex (a complex of two or more proteins that may include other nonprotein molecules) when at least one of the interacting partners is in the GTP-bound state. [GOC:go_curators, GOC:krc]
Full description |

Standard name | GO_BETA_2_MICROGLOBULIN_BINDING
Systematic name | M17891
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with beta-2-microglobulin. [GOC:mah]
Full description |

Standard name | GO_LIPID_ANTIGEN_BINDING
Systematic name | M26525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a lipid antigen. [PMID:14500461]
Full description |

Standard name | GO_ENDOGENOUS_LIPID_ANTIGEN_BINDING
Systematic name | M34416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an endogenous cellular lipid antigen. [PMID:14500461]
Full description |

Standard name | GO_ACTIN_DEPENDENT_ATPASE_ACTIVITY
Systematic name | M18939
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate. This reaction requires the presence of an actin filament to accelerate release of ADP and phosphate. [GOC:mah]
Full description |

Standard name | GO_TPR_DOMAIN_BINDING
Systematic name | M26526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a tetratricopeptide repeat (TPR) domain of a protein, the consensus sequence of which is defined by a pattern of small and large hydrophobic amino acids and a structure composed of helices. [GOC:mah]
Full description |

Standard name | GO_POTASSIUM_ION_BINDING
Systematic name | M18808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with potassium (K+) ions. [GOC:mah]
Full description |

Standard name | GO_TAT_PROTEIN_BINDING
Systematic name | M26527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with Tat, a viral transactivating regulatory protein from the human immunodeficiency virus, or the equivalent protein from another virus. [GOC:mah, PMID:9094689]
Full description |

Standard name | GO_RECEPTOR_TYROSINE_KINASE_BINDING
Systematic name | M26528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a receptor that possesses protein tyrosine kinase activity. [GOC:mah]
Full description |

Standard name | GO_THIAMINE_PYROPHOSPHATE_BINDING
Systematic name | M26529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with thiamine pyrophosphate, the diphosphoric ester of thiamine. Acts as a coenzyme of several (de)carboxylases, transketolases, and alpha-oxoacid dehydrogenases. [GOC:mlg]
Full description |

Standard name | GO_MISMATCHED_DNA_BINDING
Systematic name | M18427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with double-stranded DNA containing one or more mismatches. [GOC:mah]
Full description |

Standard name | GO_FILAMIN_BINDING
Systematic name | M18554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a filamin, any member of a family of high molecular mass cytoskeletal proteins that crosslink actin filaments to form networks and stress fibers. Filamins contain an amino-terminal alpha-actinin-like actin binding domain, which is followed by a rod-domain composed of 4 to 24 100-residue repetitive segments including a carboxy-terminal dimerization domain. [GOC:mah, PMID:11336782]
Full description |

Standard name | GO_TROPONIN_I_BINDING
Systematic name | M26530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with troponin I, the inhibitory subunit of the troponin complex. [GOC:mah, ISBN:0815316194]
Full description |

Standard name | GO_HEAT_SHOCK_PROTEIN_BINDING
Systematic name | M17893
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a heat shock protein, any protein synthesized or activated in response to heat shock. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_HISTONE_DEACETYLASE_ACTIVITY_H3_K14_SPECIFIC
Systematic name | M19179
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: histone H3 N6-acetyl-L-lysine (position 14) + H2O = histone H3 L-lysine (position 14) + acetate. This reaction represents the removal of an acetyl group from lysine at position 14 of the histone H3 protein. [EC:3.5.1.17, RHEA:24548]
Full description |

Standard name | GO_SMALL_GTPASE_BINDING
Systematic name | M15628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a small monomeric GTPase. [GOC:mah]
Full description |

Standard name | GO_TRANSLATION_INITIATION_FACTOR_BINDING
Systematic name | M18612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a translation initiation factor, any polypeptide factor involved in the initiation of ribosome-mediated translation. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_TAG
Systematic name | M26532
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A molecular function exhibited by a protein that is covalently attached (AKA tagged or conjugated) to another protein where it acts as a marker, recognized by the cellular apparatus to target the tagged protein for some cellular process such as modification, sequestration, transport or degradation. [GOC:dos, GOC:go_curators, PMID:19028679, PMID:20054389, PMID:6305978]
Full description |

Standard name | GO_SODIUM_ION_BINDING
Systematic name | M19079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with sodium ions (Na+). [GOC:mah]
Full description |

Standard name | GO_CHLORIDE_ION_BINDING
Systematic name | M26533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with chloride ions (Cl-). [GOC:mah]
Full description |

Standard name | GO_L_ASCORBIC_ACID_BINDING
Systematic name | M18269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with L-ascorbic acid, (2R)-2-[(1S)-1,2-dihydroxyethyl]-4-hydroxy-5-oxo-2,5-dihydrofuran-3-olate; L-ascorbic acid is vitamin C and has co-factor and anti-oxidant activities in many species. [GOC:mah]
Full description |

Standard name | GO_COBALAMIN_BINDING
Systematic name | M26534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with cobalamin (vitamin B12), a water-soluble vitamin characterized by possession of a corrin nucleus containing a cobalt atom. [GOC:mah]
Full description |

Standard name | GO_ALKALI_METAL_ION_BINDING
Systematic name | M18586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any alkali metal ion; alkali metals are those elements in group Ia of the periodic table, with the exception of hydrogen. [GOC:mah]
Full description |

Standard name | GO_TITIN_BINDING
Systematic name | M18819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with titin, any of a family of giant proteins found in striated and smooth muscle. In striated muscle, single titin molecules span half the sarcomere, with their N- and C-termini in the Z-disc and M-line, respectively. [GOC:mah, PMID:10481174]
Full description |

Standard name | GO_TELETHONIN_BINDING
Systematic name | M26535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with telethonin, a protein found in the Z disc of striated muscle and which is a substrate of the titin kinase. [GOC:mah, PMID:10481174]
Full description |

Standard name | GO_MITOGEN_ACTIVATED_PROTEIN_KINASE_KINASE_BINDING
Systematic name | M17903
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a mitogen-activated protein kinase kinase, any protein that can phosphorylate a MAP kinase. [GOC:mah]
Full description |

Standard name | GO_MITOGEN_ACTIVATED_PROTEIN_KINASE_KINASE_KINASE_BINDING
Systematic name | M18906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a mitogen-activated protein kinase kinase kinase, any protein that can phosphorylate a MAP kinase kinase. [GOC:bf]
Full description |

Standard name | GO_MYOSIN_V_BINDING
Systematic name | M18842
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a class V myosin; myosin V is a dimeric molecule involved in intracellular transport. [GOC:mah, http://www.mrc-lmb.cam.ac.uk/myosin/Review/Reviewframeset.html]
Full description |

Standard name | GO_CHROMATIN_DNA_BINDING
Systematic name | M18447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with DNA that is assembled into chromatin. [GOC:mah]
Full description |

Standard name | GO_NUCLEOSOME_BINDING
Systematic name | M18054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a nucleosome, a complex comprised of DNA wound around a multisubunit core and associated proteins, which forms the primary packing unit of DNA into higher order structures. [GOC:mah]
Full description |

Standard name | GO_NUCLEOSOMAL_DNA_BINDING
Systematic name | M18932
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the DNA portion of a nucleosome. [GOC:mah]
Full description |

Standard name | GO_NUCLEOSOMAL_HISTONE_BINDING
Systematic name | M29479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a histone that is assembled into a nucleosome. [GOC:mah]
Full description |

Standard name | GO_PEPTIDYL_PROLINE_DIOXYGENASE_ACTIVITY
Systematic name | M26536
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: peptidyl L-proline + 2-oxoglutarate + O2 = peptidyl hydroxy-L-proline + succinate + CO2. [GOC:mah, GOC:vw, PMID:24550447, PMID:24550462]
Full description |

Standard name | GO_PEPTIDYL_PROLINE_4_DIOXYGENASE_ACTIVITY
Systematic name | M26537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: peptidyl L-proline + 2-oxoglutarate + O2 = peptidyl trans-4-hydroxy-L-proline + succinate + CO2. [GOC:mah]
Full description |

Standard name | GO_POLYUBIQUITIN_MODIFICATION_DEPENDENT_PROTEIN_BINDING
Systematic name | M26538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein upon poly-ubiquitination of the target protein. [GOC:pg]
Full description |

Standard name | GO_UBIQUITIN_CONJUGATING_ENZYME_BINDING
Systematic name | M34417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a ubiquitin conjugating enzyme, any of the E2 proteins. [GOC:vp]
Full description |

Standard name | GO_OPIOID_RECEPTOR_BINDING
Systematic name | M26540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an opioid receptor. [GOC:nln]
Full description |

Standard name | GO_G_PROTEIN_BETA_SUBUNIT_BINDING
Systematic name | M26541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a G-protein beta subunit. [GOC:mah]
Full description |

Standard name | GO_G_PROTEIN_GAMMA_SUBUNIT_BINDING
Systematic name | M34418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a G-protein gamma subunit. [GOC:mah]
Full description |

Standard name | GO_G_PROTEIN_BETA_GAMMA_SUBUNIT_COMPLEX_BINDING
Systematic name | M18922
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a complex of G-protein beta/gamma subunits. [GOC:nln, GOC:vw]
Full description |

Standard name | GO_ADENOSINE_RECEPTOR_BINDING
Systematic name | M29480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an adenosine receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_ADRENERGIC_RECEPTOR_BINDING
Systematic name | M18145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an adrenergic receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_ALPHA_2A_ADRENERGIC_RECEPTOR_BINDING
Systematic name | M26542
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an alpha-2A adrenergic receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_BETA_1_ADRENERGIC_RECEPTOR_BINDING
Systematic name | M34419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a beta-1 adrenergic receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_BETA_2_ADRENERGIC_RECEPTOR_BINDING
Systematic name | M26543
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a beta-2 adrenergic receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_ANGIOTENSIN_RECEPTOR_BINDING
Systematic name | M19000
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an angiotensin receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_HAPTOGLOBIN_BINDING
Systematic name | M26544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a haptoglobin, any alpha2 globulin of blood plasma that can combine with free oxyhemoglobin to form a stable complex. [GOC:mah, ISBN:0198506732]
Full description |

Standard name | GO_HEMOGLOBIN_ALPHA_BINDING
Systematic name | M29481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a hemoglobin alpha chain. [GOC:mah]
Full description |

Standard name | GO_CCR1_CHEMOKINE_RECEPTOR_BINDING
Systematic name | M26545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a CCR1 chemokine receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_CCR2_CHEMOKINE_RECEPTOR_BINDING
Systematic name | M26546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a CCR2 chemokine receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_CCR3_CHEMOKINE_RECEPTOR_BINDING
Systematic name | M34420
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a CCR3 chemokine receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_CCR5_CHEMOKINE_RECEPTOR_BINDING
Systematic name | M26547
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a CCR5 chemokine receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_CCR6_CHEMOKINE_RECEPTOR_BINDING
Systematic name | M26548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a CCR6 chemokine receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_D1_DOPAMINE_RECEPTOR_BINDING
Systematic name | M26549
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a D1 dopamine receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_D2_DOPAMINE_RECEPTOR_BINDING
Systematic name | M29482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a D2 dopamine receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_MELANOCORTIN_RECEPTOR_BINDING
Systematic name | M34421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a melanocortin receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_TYPE_5_METABOTROPIC_GLUTAMATE_RECEPTOR_BINDING
Systematic name | M26550
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a type 5 metabotropic glutamate receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_SEROTONIN_RECEPTOR_BINDING
Systematic name | M26551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a metabotropic serotonin receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_TYPE_2A_SEROTONIN_RECEPTOR_BINDING
Systematic name | M34422
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a type 2A serotonin receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_OLFACTORY_RECEPTOR_BINDING
Systematic name | M26552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an olfactory receptor. [GOC:mah, GOC:nln]
Full description |

Standard name | GO_MEDIUM_CHAIN_FATTY_ACID_COA_LIGASE_ACTIVITY
Systematic name | M26553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a medium-chain carboxylic acid + CoA = AMP + diphosphate + an acyl-CoA; a medium-chain fatty acid is any fatty acid with a chain length of between C6 and C12. [EC:6.2.1.3, GOC:mah]
Full description |

Standard name | GO_VERY_LONG_CHAIN_FATTY_ACID_COA_LIGASE_ACTIVITY
Systematic name | M26554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a very-long-chain fatty acid + CoA = AMP + diphosphate + an acyl-CoA; a very long-chain fatty acid is a fatty acid which has a chain length greater than C22. [EC:6.2.1.3, GOC:mah]
Full description |

Standard name | GO_INSULIN_LIKE_GROWTH_FACTOR_I_BINDING
Systematic name | M26555
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with insulin-like growth factor I. [GOC:mah]
Full description |

Standard name | GO_INSULIN_LIKE_GROWTH_FACTOR_II_BINDING
Systematic name | M26556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with insulin-like growth factor II. [GOC:mah]
Full description |

Standard name | GO_THIOESTERASE_BINDING
Systematic name | M19201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any thioesterase enzyme. [GOC:dl]
Full description |

Standard name | GO_MYOSIN_LIGHT_CHAIN_BINDING
Systematic name | M26557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a light chain of a myosin complex. [GOC:mah]
Full description |

Standard name | GO_MYOSIN_HEAVY_CHAIN_BINDING
Systematic name | M18560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a heavy chain of a myosin complex. [GOC:mah]
Full description |

Standard name | GO_CLATHRIN_HEAVY_CHAIN_BINDING
Systematic name | M26558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a clathrin heavy chain. [GOC:mah]
Full description |

Standard name | GO_CLATHRIN_LIGHT_CHAIN_BINDING
Systematic name | M26559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a clathrin light chain. [GOC:mah]
Full description |

Standard name | GO_BILE_ACID_BINDING
Systematic name | M26560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with bile acids, any of a group of steroid carboxylic acids occurring in bile. [GOC:rph]
Full description |

Standard name | GO_DNA_INSERTION_OR_DELETION_BINDING
Systematic name | M26561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with double-stranded DNA containing insertions or deletions. [GOC:vk]
Full description |

Standard name | GO_UBIQUITIN_LIKE_PROTEIN_BINDING
Systematic name | M17926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a small conjugating protein such as ubiquitin or a ubiquitin-like protein. [GOC:mah]
Full description |

Standard name | GO_SUMO_BINDING
Systematic name | M18520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the small ubiquitin-like protein SUMO. [GOC:mah]
Full description |

Standard name | GO_SUMO_POLYMER_BINDING
Systematic name | M26565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a polymer of the small ubiquitin-like protein SUMO. [GOC:mah]
Full description |

Standard name | GO_ACROSIN_BINDING
Systematic name | M26566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with acrosin, a protein that is found in the acrosomes of sperm and possesses protease and carbohydrate binding activities. [GOC:mah, PMID:12398221]
Full description |

Standard name | GO_RIBOFLAVIN_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M29483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of riboflavin from one side of a membrane to the other. Riboflavin (vitamin B2) is a water-soluble B-complex vitamin, converted in the cell to FMN and FAD, cofactors required for the function of flavoproteins. [GOC:rn, PMID:16204239]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_PHOSPHATE_BINDING
Systematic name | M18687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylinositol-3-phosphate, a derivative of phosphatidylinositol in which the inositol ring is phosphorylated at the 3' position. [GOC:bf, PMID:10209156, PMID:11395417, PMID:11557775]
Full description |

Standard name | GO_OXIDIZED_DNA_BINDING
Systematic name | M26567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with oxidized residues in DNA. [GOC:vk]
Full description |

Standard name | GO_MHC_CLASS_I_RECEPTOR_ACTIVITY
Systematic name | M26568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an MHC class I protein complex to initiate a change in cellular activity. Class I here refers to classical class I molecules. [GOC:add, ISBN:0781735149]
Full description |

Standard name | GO_MHC_CLASS_IB_RECEPTOR_ACTIVITY
Systematic name | M26569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an MHC class Ib protein complex and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. Class Ib here refers to non-classical class I molecules, such as those of the CD1 or HLA-E gene families. [GOC:add, GOC:signaling, ISBN:0781735149]
Full description |

Standard name | GO_MHC_CLASS_II_RECEPTOR_ACTIVITY
Systematic name | M18156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with an MHC class II protein complex and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:add, GOC:signaling, ISBN:0781735149]
Full description |

Standard name | GO_MISMATCH_REPAIR_COMPLEX_BINDING
Systematic name | M26570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a mismatch repair complex. [GOC:vk]
Full description |

Standard name | GO_MUTLALPHA_COMPLEX_BINDING
Systematic name | M26571
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the mismatch repair complex MutLalpha. [GOC:vk]
Full description |

Standard name | GO_MUTSALPHA_COMPLEX_BINDING
Systematic name | M26572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the mismatch repair complex MutSalpha. [GOC:vk]
Full description |

Standard name | GO_DEMETHYLASE_ACTIVITY
Systematic name | M18017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of a methyl group from a substrate. [GOC:mah]
Full description |

Standard name | GO_HISTONE_DEMETHYLASE_ACTIVITY_H3_K4_SPECIFIC
Systematic name | M26573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of a methyl group from lysine at position 4 of the histone H3 protein. [GOC:mah]
Full description |

Standard name | GO_HISTONE_DEMETHYLASE_ACTIVITY_H3_K9_SPECIFIC
Systematic name | M26574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: histone H3 N6-methyl-L-lysine (position 9) + alpha-ketoglutarate + O2 = succinate + CO2 + formaldehyde + lysine. This reaction is the removal of a methyl group from lysine at position 9 of the histone H3 protein. [PMID:16362057]
Full description |

Standard name | GO_DEOXYRIBONUCLEOTIDE_BINDING
Systematic name | M26575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a deoxyribonucleotide, any compound consisting of a deoxyribonucleoside that is esterified with (ortho)phosphate or an oligophosphate at any hydroxyl group on the deoxyribose moiety. [GOC:mah]
Full description |

Standard name | GO_RIBONUCLEOTIDE_BINDING
Systematic name | M18769
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a ribonucleotide, any compound consisting of a ribonucleoside that is esterified with (ortho)phosphate or an oligophosphate at any hydroxyl group on the ribose moiety. [GOC:mah]
Full description |

Standard name | GO_PURINE_DEOXYRIBONUCLEOTIDE_BINDING
Systematic name | M29484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a purine deoxyribonucleotide, any compound consisting of a purine deoxyribonucleoside that is esterified with (ortho)phosphate or an oligophosphate at any hydroxyl group on the deoxyribose moiety. [GOC:mah]
Full description |

Standard name | GO_GTPASE_ACTIVATING_PROTEIN_BINDING
Systematic name | M18822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a GTPase activating protein. [GOC:nln]
Full description |

Standard name | GO_TUMOR_NECROSIS_FACTOR_RECEPTOR_SUPERFAMILY_BINDING
Systematic name | M19188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any member of the tumor necrosis factor receptor superfamily. [GOC:add]
Full description |

Standard name | GO_STEROL_BINDING
Systematic name | M18284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a sterol, any steroid containing a hydroxy group in the 3 position, closely related to cholestan-3-ol. [GOC:mah]
Full description |

Standard name | GO_BITTER_TASTE_RECEPTOR_ACTIVITY
Systematic name | M18715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with soluble bitter compounds to initiate a change in cell activity. These receptors are responsible for the sense of bitter taste. [GOC:mah]
Full description |

Standard name | GO_ACETYLCHOLINE_RECEPTOR_BINDING
Systematic name | M26577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an acetylcholine receptor. [GOC:mah]
Full description |

Standard name | GO_CALMODULIN_DEPENDENT_PROTEIN_PHOSPHATASE_ACTIVITY
Systematic name | M26578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: protein serine/threonine phosphate + H2O = protein serine/threonine + phosphate, dependent on the presence of calcium-bound calmodulin. [GOC:mah, PMID:15359118]
Full description |

Standard name | GO_RIBONUCLEASE_P_RNA_BINDING
Systematic name | M34423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the RNA subunit of ribonuclease P. [GOC:pg, PMID:11455963]
Full description |

Standard name | GO_AMIDE_BINDING
Systematic name | M18547
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an amide, any derivative of an oxoacid in which an acidic hydroxy group has been replaced by an amino or substituted amino group. [GOC:mah]
Full description |

Standard name | GO_ATPASE_COUPLED_AMIDE_TRANSPORTER_ACTIVITY
Systematic name | M29485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O + amide(out) = ADP + phosphate + amide(in). [GOC:mah]
Full description |

Standard name | GO_MONOCARBOXYLIC_ACID_BINDING
Systematic name | M19149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a monocarboxylic acid, any organic acid containing one carboxyl (COOH) group or anion (COO-). [GOC:mah]
Full description |

Standard name | GO_DEHYDROASCORBIC_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M29486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of dehydroascorbate, 5-(1,2-dihydroxyethyl)furan-2,3,4(5H)-trione, from one side of a membrane to the other. [GOC:go_curators]
Full description |

Standard name | GO_MAP_KINASE_PHOSPHATASE_ACTIVITY
Systematic name | M18661
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a phosphorylated MAP kinase + H2O = a MAP kinase + phosphate. [GOC:mah, PMID:12184814, PMID:17208316]
Full description |

Standard name | GO_PROTEIN_DEACETYLASE_ACTIVITY
Systematic name | M17984
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of an acetyl group or groups from a protein substrate. [GOC:mah]
Full description |

Standard name | GO_RNA_STRAND_ANNEALING_ACTIVITY
Systematic name | M34424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Facilitates the base-pairing of complementary single-stranded RNA. [GOC:mah]
Full description |

Standard name | GO_RECEPTOR_SERINE_THREONINE_KINASE_BINDING
Systematic name | M18523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a receptor that possesses protein serine/threonine kinase activity. [GOC:mah]
Full description |

Standard name | GO_ACTIVATING_TRANSCRIPTION_FACTOR_BINDING
Systematic name | M18775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an activating transcription factor, any protein whose activity is required to initiate or upregulate transcription. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_SIALIC_ACID_BINDING
Systematic name | M26580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with sialic acid, any of a variety of N- or O- substituted derivatives of neuraminic acid, a nine carbon monosaccharide. Sialic acids often occur in polysaccharides, glycoproteins, and glycolipids in animals and bacteria. [GOC:add, ISBN:9780721601465]
Full description |

Standard name | GO_ATPASE_COUPLED_LIPID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M29487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: ATP + H2O + lipid(in) = ADP + phosphate + lipid(out). [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_POLY_G_BINDING
Systematic name | M26582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a sequence of guanine residues in an RNA molecule. [GOC:mah]
Full description |

Standard name | GO_DNA_POLYMERASE_ACTIVITY
Systematic name | M12881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: deoxynucleoside triphosphate + DNA(n) = diphosphate + DNA(n+1); the synthesis of DNA from deoxyribonucleotide triphosphates in the presence of a nucleic acid template and a 3'hydroxyl group. [EC:2.7.7.7, GOC:mah]
Full description |

Standard name | GO_APOLIPOPROTEIN_BINDING
Systematic name | M18980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an apolipoprotein, the protein component of a lipoprotein complex. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_APOLIPOPROTEIN_A_I_BINDING
Systematic name | M26583
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with apolipoprotein A-I. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_APOLIPOPROTEIN_RECEPTOR_BINDING
Systematic name | M26584
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an apolipoprotein receptor. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_PEPTIDE_N_ACETYLTRANSFERASE_ACTIVITY
Systematic name | M18531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the acetylation of an amino acid residue of a peptide or protein, according to the reaction: acetyl-CoA + peptide = CoA + N-acetylpeptide. [GOC:mah]
Full description |

Standard name | GO_GPI_ANCHOR_BINDING
Systematic name | M26585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any glycosylphosphatidylinositol anchor. GPI anchors serve to attach membrane proteins to the lipid bilayer of cell membranes. [GOC:vw]
Full description |

Standard name | GO_PROTEIN_KINASE_A_CATALYTIC_SUBUNIT_BINDING
Systematic name | M18638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with one or both of the catalytic subunits of protein kinase A. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_KINASE_A_REGULATORY_SUBUNIT_BINDING
Systematic name | M17869
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with one or both of the regulatory subunits of protein kinase A. [GOC:mah]
Full description |

Standard name | GO_SHORT_CHAIN_CARBOXYLESTERASE_ACTIVITY
Systematic name | M29488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a carboxylic ester + H2O = an alcohol + a carboxylic anion, where the carboxylic chain has 8 or fewer carbon atoms. [GOC:jp]
Full description |

Standard name | GO_UBIQUITIN_UBIQUITIN_LIGASE_ACTIVITY
Systematic name | M18036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Isoenergetic transfer of ubiquitin from one protein to an existing ubiquitin chain via the reaction X-ubiquitin + Y-ubiquitin -> Y-ubiquitin-ubiquitin + X, where both the X-ubiquitin and Y-ubiquitin-ubiquitin linkages are thioester bonds between the C-terminal glycine of ubiquitin and a sulfhydryl side group of a cysteine residue. [GOC:mah, GOC:mcc, PMID:10089879, PMID:17190603]
Full description |

Standard name | GO_DYNACTIN_BINDING
Systematic name | M26586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any part of a dynactin complex; dynactin is a large protein complex that activates dynein-based motor activity. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_CHONDROITIN_SULFOTRANSFERASE_ACTIVITY
Systematic name | M26588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 3'-phosphoadenosine 5'-phosphosulfate + chondroitin = adenosine 3',5'-bisphosphate + chondroitin sulfate. [EC:2.8.2.17, EC:2.8.2.5, GOC:mah]
Full description |

Standard name | GO_HEPARAN_SULFATE_SULFOTRANSFERASE_ACTIVITY
Systematic name | M17962
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 3'-phosphoadenosine 5'-phosphosulfate + heparan sulfate = adenosine 3',5'-bisphosphate + sulfated heparan sulfate. [GOC:mah]
Full description |

Standard name | GO_U3_SNORNA_BINDING
Systematic name | M26589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with U3 small nucleolar RNA. [GOC:mah]
Full description |

Standard name | GO_BOX_H_ACA_SNORNA_BINDING
Systematic name | M26590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with box H/ACA small nucleolar RNA. [GOC:mah]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_BISPHOSPHATE_PHOSPHATASE_ACTIVITY
Systematic name | M26591
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: phosphatidylinositol bisphosphate + H2O = phosphatidylinositol phosphate + phosphate. [GOC:mah]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_TRISPHOSPHATE_PHOSPHATASE_ACTIVITY
Systematic name | M26592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: phosphatidylinositol trisphosphate + H2O = phosphatidylinositol bisphosphate + phosphate. [GOC:mah]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_PHOSPHATE_5_PHOSPHATASE_ACTIVITY
Systematic name | M18133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of the 5-phosphate group of a phosphatidylinositol phosphate. [GOC:elh]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_PHOSPHATE_4_PHOSPHATASE_ACTIVITY
Systematic name | M26593
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of the 4-phosphate group of a phosphatidylinositol phosphate. [GOC:mah]
Full description |

Standard name | GO_ARGININE_BINDING
Systematic name | M26594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with 2-amino-5-(carbamimidamido)pentanoic acid. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_INHIBIN_BINDING
Systematic name | M26595
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an inhibin monomer, any of the polypeptides that combine to form activin and inhibin dimers. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_TYPE_I_TRANSFORMING_GROWTH_FACTOR_BETA_RECEPTOR_BINDING
Systematic name | M26596
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a type I transforming growth factor beta receptor. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_NAD_DEPENDENT_PROTEIN_DEACETYLASE_ACTIVITY
Systematic name | M18860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of one or more acetyl groups from a protein, requiring NAD. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_IMMUNOGLOBULIN_RECEPTOR_BINDING
Systematic name | M18357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with one or more specific sites on an immunoglobulin receptor molecule. [GOC:BHF, GOC:vk]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_KINASE_ACTIVITY
Systematic name | M18711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a phosphatidylinositol = ADP + a phosphatidylinositol 3-phosphate. This reaction is the addition of a phosphate group to phosphatidylinositol or one of its phosphorylated derivatives at the 3' position of the inositol ring. [GOC:bf, PMID:10209156, PMID:9255069]
Full description |

Standard name | GO_1_PHOSPHATIDYLINOSITOL_4_PHOSPHATE_3_KINASE_ACTIVITY
Systematic name | M26597
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-phosphatidyl-1D-myo-inositol 4-phosphate + ATP = 1-phosphatidyl-1D-myo-inositol 3,4-bisphosphate + ADP + 2 H(+). [EC:2.7.1.154, RHEA:18373]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_KINASE_REGULATOR_ACTIVITY
Systematic name | M26598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of any of the phosphatidylinositol 3-kinases (PI3Ks). Regulatory subunits can link a PI3K catalytic subunit to upstream signaling events and help position the catalytic subunits close to their lipid substrates. [GOC:bf, PMID:9255069]
Full description |

Standard name | GO_HISTONE_ACETYLTRANSFERASE_BINDING
Systematic name | M18982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the enzyme histone acetyltransferase. [GOC:bf]
Full description |

Standard name | GO_METHYLATED_HISTONE_BINDING
Systematic name | M17939
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a histone in which a residue has been modified by methylation. Histones are any of a group of water-soluble proteins found in association with the DNA of eukaroytic chromosomes. [GOC:bf, PMID:14585615]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_BINDING
Systematic name | M18286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any inositol-containing glycerophospholipid, i.e. phosphatidylinositol (PtdIns) and its phosphorylated derivatives. [GOC:bf, ISBN:0198506732, PMID:11395417]
Full description |

Standard name | GO_HISTONE_KINASE_ACTIVITY
Systematic name | M19191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphate group to a histone. Histones are any of a group of water-soluble proteins found in association with the DNA of eukaroytic chromosomes. [GOC:bf]
Full description |

Standard name | GO_HISTONE_SERINE_KINASE_ACTIVITY
Systematic name | M26599
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphate group to a serine residue of a histone. Histones are any of a group of water-soluble proteins found in association with the DNA of eukaroytic chromosomes. [GOC:bf]
Full description |

Standard name | GO_HISTONE_THREONINE_KINASE_ACTIVITY
Systematic name | M26600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a phosphate group to a threonine residue of a histone. Histones are any of a group of water-soluble proteins found in association with the DNA of eukaroytic chromosomes. [GOC:bf]
Full description |

Standard name | GO_SIRNA_BINDING
Systematic name | M26601
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a small interfering RNA, a 21-23 nucleotide RNA that is processed from double stranded RNA (dsRNA) by an RNAse enzyme. [PMID:15066275, PMID:15066283]
Full description |

Standard name | GO_MIRNA_BINDING
Systematic name | M18028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a microRNA, a 21-23 nucleotide RNA that is processed from a stem-loop RNA precursor (pre-miRNA) that is encoded within plant and animal genomes. [PMID:15066283]
Full description |

Standard name | GO_DOPAMINE_BINDING
Systematic name | M18923
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with dopamine, a catecholamine neurotransmitter formed by aromatic-L-amino-acid decarboxylase from 3,4-dihydroxy-L-phenylalanine. [ISBN:0198506732]
Full description |

Standard name | GO_PROTEIN_ARGININE_OMEGA_N_MONOMETHYLTRANSFERASE_ACTIVITY
Systematic name | M34425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the addition of a methyl group to either of the unmethylated terminal nitrogen atoms (also called omega nitrogen) in peptidyl-arginine to form an omega-N-G-monomethylated arginine residue. The reaction is S-adenosyl-L-methionine + [protein]-L-arginine = S-adenosyl-L-homocysteine + [protein]-Nomega-methyl-L-arginine. [EC:2.1.1.321, PMID:14705965, RESID:AA0069]
Full description |

Standard name | GO_PROTEIN_ARGININE_OMEGA_N_ASYMMETRIC_METHYLTRANSFERASE_ACTIVITY
Systematic name | M34426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the addition of a second methyl group to methylated peptidyl-arginine. Methylation is on the same terminal nitrogen (omega nitrogen) residue that was previously methylated, resulting in asymmetrical peptidyl-N(omega),N(omega)-dimethylated arginine residues. [PMID:14705965, RESID:AA0068, RESID:AA0069, RHEA:48096]
Full description |

Standard name | GO_UDP_GLUCOSYLTRANSFERASE_ACTIVITY
Systematic name | M26603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a glucosyl group from UDP-glucose to an acceptor molecule. [PMID:19858195]
Full description |

Standard name | GO_UDP_XYLOSYLTRANSFERASE_ACTIVITY
Systematic name | M26604
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a xylosyl group from UDP-xylose to an acceptor molecule. [PMID:30127001]
Full description |

Standard name | GO_GLUTAMATE_RECEPTOR_BINDING
Systematic name | M19035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a glutamate receptor. [GOC:bf]
Full description |

Standard name | GO_IONOTROPIC_GLUTAMATE_RECEPTOR_BINDING
Systematic name | M17872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an ionotropic glutamate receptor. Ionotropic glutamate receptors bind glutamate and exert an effect through the regulation of ion channels. [GOC:bf, ISBN:0198506732]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_GLUTAMATE_RECEPTOR_BINDING
Systematic name | M26605
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a G protein-coupled glutamate receptor (a metabotropic glutamate receptor). [GOC:bf, ISBN:0198506732, PMID:9069287]
Full description |

Standard name | GO_NUCLEAR_HORMONE_RECEPTOR_BINDING
Systematic name | M26606
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a nuclear hormone receptor, a ligand-dependent receptor found in the nucleus of the cell. [GOC:bf]
Full description |

Standard name | GO_STEROID_HORMONE_RECEPTOR_BINDING
Systematic name | M18714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a steroid hormone receptor. [GOC:bf]
Full description |

Standard name | GO_GLUCOCORTICOID_RECEPTOR_BINDING
Systematic name | M18533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a glucocorticoid receptor. [GOC:bf]
Full description |

Standard name | GO_5_3_EXODEOXYRIBONUCLEASE_ACTIVITY
Systematic name | M26607
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the sequential cleavage of mononucleotides from a free 5' terminus of a DNA molecule. [ISBN:0198547684]
Full description |

Standard name | GO_TOLL_LIKE_RECEPTOR_BINDING
Systematic name | M26608
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a Toll-like protein, a pattern recognition receptor that binds pattern motifs from a variety of microbial sources to initiate an innate immune response. [PMID:19076341]
Full description |

Standard name | GO_SELENOCYSTEINE_INSERTION_SEQUENCE_BINDING
Systematic name | M29489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the selenocysteine insertion sequence (SECIS), a regulatory sequence within mRNA which directs incorporation of a selenocysteine at a stop codon (UGA) during translation. [GOC:imk, PMID:10760958]
Full description |

Standard name | GO_CHONDROITIN_SULFATE_BINDING
Systematic name | M26609
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with chondroitin sulfate, a glycosaminoglycan made up of two alternating monosaccharides: D-glucuronic acid (GlcA) and N-acetyl-D-galactosamine (GalNAc). [GOC:kmv, ISBN:0198506732]
Full description |

Standard name | GO_ATP_GATED_ION_CHANNEL_ACTIVITY
Systematic name | M26610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an ion by a channel that opens when ATP has been bound by the channel complex or one of its constituent parts. [GOC:bf]
Full description |

Standard name | GO_LIPASE_BINDING
Systematic name | M26611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any lipase. [GOC:BHF]
Full description |

Standard name | GO_CAMP_RESPONSE_ELEMENT_BINDING
Systematic name | M18539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the cyclic AMP response element (CRE), a short palindrome-containing sequence found in the promoters of genes whose expression is regulated in response to cyclic AMP. [PMID:2875459, PMID:2900470]
Full description |

Standard name | GO_DNA_DEMETHYLASE_ACTIVITY
Systematic name | M29490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of a methyl group from one or more nucleosides within a DNA molecule. [GOC:bf]
Full description |

Standard name | GO_OXIDATIVE_RNA_DEMETHYLASE_ACTIVITY
Systematic name | M26612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of a methyl group from one or more nucleosides within a RNA molecule involving the oxidation (i.e. electron loss) of one or more atoms. [PMID:12594517, PMID:16482161, PMID:18775698]
Full description |

Standard name | GO_NADH_PYROPHOSPHATASE_ACTIVITY
Systematic name | M26613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NADH + H2O = AMP + NMNH + 2 H+. [MetaCyc:RXN0-4401, PMID:12399474, PMID:20181750]
Full description |

Standard name | GO_SIGNALING_ADAPTOR_ACTIVITY
Systematic name | M18918
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding activity of a molecule that brings together two or more molecules in a signaling pathway, permitting those molecules to function in a coordinated way. Adaptor molecules themselves do not have catalytic activity. [GOC:bf, PMID:19104498]
Full description |

Standard name | GO_AP_2_ADAPTOR_COMPLEX_BINDING
Systematic name | M26615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the AP-2 adaptor complex. The AP-2 adaptor complex is a heterotetrameric AP-type membrane coat adaptor complex that consists of alpha, beta2, mu2 and sigma2 subunits and links clathrin to the membrane surface of a vesicle. In at least humans, the AP-2 complex can be heterogeneric due to the existence of multiple subunit isoforms encoded by different alpha genes (alphaA and alphaC). [GOC:BHF, PMID:12221107, PMID:15728179, PMID:21097499]
Full description |

Standard name | GO_RNA_STEM_LOOP_BINDING
Systematic name | M26616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a stem-loop in an RNA molecule. An RNA stem-loop is a secondary RNA structure consisting of a double-stranded RNA (dsRNA) stem and a terminal loop. [GOC:sart, PMID:16568238, PMID:20455544]
Full description |

Standard name | GO_AP_1_ADAPTOR_COMPLEX_BINDING
Systematic name | M26618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the AP-1 adaptor complex. The AP-1 adaptor complex is a heterotetrameric AP-type membrane coat adaptor complex that consists of beta1, gamma, mu1 and sigma1 subunits and links clathrin to the membrane surface of a vesicle. In at least humans, the AP-1 complex can be heterogeneric due to the existence of multiple subunit isoforms encoded by different genes (gamma1 and gamma2, mu1A and mu1B, and sigma1A, sigma1B and sigma1C). [PMID:21097499]
Full description |

Standard name | GO_ENONE_REDUCTASE_ACTIVITY
Systematic name | M26619
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: an enone + NADPH + H+ = a ketone + NADP+. [EC:1.3.1.-, GOC:kad, PMID:17945329, PMID:19166903]
Full description |

Standard name | GO_OLIGOPEPTIDE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of oligopeptides from one side of a membrane to the other. Oligopeptides are molecules that contain a small number (2 to 20) of amino-acid residues connected by peptide linkages. [GOC:vw, ISBN:0198506732]
Full description |

Standard name | GO_LYSOPHOSPHATIDIC_ACID_BINDING
Systematic name | M26621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with lysophosphatidic acid (LPA), a phospholipid derivative that acts as a potent mitogen due to its activation of high-affinity G protein-coupled receptors. [GOC:curators]
Full description |

Standard name | GO_PRE_MRNA_BINDING
Systematic name | M19092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with pre-messenger RNA (pre-mRNA), an intermediate molecule between DNA and protein that may contain introns and, at least in part, encodes one or more proteins. Introns are removed from pre-mRNA to form a mRNA molecule. [GOC:bf, GOC:kmv, PMID:21901112, SO:0000120]
Full description |

Standard name | GO_MEDIATOR_COMPLEX_BINDING
Systematic name | M26623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a mediator complex. The mediator complex is a protein complex that interacts with the carboxy-terminal domain of the largest subunit of RNA polymerase II and plays an active role in transducing the signal from a transcription factor to the transcriptional machinery. The Saccharomyces complex contains several identifiable subcomplexes: a head domain comprising Srb2, -4, and -5, Med6, -8, and -11, and Rox3 proteins; a middle domain comprising Med1, -4, and -7, Nut1 and -2, Cse2, Rgr1, Soh1, and Srb7 proteins; a tail consisting of Gal11p, Med2p, Pgd1p, and Sin4p; and a regulatory subcomplex comprising Ssn2, -3, and -8, and Srb8 proteins. Metazoan mediator complexes have similar modular structures and include homologs of yeast Srb and Med proteins. [GOC:yaf, PMID:18391015]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACID_BINDING
Systematic name | M17877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a long-chain fatty acid. A long-chain fatty acid is a fatty acid with a chain length between C13 and C22. [GOC:pm, PMID:12641450]
Full description |

Standard name | GO_LONG_CHAIN_FATTY_ACYL_COA_BINDING
Systematic name | M26624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a long-chain fatty acyl-CoA, any derivative of coenzyme A in which the sulfhydryl group is in a thioester linkage with a long-chain fatty-acyl group. Long-chain fatty-acyl-CoAs have chain lengths of C13 or more. [GOC:krc, GOC:pm]
Full description |

Standard name | GO_BMP_BINDING
Systematic name | M26625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a member of the bone morphogenetic protein (BMP) family. [GOC:BHF, PMID:9660951]
Full description |

Standard name | GO_DTTP_DIPHOSPHATASE_ACTIVITY
Systematic name | M34427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: dTTP + H2O = dTMP + diphosphate. [GOC:dgf, PMID:22531138, RHEA:28534]
Full description |

Standard name | GO_ANNEALING_HELICASE_ACTIVITY
Systematic name | M26626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the ATP-dependent rewinding of single-stranded DNA (ssDNA) to reform base pairs between strands. Often acts on ssDNA bubbles bound by replication protein A (RPA). [GOC:bf, GOC:sp, PMID:21078962, PMID:22704558, PMID:22705370, PMID:22759634]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_KINASE_REGULATORY_SUBUNIT_BINDING
Systematic name | M26627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a regulatory subunit of phosphatidylinositol 3-kinase. The regulatory subunit associates with the catalytic subunit to regulate both its activity and subcellular location. [GOC:bf, PMID:20505341]
Full description |

Standard name | GO_GLUTATHIONE_HYDROLASE_ACTIVITY
Systematic name | M26628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: glutathione + H2O = L-cysteinylglycine + L-glutamate. [EC:3.4.19.13, GOC:imk]
Full description |

Standard name | GO_K48_LINKED_POLYUBIQUITIN_MODIFICATION_DEPENDENT_PROTEIN_BINDING
Systematic name | M26630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein upon poly-ubiquitination formed by linkages between lysine residues at position 48 in the target protein. [GOC:al, PMID:20739285]
Full description |

Standard name | GO_CARGO_RECEPTOR_ACTIVITY
Systematic name | M18649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binding specifically to a substance (cargo) to deliver it to a transport vesicle. Cargo receptors span a membrane (either the plasma membrane or a vesicle membrane), binding simultaneously to cargo molecules and coat adaptors, to efficiently recruit soluble proteins to nascent vesicles. [PMID:15239958, PMID:27903609]
Full description |

Standard name | GO_SPHINGOSINE_1_PHOSPHATE_RECEPTOR_ACTIVITY
Systematic name | M26632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with the sphingolipid sphingosine-1-phosphate (S1P), and transmitting the signal across the membrane by activating an associated G-protein. [GOC:bf, PMID:12728273, Wikipedia:S1PR1]
Full description |

Standard name | GO_COLLAGEN_RECEPTOR_ACTIVITY
Systematic name | M26633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a collagen and transmitting the signal from one side of the membrane to the other to initiate a change in cell activity. [GOC:bf, GOC:uh, PMID:21568710]
Full description |

Standard name | GO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_BINDING
Systematic name | M26634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a vascular endothelial growth factor. [PMID:17470632]
Full description |

Standard name | GO_NODAL_BINDING
Systematic name | M26635
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a nodal protein, a member of the transforming growth factor-beta superfamily. [GOC:bf, PMID:20629020]
Full description |

Standard name | GO_NEUREGULIN_BINDING
Systematic name | M26636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a neuregulin, a member of the EGF family of growth factors. [GOC:bf, GOC:signaling]
Full description |

Standard name | GO_PATTERN_RECOGNITION_RECEPTOR_ACTIVITY
Systematic name | M26637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a pathogen-associated molecular pattern (PAMP), a structure conserved among microbial species to initiate an innate immune response. [GOC:ar, GOC:bf, Wikipedia:Pattern_recognition_receptor]
Full description |

Standard name | GO_CO_RECEPTOR_BINDING
Systematic name | M26638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a coreceptor. A coreceptor acts in cooperation with a primary receptor to transmit a signal within the cell. [GOC:bf, GOC:jl]
Full description |

Standard name | GO_ATPASE_INHIBITOR_ACTIVITY
Systematic name | M26639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of any enzyme that catalyzes the hydrolysis of ATP to ADP and orthophosphate. [GOC:jl]
Full description |

Standard name | GO_NEUREXIN_FAMILY_PROTEIN_BINDING
Systematic name | M18776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with neurexins, synaptic cell surface proteins related to latrotoxin receptor, laminin and agrin. Neurexins act as cell recognition molecules at nerve terminals. [GOC:curators, GOC:pr, PMID:18923512]
Full description |

Standard name | GO_HISTONE_METHYLTRANSFERASE_ACTIVITY
Systematic name | M19228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + histone = S-adenosyl-L-homocysteine + methyl-histone. Histone methylation generally occurs on either an arginine or lysine residue. [EC:2.1.1.43]
Full description |

Standard name | GO_CHEMOATTRACTANT_ACTIVITY
Systematic name | M18697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Providing the environmental signal that initiates the directed movement of a motile cell or organism towards a higher concentration of that signal. [GOC:go_curators, ISBN:0198506732]
Full description |

Standard name | GO_TELOMERIC_DNA_BINDING
Systematic name | M18482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a telomere, a specific structure at the end of a linear chromosome required for the integrity and maintenance of the end. [GOC:jl, SO:0000624]
Full description |

Standard name | GO_NEUROTRANSMITTER_BINDING
Systematic name | M7307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a neurotransmitter, any chemical substance that is capable of transmitting (or inhibiting the transmission of) a nerve impulse from a neuron to another cell. [ISBN:0198506732]
Full description |

Standard name | GO_ACETYLCHOLINE_BINDING
Systematic name | M18573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with acetylcholine, an acetic acid ester of the organic base choline that functions as a neurotransmitter, released at the synapses of parasympathetic nerves and at neuromuscular junctions. [GOC:ai]
Full description |

Standard name | GO_SH2_DOMAIN_BINDING
Systematic name | M12764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a SH2 domain (Src homology 2) of a protein, a protein domain of about 100 amino-acid residues and belonging to the alpha + beta domain class. [GOC:go_curators, Pfam:PF00017]
Full description |

Standard name | GO_PEPTIDE_BINDING
Systematic name | M3935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with peptides, any of a group of organic compounds comprising two or more amino acids linked by peptide bonds. [GOC:jl]
Full description |

Standard name | GO_MHC_PROTEIN_BINDING
Systematic name | M18976
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with major histocompatibility complex molecules; a set of molecules displayed on cell surfaces that are responsible for lymphocyte recognition and antigen presentation. [GOC:jl]
Full description |

Standard name | GO_MHC_CLASS_I_PROTEIN_BINDING
Systematic name | M18641
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with major histocompatibility complex class I molecules; a set of molecules displayed on cell surfaces that are responsible for lymphocyte recognition and antigen presentation. [GOC:jl]
Full description |

Standard name | GO_MHC_CLASS_II_PROTEIN_BINDING
Systematic name | M26641
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with major histocompatibility complex class II molecules; a set of molecules displayed on cell surfaces that are responsible for lymphocyte recognition and antigen presentation. [GOC:jl]
Full description |

Standard name | GO_PHOSPHATE_ION_BINDING
Systematic name | M18186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphate. [GOC:jl]
Full description |

Standard name | GO_CHEMOKINE_RECEPTOR_BINDING
Systematic name | M5006
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any chemokine receptor. [GOC:ai]
Full description |

Standard name | GO_SPHINGOSINE_1_PHOSPHATE_PHOSPHATASE_ACTIVITY
Systematic name | M34428
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: sphingosine 1-phosphate + H2O = sphingosine + phosphate. [GOC:jl, PMID:8663293]
Full description |

Standard name | GO_HISTONE_BINDING
Systematic name | M17924
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a histone, any of a group of water-soluble proteins found in association with the DNA of eukaroytic chromosomes. They are involved in the condensation and coiling of chromosomes during cell division and have also been implicated in nonspecific suppression of gene activity. [GOC:jl]
Full description |

Standard name | GO_ASPARTIC_ENDOPEPTIDASE_ACTIVITY_INTRAMEMBRANE_CLEAVING
Systematic name | M26643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of nonterminal peptide bonds in a polypeptide chain, occurring within a membrane. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_HORMONE_BINDING
Systematic name | M9558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any hormone, naturally occurring substances secreted by specialized cells that affect the metabolism or behavior of other cells possessing functional receptors for the hormone. [GOC:jl]
Full description |

Standard name | GO_LIPID_PHOSPHATASE_ACTIVITY
Systematic name | M26644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: a phospholipid + H2O = a lipid + phosphate. [GOC:jl]
Full description |

Standard name | GO_PHOSPHORIC_ESTER_HYDROLASE_ACTIVITY
Systematic name | M18348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: RPO-R' + H2O = RPOOH + R'H. This reaction is the hydrolysis of any phosphoric ester bond, any ester formed from orthophosphoric acid, O=P(OH)3. [GOC:jl]
Full description |

Standard name | GO_PEPTIDE_ANTIGEN_BINDING
Systematic name | M18591
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an antigen peptide. [GOC:add, GOC:jl, GOC:rv]
Full description |

Standard name | GO_T_CELL_RECEPTOR_BINDING
Systematic name | M26645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a T cell receptor, the antigen-recognizing receptor on the surface of T cells. [GOC:jl]
Full description |

Standard name | GO_CD4_RECEPTOR_BINDING
Systematic name | M26646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a CD4, a receptor found on the surface of T cells, monocytes and macrophages. [GOC:jl, MSH:D015704]
Full description |

Standard name | GO_ATPASE_COUPLED_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M29491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of an ion from one side of a membrane to the other, driven by the reaction: ATP + H2O = ADP + phosphate. [GOC:jl, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_HISTONE_METHYLTRANSFERASE_ACTIVITY_H4_K20_SPECIFIC
Systematic name | M26647
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + histone H4 L-lysine (position 20) = S-adenosyl-L-homocysteine + histone H4 N6-methyl-L-lysine (position 20). This reaction is the addition of a methyl group onto lysine at position 20 of the histone H4 protein. [PMID:12086618]
Full description |

Standard name | GO_HISTONE_METHYLTRANSFERASE_ACTIVITY_H3_K4_SPECIFIC
Systematic name | M19113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + histone H3 L-lysine (position 4) = S-adenosyl-L-homocysteine + histone H3 N6-methyl-L-lysine (position 4). This reaction is the addition of a methyl group onto lysine at position 4 of the histone H3 protein. [PMID:12086618]
Full description |

Standard name | GO_IDENTICAL_PROTEIN_BINDING
Systematic name | M18581
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an identical protein or proteins. [GOC:jl]
Full description |

Standard name | GO_PROTEIN_HOMODIMERIZATION_ACTIVITY
Systematic name | M18111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an identical protein to form a homodimer. [GOC:jl]
Full description |

Standard name | GO_ACTININ_BINDING
Systematic name | M18366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with actinin, any member of a family of proteins that crosslink F-actin. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_FUCOSE_BINDING
Systematic name | M26648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with fucose, the pentose 6-deoxygalactose. [ISBN:0582227089]
Full description |

Standard name | GO_VITAMIN_D_RECEPTOR_BINDING
Systematic name | M18261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the vitamin D receptor, a nuclear receptor that mediates the action of vitamin D by binding DNA and controlling the transcription of hormone-sensitive genes. [GOC:jl, PMID:12637589]
Full description |

Standard name | GO_WNT_ACTIVATED_RECEPTOR_ACTIVITY
Systematic name | M18686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a Wnt protein and transmitting the signal across the plasma membrane to initiate a change in cell activity. [GOC:go_curators]
Full description |

Standard name | GO_HISTONE_DEACETYLASE_BINDING
Systematic name | M18087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the enzyme histone deacetylase. [GOC:jl]
Full description |

Standard name | GO_PEPTIDOGLYCAN_BINDING
Systematic name | M18879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently, in a non-covalent manner, with peptidoglycan, any of a class of glycoconjugates found in bacterial cell walls. [GOC:go_curators, PMID:14698226]
Full description |

Standard name | GO_AMIDE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of an amide, any compound containing one, two, or three acyl groups attached to a nitrogen atom, from one side of a membrane to the other. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_XENOBIOTIC_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M29492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the directed movement of a xenobiotic from one side of a membrane to the other. A xenobiotic is a compound foreign the organim exposed to it. It may be synthesized by another organism (like ampicilin) or it can be a synthetic chemical. [GOC:go_curators]
Full description |

Standard name | GO_NEUROPEPTIDE_BINDING
Systematic name | M4273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently and stoichiometrically with neuropeptides, peptides with direct synaptic effects (peptide neurotransmitters) or indirect modulatory effects on the nervous system (peptide neuromodulators). [http://www.wormbook.org/chapters/www_neuropeptides/neuropeptides.html]
Full description |

Standard name | GO_RETINOIC_ACID_RECEPTOR_BINDING
Systematic name | M18772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the retinoic acid receptor, a ligand-regulated transcription factor belonging to the nuclear receptor superfamily. [GOC:jl, PMID:12476796]
Full description |

Standard name | GO_PEROXISOME_PROLIFERATOR_ACTIVATED_RECEPTOR_BINDING
Systematic name | M18893
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any of the peroxisome proliferator activated receptors, alpha, beta or gamma. [GOC:jl, PMID:12769781]
Full description |

Standard name | GO_ORNITHINE_DECARBOXYLASE_REGULATOR_ACTIVITY
Systematic name | M26651
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulation of the activity of the enzyme ornithine decarboxylase. [GOC:jl]
Full description |

Standard name | GO_ATP_DEPENDENT_PROTEIN_BINDING
Systematic name | M26652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any protein or protein complex (a complex of two or more proteins that may include other nonprotein molecules) using energy from the hydrolysis of ATP. [GOC:jl]
Full description |

Standard name | GO_ALPHA_TUBULIN_BINDING
Systematic name | M18472
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the microtubule constituent protein alpha-tubulin. [GOC:jl]
Full description |

Standard name | GO_GAMMA_TUBULIN_BINDING
Systematic name | M18277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the microtubule constituent protein gamma-tubulin. [GOC:jl]
Full description |

Standard name | GO_RIBONUCLEOPROTEIN_COMPLEX_BINDING
Systematic name | M18587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any complex of RNA and protein. [GOC:bf, GOC:go_curators, GOC:vk]
Full description |

Standard name | GO_RIBOSOME_BINDING
Systematic name | M19070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any part of a ribosome. [GOC:go_curators]
Full description |

Standard name | GO_RIBOSOMAL_LARGE_SUBUNIT_BINDING
Systematic name | M26653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any part of the larger ribosomal subunit. [GOC:go_curators]
Full description |

Standard name | GO_RIBOSOMAL_SMALL_SUBUNIT_BINDING
Systematic name | M18511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any part of the small ribosomal subunit. [GOC:go_curators]
Full description |

Standard name | GO_CYSTEINE_TYPE_ENDOPEPTIDASE_INHIBITOR_ACTIVITY_INVOLVED_IN_APOPTOTIC_PROCESS
Systematic name | M18466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a cysteine-type endopeptidase involved in the apoptotic process. [GOC:jl, GOC:mtg_apoptosis, PMID:14744432, Wikipedia:Caspase]
Full description |

Standard name | GO_CYSTEINE_TYPE_ENDOPEPTIDASE_REGULATOR_ACTIVITY_INVOLVED_IN_APOPTOTIC_PROCESS
Systematic name | M19227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a cysteine-type endopeptidase involved in the apoptotic process. [GOC:jl, GOC:mtg_apoptosis, PMID:14744432, Wikipedia:Caspase]
Full description |

Standard name | GO_CHROMATIN_INSULATOR_SEQUENCE_BINDING
Systematic name | M34429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently and stoichiometrically with a chromatin insulator sequence, a DNA sequence that prevents enhancer-mediated activation or repression of transcription. [GOC:jl, PMID:12783795]
Full description |

Standard name | GO_SINGLE_STRANDED_TELOMERIC_DNA_BINDING
Systematic name | M34430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with single-stranded telomere-associated DNA. [GOC:jl, ISBN:0321000382]
Full description |

Standard name | GO_TUMOR_NECROSIS_FACTOR_BINDING
Systematic name | M34431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with tumor necrosis factor, a proinflammatory cytokine produced by monocytes and macrophages. [GOC:jl, http://lookwayup.com/]
Full description |

Standard name | GO_NEUROTROPHIN_BINDING
Systematic name | M26654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a neurotrophin, any of a family of growth factors that prevent apoptosis in neurons and promote nerve growth. [GOC:jl]
Full description |

Standard name | GO_ERBB_3_CLASS_RECEPTOR_BINDING
Systematic name | M34432
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the protein-tyrosine kinase receptor ErbB-3/HER3. [GOC:jl]
Full description |

Standard name | GO_UBIQUITIN_BINDING
Systematic name | M26655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with ubiquitin, a protein that when covalently bound to other cellular proteins marks them for proteolytic degradation. [GOC:ecd]
Full description |

Standard name | GO_3_5_DNA_HELICASE_ACTIVITY
Systematic name | M18634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate; drives the unwinding of the DNA helix in the direction 3' to 5'. [GOC:jl]
Full description |

Standard name | GO_5_3_DNA_HELICASE_ACTIVITY
Systematic name | M26656
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + H2O = ADP + phosphate; drives the unwinding of the DNA helix in the direction 5' to 3'. [GOC:jl]
Full description |

Standard name | GO_RNA_POLYMERASE_CORE_ENZYME_BINDING
Systematic name | M18443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an RNA polymerase core enzyme, containing a specific subunit composition defined as the core enzyme. [GOC:jl, GOC:txnOH]
Full description |

Standard name | GO_AMINE_BINDING
Systematic name | M18373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any organic compound that is weakly basic in character and contains an amino or a substituted amino group. [GOC:jl]
Full description |

Standard name | GO_ORGANIC_ACID_BINDING
Systematic name | M18642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an organic acid, any acidic compound containing carbon in covalent linkage. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_ALCOHOL_BINDING
Systematic name | M18268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an alcohol, any of a class of alkyl compounds containing a hydroxyl group. [GOC:jl, ISBN:0198506732]
Full description |

Standard name | GO_VASCULAR_ENDOTHELIAL_GROWTH_FACTOR_RECEPTOR_2_BINDING
Systematic name | M26659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with vascular endothelial growth factor receptor 2. [GOC:st]
Full description |

Standard name | GO_SULFATE_BINDING
Systematic name | M29493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with sulfate, SO4(2-), a negatively charged small molecule. [GOC:mlg]
Full description |

Standard name | GO_GLYCOSPHINGOLIPID_BINDING
Systematic name | M26660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with glycosphingolipid, a compound with residues of sphingoid and at least one monosaccharide. [GOC:jl]
Full description |

Standard name | GO_LAMININ_BINDING
Systematic name | M19034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with laminins, glycoproteins that are major constituents of the basement membrane of cells. [GOC:ecd]
Full description |

Standard name | GO_LAMININ_1_BINDING
Systematic name | M26661
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with laminin-1, a glycoprotein trimer with the subunit composition alpha1, beta1, gamma1. [GOC:go_curators]
Full description |

Standard name | GO_PHOSPHOLIPASE_BINDING
Systematic name | M18221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any phospholipase, enzymes that catalyze of the hydrolysis of a glycerophospholipid. [GOC:jl]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_4_BISPHOSPHATE_BINDING
Systematic name | M18936
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylinositol-3,4-bisphosphate, a derivative of phosphatidylinositol in which the inositol ring is phosphorylated at the 3' and 4' positions. [GOC:bf, GOC:go_curators]
Full description |

Standard name | GO_PROTEOGLYCAN_BINDING
Systematic name | M18556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a proteoglycan, any glycoprotein in which the carbohydrate units are glycosaminoglycans. [ISBN:0198506732]
Full description |

Standard name | GO_HEPARAN_SULFATE_PROTEOGLYCAN_BINDING
Systematic name | M18662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a heparan sulfate proteoglycan, any proteoglycan containing heparan sulfate as the glycosaminoglycan carbohydrate unit. [ISBN:0198506732]
Full description |

Standard name | GO_PROTEIN_KINASE_B_BINDING
Systematic name | M26662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with protein kinase B, an intracellular kinase that is important in regulating glucose metabolism. [GOC:jl, http://www.heartandmetabolism.org/]
Full description |

Standard name | GO_BHLH_TRANSCRIPTION_FACTOR_BINDING
Systematic name | M17935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any of the basic Helix-Loop-Helix (bHLH) superfamily of transcription factors, important regulatory components in transcriptional networks of many developmental pathways. [PMID:9144210]
Full description |

Standard name | GO_MRF_BINDING
Systematic name | M29494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with Myogenic Regulatory Factor (MRF), a member of the basic Helix-Loop-Helix (bHLH) superfamily of transcription factors. [PMID:10966875]
Full description |

Standard name | GO_PROTEIN_MEMBRANE_ADAPTOR_ACTIVITY
Systematic name | M26663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding activity of a molecule that brings together a protein or a protein complex with a membrane, or bringing together two membranes, either via membrane lipid binding or by interacting with a membrane protein, to establish or maintain the localization of the protein, protein complex or organelle. [GOC:go_curators]
Full description |

Standard name | GO_KINETOCHORE_BINDING
Systematic name | M26664
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a kinetochore, a proteinaceous structure on a condensed chromosome, beside the centromere, to which the spindle fibers are attached. [GOC:jl]
Full description |

Standard name | GO_LEUCINE_ZIPPER_DOMAIN_BINDING
Systematic name | M18013
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a leucine zipper domain, a protein secondary structure exhibiting a periodic repetition of leucine residues at every seventh position over a distance covering eight helical turns. [GOC:jl, InterPro:IPR002158]
Full description |

Standard name | GO_ADP_BINDING
Systematic name | M573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with ADP, adenosine 5'-diphosphate. [GOC:jl]
Full description |

Standard name | GO_INOSITOL_1_3_4_5_TETRAKISPHOSPHATE_BINDING
Systematic name | M26665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with inositol 1,3,4,5 tetrakisphosphate. [GOC:go_curators]
Full description |

Standard name | GO_PROTEIN_SERINE_THREONINE_KINASE_ACTIVATOR_ACTIVITY
Systematic name | M18266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and increases the activity of a protein serine/threonine kinase. [GOC:go_curators]
Full description |

Standard name | GO_MOLYBDOPTERIN_COFACTOR_BINDING
Systematic name | M26666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the molybdopterin cofactor (Moco), essential for the catalytic activity of some enzymes, e.g. sulfite oxidase, xanthine dehydrogenase, and aldehyde oxidase. The cofactor consists of a mononuclear molybdenum (Mo-molybdopterin) or tungsten ion (W-molybdopterin) coordinated by one or two molybdopterin ligands. [ISSN:09498257]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_KINASE_BINDING
Systematic name | M18733
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a phosphatidylinositol 3-kinase, any enzyme that catalyzes the addition of a phosphate group to an inositol lipid at the 3' position of the inositol ring. [PMID:10209156, PMID:9255069]
Full description |

Standard name | GO_INSULIN_BINDING
Systematic name | M26667
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with insulin, a polypeptide hormone produced by the islets of Langerhans of the pancreas in mammals, and by the homologous organs of other organisms. [ISBN:0198506732]
Full description |

Standard name | GO_INSULIN_RECEPTOR_SUBSTRATE_BINDING
Systematic name | M18901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any of the insulin receptor substrate (IRS) proteins, adaptor proteins that bind to the transphosphorylated insulin and insulin-like growth factor receptors, are themselves phosphorylated and in turn recruit SH2 domain-containing signaling molecules to form a productive signaling complex. [PMID:12829233]
Full description |

Standard name | GO_SEQUENCE_SPECIFIC_DNA_BINDING
Systematic name | M19027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with DNA of a specific nucleotide composition, e.g. GC-rich DNA binding, or with a specific sequence motif or type of DNA e.g. promotor binding or rDNA binding. [GOC:jl]
Full description |

Standard name | GO_PROTEIN_SELF_ASSOCIATION
Systematic name | M17916
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a domain within the same polypeptide. [GOC:jl]
Full description |

Standard name | GO_CYCLIC_NUCLEOTIDE_GATED_ION_CHANNEL_ACTIVITY
Systematic name | M17930
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an ion by a channel that opens when a cyclic nucleotide has been bound by the channel complex or one of its constituent parts. [GOC:jl]
Full description |

Standard name | GO_GLYCERALDEHYDE_3_PHOSPHATE_DEHYDROGENASE_NADPLUS_NON_PHOSPHORYLATING_ACTIVITY
Systematic name | M26668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: D-glyceraldehyde 3-phosphate + NAD+ + H2O = 3-phospho-D-glycerate + NADH + H+. [PMID:9497334]
Full description |

Standard name | GO_HISTONE_ACETYLTRANSFERASE_ACTIVITY_H3_K23_SPECIFIC
Systematic name | M34433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acetyl-CoA + histone H3 L-lysine (position 23) = CoA + histone H3 N6-acetyl-L-lysine (position 23). [EC:2.3.1.48]
Full description |

Standard name | GO_PROTEIN_FOLDING_CHAPERONE
Systematic name | M26670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any protein or protein complex (a complex of two or more proteins that may include other nonprotein molecules) that contributes to the process of protein folding. [GOC:mtg_cambridge_2009]
Full description |

Standard name | GO_RETINOIC_ACID_RESPONSIVE_ELEMENT_BINDING
Systematic name | M29495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a retinoic acid-responsive element, a variable direct repeat of the sequence PuGGTCA spaced by five nucleotides (DR5) found in the promoters of retinoic acid-responsive genes, to which retinoic acid receptors bind. [GOC:jl, GOC:vw, GOC:yaf, PMID:11327309, PMID:19917671]
Full description |

Standard name | GO_ION_CHANNEL_BINDING
Systematic name | M18553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with one or more specific sites on an ion channel, a protein complex that spans a membrane and forms a water-filled channel across the phospholipid bilayer allowing selective ion transport down its electrochemical gradient. [GOC:BHF, GOC:jl]
Full description |

Standard name | GO_SMALL_PROTEIN_ACTIVATING_ENZYME_BINDING
Systematic name | M26671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a small protein activating enzyme, such as ubiquitin-activating enzyme. [GOC:jl]
Full description |

Standard name | GO_UBIQUITIN_LIKE_PROTEIN_LIGASE_BINDING
Systematic name | M18718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a ubiquitin-like protein ligase, such as ubiquitin-ligase. [GOC:jl]
Full description |

Standard name | GO_UBIQUITIN_LIKE_PROTEIN_CONJUGATING_ENZYME_BINDING
Systematic name | M18713
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a ubiquitin-like protein conjugating enzyme such as ubiquitin conjugating enzyme. [GOC:jl]
Full description |

Standard name | GO_DNA_TOPOISOMERASE_BINDING
Systematic name | M26672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a DNA topoisomerase. [GOC:jl]
Full description |

Standard name | GO_S100_PROTEIN_BINDING
Systematic name | M18228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a S100 protein. S100 is a small calcium and zinc binding protein produced in astrocytes that is implicated in Alzheimer's disease, Down Syndrome and ALS. [GOC:jid]
Full description |

Standard name | GO_ATPASE_ACTIVITY_COUPLED_TO_TRANSMEMBRANE_MOVEMENT_OF_IONS_ROTATIONAL_MECHANISM
Systematic name | M26673
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of ions from one side of a membrane to the other according to the reaction: ATP + H2O + ion(in) = ADP + phosphate + ion(out), by a rotational mechanism. [GOC:jl]
Full description |

Standard name | GO_PROTEIN_CONTAINING_COMPLEX_BINDING
Systematic name | M26674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a macromolecular complex. [GOC:jl]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_PURINERGIC_NUCLEOTIDE_RECEPTOR_ACTIVITY
Systematic name | M34434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a purine nucleotide and transmitting the signal across the membrane by activating an associated G-protein; promotes the exchange of GDP for GTP on the alpha subunit of a heterotrimeric G-protein complex. [GOC:mah, PMID:9755289]
Full description |

Standard name | GO_BIOACTIVE_LIPID_RECEPTOR_ACTIVITY
Systematic name | M18869
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a bioactive lipid and transmitting the signal across the membrane by activating an associated G-protein; promotes the exchange of GDP for GTP on the alpha subunit of a heterotrimeric G-protein complex. A bioactive lipid is a lipid for which changes in lipid levels result in functional consequences in a variety of cellular processes. [GOC:bf, GOC:mah, PMID:12215548, PMID:18216770]
Full description |

Standard name | GO_PRE_MRNA_BRANCH_POINT_BINDING
Systematic name | M34435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a pre-mRNA branch point sequence, located upstream of the 3' splice site. [PMID:11691992, PMID:9722632]
Full description |

Standard name | GO_MYOSIN_II_BINDING
Systematic name | M26676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a class II myosin, any member of the class of 'conventional' double-headed myosins that includes muscle myosin. [GOC:mah, http://www.mrc-lmb.cam.ac.uk/myosin/Review/Reviewframeset.html]
Full description |

Standard name | GO_TRANSLATION_REGULATOR_ACTIVITY
Systematic name | M1220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Any molecular function involved in the initiation, activation, perpetuation, repression or termination of polypeptide synthesis at the ribosome. [GOC:ai]
Full description |

Standard name | GO_CXCR_CHEMOKINE_RECEPTOR_BINDING
Systematic name | M18914
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a chemokine receptor in the CXCR family. [GOC:ceb, PMID:11910892]
Full description |

Standard name | GO_ALPHA_CATENIN_BINDING
Systematic name | M26677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the alpha subunit of the catenin complex. [GOC:bf]
Full description |

Standard name | GO_GAMMA_CATENIN_BINDING
Systematic name | M19061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the gamma subunit of the catenin complex. [GOC:bf]
Full description |

Standard name | GO_CADHERIN_BINDING
Systematic name | M19119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with cadherin, a type I membrane protein involved in cell adhesion. [GOC:bf]
Full description |

Standard name | GO_PROTEIN_PHOSPHORYLATED_AMINO_ACID_BINDING
Systematic name | M18113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a phosphorylated amino acid residue within a protein. [GOC:go_curators]
Full description |

Standard name | GO_UNMETHYLATED_CPG_BINDING
Systematic name | M34436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with unmethylated CpG motifs. Unmethylated CpG dinucleotides are often associated with gene promoters. [GOC:ai, PMID:10688657]
Full description |

Standard name | GO_CHEMOREPELLENT_ACTIVITY
Systematic name | M18961
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Providing the environmental signal that initiates the directed movement of a motile cell or organism towards a lower concentration of that signal. [GOC:ai]
Full description |

Standard name | GO_DYNEIN_LIGHT_CHAIN_BINDING
Systematic name | M26678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a light chain of the dynein complex. [GOC:bf]
Full description |

Standard name | GO_DYNEIN_HEAVY_CHAIN_BINDING
Systematic name | M26679
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a heavy chain of the dynein complex. [GOC:bf]
Full description |

Standard name | GO_DYNEIN_INTERMEDIATE_CHAIN_BINDING
Systematic name | M26680
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an intermediate chain of the dynein complex. [GOC:bf]
Full description |

Standard name | GO_SYNDECAN_BINDING
Systematic name | M26681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with syndecan, an integral membrane proteoglycan (250-300 kDa) associated largely with epithelial cells. [GOC:go_curators, PMID:9355727]
Full description |

Standard name | GO_TRAIL_BINDING
Systematic name | M26682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with TRAIL (TNF-related apoptosis inducing ligand), a member of the tumor necrosis factor ligand family that rapidly induces apoptosis in a variety of transformed cell lines. [GOC:go_curators, PMID:9082980]
Full description |

Standard name | GO_INOSITOL_TRISPHOSPHATE_PHOSPHATASE_ACTIVITY
Systematic name | M19203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: myo-inositol trisphosphate + H2O = myo-inositol bisphosphate + phosphate. [GOC:bf]
Full description |

Standard name | GO_SMAD_BINDING
Systematic name | M1573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a SMAD signaling protein. [GOC:ai]
Full description |

Standard name | GO_GLUCOSYLTRANSFERASE_ACTIVITY
Systematic name | M19003
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a glucosyl group to an acceptor molecule, typically another carbohydrate or a lipid. [ISBN:0198506732]
Full description |

Standard name | GO_SPHINGOLIPID_TRANSPORTER_ACTIVITY
Systematic name | M26683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the directed movement of sphingolipids into, out of or within a cell, or between cells. Sphingolipids are a class of lipids containing the long-chain amine diol sphingosine or a closely related base (a sphingoid). [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_SPHINGOLIPID_BINDING
Systematic name | M26684
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with sphingolipids, a class of lipids containing the long-chain amine diol sphingosine or a closely related base (a sphingoid). [ISBN:0198506732]
Full description |

Standard name | GO_NATURAL_KILLER_CELL_LECTIN_LIKE_RECEPTOR_BINDING
Systematic name | M26685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a lectin-like natural killer cell receptor. [GOC:ai]
Full description |

Standard name | GO_VIRION_BINDING
Systematic name | M26686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a virion, either by binding to components of the capsid or the viral envelope. [GOC:ai]
Full description |

Standard name | GO_CADMIUM_ION_BINDING
Systematic name | M26687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with cadmium (Cd) ions. [GOC:ai]
Full description |

Standard name | GO_METAL_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of metal ions from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_EPHRIN_RECEPTOR_BINDING
Systematic name | M19124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an ephrin receptor. [GOC:ai]
Full description |

Standard name | GO_TETRAPYRROLE_BINDING
Systematic name | M18904
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a tetrapyrrole, a compound containing four pyrrole nuclei variously substituted and linked to each other through carbons at the alpha position. [GOC:curators, ISBN:0198506732]
Full description |

Standard name | GO_TRANSFERASE_ACTIVITY_TRANSFERRING_ACYL_GROUPS_ACYL_GROUPS_CONVERTED_INTO_ALKYL_ON_TRANSFER
Systematic name | M26688
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an acyl group from one compound (donor) to another (acceptor), with the acyl group being converted into alkyl on transfer. [GOC:jl]
Full description |

Standard name | GO_TRANSITION_METAL_ION_BINDING
Systematic name | M11903
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a transition metal ions; a transition metal is an element whose atom has an incomplete d-subshell of extranuclear electrons, or which gives rise to a cation or cations with an incomplete d-subshell. Transition metals often have more than one valency state. Biologically relevant transition metals include vanadium, manganese, iron, copper, cobalt, nickel, molybdenum and silver. [ISBN:0198506732]
Full description |

Standard name | GO_TRANSITION_METAL_ION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of transition metal ions from one side of a membrane to the other. A transition metal is an element whose atom has an incomplete d-subshell of extranuclear electrons, or which gives rise to a cation or cations with an incomplete d-subshell. Transition metals often have more than one valency state. Biologically relevant transition metals include vanadium, manganese, iron, copper, cobalt, nickel, molybdenum and silver. [ISBN:0198506732]
Full description |

Standard name | GO_ALPHA_1_3_FUCOSYLTRANSFERASE_ACTIVITY
Systematic name | M26689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an L-fucosyl group from GDP-beta-L-fucose to an acceptor molecule to form an alpha-(1->3) linkage. [GOC:ai]
Full description |

Standard name | GO_ER_RETENTION_SEQUENCE_BINDING
Systematic name | M26690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an endoplasmic reticulum (ER) retention sequence, a specific peptide sequence that ensures a protein is retained within the ER. [GOC:ai]
Full description |

Standard name | GO_PROTON_TRANSPORTING_ATP_SYNTHASE_ACTIVITY_ROTATIONAL_MECHANISM
Systematic name | M19007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the synthesis of ATP from ADP and phosphate by the transfer of protons from one side of a membrane to the other by a rotational mechanism driven by a gradient according to the reaction: ADP + H2O + phosphate + H+(in) = ATP + H+(out). [RHEA:57722]
Full description |

Standard name | GO_1_PHOSPHATIDYLINOSITOL_3_KINASE_REGULATOR_ACTIVITY
Systematic name | M26691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of the enzyme 1-phosphatidylinositol-3-kinase activity. [GOC:ai]
Full description |

Standard name | GO_RETINOID_X_RECEPTOR_BINDING
Systematic name | M18804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a retinoid X receptor. [GOC:ai]
Full description |

Standard name | GO_THYROID_HORMONE_RECEPTOR_BINDING
Systematic name | M19049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a thyroid hormone receptor. [GOC:ai]
Full description |

Standard name | GO_HISTONE_ACETYLTRANSFERASE_ACTIVITY_H4_K16_SPECIFIC
Systematic name | M34437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acetyl-CoA + histone H4 L-lysine (position 16) = CoA + histone H4 N6-acetyl-L-lysine (position 16). This reaction represents the addition of an acetyl group to the lysine at position 16 of histone H4. [EC:2.3.1.48]
Full description |

Standard name | GO_HISTONE_METHYLTRANSFERASE_ACTIVITY_H3_K9_SPECIFIC
Systematic name | M26693
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + histone H3 L-lysine (position 9) = S-adenosyl-L-homocysteine + histone H3 N6-methyl-L-lysine (position 9). This reaction is the addition of a methyl group onto lysine at position 9 of the histone H3 protein. [GOC:ai]
Full description |

Standard name | GO_HISTONE_METHYLTRANSFERASE_ACTIVITY_H3_K36_SPECIFIC
Systematic name | M26694
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + histone H3 L-lysine (position 36) = S-adenosyl-L-homocysteine + histone H3 N6-methyl-L-lysine (position 36). This reaction is the addition of a methyl group onto lysine at position 36 of the histone H3 protein. [GOC:ai]
Full description |

Standard name | GO_HISTONE_METHYLTRANSFERASE_ACTIVITY_H3_K27_SPECIFIC
Systematic name | M26695
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + histone H3 L-lysine (position 27) = S-adenosyl-L-homocysteine + histone H3 N6-methyl-L-lysine (position 27). This reaction is the addition of a methyl group onto lysine at position 27 of the histone H3 protein. [GOC:ai]
Full description |

Standard name | GO_TAP_BINDING
Systematic name | M34438
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with TAP protein, transporter associated with antigen processing protein. TAP protein is a heterodimeric peptide transporter consisting of the subunits TAP1 and TAP2. [PMID:11133832]
Full description |

Standard name | GO_TAP1_BINDING
Systematic name | M34439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the TAP1 subunit of TAP (transporter associated with antigen processing) protein. [PMID:11133832]
Full description |

Standard name | GO_PROTEIN_HETERODIMERIZATION_ACTIVITY
Systematic name | M17973
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a nonidentical protein to form a heterodimer. [GOC:ai]
Full description |

Standard name | GO_PROTEIN_DIMERIZATION_ACTIVITY
Systematic name | M18046
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The formation of a protein dimer, a macromolecular structure consists of two noncovalently associated identical or nonidentical subunits. [ISBN:0198506732]
Full description |

Standard name | GO_ANDROSTERONE_DEHYDROGENASE_ACTIVITY
Systematic name | M29496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: NAD(P)+ + androsterone = NAD(P)H + H+ + 5-alpha-androstane-3,17-dione. [EC:1.1.1.209, MetaCyc:1.1.1.209-RXN]
Full description |

Standard name | GO_TESTOSTERONE_DEHYDROGENASE_NADPLUS_ACTIVITY
Systematic name | M26696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: testosterone + NAD+ = androst-4-ene-3,17-dione + NADH. [EC:1.1.1.239, MetaCyc:1.1.1.239-RXN]
Full description |

Standard name | GO_KETOSTEROID_MONOOXYGENASE_ACTIVITY
Systematic name | M26697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: O2 + NADPH + progesterone = H2O + NADP+ + testosterone acetate. [EC:1.14.13.54, MetaCyc:1.14.13.54-RXN]
Full description |

Standard name | GO_1_ACYLGLYCEROPHOSPHOCHOLINE_O_ACYLTRANSFERASE_ACTIVITY
Systematic name | M26698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-acyl-sn-glycero-3-phosphocholine + acyl-CoA = phosphatidylcholine + CoA. [EC:2.3.1.23, MetaCyc:2.3.1.23-RXN]
Full description |

Standard name | GO_GLUCURONOSYL_N_ACETYLGALACTOSAMINYL_PROTEOGLYCAN_4_BETA_N_ACETYLGALACTOSAMINYLTRANSFERASE_ACTIVITY
Systematic name | M34440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: D-glucuronyl-N-acetyl-1,3-beta-D-galactosaminylproteoglycan + UDP-N-acetylgalactosamine = N-acetyl-D-galactosaminyl-1,4-beta-D-glucuronyl-N-acetyl-1,3-beta-D-galactosaminylproteoglycan + UDP. [EC:2.4.1.175, MetaCyc:2.4.1.175-RXN]
Full description |

Standard name | GO_ACYLGLYCEROL_LIPASE_ACTIVITY
Systematic name | M26699
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: H2O + acylglycerol = a fatty acid + glycerol. [EC:3.1.1.23, MetaCyc:3.1.1.23-RXN]
Full description |

Standard name | GO_NUCLEOSIDE_TRIPHOSPHATE_DIPHOSPHATASE_ACTIVITY
Systematic name | M26700
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: H2O + a nucleoside triphosphate = diphosphate + a nucleotide. [MetaCyc:3.6.1.19-RXN]
Full description |

Standard name | GO_PROTEIN_N_TERMINUS_BINDING
Systematic name | M7285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein N-terminus, the end of any peptide chain at which the 2-amino (or 2-imino) function of a constituent amino acid is not attached in peptide linkage to another amino-acid residue. [ISBN:0198506732]
Full description |

Standard name | GO_CALCIUM_DEPENDENT_PHOSPHOLIPASE_A2_ACTIVITY
Systematic name | M26701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: phosphatidylcholine + H2O = 1-acylglycerophosphocholine + a carboxylate. This reaction requires Ca2+. [EC:3.1.1.4]
Full description |

Standard name | GO_CALCIUM_INDEPENDENT_PHOSPHOLIPASE_A2_ACTIVITY
Systematic name | M26702
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: phosphatidylcholine + H2O = 1-acylglycerophosphocholine + a carboxylate. This reaction does not require Ca2+. [EC:3.1.1.4]
Full description |

Standard name | GO_3_5_CYCLIC_GMP_PHOSPHODIESTERASE_ACTIVITY
Systematic name | M17980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: guanosine 3',5'-cyclic phosphate + H2O = guanosine 5'-phosphate. [EC:3.1.4.35, MetaCyc:35-CYCLIC-GMP-PHOSPHODIESTERASE-RXN]
Full description |

Standard name | GO_ADP_RIBOSE_DIPHOSPHATASE_ACTIVITY
Systematic name | M26703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ADP-ribose + H2O = AMP + D-ribose 5-phosphate. [EC:3.6.1.13, MetaCyc:ADP-RIBOSE-PYROPHOSPHATASE-RXN]
Full description |

Standard name | GO_ARACHIDONATE_COA_LIGASE_ACTIVITY
Systematic name | M29497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: arachidonate + ATP + CoA = AMP + arachidonoyl-CoA + diphosphate + H(+). [EC:6.2.1.15, RHEA:19713]
Full description |

Standard name | GO_BUTYRATE_COA_LIGASE_ACTIVITY
Systematic name | M26704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + an acid + CoA = AMP + diphosphate + an acyl-CoA. [EC:6.2.1.2, MetaCyc:BUTYRATE--COA-LIGASE-RXN]
Full description |

Standard name | GO_DEOXYCYTIDINE_DEAMINASE_ACTIVITY
Systematic name | M29498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: deoxycytidine + H2O = deoxyuridine + NH3. [EC:3.5.4.14, MetaCyc:DEOXYCYTIDINE-DEAMINASE-RXN]
Full description |

Standard name | GO_GLYCINE_N_ACYLTRANSFERASE_ACTIVITY
Systematic name | M26705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acyl-CoA + glycine = CoA + N-acylglycine. [EC:2.3.1.13, MetaCyc:GLYCINE-N-ACYLTRANSFERASE-RXN]
Full description |

Standard name | GO_RECEPTOR_ANTAGONIST_ACTIVITY
Systematic name | M26706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The activity of a gene product that interacts with a receptor to decrease the ability of the receptor agonist to bind and activate the receptor. [GOC:ceb, ISBN:0198506732]
Full description |

Standard name | GO_CCR_CHEMOKINE_RECEPTOR_BINDING
Systematic name | M18725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a CCR chemokine receptor. [GOC:ai]
Full description |

Standard name | GO_MRNA_5_UTR_BINDING
Systematic name | M26707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the 5' untranslated region of an mRNA molecule. [GOC:jid]
Full description |

Standard name | GO_MONOSACCHARIDE_BINDING
Systematic name | M6223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any monosaccharide. Monosaccharides are the simplest carbohydrates; they are polyhydroxy aldehydes H[CH(OH)]nC(=O)H or polyhydroxy ketones H[CHOH]nC(=O)[CHOH]mH with three or more carbon atoms. They form the constitutional repeating units of oligo- and polysaccharides. [GOC:jid]
Full description |

Standard name | GO_QUINONE_BINDING
Systematic name | M17900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a quinone, any member of a class of diketones derivable from aromatic compounds by conversion of two CH groups into CO groups with any necessary rearrangement of double bonds. [ISBN:0198506732]
Full description |

Standard name | GO_UBIQUINONE_BINDING
Systematic name | M26708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with ubiquinone, a quinone derivative with a tail of isoprene units. [GOC:jid, ISBN:0582227089]
Full description |

Standard name | GO_TAU_PROTEIN_BINDING
Systematic name | M17965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with tau protein. tau is a microtubule-associated protein, implicated in Alzheimer's disease, Down Syndrome and ALS. [GOC:jid]
Full description |

Standard name | GO_ACTIVIN_BINDING
Systematic name | M18745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with activin, a dimer of inhibin-beta subunits. [GOC:jid, GOC:mah]
Full description |

Standard name | GO_CXCR3_CHEMOKINE_RECEPTOR_BINDING
Systematic name | M26709
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a the CXCR3 chemokine receptor. [GOC:jid, PMID:10556837]
Full description |

Standard name | GO_FLAP_ENDONUCLEASE_ACTIVITY
Systematic name | M26710
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of a flap structure in DNA, but not other DNA structures; processes the ends of Okazaki fragments in lagging strand DNA synthesis. [GOC:jid]
Full description |

Standard name | GO_MITOGEN_ACTIVATED_PROTEIN_KINASE_P38_BINDING
Systematic name | M26711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with mitogen-activated protein kinase p38, an enzyme that catalyzes the transfer of phosphate from ATP to hydroxyl side chains on proteins in response to mitogen activation. [GOC:curators, PMID:17827184]
Full description |

Standard name | GO_CALCIUM_DEPENDENT_PROTEIN_BINDING
Systematic name | M18207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any protein or protein complex (a complex of two or more proteins that may include other nonprotein molecules), in the presence of calcium. [GOC:jid, PMID:10485905]
Full description |

Standard name | GO_RAC_GTPASE_BINDING
Systematic name | M18874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with Rac protein, any member of the Rac subfamily of the Ras superfamily of monomeric GTPases. [GOC:ebc, PMID:11702775]
Full description |

Standard name | GO_NERVE_GROWTH_FACTOR_BINDING
Systematic name | M26712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with nerve growth factor (NGF). [GOC:dgh]
Full description |

Standard name | GO_PLATELET_DERIVED_GROWTH_FACTOR_BINDING
Systematic name | M18852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with platelet-derived growth factor. [GOC:dgh]
Full description |

Standard name | GO_BETA_TUBULIN_BINDING
Systematic name | M192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the microtubule constituent protein beta-tubulin. [GOC:krc]
Full description |

Standard name | GO_ROUNDABOUT_BINDING
Systematic name | M26713
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the Roundabout (ROBO) receptor, a transmembrane receptor. [GOC:ecd, PMID:10102268, PMID:10197527]
Full description |

Standard name | GO_BETA_1_3_GALACTOSYLTRANSFERASE_ACTIVITY
Systematic name | M18409
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a galactose residue from a donor molecule to an oligosaccharide, forming a beta-1,3-linkage. [PMID:11551958]
Full description |

Standard name | GO_LEUKOTRIENE_B4_20_MONOOXYGENASE_ACTIVITY
Systematic name | M34441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: (6Z,8E,10E,14Z)-(5S,12R)-5,12-dihydroxyicosa-6,8,10,14-tetraenoate + NADPH + H+ + O2 = (6Z,8E,10E,14Z)-(5S,12R)-5,12,20-trihydroxyicosa-6,8,10,14-tetraenoate + NADP+ + H2O. [MetaCyc:LEUKOTRIENE-B4-20-MONOOXYGENASE-RXN, RHEA:22176]
Full description |

Standard name | GO_M7G_5_PPPN_DIPHOSPHATASE_ACTIVITY
Systematic name | M26714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 7-methylguanosine 5'-triphospho-5'-polynucleotide + H2O = 7-methylguanosine 5'-phosphate + polynucleotide. [EC:3.6.1.30, MetaCyc:M7G5PPPN-PYROPHOSPHATASE-RXN]
Full description |

Standard name | GO_NUCLEOSIDE_MONOPHOSPHATE_KINASE_ACTIVITY
Systematic name | M26715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + nucleoside monophosphate = ADP + nucleoside diphosphate. [GOC:ai, ISBN:0198506732]
Full description |

Standard name | GO_SPHINGOSINE_N_ACYLTRANSFERASE_ACTIVITY
Systematic name | M26716
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acyl-CoA + sphingosine = CoA + N-acylsphingosine. [EC:2.3.1.24, MetaCyc:SPHINGOSINE-N-ACYLTRANSFERASE-RXN, PMID:12069845]
Full description |

Standard name | GO_TAU_PROTEIN_KINASE_ACTIVITY
Systematic name | M19067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + tau-protein = ADP + O-phospho-tau-protein. [EC:2.7.11.26, MetaCyc:TAU-PROTEIN-KINASE-RXN]
Full description |

Standard name | GO_TRANSFORMING_GROWTH_FACTOR_BETA_BINDING
Systematic name | M18288
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with TGF-beta, transforming growth factor beta, a multifunctional peptide that controls proliferation, differentiation and other functions in many cell types. [ISBN:0198506732]
Full description |

Standard name | GO_ICOSANOID_BINDING
Systematic name | M26717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with icosanoids, any C20 polyunsaturated fatty acids or their derivatives, including the leukotrienes and the prostanoids. [ISBN:0198506732]
Full description |

Standard name | GO_ICOSATETRAENOIC_ACID_BINDING
Systematic name | M26718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with icosatetraenoic acid, any straight-chain fatty acid with twenty carbon atoms and four double bonds per molecule. [ISBN:0198506732]
Full description |

Standard name | GO_3_PHOSPHOADENOSINE_5_PHOSPHOSULFATE_BINDING
Systematic name | M26720
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with 3'-phosphoadenosine 5'-phosphosulfate (PAPS), a naturally occurring mixed anhydride. It is an intermediate in the formation of a variety of sulfo compounds in biological systems. [GOC:ai]
Full description |

Standard name | GO_FLAVIN_ADENINE_DINUCLEOTIDE_BINDING
Systematic name | M18994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with FAD, flavin-adenine dinucleotide, the coenzyme or the prosthetic group of various flavoprotein oxidoreductase enzymes, in either the oxidized form, FAD, or the reduced form, FADH2. [GOC:ai, GOC:imk, ISBN:0198506732]
Full description |

Standard name | GO_NADP_BINDING
Systematic name | M18782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with nicotinamide-adenine dinucleotide phosphate, a coenzyme involved in many redox and biosynthetic reactions; binding may be to either the oxidized form, NADP+, or the reduced form, NADPH. [GOC:ai]
Full description |

Standard name | GO_OXIDOREDUCTASE_ACTIVITY_ACTING_ON_NAD_P_H_OXYGEN_AS_ACCEPTOR
Systematic name | M18682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which NADH or NADPH acts as a hydrogen or electron donor and reduces an oxygen molecule. [EC:1.6.3.-]
Full description |

Standard name | GO_ANDROGEN_RECEPTOR_BINDING
Systematic name | M18239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an androgen receptor. [GOC:ai]
Full description |

Standard name | GO_LBD_DOMAIN_BINDING
Systematic name | M26721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the LBD, the ligand binding domain found in nuclear receptors. In general, the LBDs consist of three layers comprised of twelve alpha-helices and several beta-strands that are organized around a lipophilic ligand-binding pocket. [PMID:9682036]
Full description |

Standard name | GO_WW_DOMAIN_BINDING
Systematic name | M18529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a WW domain of a protein, a small module composed of 40 amino acids and plays a role in mediating protein-protein interactions via proline-rich regions. [PMID:14531730]
Full description |

Standard name | GO_CARD_DOMAIN_BINDING
Systematic name | M26722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a CARD (N-terminal caspase recruitment) domain, a protein-protein interaction domain that belongs to the death domain-fold superfamily. These protein molecule families are similar in structure with each consisting of six or seven anti-parallel alpha-helices that form highly specific homophilic interactions between signaling partners. CARD exists in the N-terminal prodomains of several caspases and in apoptosis-regulatory proteins and mediates the assembly of CARD-containing proteins that participate in activation or suppression of CARD carrying members of the caspase family. [PMID:12054670]
Full description |

Standard name | GO_RS_DOMAIN_BINDING
Systematic name | M26723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an RS domain of a protein; RS domains are usually highly phosphorylated and characterized by the presence of arginine (R)/serine (S) dipeptides. The RS domain promotes protein-protein interactions and directs subcellular localization and, in certain situations, nucleocytoplasmic shuttling of individual SR proteins. They also play a role in splicing. [PMID:11684676, PMID:12215544]
Full description |

Standard name | GO_LOW_DENSITY_LIPOPROTEIN_PARTICLE_RECEPTOR_BINDING
Systematic name | M18492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a low-density lipoprotein receptor. [GOC:ai]
Full description |

Standard name | GO_DOPAMINE_RECEPTOR_BINDING
Systematic name | M19054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a dopamine receptor. [GOC:ai]
Full description |

Standard name | GO_RAGE_RECEPTOR_BINDING
Systematic name | M18595
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the RAGE receptor, the receptor for advanced glycation end-products. [GOC:ai]
Full description |

Standard name | GO_GABA_RECEPTOR_BINDING
Systematic name | M18644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the gamma-aminobutyric acid (GABA, 4-aminobutyrate) receptor. [GOC:ai]
Full description |

Standard name | GO_PHOSPHOSERINE_RESIDUE_BINDING
Systematic name | M26724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a phosphorylated serine residue within a protein. [GOC:ai]
Full description |

Standard name | GO_PYRUVATE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of pyruvate, 2-oxopropanoate, from one side of a membrane to the other. [GOC:ai]
Full description |

Standard name | GO_CELL_ADHESION_MOLECULE_BINDING
Systematic name | M19114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a cell adhesion molecule. [GOC:ai]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX_BINDING
Systematic name | M18158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a component of the extracellular matrix. [GOC:ai]
Full description |

Standard name | GO_QUATERNARY_AMMONIUM_GROUP_BINDING
Systematic name | M18701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a quaternary ammonium group, including glycine betaine, choline, carnitine and proline. A quaternary ammonium group is any compound that can be regarded as derived from ammonium hydroxide or an ammonium salt by replacement of all four hydrogen atoms of the NH4+ ion by organic groups. [GOC:ai]
Full description |

Standard name | GO_NITRIC_OXIDE_SYNTHASE_BINDING
Systematic name | M18166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the enzyme nitric-oxide synthase. [GOC:ai]
Full description |

Standard name | GO_MICROTUBULE_PLUS_END_BINDING
Systematic name | M26726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the plus end of a microtubule. [GOC:ai, PMID:14557818, PMID:14614826]
Full description |

Standard name | GO_MICROTUBULE_MINUS_END_BINDING
Systematic name | M26727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the minus end of a microtubule. [GOC:ai, PMID:14557818, PMID:14614826]
Full description |

Standard name | GO_ACTIN_FILAMENT_BINDING
Systematic name | M9766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an actin filament, also known as F-actin, a helical filamentous polymer of globular G-actin subunits. [ISBN:0198506732]
Full description |

Standard name | GO_PROTEIN_KINASE_A_BINDING
Systematic name | M18068
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any subunit of protein kinase A. [GOC:ai]
Full description |

Standard name | GO_MITOGEN_ACTIVATED_PROTEIN_KINASE_BINDING
Systematic name | M17862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a mitogen-activated protein kinase. [GOC:ai]
Full description |

Standard name | GO_GTPASE_BINDING
Systematic name | M11497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a GTPase, any enzyme that catalyzes the hydrolysis of GTP. [GOC:ai]
Full description |

Standard name | GO_NF_KAPPAB_BINDING
Systematic name | M18353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with NF-kappaB, a transcription factor for eukaryotic RNA polymerase II promoters. [GOC:ai]
Full description |

Standard name | GO_UNFOLDED_PROTEIN_BINDING
Systematic name | M18048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an unfolded protein. [GOC:ai]
Full description |

Standard name | GO_CHAPERONE_BINDING
Systematic name | M18579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a chaperone protein, a class of proteins that bind to nascent or unfolded polypeptides and ensure correct folding or transport. [PMID:10585443]
Full description |

Standard name | GO_ATPASE_BINDING
Systematic name | M18449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an ATPase, any enzyme that catalyzes the hydrolysis of ATP. [GOC:ai]
Full description |

Standard name | GO_SUGAR_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a sugar from one side of a membrane to the other. A sugar is any member of a class of sweet, water-soluble, crystallizable carbohydrates, which are the monosaccharides and smaller oligosaccharides. [GOC:ai, GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_METAL_ION_PROTON_ANTIPORTER_ACTIVITY
Systematic name | M29499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: metal ion(in) + H+(out) = metal ion(out) + H+(in). [GOC:mlg]
Full description |

Standard name | GO_DIOXYGENASE_ACTIVITY
Systematic name | M18375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of an oxidation-reduction (redox) reaction in which both atoms of oxygen from one molecule of O2 are incorporated into the (reduced) product(s) of the reaction. The two atoms of oxygen may be distributed between two different products. [DOI:10.1016/S0040-4020(03)00944-X, GOC:bf]
Full description |

Standard name | GO_PHOSPHOPROTEIN_BINDING
Systematic name | M17894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a phosphorylated protein. [GOC:ai]
Full description |

Standard name | GO_NAD_BINDING
Systematic name | M18577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with nicotinamide adenine dinucleotide, a coenzyme involved in many redox and biosynthetic reactions; binding may be to either the oxidized form, NAD+, or the reduced form, NADH. [GOC:ai]
Full description |

Standard name | GO_MUSCLE_ALPHA_ACTININ_BINDING
Systematic name | M26730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with muscle isoforms of actinin. Muscle alpha-actinin isoforms are found in skeletal and cardiac muscle and are localized to the Z-disc. [PMID:10984498, PMID:11699871, PMID:15014165]
Full description |

Standard name | GO_FATZ_BINDING
Systematic name | M26731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a member of the FATZ family of proteins, filamin-, actinin-, and telethonin-binding proteins of the Z-disc of striated muscle. FATZ proteins are located in the Z-disc of the sarcomere and are involved in a complex network of interactions with other Z-band components. [PMID:10984498, PMID:11699871]
Full description |

Standard name | GO_EPINEPHRINE_BINDING
Systematic name | M26732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with epinephrine, a hormone produced by the medulla of the adrenal glands that increases heart activity, improves the power and prolongs the action of muscles, and increases the rate and depth of breathing. It is synthesized by the methylation of norepinephrine. [GOC:ai]
Full description |

Standard name | GO_ALPHA_ACTININ_BINDING
Systematic name | M18989
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with alpha-actinin, one of a family of proteins that cross-link F-actin as antiparallel homodimers. Alpha-actinin has a molecular mass of 93-103 KDa; at the N-terminus there are two calponin homology domains, at the C-terminus there are two EF-hands. These two domains are connected by the rod domain. This domain is formed by triple-helical spectrin repeats. [PMID:10984498, PMID:11699871, PMID:15014165]
Full description |

Standard name | GO_BH_DOMAIN_BINDING
Systematic name | M26734
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the Bcl-2 homology (BH) domain of a protein. Bcl-2-related proteins share homology in one to four conserved regions designated the Bcl-2 homology (BH) domains BH1, BH2, BH3 and BH4. These domains contribute at multiple levels to the function of these proteins in cell death and survival. Anti-apoptotic members of the Bcl-2 family have four BH domains (BH1-BH4). Pro-apoptotic members have fewer BH domains. [PMID:11048732, PMID:12133724, PMID:9020082, PMID:9704409]
Full description |

Standard name | GO_HORMONE_RECEPTOR_BINDING
Systematic name | M17971
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a receptor for hormones. [GOC:ai]
Full description |

Standard name | GO_PEPTIDE_HORMONE_RECEPTOR_BINDING
Systematic name | M18065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a receptor for peptide hormones. [GOC:ai]
Full description |

Standard name | GO_CORTICOTROPIN_RELEASING_HORMONE_RECEPTOR_BINDING
Systematic name | M26735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a receptor for corticotropin-releasing hormone (CRH), a polypeptide hormone involved in the stress response. It is released by the hypothalamus and stimulates the release of corticotropin by the anterior pituitary gland. [GOC:ai]
Full description |

Standard name | GO_BH3_DOMAIN_BINDING
Systematic name | M26736
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the BH3 domain of a protein of the Bcl-2 family. The BH3 domain is a potent death domain and has an important role in protein-protein interactions and in cell death. [PMID:11048732, PMID:12133724, PMID:9020082, PMID:9704409, Prosite:PS01259]
Full description |

Standard name | GO_NFAT_PROTEIN_BINDING
Systematic name | M26737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with NFAT (nuclear factor of activated T cells) proteins, a family of transcription factors. NFAT proteins have crucial roles in the development and function of the immune system. [PMID:15928679]
Full description |

Standard name | GO_2_IRON_2_SULFUR_CLUSTER_BINDING
Systematic name | M18987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a 2 iron, 2 sulfur (2Fe-2S) cluster; this cluster consists of two iron atoms, with two inorganic sulfur atoms found between the irons and acting as bridging ligands. [GOC:ai, PMID:15952888, Wikipedia:Iron-sulfur_cluster]
Full description |

Standard name | GO_4_IRON_4_SULFUR_CLUSTER_BINDING
Systematic name | M19161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a 4 iron, 4 sulfur (4Fe-4S) cluster; this cluster consists of four iron atoms, with the inorganic sulfur atoms found between the irons and acting as bridging ligands. [GOC:ai, PMID:15952888, Wikipedia:Iron-sulfur_cluster]
Full description |

Standard name | GO_METAL_CLUSTER_BINDING
Systematic name | M18616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a cluster of atoms including both metal ions and nonmetal atoms, usually sulfur and oxygen. Examples include iron-sulfur clusters and nickel-iron-sulfur clusters. [GOC:jsg]
Full description |

Standard name | GO_5_DEOXYRIBOSE_5_PHOSPHATE_LYASE_ACTIVITY
Systematic name | M26738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the beta-elimination of the 5' deoxyribose-5-phosphate at an abasic site in DNA where a DNA-(apurinic or apyrimidinic site) lyase has already cleaved the C-O-P bond 3' to the apurinic or apyrimidinic site. [PMID:11251121, PMID:16120966]
Full description |

Standard name | GO_PROTEIN_PHOSPHATASE_2A_BINDING
Systematic name | M19145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the enzyme protein phosphatase 2A. [GOC:ai]
Full description |

Standard name | GO_INOSITOL_TRISPHOSPHATE_KINASE_ACTIVITY
Systematic name | M18639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: inositol trisphosphate + ATP = inositol tetrakisphosphate + ADP. [GOC:ai]
Full description |

Standard name | GO_MISFOLDED_PROTEIN_BINDING
Systematic name | M19033
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a misfolded protein. [GOC:ai]
Full description |

Standard name | GO_GLYCOLIPID_BINDING
Systematic name | M18495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a glycolipid, any compound containing one or more monosaccharide residues bound by a glycosidic linkage to a hydrophobic group such as an acylglycerol, a sphingoid, a ceramide (N-acylsphingoid) or a prenyl phosphate. [PMID:19635802]
Full description |

Standard name | GO_HISTONE_DEMETHYLASE_ACTIVITY_H3_K36_SPECIFIC
Systematic name | M26739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: histone H3 N6-methyl-L-lysine (position 36) + alpha-ketoglutarate + O2 = succinate + CO2 + formaldehyde + lysine. This reaction is the removal of a methyl group from lysine at position 36 of the histone H3 protein. [PMID:16362057]
Full description |

Standard name | GO_HSP90_PROTEIN_BINDING
Systematic name | M18372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with Hsp90 proteins, any of a group of heat shock proteins around 90kDa in size. [GOC:ai]
Full description |

Standard name | GO_G_QUADRUPLEX_DNA_BINDING
Systematic name | M26740
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with G-quadruplex DNA structures, in which groups of four guanines adopt a flat, cyclic Hoogsteen hydrogen-bonding arrangement known as a guanine tetrad. The stacking of guanine tetrads results in G-quadruplex DNA structures. G-quadruplex DNA can form under physiological conditions from some G-rich sequences, such as those found in telomeres, immunoglobulin switch regions, gene promoters, fragile X repeats, and the dimerization domain in the human immunodeficiency virus (HIV) genome. [PMID:16142245, PMID:9512530]
Full description |

Standard name | GO_PEROXIREDOXIN_ACTIVITY
Systematic name | M26741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 2 R'-SH + ROOH = R'-S-S-R' + H2O + ROH. [EC:1.11.1.15, RHEA:10008]
Full description |

Standard name | GO_DYNEIN_LIGHT_INTERMEDIATE_CHAIN_BINDING
Systematic name | M26742
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a light intermediate chain of the dynein complex. [GOC:bf]
Full description |

Standard name | GO_PROTEIN_CARBOXYL_O_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a methyl group to a carboxyl group on a protein. [GOC:ai]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_5_BISPHOSPHATE_3_PHOSPHATASE_ACTIVITY
Systematic name | M17992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-phosphatidyl-1D-myo-inositol 3,5-bisphosphate + H2O = a 1-phosphatidyl-1D-myo-inositol 5-phosphate + phosphate + 2 H+. [PMID:19901554, RHEA:39019]
Full description |

Standard name | GO_NADP_RETINOL_DEHYDROGENASE_ACTIVITY
Systematic name | M26744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: all-trans-retinol + NADP+ = all-trans-retinal + NADPH + H+. [RHEA:25033]
Full description |

Standard name | GO_INOSITOL_1_3_4_5_TETRAKISPHOSPHATE_5_PHOSPHATASE_ACTIVITY
Systematic name | M29500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1D-myo-inositol 1,3,4,5-tetrakisphosphate + H2O = 1D-myo-inositol 1,3,4-trisphosphate + phosphate. [EC:3.1.3.56, RHEA:11392]
Full description |

Standard name | GO_CARBOXYLIC_ESTER_HYDROLASE_ACTIVITY
Systematic name | M18646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a carboxylic ester bond. [EC:3.1.1, EC:3.1.1.1, GOC:curators]
Full description |

Standard name | GO_1_ACYL_2_LYSOPHOSPHATIDYLSERINE_ACYLHYDROLASE_ACTIVITY
Systematic name | M34442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-acyl-2-lysophosphatidylserine + H2O = sn-glycerol-phosphoserine + a carboxylate. [BRENDA:3.1.1.32]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_KINASE_ACTIVITY
Systematic name | M18451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a phosphatidylinositol = ADP + a phosphatidylinositol phosphate. [GOC:ai]
Full description |

Standard name | GO_INOSITOL_TETRAKISPHOSPHATE_PHOSPHATASE_ACTIVITY
Systematic name | M18218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: myo-inositol tetrakisphosphate + H2O = myo-inositol trisphosphate + phosphate. [GOC:ai]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_MONOPHOSPHATE_PHOSPHATASE_ACTIVITY
Systematic name | M18045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: phosphatidylinositol monophosphate + H2O = phosphatidylinositol + phosphate. [GOC:ai]
Full description |

Standard name | GO_INOSITOL_PHOSPHATE_PHOSPHATASE_ACTIVITY
Systematic name | M18633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: inositol phosphate(n) + H2O = inositol phosphate(n-1) + phosphate. This reaction is the removal of a phosphate group from an inositol phosphate. [GOC:ai]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_4_BISPHOSPHATE_5_KINASE_ACTIVITY
Systematic name | M29502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-phosphatidyl-1D-myo-inositol 3,4-bisphosphate + ATP = a 1-phosphatidyl-1D-myo-inositol 3,4,5-trisphosphate + ADP + 2 H(+). [EC:2.7.1.153]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_BISPHOSPHATE_KINASE_ACTIVITY
Systematic name | M26745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: ATP + a phosphatidylinositol bisphosphate = ADP + a phosphatidylinositol trisphosphate. [GOC:ai]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_PHOSPHATE_PHOSPHATASE_ACTIVITY
Systematic name | M17963
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: phosphatidylinositol phosphate(n) + H2O = phosphatidylinositol phosphate(n-1) + phosphate. This reaction is the removal of a phosphate group from a phosphatidylinositol phosphate. [GOC:ai]
Full description |

Standard name | GO_D_GLUCOSE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of the D-enantiomer of the hexose monosaccharide glucose from one side of a membrane to the other. [GOC:jid, GOC:jsg, GOC:mah]
Full description |

Standard name | GO_LIPASE_INHIBITOR_ACTIVITY
Systematic name | M18446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a lipase, an enzyme that catalyzes of the hydrolysis of a lipid. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_UBIQUITIN_PROTEIN_TRANSFERASE_INHIBITOR_ACTIVITY
Systematic name | M26747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a ubiquitin-protein transferase. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_UBIQUITIN_PROTEIN_TRANSFERASE_REGULATOR_ACTIVITY
Systematic name | M26748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a ubiquitin-protein transferase, an enzyme that catalyzes the covalent attachment of ubiquitin to lysine in a substrate protein. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_C3HC4_TYPE_RING_FINGER_DOMAIN_BINDING
Systematic name | M26749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a C3HC4-type zinc finger domain of a protein. The C3HC4-type zinc finger is a variant of RING finger, is a cysteine-rich domain of 40 to 60 residues that coordinates two zinc ions, and has the consensus sequence: C-X2-C-X(9-39)-C-X(1-3)-H-X(2-3)-C-X2-C-X(4-48)-C-X2-C, where X is any amino acid. Many proteins containing a C3HC4-type RING finger play a key role in the ubiquitination pathway. [GOC:amm, InterPro:IPR001841, InterPro:IPR018957]
Full description |

Standard name | GO_MOLECULAR_TRANSDUCER_ACTIVITY
Systematic name | M26750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A compound molecular function in which an effector function is controlled by one or more regulatory components. [GOC:dos, GOC:pdt]
Full description |

Standard name | GO_MOLECULAR_ADAPTOR_ACTIVITY
Systematic name | M3632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding activity of a molecule that brings together two or more molecules through a selective, non-covalent, often stoichiometric interaction, permitting those molecules to function in a coordinated way. [GOC:mtg_MIT_16mar07, GOC:vw]
Full description |

Standard name | GO_PHOSPHATIDYLCHOLINE_STEROL_O_ACYLTRANSFERASE_ACTIVATOR_ACTIVITY
Systematic name | M26752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Increases the activity of phosphatidylcholine-sterol O-acyltransferase, an enzyme that converts cholesterol and phosphatidylcholine (lecithins) to cholesteryl esters and lyso-phosphatidylcholines. [GOC:BHF, GOC:dph, GOC:tb, PMID:4335615]
Full description |

Standard name | GO_LIPASE_ACTIVATOR_ACTIVITY
Systematic name | M18651
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and increases the activity of a lipase, an enzyme that catalyzes of the hydrolysis of a lipid. [GOC:BHF, GOC:dph, GOC:tb]
Full description |

Standard name | GO_NUCLEOSIDE_TRIPHOSPHATASE_REGULATOR_ACTIVITY
Systematic name | M18508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the rate of NTP hydrolysis by a NTPase. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_ATPASE_REGULATOR_ACTIVITY
Systematic name | M18130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the rate of ATP hydrolysis by an ATPase. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_ENDOPEPTIDASE_ACTIVATOR_ACTIVITY
Systematic name | M26753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Increases the activity of an endopeptidase, any enzyme that hydrolyzes nonterminal peptide bonds in polypeptides. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_PEPTIDASE_REGULATOR_ACTIVITY
Systematic name | M17907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a peptidase, any enzyme that catalyzes the hydrolysis peptide bonds. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_ENDOPEPTIDASE_REGULATOR_ACTIVITY
Systematic name | M26754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a peptidase, any enzyme that hydrolyzes nonterminal peptide bonds in polypeptides. [GOC:dph, GOC:tb]
Full description |

Standard name | GO_L_ARGININE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M34444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the stereospecific transfer of L-arginine, 2-amino-5-guanidinopentanoic acid, across a biological membrane. [GOC:dph]
Full description |

Standard name | GO_CYCLIN_DEPENDENT_PROTEIN_SERINE_THREONINE_KINASE_ACTIVATOR_ACTIVITY
Systematic name | M26755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binds to and increases the activity of a cyclin-dependent protein serine/threonine kinase. [GOC:dph, PMID:2569363, PMID:3322810]
Full description |

Standard name | GO_LYS63_SPECIFIC_DEUBIQUITINASE_ACTIVITY
Systematic name | M26756
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Hydrolysis of Lys63-Linked ubiquitin unit(s) from a ubiquitinated protein. [GOC:dph, GOC:pg, PMID:18313383]
Full description |

Standard name | GO_NUCLEAR_IMPORT_SIGNAL_RECEPTOR_ACTIVITY
Systematic name | M26757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a nuclear import signal (NIS) on a cargo to be transported, to mediate transport of the cargo through the nuclear pore, from the cytoplasm to the nuclear lumen. The cargo can be either a RNA or a protein. [GOC:dph, GOC:pg, GOC:vw, PMID:28713609, Wikipedia:Nuclear_transport]
Full description |

Standard name | GO_RNA_POLYMERASE_II_SPECIFIC_DNA_BINDING_TRANSCRIPTION_FACTOR_BINDING
Systematic name | M26758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a sequence-specific DNA binding RNA polymerase II transcription factor, any of the factors that interact selectively and non-covalently with a specific DNA sequence in order to modulate transcription. [GOC:dph, GOC:vw]
Full description |

Standard name | GO_UBIQUITIN_LIKE_PROTEIN_CONJUGATING_ENZYME_ACTIVITY
Systematic name | M18055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Isoenergetic transfer of a ubiquitin-like protein (ULP) from one protein to another via the reaction X-SCP + Y -> Y-SCP + X, where both the X-SCP and Y-SCP linkages are thioester bonds between the C-terminal amino acid of SCP and a sulfhydryl side group of a cysteine residue. [GOC:dph]
Full description |

Standard name | GO_UBIQUITIN_LIKE_PROTEIN_LIGASE_ACTIVITY
Systematic name | M18729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a ubiquitin-like protein (ULP) to a substrate protein via the reaction X-ULP + S --> X + S-ULP, where X is either an E2 or E3 enzyme, the X-ULP linkage is a thioester bond, and the S-ULP linkage is an isopeptide bond between the C-terminal glycine of ULP and the epsilon-amino group of lysine residues in the substrate. [GOC:dph]
Full description |

Standard name | GO_SUMO_LIGASE_ACTIVITY
Systematic name | M26759
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of SUMO to a substrate protein via the reaction X-SUMO + S --> X + S-SUMO, where X is either an E2 or E3 enzyme, the X-SUMO linkage is a thioester bond, and the S-SUMO linkage is an isopeptide bond between the C-terminal amino acid of SUMO and the epsilon-amino group of lysine residues in the substrate. [GOC:dph]
Full description |

Standard name | GO_IMPORTIN_ALPHA_FAMILY_PROTEIN_BINDING
Systematic name | M26760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any member of the importin-alpha family. [PMID:15350979, PMID:17170104, PMID:23734157]
Full description |

Standard name | GO_PEPTIDE_LYSINE_N_ACETYLTRANSFERASE_ACTIVITY
Systematic name | M34445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: acetyl-CoA + lysine in peptide = CoA + N-acetyl-lysine-peptide. [GOC:dph]
Full description |

Standard name | GO_PEPTIDOGLYCAN_MURALYTIC_ACTIVITY
Systematic name | M26761
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A catalytic activity that contributes to the degradation of peptidoglycan. [GOC:dph, GOC:jh, PMID:22748813]
Full description |

Standard name | GO_REGULATORY_RNA_BINDING
Systematic name | M26762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a small regulatory RNA, a short RNA (usually 50-200 nt long) that is either independently transcribed or processed from a longer RNA by an RNAse enzyme. [PMID:14622403, PMID:23475961]
Full description |

Standard name | GO_RNA_2_O_METHYLTRANSFERASE_ACTIVITY
Systematic name | M26763
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: S-adenosyl-L-methionine + RNA = S-adenosyl-L-homocysteine + RNA containing 2'-O-methylribonucleotide. [PMID:30626973, RHEA:58956]
Full description |

Standard name | GO_ASPARTIC_TYPE_PEPTIDASE_ACTIVITY
Systematic name | M19143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of peptide bonds in a polypeptide chain by a mechanism in which a water molecule bound by the side chains of aspartic residues at the active center acts as a nucleophile. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE]
Full description |

Standard name | GO_THREONINE_TYPE_PEPTIDASE_ACTIVITY
Systematic name | M18419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of peptide bonds in a polypeptide chain by a mechanism in which the hydroxyl group of a threonine residue at the active center acts as a nucleophile. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE]
Full description |

Standard name | GO_CYSTEINE_TYPE_EXOPEPTIDASE_ACTIVITY
Systematic name | M29503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of C- or N-terminal peptide bonds in a polypeptide chain by a mechanism in which the sulfhydryl group of a cysteine residue at the active center acts as a nucleophile. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE, http://merops.sanger.ac.uk/about/glossary.htm#EXOPEPTIDASE]
Full description |

Standard name | GO_METALLOAMINOPEPTIDASE_ACTIVITY
Systematic name | M19051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of N-terminal amino acid residues from a polypeptide chain by a mechanism in which water acts as a nucleophile, one or two metal ions hold the water molecule in place, and charged amino acid side chains are ligands for the metal ions. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#AMINOPEPTIDASE, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE]
Full description |

Standard name | GO_SERINE_TYPE_EXOPEPTIDASE_ACTIVITY
Systematic name | M17886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a peptide bond not more than three residues from the N- or C-terminus of a polypeptide chain by a catalytic mechanism that involves a catalytic triad consisting of a serine nucleophile that is activated by a proton relay involving an acidic residue (e.g. aspartate or glutamate) and a basic residue (usually histidine). [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE, http://merops.sanger.ac.uk/about/glossary.htm#EXOPEPTIDASE, ISBN:0716720094]
Full description |

Standard name | GO_ARMADILLO_REPEAT_DOMAIN_BINDING
Systematic name | M19192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the armadillo repeat domain of a protein, an approximately 40 amino acid long tandemly repeated sequence motif first identified in the Drosophila segment polarity protein armadillo. Arm-repeat proteins are involved in various processes, including intracellular signalling and cytoskeletal regulation. [GOC:BHF, GOC:mah, GOC:vk, InterPro:IPR000225]
Full description |

Standard name | GO_TELOMERASE_RNA_BINDING
Systematic name | M18433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the telomerase RNA template. [GOC:krc, PMID:16884717]
Full description |

Standard name | GO_FIBRINOGEN_BINDING
Systematic name | M29504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with fibrinogen, a highly soluble hexameric glycoprotein complex that is found in blood plasma and is converted to fibrin by thrombin in the coagulation cascade. [GOC:BHF, GOC:mah, GOC:vk]
Full description |

Standard name | GO_FRUCTOSE_BINDING
Systematic name | M26764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the D- or L-enantiomer of fructose, the ketohexose arabino-hex-2-ulose. [CHEBI:28757, GOC:BHF, GOC:mah]
Full description |

Standard name | GO_RNA_POLYMERASE_BINDING
Systematic name | M18416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an RNA polymerase molecule or complex. [GOC:BHF, GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_PROLINE_RICH_REGION_BINDING
Systematic name | M18753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a proline-rich region, i.e. a region that contains a high proportion of proline residues, in a protein. [GOC:mah]
Full description |

Standard name | GO_CHROMO_SHADOW_DOMAIN_BINDING
Systematic name | M26765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a chromo shadow domain, a protein domain that is distantly related, and found in association with, the chromo domain. [GOC:BHF, GOC:vk, InterPro:IPR008251, PMID:7667093]
Full description |

Standard name | GO_FRUCTOSE_6_PHOSPHATE_BINDING
Systematic name | M26766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with fructose 6-phosphate. [GOC:mah]
Full description |

Standard name | GO_DELTA_CATENIN_BINDING
Systematic name | M26767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the delta subunit of the catenin complex. [GOC:rph]
Full description |

Standard name | GO_ISOPEPTIDASE_ACTIVITY
Systematic name | M29505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of an isopeptide bond. An isopeptide bond is an amide linkage between a carboxyl group of one amino acid and an amino group of another amino acid in which at least one of these groups is not on the a-carbon of one of the amino acids (for example, the link between an epsilon-amino group of a lysine molecule to a carboxyl group on a second amino acid is an isopeptide bond). [GOC:mah, Wikipedia:Isopeptidase]
Full description |

Standard name | GO_LARGE_RIBOSOMAL_SUBUNIT_RRNA_BINDING
Systematic name | M26768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the large ribosomal subunit RNA (LSU rRNA), a constituent of the large ribosomal subunit. In S. cerevisiae, this is the 25S rRNA. [GOC:elh]
Full description |

Standard name | GO_SMALL_RIBOSOMAL_SUBUNIT_RRNA_BINDING
Systematic name | M26769
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the small ribosomal subunit RNA (SSU rRNA), a constituent of the small ribosomal subunit. In S. cerevisiae, this is the 18S rRNA. [GOC:elh]
Full description |

Standard name | GO_DNA_POLYMERASE_BINDING
Systematic name | M19154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a DNA polymerase. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_4_PHOSPHATE_BINDING
Systematic name | M19214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylinositol-4-phosphate, a derivative of phosphatidylinositol in which the inositol ring is phosphorylated at the 4' position. [GOC:bf, GOC:mah]
Full description |

Standard name | GO_VITAMIN_B6_BINDING
Systematic name | M26770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any of the vitamin B6 compounds: pyridoxal, pyridoxamine and pyridoxine and the active form, pyridoxal phosphate. [GOC:mah]
Full description |

Standard name | GO_PHOSPHATIDIC_ACID_BINDING
Systematic name | M18861
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidic acid, any of a class of glycerol phosphate in which both the remaining hydroxyl groups of the glycerol moiety are esterified with fatty acids. [CHEBI:16337, GOC:jp, ISBN:0198506732]
Full description |

Standard name | GO_THYROID_HORMONE_BINDING
Systematic name | M26772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with thyroxine (T4) or triiodothyronine (T3), tyrosine-based hormones produced by the thyroid gland. [GOC:rph]
Full description |

Standard name | GO_LIPOPROTEIN_PARTICLE_RECEPTOR_BINDING
Systematic name | M18106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a lipoprotein particle receptor. [GOC:BHF, GOC:rl]
Full description |

Standard name | GO_AROMATASE_ACTIVITY
Systematic name | M26773
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reduction of an aliphatic ring to yield an aromatic ring. [GOC:cb]
Full description |

Standard name | GO_NADPH_BINDING
Systematic name | M18204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the reduced form, NADPH, of nicotinamide-adenine dinucleotide phosphate, a coenzyme involved in many redox and biosynthetic reactions. [GOC:mah]
Full description |

Standard name | GO_NADPLUS_BINDING
Systematic name | M26774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the oxidized form, NAD, of nicotinamide adenine dinucleotide, a coenzyme involved in many redox and biosynthetic reactions. [GOC:mah]
Full description |

Standard name | GO_CO_SMAD_BINDING
Systematic name | M18455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a common mediator SMAD signaling protein. [GOC:BHF, GOC:vk, PMID:19114992]
Full description |

Standard name | GO_I_SMAD_BINDING
Systematic name | M18015
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an inhibitory SMAD signaling protein. [GOC:BHF, GOC:vk, PMID:19114992]
Full description |

Standard name | GO_R_SMAD_BINDING
Systematic name | M18177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a receptor-regulated SMAD signaling protein. [GOC:BHF, GOC:vk, PMID:19114992]
Full description |

Standard name | GO_REPRESSING_TRANSCRIPTION_FACTOR_BINDING
Systematic name | M18952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a transcription repressor, any protein whose activity is required to prevent or downregulate transcription. [GOC:mah, GOC:txnOH]
Full description |

Standard name | GO_OLIGOSACCHARIDE_BINDING
Systematic name | M26775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any oligosaccharide, a molecule with between two and (about) 20 monosaccharide residues connected by glycosidic linkages. [GOC:mah]
Full description |

Standard name | GO_DEATH_DOMAIN_BINDING
Systematic name | M26776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a death domain of a protein. The death domain (DD) is a homotypic protein interaction module composed of a bundle of six alpha-helices. DD bind each other forming oligomers. Some DD-containing proteins are involved in the regulation of apoptosis and inflammation through their activation of caspases and NF-kappaB. [GOC:BHF, GOC:rl, InterPro:IPR000488, Pfam:PF00531]
Full description |

Standard name | GO_K63_LINKED_POLYUBIQUITIN_MODIFICATION_DEPENDENT_PROTEIN_BINDING
Systematic name | M26777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein upon poly-ubiquitination formed by linkages between lysine residues at position 63 in the target protein. [GOC:mah, PMID:15556404, PMID:17525341]
Full description |

Standard name | GO_ADENYLYLTRANSFERASE_ACTIVITY
Systematic name | M18038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an adenylyl group to an acceptor. [GOC:mah]
Full description |

Standard name | GO_CYTIDYLYLTRANSFERASE_ACTIVITY
Systematic name | M26778
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a cytidylyl group to an acceptor. [GOC:mah]
Full description |

Standard name | GO_GUANYLYLTRANSFERASE_ACTIVITY
Systematic name | M26779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of a guanylyl group to an acceptor. [GOC:mah]
Full description |

Standard name | GO_URIDYLYLTRANSFERASE_ACTIVITY
Systematic name | M26780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of an uridylyl group to an acceptor. [GOC:mah]
Full description |

Standard name | GO_METALLODIPEPTIDASE_ACTIVITY
Systematic name | M34446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of a dipeptide by a mechanism in which water acts as a nucleophile, one or two metal ions hold the water molecule in place, and charged amino acid side chains are ligands for the metal ions. [GOC:mah, http://merops.sanger.ac.uk/about/glossary.htm#CATTYPE]
Full description |

Standard name | GO_LYSINE_ACETYLATED_HISTONE_BINDING
Systematic name | M18064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a histone in which a lysine residue has been modified by acetylation. [GOC:BHF, GOC:mah, GOC:rl, PMID:17582821]
Full description |

Standard name | GO_PROTEASOME_BINDING
Systematic name | M18042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a proteasome, a large multisubunit protein complex that catalyzes protein degradation. [GOC:mah]
Full description |

Standard name | GO_INOSITOL_1_4_5_TRISPHOSPHATE_BINDING
Systematic name | M26781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with inositol 1,4,5 trisphosphate. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_TRANSMEMBRANE_RECEPTOR_PROTEIN_SERINE_THREONINE_KINASE_BINDING
Systematic name | M26782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a receptor that spans a cell membrane and possesses protein serine/threonine kinase activity. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_ACTIVIN_RECEPTOR_BINDING
Systematic name | M26783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an activin receptor. [GOC:BHF, GOC:vk]
Full description |

Standard name | GO_BMP_RECEPTOR_BINDING
Systematic name | M26784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a BMP receptor. [GOC:BHF, GOC:vk]
Full description |

Standard name | GO_POLY_PURINE_TRACT_BINDING
Systematic name | M18280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any stretch of purines (adenine or guanine) in an RNA molecule. [GOC:mah]
Full description |

Standard name | GO_LEUCINE_BINDING
Systematic name | M26785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with 2-amino-4-methylpentanoic acid. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_PROTEIN_GLUTAMIC_ACID_LIGASE_ACTIVITY
Systematic name | M26786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the posttranslational transfer of one or more glutamate residues to a specific residue on a target protein. [GOC:mah, PMID:19524510]
Full description |

Standard name | GO_C2H2_ZINC_FINGER_DOMAIN_BINDING
Systematic name | M18057
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a C2H2-type zinc finger domain of a protein. The C2H2 zinc finger is the classical zinc finger domain, in which two conserved cysteines and histidines co-ordinate a zinc ion. [GOC:BHF, GOC:mah, Pfam:PF00096]
Full description |

Standard name | GO_DYNEIN_COMPLEX_BINDING
Systematic name | M26787
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a dynein complex, a protein complex that contains two or three dynein heavy chains and several light chains, and has microtubule motor activity. [GOC:bf, GOC:BHF, GOC:mah]
Full description |

Standard name | GO_GROWTH_FACTOR_RECEPTOR_BINDING
Systematic name | M18816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a growth factor receptor. [GOC:mah, GOC:vw]
Full description |

Standard name | GO_PRIMARY_MIRNA_BINDING
Systematic name | M26788
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a primary microRNA (pri-miRNA) transcript, an RNA molecule that is processed into a short hairpin-shaped structure called a pre-miRNA and finally into a functional miRNA. Both double-stranded and single-stranded regions of a pri-miRNA are required for binding. [GOC:sl, PMID:15531877, PMID:15574589]
Full description |

Standard name | GO_PRE_MIRNA_BINDING
Systematic name | M26789
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a precursor microRNA (pre-miRNA) transcript, a stem-loop-containing precursor of microRNA. [PMID:18951094]
Full description |

Standard name | GO_E_BOX_BINDING
Systematic name | M18303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an E-box, a DNA motif with the consensus sequence CANNTG that is found in the promoters of a wide array of genes expressed in neurons, muscle and other tissues. [GOC:BHF, GOC:vk, PMID:11812799]
Full description |

Standard name | GO_LYSOPHOSPHATIDIC_ACID_RECEPTOR_ACTIVITY
Systematic name | M34447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with the phospholipid derivative lysophosphatidic acid, and transmitting the signal across the membrane by activating an associated G-protein. [GOC:bf, GOC:mah, PMID:15755723]
Full description |

Standard name | GO_SNRNP_BINDING
Systematic name | M26790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any part of a small nuclear ribonucleoprotein particle. [GOC:BHF, GOC:mah, GOC:rl]
Full description |

Standard name | GO_CONNEXIN_BINDING
Systematic name | M26791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a connexin, any of a group of related proteins that assemble to form gap junctions. [GOC:mah, PMID:19864490]
Full description |

Standard name | GO_ANKYRIN_REPEAT_BINDING
Systematic name | M26792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an ankyrin repeat of a protein. Ankyrin repeats are tandemly repeated modules of about 33 amino acids; each repeat folds into a helix-loop-helix structure with a beta-hairpin/loop region projecting out from the helices at a 90-degree angle, and repeats stack to form an L-shaped structure. [GOC:mah, InterPro:IPR002110]
Full description |

Standard name | GO_HISTONE_DEMETHYLASE_ACTIVITY_H3_K27_SPECIFIC
Systematic name | M26793
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of a methyl group from lysine at position 27 of the histone H3 protein. [GOC:sp, PMID:20622853]
Full description |

Standard name | GO_LYSOPHOSPHOLIPID_ACYLTRANSFERASE_ACTIVITY
Systematic name | M18390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the transfer of acyl groups from an acyl-CoA to a lysophospholipid. [GOC:cjk]
Full description |

Standard name | GO_LIPOPEPTIDE_BINDING
Systematic name | M26794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a lipopeptide, any of a group of organic compounds comprising two or more amino acids linked by peptide bonds and containing a nonprotein group consisting of a lipid or lipids. [GOC:add, PMID:12077222, PMID:12524386, PMID:2757794]
Full description |

Standard name | GO_PROTEIN_LIPID_COMPLEX_BINDING
Systematic name | M18026
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein-lipid complex, any macromolecular complex that contains both protein and lipid molecules. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_HMG_BOX_DOMAIN_BINDING
Systematic name | M18516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an HMG box domain, a protein domain that consists of three helices in an irregular array. HMG-box domains are found in one or more copies in HMG-box proteins, which form a large, diverse family involved in the regulation of DNA-dependent processes such as transcription, replication, and strand repair, all of which require the bending and unwinding of chromatin. [GOC:yaf, InterPro:IPR009071, PMID:18445004]
Full description |

Standard name | GO_NEUROPEPTIDE_RECEPTOR_BINDING
Systematic name | M18007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a neuropeptide receptor. [GOC:kmv, GOC:mah]
Full description |

Standard name | GO_14_3_3_PROTEIN_BINDING
Systematic name | M18423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a 14-3-3 protein. A 14-3-3 protein is any of a large family of approximately 30kDa acidic proteins which exist primarily as homo- and heterodimers within all eukaryotic cells, and have been implicated in the modulation of distinct biological processes by binding to specific phosphorylated sites on diverse target proteins, thereby forcing conformational changes or influencing interactions between their targets and other molecules. Each 14-3-3 protein sequence can be roughly divided into three sections: a divergent amino terminus, the conserved core region and a divergent carboxy-terminus. The conserved middle core region of the 14-3-3s encodes an amphipathic groove that forms the main functional domain, a cradle for interacting with client proteins. [GOC:cna, GOC:mah, PMID:15167810, PMID:19575580]
Full description |

Standard name | GO_ARP2_3_COMPLEX_BINDING
Systematic name | M26795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an Arp2/3 complex, a protein complex that contains two actin-related proteins, Arp2 and Arp3, and five novel proteins (ARPC1-5). [GOC:mah]
Full description |

Standard name | GO_CORECEPTOR_ACTIVITY_INVOLVED_IN_WNT_SIGNALING_PATHWAY
Systematic name | M26796
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | In cooperation with a primary Wnt receptor, initiating a change in cell activity through the Wnt signaling pathway. [GOC:BHF, GOC:mah]
Full description |

Standard name | GO_FAD_BINDING
Systematic name | M18188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the oxidized form, FAD, of flavin-adenine dinucleotide, the coenzyme or the prosthetic group of various flavoprotein oxidoreductase enzymes. [GOC:mah]
Full description |

Standard name | GO_WD40_REPEAT_DOMAIN_BINDING
Systematic name | M26797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a WD40 repeat domain of a protein. The WD40 repeat is a short structural motif of approximately 40 amino acids, often terminating in a tryptophan-aspartic acid (W-D) dipeptide. Several of these repeats are combined to form a type of protein domain called the WD domain. [GOC:yaf, InterPro:IPR017986]
Full description |

Standard name | GO_MODIFIED_AMINO_ACID_BINDING
Systematic name | M18552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a modified amino acid. [GOC:mah]
Full description |

Standard name | GO_NAADP_SENSITIVE_CALCIUM_RELEASE_CHANNEL_ACTIVITY
Systematic name | M26798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a calcium ion by a channel that opens when nicotinic acid adenine dinucleotide phosphate (NAADP) has been bound by the channel complex or one of its constituent parts. [PMID:19387438, PMID:19557428]
Full description |

Standard name | GO_MODIFIED_AMINO_ACID_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of modified amino acids from one side of a membrane to the other. [GOC:mah]
Full description |

Standard name | GO_DIVALENT_INORGANIC_CATION_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M17972
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of inorganic cations with a valency of two from one side of a membrane to the other. Inorganic cations are atoms or small molecules with a positive charge that do not contain carbon in covalent linkage. [GOC:mah]
Full description |

Standard name | GO_PROTEIN_PHOSPHATASE_ACTIVATOR_ACTIVITY
Systematic name | M26799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Increases the activity of a protein phosphatase, an enzyme which catalyzes of the removal of a phosphate group from a protein substrate molecule. [GOC:mah]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_5_BISPHOSPHATE_BINDING
Systematic name | M17889
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylinositol-3,5-bisphosphate, a derivative of phosphatidylinositol in which the inositol ring is phosphorylated at the 3' and 5' positions. [GOC:bf, PMID:18397324]
Full description |

Standard name | GO_VOLTAGE_GATED_SODIUM_CHANNEL_ACTIVITY_INVOLVED_IN_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M26800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a sodium ion by a voltage-gated channel through the plasma membrane of a cardiac muscle cell contributing to the depolarization phase of an action potential. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_VOLTAGE_GATED_CALCIUM_CHANNEL_ACTIVITY_INVOLVED_IN_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL
Systematic name | M26801
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a calcium ion by a voltage-gated channel across the plasma membrane of a cardiac muscle cell that contributes to the depolarization phase of an action potential. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_VOLTAGE_GATED_POTASSIUM_CHANNEL_ACTIVITY_INVOLVED_IN_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL_REPOLARIZATION
Systematic name | M26802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a potassium ion by a voltage-gated channel through the plasma membrane of a cardiac muscle cell contributing to the repolarization phase of an action potential. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_PROTEIN_BINDING_INVOLVED_IN_HETEROTYPIC_CELL_CELL_ADHESION
Systematic name | M26803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any protein or protein complex contributing to the adhesion of two different types of cells. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_CELL_ADHESIVE_PROTEIN_BINDING_INVOLVED_IN_BUNDLE_OF_HIS_CELL_PURKINJE_MYOCYTE_COMMUNICATION
Systematic name | M26804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any protein or protein complex that results in the connection of a bundle of His cell with a Purkinje myocyte and contributes to the communication between the two cells. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11]
Full description |

Standard name | GO_CASPASE_BINDING
Systematic name | M26805
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a caspase family protein. [GOC:dos, GOC:ha]
Full description |

Standard name | GO_TRANSLATION_REGULATOR_ACTIVITY_NUCLEIC_ACID_BINDING
Systematic name | M18944
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Any selective and non-covalent interaction with a nucleic acid involved in the initiation, activation, perpetuation, repression or termination of polypeptide synthesis at the ribosome. [GOC:dph, GOC:tb, GOC:vw]
Full description |

Standard name | GO_VITAMIN_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26806
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a vitamin from one side of a membrane to the other. [GOC:tb]
Full description |

Standard name | GO_PHOSPHATIDYLCHOLINE_FLOPPASE_ACTIVITY
Systematic name | M34448
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the movement of phosphatidylcholine from the cytosolic to the exoplasmic leaftlet of a membrane, using energy from the hydrolysis of ATP. [GOC:ab, PMID:16452632, RHEA:38584]
Full description |

Standard name | GO_ALPHA_GLUCOSIDASE_ACTIVITY
Systematic name | M26807
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of terminal, non-reducing alpha-linked alpha-D-glucose residue with release of alpha-D-glucose. [GOC:tb]
Full description |

Standard name | GO_CERAMIDE_BINDING
Systematic name | M26808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any ceramide, a class of lipids that is composed of sphingosine linked to a fatty acid. Ceramides are a major component of cell membranes. [GOC:sart]
Full description |

Standard name | GO_UBIQUITIN_PROTEIN_TRANSFERASE_ACTIVATOR_ACTIVITY
Systematic name | M26809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Increases the activity of a ubiquitin-protein transferase, an enzyme that catalyzes the covalent attachment of ubiquitin to lysine in a substrate protein. [GOC:rb, PMID:18321851]
Full description |

Standard name | GO_SUPERCOILED_DNA_BINDING
Systematic name | M26810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with supercoiled DNA. For example, during replication and transcription, template DNA is negatively supercoiled in the receding downstream DNA and positively supercoiled in the approaching downstream DNA. [GOC:pr, GOC:rph, PMID:20723754, PMID:21345933, Wikipedia:DNA_supercoil]
Full description |

Standard name | GO_NEUROLIGIN_FAMILY_PROTEIN_BINDING
Systematic name | M26811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a member of the neuroligin protein family, neuronal cell surface proteins that mediate synapse formation. [GOC:BHF, GOC:pr, GOC:sjp, PMID:21424692]
Full description |

Standard name | GO_SCAFFOLD_PROTEIN_BINDING
Systematic name | M18486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a scaffold protein. Scaffold proteins are crucial regulators of many key signaling pathways. Although not strictly defined in function, they are known to interact and/or bind with multiple members of a signaling pathway, tethering them into complexes. [GOC:BHF, GOC:sjp, PMID:10433269, Wikipedia:Scaffold_protein]
Full description |

Standard name | GO_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_APOPTOTIC_PROCESS
Systematic name | M19216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of internal, alpha-peptide bonds in a polypeptide chain by a mechanism in which the sulfhydryl group of a cysteine residue at the active center acts as a nucleophile, and contributing to the apoptotic process. [GOC:mtg_apoptosis]
Full description |

Standard name | GO_PRE_MRNA_INTRONIC_BINDING
Systematic name | M26812
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an intronic sequence of a pre-messenger RNA (pre-mRNA). [GOC:ans, PMID:16260624]
Full description |

Standard name | GO_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_APOPTOTIC_SIGNALING_PATHWAY
Systematic name | M26813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of internal, alpha-peptide bonds in a polypeptide chain by a mechanism in which the sulfhydryl group of a cysteine residue at the active center acts as a nucleophile, and contributing to the apoptotic signaling pathway. [GOC:mtg_apoptosis, PMID:11717445, Wikipedia:Caspase]
Full description |

Standard name | GO_CYSTEINE_TYPE_ENDOPEPTIDASE_ACTIVITY_INVOLVED_IN_EXECUTION_PHASE_OF_APOPTOSIS
Systematic name | M34449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the hydrolysis of internal, alpha-peptide bonds in a polypeptide chain by a mechanism in which the sulfhydryl group of a cysteine residue at the active center acts as a nucleophile, and contributing to the execution phase of apoptosis. [GOC:mtg_apoptosis, Wikipedia:Caspase]
Full description |

Standard name | GO_7SK_SNRNA_BINDING
Systematic name | M26814
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a 7SK small nuclear RNA (7SK snRNA). [GOC:nhn, PMID:21853533]
Full description |

Standard name | GO_MDM2_MDM4_FAMILY_PROTEIN_BINDING
Systematic name | M26815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any isoform of the MDM2/MDM4 protein family, comprising negative regulators of p53. [InterPro:IPR016495]
Full description |

Standard name | GO_CYCLIN_DEPENDENT_PROTEIN_KINASE_ACTIVITY
Systematic name | M18704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the phosphorylation of an amino acid residue in a protein, usually according to the reaction: a protein + ATP = a phosphoprotein + ADP. This reaction requires the binding of a regulatory cyclin subunit and full activity requires stimulatory phosphorylation by a CDK-activating kinase (CAK). [GOC:pr]
Full description |

Standard name | GO_STRUCTURAL_MOLECULE_ACTIVITY_CONFERRING_ELASTICITY
Systematic name | M26816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of a complex or assembly within or outside a cell, providing elasticity and recoiling. [GOC:BHF, GOC:rl, PMID:23283722]
Full description |

Standard name | GO_CULLIN_FAMILY_PROTEIN_BINDING
Systematic name | M18898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any member of the cullin family, hydrophobic proteins that act as scaffolds for ubiquitin ligases (E3). [GOC:ha, InterPro:IPR016158, PMID:18698375]
Full description |

Standard name | GO_ANNEALING_ACTIVITY
Systematic name | M18655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A nucleic acid binding activity that brings together complementary sequences of nucleic acids so that they pair by hydrogen bonds to form a double-stranded polynucleotide. [GOC:mba, Wikipedia:Nucleic_acid_thermodynamics#Annealing]
Full description |

Standard name | GO_CALCITONIN_FAMILY_RECEPTOR_ACTIVITY
Systematic name | M26817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with any member of the calcitonin family (e.g. adrenomedullin, adrenomedullin 2 (intermedin), amylin, calcitonin and calcitonin gene-related peptides (CGRPs)) to initiate a change in cell activity. [GOC:bhm, InterPro:IPR003287, PMID:10871296, PMID:12037140, PMID:18687416]
Full description |

Standard name | GO_STAT_FAMILY_PROTEIN_BINDING
Systematic name | M26818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any member of the signal transducers and activators of transcription (STAT) protein family. STATs are, as the name indicates, both signal transducers and transcription factors. STATs are activated by cytokines and some growth factors and thus control important biological processes including cell growth, cell differentiation, apoptosis and immune responses. [GOC:mr, InterPro:IPR001217, PMID:21447371, PMID:24470978]
Full description |

Standard name | GO_DISORDERED_DOMAIN_SPECIFIC_BINDING
Systematic name | M26819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a disordered domain of a protein. [GOC:gg, PMID:11746698]
Full description |

Standard name | GO_RNA_POLYMERASE_ACTIVITY
Systematic name | M19144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: nucleoside triphosphate + RNA(n) = diphosphate + RNA(n+1); the synthesis of RNA from ribonucleotide triphosphates in the presence of a nucleic acid template. [GOC:pf]
Full description |

Standard name | GO_G_RICH_STRAND_TELOMERIC_DNA_BINDING
Systematic name | M26820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with G-rich, single-stranded, telomere-associated DNA. [PMID:11349150]
Full description |

Standard name | GO_LIGAND_ACTIVATED_TRANSCRIPTION_FACTOR_ACTIVITY
Systematic name | M29507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A DNA-binding transcription factor activity that is directly regulated by binding of a ligand to the protein with this activity. Examples include the lac and trp repressors in E.coli and many steroid hormone receptors. [GOC:dos, http://www.ecocyc.org/ECOLI/NEW-IMAGE?object=BC-3.1.2.3]
Full description |

Standard name | GO_CELL_ADHESION_MEDIATOR_ACTIVITY
Systematic name | M26821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding by a cell-adhesion protein on a cell surface to an adhesion molecule on another cell surface, to mediate adhesion of the cell to the external substrate or to another cell. [GOC:vw, Wikipedia:Cell_adhesion]
Full description |

Standard name | GO_CELL_MATRIX_ADHESION_MEDIATOR_ACTIVITY
Systematic name | M26823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding by a cell-adhesion protein on the cell surface to an extracellular matrix component, to mediate adhesion of the cell to the extracellular matrix. [Wikipedia:Cell_adhesion]
Full description |

Standard name | GO_COLLAGEN_BINDING_INVOLVED_IN_CELL_MATRIX_ADHESION
Systematic name | M26824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Any collagen binding that occurs as part of cell-matrix adhesion. [GOC:dos]
Full description |

Standard name | GO_CADHERIN_BINDING_INVOLVED_IN_CELL_CELL_ADHESION
Systematic name | M26825
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Any cadherin binding that occurs as part of the process of cell-cell adhesion. [GOC:dos]
Full description |

Standard name | GO_BMP_RECEPTOR_ACTIVITY
Systematic name | M26827
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a member of the bone morphogenetic protein (BMP) family, and transmitting a signal across the plasma membrane to initiate a change in cell activity. [GOC:BHF, GOC:dos]
Full description |

Standard name | GO_SEQUENCE_SPECIFIC_SINGLE_STRANDED_DNA_BINDING
Systematic name | M26828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with single-stranded DNA of a specific nucleotide composition. [PMID:9531483]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_SYNAPSE
Systematic name | M26829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of a synapse. [GOC:dos]
Full description |

Standard name | GO_POSTSYNAPTIC_NEUROTRANSMITTER_RECEPTOR_ACTIVITY
Systematic name | M26830
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Neurotransmitter receptor activity occuring in the postsynaptic membrane during synaptic transmission. [GOC:dos, GOC:signaling]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_POSTSYNAPTIC_ACTIN_CYTOSKELETON
Systematic name | M29508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of a postsynaptic actin cytoskeleton. [GOC:dos]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_GLUTAMATE_RECEPTOR_ACTIVITY
Systematic name | M29509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with glutamate and transmitting a signal from one side of the membrane to the other by activating an associated G-protein, initiating a change in cell activity. [GOC:dos]
Full description |

Standard name | GO_LIGAND_GATED_CATION_CHANNEL_ACTIVITY
Systematic name | M26831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an inorganic cation by a channel that opens when a specific ligand has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_LIGAND_GATED_ANION_CHANNEL_ACTIVITY
Systematic name | M26832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of an inorganic anion by a channel that opens when a specific ligand has been bound by the channel complex or one of its constituent parts. [GOC:mtg_transport, ISBN:0815340729]
Full description |

Standard name | GO_ION_CHANNEL_REGULATOR_ACTIVITY
Systematic name | M26833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Modulates the activity of a channel via direct interaction with it. A channel catalyzes energy-independent facilitated diffusion, mediated by passage of a solute through a transmembrane aqueous pore or channel. [GOC:dos]
Full description |

Standard name | GO_RNA_POLYMERASE_II_C_TERMINAL_DOMAIN_BINDING
Systematic name | M26834
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the C-terminal domain (CTD) of the largest subunit of RNA polymerase II. The CTD is comprised of repeats of a heptapeptide with the consensus sequence YSPTSPS. The number of repeats varies with the species and a minimum number of repeats is required for RNAP II function. [PMID:20889714]
Full description |

Standard name | GO_STRUCTURAL_CONSTITUENT_OF_POSTSYNAPSE
Systematic name | M29510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The action of a molecule that contributes to the structural integrity of a postsynapse. [GOC:dos]
Full description |

Standard name | GO_VOLTAGE_GATED_CALCIUM_CHANNEL_ACTIVITY_INVOLVED_IN_REGULATION_OF_CYTOSOLIC_CALCIUM_LEVELS
Systematic name | M26836
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Regulation of cytosolic calcium ion concentrations via the directed movement of calcium ions across the plasma-membrane into the cytosol via the action of a voltage-gated calcium ion channel. [GOC:dos]
Full description |

Standard name | GO_G_PROTEIN_COUPLED_NEUROTRANSMITTER_RECEPTOR_ACTIVITY
Systematic name | M17938
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with a neurotransmitter and transmitting the signal across the membrane by activating an associated G-protein; promotes the exchange of GDP for GTP on the alpha subunit of a heterotrimeric G-protein complex. [GOC:bf, GOC:fj, GOC:mah]
Full description |

Standard name | GO_NEUROTRANSMITTER_RECEPTOR_ACTIVITY_INVOLVED_IN_REGULATION_OF_POSTSYNAPTIC_MEMBRANE_POTENTIAL
Systematic name | M29511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Neurotransmitter receptor activity occurring in the postsynaptic membrane that is involved in regulating postsynaptic membrane potential, either directly (ionotropic receptors) or indirectly (e.g. via GPCR activation of an ion channel). [GOC:dos]
Full description |

Standard name | GO_SEROTONIN_RECEPTOR_ACTIVITY
Systematic name | M18162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Combining with the biogenic amine serotonin and transmitting a signal across a membrane by activating some effector activity. Serotonin (5-hydroxytryptamine) is a neurotransmitter and hormone found in vertebrates and invertebrates. [GOC:dos]
Full description |

Standard name | GO_NEUROTRANSMITTER_RECEPTOR_REGULATOR_ACTIVITY
Systematic name | M26837
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A molecular function that directly (via physical interaction or direct modification) activates, inhibits or otherwise modulates the activity of a neurotransmitter receptor. Modulation of activity includes changes in desensitization rate, ligand affinity, ion selectivity and pore-opening/closing. [GOC:dos, PMID:12740117, PMID:18387948]
Full description |

Standard name | GO_LIGAND_GATED_CALCIUM_CHANNEL_ACTIVITY
Systematic name | M18509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a calcium ions by a channel that opens when a specific ligand has been bound by the channel complex or one of its constituent parts. [GOC:dos]
Full description |

Standard name | GO_ESTROGEN_16_ALPHA_HYDROXYLASE_ACTIVITY
Systematic name | M26839
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: estrogen + donor-H2 + O2 = 16-alpha-hydroxyestrogen + H2O. [GOC:BHF]
Full description |

Standard name | GO_ESTROGEN_2_HYDROXYLASE_ACTIVITY
Systematic name | M34450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: estrogen + donor-H2 + O2 = 2-hydroxyestrogen + H2O. [GOC:BHF, GOC:rl, PMID:14559847]
Full description |

Standard name | GO_CERAMIDASE_ACTIVITY
Systematic name | M26840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: H2O + a ceramide = a sphingoid base + a fatty acid. [EC:3.5.1.23, GOC:pz]
Full description |

Standard name | GO_3_OXO_ARACHIDOYL_COA_SYNTHASE_ACTIVITY
Systematic name | M26841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: stearoyl-CoA(4-) + malonyl-CoA(5-) + H+ <=> 3-oxoicosanoyl-CoA. + carbon dioxide + coenzyme A. [EC:2.3.1.199, GOC:pz]
Full description |

Standard name | GO_PHOSPHATIDYL_PHOSPHOLIPASE_B_ACTIVITY
Systematic name | M34451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 2 H2O + a phosphatidylcholine = sn-glycero-3-phosphocholine + 2 H+ + 2 a carboxylate. [EC:3.1.1.5, GOC:pz]
Full description |

Standard name | GO_PHOSPHOLIPASE_A2_ACTIVITY_CONSUMING_1_2_DIPALMITOYLPHOSPHATIDYLCHOLINE
Systematic name | M26842
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1,2-dihexadecanoyl-sn-glycero-3-phosphocholine + H2O = 1-hexadecanoyl-sn-glycero-3-phosphocholine + hexadecanoate + H+. [EC:3.1.1.4, GOC:pz]
Full description |

Standard name | GO_HYPOGLYCIN_A_GAMMA_GLUTAMYL_TRANSPEPTIDASE_ACTIVITY
Systematic name | M26843
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: glutathionate + hypoglycin A = L-cysteinylglycine + hypoglycin B. [EC:2.3.2.2, GOC:pz]
Full description |

Standard name | GO_ALPHA_AMYLASE_ACTIVITY_RELEASING_MALTOHEXAOSE
Systematic name | M26845
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: n H2O + a 1,4-alpha-D-glucan = alpha-maltohexaose + a 1,4-alpha-D-glucan. [EC:3.2.1.1, GOC:pz]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_3_5_BISPHOSPHATE_PHOSPHATASE_ACTIVITY
Systematic name | M26846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-phosphatidyl-myo-inositol 3,5-bisphosphate + H2O = 1-phosphatidyl-1D-myo-inositol phosphate + phosphate. [GOC:hjd]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_4_5_BISPHOSPHATE_PHOSPHATASE_ACTIVITY
Systematic name | M26847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the reaction: 1-phosphatidyl-myo-inositol 4,5-bisphosphate + H2O = 1-phosphatidyl-1D-myo-inositol phosphate + phosphate. [GOC:hjd]
Full description |

Standard name | GO_LIPID_TRANSFER_ACTIVITY
Systematic name | M26848
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Removes a lipid from a membrane or a monolayer lipid particle, transports it through the aqueous phase while protected in a hydrophobic pocket, and brings it to an acceptor membrane or lipid particle. This results in intermembrane transfer of lipids. [GOC:krc, PMID:20823909, PMID:24220498, PMID:25797198]
Full description |

Standard name | GO_PHOSPHOLIPID_TRANSFER_ACTIVITY
Systematic name | M29512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Removes a phospholipid from a membrane or a monolayer lipid particle, transports it through the aqueous phase while protected in a hydrophobic pocket, and brings it to an acceptor membrane or lipid particle. [GOC:krc, PMID:20823909, PMID:24220498, PMID:25797198]
Full description |

Standard name | GO_STEROL_TRANSFER_ACTIVITY
Systematic name | M34452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Removes a sterol from a membrane or a monolayer lipid particle, transports it through the aqueous phase while protected in a hydrophobic pocket, and brings it to an acceptor membrane or lipid particle. [GOC:krc, PMID:20823909, PMID:24220498, PMID:25797198]
Full description |

Standard name | GO_SPHINGOLIPID_TRANSFER_ACTIVITY
Systematic name | M29513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Removes a sphingolipid from a membrane or a monolayer lipid particle, transports it through the aqueous phase while protected in a hydrophobic pocket, and brings it to an acceptor membrane or lipid particle. [GOC:krc, PMID:20823909, PMID:24220498, PMID:25797198]
Full description |

Standard name | GO_SULFATIDE_BINDING
Systematic name | M34453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with sulfatide, also known as 3-O-sulfogalactosylceramide, SM4, or sulfated galactocerebroside. Sulfatide is a class of sulfoglycolipid, which are glycolipids that contain a sulfate group. [GOC:krc, PMID:21525289, PMID:22619219, PMID:22977233, PMID:23574804, PMID:29497057, PMID:3549017, Wikipedia:Sulfatide]
Full description |

Standard name | GO_INTRACILIARY_TRANSPORT_PARTICLE_B_BINDING
Systematic name | M29514
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an intraciliary transport particle B (IFT B) complex. [PMID:20889716]
Full description |

Standard name | GO_ACYL_COA_BINDING
Systematic name | M34454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an acyl-CoA, a thioester that results from the formal condensation of the thiol group of coenzyme A with the carboxy group of any carboxylic acid. [GOC:krc]
Full description |

Standard name | GO_MODIFICATION_DEPENDENT_PROTEIN_BINDING
Systematic name | M26849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein upon post-translation modification of the target protein. [PMID:26060076]
Full description |

Standard name | GO_UBIQUITINATION_LIKE_MODIFICATION_DEPENDENT_PROTEIN_BINDING
Systematic name | M26850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein upon modification by a ubiquitin-like protein of the target protein. [PMID:26060076]
Full description |

Standard name | GO_UBIQUITIN_DEPENDENT_PROTEIN_BINDING
Systematic name | M34455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein upon ubiquitination of the target protein. [PMID:26060076]
Full description |

Standard name | GO_CLASS_I_DNA_APURINIC_OR_APYRIMIDINIC_SITE_ENDONUCLEASE_ACTIVITY
Systematic name | M26851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the cleavage of an AP site 3' of the baseless site by a beta-lyase mechanism, leaving an unsaturated aldehyde, termed a 3'-(4-hydroxy-5-phospho-2-pentenal) residue, and a 5'-phosphate. [PMID:1698278, Wikipedia:AP_endonuclease]
Full description |

Standard name | GO_CATALYTIC_ACTIVITY_ACTING_ON_DNA
Systematic name | M26852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalytic activity that acts to modify DNA. [GOC:molecular_function_refactoring, GOC:pdt]
Full description |

Standard name | GO_CATALYTIC_ACTIVITY_ACTING_ON_RNA
Systematic name | M26853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalytic activity that acts to modify RNA. [GOC:molecular_function_refactoring, GOC:pdt]
Full description |

Standard name | GO_CATALYTIC_ACTIVITY_ACTING_ON_A_TRNA
Systematic name | M26854
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalytic activity that acts to modify a tRNA. [GOC:molecular_function_refactoring, GOC:pdt]
Full description |

Standard name | GO_CATALYTIC_ACTIVITY_ACTING_ON_A_RRNA
Systematic name | M26855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalytic activity that acts to modify a ribosomal RNA. [GOC:molecular_function_refactoring, GOC:pdt]
Full description |

Standard name | GO_CATALYTIC_ACTIVITY_ACTING_ON_A_GLYCOPROTEIN
Systematic name | M26856
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of a biochemical reaction at physiological temperatures in which one of the substrates is a glycoprotein. [GOC:molecular_function_refactoring, GOC:pdt]
Full description |

Standard name | GO_MOLECULAR_CARRIER_ACTIVITY
Systematic name | M26857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Directly binding to a specific ion or molecule and delivering it either to an acceptor molecule or to a specific location. [GOC:molecular_function_refactoring, GOC:pdt]
Full description |

Standard name | GO_TRANSCRIPTION_REGULATOR_ACTIVITY
Systematic name | M29515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | A molecular function that controls the rate, timing and/or magnitude of transcription of genetic information. The function of transcriptional regulators is to modulate gene expression at the transcription step so that they are expressed in the right cell at the right time and in the right amount throughout the life of the cell and the organism. [GOC:pg, GOC:txnOH-2018, Wikipedia:Transcription_factor]
Full description |

Standard name | GO_NUCLEOCYTOPLASMIC_CARRIER_ACTIVITY
Systematic name | M26858
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Carries substances between the nucleus and the cytoplasm of a cell by moving along with the target protein. [GOC:pg]
Full description |

Standard name | GO_GENERAL_TRANSCRIPTION_INITIATION_FACTOR_ACTIVITY
Systematic name | M26860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | An activity that contributes to transcription start site selection and transcription initiation. [GOC:txnOH-2018]
Full description |

Standard name | GO_EXOGENOUS_PROTEIN_BINDING
Systematic name | M26861
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any protein or protein complex from a different species, for example a pathogen molecule binding to a host protein (a complex of two or more proteins that may include other nonprotein molecules). [PMID:28861068]
Full description |

Standard name | GO_GENERAL_TRANSCRIPTION_INITIATION_FACTOR_BINDING
Systematic name | M26862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a general transcription initiation factor, a protein that contributes to transcription start site selection and transcription initiation. [GOC:txnOH-2018]
Full description |

Standard name | GO_DNA_BINDING_TRANSCRIPTION_FACTOR_BINDING
Systematic name | M26863
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a DNA-binding transcription factor, a protein that interacts with a specific DNA sequence (sometimes referred to as a motif) within the regulatory region of a gene to modulate transcription. [GOC:txnOH-2018]
Full description |

Standard name | GO_SMALL_MOLECULE_SENSOR_ACTIVITY
Systematic name | M29516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binding to a small molecule and eliciting a change in the protein's activity in response to the intracellular level of that small molecule. [PMID:26328879]
Full description |

Standard name | GO_INTRAMEMBRANE_LIPID_TRANSPORTER_ACTIVITY
Systematic name | M29517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transport of a lipid from a region of a membrane to a different region on the same membrane. [PMID:16828084]
Full description |

Standard name | GO_CARGO_ADAPTOR_ACTIVITY
Systematic name | M29518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Binding directly to the structural scaffolding elements of a vesicle coat (such as clathrin or COPII), and bridging the membrane, cargo, and membrane deformation machinery. [PMID:25795254]
Full description |

Standard name | GO_SOLUTE_ANION_ANTIPORTER_ACTIVITY
Systematic name | M29519
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: anion(in) + solute(out) = anion(out) + solute(in). [GOC:pg]
Full description |

Standard name | GO_ATPASE_COUPLED_INTRAMEMBRANE_LIPID_TRANSPORTER_ACTIVITY
Systematic name | M29520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the movement of lipids from one membrane leaflet to the other, using energy from the hydrolysis of ATP. This includes flippases and floppases. [PMID:16828084]
Full description |

Standard name | GO_FLIPPASE_ACTIVITY
Systematic name | M29521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the movement of lipids from the exoplasmic to the cytosolic leaftlet of a membrane, using energy from the hydrolysis of ATP. [PMID:20043909, PMID:25284293, Wikipedia:Flippase]
Full description |

Standard name | GO_FLOPPASE_ACTIVITY
Systematic name | M29522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the movement of a lipid from the cytosolic to the exoplasmic leaftlet of a membrane, using energy from the hydrolysis of ATP. [PMID:20043909, PMID:25284293, Wikipedia:Flippase]
Full description |

Standard name | GO_IMMUNE_RECEPTOR_ACTIVITY
Systematic name | M29523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Receiving a signal and transmitting it in a cell to initiate an immune response. [PMID:31415752, Wikipedia:Immune_receptor]
Full description |

Standard name | GO_SOLUTE_BICARBONATE_SYMPORTER_ACTIVITY
Systematic name | M34456
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a solute or solutes from one side of a membrane to the other according to the reaction: solute(out) + HCO3-(out) = solute(in) + HCO3-(in). [PMID:27166256]
Full description |

Standard name | GO_PROTEIN_DEMETHYLASE_ACTIVITY
Systematic name | M34457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the removal of a methyl group from a protein. [PMID:24498420]
Full description |

Standard name | GO_RNA_BINDING_INVOLVED_IN_POSTTRANSCRIPTIONAL_GENE_SILENCING
Systematic name | M29524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Any RNA binding that is involved in posttranscriptional gene silencing. [GOC:aruk, GOC:bc, GOC:rl, PMID:23985560, PMID:28379604]
Full description |

Standard name | GO_OLIGOPEPTIDE_BINDING
Systematic name | M18454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an oligopeptide. [GOC:TermGenie, PMID:21854595]
Full description |

Standard name | GO_CATECHOLAMINE_BINDING
Systematic name | M18206
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with catecholamine. [GOC:TermGenie]
Full description |

Standard name | GO_AZOLE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the directed movement of azoles, heterocyclic compound found in many biologically important substances, from one side of a membrane to the other. [GOC:go_curators, ISBN:3527307206, Wikipedia:Azole]
Full description |

Standard name | GO_CARBOHYDRATE_DERIVATIVE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of carbohydrate derivative from one side of a membrane to the other. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_FATTY_ACID_DERIVATIVE_BINDING
Systematic name | M26866
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with fatty acid derivative. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_PHOSPHATIDYLGLYCEROL_BINDING
Systematic name | M26867
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylglycerol. [GOC:kmv, GOC:TermGenie]
Full description |

Standard name | GO_CARDIOLIPIN_BINDING
Systematic name | M26868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with cardiolipin. [GOC:kmv, GOC:TermGenie]
Full description |

Standard name | GO_ORGANIC_HYDROXY_COMPOUND_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M18137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of organic hydroxy compound from one side of a membrane to the other. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_SULFUR_COMPOUND_BINDING
Systematic name | M17957
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a sulfur compound. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_SULFUR_COMPOUND_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M17921
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a sulfur compound from one side of a membrane to the other. [GOC:pr, GOC:TermGenie]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_PHOSPHATE_BINDING
Systematic name | M18131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylinositol phosphate. [GOC:TermGenie, PMID:23445487]
Full description |

Standard name | GO_VOLTAGE_GATED_POTASSIUM_CHANNEL_ACTIVITY_INVOLVED_IN_VENTRICULAR_CARDIAC_MUSCLE_CELL_ACTION_POTENTIAL_REPOLARIZATION
Systematic name | M26869
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transmembrane transfer of a potassium ion by a voltage-gated channel through the plasma membrane of a ventricular cardiomyocyte contributing to the repolarization phase of an action potential. A voltage-gated channel is a channel whose open state is dependent on the voltage across the membrane in which it is embedded. [GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:8528244]
Full description |

Standard name | GO_CERAMIDE_1_PHOSPHATE_BINDING
Systematic name | M26870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with ceramide 1-phosphate. [GOC:TermGenie, PMID:23863933]
Full description |

Standard name | GO_PHOSPHATIDYLINOSITOL_BISPHOSPHATE_BINDING
Systematic name | M18543
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with phosphatidylinositol bisphosphate. [GO_REF:0000067, GOC:bhm, GOC:TermGenie, PMID:18690034]
Full description |

Standard name | GO_CUPROUS_ION_BINDING
Systematic name | M26871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with cuprous ion, copper(1+). [GO_REF:0000067, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24567322]
Full description |

Standard name | GO_GAP_JUNCTION_CHANNEL_ACTIVITY_INVOLVED_IN_CELL_COMMUNICATION_BY_ELECTRICAL_COUPLING
Systematic name | M29525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Any gap junction channel activity that is involved in cell communication by electrical coupling. [GO_REF:0000061, GOC:BHF, GOC:mtg_cardiac_conduct_nov11, GOC:rl, GOC:TermGenie, PMID:24587307]
Full description |

Standard name | GO_S_ADENOSYL_L_METHIONINE_BINDING
Systematic name | M26873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with S-adenosyl-L-methionine. [GO_REF:0000067, GOC:BHF, GOC:hal, GOC:TermGenie, PMID:22985361]
Full description |

Standard name | GO_PEPTIDE_TRANSMEMBRANE_TRANSPORTER_ACTIVITY
Systematic name | M26874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Enables the transfer of a peptide from one side of a membrane to the other. [GO_REF:0000070, GOC:TermGenie, GOC:vw]
Full description |

Standard name | GO_CORECEPTOR_ACTIVITY_INVOLVED_IN_WNT_SIGNALING_PATHWAY_PLANAR_CELL_POLARITY_PATHWAY
Systematic name | M26875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Any coreceptor activity that is involved in Wnt signaling pathway, planar cell polarity pathway. [GO_REF:0000061, GOC:bf, GOC:PARL, GOC:TermGenie, PMID:24431302]
Full description |

Standard name | GO_RETROMER_COMPLEX_BINDING
Systematic name | M34458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a retromer complex. [GOC:bc, GOC:PARL, GOC:TermGenie, PMID:27385586]
Full description |

Standard name | GO_POLYSOME_BINDING
Systematic name | M26876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a polysome. [GOC:bc, GOC:PARL, GOC:TermGenie, PMID:18426977]
Full description |

Standard name | GO_PHOSPHATIDIC_ACID_TRANSFER_ACTIVITY
Systematic name | M26877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Removes a phosphatidic acid from a membrane or a monolayer lipid particle, transports it through the aqueous phase while protected in a hydrophobic pocket, and brings it to an acceptor membrane or lipid particle. Phosphatidic acid refers to a glycophospholipids with, in general, a saturated fatty acid bonded to carbon-1, an unsaturated fatty acid bonded to carbon-2, and a phosphate group bonded to carbon-3. [PMID:23042293]
Full description |

Standard name | GO_HISTONE_METHYLTRANSFERASE_BINDING
Systematic name | M26878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a histone methyltransferase enzyme. [GOC:ame, GOC:BHF, PMID:19486527]
Full description |

Standard name | GO_STEROID_HORMONE_BINDING
Systematic name | M26879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a steroid hormone. [GOC:ln]
Full description |

Standard name | GO_N6_METHYLADENOSINE_CONTAINING_RNA_BINDING
Systematic name | M26880
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with an RNA molecule modified by N6-methyladenosine (m6A), a modification present at internal sites of mRNAs and some non-coding RNAs. [PMID:22575960, PMID:24284625]
Full description |

Standard name | GO_KERATIN_FILAMENT_BINDING
Systematic name | M26881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a keratin filament, an intermediate filament composed of acidic and basic keratins (types I and II), typically expressed in epithelial cells. [GOC:krc, PMID:6170061]
Full description |

Standard name | GO_LYS48_SPECIFIC_DEUBIQUITINASE_ACTIVITY
Systematic name | M26882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Hydrolysis of Lys48-linked ubiquitin unit(s) from a ubiquitinated protein. [GOC:bf, GOC:PARL, PMID:22970133]
Full description |

Standard name | GO_UBIQUITIN_SPECIFIC_PROTEASE_BINDING
Systematic name | M18801
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a ubiquitin-specific protease. [GOC:bf, GOC:PARL, PMID:24063750]
Full description |

Standard name | GO_PROTEIN_ADP_RIBOSYLASE_ACTIVITY
Systematic name | M26883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The transfer, from NAD, of ADP-ribose to a protein amino acid residue. [PMID:1899243, RESID:AA0040, RESID:AA0168, RESID:AA0169, RESID:AA0231, RESID:AA0237, RESID:AA0295, wikipedia:ADP-ribosylation]
Full description |

Standard name | GO_PROTEIN_ANTIGEN_BINDING
Systematic name | M26884
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein antigen. [PMID:9360996]
Full description |

Standard name | GO_EXTRACELLULAR_MATRIX_PROTEIN_BINDING
Systematic name | M26885
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a protein that is part of an extracellular matrix. [PMID:22355679]
Full description |

Standard name | GO_U1_SNRNP_BINDING
Systematic name | M26886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any part of a U1 small nuclear ribonucleoprotein particle. [PMID:14713954]
Full description |

Standard name | GO_TRANSFERRIN_RECEPTOR_BINDING
Systematic name | M26887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with the transferrin receptor. [GOC:pm, PMID:9819414]
Full description |

Standard name | GO_UBIQUITIN_LIGASE_SUBSTRATE_ADAPTOR_ACTIVITY
Systematic name | M26888
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | The binding activity of a molecule that brings together a ubiquitin ligase and its substrate. Usually mediated by F-box BTB/POZ domain proteins. [PMID:24658274]
Full description |

Standard name | GO_ARRESTIN_FAMILY_PROTEIN_BINDING
Systematic name | M26889
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with any member of the arrestin family, proteins involved in agonist-mediated desensitization of G protein-coupled receptors. [PMID:23911909]
Full description |

Standard name | GO_PROTEIN_TYROSINE_KINASE_BINDING
Systematic name | M18900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with protein tyrosine kinase. [PMID:25499537]
Full description |

Standard name | GO_RNA_ADENYLYLTRANSFERASE_ACTIVITY
Systematic name | M26890
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of the template-independent extension of the 3'- end of an RNA strand by addition of one adenosine molecule at a time. Cannot initiate a chain 'de novo'. The primer, depending on the source of the enzyme, may be an RNA, or oligo(A) bearing a 3'-OH terminal group. [GOC:vw]
Full description |

Standard name | GO_SEQUENCE_SPECIFIC_MRNA_BINDING
Systematic name | M26891
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with messenger RNA (mRNA) of a specific nucleotide composition or a specific sequence motif. [PMID:11886857]
Full description |

Standard name | GO_PROMOTER_SPECIFIC_CHROMATIN_BINDING
Systematic name | M26893
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with a section of chromatin that is associated with gene promoter sequences of DNA. [PMID:19948729]
Full description |

Standard name | GO_ATP_DEPENDENT_MICROTUBULE_MOTOR_ACTIVITY
Systematic name | M18056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Catalysis of movement along a microtubule, coupled to the hydrolysis of ATP. [PMID:19686686]
Full description |

Standard name | GO_UBIQUITIN_LIGASE_INHIBITOR_ACTIVITY
Systematic name | M26894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Stops, prevents or reduces the activity of a ubiquitin ligase. [GOC:dph, GOC:vw, PMID:21389117]
Full description |

Standard name | GO_GLYCOGEN_BINDING
Systematic name | M34459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | GO:MF
Brief description | Interacting selectively and non-covalently with glycogen. [GOC:mengo_curators]
Full description |

Standard name | METHYLCYTOSINE_DIOXYGENASE_TET_UNIPROT_A0A023HHK9_UNREVIEWED_TARGET_GENES
Systematic name | M34460
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:A0A023HHK9 (Methylcytosine_dioxygenase_TET_UniProt_A0A023HHK9_Unreviewed) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | IGLV5_37_TARGET_GENES
Systematic name | M30025
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:A0A075B6J1 (IGLV5_37) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZSCAN5C_TARGET_GENES
Systematic name | M30410
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:A6NGD5 (ZSCAN5C) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SMCHD1_TARGET_GENES
Systematic name | M30164
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:A6NHR9 (SMCHD1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZSCAN5B_TARGET_GENES
Systematic name | M30409
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:A6NJL1 (ZSCAN5B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PDCD6_AHRR_TARGET_GENES
Systematic name | M34461
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:A9YTQ3 (PDCD6_AHRR) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | OVOL3_TARGET_GENES
Systematic name | M30105
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O00110 (OVOL3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | FOXE1_TARGET_GENES
Systematic name | M29968
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O00358 (FOXE1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | FOXN3_TARGET_GENES
Systematic name | M29973
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O00409 (FOXN3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | KMT2D_TARGET_GENES
Systematic name | M30042
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O14686 (KMT2D) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF197_TARGET_GENES
Systematic name | M30272
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O14709 (ZNF197) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PRMT5_TARGET_GENES
Systematic name | M30130
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O14744 (PRMT5) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TERT_TARGET_GENES
Systematic name | M30202
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O14746 (TERT) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF213_TARGET_GENES
Systematic name | M30277
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O14771 (ZNF213) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | XPO1_TARGET_GENES
Systematic name | M34462
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O14980 (XPO1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NKX2_8_TARGET_GENES
Systematic name | M30092
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O15522 (NKX2_8) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MAFG_TARGET_GENES
Systematic name | M30053
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O15525 (MAFG) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PER1_TARGET_GENES
Systematic name | M30117
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O15534 (PER1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SOX15_TARGET_GENES
Systematic name | M30175
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O60248 (SOX15) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF292_TARGET_GENES
Systematic name | M30293
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O60281 (ZNF292) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SYNCRIP_TARGET_GENES
Systematic name | M30189
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O60506 (SYNCRIP) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CREBL2_TARGET_GENES
Systematic name | M29931
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O60519 (CREBL2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | FOXD2_TARGET_GENES
Systematic name | M29966
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O60548 (FOXD2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | LMX1B_TARGET_GENES
Systematic name | M30052
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O60663 (LMX1B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF354A_TARGET_GENES
Systematic name | M30305
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O60765 (ZNF354A) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NR1I2_TARGET_GENES
Systematic name | M30100
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O75469 (NR1I2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | GCM2_TARGET_GENES
Systematic name | M34463
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O75603 (GCM2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | WDHD1_TARGET_GENES
Systematic name | M30227
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O75717 (WDHD1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | KLF7_TARGET_GENES
Systematic name | M30041
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O75840 (KLF7) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NKX2_2_TARGET_GENES
Systematic name | M30089
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O95096 (NKX2_2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF202_TARGET_GENES
Systematic name | M30274
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O95125 (ZNF202) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PGM3_TARGET_GENES
Systematic name | M34464
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O95394 (PGM3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SVIL_TARGET_GENES
Systematic name | M30188
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O95425 (SVIL) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | WIZ_TARGET_GENES
Systematic name | M30228
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O95785 (WIZ) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SNAI1_TARGET_GENES
Systematic name | M30167
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O95863 (SNAI1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CBX7_TARGET_GENES
Systematic name | M29912
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O95931 (CBX7) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PTTG1_TARGET_GENES
Systematic name | M30133
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O95997 (PTTG1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HAND1_TARGET_GENES
Systematic name | M29988
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:O96004 (HAND1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | F10_TARGET_GENES
Systematic name | M29962
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P00742 (F10) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NPM1_TARGET_GENES
Systematic name | M34465
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P06748 (NPM1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | GLI1_TARGET_GENES
Systematic name | M29978
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P08151 (GLI1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SNRNP70_TARGET_GENES
Systematic name | M30171
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P08621 (SNRNP70) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HOXB7_TARGET_GENES
Systematic name | M30012
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P09629 (HOXB7) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HOXC6_TARGET_GENES
Systematic name | M30016
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P09630 (HOXC6) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | GLI3_TARGET_GENES
Systematic name | M29979
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P10071 (GLI3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | GLI4_TARGET_GENES
Systematic name | M29980
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P10075 (GLI4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | RARB_TARGET_GENES
Systematic name | M30135
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P10826 (RARB) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | THRA_TARGET_GENES
Systematic name | M30209
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P10827 (THRA) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SKIL_TARGET_GENES
Systematic name | M30161
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P12757 (SKIL) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF708_TARGET_GENES
Systematic name | M30382
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17019 (ZNF708) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF16_TARGET_GENES
Systematic name | M30266
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17020 (ZNF16) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF19_TARGET_GENES
Systematic name | M30271
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17023 (ZNF19) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF20_TARGET_GENES
Systematic name | M34466
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17024 (ZNF20) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF22_TARGET_GENES
Systematic name | M30279
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17026 (ZNF22) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF23_TARGET_GENES
Systematic name | M30283
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17027 (ZNF23) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF26_TARGET_GENES
Systematic name | M30289
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17031 (ZNF26) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF37A_TARGET_GENES
Systematic name | M30309
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17032 (ZNF37A) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF30_TARGET_GENES
Systematic name | M30294
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17039 (ZNF30) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HMGA1_TARGET_GENES
Systematic name | M30002
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17096 (HMGA1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF7_TARGET_GENES
Systematic name | M30379
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17097 (ZNF7) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF8_TARGET_GENES
Systematic name | M30394
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17098 (ZNF8) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HOXB4_TARGET_GENES
Systematic name | M30010
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17483 (HOXB4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HOXB6_TARGET_GENES
Systematic name | M30011
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P17509 (HOXB6) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PTPRA_TARGET_GENES
Systematic name | M30132
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P18433 (PTPRA) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ADCYAP1_TARGET_GENES
Systematic name | M29881
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P18509 (ADCYAP1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ATF6_TARGET_GENES
Systematic name | M29894
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P18850 (ATF6) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TFEB_TARGET_GENES
Systematic name | M30207
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P19484 (TFEB) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NR1D1_TARGET_GENES
Systematic name | M30098
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P20393 (NR1D1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF10_TARGET_GENES
Systematic name | M30256
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P21506 (ZNF10) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NME2_TARGET_GENES
Systematic name | M30094
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P22392 (NME2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | H1_6_TARGET_GENES
Systematic name | M29987
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P22492 (H1_6) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MYF6_TARGET_GENES
Systematic name | M30076
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P23409 (MYF6) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PAX7_TARGET_GENES
Systematic name | M30110
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P23759 (PAX7) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PAX3_TARGET_GENES
Systematic name | M30108
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P23760 (PAX3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NFKBIA_TARGET_GENES
Systematic name | M30087
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P25963 (NFKBIA) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PSMB5_TARGET_GENES
Systematic name | M30131
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P28074 (PSMB5) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MSX1_TARGET_GENES
Systematic name | M30070
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P28360 (MSX1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SMARCA1_TARGET_GENES
Systematic name | M30163
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P28370 (SMARCA1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | GTF2E2_TARGET_GENES
Systematic name | M29984
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P29084 (GTF2E2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HOXA10_TARGET_GENES
Systematic name | M30007
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P31260 (HOXA10) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HOXA7_TARGET_GENES
Systematic name | M30009
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P31268 (HOXA7) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HOXA13_TARGET_GENES
Systematic name | M30008
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P31271 (HOXA13) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HOXC13_TARGET_GENES
Systematic name | M30015
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P31276 (HOXC13) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HOXD11_TARGET_GENES
Systematic name | M30018
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P31277 (HOXD11) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CIITA_TARGET_GENES
Systematic name | M29925
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P33076 (CIITA) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MCM5_TARGET_GENES
Systematic name | M30059
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P33992 (MCM5) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | RORA_TARGET_GENES
Systematic name | M30144
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P35398 (RORA) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NUP214_TARGET_GENES
Systematic name | M34467
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P35658 (NUP214) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SOX11_TARGET_GENES
Systematic name | M30174
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P35716 (SOX11) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ID1_TARGET_GENES
Systematic name | M30022
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P41134 (ID1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SOX3_TARGET_GENES
Systematic name | M30176
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P41225 (SOX3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CASP3_TARGET_GENES
Systematic name | M34468
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P42574 (CASP3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | RBM34_TARGET_GENES
Systematic name | M30140
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P42696 (RBM34) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NR4A2_TARGET_GENES
Systematic name | M30102
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P43354 (NR4A2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CBX5_TARGET_GENES
Systematic name | M29911
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P45973 (CBX5) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CDX1_TARGET_GENES
Systematic name | M29917
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P47902 (CDX1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF165_TARGET_GENES
Systematic name | M30267
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P49910 (ZNF165) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TERF1_TARGET_GENES
Systematic name | M30200
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P54274 (TERF1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | F2RL1_TARGET_GENES
Systematic name | M29963
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P55085 (F2RL1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CDH4_TARGET_GENES
Systematic name | M34469
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P55283 (CDH4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | FOXG1_TARGET_GENES
Systematic name | M29971
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P55316 (FOXG1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | DLX6_TARGET_GENES
Systematic name | M29943
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P56179 (DLX6) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HDAC4_TARGET_GENES
Systematic name | M29991
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P56524 (HDAC4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SOX10_TARGET_GENES
Systematic name | M30173
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P56693 (SOX10) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF445_TARGET_GENES
Systematic name | M30324
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P59923 (ZNF445) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | YBX1_TARGET_GENES
Systematic name | M30231
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P67809 (YBX1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PITX1_TARGET_GENES
Systematic name | M30122
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P78337 (PITX1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SRPK2_TARGET_GENES
Systematic name | M30180
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P78362 (SRPK2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | IRX3_TARGET_GENES
Systematic name | M30031
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P78415 (IRX3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NKX6_1_TARGET_GENES
Systematic name | M30093
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P78426 (NKX6_1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PRKDC_TARGET_GENES
Systematic name | M30129
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:P78527 (PRKDC) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TFAM_TARGET_GENES
Systematic name | M30204
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q00059 (TFAM) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | GUCY1B1_TARGET_GENES
Systematic name | M29986
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q02153 (GUCY1B1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ID2_TARGET_GENES
Systematic name | M30023
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q02363 (ID2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MAP2K1_TARGET_GENES
Systematic name | M30055
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q02750 (MAP2K1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TOP2B_TARGET_GENES
Systematic name | M30211
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q02880 (TOP2B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HHEX_TARGET_GENES
Systematic name | M29997
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q03014 (HHEX) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | LMNB2_TARGET_GENES
Systematic name | M30050
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q03252 (LMNB2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CEBPZ_TARGET_GENES
Systematic name | M29919
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q03701 (CEBPZ) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF85_TARGET_GENES
Systematic name | M30399
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q03923 (ZNF85) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HSF2_TARGET_GENES
Systematic name | M30020
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q03933 (HSF2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF92_TARGET_GENES
Systematic name | M30400
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q03936 (ZNF92) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | EMX1_TARGET_GENES
Systematic name | M29957
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q04741 (EMX1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PAX8_TARGET_GENES
Systematic name | M30111
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q06710 (PAX8) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF33A_TARGET_GENES
Systematic name | M30302
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q06730 (ZNF33A) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | DLX2_TARGET_GENES
Systematic name | M29941
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q07687 (DLX2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PPARA_TARGET_GENES
Systematic name | M30123
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q07869 (PPARA) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CHAF1A_TARGET_GENES
Systematic name | M29921
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13111 (CHAF1A) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CHAF1B_TARGET_GENES
Systematic name | M29922
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13112 (CHAF1B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | RLF_TARGET_GENES
Systematic name | M30143
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13129 (RLF) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ERCC8_TARGET_GENES
Systematic name | M29959
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13216 (ERCC8) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SRSF9_TARGET_GENES
Systematic name | M30183
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13242 (SRSF9) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NR5A1_TARGET_GENES
Systematic name | M30103
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13285 (NR5A1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SKP2_TARGET_GENES
Systematic name | M30162
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13309 (SKP2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ATM_TARGET_GENES
Systematic name | M29895
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13315 (ATM) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF211_TARGET_GENES
Systematic name | M30276
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13398 (ZNF211) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ILK_TARGET_GENES
Systematic name | M30026
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13418 (ILK) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TCOF1_TARGET_GENES
Systematic name | M30197
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13428 (TCOF1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SNAPC2_TARGET_GENES
Systematic name | M30168
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13487 (SNAPC2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SQSTM1_TARGET_GENES
Systematic name | M30178
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13501 (SQSTM1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | IRF5_TARGET_GENES
Systematic name | M30028
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13568 (IRF5) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | DYRK1A_TARGET_GENES
Systematic name | M29950
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q13627 (DYRK1A) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SAFB2_TARGET_GENES
Systematic name | M34470
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14151 (SAFB2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TFDP2_TARGET_GENES
Systematic name | M30206
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14188 (TFDP2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | WRN_TARGET_GENES
Systematic name | M30229
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14191 (WRN) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NPAT_TARGET_GENES
Systematic name | M30096
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14207 (NPAT) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | E2F2_TARGET_GENES
Systematic name | M29951
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14209 (E2F2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CSHL1_TARGET_GENES
Systematic name | M29932
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14406 (CSHL1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NFE2L1_TARGET_GENES
Systematic name | M30085
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14494 (NFE2L1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NCOA6_TARGET_GENES
Systematic name | M30082
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14686 (NCOA6) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MEF2D_TARGET_GENES
Systematic name | M30063
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14814 (MEF2D) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ARID5B_TARGET_GENES
Systematic name | M29889
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14865 (ARID5B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF169_TARGET_GENES
Systematic name | M30268
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q14929 (ZNF169) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF146_TARGET_GENES
Systematic name | M30264
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15072 (ZNF146) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZMYND11_TARGET_GENES
Systematic name | M30254
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15326 (ZMYND11) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | E2F5_TARGET_GENES
Systematic name | M29952
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15329 (E2F5) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SIX1_TARGET_GENES
Systematic name | M30159
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15475 (SIX1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TERF2_TARGET_GENES
Systematic name | M30201
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15554 (TERF2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TEAD2_TARGET_GENES
Systematic name | M30199
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15562 (TEAD2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NCOA2_TARGET_GENES
Systematic name | M30080
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15596 (NCOA2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TRIP13_TARGET_GENES
Systematic name | M30213
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15645 (TRIP13) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ELF2_TARGET_GENES
Systematic name | M29955
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15723 (ELF2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NAB2_TARGET_GENES
Systematic name | M30079
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15742 (NAB2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CEBPE_TARGET_GENES
Systematic name | M29918
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15744 (CEBPE) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NEUROD2_TARGET_GENES
Systematic name | M30083
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15784 (NEUROD2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZFHX3_TARGET_GENES
Systematic name | M30244
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q15911 (ZFHX3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF239_TARGET_GENES
Systematic name | M30285
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q16600 (ZNF239) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | POU2AF1_TARGET_GENES
Systematic name | M34471
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q16633 (POU2AF1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TAZ_TARGET_GENES
Systematic name | M30192
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q16635 (TAZ) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SMN1_SMN2_TARGET_GENES
Systematic name | M34472
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q16637 (SMN1_SMN2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZSCAN26_TARGET_GENES
Systematic name | M30405
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q16670 (ZSCAN26) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | RFX7_TARGET_GENES
Systematic name | M30142
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q2KHR2 (RFX7) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF423_TARGET_GENES
Systematic name | M30320
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q2M1K9 (ZNF423) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF791_TARGET_GENES
Systematic name | M30393
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q3KP31 (ZNF791) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF528_TARGET_GENES
Systematic name | M30340
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q3MIS6 (ZNF528) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZSCAN23_TARGET_GENES
Systematic name | M30404
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q3MJ62 (ZSCAN23) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF404_TARGET_GENES
Systematic name | M30313
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q494X3 (ZNF404) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | GREB1_TARGET_GENES
Systematic name | M29981
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q4ZG55 (GREB1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF585B_TARGET_GENES
Systematic name | M30358
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q52M93 (ZNF585B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | COBLL1_TARGET_GENES
Systematic name | M29926
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q53SF7 (COBLL1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF766_TARGET_GENES
Systematic name | M30385
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q5HY98 (ZNF766) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF667_TARGET_GENES
Systematic name | M30373
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q5HYK9 (ZNF667) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SNAPC4_TARGET_GENES
Systematic name | M30169
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q5SXM2 (SNAPC4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF362_TARGET_GENES
Systematic name | M30308
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q5T0B9 (ZNF362) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF618_TARGET_GENES
Systematic name | M30366
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q5T7W0 (ZNF618) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF776_TARGET_GENES
Systematic name | M30388
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q68DI1 (ZNF776) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF626_TARGET_GENES
Systematic name | M30369
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q68DY1 (ZNF626) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF660_TARGET_GENES
Systematic name | M30371
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q6AZW8 (ZNF660) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF746_TARGET_GENES
Systematic name | M34473
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q6NUN9 (ZNF746) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CAVIN1_TARGET_GENES
Systematic name | M29910
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q6NZI2 (CAVIN1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CTR9_TARGET_GENES
Systematic name | M29934
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q6PD62 (CTR9) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | FOXR2_TARGET_GENES
Systematic name | M29976
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q6PJQ5 (FOXR2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF322_TARGET_GENES
Systematic name | M30299
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q6U7Q0 (ZNF322) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZSCAN2_TARGET_GENES
Systematic name | M30402
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q7Z7L9 (ZSCAN2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PBRM1_TARGET_GENES
Systematic name | M30112
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q86U86 (PBRM1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF329_TARGET_GENES
Systematic name | M30300
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q86UD4 (ZNF329) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF589_TARGET_GENES
Systematic name | M30360
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q86UQ0 (ZNF589) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF410_TARGET_GENES
Systematic name | M30316
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q86VK4 (ZNF410) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZSCAN30_TARGET_GENES
Systematic name | M30406
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q86W11 (ZSCAN30) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CARM1_TARGET_GENES
Systematic name | M29909
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q86X55 (CARM1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MIER1_TARGET_GENES
Systematic name | M30065
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N108 (MIER1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZFP82_TARGET_GENES
Systematic name | M30250
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N141 (ZFP82) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | BCL6B_TARGET_GENES
Systematic name | M29904
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N143 (BCL6B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PIAS4_TARGET_GENES
Systematic name | M30121
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N2W9 (PIAS4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF664_TARGET_GENES
Systematic name | M30372
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N3J9 (ZNF664) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | LCORL_TARGET_GENES
Systematic name | M30045
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N3X6 (LCORL) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PGBD5_TARGET_GENES
Systematic name | M30118
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N414 (PGBD5) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF843_TARGET_GENES
Systematic name | M30398
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N446 (ZNF843) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | RYBP_TARGET_GENES
Systematic name | M30149
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N488 (RYBP) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF561_TARGET_GENES
Systematic name | M30351
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N587 (ZNF561) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PAF1_TARGET_GENES
Systematic name | M30106
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N7H5 (PAF1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF433_TARGET_GENES
Systematic name | M30322
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N7K0 (ZNF433) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF781_TARGET_GENES
Systematic name | M30390
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N8C0 (ZNF781) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF513_TARGET_GENES
Systematic name | M30337
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N8E2 (ZNF513) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF491_TARGET_GENES
Systematic name | M30329
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N8L2 (ZNF491) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF454_TARGET_GENES
Systematic name | M30325
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N9F8 (ZNF454) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | BANP_TARGET_GENES
Systematic name | M29900
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N9N5 (BANP) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF610_TARGET_GENES
Systematic name | M30365
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8N9Z0 (ZNF610) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZFP28_TARGET_GENES
Systematic name | M30245
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8NHY6 (ZFP28) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF563_TARGET_GENES
Systematic name | M30352
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TA94 (ZNF563) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SNIP1_TARGET_GENES
Systematic name | M30170
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TAD8 (SNIP1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NKX2_3_TARGET_GENES
Systematic name | M30090
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TAU0 (NKX2_3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZSCAN18_TARGET_GENES
Systematic name | M30401
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TBC5 (ZSCAN18) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | BAHD1_TARGET_GENES
Systematic name | M29899
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TBE0 (BAHD1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF502_TARGET_GENES
Systematic name | M30332
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TBZ5 (ZNF502) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF596_TARGET_GENES
Systematic name | M30363
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TC21 (ZNF596) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF507_TARGET_GENES
Systematic name | M30333
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TCN5 (ZNF507) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | KLF14_TARGET_GENES
Systematic name | M30038
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TD94 (KLF14) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CREB3L4_TARGET_GENES
Systematic name | M29930
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TEY5 (CREB3L4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF418_TARGET_GENES
Systematic name | M30318
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8TF45 (ZNF418) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SETD7_TARGET_GENES
Systematic name | M30154
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q8WTS6 (SETD7) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HSD17B8_TARGET_GENES
Systematic name | M30019
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q92506 (HSD17B8) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MAML1_TARGET_GENES
Systematic name | M30054
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q92585 (MAML1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF592_TARGET_GENES
Systematic name | M30361
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q92610 (ZNF592) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | GTF3A_TARGET_GENES
Systematic name | M29985
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q92664 (GTF3A) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | KAT2A_TARGET_GENES
Systematic name | M30033
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q92830 (KAT2A) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | DLX4_TARGET_GENES
Systematic name | M29942
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q92988 (DLX4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | KAT5_TARGET_GENES
Systematic name | M30034
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q92993 (KAT5) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | BRF1_TARGET_GENES
Systematic name | M29907
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q92994 (BRF1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PBXIP1_TARGET_GENES
Systematic name | M30113
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96AQ6 (PBXIP1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PHF21A_TARGET_GENES
Systematic name | M30120
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96BD5 (PHF21A) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF669_TARGET_GENES
Systematic name | M30374
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96BR6 (ZNF669) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CENPT_TARGET_GENES
Systematic name | M29920
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96BT3 (CENPT) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF707_TARGET_GENES
Systematic name | M30381
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96C28 (ZNF707) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF524_TARGET_GENES
Systematic name | M30339
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96C55 (ZNF524) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF501_TARGET_GENES
Systematic name | M30331
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96CX3 (ZNF501) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF837_TARGET_GENES
Systematic name | M30397
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96EG3 (ZNF837) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MCRS1_TARGET_GENES
Systematic name | M30060
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96EZ8 (MCRS1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SIPA1_TARGET_GENES
Systematic name | M30157
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96FS4 (SIPA1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HMCES_TARGET_GENES
Systematic name | M30000
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96FZ2 (HMCES) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF274_TARGET_GENES
Systematic name | M30291
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96GC6 (ZNF274) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF486_TARGET_GENES
Systematic name | M30326
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96H40 (ZNF486) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF419_TARGET_GENES
Systematic name | M30319
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96HQ0 (ZNF419) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | RBM17_TARGET_GENES
Systematic name | M30139
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96I25 (RBM17) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | RAX2_TARGET_GENES
Systematic name | M30136
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96IS3 (RAX2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CHAMP1_TARGET_GENES
Systematic name | M29923
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96JM3 (CHAMP1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZFP91_TARGET_GENES
Systematic name | M30251
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96JP5 (ZFP91) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF514_TARGET_GENES
Systematic name | M30338
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96K75 (ZNF514) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF512B_TARGET_GENES
Systematic name | M30336
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96KM6 (ZNF512B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF354B_TARGET_GENES
Systematic name | M30306
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96LW1 (ZNF354B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZSCAN31_TARGET_GENES
Systematic name | M30407
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96LW9 (ZSCAN31) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF597_TARGET_GENES
Systematic name | M30364
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96LX8 (ZNF597) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF512_TARGET_GENES
Systematic name | M30335
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96ME7 (ZNF512) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF488_TARGET_GENES
Systematic name | M30327
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96MN9 (ZNF488) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF560_TARGET_GENES
Systematic name | M30350
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96MR9 (ZNF560) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF830_TARGET_GENES
Systematic name | M30396
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96NB3 (ZNF830) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF558_TARGET_GENES
Systematic name | M30349
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96NG5 (ZNF558) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF582_TARGET_GENES
Systematic name | M30356
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96NG8 (ZNF582) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZFP3_TARGET_GENES
Systematic name | M30246
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96NJ6 (ZFP3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZIM3_TARGET_GENES
Systematic name | M30252
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96PE6 (ZIM3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | LMTK3_TARGET_GENES
Systematic name | M30051
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96Q04 (LMTK3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ALKBH3_TARGET_GENES
Systematic name | M29885
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q96Q83 (ALKBH3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CDC5L_TARGET_GENES
Systematic name | M29915
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q99459 (CDC5L) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MPHOSPH8_TARGET_GENES
Systematic name | M30069
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q99549 (MPHOSPH8) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | FEV_TARGET_GENES
Systematic name | M29964
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q99581 (FEV) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZBTB18_TARGET_GENES
Systematic name | M30238
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q99592 (ZBTB18) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PHB2_TARGET_GENES
Systematic name | M30119
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q99623 (PHB2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF184_TARGET_GENES
Systematic name | M30270
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q99676 (ZNF184) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SIGMAR1_TARGET_GENES
Systematic name | M30156
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q99720 (SIGMAR1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | EBNA1BP2_TARGET_GENES
Systematic name | M29953
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q99848 (EBNA1BP2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF2_TARGET_GENES
Systematic name | M30273
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9BSG1 (ZNF2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF577_TARGET_GENES
Systematic name | M30353
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9BSK1 (ZNF577) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PCGF1_TARGET_GENES
Systematic name | M30115
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9BSM1 (PCGF1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | DIDO1_TARGET_GENES
Systematic name | M29940
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9BTC0 (DIDO1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | FOXQ1_TARGET_GENES
Systematic name | M29975
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9C009 (FOXQ1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF436_TARGET_GENES
Systematic name | M30323
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9C0F3 (ZNF436) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF407_TARGET_GENES
Systematic name | M30314
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9C0G0 (ZNF407) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF350_TARGET_GENES
Systematic name | M30304
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9GZX5 (ZNF350) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HOXD1_TARGET_GENES
Systematic name | M30017
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9GZZ0 (HOXD1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ALX4_TARGET_GENES
Systematic name | M29886
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9H161 (ALX4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PRDM12_TARGET_GENES
Systematic name | M30125
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9H4Q4 (PRDM12) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF768_TARGET_GENES
Systematic name | M30386
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9H5H4 (ZNF768) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | STN1_TARGET_GENES
Systematic name | M30184
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9H668 (STN1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TDRD3_TARGET_GENES
Systematic name | M30198
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9H7E2 (TDRD3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | VRTN_TARGET_GENES
Systematic name | M34474
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9H8Y1 (VRTN) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | BRF2_TARGET_GENES
Systematic name | M29908
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9HAW0 (BRF2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TAF9B_TARGET_GENES
Systematic name | M30190
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9HBM6 (TAF9B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | BARX1_TARGET_GENES
Systematic name | M29902
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9HBU1 (BARX1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ARNT2_TARGET_GENES
Systematic name | M29890
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9HBZ2 (ARNT2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HES4_TARGET_GENES
Systematic name | M29995
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9HCC6 (HES4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF532_TARGET_GENES
Systematic name | M30343
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9HCE3 (ZNF532) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | METTL14_TARGET_GENES
Systematic name | M30064
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9HCE5 (METTL14) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | UBN1_TARGET_GENES
Systematic name | M30219
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9NPG3 (UBN1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | LHX9_TARGET_GENES
Systematic name | M30049
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9NQ69 (LHX9) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PRDM5_TARGET_GENES
Systematic name | M30127
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9NQX1 (PRDM5) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF331_TARGET_GENES
Systematic name | M30301
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9NQX6 (ZNF331) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF302_TARGET_GENES
Systematic name | M30296
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9NR11 (ZNF302) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ASH1L_TARGET_GENES
Systematic name | M29891
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9NR48 (ASH1L) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | DROSHA_TARGET_GENES
Systematic name | M29949
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9NRR4 (DROSHA) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ARHGAP35_TARGET_GENES
Systematic name | M29887
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9NRY4 (ARHGAP35) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SIRT3_TARGET_GENES
Systematic name | M30158
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9NTG7 (SIRT3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | THAP1_TARGET_GENES
Systematic name | M30208
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9NVV9 (THAP1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | FOXJ2_TARGET_GENES
Systematic name | M29972
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9P0K8 (FOXJ2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF581_TARGET_GENES
Systematic name | M30355
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9P0T4 (ZNF581) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HMG20B_TARGET_GENES
Systematic name | M30001
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9P0W2 (HMG20B) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | PPARGC1A_TARGET_GENES
Systematic name | M30124
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UBK2 (PPARGC1A) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HEY2_TARGET_GENES
Systematic name | M29996
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UBP5 (HEY2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | LHX3_TARGET_GENES
Systematic name | M30047
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UBR4 (LHX3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZMYM2_TARGET_GENES
Systematic name | M30253
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UBW7 (ZMYM2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF282_TARGET_GENES
Systematic name | M30292
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UDV7 (ZNF282) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SFMBT1_TARGET_GENES
Systematic name | M30155
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UHJ3 (SFMBT1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NUFIP1_TARGET_GENES
Systematic name | M30104
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UHK0 (NUFIP1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | DACH1_TARGET_GENES
Systematic name | M29936
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UI36 (DACH1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SIX4_TARGET_GENES
Systematic name | M30160
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UIU6 (SIX4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF391_TARGET_GENES
Systematic name | M30310
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UJN7 (ZNF391) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SALL4_TARGET_GENES
Systematic name | M30150
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UJQ4 (SALL4) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF112_TARGET_GENES
Systematic name | M30258
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UJU3 (ZNF112) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | FOXD3_TARGET_GENES
Systematic name | M29967
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UJU5 (FOXD3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF223_TARGET_GENES
Systematic name | M30281
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UK11 (ZNF223) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | TASOR_TARGET_GENES
Systematic name | M30191
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UK61 (TASOR) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | CASP8AP2_TARGET_GENES
Systematic name | M30225
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9UKL3 (CASP8AP2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | RUVBL2_TARGET_GENES
Systematic name | M30148
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y230 (RUVBL2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | RUVBL1_TARGET_GENES
Systematic name | M30147
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y265 (RUVBL1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ATF5_TARGET_GENES
Systematic name | M29893
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y2D1 (ATF5) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF510_TARGET_GENES
Systematic name | M30334
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y2H8 (ZNF510) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZBTB1_TARGET_GENES
Systematic name | M30235
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y2K1 (ZBTB1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF257_TARGET_GENES
Systematic name | M30288
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y2Q1 (ZNF257) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | THRAP3_TARGET_GENES
Systematic name | M30210
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y2W1 (THRAP3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | MED16_TARGET_GENES
Systematic name | M34475
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y2X0 (MED16) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZBTB12_TARGET_GENES
Systematic name | M30237
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y330 (ZBTB12) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF711_TARGET_GENES
Systematic name | M30383
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y462 (ZNF711) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZNF175_TARGET_GENES
Systematic name | M30269
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y473 (ZNF175) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NFE2L3_TARGET_GENES
Systematic name | M30086
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y4A8 (NFE2L3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | NEUROG3_TARGET_GENES
Systematic name | M30084
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y4Z2 (NEUROG3) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HES2_TARGET_GENES
Systematic name | M29994
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y543 (HES2) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | ZSCAN21_TARGET_GENES
Systematic name | M30403
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y5A6 (ZSCAN21) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | SUPT16H_TARGET_GENES
Systematic name | M30186
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y5B9 (SUPT16H) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | DMRT1_TARGET_GENES
Systematic name | M29944
Organism | Homo sapiens
PMID | 30445619
Authors |
Category | C3
Sub-category | TFT:GTRD
Brief description | Genes containing one or more binding sites for UniProt:Q9Y5R6 (DMRT1) in their promoter regions (TSS -1000,+100 bp) as identified by GTRD version 20.04 ChIP-seq harmonization.
Full description |

Standard name | HALLMARK_TNFA_SIGNALING_VIA_NFKB
Systematic name | M5890
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes regulated by NF-kB in response to TNF [GeneID=7124].
Full description |

Standard name | HALLMARK_HYPOXIA
Systematic name | M5891
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated in response to low oxygen levels (hypoxia).
Full description |

Standard name | HALLMARK_CHOLESTEROL_HOMEOSTASIS
Systematic name | M5892
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes involved in cholesterol homeostasis.
Full description |

Standard name | HALLMARK_MITOTIC_SPINDLE
Systematic name | M5893
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes important for mitotic spindle assembly.
Full description |

Standard name | HALLMARK_WNT_BETA_CATENIN_SIGNALING
Systematic name | M5895
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated by activation of WNT signaling through accumulation of beta catenin CTNNB1 [GeneID=1499].
Full description |

Standard name | HALLMARK_TGF_BETA_SIGNALING
Systematic name | M5896
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated in response to TGFB1 [GeneID=7040].
Full description |

Standard name | HALLMARK_IL6_JAK_STAT3_SIGNALING
Systematic name | M5897
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated by IL6 [GeneID=3569] via STAT3 [GeneID=6774], e.g., during acute phase response.
Full description |

Standard name | HALLMARK_DNA_REPAIR
Systematic name | M5898
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes involved in DNA repair.
Full description |

Standard name | HALLMARK_G2M_CHECKPOINT
Systematic name | M5901
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes involved in the G2/M checkpoint, as in progression through the cell division cycle.
Full description |

Standard name | HALLMARK_APOPTOSIS
Systematic name | M5902
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes mediating programmed cell death (apoptosis) by activation of caspases.
Full description |

Standard name | HALLMARK_NOTCH_SIGNALING
Systematic name | M5903
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated by activation of Notch signaling.
Full description |

Standard name | HALLMARK_ADIPOGENESIS
Systematic name | M5905
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated during adipocyte differentiation (adipogenesis).
Full description |

Standard name | HALLMARK_ESTROGEN_RESPONSE_EARLY
Systematic name | M5906
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes defining early response to estrogen.
Full description |

Standard name | HALLMARK_ESTROGEN_RESPONSE_LATE
Systematic name | M5907
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes defining late response to estrogen.
Full description |

Standard name | HALLMARK_ANDROGEN_RESPONSE
Systematic name | M5908
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes defining response to androgens.
Full description |

Standard name | HALLMARK_MYOGENESIS
Systematic name | M5909
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes involved in development of skeletal muscle (myogenesis).
Full description |

Standard name | HALLMARK_PROTEIN_SECRETION
Systematic name | M5910
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes involved in protein secretion pathway.
Full description |

Standard name | HALLMARK_INTERFERON_ALPHA_RESPONSE
Systematic name | M5911
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated in response to alpha interferon proteins.
Full description |

Standard name | HALLMARK_INTERFERON_GAMMA_RESPONSE
Systematic name | M5913
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated in response to IFNG [GeneID=3458].
Full description |

Standard name | HALLMARK_APICAL_JUNCTION
Systematic name | M5915
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes encoding components of apical junction complex.
Full description |

Standard name | HALLMARK_APICAL_SURFACE
Systematic name | M5916
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes encoding proteins over-represented on the apical surface of epithelial cells, e.g., important for cell polarity (apical area).
Full description |

Standard name | HALLMARK_HEDGEHOG_SIGNALING
Systematic name | M5919
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated by activation of hedgehog signaling.
Full description |

Standard name | HALLMARK_COMPLEMENT
Systematic name | M5921
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes encoding components of the complement system, which is part of the innate immune system.
Full description |

Standard name | HALLMARK_UNFOLDED_PROTEIN_RESPONSE
Systematic name | M5922
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated during unfolded protein response, a cellular stress response related to the endoplasmic reticulum.
Full description |

Standard name | HALLMARK_PI3K_AKT_MTOR_SIGNALING
Systematic name | M5923
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated by activation of the PI3K/AKT/mTOR pathway.
Full description |

Standard name | HALLMARK_MTORC1_SIGNALING
Systematic name | M5924
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated through activation of mTORC1 complex.
Full description |

Standard name | HALLMARK_E2F_TARGETS
Systematic name | M5925
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes encoding cell cycle related targets of E2F transcription factors.
Full description |

Standard name | HALLMARK_MYC_TARGETS_V1
Systematic name | M5926
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | A subgroup of genes regulated by MYC - version 1 (v1).
Full description |

Standard name | HALLMARK_MYC_TARGETS_V2
Systematic name | M5928
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | A subgroup of genes regulated by MYC - version 2 (v2).
Full description |

Standard name | HALLMARK_EPITHELIAL_MESENCHYMAL_TRANSITION
Systematic name | M5930
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes defining epithelial-mesenchymal transition, as in wound healing, fibrosis and metastasis.
Full description |

Standard name | HALLMARK_INFLAMMATORY_RESPONSE
Systematic name | M5932
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes defining inflammatory response.
Full description |

Standard name | HALLMARK_XENOBIOTIC_METABOLISM
Systematic name | M5934
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes encoding proteins involved in processing of drugs and other xenobiotics.
Full description |

Standard name | HALLMARK_FATTY_ACID_METABOLISM
Systematic name | M5935
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes encoding proteins involved in metabolism of fatty acids.
Full description |

Standard name | HALLMARK_OXIDATIVE_PHOSPHORYLATION
Systematic name | M5936
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes encoding proteins involved in oxidative phosphorylation.
Full description |

Standard name | HALLMARK_GLYCOLYSIS
Systematic name | M5937
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes encoding proteins involved in glycolysis and gluconeogenesis.
Full description |

Standard name | HALLMARK_REACTIVE_OXYGEN_SPECIES_PATHWAY
Systematic name | M5938
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated by reactive oxigen species (ROS).
Full description |

Standard name | HALLMARK_P53_PATHWAY
Systematic name | M5939
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes involved in p53 pathways and networks.
Full description |

Standard name | HALLMARK_UV_RESPONSE_UP
Systematic name | M5941
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated in response to ultraviolet (UV) radiation.
Full description |

Standard name | HALLMARK_UV_RESPONSE_DN
Systematic name | M5942
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes down-regulated in response to ultraviolet (UV) radiation.
Full description |

Standard name | HALLMARK_ANGIOGENESIS
Systematic name | M5944
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated during formation of blood vessels (angiogenesis).
Full description |

Standard name | HALLMARK_HEME_METABOLISM
Systematic name | M5945
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes involved in metabolism of heme (a cofactor consisting of iron and porphyrin) and erythroblast differentiation.
Full description |

Standard name | HALLMARK_COAGULATION
Systematic name | M5946
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes encoding components of blood coagulation system; also up-regulated in platelets.
Full description |

Standard name | HALLMARK_IL2_STAT5_SIGNALING
Systematic name | M5947
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated by STAT5 in response to IL2 stimulation.
Full description |

Standard name | HALLMARK_BILE_ACID_METABOLISM
Systematic name | M5948
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes involve in metabolism of bile acids and salts.
Full description |

Standard name | HALLMARK_PEROXISOME
Systematic name | M5949
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes encoding components of peroxisome.
Full description |

Standard name | HALLMARK_ALLOGRAFT_REJECTION
Systematic name | M5950
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated during transplant rejection.
Full description |

Standard name | HALLMARK_SPERMATOGENESIS
Systematic name | M5951
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated during production of male gametes (sperm), as in spermatogenesis.
Full description |

Standard name | HALLMARK_KRAS_SIGNALING_UP
Systematic name | M5953
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes up-regulated by KRAS activation.
Full description |

Standard name | HALLMARK_KRAS_SIGNALING_DN
Systematic name | M5956
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes down-regulated by KRAS activation.
Full description |

Standard name | HALLMARK_PANCREAS_BETA_CELLS
Systematic name | M5957
Organism | Homo sapiens
PMID |
Authors |
Category | H
Sub-category |
Brief description | Genes specifically up-regulated in pancreatic beta cells.
Full description |

Standard name | HP_MULTICYSTIC_KIDNEY_DYSPLASIA
Systematic name | M34476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Multicystic kidney dysplasia
Full description | Multicystic dysplasia of the kidney is characterized by multiple cysts of varying size in the kidney and the absence of a normal pelvicaliceal system. The condition is associated with ureteral or ureteropelvic atresia, and the affected kidney is nonfunctional. [HPO:curators]

Standard name | HP_RECURRENT_URINARY_TRACT_INFECTIONS
Systematic name | M34477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Recurrent urinary tract infections
Full description | Repeated infections of the urinary tract. [HPO:probinson]

Standard name | HP_NEUROGENIC_BLADDER
Systematic name | M34478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neurogenic bladder
Full description | A type of bladder dysfunction caused by neurologic damage. Neurogenic bladder can be flaccid or spastic. Common manifestatios of neurogenic bladder are overflow incontinence, frequency, urgency, urge incontinence, and retention. [HPO:probinson, PMID:18095004, PMID:22400020]

Standard name | HP_URINARY_URGENCY
Systematic name | M34479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Urinary urgency
Full description | Urge incontinence is the strong, sudden need to urinate. [HPO:probinson, PMID:12559262]

Standard name | HP_HYPOPLASIA_OF_THE_UTERUS
Systematic name | M34480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoplasia of the uterus
Full description | Underdevelopment of the uterus. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_BLADDER
Systematic name | M34481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the bladder
Full description | An abnormality of the urinary bladder. [HPO:probinson]

Standard name | HP_BLADDER_DIVERTICULUM
Systematic name | M34482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bladder diverticulum
Full description | Diverticulum (sac or pouch) in the wall of the urinary bladder. [HPO:probinson]

Standard name | HP_URINARY_RETENTION
Systematic name | M34483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Urinary retention
Full description | Inability to completely empty the urinary bladder during the process of urination. [HPO:probinson]

Standard name | HP_NOCTURIA
Systematic name | M34484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nocturia
Full description | Abnormally increased production of urine during the night leading to an unusually frequent need to urinate. [HPO:sdoelken]

Standard name | HP_ABNORMALITY_OF_MALE_INTERNAL_GENITALIA
Systematic name | M34485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of male internal genitalia
Full description | An abnormality of the male internal genitalia. [HPO:probinson]

Standard name | HP_INGUINAL_HERNIA
Systematic name | M34486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Inguinal hernia
Full description | Protrusion of the contents of the abdominal cavity through the inguinal canal. [HPO:probinson]

Standard name | HP_PROSTATITIS
Systematic name | M34487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Prostatitis
Full description | The presence of inflammation of the prostate. [HPO:probinson]

Standard name | HP_FUNCTIONAL_ABNORMALITY_OF_MALE_INTERNAL_GENITALIA
Systematic name | M34488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Functional abnormality of male internal genitalia
Full description |

Standard name | HP_MALE_HYPOGONADISM
Systematic name | M34489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Male hypogonadism
Full description | Decreased functionality of the male gonad, i.e., of the testis, with reduced spermatogenesis or testosterone synthesis. [HPO:probinson]

Standard name | HP_CRYPTORCHIDISM
Systematic name | M34490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cryptorchidism
Full description | Testis in inguinal canal. That is, absence of one or both testes from the scrotum owing to failure of the testis or testes to descend through the inguinal canal to the scrotum. [HPO:probinson, PMID:23650202]

Standard name | HP_TESTICULAR_ATROPHY
Systematic name | M34491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Testicular atrophy
Full description | Wasting (atrophy) of the testicle (the male gonad) manifested by a decrease in size and potentially by a loss of fertility. [HPO:probinson]

Standard name | HP_AMBIGUOUS_GENITALIA_MALE
Systematic name | M34492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ambiguous genitalia, male
Full description | Ambiguous genitalia in an individual with XY genetic gender. [HPO:probinson]

Standard name | HP_HYDROCELE_TESTIS
Systematic name | M34493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hydrocele testis
Full description | Accumulation of clear fluid in the between the layers of membrane (tunica vaginalis) surrounding the testis. [HPO:probinson]

Standard name | HP_ABNORMAL_TESTIS_MORPHOLOGY
Systematic name | M34494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal testis morphology
Full description | An anomaly of the testicle (the male gonad). [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_PENIS
Systematic name | M34495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the penis
Full description |

Standard name | HP_MALE_PSEUDOHERMAPHRODITISM
Systematic name | M34496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Male pseudohermaphroditism
Full description | Hermaphroditism refers to a discrepancy between the morphology of the gonads and that of the external genitalia. In male pseudohermaphroditism, the genotype is male (XY) and the external genitalia are imcompletely virilized, ambiguous, or complete female. If gonads are present, they are testes. [HPO:curators]

Standard name | HP_EPISPADIAS
Systematic name | M34497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Epispadias
Full description | Displacement of the urethral opening on the dorsal (superior) surface of the penis. [HPO:probinson, PMID:23650202]

Standard name | HP_LONG_PENIS
Systematic name | M34498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Long penis
Full description | Penile length more than 2 SD above the mean for age. []

Standard name | HP_CHORDEE
Systematic name | M34499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Chordee
Full description | Ventral, lateral, or ventrolateral bowing of the shaft and glans penis of more than 30 degrees. [HPO:probinson, PMID:23650202]

Standard name | HP_HYPOGONADOTROPIC_HYPOGONADISM
Systematic name | M34500
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypogonadotropic hypogonadism
Full description | Hypogonadotropic hypogonadism is characterized by reduced function of the gonads (testes in males or ovaries in females) and results from the absence of the gonadal stimulating pituitary hormones: follicle stimulating hormone (FSH) and luteinizing hormone (LH). [HPO:probinson, PMID:23503957]

Standard name | HP_ABNORMALITY_OF_THE_SCROTUM
Systematic name | M34501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the scrotum
Full description |

Standard name | HP_SCROTAL_HYPOPLASIA
Systematic name | M34502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Scrotal hypoplasia
Full description |

Standard name | HP_BIFID_SCROTUM
Systematic name | M34503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bifid scrotum
Full description | Midline indentation or cleft of the scrotum. [HPO:probinson, PMID:23650202]

Standard name | HP_SHAWL_SCROTUM
Systematic name | M34504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Shawl scrotum
Full description | Superior margin of the scrotum superior to the base of the penis. [HPO:probinson, PMID:23650202]

Standard name | HP_PERINEAL_HYPOSPADIAS
Systematic name | M34505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Perineal hypospadias
Full description | Hypospadias with location of the urethral meatus in the perineal region. [HPO:probinson, PMID:8097257]

Standard name | HP_MACROORCHIDISM
Systematic name | M34506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Macroorchidism
Full description | The presence of abnormally large testes. [HPO:probinson]

Standard name | HP_MICROPENIS
Systematic name | M34507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Micropenis
Full description | Abnormally small penis. At birth, the normal penis is about 3 cm (stretched length from pubic tubercle to tip of penis) with micropenis less than 2.0-2.5 cm. [HPO:probinson, PMID:15102623]

Standard name | HP_ABNORMALITY_OF_FEMALE_EXTERNAL_GENITALIA
Systematic name | M34508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of female external genitalia
Full description | An abnormality of the female external genitalia. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_CLITORIS
Systematic name | M34509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the clitoris
Full description | An abnormality of the clitoris. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_LABIA
Systematic name | M34510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the labia
Full description | An anomaly of the labia, the externally visible portions of the vulva. [HPO:probinson]

Standard name | HP_CLITORAL_HYPOPLASIA
Systematic name | M34511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Clitoral hypoplasia
Full description | Developmental hypoplasia of the clitoris. [HPO:probinson]

Standard name | HP_AMBIGUOUS_GENITALIA_FEMALE
Systematic name | M34512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ambiguous genitalia, female
Full description | Ambiguous genitalia in an individual with XX genetic gender. [HPO:probinson]

Standard name | HP_AMBIGUOUS_GENITALIA
Systematic name | M34513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ambiguous genitalia
Full description | A genital phenotype that is not clearly assignable to a single gender. Ambiguous genitalia can be evaluated using the Prader scale: Prader 0: Normal female external genitalia. Prader 1: Female external genitalia with clitoromegaly. Prader 2: Clitoromegaly with partial labial fusion forming a funnel-shaped urogenital sinus. Prader 3: Increased phallic enlargement. Complete labioscrotal fusion forming a urogenital sinus with a single opening. Prader 4: Complete scrotal fusion with urogenital opening at the base or on the shaft of the phallus. Prader 5: Normal male external genitalia. The diagnosis of ambiguous genitalia is made for Prader 1-4. [HPO:probinson, PMID:15102623]

Standard name | HP_FUSED_LABIA_MINORA
Systematic name | M34514
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Fused labia minora
Full description | Fusion of the labia minora as a result of labial adhesions resulting in vaginal obstruction. [HPO:curators]

Standard name | HP_HYPOPLASTIC_LABIA_MINORA
Systematic name | M34515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoplastic labia minora
Full description |

Standard name | HP_LABIAL_HYPERTROPHY
Systematic name | M34516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Labial hypertrophy
Full description |

Standard name | HP_URETHRAL_ATRESIA
Systematic name | M34517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Urethral atresia
Full description | Congenital anomaly characterized by closure or failure to develop an opening in the urethra. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_URETER
Systematic name | M34518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the ureter
Full description | An abnormality of the ureter. The ureter is the duct by which urine passes from the kidney to the bladder. [HPO:probinson]

Standard name | HP_URETEROCELE
Systematic name | M34519
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ureterocele
Full description | A ureterocele is a congenital saccular dilatation of the distal segment of the ureter. [eMedicine:453993]

Standard name | HP_HYDROURETER
Systematic name | M34520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hydroureter
Full description | The distention of the ureter with urine. [HPO:curators]

Standard name | HP_URETERAL_DUPLICATION
Systematic name | M34521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ureteral duplication
Full description | A developmental anomaly characterized by the presence of two, instead of one, ureter connecting a kidney to the bladder. [HPO:curators]

Standard name | HP_URETEROPELVIC_JUNCTION_OBSTRUCTION
Systematic name | M34522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ureteropelvic junction obstruction
Full description | Blockage of urine flow from the renal pelvis to the proximal ureter. [Eurenomics:ewuehl]

Standard name | HP_RENAL_DUPLICATION
Systematic name | M34523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal duplication
Full description | A congenital anomaly of the urinary tract, in which the kidney is duplicated and is drained via two separate renal pelves and ureters. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_REPRODUCTIVE_SYSTEM_PHYSIOLOGY
Systematic name | M34524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of reproductive system physiology
Full description | An abnormal functionality of the genital system. [HPO:probinson]

Standard name | HP_DUPLICATED_COLLECTING_SYSTEM
Systematic name | M34525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Duplicated collecting system
Full description | A duplication of the collecting system of the kidney, defined as a kidney with two (instead of, normally, one) pyelocaliceal systems. The pyelocaliceal system is comprised of the renal pelvis and calices. The duplicated renal collecting system can be associated with a single ureter or with double ureters. In the latter case, the two ureters empty separately into the bladder or fuse to form a single ureteral orifice. [HPO:probinson]

Standard name | HP_RENAL_INSUFFICIENCY
Systematic name | M34526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal insufficiency
Full description | A reduction in the level of performance of the kidneys in areas of function comprising the concentration of urine, removal of wastes, the maintenance of electrolyte balance, homeostasis of blood pressure, and calcium metabolism. [HPO:probinson]

Standard name | HP_HORSESHOE_KIDNEY
Systematic name | M34527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Horseshoe kidney
Full description | A connection of the right and left kidney by an isthmus of functioning renal parenchyma or fibrous tissue that crosses the midline. [HPO:probinson]

Standard name | HP_ECTOPIC_KIDNEY
Systematic name | M34528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ectopic kidney
Full description | A developmental defect in which a kidney is located in an abnormal anatomic position. [HPO:probinson]

Standard name | HP_RENAL_HYPOPLASIA
Systematic name | M34529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal hypoplasia
Full description | Hypoplasia of the kidney. [HPO:probinson]

Standard name | HP_NEPHRONOPHTHISIS
Systematic name | M34530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nephronophthisis
Full description | Presence of cysts at the corticomedullary junction of the kidney in combination with tubulointerstitial fibrosis. [Eurenomics:fschaefer]

Standard name | HP_ABNORMAL_RENAL_TUBULE_MORPHOLOGY
Systematic name | M34531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal renal tubule morphology
Full description | An abnormality of the renal tubules. [HPO:probinson]

Standard name | HP_RENAL_TUBULAR_ATROPHY
Systematic name | M34532
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal tubular atrophy
Full description | The presence of renal tubules with thick redundant basement membranes, or a reduction of greater than 50% in tubular diameter compared to surrounding non-atrophic tubules. [HPO:probinson, PMID:27211375]

Standard name | HP_GLOMERULOSCLEROSIS
Systematic name | M34533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Glomerulosclerosis
Full description | Accumulation of scar tissue within the glomerulus. [Eurenomics:fschaefer]

Standard name | HP_FOCAL_SEGMENTAL_GLOMERULOSCLEROSIS
Systematic name | M34534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Focal segmental glomerulosclerosis
Full description | Segmental accumulation of scar tissue in individual (but not all) glomeruli. [Eurenomics:fschaefer]

Standard name | HP_TALL_STATURE
Systematic name | M34535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tall stature
Full description | A height above that which is expected according to age and gender norms. [HPO:probinson]

Standard name | HP_GLOMERULONEPHRITIS
Systematic name | M34536
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Glomerulonephritis
Full description | Inflammation of the renal glomeruli. [HPO:probinson]

Standard name | HP_NEPHROTIC_SYNDROME
Systematic name | M34537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nephrotic syndrome
Full description | Nephrotic syndrome is a collection of findings resulting from glomerular dysfunction with an increase in glomerular capillary wall permeability associated with pronounced proteinuria. Nephrotic syndrome refers to the constellation of clinical findings that result from severe renal loss of protein, with Proteinuria and hypoalbuminemia, edema, and hyperlipidemia. [HPO:probinson]

Standard name | HP_POLYURIA
Systematic name | M34538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Polyuria
Full description | An increased rate of urine production. [HPO:probinson]

Standard name | HP_RENAL_AGENESIS
Systematic name | M34539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal agenesis
Full description | Agenesis, that is, failure of the kidney to develop during embryogenesis and development. [HPO:probinson]

Standard name | HP_ENLARGED_KIDNEY
Systematic name | M34540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Enlarged kidney
Full description | An abnormal increase in the size of the kidney. [HPO:probinson]

Standard name | HP_RENAL_CYST
Systematic name | M34541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal cyst
Full description | A fluid filled sac in the kidney. [Eurenomics:fschaefer]

Standard name | HP_RENAL_CORTICOMEDULLARY_CYSTS
Systematic name | M34542
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal corticomedullary cysts
Full description | The presence of multiple cysts at the border between the renal cortex and medulla. [HPO:probinson]

Standard name | HP_RENAL_DYSPLASIA
Systematic name | M34543
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal dysplasia
Full description | The presence of developmental dysplasia of the kidney. [HPO:probinson]

Standard name | HP_NEPHROPATHY
Systematic name | M34544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nephropathy
Full description | A nonspecific term referring to disease or damage of the kidneys. [HPO:curators]

Standard name | HP_POLYCYSTIC_KIDNEY_DYSPLASIA
Systematic name | M34545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Polycystic kidney dysplasia
Full description | The presence of multiple cysts in both kidneys. [HPO:probinson]

Standard name | HP_PROXIMAL_TUBULOPATHY
Systematic name | M34546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Proximal tubulopathy
Full description | Dysfunction of the proximal tubule, which is the portion of the duct system of the nephron of the kidney which leads from Bowman's capsule to the loop of Henle. [HPO:probinson]

Standard name | HP_RENAL_PHOSPHATE_WASTING
Systematic name | M34547
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal phosphate wasting
Full description | High urine phosphate in the presence of hypophosphatemia. [HPO:probinson]

Standard name | HP_NEPHROCALCINOSIS
Systematic name | M34548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nephrocalcinosis
Full description | Nephrocalcinosis is the deposition of calcium salts in renal parenchyma. [HPO:probinson]

Standard name | HP_UNILATERAL_RENAL_AGENESIS
Systematic name | M34549
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Unilateral renal agenesis
Full description | A unilateral form of agenesis of the kidney. [HPO:probinson]

Standard name | HP_NEPHRITIS
Systematic name | M34550
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nephritis
Full description | The presence of inflammation affecting the kidney. [HPO:probinson]

Standard name | HP_RENAL_TUBULAR_DYSFUNCTION
Systematic name | M34551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal tubular dysfunction
Full description | Abnormal function of the renal tubule. The basic functional unit of the kidney, the nephron, consists of a renal corpuscle attached to a renal tubule, with roughly 0.8 to 1.5 nephrons per adult kidney. The functions of the renal tubule include reabsorption of water, electrolytes, glucose, and amino acids and secretion of substances such as uric acid. []

Standard name | HP_PELVIC_KIDNEY
Systematic name | M34552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pelvic kidney
Full description | A developmental defect in which a kidney is located in an abnormal anatomic position within the pelvis. [HPO:probinson]

Standard name | HP_RENAL_SALT_WASTING
Systematic name | M34553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal salt wasting
Full description | A high concentration of one or more electrolytes in the urine in the presence of low serum concentrations of the electrolyte(s). [Eurenomics:fschaefer]

Standard name | HP_RENAL_POTASSIUM_WASTING
Systematic name | M34554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal potassium wasting
Full description | High urine potassium in the presence of hypokalemia. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_UTERUS
Systematic name | M34555
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the uterus
Full description | An abnormality of the uterus. [HPO:probinson]

Standard name | HP_MENORRHAGIA
Systematic name | M34556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Menorrhagia
Full description | Prolonged and excessive menses at regular intervals in excess of 80 mL or lasting longer than 7 days. [HPO:probinson, PMID:22594864]

Standard name | HP_GONADAL_DYSGENESIS
Systematic name | M34557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gonadal dysgenesis
Full description |

Standard name | HP_FEMALE_HYPOGONADISM
Systematic name | M34558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Female hypogonadism
Full description | Decreased functionality of the female gonads, i.e., of the ovary. [HPO:probinson]

Standard name | HP_HYPOGONADISM
Systematic name | M34559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypogonadism
Full description | A decreased functionality of the gonad. [HPO:curators]

Standard name | HP_BIFID_UTERUS
Systematic name | M34560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bifid uterus
Full description | The presence of a bifid uterus. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_OVARY
Systematic name | M34561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the ovary
Full description | An abnormality of the ovary. [HPO:probinson]

Standard name | HP_OVARIAN_CYST
Systematic name | M34562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ovarian cyst
Full description | The presence of one or more cysts of the ovary. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_MENSTRUAL_CYCLE
Systematic name | M34563
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the menstrual cycle
Full description | An abnormality of the ovulation cycle. [HPO:probinson, PMID:23281358]

Standard name | HP_AMENORRHEA
Systematic name | M34564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Amenorrhea
Full description | Absence of menses for an interval of time equivalent to a total of more than (or equal to) 3 previous cycles or 6 months. [PMID:22594864]

Standard name | HP_ABNORMAL_VAGINA_MORPHOLOGY
Systematic name | M34565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal vagina morphology
Full description | Any structural abnormality of the vagina. [HPO:probinson]

Standard name | HP_DECREASED_FERTILITY
Systematic name | M34566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Decreased fertility
Full description |

Standard name | HP_VAGINAL_ATRESIA
Systematic name | M34567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Vaginal atresia
Full description | Congenital occlusion of the vagina or adhesion of the walls of the vagina causing occlusion. [HPO:probinson]

Standard name | HP_OVARIAN_GONADOBLASTOMA
Systematic name | M34568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ovarian gonadoblastoma
Full description | The presence of a gonadoblastoma of the ovary. [eMedicine:986581, HPO:probinson]

Standard name | HP_GONADOBLASTOMA
Systematic name | M34569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gonadoblastoma
Full description | The presence of a gonadoblastoma, a neoplasm of a gonad that consists of aggregates of germ cells and sex cord elements. [HPO:probinson]

Standard name | HP_APLASIA_OF_THE_UTERUS
Systematic name | M34570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aplasia of the uterus
Full description | Aplasia of the uterus. [HPO:probinson]

Standard name | HP_WIDE_MOUTH
Systematic name | M34571
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Wide mouth
Full description | Distance between the oral commissures more than 2 SD above the mean. Alternatively, an apparently increased width of the oral aperture (subjective). [PMID:19125428]

Standard name | HP_ORAL_ULCER
Systematic name | M34572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Oral ulcer
Full description | Erosion of the mucous mebrane of the mouth with local excavation of the surface, resulting from the sloughing of inflammatory necrotic tissue. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_TONGUE
Systematic name | M34573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the tongue
Full description | Any abnormality of the tongue. [HPO:probinson]

Standard name | HP_MACROGLOSSIA
Systematic name | M34574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Macroglossia
Full description | Increased length and width of the tongue. [PMID:19125428]

Standard name | HP_ABNORMAL_LIP_MORPHOLOGY
Systematic name | M34575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal lip morphology
Full description | An abnormality of the lip. [HPO:probinson]

Standard name | HP_NARROW_MOUTH
Systematic name | M34576
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Narrow mouth
Full description | Distance between the commissures of the mouth more than 2 SD below the mean. Alternatively, an apparently decreased width of the oral aperture (subjective). [PMID:19125428]

Standard name | HP_MEDIAN_CLEFT_LIP
Systematic name | M34577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Median cleft lip
Full description | A type of cleft lip presenting as a midline (median) gap in the upper lip. [HPO:probinson]

Standard name | HP_GLOSSOPTOSIS
Systematic name | M34578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Glossoptosis
Full description | Posterior displacement of the tongue into the pharynx, i.e., a tongue that is mislocalised posteriorly. [HPO:probinson, PMID:19125428]

Standard name | HP_ABNORMALITY_OF_THE_DENTITION
Systematic name | M34579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the dentition
Full description | Any abnormality of the teeth. [HPO:ibailleulforestier]

Standard name | HP_ABNORMALITY_OF_THE_GINGIVA
Systematic name | M34580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the gingiva
Full description | Any abnormality of the gingiva (also known as gums). [HPO:probinson]

Standard name | HP_GINGIVAL_FIBROMATOSIS
Systematic name | M34581
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gingival fibromatosis
Full description | The presence of fibrosis of the gingiva. [HPO:probinson]

Standard name | HP_MICROGLOSSIA
Systematic name | M34582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Microglossia
Full description | Decreased length and width of the tongue. [PMID:19125428]

Standard name | HP_ABNORMALITY_OF_THE_UVULA
Systematic name | M34583
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the uvula
Full description | Abnormality of the uvula, the conic projection from the posterior edge of the middle of the soft palate. [HPO:probinson]

Standard name | HP_ABNORMAL_PALATE_MORPHOLOGY
Systematic name | M34584
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal palate morphology
Full description | Any abnormality of the palate, i.e., of roof of the mouth. [HPO:probinson]

Standard name | HP_SUBMUCOUS_CLEFT_HARD_PALATE
Systematic name | M34585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Submucous cleft hard palate
Full description | Hard-palate submucous clefts are characterized by bony defects in the midline of the bony palate that are covered by the mucous membrane of the roof of the mouth. It may be possible to detect a submucous cleft hard palate upon palpation as a notch in the bony palate. [HPO:probinson, PMID:19779505]

Standard name | HP_ABNORMALITY_OF_UPPER_LIP
Systematic name | M34586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of upper lip
Full description | An abnormality of the upper lip. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_LOWER_LIP
Systematic name | M34587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of lower lip
Full description | An abnormality of the lower lip. [HPO:probinson]

Standard name | HP_THICK_LOWER_LIP_VERMILION
Systematic name | M34588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thick lower lip vermilion
Full description | Increased thickness of the lower lip, leading to a prominent appearance of the lower lip. The height of the vermilion of the lower lip in the midline is more than 2 SD above the mean. Alternatively, an apparently increased height of the vermilion of the lower lip in the frontal view (subjective). [HPO:curators, PMID:19125428]

Standard name | HP_LOBULATED_TONGUE
Systematic name | M34589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lobulated tongue
Full description | Multiple indentations and/or elevations on the edge and/or surface of the tongue producing an irregular surface contour. [PMID:19125428]

Standard name | HP_MOVEMENT_ABNORMALITY_OF_THE_TONGUE
Systematic name | M34590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Movement abnormality of the tongue
Full description |

Standard name | HP_DIFFICULTY_IN_TONGUE_MOVEMENTS
Systematic name | M34591
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Difficulty in tongue movements
Full description |

Standard name | HP_CLEFT_SOFT_PALATE
Systematic name | M34592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cleft soft palate
Full description | Cleft of the soft palate (also known as the velum, or muscular palate) as a result of a developmental defect occurring between the 7th and 12th week of pregnancy. Cleft soft palate can cause functional abnormalities of the Eustachian tube with resulting middle ear anomalies and hearing difficulties, as well as speech problems associated with hypernasal speech due to velopharyngeal insufficiency. [HPO:curators]

Standard name | HP_BROAD_ALVEOLAR_RIDGES
Systematic name | M34593
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad alveolar ridges
Full description |

Standard name | HP_SHORT_UPPER_LIP
Systematic name | M34594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short upper lip
Full description | Decreased width of the upper lip. [HPO:probinson]

Standard name | HP_NARROW_PALATE
Systematic name | M34595
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Narrow palate
Full description | Width of the palate more than 2 SD below the mean (objective) or apparently decreased palatal width (subjective). [PMID:19125428]

Standard name | HP_ABNORMAL_ORAL_FRENULUM_MORPHOLOGY
Systematic name | M34596
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal oral frenulum morphology
Full description | An abnormality of the lingual frenulum, that is of the small fold of mucous membrane that attaches the tongue to the floor of the mouth, or the presence of accessory frenula in the oral cavity. [HPO:probinson, PMID:23633765]

Standard name | HP_ACCESSORY_ORAL_FRENULUM
Systematic name | M34597
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Accessory oral frenulum
Full description | Extra fold of tissue extending from the alveolar ridge to the inner surface of the upper or lower lip. [PMID:19125428]

Standard name | HP_OPEN_MOUTH
Systematic name | M34598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Open mouth
Full description | A facial appearance characterized by a permanently or nearly permanently opened mouth. [HPO:probinson]

Standard name | HP_ABNORMAL_PAROTID_GLAND_MORPHOLOGY
Systematic name | M34599
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal parotid gland morphology
Full description | Any abnormality of the parotid glands, which are the salivary glands that are located in the subcutaneous tissues of the face overlying the mandibular ramus and anterior and inferior to the external ear. [HPO:curators]

Standard name | HP_TONGUE_NODULES
Systematic name | M34600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tongue nodules
Full description |

Standard name | HP_SHORT_LINGUAL_FRENULUM
Systematic name | M34601
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short lingual frenulum
Full description | The presence of an abnormally short lingual frenulum. [HPO:probinson]

Standard name | HP_PIERRE_ROBIN_SEQUENCE
Systematic name | M34602
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pierre-Robin sequence
Full description | Pierre Robin malformation is a sequence of developmental malformations characterized by micrognathia (mandibular hypoplasia), glossoptosis and cleft palate. [HPO:probinson]

Standard name | HP_ORAL_CLEFT
Systematic name | M34603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Oral cleft
Full description | The presence of a cleft in the oral cavity, the two main types of which are cleft lip and cleft palate. In cleft lip, there is the congenital failure of the maxillary and median nasal processes to fuse, forming a groove or fissure in the lip. In cleft palate, there is a congenital failure of the palate to fuse properly, forming a grooved depression or fissure in the roof of the mouth. Clefts of the lip and palate can occur individually or together. It is preferable to code each defect separately. [HPO:probinson, PMID:21331089]

Standard name | HP_GLOSSITIS
Systematic name | M34604
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Glossitis
Full description | Inflammation of the tongue. [HPO:sdoelken]

Standard name | HP_TRIANGULAR_MOUTH
Systematic name | M34605
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Triangular mouth
Full description | The presence of a triangular form of the mouth. [HPO:probinson]

Standard name | HP_TRISMUS
Systematic name | M34606
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Trismus
Full description | Limitation in the ability to open the mouth. [HPO:curators]

Standard name | HP_GINGIVAL_OVERGROWTH
Systematic name | M34607
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gingival overgrowth
Full description | Hyperplasia of the gingiva (that is, a thickening of the soft tissue overlying the alveolar ridge. The degree of thickening ranges from involvement of the interdental papillae alone to gingival overgrowth covering the entire tooth crown. [PMID:19125428]

Standard name | HP_THICK_UPPER_LIP_VERMILION
Systematic name | M34608
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thick upper lip vermilion
Full description | Height of the vermilion of the upper lip in the midline more than 2 SD above the mean. Alternatively, an apparently increased height of the vermilion of the upper lip in the frontal view (subjective). [PMID:19125428]

Standard name | HP_XEROSTOMIA
Systematic name | M34609
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Xerostomia
Full description | Dryness of the mouth due to salivary gland dysfunction. [HPO:probinson]

Standard name | HP_HIGH_PALATE
Systematic name | M34610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | High palate
Full description | Height of the palate more than 2 SD above the mean (objective) or palatal height at the level of the first permanent molar more than twice the height of the teeth (subjective). [PMID:19125428]

Standard name | HP_THIN_UPPER_LIP_VERMILION
Systematic name | M34611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thin upper lip vermilion
Full description | Height of the vermilion of the upper lip in the midline more than 2 SD below the mean. Alternatively, an apparently reduced height of the vermilion of the upper lip in the frontal view (subjective). [PMID:19125428]

Standard name | HP_VELOPHARYNGEAL_INSUFFICIENCY
Systematic name | M34612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Velopharyngeal insufficiency
Full description | Inability of velopharyngeal sphincter to sufficiently separate the nasal cavity from the oral cavity during speech. [DDD:jhurst]

Standard name | HP_FURROWED_TONGUE
Systematic name | M34613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Furrowed tongue
Full description | Accentuation of the grooves on the dorsal surface of the tongue. [PMID:19125428]

Standard name | HP_ABNORMALITY_OF_TASTE_SENSATION
Systematic name | M34614
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of taste sensation
Full description |

Standard name | HP_GINGIVAL_BLEEDING
Systematic name | M34615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gingival bleeding
Full description | Hemorrhage affecting the gingiva. [HPO:ibailleulforestier]

Standard name | HP_GINGIVITIS
Systematic name | M34616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gingivitis
Full description | Inflammation of the gingiva. [HPO:probinson]

Standard name | HP_THIN_VERMILION_BORDER
Systematic name | M34617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thin vermilion border
Full description | Height of the vermilion of the medial part of the lip more than 2 SD below the mean, or apparently reduced height of the vermilion of the lip in the frontal view. The vermilion is the red part of the lips (and confusingly, the vermilion itself is also often referred to as being equivalent the lips). [HPO:probinson, PMID:19125428]

Standard name | HP_ABNORMALITY_OF_THE_FONTANELLES_OR_CRANIAL_SUTURES
Systematic name | M34618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the fontanelles or cranial sutures
Full description | Any abnormality of the fontanelles (the regions covered by a thick membrane that normally ossify in the first two years of life) or the cranial sutures (the fibrous joints in which the articulating bones or cartilages of the skull are connected by sutural ligaments). [HPO:probinson, PMID:12825844]

Standard name | HP_ABNORMALITY_OF_THE_ANTERIOR_FONTANELLE
Systematic name | M34619
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the anterior fontanelle
Full description | An abnormality of the anterior fontanelle, i.e., the cranial fontanelle that is located at the intersection of the coronal and sagittal sutures. [HPO:curators]

Standard name | HP_SMALL_ANTERIOR_FONTANELLE
Systematic name | M34620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Small anterior fontanelle
Full description | Abnormally decreased size of the anterior fontanelle with respect to age-dependent norms. [HPO:probinson]

Standard name | HP_HYDROCEPHALUS
Systematic name | M34621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hydrocephalus
Full description | Hydrocephalus is an active distension of the ventricular system of the brain resulting from inadequate passage of CSF from its point of production within the cerebral ventricles to its point of absorption into the systemic circulation. [HPO:probinson, PMID:18211712, PMID:19410151]

Standard name | HP_ABNORMALITY_OF_SKULL_SIZE
Systematic name | M34622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of skull size
Full description | Any abnormality of the size of the skull. [HPO:curators]

Standard name | HP_PARIETAL_BOSSING
Systematic name | M34623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Parietal bossing
Full description | Parietal bossing is a marked prominence in the parietal region. [HPO:probinson]

Standard name | HP_TRIGONOCEPHALY
Systematic name | M34624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Trigonocephaly
Full description | Wedge-shaped, or triangular head, with the apex of the triangle at the midline of the forehead and the base of the triangle at the occiput. [PMID:19125436]

Standard name | HP_BRACHYTURRICEPHALY
Systematic name | M34625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Brachyturricephaly
Full description | Abnormal vertical height of the skull and a shortening of its anterior-posterior length, frequently combined with malformations of the occipital region. [PMID:8460563]

Standard name | HP_ABNORMALITY_OF_THE_PARANASAL_SINUSES
Systematic name | M34626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the paranasal sinuses
Full description | Abnormality of the paranasal (cranial) sinuses, which are air-filled spaces that are located within the bones of the skull and face and communicate with the nasal cavity. They comprise the maxillary sinuses, the frontal sinuses, the ethmoid sinuses, and the sphenoid sinuses. [HPO:curators]

Standard name | HP_BRACHYCEPHALY
Systematic name | M34627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Brachycephaly
Full description | An abnormality of skull shape characterized by a decreased anterior-posterior diameter. That is, a cephalic index greater than 81%. Alternatively, an apparently shortened anteroposterior dimension (length) of the head compared to width. [HPO:probinson, PMID:19125436]

Standard name | HP_PROGRESSIVE_MICROCEPHALY
Systematic name | M34628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Progressive microcephaly
Full description | Progressive microcephaly is diagnosed when the head circumference falls progressively behind age- and gender-dependent norms. [HPO:probinson]

Standard name | HP_WIDE_ANTERIOR_FONTANEL
Systematic name | M34629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Wide anterior fontanel
Full description | Enlargement of the anterior fontanelle with respect to age-dependent norms. [HPO:curators]

Standard name | HP_TURRICEPHALY
Systematic name | M34630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Turricephaly
Full description | Tall head relative to width and length. [PMID:19125436]

Standard name | HP_OXYCEPHALY
Systematic name | M34631
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Oxycephaly
Full description | Oxycephaly (from Greek oxus, sharp, and kephalos, head) refers to a conical or pointed shape of the skull. [HPO:curators]

Standard name | HP_ABNORMALITY_OF_THE_MASTOID
Systematic name | M34632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the mastoid
Full description | An abnormality of the mastoid process, which is the conical prominence projecting from the undersurface of the mastoid portion of the temporal bone. [HPO:pnrobinson]

Standard name | HP_MASTOIDITIS
Systematic name | M34633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mastoiditis
Full description |

Standard name | HP_CRANIAL_ASYMMETRY
Systematic name | M34634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cranial asymmetry
Full description | Asymmetry of the bones of the skull. [HPO:curators]

Standard name | HP_DOLICHOCEPHALY
Systematic name | M34635
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dolichocephaly
Full description | An abnormality of skull shape characterized by a increased anterior-posterior diameter, i.e., an increased antero-posterior dimension of the skull. Cephalic index less than 76%. Alternatively, an apparently increased antero-posterior length of the head compared to width. Often due to premature closure of the sagittal suture. [HPO:probinson, PMID:19125436]

Standard name | HP_PROMINENT_OCCIPUT
Systematic name | M34636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Prominent occiput
Full description | Increased convexity of the occiput (posterior part of the skull). [PMID:19125436]

Standard name | HP_DELAYED_CRANIAL_SUTURE_CLOSURE
Systematic name | M34637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delayed cranial suture closure
Full description | Infants normally have two fontanels at birth, the diamond-shaped anterior fontanelle at the junction of the coronal and sagittal sutures, and the posterior fontanelle at the intersection of the occipital and parietal bones. The posterior fontanelle usually closes by the 8th week of life, and the anterior fontanel closes by the 18th month of life on average. This term applies if there is delay of closure of the fontanelles beyond the normal age. [HPO:probinson]

Standard name | HP_FACIAL_GRIMACING
Systematic name | M34638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial grimacing
Full description |

Standard name | HP_SMALL_FACE
Systematic name | M34639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Small face
Full description | A face that is short (HP:0011219) and narrow (HP:0000275). [HP:probinson]

Standard name | HP_NARROW_FACE
Systematic name | M34640
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Narrow face
Full description | Bizygomatic (upper face) and bigonial (lower face) width are both more than 2 standard deviations below the mean (objective); or, an apparent reduction in the width of the upper and lower face (subjective). [PMID:19125436]

Standard name | HP_RETROGNATHIA
Systematic name | M34641
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retrognathia
Full description | An abnormality in which the mandible is mislocalised posteriorly. [HPO:probinson]

Standard name | HP_COARSE_FACIAL_FEATURES
Systematic name | M34642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Coarse facial features
Full description | Absence of fine and sharp appearance of brows, nose, lips, mouth, and chin, usually because of rounded and heavy features or thickened skin with or without thickening of subcutaneous and bony tissues. [PMID:19125436]

Standard name | HP_FACIAL_EDEMA
Systematic name | M34643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial edema
Full description |

Standard name | HP_BROAD_FACE
Systematic name | M34644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad face
Full description | Bizygomatic (upper face) and bigonial (lower face) width greater than 2 standard deviations above the mean (objective); or an apparent increase in the width of the face (subjective). [PMID:19125436]

Standard name | HP_EPICANTHUS
Systematic name | M34645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Epicanthus
Full description | A fold of skin starting above the medial aspect of the upper eyelid and arching downward to cover, pass in front of and lateral to the medial canthus. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_PHILTRUM
Systematic name | M34646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the philtrum
Full description | An abnormality of the philtrum. [HPO:probinson]

Standard name | HP_BROAD_PHILTRUM
Systematic name | M34647
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad philtrum
Full description | Distance between the philtral ridges, measured just above the vermilion border, more than 2 standard deviations above the mean, or alternatively, an apparently increased distance between the ridges of the philtrum. [PMID:19152422]

Standard name | HP_ABNORMALITY_OF_THE_FOREHEAD
Systematic name | M34648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the forehead
Full description | An anomaly of the forehead. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_FACIAL_ADIPOSE_TISSUE
Systematic name | M34649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of facial adipose tissue
Full description |

Standard name | HP_FULL_CHEEKS
Systematic name | M34650
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Full cheeks
Full description | Increased prominence or roundness of soft tissues between zygomata and mandible. [DDD:awilkie]

Standard name | HP_LOW_ANTERIOR_HAIRLINE
Systematic name | M34651
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Low anterior hairline
Full description | Distance between the hairline (trichion) and the glabella (the most prominent point on the frontal bone above the root of the nose), in the midline, more than two SD below the mean. Alternatively, an apparently decreased distance between the hairline and the glabella. [PMID:19125436]

Standard name | HP_FACIAL_HYPOTONIA
Systematic name | M34652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial hypotonia
Full description | Reduced muscle tone of a muscle that is innervated by the facial nerve (the seventh cranial nerve). [HPO:probinson]

Standard name | HP_MASK_LIKE_FACIES
Systematic name | M34653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mask-like facies
Full description | A lack of facial expression often with staring eyes and a slightly open mouth. [HPO:probinson]

Standard name | HP_OVAL_FACE
Systematic name | M34654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Oval face
Full description | A face with a rounded and slightly elongated outline. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_FACIAL_MUSCULATURE
Systematic name | M34655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of facial musculature
Full description | An anomaly of a muscle that is innervated by the facial nerve (the seventh cranial nerve). [HPO:probinson]

Standard name | HP_MANDIBULAR_PROGNATHIA
Systematic name | M34656
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mandibular prognathia
Full description | Abnormal prominence of the chin related to increased length of the mandible. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_CHIN
Systematic name | M34657
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the chin
Full description | An abnormality of the chin, i.e., of the inferior portion of the face lying inferior to the lower lip and including the central prominence of the lower jaw. [HPO:probinson, PMID:19125436]

Standard name | HP_POINTED_CHIN
Systematic name | M34658
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pointed chin
Full description | A marked tapering of the lower face to the chin. [PMID:19125436]

Standard name | HP_MICRORETROGNATHIA
Systematic name | M34659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Microretrognathia
Full description | A form of developmental hypoplasia of the mandible in which the mandible is mislocalised posteriorly. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_MIDFACE
Systematic name | M34660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the midface
Full description | An anomaly of the midface, which is a region and not an anatomical term. It extends, superiorly, from the inferior orbital margin to, inferiorly, the level of nasal base. It is formed by the maxilla (upper jaw) and zygoma and cheeks and malar region. Traditionally, the nose and premaxilla are not included in the midface. [HPO:probinson, PMID:19125436]

Standard name | HP_ROUND_FACE
Systematic name | M34661
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Round face
Full description | The facial appearance is more circular than usual as viewed from the front. [PMID:19125436]

Standard name | HP_ABNORMALITY_OF_THE_ORBITAL_REGION
Systematic name | M34662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the orbital region
Full description |

Standard name | HP_HYPERTELORISM
Systematic name | M34663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypertelorism
Full description | Interpupillary distance more than 2 SD above the mean (alternatively, the appearance of an increased interpupillary distance or widely spaced eyes). [PMID:19125427]

Standard name | HP_FACIAL_MYOKYMIA
Systematic name | M34664
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial myokymia
Full description | Facial myokymia is a fine fibrillary activity of one or more muscles innervated by the facial nerve (the seventh cranial nerve). [HPO:curators]

Standard name | HP_SMOOTH_PHILTRUM
Systematic name | M34665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Smooth philtrum
Full description | Flat skin surface, with no ridge formation in the central region of the upper lip between the nasal base and upper vermilion border. [PMID:19152422]

Standard name | HP_BIRD_LIKE_FACIES
Systematic name | M34666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bird-like facies
Full description |

Standard name | HP_SQUARE_FACE
Systematic name | M34667
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Square face
Full description | Facial contours, as viewed from the front, show a broad upper face/cranium and lower face/mandible, creating a square appearance. [PMID:19125436]

Standard name | HP_SHORT_PHILTRUM
Systematic name | M34668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short philtrum
Full description | Distance between nasal base and midline upper lip vermilion border more than 2 SD below the mean. Alternatively, an apparently decreased distance between nasal base and midline upper lip vermilion border. [PMID:19152422]

Standard name | HP_FACIAL_ASYMMETRY
Systematic name | M34669
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial asymmetry
Full description | An abnormal difference between the left and right sides of the face. [HPO:probinson]

Standard name | HP_TRIANGULAR_FACE
Systematic name | M34670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Triangular face
Full description | Facial contour, as viewed from the front, triangular in shape, with breadth at the temples and tapering to a narrow chin. [DDD:jclayton-smith, PMID:19125436]

Standard name | HP_ABNORMALITY_OF_THE_MAXILLA
Systematic name | M34671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the maxilla
Full description | An abnormality of the Maxilla (upper jaw bone). [HPO:probinson]

Standard name | HP_FACIAL_HEMANGIOMA
Systematic name | M34672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial hemangioma
Full description | Hemangioma, a benign tumor of the vascular endothelial cells, occurring in the face. [HPO:curators]

Standard name | HP_SHORT_CHIN
Systematic name | M34673
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short chin
Full description | Decreased vertical distance from the vermilion border of the lower lip to the inferior-most point of the chin. [HPO:probinson, PMID:19125436]

Standard name | HP_PROMINENT_SUPRAORBITAL_RIDGES
Systematic name | M34674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Prominent supraorbital ridges
Full description | Greater than average forward and/or lateral protrusion of the supraorbital portion of the frontal bones. [PMID:19125436]

Standard name | HP_BROAD_FOREHEAD
Systematic name | M34675
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad forehead
Full description | Width of the forehead or distance between the frontotemporales is more than two standard deviations above the mean (objective); or apparently increased distance between the two sides of the forehead. [PMID:19125436]

Standard name | HP_HYPOMIMIC_FACE
Systematic name | M34676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypomimic face
Full description | A reduced degree of motion of the muscles beneath the skin of the face, often associated with reduced facial crease formation. [HPO:probinson]

Standard name | HP_SLOPING_FOREHEAD
Systematic name | M34677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sloping forehead
Full description | Inclination of the anterior surface of the forehead from the vertical more than two standard deviations above the mean (objective); or apparently excessive posterior sloping of the forehead in a lateral view. [PMID:19125436]

Standard name | HP_NARROW_FOREHEAD
Systematic name | M34678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Narrow forehead
Full description | Width of the forehead or distance between the frontotemporales is more than two standard deviations below the mean (objective); or apparently narrow intertemporal region (subjective). [PMID:19125436]

Standard name | HP_LONG_PHILTRUM
Systematic name | M34679
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Long philtrum
Full description | Distance between nasal base and midline upper lip vermilion border more than 2 SD above the mean. Alternatively, an apparently increased distance between nasal base and midline upper lip vermilion border. [PMID:19152422]

Standard name | HP_HIGH_FOREHEAD
Systematic name | M34680
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | High forehead
Full description | An abnormally increased height of the forehead. [HPO:probinson]

Standard name | HP_WIDOW_S_PEAK
Systematic name | M34681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Widow's peak
Full description | Frontal hairline with bilateral arcs to a low point in the midline of the forehead. [PMID:19125436]

Standard name | HP_SMALL_FOREHEAD
Systematic name | M34682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Small forehead
Full description | The presence of a forehead that is abnormally small. [HPO:curators]

Standard name | HP_ABNORMALITY_OF_THE_OUTER_EAR
Systematic name | M34683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the outer ear
Full description | An abnormality of the external ear. [HPO:probinson]

Standard name | HP_ABNORMAL_LOCATION_OF_EARS
Systematic name | M34684
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal location of ears
Full description | Abnormal location of the ear. [HPO:probinson]

Standard name | HP_POSTERIORLY_ROTATED_EARS
Systematic name | M34685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Posteriorly rotated ears
Full description | A type of abnormal location of the ears in which the position of the ears is characterized by posterior rotation (the superior part of the ears is rotated towards the back of the head, and the inferior part of the ears towards the front). [HPO:probinson, PMID:19152421]

Standard name | HP_ABNORMALITY_OF_THE_INNER_EAR
Systematic name | M34686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the inner ear
Full description | An abnormality of the inner ear. [HPO:probinson]

Standard name | HP_TINNITUS
Systematic name | M34687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tinnitus
Full description | Tinnitus is an auditory perception that can be described as the experience of sound, in the ear or in the head, in the absence of external acoustic stimulation. [Cochrane:ab005233]

Standard name | HP_OTOSCLEROSIS
Systematic name | M34688
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Otosclerosis
Full description | In otosclerosis, a callus of bone accumulates on the stapes creating a partial fixation. This limits the movement of the stapes bone, which results in hearing loss. [HPO:probinson, PMID:15931303]

Standard name | HP_ABNORMALITY_OF_EARLOBE
Systematic name | M34689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of earlobe
Full description | An abnormality of the lobule of pinna. [HPO:probinson]

Standard name | HP_LOW_SET_POSTERIORLY_ROTATED_EARS
Systematic name | M34690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Low-set, posteriorly rotated ears
Full description | Ears that are low-set (HP:0000369) and posteriorly rotated (HP:0000358). [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_MIDDLE_EAR
Systematic name | M34691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the middle ear
Full description | An abnormality of the middle ear. [HPO:probinson]

Standard name | HP_ACUTE_OTITIS_MEDIA
Systematic name | M34692
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Acute otitis media
Full description | Acute otitis media is a short and generally painful infection of the middle ear. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_AUDITORY_CANAL
Systematic name | M34693
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the auditory canal
Full description | An abnormality of the External acoustic tube (also known as the auditory canal). [HPO:probinson]

Standard name | HP_ABNORMAL_COCHLEA_MORPHOLOGY
Systematic name | M34694
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal cochlea morphology
Full description | An abnormality of the cochlea. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_PINNA
Systematic name | M34695
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the pinna
Full description | An abnormality of the pinna, which is also referred to as the auricle or external ear. [HPO:probinson]

Standard name | HP_CUPPED_EAR
Systematic name | M34696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cupped ear
Full description | Laterally protruding ear that lacks antihelical folding (including absence of inferior and superior crura). [HPO:probinson, PMID:19162421, PMID:22073081]

Standard name | HP_ABNORMALITY_OF_PERIAURICULAR_REGION
Systematic name | M34697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of periauricular region
Full description |

Standard name | HP_PREAURICULAR_SKIN_TAG
Systematic name | M34698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Preauricular skin tag
Full description | A rudimentary tag of skin often containing ear tissue including a core of cartilage and located just anterior to the auricle (outer part of the ear). [HPO:probinson]

Standard name | HP_SMALL_EARLOBE
Systematic name | M34699
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Small earlobe
Full description | Reduced volume of the earlobe. [HPO:probinson, PMID:19152421]

Standard name | HP_ABSENT_EARLOBE
Systematic name | M34700
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Absent earlobe
Full description | Absence of fleshy non-cartilaginous tissue inferior to the tragus and incisura. [HPO:probinson, PMID:19152421]

Standard name | HP_OTITIS_MEDIA
Systematic name | M34701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Otitis media
Full description | Inflammation or infection of the middle ear. [HPO:probinson]

Standard name | HP_CHRONIC_OTITIS_MEDIA
Systematic name | M34702
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Chronic otitis media
Full description | Chronic otitis media refers to fluid, swelling, or infection of the middle ear that does not heal and may cause permanent damage to the ear. [HPO:probinson]

Standard name | HP_THICKENED_HELICES
Systematic name | M34703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thickened helices
Full description | Increased thickness of the helix of the ear. [HPO:probinson]

Standard name | HP_LOP_EAR
Systematic name | M34704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lop ear
Full description | Anterior and inferior folding of the upper portion of the ear that obliterates triangular fossa and scapha. [HPO:probinson, PMID:19152421]

Standard name | HP_PROMINENT_ANTIHELIX
Systematic name | M34705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Prominent antihelix
Full description | The presence of an abnormally prominent antihelix. [HPO:probinson]

Standard name | HP_PRELINGUAL_SENSORINEURAL_HEARING_IMPAIRMENT
Systematic name | M34706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Prelingual sensorineural hearing impairment
Full description | A form of sensorineural deafness with either congenital onset or infantile onset, i.e., before the acquisition of speech. [HPO:probinson]

Standard name | HP_MACROTIA
Systematic name | M34707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Macrotia
Full description | Median longitudinal ear length greater than two standard deviations above the mean and median ear width greater than two standard deviations above the mean (objective); or, apparent increase in length and width of the pinna (subjective). [PMID:19152421]

Standard name | HP_STENOSIS_OF_THE_EXTERNAL_AUDITORY_CANAL
Systematic name | M34708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Stenosis of the external auditory canal
Full description | An abnormal narrowing of the external auditory canal. [HPO:probinson]

Standard name | HP_RECURRENT_OTITIS_MEDIA
Systematic name | M34709
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Recurrent otitis media
Full description | Increased susceptibility to otitis media, as manifested by recurrent episodes of otitis media. [HPO:probinson]

Standard name | HP_PROGRESSIVE_SENSORINEURAL_HEARING_IMPAIRMENT
Systematic name | M34710
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Progressive sensorineural hearing impairment
Full description | A progressive form of sensorineural hearing impairment. [HPO:probinson]

Standard name | HP_MIXED_HEARING_IMPAIRMENT
Systematic name | M34711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mixed hearing impairment
Full description | A type of hearing loss resulting from a combination of conductive hearing impairment and sensorineural hearing impairment. [HPO:probinson]

Standard name | HP_PROTRUDING_EAR
Systematic name | M34712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Protruding ear
Full description | Angle formed by the plane of the ear and the mastoid bone greater than the 97th centile for age (objective); or, outer edge of the helix more than 2 cm from the mastoid at the point of maximum distance (objective). [PMID:19152421]

Standard name | HP_ATRESIA_OF_THE_EXTERNAL_AUDITORY_CANAL
Systematic name | M34713
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Atresia of the external auditory canal
Full description | Absence or failure to form of the external auditory canal. [HPO:probinson]

Standard name | HP_BULBOUS_NOSE
Systematic name | M34714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bulbous nose
Full description | Increased volume and globular shape of the anteroinferior aspect of the nose. [PMID:19152422]

Standard name | HP_ABNORMALITY_OF_THE_CHOANAE
Systematic name | M34715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the choanae
Full description | Abnormality of the choanae (the posterior nasal apertures). [HPO:curators]

Standard name | HP_NARROW_NASAL_RIDGE
Systematic name | M34716
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Narrow nasal ridge
Full description | Decreased width of the nasal ridge. [PMID:19152422]

Standard name | HP_ABNORMALITY_OF_THE_NASAL_SEPTUM
Systematic name | M34717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the nasal septum
Full description | An abnormality of the nasal septum. [HPO:probinson]

Standard name | HP_EPISTAXIS
Systematic name | M34718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Epistaxis
Full description | Epistaxis, or nosebleed, refers to a hemorrhage localized in the nose. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_NASAL_BRIDGE
Systematic name | M34719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the nasal bridge
Full description | Abnormality of the nasal bridge, which is the saddle-shaped area that includes the nasal root and the lateral aspects of the nose. It lies between the glabella and the inferior boundary of the nasal bone, and extends laterally to the inner canthi. [HPO:probinson, PMID:19152422]

Standard name | HP_PROMINENT_NASAL_BRIDGE
Systematic name | M34720
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Prominent nasal bridge
Full description | Anterior positioning of the nasal root in comparison to the usual positioning for age. [PMID:19152422]

Standard name | HP_ABNORMALITY_OF_THE_NASAL_ALAE
Systematic name | M34721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the nasal alae
Full description | An abnormality of the Ala of nose. [HPO:probinson, PMID:19152422]

Standard name | HP_UNDERDEVELOPED_NASAL_ALAE
Systematic name | M34722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Underdeveloped nasal alae
Full description | Thinned, deficient, or excessively arched ala nasi. [PMID:19152422]

Standard name | HP_WIDE_NASAL_BRIDGE
Systematic name | M34723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Wide nasal bridge
Full description | Increased breadth of the nasal bridge (and with it, the nasal root). [HPO:probinson, PMID:19152422]

Standard name | HP_ABNORMALITY_OF_THE_NASAL_MUCOSA
Systematic name | M34724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the nasal mucosa
Full description |

Standard name | HP_ABNORMALITY_OF_THE_NASAL_TIP
Systematic name | M34725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the nasal tip
Full description | An abnormality of the nasal tip. [HPO:probinson, PMID:19152422]

Standard name | HP_DEPRESSED_NASAL_TIP
Systematic name | M34726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Depressed nasal tip
Full description | Decreased distance from the nasal tip to the nasal base. [PMID:19152422]

Standard name | HP_CONVEX_NASAL_RIDGE
Systematic name | M34727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Convex nasal ridge
Full description | Nasal ridge curving anteriorly to an imaginary line that connects the nasal root and tip. The nose appears often also prominent, and the columella low. [PMID:19152422]

Standard name | HP_WIDE_NOSE
Systematic name | M34728
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Wide nose
Full description | Interalar distance more than two standard deviations above the mean for age, i.e., an apparently increased width of the nasal base and alae. [PMID:19152422]

Standard name | HP_NARROW_NASAL_BRIDGE
Systematic name | M34729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Narrow nasal bridge
Full description | Decreased width of the bony bridge of the nose. [PMID:19152422]

Standard name | HP_PROMINENT_NOSE
Systematic name | M34730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Prominent nose
Full description | Distance between subnasale and pronasale more than two standard deviations above the mean, or alternatively, an apparently increased anterior protrusion of the nasal tip. [PMID:19152422]

Standard name | HP_CHOANAL_STENOSIS
Systematic name | M34731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Choanal stenosis
Full description | Abnormal narrowing of the choana (the posterior nasal aperture). [HPO:probinson]

Standard name | HP_FLARED_NOSTRILS
Systematic name | M34732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Flared nostrils
Full description |

Standard name | HP_BROAD_NASAL_TIP
Systematic name | M34733
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad nasal tip
Full description | Increase in width of the nasal tip. [HPO:probinson, PMID:19152422]

Standard name | HP_BIFID_NASAL_TIP
Systematic name | M34734
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bifid nasal tip
Full description | A splitting of the nasal tip. Visually assessable vertical indentation, cleft, or depression of the nasal tip. [HPO:sdoelken, PMID:19152422]

Standard name | HP_DEPRESSED_NASAL_RIDGE
Systematic name | M34735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Depressed nasal ridge
Full description | Lack of prominence of the nose resulting from a posteriorly-placed nasal ridge. [HPO:probinson, PMID:19152422]

Standard name | HP_ANOSMIA
Systematic name | M34736
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anosmia
Full description | An inability to perceive odors. This is a general term describing inability to smell arising in any part of the process of smelling from absorption of odorants into the nasal mucous overlying the olfactory epithelium, diffusion to the cilia, binding to olfactory receptor sites, generation of action potentials in olfactory neurons, and perception of a smell. [HPO:probinson]

Standard name | HP_NARROW_NOSE
Systematic name | M34737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Narrow nose
Full description | Interalar distance more than 2 SD below the mean for age, or alternatively, an apparently decreased width of the nasal base and alae. [PMID:19152422]

Standard name | HP_ABNORMALITY_OF_THE_NECK
Systematic name | M34738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the neck
Full description | An abnormality of the neck. [HPO:probinson]

Standard name | HP_WEBBED_NECK
Systematic name | M34739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Webbed neck
Full description | Pterygium colli is a congenital skin fold that runs along the sides of the neck down to the shoulders. It involves an ectopic fibrotic facial band superficial to the trapezius muscle. Excess hair-bearing skin is also present and extends down the cervical region well beyond the normal hairline. [HPO:probinson, PMID:24523736]

Standard name | HP_LIMITED_NECK_RANGE_OF_MOTION
Systematic name | M34740
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Limited neck range of motion
Full description |

Standard name | HP_NECK_MUSCLE_WEAKNESS
Systematic name | M34741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neck muscle weakness
Full description | Decreased strength of the neck musculature. [HPO:probinson]

Standard name | HP_LONG_NECK
Systematic name | M34742
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Long neck
Full description | Increased inferior-superior length of the neck. [HPO:probinson]

Standard name | HP_THICKENED_NUCHAL_SKIN_FOLD
Systematic name | M34743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thickened nuchal skin fold
Full description | A thickening of the skin thickness in the posterior aspect of the fetal neck. A nuchal fold measurement is obtained in a transverse section of the fetal head at the level of the cavum septum pellucidum and thalami, angled posteriorly to include the cerebellum. The measurement is taken from the outer edge of the occiput bone to the outer skin limit directly in the midline. A measurement 6 mm or more is considered significant between 18 and 24 weeks and a measurement of 5 mm or more is considered significant at 16 to 18 weeks (PMID:16100637). [HPO:probinson, PMID:16100637]

Standard name | HP_BROAD_NECK
Systematic name | M34744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad neck
Full description | Increased side-to-side width of the neck. [HPO:probinson]

Standard name | HP_CYSTIC_HYGROMA
Systematic name | M34745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cystic hygroma
Full description | A cystic lymphatic lesion of the neck. [HPO:probinson]

Standard name | HP_ABNORMAL_RETINAL_MORPHOLOGY
Systematic name | M34746
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal retinal morphology
Full description | A structural abnormality of the retina. [HPO:probinson]

Standard name | HP_RETINAL_COLOBOMA
Systematic name | M34747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retinal coloboma
Full description | A notch or cleft of the retina. [HPO:probinson]

Standard name | HP_ABNORMAL_CORNEA_MORPHOLOGY
Systematic name | M34748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal cornea morphology
Full description | Any abnormality of the cornea, which is the transparent tissue at the front of the eye that covers the iris, pupil, and anterior chamber. [HPO:probinson]

Standard name | HP_MICROCORNEA
Systematic name | M34749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Microcornea
Full description | A congenital abnormality of the cornea in which the cornea and the anterior segment of the eye are smaller than normal. The horizontal diameter of the cornea does not reach 10 mm even in adulthood. [HPO:probinson]

Standard name | HP_ASTIGMATISM
Systematic name | M34750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Astigmatism
Full description | A type of astigmatism associated with abnormal curvatures on the anterior and/or posterior surface of the cornea. [DDD:ncarter, HPO:probinson, ORCID:0000-0003-0986-4123]

Standard name | HP_MEGALOCORNEA
Systematic name | M34751
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Megalocornea
Full description | An enlargement of the cornea with normal clarity and function. Megalocornea is diagnosed with a horizontal corneal diameter of 12 mm or more at birth or 13 mm or more after two years of age. [HPO:curators]

Standard name | HP_RETINOPATHY
Systematic name | M34752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retinopathy
Full description | Any noninflammatory disease of the retina. This nonspecific term is retained here because of its wide use in the literature, but if possible new annotations should indicate the precise type of retinal abnormality. [HPO:probinson]

Standard name | HP_DEEPLY_SET_EYE
Systematic name | M34753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Deeply set eye
Full description | An eye that is more deeply recessed into the plane of the face than is typical. [PMID:19125427]

Standard name | HP_KERATITIS
Systematic name | M34754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Keratitis
Full description | Inflammation of the cornea. [HPO:curators]

Standard name | HP_ABNORMAL_EYELID_MORPHOLOGY
Systematic name | M34755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal eyelid morphology
Full description | An abnormality of the eyelids. [HPO:probinson]

Standard name | HP_ABNORMAL_FOVEAL_MORPHOLOGY
Systematic name | M34756
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal foveal morphology
Full description | An abnormality of the fovea centralis, the central area of the macula that mediates central, high resolution vision and contains the largest concentration of cone cells in the retina. [HPO:probinson]

Standard name | HP_DOWNSLANTED_PALPEBRAL_FISSURES
Systematic name | M34757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Downslanted palpebral fissures
Full description | The palpebral fissure inclination is more than two standard deviations below the mean. [PMID:19125427]

Standard name | HP_RECURRENT_CORNEAL_EROSIONS
Systematic name | M34758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Recurrent corneal erosions
Full description | The presence of recurrent corneal epithelial erosions. Although most corneal epithelial defects heal quickly, some may show recurrent ulcerations. [HPO:curators]

Standard name | HP_BLEPHARITIS
Systematic name | M34759
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Blepharitis
Full description | Inflammation of the eyelids. [HPO:probinson]

Standard name | HP_ABNORMAL_EYELASH_MORPHOLOGY
Systematic name | M34760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal eyelash morphology
Full description | An abnormality of the eyelashes. [HPO:probinson]

Standard name | HP_GLAUCOMA
Systematic name | M34761
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Glaucoma
Full description | Glaucoma refers loss of retinal ganglion cells in a characteristic pattern of optic neuropathy usually associated with increased intraocular pressure. [HPO:probinson, PMID:11815354]

Standard name | HP_ABNORMAL_CONJUNCTIVA_MORPHOLOGY
Systematic name | M34762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal conjunctiva morphology
Full description | An abnormality of the conjunctiva. [HPO:curators]

Standard name | HP_ABNORMALITY_OF_VISION
Systematic name | M34763
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of vision
Full description | Abnormality of eyesight (visual perception). [HPO:probinson]

Standard name | HP_VISUAL_IMPAIRMENT
Systematic name | M34764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Visual impairment
Full description | Visual impairment (or vision impairment) is vision loss (of a person) to such a degree as to qualify as an additional support need through a significant limitation of visual capability resulting from either disease, trauma, or congenital or degenerative conditions that cannot be corrected by conventional means, such as refractive correction, medication, or surgery. [DDD:gblack]

Standard name | HP_TELECANTHUS
Systematic name | M34765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Telecanthus
Full description | Distance between the inner canthi more than two standard deviations above the mean (objective); or, apparently increased distance between the inner canthi. [HPO:probinson]

Standard name | HP_PTOSIS
Systematic name | M34766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ptosis
Full description | The upper eyelid margin is positioned 3 mm or more lower than usual and covers the superior portion of the iris (objective); or, the upper lid margin obscures at least part of the pupil (subjective). [PMID:19125427]

Standard name | HP_ROD_CONE_DYSTROPHY
Systematic name | M34767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Rod-cone dystrophy
Full description | An inherited retinal disease subtype in which the rod photoreceptors appear to be more severely affected than the cone photoreceptors. Typical presentation is with nyctalopia (due to rod dysfunction) followed by loss of mid-peripheral field of vision, which gradually extends and leaves many patients with a small central island of vision due to the preservation of macular cones. [HPO:probinson, PMID:20212494]

Standard name | HP_VERTICAL_SUPRANUCLEAR_GAZE_PALSY
Systematic name | M34768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Vertical supranuclear gaze palsy
Full description | A supranuclear gaze palsy is an inability to look in a vertical direction as a result of cerebral impairment. There is a loss of the voluntary aspect of eye movements, but, as the brainstem is still intact, all the reflex conjugate eye movements are normal. [HPO:probinson, PMID:20671861]

Standard name | HP_ABNORMAL_ELECTRORETINOGRAM
Systematic name | M34769
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal electroretinogram
Full description | Any abnormality of the electrical responses of various cell types in the retina as measured by electroretinography. [HPO:probinson]

Standard name | HP_SLOW_SACCADIC_EYE_MOVEMENTS
Systematic name | M34770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Slow saccadic eye movements
Full description | An abnormally slow velocity of the saccadic eye movements. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_LENS
Systematic name | M34771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the lens
Full description | An abnormality of the lens. [HPO:probinson]

Standard name | HP_DEVELOPMENTAL_CATARACT
Systematic name | M34772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Developmental cataract
Full description | A cataract that occurs congenitally as the result of a developmental defect, in contrast to the majority of cataracts that occur in adulthood as the result of degenerative changes of the lens. [HPO:probinson]

Standard name | HP_PROPTOSIS
Systematic name | M34773
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Proptosis
Full description | An eye that is protruding anterior to the plane of the face to a greater extent than is typical. [HPO:sdoelken, PMID:19125427]

Standard name | HP_ALACRIMA
Systematic name | M34774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Alacrima
Full description | Absence of tear secretion. [HPO:probinson]

Standard name | HP_SUBCAPSULAR_CATARACT
Systematic name | M34775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Subcapsular cataract
Full description | A cataract that affects the region of the lens directly beneath the capsule of the lens. [HPO:probinson]

Standard name | HP_ABNORMALITY_IRIS_MORPHOLOGY
Systematic name | M34776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality iris morphology
Full description | An abnormality of the iris, which is the pigmented muscular tissue between the cornea and the lens, that is perforated by an opening called the pupil. [HPO:probinson]

Standard name | HP_ANIRIDIA
Systematic name | M34777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aniridia
Full description | Abnormality of the iris characterized by, typically bilateral, complete or partial iris hypoplasia. The phenotype ranges from mild defects of anterior iris stroma only to almost complete absence of the iris. [HPO:probinson, PMID:24138039, PMID:25313118, PMID:29850208, UManchester:psergouniotis]

Standard name | HP_LONG_EYELASHES
Systematic name | M34778
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Long eyelashes
Full description | Mid upper eyelash length >10 mm or increased length of the eyelashes (subjective). [PMID:19125427, PMID:26288407]

Standard name | HP_ANOPHTHALMIA
Systematic name | M34779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anophthalmia
Full description | Absence of the globe or eyeball. [DDD:ncarter]

Standard name | HP_PROGRESSIVE_VISUAL_LOSS
Systematic name | M34780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Progressive visual loss
Full description | A reduction of previously attained ability to see. [HPO:probinson]

Standard name | HP_ABNORMAL_CHORIORETINAL_MORPHOLOGY
Systematic name | M34781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal chorioretinal morphology
Full description | An abnormality of the choroid and retina. [HPO:probinson]

Standard name | HP_CHORIORETINAL_ATROPHY
Systematic name | M34782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Chorioretinal atrophy
Full description | Atrophy of the choroid and retinal layers of the fundus. [HPO:probinson, PMID:20224472]

Standard name | HP_ABNORMAL_EYEBROW_MORPHOLOGY
Systematic name | M34783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal eyebrow morphology
Full description | An abnormality of the eyebrow. [HPO:probinson]

Standard name | HP_EPICANTHUS_INVERSUS
Systematic name | M34784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Epicanthus inversus
Full description | A fold of skin starting at or just below the medial aspect of the lower lid and arching upward to cover, extend in front of and lateral to the medial canthus. [PMID:19125427]

Standard name | HP_ABNORMALITY_OF_REFRACTION
Systematic name | M34785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of refraction
Full description | An abnormality in the process of focusing of light by the eye in order to produce a sharp image on the retina. [HPO:probinson]

Standard name | HP_HYPERMETROPIA
Systematic name | M34786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypermetropia
Full description | An abnormality of refraction characterized by the ability to see objects in the distance clearly, while objects nearby appear blurry. [HPO:probinson]

Standard name | HP_RETINAL_DETACHMENT
Systematic name | M34787
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retinal detachment
Full description | Separation of the inner layers of the retina (neural retina) from the pigment epithelium. [HPO:probinson]

Standard name | HP_OPTIC_DISC_PALLOR
Systematic name | M34788
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Optic disc pallor
Full description | A pale yellow discoloration of the optic disk (the area of the optic nerve head in the retina). The optic disc normally has a pinkish hue with a central yellowish depression. [HPO:probinson]

Standard name | HP_EXTERNAL_OPHTHALMOPLEGIA
Systematic name | M34789
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | External ophthalmoplegia
Full description | Paralysis of the external ocular muscles. [HPO:probinson]

Standard name | HP_MYOPIA
Systematic name | M34790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Myopia
Full description | An abnormality of refraction characterized by the ability to see objects nearby clearly, while objects in the distance appear blurry. [HPO:probinson]

Standard name | HP_RETINAL_DEGENERATION
Systematic name | M34791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retinal degeneration
Full description | A nonspecific term denoting degeneration of the retinal pigment epithelium and/or retinal photoreceptor cells. [HPO:probinson, ORCID:0000-0003-0986-4123]

Standard name | HP_CONE_CONE_ROD_DYSTROPHY
Systematic name | M34792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cone/cone-rod dystrophy
Full description |

Standard name | HP_ABNORMAL_CONJUGATE_EYE_MOVEMENT
Systematic name | M34793
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal conjugate eye movement
Full description | Any deviation from the normal motor coordination of the eyes that allows for bilateral fixation on a single object. [HPO:probinson]

Standard name | HP_UNDETECTABLE_ELECTRORETINOGRAM
Systematic name | M34794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Undetectable electroretinogram
Full description | Lack of any response to stimulation upon electroretinography. [HPO:probinson]

Standard name | HP_COLOR_VISION_DEFECT
Systematic name | M34795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Color vision defect
Full description | An anomaly in the ability to discriminate between or recognize colors. [HPO:probinson]

Standard name | HP_TRITANOMALY
Systematic name | M34796
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tritanomaly
Full description | Difficulty distinguishing between yellow and blue, possible related to dysfunction of the S photopigment. [HPO:probinson]

Standard name | HP_ABNORMAL_UVEA_MORPHOLOGY
Systematic name | M34797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal uvea morphology
Full description | An abnormality of the uvea, the vascular layer of the eyeball. [HPO:probinson]

Standard name | HP_UVEITIS
Systematic name | M34798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Uveitis
Full description | Inflammation of one or all portions of the uveal tract. [HPO:curators]

Standard name | HP_RETINAL_DYSTROPHY
Systematic name | M34799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retinal dystrophy
Full description | Retinal dystrophy is an abnormality of the retina associated with a hereditary process. Retinal dystrophies are defined by their predominantly monogenic inheritance and they are frequently associated with loss or dysfunction of photoreceptor cells as a primary or secondary event. [ORCID:0000-0003-0986-4123]

Standard name | HP_BUPHTHALMOS
Systematic name | M34800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Buphthalmos
Full description | Diffusely large eye (with megalocornea) associated with glaucoma. []

Standard name | HP_RIEGER_ANOMALY
Systematic name | M34801
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Rieger anomaly
Full description | A congenital malformation of the anterior segment characterized by iridicorneal malformation, glaucoma, iris stroma hypoplasia, posterior embryotoxon, and corneal opacities. [HPO:probinson]

Standard name | HP_CORNEAL_SCARRING
Systematic name | M34802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Corneal scarring
Full description |

Standard name | HP_CHORIORETINAL_COLOBOMA
Systematic name | M34803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Chorioretinal coloboma
Full description | Absence of a region of the retina, retinal pigment epithelium, and choroid. [HPO:probinson]

Standard name | HP_ABNORMAL_SACCADIC_EYE_MOVEMENTS
Systematic name | M34804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal saccadic eye movements
Full description | An abnormality of eye movement characterized by impairment of fast (saccadic) eye movements. [HPO:probinson]

Standard name | HP_HYPOMETRIC_SACCADES
Systematic name | M34805
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypometric saccades
Full description | Saccadic undershoot, i.e., a saccadic eye movement that has less than the magnitude that would be required to gain fixation of the object. [HPO:probinson, PMID:572501]

Standard name | HP_VISUAL_LOSS
Systematic name | M34806
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Visual loss
Full description | Loss of visual acuity (implying that vision was better at a certain timepoint in life). Otherwise the term reduced visual acuity should be used (or a subclass of that). [HPO:sdoelken]

Standard name | HP_RETINAL_HEMORRHAGE
Systematic name | M34807
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retinal hemorrhage
Full description | Hemorrhage occurring within the retina. [HPO:gcarletti]

Standard name | HP_THICK_EYEBROW
Systematic name | M34808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thick eyebrow
Full description | Increased density/number and/or increased diameter of eyebrow hairs. [PMID:19125427]

Standard name | HP_SCOTOMA
Systematic name | M34809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Scotoma
Full description | A regional and pathological increase of the light detection threshold in any region of the visual field surrounded by a field of normal or relatively well-preserved vision. [HPO:probinson]

Standard name | HP_CENTROCECAL_SCOTOMA
Systematic name | M34810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Centrocecal scotoma
Full description | A scotoma (area of diminished vision within the visual field) located between the central point of fixation and the blind spot with a roughly horizontal oval shape. [HPO:probinson]

Standard name | HP_NASOLACRIMAL_DUCT_OBSTRUCTION
Systematic name | M34811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nasolacrimal duct obstruction
Full description | Blockage of the lacrimal duct. [HPO:probinson]

Standard name | HP_PIGMENTARY_RETINOPATHY
Systematic name | M34812
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pigmentary retinopathy
Full description | An abnormality of the retina characterized by pigment deposition. It is typically associated with migration and proliferation of macrophages or retinal pigment epithelial cells into the retina; melanin from these cells causes the pigmentary changes. Pigmentary retinopathy is a common final pathway of many retinal conditions and is often associated with visual loss. [ORCID:0000-0003-0986-4123]

Standard name | HP_BLEPHAROPHIMOSIS
Systematic name | M34813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Blepharophimosis
Full description | A fixed reduction in the vertical distance between the upper and lower eyelids with short palpebral fissures. [PMID:19125427]

Standard name | HP_UPSLANTED_PALPEBRAL_FISSURE
Systematic name | M34814
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Upslanted palpebral fissure
Full description | The palpebral fissure inclination is more than two standard deviations above the mean for age (objective); or, the inclination of the palpebral fissure is greater than typical for age. [PMID:19125427]

Standard name | HP_BAND_KERATOPATHY
Systematic name | M34815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Band keratopathy
Full description | An abnormality of the cornea characterized by the deposition of calcium in a band across the central cornea, leading to decreased vision, foreign body sensation, and ocular irritation. [HPO:probinson]

Standard name | HP_SHALLOW_ORBITS
Systematic name | M34816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Shallow orbits
Full description | Reduced depth of the orbits associated with prominent-appearing ocular globes. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_OPTIC_NERVE
Systematic name | M34817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the optic nerve
Full description | Abnormality of the optic nerve. [HPO:probinson]

Standard name | HP_OPTIC_NERVE_COLOBOMA
Systematic name | M34818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Optic nerve coloboma
Full description | A cleft of the optic nerve that extends inferiorly. [HPO:probinson, PMID:16219745]

Standard name | HP_COLOBOMA
Systematic name | M34819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Coloboma
Full description | A developmental defect characterized by a cleft of some portion of the eye or ocular adnexa. [HPO:probinson]

Standard name | HP_PROGRESSIVE_EXTERNAL_OPHTHALMOPLEGIA
Systematic name | M34820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Progressive external ophthalmoplegia
Full description | Initial bilateral ptosis followed by limitation of eye movements in all directions and slowing of saccades. [HPO:probinson]

Standard name | HP_ABNORMAL_SCLERA_MORPHOLOGY
Systematic name | M34821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal sclera morphology
Full description | An abnormality of the sclera. [HPO:probinson]

Standard name | HP_BLUE_SCLERAE
Systematic name | M34822
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Blue sclerae
Full description | An abnormal bluish coloration of the sclera. [HPO:probinson]

Standard name | HP_ABNORMAL_ANTERIOR_CHAMBER_MORPHOLOGY
Systematic name | M34823
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal anterior chamber morphology
Full description | Abnormality of the anterior chamber, which is the space in the eye that is behind the cornea and in front of the iris. [HPO:probinson]

Standard name | HP_SHALLOW_ANTERIOR_CHAMBER
Systematic name | M34824
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Shallow anterior chamber
Full description | Reduced depth of the anterior chamber, i.e., the anteroposterior distance between the cornea and the iris is decreased. [HPO:probinson]

Standard name | HP_OPHTHALMOPARESIS
Systematic name | M34825
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ophthalmoparesis
Full description | Ophthalmoplegia is a paralysis or weakness of one or more of the muscles that control eye movement. [HPO:curators]

Standard name | HP_ABNORMALITY_OF_THE_FRONTAL_HAIRLINE
Systematic name | M34826
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the frontal hairline
Full description | An anomaly in the placement or shape of the hairline (trichion) on the forehead, that is, the border between skin on the forehead that has head hair and that does not. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_PHARYNX
Systematic name | M34827
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the pharynx
Full description | An anomaly of the pharynx, i.e., of the tubular structure extending from the base of the skull superiorly to the esophageal inlet inferiorly. [HPO:probinson]

Standard name | HP_HYPOTELORISM
Systematic name | M34828
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypotelorism
Full description | Interpupillary distance less than 2 SD below the mean (alternatively, the appearance of an decreased interpupillary distance or closely spaced eyes). [HPO:probinson, PMID:19125427]

Standard name | HP_CENTRAL_SCOTOMA
Systematic name | M34829
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Central scotoma
Full description | An area of depressed vision located at the point of fixation and that interferes with central vision. [HPO:probinson]

Standard name | HP_SUPRANUCLEAR_GAZE_PALSY
Systematic name | M34830
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Supranuclear gaze palsy
Full description | A supranuclear gaze palsy is an inability to look in a particular direction as a result of cerebral impairment. There is a loss of the voluntary aspect of eye movements, but, as the brainstem is still intact, all the reflex conjugate eye movements are normal. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_PERIORBITAL_REGION
Systematic name | M34831
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the periorbital region
Full description | An abnormality of the region situated around the orbit of the eye. [HPO:probinson]

Standard name | HP_MACULAR_DEGENERATION
Systematic name | M34832
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Macular degeneration
Full description | A nonspecific term denoting degeneration of the retinal pigment epithelium and/or retinal photoreceptor cells of the macula lutea. [HPO:probinson, ORCID:0000-0003-0986-4123]

Standard name | HP_OPTIC_NERVE_HYPOPLASIA
Systematic name | M34833
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Optic nerve hypoplasia
Full description | Underdevelopment of the optic nerve. [HPO:probinson]

Standard name | HP_ABNORMAL_CHOROID_MORPHOLOGY
Systematic name | M34834
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal choroid morphology
Full description | Any structural abnormality of the choroid. [HPO:probinson]

Standard name | HP_IRIS_COLOBOMA
Systematic name | M34835
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Iris coloboma
Full description | A coloboma of the iris. [HPO:probinson, PMID:19369671]

Standard name | HP_PHOTOPHOBIA
Systematic name | M34836
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Photophobia
Full description | Excessive sensitivity to light with the sensation of discomfort or pain in the eyes due to exposure to bright light. [HPO:probinson]

Standard name | HP_ABNORMAL_NASOLACRIMAL_SYSTEM_MORPHOLOGY
Systematic name | M34837
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal nasolacrimal system morphology
Full description | An abnormality of the nasolacrimal drainage system, which serves as a conduit for tear flow from the external eye to the nasal cavity. [DDD:ncarter]

Standard name | HP_ABNORMAL_PUPIL_MORPHOLOGY
Systematic name | M34838
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal pupil morphology
Full description | An abnormality of the pupil. [HPO:probinson]

Standard name | HP_MIOSIS
Systematic name | M34839
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Miosis
Full description | Abnormal (non-physiological) constriction of the pupil. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_OCULAR_SMOOTH_PURSUIT
Systematic name | M34840
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of ocular smooth pursuit
Full description | An abnormality of eye movement characterized by impaired smooth-pursuit eye movements. [HPO:probinson]

Standard name | HP_BLINDNESS
Systematic name | M34841
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Blindness
Full description | Blindness is the condition of lacking visual perception defined as visual perception below 3/60 and/or a visual field of no greater than 10 degress in radius around central fixation. [DDD:gblack, PMID:28779882]

Standard name | HP_DACRYOCYSTITIS
Systematic name | M34842
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dacryocystitis
Full description | Inflammation of the nasolacrimal sac. [HPO:probinson]

Standard name | HP_ENTROPION
Systematic name | M34843
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Entropion
Full description | An abnormal inversion (turning inward) of the eyelid (usually the lower) towards the globe. Entropion is usually acquired as a result of involutional or cicatricial processes but may occasionally be congenital. [ORCID:0000-0003-0986-4123, PMID:19125427]

Standard name | HP_BLURRED_VISION
Systematic name | M34844
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Blurred vision
Full description | Lack of sharpness of vision resulting in the inability to see fine detail. [HPO:probinson]

Standard name | HP_SUPRANUCLEAR_OPHTHALMOPLEGIA
Systematic name | M34845
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Supranuclear ophthalmoplegia
Full description | A vertical gaze palsy with inability to direct the gaze of the eyes downwards. [HPO:probinson, PMID:20629667]

Standard name | HP_POSTERIOR_EMBRYOTOXON
Systematic name | M34846
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Posterior embryotoxon
Full description | A posterior embryotoxon is the presence of a prominent and anteriorly displaced line of Schwalbe. [HPO:probinson]

Standard name | HP_PERIORBITAL_FULLNESS
Systematic name | M34847
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Periorbital fullness
Full description | Increase in periorbital soft tissue. [HPO:sdoelken]

Standard name | HP_ABNORMAL_RETINAL_ARTERY_MORPHOLOGY
Systematic name | M34848
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal retinal artery morphology
Full description |

Standard name | HP_RETINAL_ARTERIAL_TORTUOSITY
Systematic name | M34849
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retinal arterial tortuosity
Full description | The presence of an increased number of twists and turns of the retinal artery. [HPO:probinson]

Standard name | HP_LACRIMATION_ABNORMALITY
Systematic name | M34850
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lacrimation abnormality
Full description | Abnormality of tear production. [HPO:probinson]

Standard name | HP_DECREASED_LACRIMATION
Systematic name | M34851
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Decreased lacrimation
Full description | Abnormally decreased lacrimation, that is, reduced ability to produce tears. [HPO:probinson]

Standard name | HP_BLUE_IRIDES
Systematic name | M34852
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Blue irides
Full description | A markedly blue coloration of the iris. [HPO:probinson]

Standard name | HP_UPPER_EYELID_COLOBOMA
Systematic name | M34853
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Upper eyelid coloboma
Full description | A short discontinuity of the margin of the upper eyelid. [HPO:probinson]

Standard name | HP_LONG_PALPEBRAL_FISSURE
Systematic name | M34854
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Long palpebral fissure
Full description | Distance between medial and lateral canthi is more than two standard deviations above the mean for age (objective); or, apparently increased length of the palpebral fissures. [PMID:19125427]

Standard name | HP_GAZE_EVOKED_NYSTAGMUS
Systematic name | M34855
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gaze-evoked nystagmus
Full description | Nystagmus made apparent by looking to the right or to the left. [HPO:curators]

Standard name | HP_DYSMETRIC_SACCADES
Systematic name | M34856
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dysmetric saccades
Full description | The controller signal for saccadic eye movements has two components: the pulse that moves the eye rapidly from one point to the next, and the step that holds the eye in the new position. When both the pulse and the step are not the correct size, a dysmetric refixation eye movement results. [HPO:probinson, PMID:572501]

Standard name | HP_RED_GREEN_DYSCHROMATOPSIA
Systematic name | M34857
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Red-green dyschromatopsia
Full description | Difficulty with discriminating red and green hues. [DDD:gblack]

Standard name | HP_AMBLYOPIA
Systematic name | M34858
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Amblyopia
Full description | Reduced visual acuity that is uncorrectable by lenses in the absence of detectable anatomic defects in the eye or visual pathways. [HPO:probinson]

Standard name | HP_SCLEROCORNEA
Systematic name | M34859
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sclerocornea
Full description | A congenital anomaly in which a part or the whole of the cornea acquires the characteristics of sclera, resulting in clouding of the cornea. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_VISUAL_EVOKED_POTENTIALS
Systematic name | M34860
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of visual evoked potentials
Full description | An anomaly of visually evoked potentials (VEP), which are electrical potentials, initiated by brief visual stimuli, which are recorded from the scalp overlying the visual cortex. [HPO:probinson, PMID:19826847]

Standard name | HP_DIPLOPIA
Systematic name | M34861
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Diplopia
Full description | Diplopia is a condition in which a single object is perceived as two images, it is also known as double vision. [HPO:probinson]

Standard name | HP_LOWER_EYELID_COLOBOMA
Systematic name | M34862
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lower eyelid coloboma
Full description | A short discontinuity of the margin of the lower eyelid. [HPO:probinson]

Standard name | HP_SPARSE_EYELASHES
Systematic name | M34863
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sparse eyelashes
Full description | Decreased density/number of eyelashes. [PMID:19125427]

Standard name | HP_DECREASED_LIGHT_AND_DARK_ADAPTED_ELECTRORETINOGRAM_AMPLITUDE
Systematic name | M34864
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Decreased light- and dark-adapted electroretinogram amplitude
Full description | Descreased amplitude of eletrical response upon electroretinography. [HPO:probinson]

Standard name | HP_ECTROPION
Systematic name | M34865
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ectropion
Full description | An outward turning (eversion) or rotation of the eyelid margin. [PMID:19125427]

Standard name | HP_OCULOMOTOR_APRAXIA
Systematic name | M34866
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Oculomotor apraxia
Full description | Ocular motor apraxia is a deficiency in voluntary, horizontal, lateral, fast eye movements (saccades) with retention of slow pursuit movements. The inability to follow objects visually is often compensated by head movements. There may be decreased smooth pursuit, and cancellation of the vestibulo-ocular reflex. [HPO:probinson, PMID:20615230]

Standard name | HP_EYELID_APRAXIA
Systematic name | M34867
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Eyelid apraxia
Full description |

Standard name | HP_PETERS_ANOMALY
Systematic name | M34868
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Peters anomaly
Full description | A form of anterior segment dysgenesis in which abnormal cleavage of the anterior chamber occurs. Peters anomaly is characterized by central, paracentral, or complete corneal opacity. [HPO:probinson]

Standard name | HP_LIPEMIA_RETINALIS
Systematic name | M34869
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lipemia retinalis
Full description | A creamy appearance of the retinal blood vessels that occurs when the concentration of lipids in the blood are extremely increased, with pale pink to milky white retinal vessels and altered pale reflexes from choroidal vasculature. [PMID:10379021, PMID:16120862]

Standard name | HP_NYCTALOPIA
Systematic name | M34870
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nyctalopia
Full description | Inability to see well at night or in poor light. [HPO:probinson]

Standard name | HP_HORIZONTAL_NYSTAGMUS
Systematic name | M34871
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Horizontal nystagmus
Full description | Nystagmus consisting of horizontal to-and-fro eye movements. [HPO:probinson]

Standard name | HP_PHTHISIS_BULBI
Systematic name | M34872
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Phthisis bulbi
Full description | Atrophy of the eyeball with blindness and decreased intraocular pressure due to end-stage intraocular disease. [HPO:probinson]

Standard name | HP_HYPODONTIA
Systematic name | M34873
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypodontia
Full description | A developmental anomaly characterized by a reduced number of teeth, whereby up to 6 teeth are missing. [HPO:ibailleulforestier]

Standard name | HP_CARIOUS_TEETH
Systematic name | M34874
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Carious teeth
Full description | Caries is a multifactorial bacterial infection affecting the structure of the tooth. This term has been used to describe the presence of more than expected dental caries. [HPO:probinson]

Standard name | HP_ANODONTIA
Systematic name | M34875
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anodontia
Full description | The congenital absence of all teeth. [HPO:ibailleulforestier]

Standard name | HP_ABNORMALITY_OF_THE_INCISOR
Systematic name | M34876
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the incisor
Full description | An abnormality of the Incisor tooth. [HPO:probinson]

Standard name | HP_OLIGODONTIA
Systematic name | M34877
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Oligodontia
Full description | A developmental anomaly characterized by a reduced number of teeth, whereby more than 6 teeth are missing. [HPO:curators, PMID:19125428]

Standard name | HP_DENTAL_CROWDING
Systematic name | M34878
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dental crowding
Full description | Overlapping teeth within an alveolar ridge. [PMID:19125428]

Standard name | HP_DELAYED_ERUPTION_OF_PRIMARY_TEETH
Systematic name | M34879
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delayed eruption of primary teeth
Full description | Delayed tooth eruption affecting the primary dentition. [HPO:ibailleulforestier]

Standard name | HP_DELAYED_ERUPTION_OF_TEETH
Systematic name | M34880
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delayed eruption of teeth
Full description | Delayed tooth eruption, which can be defined as tooth eruption more than 2 SD beyond the mean eruption age. [HPO:ibailleulforestier, PMID:19125428]

Standard name | HP_HYPOPLASIA_OF_TEETH
Systematic name | M34881
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoplasia of teeth
Full description | Developmental hypoplasia of teeth. [HPO:ibailleulforestier]

Standard name | HP_WIDELY_SPACED_TEETH
Systematic name | M34882
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Widely spaced teeth
Full description | Increased spaces (diastemata) between most of the teeth in the same dental arch. [PMID:19125428]

Standard name | HP_DENTAL_MALOCCLUSION
Systematic name | M34883
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dental malocclusion
Full description | Dental malocclusion refers to an abnormality of the occlusion, or alignment, of the teeth and the way the upper and lower teeth fit together, resulting in overcrowding of teeth or in abnormal bite patterns. [HPO:curators]

Standard name | HP_MICRODONTIA
Systematic name | M34884
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Microdontia
Full description | Decreased size of the teeth, which can be defined as a mesiodistal tooth diameter (width) more than 2 SD below mean. Alternatively, an apparently decreased maximum width of tooth. [HPO:ibailleulforestier, PMID:19125428]

Standard name | HP_MISALIGNMENT_OF_TEETH
Systematic name | M34885
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Misalignment of teeth
Full description | Abnormal alignment, positioning, or spacing of the teeth, i.e., misaligned teeth. [HPO:ibailleulforestier]

Standard name | HP_NATAL_TOOTH
Systematic name | M34886
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Natal tooth
Full description | Erupted tooth or teeth at birth. [PMID:19125428]

Standard name | HP_DELAYED_ERUPTION_OF_PERMANENT_TEETH
Systematic name | M34887
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delayed eruption of permanent teeth
Full description | Delayed tooth eruption affecting the secondary dentition. [HPO:ibailleulforestier]

Standard name | HP_CONICAL_TOOTH
Systematic name | M34888
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Conical tooth
Full description | An abnormal conical form of the teeth, that is, a tooth whose sides converge or taper together incisally. [HPO:ibailleulforestier]

Standard name | HP_DIASTEMA
Systematic name | M34889
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Diastema
Full description | Increased space between two adjacent teeth in the same dental arch. [PMID:19125428]

Standard name | HP_PERIODONTITIS
Systematic name | M34890
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Periodontitis
Full description | Inflammation of the periodontium. [HPO:ibailleulforestier]

Standard name | HP_AMELOGENESIS_IMPERFECTA
Systematic name | M34891
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Amelogenesis imperfecta
Full description | A developmental dysplasia of the dental enamel. [HPO:ibailleulforestier, PMID:18499550]

Standard name | HP_UNERUPTED_TOOTH
Systematic name | M34892
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Unerupted tooth
Full description | The presence of one or more embedded tooth germs which have failed to erupt. [HPO:ibailleulforestier]

Standard name | HP_PSYCHOSIS
Systematic name | M34893
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Psychosis
Full description | A condition characterized by changes of personality and thought patterns often accompanied by hallucinations and delusional beliefs. [HPO:curators]

Standard name | HP_RESTLESSNESS
Systematic name | M34894
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Restlessness
Full description | A state of unease characterized by diffuse motor activity or motion subject to limited control, nonproductive or disorganized behavior, and subjective distress. [PMID:28332736]

Standard name | HP_EMOTIONAL_LABILITY
Systematic name | M34895
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Emotional lability
Full description | Unstable emotional experiences and frequent mood changes; emotions that are easily aroused, intense, and/or out of proportion to events and circumstances. [PMID:23902698]

Standard name | HP_DEPRESSIVITY
Systematic name | M34896
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Depressivity
Full description | Frequent feelings of being down, miserable, and/or hopeless; difficulty recovering from such moods; pessimism about the future; pervasive shame; feeling of inferior self-worth; thoughts of suicide and suicidal behavior. [HPO:probinson, PMID:23902698]

Standard name | HP_AUTISM
Systematic name | M34897
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Autism
Full description | Autism is a neurodevelopmental disorder characterized by impaired social interaction and communication, and by restricted and repetitive behavior. Autism begins in childhood. It is marked by the presence of markedly abnormal or impaired development in social interaction and communication and a markedly restricted repertoire of activity and interest. Manifestations of the disorder vary greatly depending on the developmental level and chronological age of the individual (DSM-IV). [DDD:hvfirth]

Standard name | HP_AGGRESSIVE_BEHAVIOR
Systematic name | M34898
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aggressive behavior
Full description | Aggressive behavior can denote verbal aggression, physical aggression against objects, physical aggression against people, and may also include aggression towards oneself. [HPO:curators]

Standard name | HP_INAPPROPRIATE_BEHAVIOR
Systematic name | M34899
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Inappropriate behavior
Full description |

Standard name | HP_MOOD_SWINGS
Systematic name | M34900
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mood swings
Full description | An exaggeration of emotional affects such as laughing crying, or yawning beyond what the person feels. [HPO:curators]

Standard name | HP_OBSESSIVE_COMPULSIVE_BEHAVIOR
Systematic name | M34901
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Obsessive-compulsive behavior
Full description | Recurrent obsessions or compulsions that are severe enough to be time consuming (i.e., they take more than 1 hour a day) or cause marked distress or significant impairment (DSM-IV). [HPO:probinson]

Standard name | HP_RESTRICTIVE_BEHAVIOR
Systematic name | M34902
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Restrictive behavior
Full description | Behavior characterized by an abnormal limitation to few interests and activities. [HPO:probinson]

Standard name | HP_PSYCHOTIC_EPISODES
Systematic name | M34903
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Psychotic episodes
Full description |

Standard name | HP_DEMENTIA
Systematic name | M34904
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dementia
Full description | A loss of global cognitive ability of sufficient amount to interfere with normal social or occupational function. Dementia represents a loss of previously present cognitive abilities, generally in adults, and can affect memory, thinking, language, judgment, and behavior. [HPO:probinson]

Standard name | HP_FRONTAL_LOBE_DEMENTIA
Systematic name | M34905
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Frontal lobe dementia
Full description |

Standard name | HP_AUTISTIC_BEHAVIOR
Systematic name | M34906
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Autistic behavior
Full description | Persistent deficits in social interaction and communication and interaction as well as a markedly restricted repertoire of activity and interest as well as repetitive patterns of behavior. [HPO:probinson, PMID:28879490]

Standard name | HP_STEREOTYPY
Systematic name | M34907
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Stereotypy
Full description | A stereotypy is a repetitive, simple movement that can be voluntarily suppressed. Stereotypies are typically simple back-and-forth movements such as waving of flapping the hands or arms, and they do not involve complex sequences or movement fragments. Movement is often but not always rhythmic and may involve fingers, wrists, or more proximal portions of the upper extremity. The lower extremity is not typically involved. Stereotypies are more commonly bilateral than unilateral. [HPO:probinson]

Standard name | HP_DISINHIBITION
Systematic name | M34908
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Disinhibition
Full description | A lack of restraint manifested in several ways, including disregard for social conventions, impulsivity, and poor risk assessment. [HPO:sdoelken]

Standard name | HP_IMPAIRED_SOCIAL_INTERACTIONS
Systematic name | M34909
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Impaired social interactions
Full description | Difficulty in social interactions related to an impairment of characteristics such as eye contact, smiling, appropriate facial expressions, and body postures and characterized by difficulty in forming peer relationships and forming friendships. [HPO:probinson]

Standard name | HP_SHORT_ATTENTION_SPAN
Systematic name | M34910
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short attention span
Full description | Reduced attention span characterized by distractibility and impulsivity but not necessarily satisfying the diagnostic criteria for attention deficit hyperactivity disorder. [HPO:curators]

Standard name | HP_IRRITABILITY
Systematic name | M34911
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Irritability
Full description |

Standard name | HP_HALLUCINATIONS
Systematic name | M34912
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hallucinations
Full description | Perceptions in a conscious and awake state in the absence of external stimuli which have qualities of real perception, in that they are vivid, substantial, and located in external objective space. [HPO:sdoelken]

Standard name | HP_SELF_MUTILATION
Systematic name | M34913
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Self-mutilation
Full description |

Standard name | HP_LOW_FRUSTRATION_TOLERANCE
Systematic name | M34914
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Low frustration tolerance
Full description | The feeling of frustration can be defined as an emotional reaction that occurs if a desired goal is not achieved. Frustration intolerance is defined as an age-inappropriate response to frustration characterized by crying or temper tantrums (in children) or aggressive or other undesirable behaviors. [PMID:21461367]

Standard name | HP_DIMINISHED_MOTIVATION
Systematic name | M34915
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Diminished motivation
Full description | A reduction in goal-directed behavior, that is, motivation, the determinant of behavior and adaptation that allows individuals to get started, be energized to perform a sustained and directed action. [HPO:probinson, PMID:16030444]

Standard name | HP_DELUSIONS
Systematic name | M34916
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delusions
Full description | A belief that is pathological and is held despite evidence to the contrary. [HPO:sdoelken]

Standard name | HP_INAPPROPRIATE_LAUGHTER
Systematic name | M34917
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Inappropriate laughter
Full description |

Standard name | HP_PAROXYSMAL_BURSTS_OF_LAUGHTER
Systematic name | M34918
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Paroxysmal bursts of laughter
Full description |

Standard name | HP_DELAYED_SPEECH_AND_LANGUAGE_DEVELOPMENT
Systematic name | M34919
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delayed speech and language development
Full description | A degree of language development that is significantly below the norm for a child of a specified age. [HPO:probinson]

Standard name | HP_PERSONALITY_CHANGES
Systematic name | M34920
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Personality changes
Full description | An abnormal shift in patterns of thinking, acting, or feeling. [HPO:probinson]

Standard name | HP_HYPERACTIVITY
Systematic name | M34921
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperactivity
Full description | Hyperactivity is a state of constantly being unusually or abnormally active, including in situations in which it is not appropriate. [ORCID:0000-0002-6713-2943]

Standard name | HP_LACK_OF_INSIGHT
Systematic name | M34922
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lack of insight
Full description |

Standard name | HP_ABNORMAL_PERIPHERAL_NERVOUS_SYSTEM_MORPHOLOGY
Systematic name | M34923
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal peripheral nervous system morphology
Full description | A structural abnormality of the peripheral nervous system, which is composed of the nerves that lead to or branch off from the central nervous system. This includes the cranial nerves (olfactory and optic nerves are technically part of the central nervous system). [HPO:probinson]

Standard name | HP_SENSORY_NEUROPATHY
Systematic name | M34924
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sensory neuropathy
Full description | Peripheral neuropathy affecting the sensory nerves. [HPO:curators]

Standard name | HP_PERIPHERAL_AXONAL_DEGENERATION
Systematic name | M34925
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Peripheral axonal degeneration
Full description | Progressive deterioration of peripheral axons. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_THORAX
Systematic name | M34926
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the thorax
Full description | Any abnormality of the thorax (the region of the body formed by the sternum, the thoracic vertebrae and the ribs). [HPO:curators]

Standard name | HP_ABNORMALITY_OF_THE_STERNUM
Systematic name | M34927
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the sternum
Full description | An anomaly of the sternum, also known as the breastbone. [HPO:probinson]

STANDARD_NAME="HP_PECTUS_EXCAVATUM" SYSTEMATIC_NAME="M34928" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="" AUTHORS="" GEOID="" EXACT_SOURCE="HP:0000767" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="https://hpo.jax.org/app/browse/term/HP:0000767" CHIP="Human_NCBI_Gene_ID" CATEGORY_CODE="C5" SUB_CATEGORY_CODE="HPO" CONTRIBUTOR="Human Phenotype Ontology Group" CONTRIBUTOR_ORG="The Jackson Laboratory (JAX)" DESCRIPTION_BRIEF="Pectus excavatum" DESCRIPTION_FULL="A defect of the chest wall characterized by a depression of the sternum, giving the chest (\pectus\) a caved-in (\excavatum\) appearance. [HPO:probinson]"

Standard name | HP_PECTUS_CARINATUM
Systematic name | M34929
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pectus carinatum
Full description | A deformity of the chest caused by overgrowth of the ribs and characterized by protrusion of the sternum. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_BREAST
Systematic name | M34930
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the breast
Full description | An abnormality of the breast. [HPO:probinson]

Standard name | HP_GYNECOMASTIA
Systematic name | M34931
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gynecomastia
Full description | Abnormal development of large mammary glands in males resulting in breast enlargement. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_RIBS
Systematic name | M34932
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the ribs
Full description | An anomaly of the rib. [HPO:probinson]

Standard name | HP_SHORT_RIBS
Systematic name | M34933
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short ribs
Full description | Reduced rib length. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_DIAPHRAGM
Systematic name | M34934
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the diaphragm
Full description | Any abnormality of the diaphragm, the sheet of skeletal muscle that separates the thoracic cavity from the abdominal cavity. [HPO:probinson]

Standard name | HP_CONGENITAL_DIAPHRAGMATIC_HERNIA
Systematic name | M34935
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Congenital diaphragmatic hernia
Full description | The presence of a hernia of the diaphragm present at birth. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_THYMUS
Systematic name | M34936
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the thymus
Full description | Abnormality of the thymus, an organ located in the upper anterior portion of the chest cavity just behind the sternum and whose main function is to provide an environment for T lymphocyte maturation. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_SCAPULA
Systematic name | M34937
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the scapula
Full description | Any abnormality of the scapula, also known as the shoulder blade. [HPO:probinson]

Standard name | HP_PRIMARY_AMENORRHEA
Systematic name | M34938
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Primary amenorrhea
Full description |

Standard name | HP_NEPHROLITHIASIS
Systematic name | M34939
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nephrolithiasis
Full description | The presence of calculi (stones) in the kidneys. [HPO:probinson]

Standard name | HP_INFERTILITY
Systematic name | M34940
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Infertility
Full description |

Standard name | HP_MEMBRANOPROLIFERATIVE_GLOMERULONEPHRITIS
Systematic name | M34941
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Membranoproliferative glomerulonephritis
Full description | A type of glomerulonephritis characterized by diffuse mesangial cell proliferation and the thickening of capillary walls due to subendothelial extension of the mesangium. The term membranoproliferative glomerulonephritis is often employed to denote a general pattern of glomerular injury seen in a variety of disease processes that share a common pathogenetic mechanism, rather than to describe a single disease entity [PMID:19908070]

Standard name | HP_ABNORMALITY_OF_THE_URETHRA
Systematic name | M34942
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the urethra
Full description | An abnormality of the urethra, i.e., of the tube which connects the urinary bladder to the outside of the body. [HPO:probinson]

Standard name | HP_URETHRAL_OBSTRUCTION
Systematic name | M34943
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Urethral obstruction
Full description | Obstruction of the flow of urine through the urethra. [HPO:probinson]

Standard name | HP_OLIGOSPERMIA
Systematic name | M34944
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Oligospermia
Full description | Reduced count of spermatozoa in the semen, defined as a sperm count below 20 million per milliliter semen. [HPO:probinson]

Standard name | HP_RENAL_STEATOSIS
Systematic name | M34945
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal steatosis
Full description | Abnormal fat accumulation in the kidneys. [HPO:probinson]

Standard name | HP_CYSTIC_RENAL_DYSPLASIA
Systematic name | M34946
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cystic renal dysplasia
Full description |

Standard name | HP_IMPOTENCE
Systematic name | M34947
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Impotence
Full description | Inability to develop or maintain an erection of the penis. [HPO:probinson]

Standard name | HP_RENAL_CORTICAL_CYSTS
Systematic name | M34948
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal cortical cysts
Full description | Cysts of the cortex of the kidney. [Eurenomics:fschaefer]

Standard name | HP_ENURESIS
Systematic name | M34949
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Enuresis
Full description | Lack of the ability to control the urinary bladder leading to involuntary urination at an age where control of the bladder should already be possible. [HPO:sdoelken]

Standard name | HP_GLANDULAR_HYPOSPADIAS
Systematic name | M34950
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Glandular hypospadias
Full description |

Standard name | HP_PENOSCROTAL_HYPOSPADIAS
Systematic name | M34951
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Penoscrotal hypospadias
Full description | A severe form of hypospadias in which the urethral opening is located at the junction of the penis and scrotum. [HPO:probinson]

Standard name | HP_ABNORMAL_EXTERNAL_GENITALIA
Systematic name | M34952
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal external genitalia
Full description |

Standard name | HP_ABNORMAL_INTERNAL_GENITALIA
Systematic name | M34953
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal internal genitalia
Full description | An anomaly of the adnexa, uterus, and vagina (in female) or seminal tract and prostate (in male). [HPO:probinson]

Standard name | HP_BICORNUATE_UTERUS
Systematic name | M34954
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bicornuate uterus
Full description | The presence of a bicornuate uterus. [HPO:probinson]

Standard name | HP_HYPERGONADOTROPIC_HYPOGONADISM
Systematic name | M34955
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypergonadotropic hypogonadism
Full description | Reduced function of the gonads (testes in males or ovaries in females) associated with excess pituitary gonadotropin secretion and resulting in delayed sexual development and growth delay. [HPO:curators]

Standard name | HP_ABNORMALITY_OF_KREBS_CYCLE_METABOLISM
Systematic name | M34956
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of Krebs cycle metabolism
Full description | An abnormality of the tricarboxylic acid cycle. [HPO:probinson]

Standard name | HP_POOR_EYE_CONTACT
Systematic name | M34957
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Poor eye contact
Full description | Difficulty in looking at another person in the eye. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_ENDOCRINE_SYSTEM
Systematic name | M34958
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the endocrine system
Full description | An abnormality of the endocrine system. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_THYROID_GLAND
Systematic name | M34959
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the thyroid gland
Full description | An abnormality of the thyroid gland. [HPO:probinson]

Standard name | HP_DELAYED_PUBERTY
Systematic name | M34960
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delayed puberty
Full description | Passing the age when puberty normally occurs with no physical or hormonal signs of the onset of puberty. [HPO:probinson]

Standard name | HP_HYPERINSULINEMIC_HYPOGLYCEMIA
Systematic name | M34961
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperinsulinemic hypoglycemia
Full description | An increased concentration of insulin combined with a decreased concentration of glucose in the blood. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_PARATHYROID_GLAND
Systematic name | M34962
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the parathyroid gland
Full description | An abnormality of the parathyroid gland. [HPO:curators]

Standard name | HP_HYPOPARATHYROIDISM
Systematic name | M34963
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoparathyroidism
Full description | A condition caused by a deficiency of parathyroid hormone characterized by hypocalcemia and hyperphosphatemia. [HPO:probinson]

Standard name | HP_INSULIN_RESISTANT_DIABETES_MELLITUS
Systematic name | M34964
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Insulin-resistant diabetes mellitus
Full description | A type of diabetes mellitus related not to lack of insulin but rather to lack of response to insulin on the part of the target tissues of insulin such as muscle, fat, and liver cells. This type of diabetes is typically associated with increases both in blood glucose concentrations as will as in fasting and postprandial serum insulin levels. [HPO:probinson, PMID:7706500]

Standard name | HP_ABNORMALITY_OF_THE_ADRENAL_GLANDS
Systematic name | M34965
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the adrenal glands
Full description | Abnormality of the adrenal glands, i.e., of the endocrine glands located at the top of the kindneys. [HPO:probinson]

Standard name | HP_ADRENAL_HYPOPLASIA
Systematic name | M34966
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Adrenal hypoplasia
Full description | Developmental hypoplasia of the adrenal glands. [HPO:probinson]

Standard name | HP_HYPERTHYROIDISM
Systematic name | M34967
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperthyroidism
Full description | An abnormality of thyroid physiology characterized by excessive secretion of the thyroid hormones thyroxine (i.e., T4) and/or 3,3',5-triiodo-L-thyronine zwitterion (i.e., triiodothyronine or T3). [HPO:probinson]

Standard name | HP_INCREASED_CIRCULATING_GONADOTROPIN_LEVEL
Systematic name | M34968
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Increased circulating gonadotropin level
Full description | Overproduction of gonadotropins (FSH, LH) by the anterior pituitary gland. [DDD:spark]

Standard name | HP_PITUITARY_DWARFISM
Systematic name | M34969
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pituitary dwarfism
Full description | A type of reduced stature with normal proportions related to dysfunction of the pituitary gland related to either an isolated defect in the secretion of growth hormone or to panhypopituitarism, i.e., a deficit of all the anterior pituitary hormones. [HPO:probinson]

Standard name | HP_ADRENOGENITAL_SYNDROME
Systematic name | M34970
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Adrenogenital syndrome
Full description | Adrenogenital syndrome is also known as congenital adrenal hyperplasia, which results from disorders of steroid hormone production in the adrenal glands leading to a deficiency of cortisol. The pituitary gland reacts by increased secretion of corticotropin, which in turn causes the adrenal glands to overproduce certain intermediary hormones which have testosterone-like effects. [HPO:probinson]

Standard name | HP_HYPERACTIVE_RENIN_ANGIOTENSIN_SYSTEM
Systematic name | M34971
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperactive renin-angiotensin system
Full description | An abnormally increased activity of the renin-angiotensin system, causing hypertension by a combination of volume excess and vasoconstrictor mechanisms. [HPO:probinson]

Standard name | HP_HYPERPARATHYROIDISM
Systematic name | M34972
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperparathyroidism
Full description | Excessive production of parathyroid hormone (PTH) by the parathyroid glands. [HPO:probinson]

Standard name | HP_GROWTH_HORMONE_EXCESS
Systematic name | M34973
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Growth hormone excess
Full description | Acromegaly is a condition resulting from overproduction of growth hormone by the pituitary gland in persons with closed epiphyses, and consists chiefly in the enlargement of the distal parts of the body. The circumference of the skull increases, the nose becomes broad, the tongue becomes enlarged, the facial features become coarsened, the mandible grows excessively, and the teeth become separated. The fingers and toes grow chiefly in thickness. [DDD:spark, HPO:probinson]

Standard name | HP_ADRENAL_INSUFFICIENCY
Systematic name | M34974
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Adrenal insufficiency
Full description | Insufficient production of steroid hormones (primarily cortisol) by the adrenal glands. [HPO:probinson, PMID:11443143]

Standard name | HP_ABNORMALITY_OF_RENIN_ANGIOTENSIN_SYSTEM
Systematic name | M34975
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of renin-angiotensin system
Full description | An abnormality of the renin-angiotensin system. [HPO:probinson]

Standard name | HP_INCREASED_CIRCULATING_RENIN_LEVEL
Systematic name | M34976
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Increased circulating renin level
Full description | An increased level of renin in the blood. [HPO:probinson]

Standard name | HP_ADRENOCORTICAL_ABNORMALITY
Systematic name | M34977
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Adrenocortical abnormality
Full description |

Standard name | HP_CONGENITAL_HYPOTHYROIDISM
Systematic name | M34978
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Congenital hypothyroidism
Full description | A type of hypothyroidism with congenital onset. [HPO:probinson]

Standard name | HP_PSEUDOHYPOPARATHYROIDISM
Systematic name | M34979
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pseudohypoparathyroidism
Full description | A condition characterized by resistance to the action of parathyroid hormone, in which there is hypocalcemia, hyperphosphatemia, and (appropriately) high levels of parathyroid hormone. [HPO:probinson]

Standard name | HP_GOITER
Systematic name | M34980
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Goiter
Full description | An enlargement of the thyroid gland. [HPO:probinson]

Standard name | HP_THYROID_ADENOMA
Systematic name | M34981
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thyroid adenoma
Full description | The presence of a adenoma of the thyroid gland. [HPO:probinson]

Standard name | HP_INSULIN_RESISTANCE
Systematic name | M34982
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Insulin resistance
Full description | Increased resistance towards insulin, that is, diminished effectiveness of insulin in reducing blood glucose levels. [HPO:probinson]

Standard name | HP_NEONATAL_INSULIN_DEPENDENT_DIABETES_MELLITUS
Systematic name | M34983
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neonatal insulin-dependent diabetes mellitus
Full description |

Standard name | HP_IRREGULAR_MENSTRUATION
Systematic name | M34984
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Irregular menstruation
Full description | Abnormally high variation in the amount of time between periods. [PMID:29323693]

Standard name | HP_HYPERALDOSTERONISM
Systematic name | M34985
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperaldosteronism
Full description | Overproduction of the mineralocorticoid aldosterone by the adrenal cortex. [DDD:spark, HPO:probinson]

Standard name | HP_CENTRAL_DIABETES_INSIPIDUS
Systematic name | M34986
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Central diabetes insipidus
Full description | A form of diabetes insipidus related to a failure of vasopressin (AVP) release from the hypothalamus. [HPO:curators]

Standard name | HP_ABNORMALITY_OF_THE_HYPOTHALAMUS_PITUITARY_AXIS
Systematic name | M34987
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the hypothalamus-pituitary axis
Full description | Abnormality of the pituitary gland (also known as hypophysis), which is an endocrine gland that protrudes from the bottom of the hypothalamus at the base of the brain. The pituitary gland secretes the hormones ACTH, TSH, PRL, GH, endorphins, FSH, LH, oxytocin, and antidiuretic hormone. The secretion of hormones from the anterior pituitary is under the strict control of hypothalamic hormones, and the posterior pituitary is essentially an extension of the hypothalamus, so that hypothalamus and pituitary gland may be regarded as a functional unit. [DDD:spark]

Standard name | HP_DECREASED_FERTILITY_IN_FEMALES
Systematic name | M34988
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Decreased fertility in females
Full description |

Standard name | HP_SECONDARY_AMENORRHEA
Systematic name | M34989
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Secondary amenorrhea
Full description |

Standard name | HP_INCREASED_CIRCULATING_PROLACTIN_CONCENTRATION
Systematic name | M34990
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Increased circulating prolactin concentration
Full description | The presence of abnormally increased levels of prolactin in the blood. Prolactin is a peptide hormone produced by the anterior pituitary gland that plays a role in breast development and lactation during pregnancy. [DDD:spark, HPO:probinson]

Standard name | HP_PANHYPOPITUITARISM
Systematic name | M34991
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Panhypopituitarism
Full description | A pituitary functional deficit affecting all the anterior pituitary hormones (growth hormone, thyroid-stimulating hormone, follicle-stimulating hormone, luteinizing hormone, adrenocorticotropic hormone, and prolactin). [HPO:probinson, PMID:12466332]

Standard name | HP_HASHIMOTO_THYROIDITIS
Systematic name | M34992
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hashimoto thyroiditis
Full description | A chronic, autoimmune type of thyroiditis associated with hypothyroidism. [HPO:probinson]

Standard name | HP_DIABETES_INSIPIDUS
Systematic name | M34993
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Diabetes insipidus
Full description | A state of excessive water intake and hypotonic (dilute) polyuria. Diabetes insipidus may be due to failure of vasopressin (AVP) release (central or neurogenic diabetes insipidus) or to a failure of the kidney to respond to AVP (nephrogenic diabetes insipidus). [HPO:curators]

Standard name | HP_EPISODIC_HYPERTENSION
Systematic name | M34994
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Episodic hypertension
Full description |

Standard name | HP_OLIGOMENORRHEA
Systematic name | M34995
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Oligomenorrhea
Full description | Infrequent menses (less than 6 per year or more than 35 days between cycles). [HPO:probinson, PMID:22594864]

Standard name | HP_INSULIN_RESISTANT_DIABETES_MELLITUS_AT_PUBERTY
Systematic name | M34996
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Insulin-resistant diabetes mellitus at puberty
Full description |

Standard name | HP_11_PAIRS_OF_RIBS
Systematic name | M34997
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | 11 pairs of ribs
Full description | Presence of only 11 pairs of ribs. [HPO:probinson]

Standard name | HP_SHORT_STERNUM
Systematic name | M34998
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short sternum
Full description | Decreased inferosuperior length of the sternum. [HPO:probinson]

Standard name | HP_THIN_RIBS
Systematic name | M34999
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thin ribs
Full description | Ribs with a reduced diameter. [HPO:probinson]

Standard name | HP_PROMINENT_STERNUM
Systematic name | M35000
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Prominent sternum
Full description |

Standard name | HP_BROAD_RIBS
Systematic name | M35001
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad ribs
Full description | Increased width of ribs [HPO:probinson]

Standard name | HP_CUPPED_RIBS
Systematic name | M35002
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cupped ribs
Full description | Wide, concave rib end. [HPO:probinson]

Standard name | HP_HORIZONTAL_RIBS
Systematic name | M35003
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Horizontal ribs
Full description | A horizontal (flat) conformation of the ribs, the long curved bones that form the rib cage and normally progressively oblique (slanted) from ribs 1 through 9, then less slanted through rib 12. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_CLAVICLE
Systematic name | M35004
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the clavicle
Full description | Any abnormality of the clavicles (collar bones). [HPO:probinson]

Standard name | HP_LONG_CLAVICLES
Systematic name | M35005
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Long clavicles
Full description | Increased length of the clavicles. [HPO:probinson]

Standard name | HP_CERVICAL_RIBS
Systematic name | M35006
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cervical ribs
Full description |

Standard name | HP_BIFID_RIBS
Systematic name | M35007
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bifid ribs
Full description | A bifid rib refers to cleavage of the sternal end of a rib, usually unilateral. Bifid ribs are usually asymptomatic, and are often discovered incidentally by chest x-ray. [HPO:probinson]

Standard name | HP_SHORT_CLAVICLES
Systematic name | M35008
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short clavicles
Full description | Reduced length of the clavicles. [HPO:probinson]

Standard name | HP_LATERAL_CLAVICLE_HOOK
Systematic name | M35009
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lateral clavicle hook
Full description | An excessive upward convexity of the lateral clavicle. [HPO:probinson, PMID:7322653]

Standard name | HP_RACHITIC_ROSARY
Systematic name | M35010
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Rachitic rosary
Full description | A row of beadlike prominences at the junction of a rib and its cartilage (i.e., enlarged costochondral joints), resembling a rosary. [HPO:probinson, PMID:26745253]

Standard name | HP_THICKENED_RIBS
Systematic name | M35011
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thickened ribs
Full description | Increased thickness (diameter) of ribs. [HPO:probinson]

Standard name | HP_RIB_FUSION
Systematic name | M35012
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Rib fusion
Full description | Complete or partial merging of adjacent ribs. [HPO:probinson]

Standard name | HP_FLARING_OF_RIB_CAGE
Systematic name | M35013
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Flaring of rib cage
Full description | The presence of wide, concave anterior rib ends. [HPO:curators]

Standard name | HP_ANTERIOR_RIB_CUPPING
Systematic name | M35014
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anterior rib cupping
Full description | Wide, concave anterior rib end. [HPO:probinson]

Standard name | HP_SPRENGEL_ANOMALY
Systematic name | M35015
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sprengel anomaly
Full description | A congenital skeletal deformity characterized by the elevation of one scapula (thus, one scapula is located superior to the other). [HPO:probinson]

Standard name | HP_SHIELD_CHEST
Systematic name | M35016
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Shield chest
Full description | A broad chest. [HPO:probinson, PMID:22368597]

Standard name | HP_PECTUS_EXCAVATUM_OF_INFERIOR_STERNUM
Systematic name | M35017
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pectus excavatum of inferior sternum
Full description | Pectus excavatum (defect of the chest wall characterized by depression of the sternum) affecting primarily the inferior region of the sternum. [HPO:probinson]

Standard name | HP_BROAD_CLAVICLES
Systematic name | M35018
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad clavicles
Full description | Increased width (cross-sectional diameter) of the clavicles. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_COSTOCHONDRAL_JUNCTION
Systematic name | M35019
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the costochondral junction
Full description | Any anomaly of the costochondral junction. The costochondral junctions are located between the distal part of the ribs and the costal cartilages, which are bars of hyaline cartilage that connect the ribs to the sternum. [HPO:probinson]

Standard name | HP_ENLARGEMENT_OF_THE_COSTOCHONDRAL_JUNCTION
Systematic name | M35020
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Enlargement of the costochondral junction
Full description | Abnormally increased size of the costochondral junctions, which are located between the distal part of the ribs and the costal cartilages, which are bars of hyaline cartilage that connect the ribs to the sternum. [HPO:probinson]

Standard name | HP_MISSING_RIBS
Systematic name | M35021
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Missing ribs
Full description | A developmental anomaly with absence of one or more ribs. [HPO:probinson]

Standard name | HP_POSTERIOR_RIB_CUPPING
Systematic name | M35022
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Posterior rib cupping
Full description | Wide, concave posterior rib end. [HPO:probinson]

Standard name | HP_BEADED_RIBS
Systematic name | M35023
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Beaded ribs
Full description | The presence of a row of multiple rounded expansions (beadlike prominences) at the junction of a rib and its cartilage. [HPO:probinson]

Standard name | HP_PLATYSPONDYLY
Systematic name | M35024
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Platyspondyly
Full description | A flattened vertebral body shape with reduced distance between the vertebral endplates. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_SKELETAL_MATURATION
Systematic name | M35025
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of skeletal maturation
Full description | The bones of the skeleton undergo a series of characteristic changes in size, shape, and calcification from fetal life until puberty. An abnormality of this process can include delayed or accelerated skeletal maturation, or deviation of some, but not all bones from the expected patterns of maturation. [HPO:probinson]

Standard name | HP_CHONDROCALCINOSIS
Systematic name | M35026
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Chondrocalcinosis
Full description | Radiographic evidence of articular calcification that represent calcium pyrophosphate depositions in soft tissue surrounding joints and at the insertions of tendons near joints (Entheses/Sharpey fibers) . [HPO:sdoelken]

Standard name | HP_THICKENED_CORTEX_OF_LONG_BONES
Systematic name | M35027
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thickened cortex of long bones
Full description | Abnormal thickening of the cortex of long bones. [HPO:curators]

Standard name | HP_OSTEOPENIA
Systematic name | M35028
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Osteopenia
Full description | Osteopenia is a term to define bone density that is not normal but also not as low as osteoporosis. By definition from the World Health Organization osteopenia is defined by bone densitometry as a T score -1 to -2.5. [HPO:probinson, PMID:21234807]

Standard name | HP_OSTEOPOROSIS
Systematic name | M35029
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Osteoporosis
Full description | Osteoporosis is a systemic skeletal disease characterized by low bone density and microarchitectural deterioration of bone tissue with a consequent increase in bone fragility. According to the WHO criteria, osteoporosis is defined as a BMD that lies 2.5 standard deviations or more below the average value for young healthy adults (a T-score below -2.5 SD). [HPO:probinson, PMID:28293453]

Standard name | HP_ABNORMAL_DIAPHYSIS_MORPHOLOGY
Systematic name | M35030
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal diaphysis morphology
Full description | An abnormality of the structure or form of the diaphysis, i.e., of the main or mid-section (shaft) of a long bone. [HPO:probinson]

Standard name | HP_DYSOSTOSIS_MULTIPLEX
Systematic name | M35031
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dysostosis multiplex
Full description |

Standard name | HP_ABNORMALITY_OF_THE_METAPHYSIS
Systematic name | M35032
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the metaphysis
Full description | An abnormality of one or more metaphysis, i.e., of the somewhat wider portion of a long bone that is adjacent to the epiphyseal growth plate and grows during childhood. [HPO:probinson]

Standard name | HP_HYPOPLASTIC_ILIA
Systematic name | M35033
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoplastic ilia
Full description | Underdevelopment of the ilium. [HPO:probinson]

Standard name | HP_DUMBBELL_SHAPED_LONG_BONE
Systematic name | M35034
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dumbbell-shaped long bone
Full description | An abnormal appearance of the long bones with resemblance to a dumbbell, a short bar with a weight at each end. That is, the long bone is shortened and displays flaring (widening) of the metaphyses. [HPO:probinson]

Standard name | HP_JAUNDICE
Systematic name | M35035
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Jaundice
Full description | Yellow pigmentation of the skin due to bilirubin, which in turn is the result of increased bilirubin concentration in the bloodstream. [HPO:probinson]

Standard name | HP_HYPERPIGMENTATION_OF_THE_SKIN
Systematic name | M35036
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperpigmentation of the skin
Full description | A darkening of the skin related to an increase in melanin production and deposition. [HPO:probinson]

Standard name | HP_SINGLE_TRANSVERSE_PALMAR_CREASE
Systematic name | M35037
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Single transverse palmar crease
Full description | The distal and proximal transverse palmar creases are merged into a single transverse palmar crease. [HPO:probinson, PMID:19125433]

Standard name | HP_ACANTHOSIS_NIGRICANS
Systematic name | M35038
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Acanthosis nigricans
Full description | A dermatosis characterized by thickened, hyperpigmented plaques, typically on the intertriginous surfaces and neck. [DDD:cmoss, PMID:19061584]

Standard name | HP_CAFE_AU_LAIT_SPOT
Systematic name | M35039
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cafe-au-lait spot
Full description | Cafe-au-lait spots are hyperpigmented lesions that can vary in color from light brown to dark brown with smooth borders and having a size of 1.5 cm or more in adults and 0.5 cm or more in children. [HPO:probinson]

Standard name | HP_DRY_SKIN
Systematic name | M35040
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dry skin
Full description | Skin characterized by the lack of natural or normal moisture. [HPO:probinson]

Standard name | HP_CYANOSIS
Systematic name | M35041
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cyanosis
Full description | Bluish discoloration of the skin and mucosa due to poor circulation or inadequate oxygenation of arterial or capillary blood. [PMID:25658213]

Standard name | HP_HYPERKERATOSIS
Systematic name | M35042
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperkeratosis
Full description | Hyperkeratosis is thickening of the outer layer of the skin, the stratum corneum, which is composed of large, polyhedral, plate-like envelopes filled with keratin which are the dead cells that have migrated up from the stratum granulosum. [HPO:probinson]

Standard name | HP_THIN_SKIN
Systematic name | M35043
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thin skin
Full description | Reduction in thickness of the skin, generally associated with a loss of suppleness and elasticity of the skin. [HPO:probinson]

Standard name | HP_ECZEMA
Systematic name | M35044
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Eczema
Full description | Eczema is a form of dermatitis. The term eczema is broadly applied to a range of persistent skin conditions and can be related to a number of underlying conditions. Manifestations of eczema can include dryness and recurring skin rashes with redness, skin edema, itching and dryness, crusting, flaking, blistering, cracking, oozing, or bleeding. [HPO:probinson]

Standard name | HP_CUTIS_MARMORATA
Systematic name | M35045
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cutis marmorata
Full description | A reticular discoloration of the skin with cyanotic (reddish-blue appearing) areas surrounding pale central areas due to dilation of capillary blood vessels and stagnation of blood within the vessels. Cutis marmorata, also called livedo reticularis, generally occurs on the legs, arms and trunk and is often more severe in cold weather. [HPO:sdoelken]

Standard name | HP_HYPOHIDROSIS
Systematic name | M35046
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypohidrosis
Full description | Abnormally diminished capacity to sweat. [HPO:probinson]

Standard name | HP_PETECHIAE
Systematic name | M35047
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Petechiae
Full description | Petechiae are pinpoint-sized reddish/purple spots, resembling a rash, that appear just under the skin or a mucous membrane when capillaries have ruptured and some superficial bleeding into the skin has happened. This term refers to an abnormally increased susceptibility to developing petechiae. [HPO:probinson]

Standard name | HP_ECTODERMAL_DYSPLASIA
Systematic name | M35048
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ectodermal dysplasia
Full description | Ectodermal dysplasia is a group of conditions in which there is abnormal development of the skin, hair, nails, teeth, or sweat glands. [HPO:probinson]

Standard name | HP_ANHIDROSIS
Systematic name | M35049
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anhidrosis
Full description | Inability to sweat. [HPO:probinson]

Standard name | HP_ABNORMAL_SWEAT_GLAND_MORPHOLOGY
Systematic name | M35050
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal sweat gland morphology
Full description | Any structural abnormality of the sweat gland. [HPO:probinson]

Standard name | HP_CUTIS_LAXA
Systematic name | M35051
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cutis laxa
Full description | Wrinkled, redundant, inelastic and sagging skin. [HPO:probinson]

Standard name | HP_HYPEREXTENSIBLE_SKIN
Systematic name | M35052
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperextensible skin
Full description | A condition in which the skin can be stretched beyond normal, and then returns to its initial position. [HPO:sdoelken]

Standard name | HP_HYPERHIDROSIS
Systematic name | M35053
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperhidrosis
Full description | Abnormal excessive perspiration (sweating) despite the lack of appropriate stimuli like hot and humid weather. [HPO:probinson]

Standard name | HP_ECZEMATOID_DERMATITIS
Systematic name | M35054
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Eczematoid dermatitis
Full description |

Standard name | HP_SOFT_SKIN
Systematic name | M35055
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Soft skin
Full description | Subjective impression of increased softness upon palpitation of the skin. [HPO:probinson]

Standard name | HP_BRUISING_SUSCEPTIBILITY
Systematic name | M35056
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bruising susceptibility
Full description | An ecchymosis (bruise) refers to the skin discoloration caused by the escape of blood into the tissues from ruptured blood vessels. This term refers to an abnormally increased susceptibility to bruising. The corresponding phenotypic abnormality is generally elicited on medical history as a report of frequent ecchymoses or bruising without adequate trauma. [HPO:probinson]

STANDARD_NAME="HP_PURPURA" SYSTEMATIC_NAME="M35057" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="" AUTHORS="" GEOID="" EXACT_SOURCE="HP:0000979" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="https://hpo.jax.org/app/browse/term/HP:0000979" CHIP="Human_NCBI_Gene_ID" CATEGORY_CODE="C5" SUB_CATEGORY_CODE="HPO" CONTRIBUTOR="Human Phenotype Ontology Group" CONTRIBUTOR_ORG="The Jackson Laboratory (JAX)" DESCRIPTION_BRIEF="Purpura" DESCRIPTION_FULL="Purpura (from Latin: purpura, meaning \purple\) is the appearance of red or purple discolorations on the skin that do not blanch on applying pressure. They are caused by bleeding underneath the skin. This term refers to an abnormally increased susceptibility to developing purpura. Purpura are larger than petechiae. [HPO:probinson, PMID:11515831]"

Standard name | HP_PALLOR
Systematic name | M35058
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pallor
Full description | Abnormally pale skin. [HPO:probinson]

Standard name | HP_PALMOPLANTAR_KERATODERMA
Systematic name | M35059
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Palmoplantar keratoderma
Full description | Abnormal thickening of the skin of the palms of the hands and the soles of the feet. [HPO:probinson]

Standard name | HP_SKIN_RASH
Systematic name | M35060
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Skin rash
Full description | A red eruption of the skin. [HPO:probinson]

Standard name | HP_PRURITUS
Systematic name | M35061
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pruritus
Full description | Pruritus is an itch or a sensation that makes a person want to scratch. This term refers to an abnormally increased disposition to experience pruritus. [HPO:probinson]

Standard name | HP_XANTHOMATOSIS
Systematic name | M35062
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Xanthomatosis
Full description | The presence of multiple xanthomas (xanthomata) in the skin. Xanthomas are yellowish, firm, lipid-laden nodules in the skin. [HPO:curators]

Standard name | HP_CUTANEOUS_PHOTOSENSITIVITY
Systematic name | M35063
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cutaneous photosensitivity
Full description | An increased sensitivity of the skin to light. Photosensitivity may result in a rash upon exposure to the sun (which is known as photodermatosis). Photosensitivity can be diagnosed by phototests in which light is shone on small areas of skin. [HPO:probinson]

Standard name | HP_MOLLUSCOID_PSEUDOTUMORS
Systematic name | M35064
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Molluscoid pseudotumors
Full description | Bluish-grey, spongy nodules associated with scars over pressure points and easily traumatized areas like the elbows and knees. [HPO:probinson]

Standard name | HP_MELANOCYTIC_NEVUS
Systematic name | M35065
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Melanocytic nevus
Full description | A oval and round, colored (usually medium-to dark brown, reddish brown, or flesh colored) lesion. Typically, a melanocytic nevus is less than 6 mm in diameter, but may be much smaller or larger. [HPO:probinson]

Standard name | HP_FACIAL_CAPILLARY_HEMANGIOMA
Systematic name | M35066
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial capillary hemangioma
Full description | Hemangioma, a benign tumor of the vascular endothelial cells with small endothelial spaces, occurring in the face. []

Standard name | HP_AXILLARY_FRECKLING
Systematic name | M35067
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Axillary freckling
Full description | The presence in the axillary region (armpit) of an increased number of freckles, small circular spots on the skin that are darker than the surrounding skin because of deposits of melanin. [PMID:12186179]

Standard name | HP_HYPERTRICHOSIS
Systematic name | M35068
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypertrichosis
Full description | Hypertrichosis is increased hair growth that is abnormal in quantity or location. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_SKIN_PIGMENTATION
Systematic name | M35069
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of skin pigmentation
Full description | An abnormality of the pigmentation of the skin. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_SUBCUTANEOUS_FAT_TISSUE
Systematic name | M35070
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of subcutaneous fat tissue
Full description |

Standard name | HP_MULTIPLE_LENTIGINES
Systematic name | M35071
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Multiple lentigines
Full description | Presence of an unusually high number of lentigines (singular: lentigo), which are flat, tan to brown oval spots. [HPO:probinson]

Standard name | HP_LYMPHEDEMA
Systematic name | M35072
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lymphedema
Full description | Localized fluid retention and tissue swelling caused by a compromised lymphatic system. [HPO:sdoelken]

Standard name | HP_DERMATOLOGICAL_MANIFESTATIONS_OF_SYSTEMIC_DISORDERS
Systematic name | M35073
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dermatological manifestations of systemic disorders
Full description |

Standard name | HP_HIRSUTISM
Systematic name | M35074
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hirsutism
Full description | Abnormally increased hair growth referring to a male pattern of body hair (androgenic hair). [HPO:sdoelken]

Standard name | HP_TELANGIECTASIA
Systematic name | M35075
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Telangiectasia
Full description | Telangiectasias refer to small dilated blood vessels located near the surface of the skin or mucous membranes, measuring between 0.5 and 1 millimeter in diameter. Telangiectasia are located especially on the tongue, lips, palate, fingers, face, conjunctiva, trunk, nail beds, and fingertips. [HPO:probinson]

Standard name | HP_HYPOPIGMENTATION_OF_THE_SKIN
Systematic name | M35076
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypopigmentation of the skin
Full description | A reduction of skin color related to a decrease in melanin production and deposition. [HPO:probinson]

Standard name | HP_MULTIPLE_LIPOMAS
Systematic name | M35077
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Multiple lipomas
Full description | The presence of multiple lipomas (a type of benign tissue made of fatty tissue). [HPO:sdoelken]

Standard name | HP_ANGIOKERATOMA
Systematic name | M35078
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Angiokeratoma
Full description | A vascular lesion defined histologically as one or more dilated blood vessels lying directly subepidermal and showing an epidermal proliferative reaction. Clinically, angiokeratoma presents as a small, raised, dark-red spot. [HPO:probinson, PMID:8993949]

Standard name | HP_ANEMIC_PALLOR
Systematic name | M35079
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anemic pallor
Full description | A type of pallor that is secondary to the presence of anemia. [HPO:probinson]

Standard name | HP_ABNORMAL_PALMAR_DERMATOGLYPHICS
Systematic name | M35080
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal palmar dermatoglyphics
Full description | An abnormality of the dermatoglyphs, i.e., an abnormality of the patterns of ridges of the skin of palm of hand. [HPO:probinson]

Standard name | HP_ERYTHRODERMA
Systematic name | M35081
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Erythroderma
Full description | An inflammatory exfoliative dermatosis involving nearly all of the surface of the skin. Erythroderma develops suddenly. A patchy erythema may generalize and spread to affect most of the skin. Scaling may appear in 2-6 days and be accompanied by hot, red, dry skin, malaise, and fever. [HPO:probinson]

Standard name | HP_ALBINISM
Systematic name | M35082
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Albinism
Full description | An abnormal reduction in the amount of pigmentation (reduced or absent) of skin, hair and eye (iris and retina). [HPO:sdoelken]

Standard name | HP_URTICARIA
Systematic name | M35083
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Urticaria
Full description | Raised, well-circumscribed areas of erythema and edema involving the dermis and epidermis. Urticaria is intensely pruritic, and blanches completely with pressure. [HPO:probinson]

Standard name | HP_SOFT_DOUGHY_SKIN
Systematic name | M35084
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Soft, doughy skin
Full description | A skin texture that is unusually soft (and may feel silky), and has a malleable consistency resembling that of dough. []

Standard name | HP_POIKILODERMA
Systematic name | M35085
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Poikiloderma
Full description | Poikiloderma refers to a patch of skin with (1) reticulated hypopigmentation and hyperpigmentation, (2) wrinkling secondary to epidermal atrophy, and (3) telangiectasias. [HPO:probinson]

Standard name | HP_FRAGILE_SKIN
Systematic name | M35086
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Fragile skin
Full description | Skin that splits easily with minimal injury. [HPO:probinson]

Standard name | HP_SUBCUTANEOUS_LIPOMA
Systematic name | M35087
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Subcutaneous lipoma
Full description | The presence of subcutaneous lipoma. [HPO:probinson]

Standard name | HP_ABSENT_DISTAL_INTERPHALANGEAL_CREASES
Systematic name | M35088
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Absent distal interphalangeal creases
Full description | Absence of the distal interphalangeal flexion creases of the fingers. [HPO:curators]

Standard name | HP_HYPERMELANOTIC_MACULE
Systematic name | M35089
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypermelanotic macule
Full description | A hyperpigmented circumscribed area of change in normal skin color without elevation or depression of any size. [DDD:cmoss]

Standard name | HP_PARAKERATOSIS
Systematic name | M35090
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Parakeratosis
Full description | Abnormal formation of the keratinocytes of the epidermis characterized by persistence of nuclei, incomplete formation of keratin, and moistness and swelling of the keratinocytes. [HPO:probinson]

Standard name | HP_FACIAL_ERYTHEMA
Systematic name | M35091
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial erythema
Full description | Redness of the skin of the face, caused by hyperemia of the capillaries in the lower layers of the skin. [HPO:probinson]

Standard name | HP_PROMINENT_SCALP_VEINS
Systematic name | M35092
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Prominent scalp veins
Full description |

Standard name | HP_VITILIGO
Systematic name | M35093
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Vitiligo
Full description |

Standard name | HP_INTERMITTENT_JAUNDICE
Systematic name | M35094
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Intermittent jaundice
Full description | Jaundice that is sometimes present, sometimes not. [HPO:curators]

Standard name | HP_ATOPIC_DERMATITIS
Systematic name | M35095
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Atopic dermatitis
Full description | Atopic dermatitis (AD) or atopic eczema is an itchy, inflammatory skin condition with a predilection for the skin flexures. It is characterized by poorly defined erythema with edema, vesicles, and weeping in the acute stage and skin thickening (lichenification) in the chronic stage. [HPO:probinson, PMID:27904186]

Standard name | HP_CAVERNOUS_HEMANGIOMA
Systematic name | M35096
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cavernous hemangioma
Full description | The presence of a cavernous hemangioma. A hemangioma characterized by large endothelial spaces (caverns) is called a cavernous hemangioma. [HPO:probinson]

Standard name | HP_SEBORRHEIC_DERMATITIS
Systematic name | M35097
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Seborrheic dermatitis
Full description | Seborrheic dermatitis is a form of eczema which is closely related to dandruff. It causes dry or greasy peeling of the scalp, eyebrows, and face, and sometimes trunk. [HPO:curators]

Standard name | HP_HYPOPIGMENTED_SKIN_PATCHES
Systematic name | M35098
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypopigmented skin patches
Full description |

Standard name | HP_NUMEROUS_NEVI
Systematic name | M35099
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Numerous nevi
Full description |

Standard name | HP_ERYSIPELAS
Systematic name | M35100
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Erysipelas
Full description | Increased susceptibility to erysipelas, as manifested by a medical history of repeated episodes of erysipelas, which is a superficial infection of the skin, typically involving the lymphatic system. [HPO:probinson]

Standard name | HP_MILIA
Systematic name | M35101
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Milia
Full description | Presence of multiple small cysts containing keratin (skin protein) and presenting as tiny pearly-white bumps just under the surface of the skin. [HPO:probinson]

Standard name | HP_APLASIA_CUTIS_CONGENITA
Systematic name | M35102
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aplasia cutis congenita
Full description | A developmental defect resulting in the congenital absence of skin in multiple or solitary non-inflammatory, well-demarcated, oval or circular ulcers with a diameter of about 1 to 2 cm. Aplasia cutis congenita most commonly occurs on the scalp, but may present in the face, trunk, or limbs. [HPO:probinson]

Standard name | HP_POOR_WOUND_HEALING
Systematic name | M35103
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Poor wound healing
Full description | A reduced ability to heal cutaneous wounds. [HPO:probinson]

Standard name | HP_PTERYGIUM
Systematic name | M35104
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pterygium
Full description | Pterygia are 'winglike' triangular membranes occurring in the neck, eyes, knees, elbows, ankles or digits. [HPO:probinson]

Standard name | HP_AXILLARY_PTERYGIUM
Systematic name | M35105
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Axillary pterygium
Full description | Presence of a cutaneous membrane (flap) in the armpit. []

Standard name | HP_ACNE
Systematic name | M35106
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Acne
Full description | A skin condition in which there is an increase in sebum secretion by the pilosebaceous apparatus associated with open comedones (blackheads), closed comedones (whiteheads), and pustular nodules (papules, pustules, and cysts). [HPO:probinson]

Standard name | HP_ACROCYANOSIS
Systematic name | M35107
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Acrocyanosis
Full description |

Standard name | HP_STRIAE_DISTENSAE
Systematic name | M35108
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Striae distensae
Full description | Thinned, erythematous, depressed bands of atrophic skin. Initially, striae appear as flattened and thinned, pinkish linear regions of the skin. Striae tend to enlarge in length and become reddish or purplish. Later, striae tend to appear as white, depressed bands that are parallel to the lines of skin tension. Striae distensae occur most often in areas that have been subject to distension such as the lower back, buttocks, thighs, breast, abdomen, and shoulders. [HPO:probinson]

Standard name | HP_NEUROFIBROMAS
Systematic name | M35109
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neurofibromas
Full description | The presence of multiple cutaneous neurofibromas. [HPO:probinson]

Standard name | HP_EPISODIC_HYPERHIDROSIS
Systematic name | M35110
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Episodic hyperhidrosis
Full description | Intermittent episodes of abnormally increased perspiration. [HPO:probinson]

Standard name | HP_MOTTLED_PIGMENTATION
Systematic name | M35111
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mottled pigmentation
Full description | Patchy and irregular skin pigmentation. [HPO:probinson]

Standard name | HP_THICKENED_SKIN
Systematic name | M35112
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thickened skin
Full description | Laminar thickening of skin. [HPO:sdoelken]

Standard name | HP_CIGARETTE_PAPER_SCARS
Systematic name | M35113
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cigarette-paper scars
Full description | Thin (atrophic) and wide scars. [HPO:probinson]

Standard name | HP_ATROPHIC_SCARS
Systematic name | M35114
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Atrophic scars
Full description | Scars that form a depression compared to the level of the surrounding skin because of damage to the collagen, fat or other tissues below the skin. [HPO:probinson]

Standard name | HP_BILIARY_TRACT_ABNORMALITY
Systematic name | M35115
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Biliary tract abnormality
Full description | An abnormality of the biliary tree. [HPO:probinson]

Standard name | HP_CHOLELITHIASIS
Systematic name | M35116
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cholelithiasis
Full description | Hard, pebble-like deposits that form within the gallbladder. [HPO:probinson]

Standard name | HP_CHOLECYSTITIS
Systematic name | M35117
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cholecystitis
Full description | The presence of inflammatory changes in the gallbladder. [HPO:probinson]

Standard name | HP_ECTOPIA_LENTIS
Systematic name | M35118
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ectopia lentis
Full description | Dislocation or malposition of the crystalline lens of the eye. A partial displacement (or dislocation) of the lens is described as a subluxation of the lens, while a complete displacement is termed luxation of the lens. A complete displacement occurs if the lens is completely outside the patellar fossa of the lens, either in the anterior chamber, in the vitreous, or directly on the retina. If the lens is partially displaced but still contained within the lens space, then it is termed subluxation. [HPO:probinson]

Standard name | HP_PAPILLEDEMA
Systematic name | M35119
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Papilledema
Full description | Papilledema refers to edema (swelling) of the optic disc secondary to any factor which increases cerebral spinal fluid pressure. [HPO:probinson]

Standard name | HP_DEVELOPMENTAL_GLAUCOMA
Systematic name | M35120
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Developmental glaucoma
Full description | Glaucoma which forms during the early years of a child's life is called developmental or congenital glaucoma. []

Standard name | HP_ABNORMALLY_LARGE_GLOBE
Systematic name | M35121
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormally large globe
Full description | Diffusely large eye (with megalocornea) without glaucoma. [HPO:probinson]

Standard name | HP_ABSENT_LACRIMAL_PUNCTUM
Systematic name | M35122
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Absent lacrimal punctum
Full description | No identifiable superior and/or inferior lacrimal punctum. [PMID:19125427]

Standard name | HP_OPTIC_NERVE_DYSPLASIA
Systematic name | M35123
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Optic nerve dysplasia
Full description | The presence of developmental dysplasia of the optic nerve. [HPO:probinson]

Standard name | HP_IRIDOCYCLITIS
Systematic name | M35124
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Iridocyclitis
Full description | A type of anterior uveitis, in which there is Inflammation of the iris and the ciliary body. [HPO:probinson]

Standard name | HP_KERATOCONJUNCTIVITIS
Systematic name | M35125
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Keratoconjunctivitis
Full description | Inflammation of the cornea and conjunctiva. [HPO:probinson]

Standard name | HP_HETEROCHROMIA_IRIDIS
Systematic name | M35126
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Heterochromia iridis
Full description | Heterochromia iridis is a difference in the color of the iris in the two eyes. [HPO:probinson]

Standard name | HP_ANGIOID_STREAKS_OF_THE_FUNDUS
Systematic name | M35127
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Angioid streaks of the fundus
Full description | Irregular lines in the deep retina that are typically configured in a radiating fashion and emanate from the optic disc. Angioid streaks are crack-like dehiscences in abnormally thickened and calcified Bruch's membrane, resulting in atrophy of the overlying retinal pigment epithelium. They may be associated with a number of endocrine, metabolic, and connective tissue abnormalities but are frequently idiopathic. [HPO:probinson, ORCID:0000-0003-0986-4123, PMID:30844178]

Standard name | HP_ABNORMAL_MACULAR_MORPHOLOGY
Systematic name | M35128
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal macular morphology
Full description | A structural abnormality of the macula lutea, which is an oval-shaped highly pigmented yellow spot near the center of the retina. [HPO:probinson, PMID:16255686]

Standard name | HP_MACULAR_HYPOPLASIA
Systematic name | M35129
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Macular hypoplasia
Full description | Underdevelopment of the macula lutea. [HPO:probinson]

Standard name | HP_RETINAL_ATROPHY
Systematic name | M35130
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retinal atrophy
Full description | Well-demarcated area(s) of partial or complete depigmentation in the fundus, reflecting atrophy of the retinal pigment epithelium with associated retinal photoreceptor loss. [ORCID:0000-0003-0986-4123]

Standard name | HP_OCULAR_ALBINISM
Systematic name | M35131
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ocular albinism
Full description | An abnormal reduction in the amount of pigmentation (reduced or absent) of the iris and retina. [HPO:probinson]

Standard name | HP_LEBER_OPTIC_ATROPHY
Systematic name | M35132
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Leber optic atrophy
Full description | Degeneration of retinal ganglion cells and their axons. [HPO:probinson]

Standard name | HP_XANTHELASMA
Systematic name | M35133
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Xanthelasma
Full description | The presence of xanthomata in the skin of the eyelid. [HPO:curators]

Standard name | HP_POSTERIOR_POLAR_CATARACT
Systematic name | M35134
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Posterior polar cataract
Full description | A polar cataract that affects the posterior pole of the lens. [HPO:probinson]

Standard name | HP_SUDDEN_LOSS_OF_VISUAL_ACUITY
Systematic name | M35135
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sudden loss of visual acuity
Full description | Severe loss of visual acuity within hours or days. This is characteristic of Leber hereditary optic neuropathy. [HPO:probinson]

Standard name | HP_JUVENILE_CATARACT
Systematic name | M35136
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Juvenile cataract
Full description | A type of cataract that is not apparent at birth but that arises in childhood or adolescence. [HPO:probinson]

Standard name | HP_KERATOGLOBUS
Systematic name | M35137
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Keratoglobus
Full description | Limbus-to-limbus corneal thinning, often greatest in the periphery, with globular protrusion of the cornea. [PMID:19667340]

Standard name | HP_ABNORMALITY_OF_CORNEAL_SIZE
Systematic name | M35138
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of corneal size
Full description | Any abnormality of the size or morphology of the cornea. [HPO:curators]

Standard name | HP_VISUAL_FIELD_DEFECT
Systematic name | M35139
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Visual field defect
Full description |

Standard name | HP_CRYPTOPHTHALMOS
Systematic name | M35140
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cryptophthalmos
Full description | Cryptophthalmos is a condition of total absence of eyelids and the skin of forehead is continuous with that of cheek, in which the eyeball is completely concealed by the skin, which is stretched over the orbital cavity. [HPO:probinson, PMID:19125427]

Standard name | HP_CORNEAL_DYSTROPHY
Systematic name | M35141
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Corneal dystrophy
Full description | An abnormality of the cornea that is characterized by opacity of one or parts of the cornea. [HPO:probinson]

Standard name | HP_LENS_SUBLUXATION
Systematic name | M35142
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lens subluxation
Full description | Partial dislocation of the lens of the eye. [HPO:probinson]

Standard name | HP_CONSTRICTION_OF_PERIPHERAL_VISUAL_FIELD
Systematic name | M35143
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Constriction of peripheral visual field
Full description | An absolute or relative decrease in retinal sensitivity extending from edge (periphery) of the visual field in a concentric pattern. The visual field is the area that is perceived simultaneously by a fixating eye. [ORCID:0000-0003-0986-4123]

Standard name | HP_CHORIORETINAL_DYSTROPHY
Systematic name | M35144
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Chorioretinal dystrophy
Full description |

Standard name | HP_RETINAL_ARTERIOLAR_TORTUOSITY
Systematic name | M35145
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retinal arteriolar tortuosity
Full description | The presence of an increased number of twists and turns of the retinal arterioles. [HPO:probinson]

Standard name | HP_ALTERNATING_ESOTROPIA
Systematic name | M35146
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Alternating esotropia
Full description | Esotropia in which either eye may be used for fixation. [ORCID:0000-0003-0986-4123]

Standard name | HP_OPTIC_NEUROPATHY
Systematic name | M35147
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Optic neuropathy
Full description |

Standard name | HP_CHOROIDEREMIA
Systematic name | M35148
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Choroideremia
Full description |

Standard name | HP_LIMBAL_DERMOID
Systematic name | M35149
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Limbal dermoid
Full description | A benign tumor typically found at the junction of the cornea and sclera (limbal epibullar dermoid). [HPO:probinson]

Standard name | HP_SEVERELY_REDUCED_VISUAL_ACUITY
Systematic name | M35150
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Severely reduced visual acuity
Full description | Severe reduction of the ability to see defined as visual acuity less than 6/60 (20/200 in US notation; 0.1 in decimal notation) but at least 3/60 (20/400 in US notation; 0.05 in decimal notation). [PMID:28779882]

Standard name | HP_ORBITAL_CYST
Systematic name | M35151
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Orbital cyst
Full description | Presence of a cyst in the region of the periorbital tissues. Orbital cysts can be derived from epithelial or glandular tissue within or surrounding the orbit (lacrimal glands, salivary glands, conjunctival, oral, nasal, or sinus epithelium). [HPO:probinson]

Standard name | HP_RETINAL_EXUDATE
Systematic name | M35152
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Retinal exudate
Full description | Fluid which has escaped from retinal blood vessels with a high concentration of lipid, protein, and cellular debris with a typically bright, reflective, white or cream colored appearance on the surface of the retina. [HPO:probinson]

Standard name | HP_IMPAIRED_HORIZONTAL_SMOOTH_PURSUIT
Systematic name | M35153
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Impaired horizontal smooth pursuit
Full description | An abnormality of ocular smooth pursuit characterized by an impairment of the ability to track horizontally moving objects. [HPO:probinson]

Standard name | HP_SACCADIC_SMOOTH_PURSUIT
Systematic name | M35154
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Saccadic smooth pursuit
Full description | An abnormality of tracking eye movements in which smooth pursuit is interrupted by an abnormally high number of saccadic movements. [HPO:probinson]

Standard name | HP_SEPTATE_VAGINA
Systematic name | M35155
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Septate vagina
Full description | The presence of a vaginal septum, thereby creating a vaginal duplication. The septum is longitudinal in the majority of cases. [HPO:curators]

Standard name | HP_BRACHYDACTYLY
Systematic name | M35156
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Brachydactyly
Full description | Digits that appear disproportionately short compared to the hand/foot. The word brachydactyly is used here to describe a series distinct patterns of shortened digits (brachydactyly types A-E). This is the sense used here. [HPO:probinson]

STANDARD_NAME="HP_SYNDACTYLY" SYSTEMATIC_NAME="M35157" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="" AUTHORS="" GEOID="" EXACT_SOURCE="HP:0001159" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="https://hpo.jax.org/app/browse/term/HP:0001159" CHIP="Human_NCBI_Gene_ID" CATEGORY_CODE="C5" SUB_CATEGORY_CODE="HPO" CONTRIBUTOR="Human Phenotype Ontology Group" CONTRIBUTOR_ORG="The Jackson Laboratory (JAX)" DESCRIPTION_BRIEF="Syndactyly" DESCRIPTION_FULL="Webbing or fusion of the fingers or toes, involving soft parts only or including bone structure. Bony fusions are referred to as \bony\ syndactyly if the fusion occurs in a radio-ulnar axis. Fusions of bones of the fingers or toes in a proximo-distal axis are referred to as \symphalangism\. [HPO:probinson]"

Standard name | HP_POSTAXIAL_HAND_POLYDACTYLY
Systematic name | M35158
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Postaxial hand polydactyly
Full description | Supernumerary digits located at the ulnar side of the hand (that is, on the side with the fifth finger). [HPO:sdoelken]

Standard name | HP_ABNORMALITY_OF_THE_METACARPAL_BONES
Systematic name | M35159
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the metacarpal bones
Full description | An abnormality of the metacarpal bones. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_FINGER
Systematic name | M35160
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of finger
Full description | An anomaly of a finger. [HPO:probinson]

Standard name | HP_BROAD_PALM
Systematic name | M35161
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad palm
Full description | For children from birth to 4 years of age the palm width is more than 2 SD above the mean; for children from 4 to 16 years of age the palm width is above the 95th centile; or, the width of the palm appears disproportionately wide for the length. [HPO:probinson, PMID:19125433]

Standard name | HP_ABNORMAL_THUMB_MORPHOLOGY
Systematic name | M35162
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal thumb morphology
Full description | An abnormal structure of the first digit of the hand. []

Standard name | HP_LARGE_HANDS
Systematic name | M35163
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Large hands
Full description |

Standard name | HP_PREAXIAL_HAND_POLYDACTYLY
Systematic name | M35164
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Preaxial hand polydactyly
Full description | Supernumerary digits located at the radial side of the hand. Polydactyly (supernumerary digits) involving the thumb occurs in many distinct forms of high variability and severity. Ranging from fleshy nubbins over varying degrees of partial duplication/splitting to completely duplicated or even triplicated thumbs or preaxial (on the radial side of the hand) supernumerary digits. [HPO:probinson]

Standard name | HP_ULNAR_CLAW
Systematic name | M35165
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ulnar claw
Full description | An abnormal hand position characterized by hyperextension of the fourth and fifth fingers at the metacarpophalangeal joints and flexion of the interphalangeal joints of the same fingers such that they are curled towards the palm. [HPO:probinson]

Standard name | HP_HAND_OLIGODACTYLY
Systematic name | M35166
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hand oligodactyly
Full description | A developmental defect resulting in the presence of fewer than the normal number of fingers. [HPO:probinson]

Standard name | HP_ADDUCTED_THUMB
Systematic name | M35167
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Adducted thumb
Full description | In the resting position, the tip of the thumb is on, or near, the palm, close to the base of the fourth or fifth finger. [PMID:19125433]

Standard name | HP_TAPERED_FINGER
Systematic name | M35168
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tapered finger
Full description | The gradual reduction in girth of the finger from proximal to distal. [PMID:19125433]

Standard name | HP_HYPEREXTENSIBILITY_OF_THE_FINGER_JOINTS
Systematic name | M35169
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperextensibility of the finger joints
Full description | The ability of the finger joints to move beyond their normal range of motion. [HPO:curators]

Standard name | HP_HAND_CLENCHING
Systematic name | M35170
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hand clenching
Full description | An abnormal hand posture in which the hands are clenched to fists. All digits held completely flexed at the metacarpophalangeal and interphalangeal joints. [HPO:sdoelken, PMID:10085502]

Standard name | HP_ABNORMALITY_OF_THE_CARPAL_BONES
Systematic name | M35171
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the carpal bones
Full description | An abnormality affecting the carpal bones of the wrist (scaphoid, lunate, triquetral, pisiform, trapezium, trapezoid, capitate, hamate). [HPO:probinson]

Standard name | HP_ULNAR_DEVIATION_OF_THE_HAND_OR_OF_FINGERS_OF_THE_HAND
Systematic name | M35172
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ulnar deviation of the hand or of fingers of the hand
Full description |

Standard name | HP_ABNORMALITIES_OF_PLACENTA_OR_UMBILICAL_CORD
Systematic name | M35173
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormalities of placenta or umbilical cord
Full description | An abnormality of the placenta (the organ that connects the developing fetus to the uterine wall) or of the umbilical cord (the cord that connects the fetus to the placenta). [HPO:curators]

Standard name | HP_SHORT_UMBILICAL_CORD
Systematic name | M35174
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short umbilical cord
Full description | Decreased length of the umbilical cord. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_PRENATAL_DEVELOPMENT_OR_BIRTH
Systematic name | M35175
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of prenatal development or birth
Full description | An abnormality of the fetus or the birth of the fetus, excluding structural abnormalities. [HPO:probinson]

Standard name | HP_TRIPHALANGEAL_THUMB
Systematic name | M35176
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Triphalangeal thumb
Full description | A thumb with three phalanges in a single, proximo-distal axis. Thus, this term applies if the thumb has an accessory phalanx, leading to a digit like appearance of the thumb. [HPO:probinson, PMID:19125433]

Standard name | HP_DISTAL_SYMPHALANGISM_OF_HANDS
Systematic name | M35177
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Distal symphalangism of hands
Full description | The term distal symphalangism refers to a bony fusion of the distal and middle phalanges of the digits of the hand, in other words the distal interphalangeal joint (DIJ) is missing which can be seen either on x-rays or as an absence of the distal interphalangeal finger creases. [HPO:sdoelken]

Standard name | HP_ABNORMAL_FINGERTIP_MORPHOLOGY
Systematic name | M35178
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal fingertip morphology
Full description | An abnormal structure of the tip (end) of a finger. []

STANDARD_NAME="HP_PROMINENT_FINGERTIP_PADS" SYSTEMATIC_NAME="M35179" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="" AUTHORS="" GEOID="" EXACT_SOURCE="HP:0001212" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="https://hpo.jax.org/app/browse/term/HP:0001212" CHIP="Human_NCBI_Gene_ID" CATEGORY_CODE="C5" SUB_CATEGORY_CODE="HPO" CONTRIBUTOR="Human Phenotype Ontology Group" CONTRIBUTOR_ORG="The Jackson Laboratory (JAX)" DESCRIPTION_BRIEF="Prominent fingertip pads" DESCRIPTION_FULL="A soft tissue prominence of the ventral aspects of the fingertips. The term \persistent fetal fingertip pads\ is often used as a synonym, but should better not be used because it implies knowledge of history of the patient which often does not exist. [HPO:probinson]"

Standard name | HP_DELAYED_OSSIFICATION_OF_CARPAL_BONES
Systematic name | M35180
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delayed ossification of carpal bones
Full description | Ossification of carpal bones occurs later than age-adjusted norms. [HPO:probinson]

Standard name | HP_CLUBBING
Systematic name | M35181
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Clubbing
Full description | Broadening of the soft tissues (non-edematous swelling of soft tissues) of the digital tips in all dimensions associated with an increased longitudinal and lateral curvature of the nails. [HPO:sdoelken, PMID:19125433]

Standard name | HP_AUTOAMPUTATION
Systematic name | M35182
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Autoamputation
Full description | Spontaneous detachment (amputation) of an appendage from the body. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_THENAR_EMINENCE
Systematic name | M35183
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the thenar eminence
Full description | An abnormality of the thenar eminence, i.e., of the muscle on the palm of the human hand just beneath the thumb. [HPO:curators]

Standard name | HP_BROAD_METACARPALS
Systematic name | M35184
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad metacarpals
Full description | Abnormally broad metacarpal bones. [HPO:probinson]

Standard name | HP_ABNORMAL_FINGERNAIL_MORPHOLOGY
Systematic name | M35185
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal fingernail morphology
Full description | An abnormality of the fingernails. [HPO:probinson]

Standard name | HP_2_3_FINGER_SYNDACTYLY
Systematic name | M35186
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | 2-3 finger syndactyly
Full description | Syndactyly with fusion of fingers two and three. [HPO:sdoelken]

Standard name | HP_SLENDER_FINGER
Systematic name | M35187
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Slender finger
Full description | Fingers that are disproportionately narrow (reduced girth) for the hand/foot size or build of the individual. [PMID:19125433]

Standard name | HP_WRIST_FLEXION_CONTRACTURE
Systematic name | M35188
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Wrist flexion contracture
Full description | A chronic loss of wrist joint motion due to structural changes in muscle, tendons, ligaments, or skin that prevent normal movement of the joints of the wrist. [HPO:probinson]

Standard name | HP_CAPITATE_HAMATE_FUSION
Systematic name | M35189
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Capitate-hamate fusion
Full description |

Standard name | HP_LETHARGY
Systematic name | M35190
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lethargy
Full description | A state of disinterestedness, listlessness, and indifference, resulting in difficulty performing simple tasks or concentrating. [HPO:probinson]

Standard name | HP_INTELLECTUAL_DISABILITY_MILD
Systematic name | M35191
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Intellectual disability, mild
Full description | Mild intellectual disability is defined as an intelligence quotient (IQ) in the range of 50-69. [HPO:probinson]

Standard name | HP_SPASTICITY
Systematic name | M35192
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Spasticity
Full description | A motor disorder characterized by a velocity-dependent increase in tonic stretch reflexes with increased muscle tone, exaggerated (hyperexcitable) tendon reflexes. [HPO:probinson]

Standard name | HP_SPASTIC_PARAPLEGIA
Systematic name | M35193
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Spastic paraplegia
Full description | Spasticity and weakness of the leg and hip muscles. [HPO:probinson]

Standard name | HP_COMA
Systematic name | M35194
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Coma
Full description | Complete absence of wakefulness and content of conscience, which manifests itself as a lack of response to any kind of external stimuli. [HPO:probinson]

Standard name | HP_DYSARTHRIA
Systematic name | M35195
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dysarthria
Full description | Dysarthric speech is a general description referring to a neurological speech disorder characterized by poor articulation. Depending on the involved neurological structures, dysarthria may be further classified as spastic, flaccid, ataxic, hyperkinetic and hypokinetic, or mixed. [HPO:curators]

Standard name | HP_EXCESSIVE_DAYTIME_SOMNOLENCE
Systematic name | M35196
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Excessive daytime somnolence
Full description | A state of abnormally strong desire for sleep during the daytime. []

Standard name | HP_SPASTIC_DIPLEGIA
Systematic name | M35197
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Spastic diplegia
Full description | Spasticity (neuromuscular hypertonia) primarily in the muscles of the legs, hips, and pelvis. [HPO:curators]

Standard name | HP_HYPOREFLEXIA
Systematic name | M35198
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyporeflexia
Full description | Reduction of neurologic reflexes such as the knee-jerk reaction. [HPO:probinson]

Standard name | HP_CHOREOATHETOSIS
Systematic name | M35199
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Choreoathetosis
Full description | Involuntary movements characterized by both athetosis (inability to sustain muscles in a fixed position) and chorea (widespread jerky arrhythmic movements). [HPO:probinson]

Standard name | HP_MENTAL_DETERIORATION
Systematic name | M35200
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mental deterioration
Full description | Loss of previously present mental abilities, generally in adults. [HPO:probinson]

Standard name | HP_HEMIPARESIS
Systematic name | M35201
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hemiparesis
Full description | Loss of strength in the arm, leg, and sometimes face on one side of the body. Hemiplegia refers to a complete loss of strength, whereas hemiparesis refers to an incomplete loss of strength. [HPO:probinson, UKB:tklockgether]

Standard name | HP_MOTOR_DELAY
Systematic name | M35202
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Motor delay
Full description | A type of Developmental delay characterized by a delay in acquiring motor skills. [HPO:probinson]

Standard name | HP_POLYNEUROPATHY
Systematic name | M35203
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Polyneuropathy
Full description | A generalized disorder of peripheral nerves. [HPO:curators]

Standard name | HP_CEREBELLAR_ATROPHY
Systematic name | M35204
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cerebellar atrophy
Full description | Atrophy (wasting) of the cerebellum. [HPO:probinson, PMID:12169461]

Standard name | HP_ABNORMAL_CORPUS_CALLOSUM_MORPHOLOGY
Systematic name | M35205
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal corpus callosum morphology
Full description | Abnormality of the corpus callosum. [HPO:probinson, PMID:21263138]

Standard name | HP_AGENESIS_OF_CORPUS_CALLOSUM
Systematic name | M35206
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Agenesis of corpus callosum
Full description | Absence of the corpus callosum as a result of the failure of the corpus callosum to develop, which can be the result of a failure in any one of the multiple steps of callosal development including cellular proliferation and migration, axonal growth or glial patterning at the midline. [HPO:curators]

Standard name | HP_HYPERTONIA
Systematic name | M35207
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypertonia
Full description | A condition in which there is increased muscle tone so that arms or legs, for example, are stiff and difficult to move. [HPO:probinson]

Standard name | HP_ORTHOSTATIC_HYPOTENSION
Systematic name | M35208
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Orthostatic hypotension
Full description | A form of hypotension characterized by a sudden fall in blood pressure that occurs when a person assumes a standing position. [HPO:probinson]

Standard name | HP_SYNCOPE
Systematic name | M35209
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Syncope
Full description | Syncope refers to a generalized weakness of muscles with loss of postural tone, inability to stand upright, and loss of consciousness. Once the patient is in a horizontal position, blood flow to the brain is no longer hindered by gravitation and consciousness is regained. Unconsciousness usually lasts for seconds to minutes. Headache and drowsiness (which usually follow seizures) do not follow a syncopal attack. Syncope results from a sudden impairment of brain metabolism usually due to a reduction in cerebral blood flow. [HPO:probinson]

Standard name | HP_TETANY
Systematic name | M35210
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tetany
Full description | A condition characterized by intermittent involuntary contraction of muscles (spasms) related to hypocalcemia or occasionally magnesium deficiency. []

Standard name | HP_BULBAR_PALSY
Systematic name | M35211
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bulbar palsy
Full description | Bulbar weakness (or bulbar palsy) refers to bilateral impairment of function of the lower cranial nerves IX, X, XI and XII, which occurs due to lower motor neuron lesion either at nuclear or fascicular level in the medulla or from bilateral lesions of the lower cranial nerves outside the brain-stem. Bulbar weakness is often associated with difficulty in chewing, weakness of the facial muscles, dysarthria, palatal weakness and regurgitation of fluids, dysphagia, and dysphonia. [HPO:curators]

Standard name | HP_AREFLEXIA
Systematic name | M35212
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Areflexia
Full description | Absence of neurologic reflexes such as the knee-jerk reaction. [HPO:probinson]

Standard name | HP_SPASTIC_TETRAPARESIS
Systematic name | M35213
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Spastic tetraparesis
Full description | Spastic weakness affecting all four limbs. [HPO:curators]

Standard name | HP_MENINGITIS
Systematic name | M35214
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Meningitis
Full description | Inflammation of the meninges. [HPO:probinson]

Standard name | HP_GAIT_DISTURBANCE
Systematic name | M35215
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gait disturbance
Full description | The term gait disturbance can refer to any disruption of the ability to walk. In general, this can refer to neurological diseases but also fractures or other sources of pain that is triggered upon walking. However, in the current context gait disturbance refers to difficulty walking on the basis of a neurological or muscular disease. [HPO:probinson, PMID:27770207]

Standard name | HP_CONFUSION
Systematic name | M35216
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Confusion
Full description | Lack of clarity and coherence of thought, perception, understanding, or action. [HPO:curators]

Standard name | HP_GENERALIZED_HYPOTONIA
Systematic name | M35217
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Generalized hypotonia
Full description | Generalized muscular hypotonia (abnormally low muscle tone). [HPO:curators]

Standard name | HP_ABNORMAL_CRANIAL_NERVE_MORPHOLOGY
Systematic name | M35218
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal cranial nerve morphology
Full description | Structural abnormality affecting one or more of the cranial nerves, which emerge directly from the brain stem. [HPO:probinson]

Standard name | HP_CRANIAL_NERVE_COMPRESSION
Systematic name | M35219
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cranial nerve compression
Full description |

Standard name | HP_STROKE
Systematic name | M35220
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Stroke
Full description | Sudden impairment of blood flow to a part of the brain due to occlusion or rupture of an artery to the brain. [HPO:probinson]

Standard name | HP_ENCEPHALOPATHY
Systematic name | M35221
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Encephalopathy
Full description | Encephalopathy is a term that means brain disease, damage, or malfunction. In general, encephalopathy is manifested by an altered mental state. [HPO:probinson, KI:phemming]

Standard name | HP_PARKINSONISM
Systematic name | M35222
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Parkinsonism
Full description | Characteristic neurologic anomaly resulting form degeneration of dopamine-generating cells in the substantia nigra, a region of the midbrain, characterized clinically by shaking, rigidity, slowness of movement and difficulty with walking and gait. [HPO:probinson]

Standard name | HP_TORSION_DYSTONIA
Systematic name | M35223
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Torsion dystonia
Full description | Sustained involuntary muscle contractions that produce twisting and repetitive movements of the body. [HPO:probinson]

Standard name | HP_TONGUE_FASCICULATIONS
Systematic name | M35224
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tongue fasciculations
Full description | Fasciculations or fibrillation affecting the tongue muscle. [HPO:probinson]

Standard name | HP_DYSMETRIA
Systematic name | M35225
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dysmetria
Full description | A type of ataxia characterized by the inability to carry out movements with the correct range and motion across the plane of more than one joint related to incorrect estimation of the distances required for targeted movements. [HPO:probinson]

Standard name | HP_ABNORMAL_NERVOUS_SYSTEM_ELECTROPHYSIOLOGY
Systematic name | M35226
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal nervous system electrophysiology
Full description | An abnormality of the function of the electrical signals with which nerve cells communicate with each other or with muscles as measured by electrophysiological investigations. [HPO:probinson]

Standard name | HP_GIANT_SOMATOSENSORY_EVOKED_POTENTIALS
Systematic name | M35227
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Giant somatosensory evoked potentials
Full description | An abnormal enlargement (i.e. increase in measured voltage) of somatosensory evoked potentials. [HPO:curators]

Standard name | HP_REDUCED_TENDON_REFLEXES
Systematic name | M35228
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Reduced tendon reflexes
Full description | Diminution of tendon reflexes, which is an invariable sign of peripheral nerve disease. [HPO:probinson, PMID:20941667]

Standard name | HP_NEONATAL_HYPOTONIA
Systematic name | M35229
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neonatal hypotonia
Full description | Muscular hypotonia (abnormally low muscle tone) manifesting in the neonatal period. [HPO:curators]

Standard name | HP_CEREBELLAR_HYPOPLASIA
Systematic name | M35230
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cerebellar hypoplasia
Full description | Underdevelopment of the cerebellum. [HPO:probinson, PMID:27160001]

Standard name | HP_MUSCLE_WEAKNESS
Systematic name | M35231
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Muscle weakness
Full description | Reduced strength of muscles. [HPO:probinson, PMID:15832536]

Standard name | HP_HYPOGLYCEMIC_COMA
Systematic name | M35232
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoglycemic coma
Full description |

Standard name | HP_EEG_WITH_IRREGULAR_GENERALIZED_SPIKE_AND_WAVE_COMPLEXES
Systematic name | M35233
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | EEG with irregular generalized spike and wave complexes
Full description | EEG shows spikes (<80 ms) and waves, which are recorded over the entire scalp and do not have a specific frequency. [HPO:jalbers]

Standard name | HP_PHOTOSENSITIVE_MYOCLONIC_SEIZURE
Systematic name | M35234
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Photosensitive myoclonic seizure
Full description | Generalised myoclonic seizure provoked by flashing or flickering light. [PMID:28276060]

Standard name | HP_SPECIFIC_LEARNING_DISABILITY
Systematic name | M35235
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Specific learning disability
Full description | Impairment of certain skills such as reading or writing, coordination, self-control, or attention that interfere with the ability to learn. The impairment is not related to a global deficiency of intelligence. [HPO:probinson]

Standard name | HP_DYSTONIA
Systematic name | M35236
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dystonia
Full description | An abnormally increased muscular tone that causes fixed abnormal postures. There is a slow, intermittent twisting motion that leads to exaggerated turning and posture of the extremities and trunk. [HPO:probinson]

Standard name | HP_COMMUNICATING_HYDROCEPHALUS
Systematic name | M35237
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Communicating hydrocephalus
Full description | A form of hydrocephalus in which there is no visible obstruction to the flow of the cerebrospinal fluid between the ventricles and subarachnoid space. [eMedicine:1135286, HPO:probinson]

Standard name | HP_BIMANUAL_SYNKINESIA
Systematic name | M35238
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bimanual synkinesia
Full description | Involuntary movements of one hand that accompany and mirror intentional movements of the opposite hand. [HPO:probinson, PMID:22412265, PMID:28945198]

Standard name | HP_MYOCLONUS
Systematic name | M35239
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Myoclonus
Full description | Very brief, involuntary random muscular contractions occurring at rest, in response to sensory stimuli, or accompanying voluntary movements. [HPO:probinson, PMID:20589866]

Standard name | HP_TREMOR
Systematic name | M35240
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tremor
Full description | An unintentional, oscillating to-and-fro muscle movement about a joint axis. [HPO:probinson, PMID:16344298, PMID:20589866]

Standard name | HP_PARTIAL_AGENESIS_OF_THE_CORPUS_CALLOSUM
Systematic name | M35241
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Partial agenesis of the corpus callosum
Full description | A partial failure of the development of the corpus callosum. [HPO:curators]

Standard name | HP_LISSENCEPHALY
Systematic name | M35242
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lissencephaly
Full description | A spectrum of malformations of cortical development caused by insufficient neuronal migration that subsumes the terms agyria, pachygyria and subcortical band heterotopia. See also neuropathological definitions for 2-, 3-, and 4-layered lissencephaly. [COST:neuromig, HPO:probinson, PMID:28440899]

Standard name | HP_CEREBRAL_HEMORRHAGE
Systematic name | M35243
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cerebral hemorrhage
Full description | Hemorrhage into the parenchyma of the brain. [HPO:gcarletti]

Standard name | HP_ABSENT_SPEECH
Systematic name | M35244
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Absent speech
Full description | Complete lack of development of speech and language abilities. [HPO:probinson]

Standard name | HP_PSYCHOTIC_MENTATION
Systematic name | M35245
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Psychotic mentation
Full description |

Standard name | HP_HYPERREFLEXIA
Systematic name | M35246
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperreflexia
Full description | Hyperreflexia is the presence of hyperactive stretch reflexes of the muscles. [HPO:probinson]

Standard name | HP_BRISK_REFLEXES
Systematic name | M35247
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Brisk reflexes
Full description | Tendon reflexes that are noticeably more active than usual (conventionally denoted 3+ on clinical examination). Brisk reflexes may or may not indicate a neurological lesion. They are distinguished from hyperreflexia by the fact that hyerreflexia is characterized by hyperactive repeating (clonic) reflexes, which are considered to be always abnormal. []

Standard name | HP_FACIAL_DIPLEGIA
Systematic name | M35248
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial diplegia
Full description | Facial diplegia refers to bilateral facial palsy (bilateral facial palsy is much rarer than unilateral facial palsy). [HPO:probinson]

Standard name | HP_SLURRED_SPEECH
Systematic name | M35249
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Slurred speech
Full description | Abnormal coordination of muscles involved in speech. [DDD:fmunitoni]

Standard name | HP_MEGALENCEPHALY
Systematic name | M35250
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Megalencephaly
Full description | Diffuse enlargement of the entire cerebral hemispheres leading to macrocephaly (with or without overlying cortical dysplasia). [COST:neuromig, HPO:probinson, PMID:28658095]

Standard name | HP_PLAGIOCEPHALY
Systematic name | M35251
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Plagiocephaly
Full description | Asymmetric head shape, which is usually a combination of unilateral occipital flattening with ipsilateral frontal prominence, leading to rhomboid cranial shape. [PMID:19125436]

Standard name | HP_HOLOPROSENCEPHALY
Systematic name | M35252
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Holoprosencephaly
Full description | Holoprosencephaly is a structural anomaly of the brain in which the developing forebrain fails to divide into two separate hemispheres and ventricles. [HPO:probinson]

Standard name | HP_NYSTAGMUS_INDUCED_HEAD_NODDING
Systematic name | M35253
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nystagmus-induced head nodding
Full description | Head movements associated with nystagmus, that may represent an attempt to compensate for the involuntary eye movements and to improve vision. [HPO:probinson]

Standard name | HP_CALVARIAL_SKULL_DEFECT
Systematic name | M35254
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Calvarial skull defect
Full description | A localized defect in the bone of the skull resulting from abnormal embryological development. The defect is covered by normal skin. In some cases, skull x-rays have shown underlying lytic bone lesions which have closed before the age of one year. [HPO:probinson]

Standard name | HP_CRANIOSYNOSTOSIS
Systematic name | M35255
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Craniosynostosis
Full description | Craniosynostosis refers to the premature closure of the cranial sutures. Primary craniosynostosis refers to the closure of one or more sutures due to abnormalities in skull development, and secondary craniosynostosis results from failure of brain growth. [HPO:probinson]

Standard name | HP_ABNORMAL_JOINT_MORPHOLOGY
Systematic name | M35256
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal joint morphology
Full description | An abnormal structure or form of the joints, i.e., one or more of the articulations where two bones join. [HPO:probinson]

Standard name | HP_ARTHRITIS
Systematic name | M35257
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Arthritis
Full description | Inflammation of a joint. [HPO:probinson]

Standard name | HP_RHEUMATOID_ARTHRITIS
Systematic name | M35258
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Rheumatoid arthritis
Full description | Inflammatory changes in the synovial membranes and articular structures with widespread fibrinoid degeneration of the collagen fibers in mesenchymal tissues, as well as atrophy and rarefaction of bony structures. [HPO:probinson]

Standard name | HP_JOINT_DISLOCATION
Systematic name | M35259
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Joint dislocation
Full description | Displacement or malalignment of joints. [HPO:curators]

Standard name | HP_CONGENITAL_HIP_DISLOCATION
Systematic name | M35260
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Congenital hip dislocation
Full description |

Standard name | HP_LIMITATION_OF_JOINT_MOBILITY
Systematic name | M35261
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Limitation of joint mobility
Full description | A reduction in the freedom of movement of one or more joints. [HPO:probinson]

Standard name | HP_LIMITED_ELBOW_EXTENSION
Systematic name | M35262
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Limited elbow extension
Full description | Limited ability to straighten the arm at the elbow joint. [HPO:probinson]

Standard name | HP_JOINT_HYPERMOBILITY
Systematic name | M35263
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Joint hypermobility
Full description | The ability of a joint to move beyond its normal range of motion. [HPO:probinson]

Standard name | HP_HIP_DYSPLASIA
Systematic name | M35264
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hip dysplasia
Full description | The presence of developmental dysplasia of the hip. [HPO:probinson]

Standard name | HP_JOINT_SWELLING
Systematic name | M35265
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Joint swelling
Full description |

Standard name | HP_JOINT_STIFFNESS
Systematic name | M35266
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Joint stiffness
Full description | Joint stiffness is a perceived sensation of tightness in a joint or joints when attempting to move them after a period of inactivity. Joint stiffness typically subsides over time. [HPO:probinson]

Standard name | HP_JOINT_LAXITY
Systematic name | M35267
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Joint laxity
Full description | Lack of stability of a joint. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_LIVER
Systematic name | M35268
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the liver
Full description | An abnormality of the liver. [HPO:probinson]

Standard name | HP_CIRRHOSIS
Systematic name | M35269
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cirrhosis
Full description | A chronic disorder of the liver in which liver tissue becomes scarred and is partially replaced by regenerative nodules and fibrotic tissue resulting in loss of liver function. [HPO:probinson]

Standard name | HP_HEPATIC_FIBROSIS
Systematic name | M35270
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hepatic fibrosis
Full description | The presence of excessive fibrous connective tissue in the liver. Fibrosis is a reparative or reactive process. [HPO:probinson]

Standard name | HP_CHOLESTASIS
Systematic name | M35271
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cholestasis
Full description | Impairment of bile flow due to obstruction in bile ducts. [HPO:probinson]

Standard name | HP_HEPATIC_FAILURE
Systematic name | M35272
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hepatic failure
Full description |

Standard name | HP_HEPATOCELLULAR_CARCINOMA
Systematic name | M35273
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hepatocellular carcinoma
Full description | A kind of neoplasm of the liver that originates in hepatocytes and presents macroscopically as a soft and hemorrhagic tan mass in the liver. [HPO:probinson]

Standard name | HP_MACROVESICULAR_HEPATIC_STEATOSIS
Systematic name | M35274
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Macrovesicular hepatic steatosis
Full description | A form of hepatic steatosis characterized by the presence of large, lipid-laden vesicles in the affected hepatocytes. [HPO:probinson]

Standard name | HP_HEPATOCELLULAR_NECROSIS
Systematic name | M35275
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hepatocellular necrosis
Full description |

Standard name | HP_INTRAHEPATIC_CHOLESTASIS
Systematic name | M35276
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Intrahepatic cholestasis
Full description | Impairment of bile flow due to obstruction in the small bile ducts within the liver. [HPO:probinson]

Standard name | HP_HEPATIC_CYSTS
Systematic name | M35277
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hepatic cysts
Full description |

Standard name | HP_BILE_DUCT_PROLIFERATION
Systematic name | M35278
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bile duct proliferation
Full description | Proliferative changes of the bile ducts. [HPO:probinson]

Standard name | HP_MICRONODULAR_CIRRHOSIS
Systematic name | M35279
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Micronodular cirrhosis
Full description | A type of cirrhosis characterized by the presence of small regenerative nodules. [HPO:probinson]

Standard name | HP_MICROVESICULAR_HEPATIC_STEATOSIS
Systematic name | M35280
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Microvesicular hepatic steatosis
Full description | A form of hepatic steatosis characterized by the presence of small, lipid-laden vesicles in the affected hepatocytes. [HPO:probinson]

Standard name | HP_X_LINKED_RECESSIVE_INHERITANCE
Systematic name | M35281
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | X-linked recessive inheritance
Full description | A mode of inheritance that is observed for recessive traits related to a gene encoded on the X chromosome. In the context of medical genetics, X-linked recessive disorders manifest in males (who have one copy of the X chromosome and are thus hemizygotes), but generally not in female heterozygotes who have one mutant and one normal allele. [HPO:curators]

Standard name | HP_ABNORMALITY_OF_THE_MUSCULATURE_OF_THE_HAND
Systematic name | M35282
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the musculature of the hand
Full description |

Standard name | HP_X_LINKED_DOMINANT_INHERITANCE
Systematic name | M35283
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | X-linked dominant inheritance
Full description | A mode of inheritance that is observed for dominant traits related to a gene encoded on the X chromosome. In the context of medical genetics, X-linked dominant disorders tend to manifest very severely in affected males. The severity of manifestation in females may depend on the degree of skewed X inactivation. [HPO:curators]

Standard name | HP_HETEROGENEOUS
Systematic name | M35284
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Heterogeneous
Full description |

Standard name | HP_MULTIFACTORIAL_INHERITANCE
Systematic name | M35285
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Multifactorial inheritance
Full description | A mode of inheritance that depends on a mixture of major and minor genetic determinants possibly together with environmental factors. Diseases inherited in this manner are termed complex diseases. [HPO:probinson]

Standard name | HP_MITOCHONDRIAL_INHERITANCE
Systematic name | M35286
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mitochondrial inheritance
Full description | A mode of inheritance that is observed for traits related to a gene encoded on the mitochondrial genome. Because the mitochondrial genome is essentially always maternally inherited, a mitochondrial condition can only be transmitted by females, although the condition can affect both sexes. The proportion of mutant mitochondria can vary (heteroplasmy). [HPO:probinson]

Standard name | HP_SOMATIC_MUTATION
Systematic name | M35287
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Somatic mutation
Full description | A mode of inheritance in which a trait or disorder results from a de novo mutation occurring after conception, rather than being inherited from a preceding generation. []

Standard name | HP_ABNORMALITY_OF_THE_CALF_MUSCULATURE
Systematic name | M35288
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the calf musculature
Full description |

Standard name | HP_HEPATOSPLENOMEGALY
Systematic name | M35289
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hepatosplenomegaly
Full description | Simultaneous enlargement of the liver and spleen. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_SHOULDER_GIRDLE_MUSCULATURE
Systematic name | M35290
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the shoulder girdle musculature
Full description |

Standard name | HP_ABNORMALITY_OF_THE_FOOT_MUSCULATURE
Systematic name | M35291
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the foot musculature
Full description | An anomaly of the musculature of foot. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_MUSCULATURE_OF_THE_LOWER_LIMBS
Systematic name | M35292
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the musculature of the lower limbs
Full description |

Standard name | HP_ABNORMAL_ABDOMEN_MORPHOLOGY
Systematic name | M35293
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal abdomen morphology
Full description | A structural abnormality of the abdomen ('belly'), that is, the part of the body between the pelvis and the thorax. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_MUSCULATURE_OF_THE_THIGH
Systematic name | M35294
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the musculature of the thigh
Full description |

Standard name | HP_SOMATIC_MOSAICISM
Systematic name | M35295
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Somatic mosaicism
Full description | The presence of genetically distinct populations of somatic cells in a given organism caused by DNA mutations, epigenetic alterations of DNA, chromosomal abnormalities or the spontaneous reversion of inherited mutations. [HPO:probinson, PMID:12360233]

Standard name | HP_ABNORMALITY_OF_THE_MUSCULATURE_OF_THE_UPPER_LIMBS
Systematic name | M35296
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the musculature of the upper limbs
Full description |

Standard name | HP_Y_LINKED_INHERITANCE
Systematic name | M35297
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Y-linked inheritance
Full description | A mode of inheritance that is observed for traits related to a gene encoded on the Y chromosome. [HPO:curators]

Standard name | HP_ABNORMALITY_OF_THE_UPPER_ARM
Systematic name | M35298
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the upper arm
Full description |

Standard name | HP_ABNORMALITY_OF_THE_MUSCULATURE_OF_THE_UPPER_ARM
Systematic name | M35299
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the musculature of the upper arm
Full description |

Standard name | HP_APLASIA_HYPOPLASIA_INVOLVING_THE_SKELETAL_MUSCULATURE
Systematic name | M35300
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aplasia/Hypoplasia involving the skeletal musculature
Full description | Absence or underdevelopment of the musculature. [HPO:curators]

Standard name | HP_CONTIGUOUS_GENE_SYNDROME
Systematic name | M35301
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Contiguous gene syndrome
Full description |

Standard name | HP_DELAYED_CLOSURE_OF_THE_ANTERIOR_FONTANELLE
Systematic name | M35302
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delayed closure of the anterior fontanelle
Full description | A delay in closure (ossification) of the anterior fontanelle, which generally undergoes closure around the 18th month of life. [HPO:probinson]

Standard name | HP_FRECKLING
Systematic name | M35303
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Freckling
Full description | The presence of an increased number of freckles, small circular spots on the skin that are darker than the surrounding skin because of deposits of melanin. []

Standard name | HP_SUBCUTANEOUS_NODULE
Systematic name | M35304
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Subcutaneous nodule
Full description | Slightly elevated lesions on or in the skin with a diameter of over 5 mm. [HPO:probinson]

Standard name | HP_BILATERAL_PTOSIS
Systematic name | M35305
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bilateral ptosis
Full description |

Standard name | HP_CARPAL_BONE_HYPOPLASIA
Systematic name | M35306
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Carpal bone hypoplasia
Full description | Underdevelopment of one or more carpal bones. [HPO:probinson]

Standard name | HP_BROAD_FINGER
Systematic name | M35307
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad finger
Full description | Increased width of a non-thumb digit of the hand. [PMID:19125433]

Standard name | HP_FAILURE_TO_THRIVE
Systematic name | M35308
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Failure to thrive
Full description | Failure to thrive (FTT) refers to a child whose physical growth is substantially below the norm. [HPO:probinson]

Standard name | HP_INTRAUTERINE_GROWTH_RETARDATION
Systematic name | M35309
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Intrauterine growth retardation
Full description | An abnormal restriction of fetal growth with fetal weight below the tenth percentile for gestational age. [HPO:probinson]

Standard name | HP_SMALL_FOR_GESTATIONAL_AGE
Systematic name | M35310
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Small for gestational age
Full description | Smaller than normal size according to sex and gestational age related norms, defined as a weight below the 10th percentile for the gestational age. [DDD:hfirth]

Standard name | HP_DISPROPORTIONATE_TALL_STATURE
Systematic name | M35311
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Disproportionate tall stature
Full description | A tall and slim body build with increased arm span to height ratio (>1.05) and a reduced upper-to-lower segment ratio (<0.85), i.e., unusually long arms and legs. The extremities as well as the hands and feet are unusually slim. [DDD:hfirth, HPO:probinson]

Standard name | HP_LARGE_FOR_GESTATIONAL_AGE
Systematic name | M35312
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Large for gestational age
Full description | The term large for gestational age applies to babies whose birth weight lies above the 90th percentile for that gestational age. [eMedicine:262679, HPO:probinson]

Standard name | HP_DEATH_IN_INFANCY
Systematic name | M35313
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Death in infancy
Full description | Death within the first 24 months of life. [HPO:probinson]

Standard name | HP_SEVERE_FAILURE_TO_THRIVE
Systematic name | M35314
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Severe failure to thrive
Full description |

Standard name | HP_HEMIHYPERTROPHY
Systematic name | M35315
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hemihypertrophy
Full description | Overgrowth of only one side of the body. [HPO:probinson]

Standard name | HP_MILD_POSTNATAL_GROWTH_RETARDATION
Systematic name | M35316
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mild postnatal growth retardation
Full description | A mild degree of slow or limited growth after birth, being between two and three standard deviations below age- and sex-related norms. [DDD:hfirth]

Standard name | HP_FAILURE_TO_THRIVE_IN_INFANCY
Systematic name | M35317
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Failure to thrive in infancy
Full description |

Standard name | HP_SLENDER_BUILD
Systematic name | M35318
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Slender build
Full description | Asthenic habitus refers to a slender build with long limbs, an angular profile, and prominent muscles or bones. [HPO:probinson]

Standard name | HP_PROTUBERANT_ABDOMEN
Systematic name | M35319
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Protuberant abdomen
Full description | A thrusting or bulging out of the abdomen. [HPO:probinson]

Standard name | HP_OMPHALOCELE
Systematic name | M35320
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Omphalocele
Full description | A midline anterior incomplete closure of the abdominal wall in which there is herniation of the abdominal viscera into the base of the abdominal cord. [HPO:probinson]

Standard name | HP_DIASTASIS_RECTI
Systematic name | M35321
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Diastasis recti
Full description | A separation of the rectus abdominis muscle into right and left halves (which are normally joined at the midline at the linea alba). [HPO:probinson]

Standard name | HP_ASCITES
Systematic name | M35322
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ascites
Full description | Accumulation of fluid in the peritoneal cavity. [HPO:probinson]

Standard name | HP_ANTERIORLY_PLACED_ANUS
Systematic name | M35323
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anteriorly placed anus
Full description | Anterior malposition of the anus. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_RIB_CAGE
Systematic name | M35324
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the rib cage
Full description | A morphological anomaly of the rib cage. [HPO:probinson]

Standard name | HP_OVERGROWTH
Systematic name | M35325
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Overgrowth
Full description | Excessive postnatal growth which may comprise increased weight, increased length, and/or increased head circumference. [HPO:probinson]

Standard name | HP_ABNORMAL_ILEUM_MORPHOLOGY
Systematic name | M35326
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal ileum morphology
Full description |

Standard name | HP_ABNORMAL_UMBILICUS_MORPHOLOGY
Systematic name | M35327
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal umbilicus morphology
Full description | An abnormality of the structure or appearance of the umbilicus. [HPO:probinson]

Standard name | HP_BARREL_SHAPED_CHEST
Systematic name | M35328
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Barrel-shaped chest
Full description | A rounded, bulging chest that resembles the shape of a barrel. That is, there is an increased anteroposterior diameter and usually some degree of kyphosis. [HPO:probinson]

Standard name | HP_ASYMMETRY_OF_THE_THORAX
Systematic name | M35329
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Asymmetry of the thorax
Full description | Lack of symmetry between the left and right halves of the thorax. [HPO:probinson]

Standard name | HP_PRENATAL_MOVEMENT_ABNORMALITY
Systematic name | M35330
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Prenatal movement abnormality
Full description | An abnormality of fetal movement. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_AMNIOTIC_FLUID
Systematic name | M35331
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the amniotic fluid
Full description | Abnormality of the amniotic fluid, which is the fluid contained in the amniotic sac surrounding the developing fetus. [HPO:curators]

Standard name | HP_POLYHYDRAMNIOS
Systematic name | M35332
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Polyhydramnios
Full description | The presence of excess amniotic fluid in the uterus during pregnancy. [HPO:probinson]

Standard name | HP_OLIGOHYDRAMNIOS
Systematic name | M35333
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Oligohydramnios
Full description | Diminished amniotic fluid volume in pregnancy. [HPO:probinson]

Standard name | HP_FETAL_POLYURIA
Systematic name | M35334
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Fetal polyuria
Full description | Abnormally increased production of urine by the fetus resulting in polyhydramnios. [HPO:probinson, PMID:21460147]

Standard name | HP_WIDELY_SPACED_MAXILLARY_CENTRAL_INCISORS
Systematic name | M35335
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Widely-spaced maxillary central incisors
Full description | Increased distance between the maxillary central permanent incisor tooth. [HPO:ibailleulforestier]

Standard name | HP_MACRODONTIA
Systematic name | M35336
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Macrodontia
Full description | Increased size of the teeth, which can be defined as a mesiodistal tooth diameter (width) more than 2 SD above mean for age. Alternatively, an apparently increased maximum width of the tooth. [HPO:ibailleulforestier, PMID:19125428]

Standard name | HP_MOOD_CHANGES
Systematic name | M35337
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mood changes
Full description |

Standard name | HP_RECURRENT_SKIN_INFECTIONS
Systematic name | M35338
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Recurrent skin infections
Full description | Infections of the skin that happen multiple times. [HPO:curators]

Standard name | HP_REDUNDANT_SKIN
Systematic name | M35339
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Redundant skin
Full description | Loose and sagging skin often associated with loss of skin elasticity. [HPO:probinson]

Standard name | HP_ROTARY_NYSTAGMUS
Systematic name | M35340
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Rotary nystagmus
Full description | A form of nystagmus in which the eyeball makes rotary motions around the axis. [HPO:probinson]

Standard name | HP_BELL_SHAPED_THORAX
Systematic name | M35341
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bell-shaped thorax
Full description | The rib cage has the shape of a wide mouthed bell. That is, the superior portion of the rib cage is constricted, followed by a convex region, and the inferior portion of the rib cage expands again to have a large diameter. [HPO:probinson]

Standard name | HP_SELECTIVE_TOOTH_AGENESIS
Systematic name | M35342
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Selective tooth agenesis
Full description | Agenesis specifically affecting one of the classes incisor, premolar, or molar. [HPO:ibailleulforestier]

Standard name | HP_ALOPECIA
Systematic name | M35343
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Alopecia
Full description | A noncongenital process of hair loss, which may progress to partial or complete baldness. [PMID:14676077]

Standard name | HP_ABNORMALITY_OF_THE_NAIL
Systematic name | M35344
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the nail
Full description | Abnormality of the nail. [HPO:probinson]

Standard name | HP_CONCAVE_NAIL
Systematic name | M35345
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Concave nail
Full description | The natural longitudinal (posterodistal) convex arch is not present or is inverted. [PMID:19125433]

Standard name | HP_ABNORMALITY_OF_THE_LARYNX
Systematic name | M35346
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the larynx
Full description | An abnormality of the larynx. [HPO:probinson]

Standard name | HP_LARYNGOMALACIA
Systematic name | M35347
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Laryngomalacia
Full description | Laryngomalacia is a congenital abnormality of the laryngeal cartilage in which the cartilage is floppy and prolapses over the larynx during inspiration. [HPO:probinson]

Standard name | HP_LARYNGEAL_STENOSIS
Systematic name | M35348
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Laryngeal stenosis
Full description | Stricture or narrowing of the larynx that may be associated with symptoms of respiratory difficulty depending on the degree of laryngeal narrowing. [HPO:probinson]

Standard name | HP_VOCAL_CORD_PARESIS
Systematic name | M35349
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Vocal cord paresis
Full description | Decreased strength of the vocal folds. [HPO:probinson]

Standard name | HP_VOCAL_CORD_PARALYSIS
Systematic name | M35350
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Vocal cord paralysis
Full description | A loss of the ability to move the vocal folds. [HPO:probinson]

Standard name | HP_SUBGLOTTIC_STENOSIS
Systematic name | M35351
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Subglottic stenosis
Full description |

Standard name | HP_ABNORMALITY_OF_THE_VOICE
Systematic name | M35352
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the voice
Full description |

Standard name | HP_HOARSE_VOICE
Systematic name | M35353
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hoarse voice
Full description | Hoarseness refers to a change in the pitch or quality of the voice, with the voice sounding weak, very breathy, scratchy, or husky. [HPO:probinson]

Standard name | HP_NASAL_SPEECH
Systematic name | M35354
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nasal speech
Full description | A type of speech characterized by the presence of an abnormally increased nasal airflow during speech. [HPO:sdoelken]

Standard name | HP_WEAK_CRY
Systematic name | M35355
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Weak cry
Full description |

Standard name | HP_HOARSE_CRY
Systematic name | M35356
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hoarse cry
Full description |

Standard name | HP_DYSPHONIA
Systematic name | M35357
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dysphonia
Full description | An impairment in the ability to produce voice sounds. [HPO:probinson]

Standard name | HP_HIGH_PITCHED_VOICE
Systematic name | M35358
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | High pitched voice
Full description | An abnormal increase in the pitch (frequency) of the voice. [HPO:probinson]

Standard name | HP_WEAK_VOICE
Systematic name | M35359
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Weak voice
Full description | Reduced intensity (volume) of speech. [HPO:probinson]

Standard name | HP_PREMATURE_BIRTH
Systematic name | M35360
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Premature birth
Full description | The birth of a baby of less than 37 weeks of gestational age. [HPO:probinson]

Standard name | HP_BREECH_PRESENTATION
Systematic name | M35361
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Breech presentation
Full description | A position of the fetus at delivery in which the fetus enters the birth canal with the buttocks or feet first. [HPO:probinson]

Standard name | HP_ABNORMAL_HEART_MORPHOLOGY
Systematic name | M35362
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal heart morphology
Full description | Any structural anomaly of the heart. [HPO:probinson]

Standard name | HP_ABNORMAL_MITRAL_VALVE_MORPHOLOGY
Systematic name | M35363
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal mitral valve morphology
Full description | Any structural anomaly of the mitral valve. [HPO:probinson]

Standard name | HP_CONGESTIVE_HEART_FAILURE
Systematic name | M35364
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Congestive heart failure
Full description | The presence of an abnormality of cardiac function that is responsible for the failure of the heart to pump blood at a rate that is commensurate with the needs of the tissues or a state in which abnormally elevated filling pressures are required for the heart to do so. Heart failure is frequently related to a defect in myocardial contraction. [HPO:probinson]

Standard name | HP_TETRALOGY_OF_FALLOT
Systematic name | M35365
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tetralogy of Fallot
Full description | A congenital cardiac malformation comprising pulmonary stenosis, overriding aorta, ventricular septum defect, and right ventricular hypertrophy. The diagnosis of TOF is made if at least three of the four above mentioned features are present. [HPO:probinson]

Standard name | HP_ABNORMAL_MYOCARDIUM_MORPHOLOGY
Systematic name | M35366
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal myocardium morphology
Full description | A structural anomaly of the muscle layer of the heart wall. []

Standard name | HP_HYPERTROPHIC_CARDIOMYOPATHY
Systematic name | M35367
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypertrophic cardiomyopathy
Full description | Hypertrophic cardiomyopathy (HCM) is defined by the presence of increased ventricular wall thickness or mass in the absence of loading conditions (hypertension, valve disease) sufficient to cause the observed abnormality. [PMID:17916581]

Standard name | HP_CARDIOMEGALY
Systematic name | M35368
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cardiomegaly
Full description | Increased size of the heart. [HPO:probinson]

Standard name | HP_ABNORMAL_PULMONARY_VALVE_MORPHOLOGY
Systematic name | M35369
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal pulmonary valve morphology
Full description | Any structural abnormality of the pulmonary valve. [HPO:probinson]

Standard name | HP_PULMONIC_STENOSIS
Systematic name | M35370
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pulmonic stenosis
Full description | A narrowing of the right ventricular outflow tract that can occur at the pulmonary valve (valvular stenosis) or just below the pulmonary valve (infundibular stenosis). [HPO:probinson]

Standard name | HP_PATENT_DUCTUS_ARTERIOSUS
Systematic name | M35371
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Patent ductus arteriosus
Full description | In utero, the ductus arteriosus (DA) serves to divert ventricular output away from the lungs and toward the placenta by connecting the main pulmonary artery to the descending aorta. A patent ductus arteriosus (PDA) in the first 3 days of life is a physiologic shunt in healthy term and preterm newborn infants, and normally is substantially closed within about 24 hours after bith and completely closed after about three weeks. Failure of physiologcal closure is referred to a persistent or patent ductus arteriosus (PDA). Depending on the degree of left-to-right shunting, PDA can have clinical consequences. [HPO:probinson, PMID:20421261]

Standard name | HP_DILATED_CARDIOMYOPATHY
Systematic name | M35372
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dilated cardiomyopathy
Full description | Dilated cardiomyopathy (DCM) is defined by the presence of left ventricular dilatation and left ventricular systolic dysfunction in the absence of abnormal loading conditions (hypertension, valve disease) or coronary artery disease sufficient to cause global systolic impairment. Right ventricular dilation and dysfunction may be present but are not necessary for the diagnosis. [PMID:17916581]

Standard name | HP_SUDDEN_CARDIAC_DEATH
Systematic name | M35373
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sudden cardiac death
Full description | The heart suddenly and unexpectedly stops beating resulting in death within a short time period (generally within 1 h of symptom onset). [HPO:probinson]

Standard name | HP_ABNORMAL_AORTIC_VALVE_MORPHOLOGY
Systematic name | M35374
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal aortic valve morphology
Full description | Any abnormality of the aortic valve. [HPO:curators]

Standard name | HP_COR_PULMONALE
Systematic name | M35375
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cor pulmonale
Full description | Right-sided heart failure resulting from chronic hypertension in the pulmonary arteries and right ventricle. [HPO:probinson]

Standard name | HP_TACHYCARDIA
Systematic name | M35376
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tachycardia
Full description | A rapid heartrate that exceeds the range of the normal resting heartrate for age. [HPO:probinson]

Standard name | HP_AORTIC_VALVE_STENOSIS
Systematic name | M35377
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aortic valve stenosis
Full description | The presence of a stenosis (narrowing) of the aortic valve. [HPO:probinson]

Standard name | HP_ABNORMAL_HEART_VALVE_MORPHOLOGY
Systematic name | M35378
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal heart valve morphology
Full description | Any structural abnormality of a cardiac valve. [HPO:probinson]

Standard name | HP_PATENT_FORAMEN_OVALE
Systematic name | M35379
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Patent foramen ovale
Full description | Failure of the foramen ovale to seal postnatally, leaving a potential conduit between the left and right cardiac atria. [DDD:dbrown, HPO:probinson]

Standard name | HP_MYOCARDIAL_INFARCTION
Systematic name | M35380
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Myocardial infarction
Full description | Necrosis of the myocardium caused by an obstruction of the blood supply to the heart and often associated with chest pain, shortness of breath, palpitations, and anxiety as well as characteristic EKG findings and elevation of serum markers including creatine kinase-MB fraction and troponin. [HPO:probinson]

Standard name | HP_AORTIC_REGURGITATION
Systematic name | M35381
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aortic regurgitation
Full description | An insufficiency of the aortic valve, leading to regurgitation (backward flow) of blood from the aorta into the left ventricle. [HPO:probinson]

Standard name | HP_TRUNCUS_ARTERIOSUS
Systematic name | M35382
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Truncus arteriosus
Full description | A single arterial trunk arises from the cardiac mass. The pulmonary arteries, aorta and coronary arteries arise from this single trunk with no evidence of another outflow tract. [DDD:dbrown, HPO:probinson]

Standard name | HP_BRADYCARDIA
Systematic name | M35383
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bradycardia
Full description | A slower than normal heart rate (in adults, slower than 60 beats per minute). [HPO:probinson]

Standard name | HP_VENTRICULAR_FIBRILLATION
Systematic name | M35384
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ventricular fibrillation
Full description | Uncontrolled contractions of muscles fibers in the left ventricle not producing contraction of the left ventricle. Ventricular fibrillation usually begins with a ventricular premature contraction and a short run of rapid ventricular tachycardia degenerating into uncoordinating ventricular fibrillations. [HPO:probinson]

Standard name | HP_TORSADE_DE_POINTES
Systematic name | M35385
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Torsade de pointes
Full description | A type of ventricular tachycardia characterized by polymorphioc QRS complexes that change in amplitue and cycle length, and thus have the appearance of oscillating around the baseline in the EKG. [HPO:probinson]

Standard name | HP_RIGHT_VENTRICULAR_HYPERTROPHY
Systematic name | M35386
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Right ventricular hypertrophy
Full description | In this case the right ventricle is more muscular than normal, causing a characteristic boot-shaped (coeur-en-sabot) appearance as seen on anterior- posterior chest x-rays. Right ventricular hypertrophy is commonly associated with any form of right ventricular outflow obstruction or pulmonary hypertension, which may in turn owe its origin to left-sided disease. The echocardiographic signs are thickening of the anterior right ventricular wall and the septum. Cavity size is usually normal, or slightly enlarged. In many cases there is associated volume overload present due to tricuspid regurgitation, in the absence of this, septal motion is normal. [HPO:probinson]

Standard name | HP_TRANSPOSITION_OF_THE_GREAT_ARTERIES
Systematic name | M35387
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Transposition of the great arteries
Full description | A complex congenital heart defect in which the aorta arises from the morphologic right ventricle and the pulmonary artery arises from the morphologic left ventricle. [eMedicine:900574, HPO:probinson, PMID:10798431]

Standard name | HP_ASYMMETRIC_SEPTAL_HYPERTROPHY
Systematic name | M35388
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Asymmetric septal hypertrophy
Full description | Hypertrophic cardiomyopathy with an asymmetrical pattern of hypertrophy, with a predilection for the interventricular septum and myocyte disarray. [HPO:probinson, PMID:17916581]

Standard name | HP_ABNORMAL_CARDIAC_SEPTUM_MORPHOLOGY
Systematic name | M35389
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal cardiac septum morphology
Full description | An anomaly of the intra-atrial or intraventricular septum. [HPO:probinson]

Standard name | HP_COMPLETE_ATRIOVENTRICULAR_CANAL_DEFECT
Systematic name | M35390
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Complete atrioventricular canal defect
Full description | A congenital heart defect characteizred by a specific combination of heart defects with a common atrioventricular valve, primum atrial septal defect and inlet ventricular septal defect. [DDD:dbrown, HPO:probinson, PMID:16722604]

Standard name | HP_CORONARY_ARTERY_ATHEROSCLEROSIS
Systematic name | M35391
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Coronary artery atherosclerosis
Full description | Reduction of the diameter of the coronary arteries as the result of an accumulation of atheromatous plaques within the walls of the coronary arteries, which increases the risk of myocardial ischemia. [HPO:probinson]

Standard name | HP_ABNORMAL_AORTIC_MORPHOLOGY
Systematic name | M35392
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal aortic morphology
Full description | An abnormality of the aorta. [HPO:probinson, PMID:24910511]

Standard name | HP_COARCTATION_OF_AORTA
Systematic name | M35393
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Coarctation of aorta
Full description | Coarctation of the aorta is a narrowing or constriction of a segment of the aorta. [HPO:probinson, PMID:23909637]

Standard name | HP_ANGINA_PECTORIS
Systematic name | M35394
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Angina pectoris
Full description | Paroxysmal chest pain that occurs with exertion or stress and is related to myocardial ischemia. [HPO:probinson]

Standard name | HP_SUBVALVULAR_AORTIC_STENOSIS
Systematic name | M35395
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Subvalvular aortic stenosis
Full description | A fixed form of obstruction to blood flow across the left-ventricular outflow tract related to stenosis (narrowing) below the level of the aortic valve. [HPO:probinson]

Standard name | HP_SECUNDUM_ATRIAL_SEPTAL_DEFECT
Systematic name | M35396
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Secundum atrial septal defect
Full description | A kind of atrial septum defect arising from an enlarged foramen ovale, inadequate growth of the septum secundum, or excessive absorption of the septum primum. [DDD:dbrown, HPO:probinson]

Standard name | HP_MYOCARDIAL_FIBROSIS
Systematic name | M35397
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Myocardial fibrosis
Full description | Myocardial fibrosis is characterized by dysregulated collagen turnover (increased synthesis predominates over unchanged or decreased degradation) and excessive diffuse collagen accumulation in the interstitial and perivascular spaces as well as by phenotypically transformed fibroblasts, termed myofibroblasts. [PMID:28157267]

Standard name | HP_SINUS_BRADYCARDIA
Systematic name | M35398
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sinus bradycardia
Full description | Bradycardia related to a mean resting sinus rate of less than 50 beats per minute. [HPO:probinson]

Standard name | HP_ATRIAL_ARRHYTHMIA
Systematic name | M35399
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Atrial arrhythmia
Full description | A type of supraventricular tachycardia in which the atria are the principal site of electrophysiologic disturbance. [DDD:dbrown]

Standard name | HP_CARDIAC_ARREST
Systematic name | M35400
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cardiac arrest
Full description | An abrupt loss of heart function. []

Standard name | HP_ABNORMAL_PERICARDIUM_MORPHOLOGY
Systematic name | M35401
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal pericardium morphology
Full description | An abnormality of the pericardium, i.e., of the fluid filled sac that surrounds the heart and the proximal ends of the aorta, vena cava, and the pulmonary artery. [HPO:probinson]

Standard name | HP_PERICARDIAL_EFFUSION
Systematic name | M35402
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pericardial effusion
Full description | Accumulation of fluid within the pericardium. [HPO:probinson]

Standard name | HP_SUDDEN_DEATH
Systematic name | M35403
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sudden death
Full description | Rapid and unexpected death. [HPO:probinson]

Standard name | HP_ABNORMAL_TRICUSPID_VALVE_MORPHOLOGY
Systematic name | M35404
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal tricuspid valve morphology
Full description | Any structural anomaly of the tricuspid valve. [HPO:probinson]

Standard name | HP_TRICUSPID_VALVE_PROLAPSE
Systematic name | M35405
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tricuspid valve prolapse
Full description | One or more of the leaflets (cusps) of the tricuspid valve bulges back into the right atrium upon contraction of the right ventricle. [HPO:probinson]

Standard name | HP_ENDOCARDIAL_FIBROELASTOSIS
Systematic name | M35406
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Endocardial fibroelastosis
Full description | Diffuse thickening of the ventricular endocardium and by associated myocardial dysfunction [PMID:23109776]

Standard name | HP_ABNORMAL_RIGHT_VENTRICLE_MORPHOLOGY
Systematic name | M35407
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal right ventricle morphology
Full description | An abnormality of the right ventricle of the heart. [HPO:probinson]

Standard name | HP_RIGHT_VENTRICULAR_FAILURE
Systematic name | M35408
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Right ventricular failure
Full description | Reduced ability of the right ventricle to perform its function (to receive blood from the right atrium and to eject blood into the pulmonary artery), often leading to pitting peripheral edema, ascites, and hepatomegaly. [HPO:probinson]

Standard name | HP_THIRD_DEGREE_ATRIOVENTRICULAR_BLOCK
Systematic name | M35409
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Third degree atrioventricular block
Full description | Third-degree atrioventricular (AV) block (also referred to as complete heart block) is the complete dissociation of the atria and the ventricles. Third-degree AV block exists when more P waves than QRS complexes exist and no relationship (no conduction) exists between them. [PMID:21841933]

Standard name | HP_ABNORMAL_LEFT_VENTRICLE_MORPHOLOGY
Systematic name | M35410
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal left ventricle morphology
Full description | Any structural abnormality of the left ventricle of the heart. [HPO:probinson]

Standard name | HP_LEFT_VENTRICULAR_HYPERTROPHY
Systematic name | M35411
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Left ventricular hypertrophy
Full description | Enlargement or increased size of the heart left ventricle. [MP:0002625]

Standard name | HP_ABNORMAL_CARDIAC_VENTRICLE_MORPHOLOGY
Systematic name | M35412
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal cardiac ventricle morphology
Full description | An abnormality of a cardiac ventricle. [HPO:probinson]

Standard name | HP_VENTRICULAR_HYPERTROPHY
Systematic name | M35413
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ventricular hypertrophy
Full description | Enlargement of the cardiac ventricular muscle tissue with increase in the width of the wall of the ventricle and loss of elasticity. Ventricular hypertrophy is clinically differentiated into left and right ventricular hypertrophy. [HPO:probinson]

Standard name | HP_MITRAL_STENOSIS
Systematic name | M35414
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mitral stenosis
Full description | An abnormal narrowing of the orifice of the mitral valve. [DDD:dbrown]

Standard name | HP_RESTRICTIVE_CARDIOMYOPATHY
Systematic name | M35415
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Restrictive cardiomyopathy
Full description | Restrictive left ventricular physiology is characterized by a pattern of ventricular filling in which increased stiffness of the myocardium causes ventricular pressure to rise precipitously with only small increases in volume, defined as restrictive ventricular physiology in the presence of normal or reduced diastolic volumes (of one or both ventricles), normal or reduced systolic volumes, and normal ventricular wall thickness. [HPO:probinson, PMID:17916581]

Standard name | HP_PROGRESSIVE_HEARING_IMPAIRMENT
Systematic name | M35416
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Progressive hearing impairment
Full description | A progressive form of hearing impairment. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_PANCREAS
Systematic name | M35417
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the pancreas
Full description | An abnormality of the pancreas. [HPO:probinson]

Standard name | HP_PANCREATITIS
Systematic name | M35418
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pancreatitis
Full description | The presence of inflammation in the pancreas. [HPO:probinson]

Standard name | HP_ANNULAR_PANCREAS
Systematic name | M35419
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Annular pancreas
Full description | A congenital anomaly in which the pancreas completely (or sometimes incompletely) encircles the second portion of duodenum and occasionally obstructs the more proximal duodenum. [HPO:probinson]

Standard name | HP_ACUTE_PANCREATITIS
Systematic name | M35420
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Acute pancreatitis
Full description | A acute form of pancreatitis. [HPO:probinson]

Standard name | HP_PANCREATIC_CYSTS
Systematic name | M35421
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pancreatic cysts
Full description | A cyst of the pancreas that possess a lining of mucous epithelium. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_NASOPHARYNX
Systematic name | M35422
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the nasopharynx
Full description |

Standard name | HP_PHIMOSIS
Systematic name | M35423
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Phimosis
Full description | The male foreskin cannot be fully retracted from the head of the penis. [HPO:sdoelken]

Standard name | HP_NASAL_OBSTRUCTION
Systematic name | M35424
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nasal obstruction
Full description | Reduced ability to pass air through the nasal cavity often leading to mouth breathing. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_SPLEEN
Systematic name | M35425
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the spleen
Full description | An abnormality of the spleen. [HPO:probinson]

Standard name | HP_SPLENOMEGALY
Systematic name | M35426
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Splenomegaly
Full description | Abnormal increased size of the spleen. [HPO:probinson]

Standard name | HP_ACCESSORY_SPLEEN
Systematic name | M35427
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Accessory spleen
Full description | An accessory spleen is a round, iso-echogenic, homogenic and smooth structure and is seen as a normal variant mostly on the medial contour of the spleen, near the hilus or around the lower pole. This has no pathogenic relevance. [HPO:probinson]

Standard name | HP_POLYSPLENIA
Systematic name | M35428
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Polysplenia
Full description | Polysplenia is a congenital disease manifested by multiple small accessory spleens. [HPO:curators]

Standard name | HP_SINGLE_VENTRICLE
Systematic name | M35429
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Single ventricle
Full description | The presence of only one working lower chamber in the heart, usually with a virtual absence of the ventricular septum and usually present in conjunction with double inlet left or right ventricle. [MP:0010432]

Standard name | HP_VESTIBULAR_DYSFUNCTION
Systematic name | M35430
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Vestibular dysfunction
Full description | An abnormality of the functioning of the vestibular apparatus. [HPO:probinson]

Standard name | HP_VESTIBULAR_HYPOFUNCTION
Systematic name | M35431
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Vestibular hypofunction
Full description | Reduced functioning of the vestibular apparatus. [HPO:probinson]

Standard name | HP_ABNORMAL_FOOT_MORPHOLOGY
Systematic name | M35432
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal foot morphology
Full description | An abnormality of the skeleton of foot. [HPO:probinson]

Standard name | HP_PES_CAVUS
Systematic name | M35433
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pes cavus
Full description | The presence of an unusually high plantar arch. Also called high instep, pes cavus refers to a distinctly hollow form of the sole of the foot when it is bearing weight. [HPO:probinson, PMID:19125433]

Standard name | HP_TALIPES_EQUINOVARUS
Systematic name | M35434
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Talipes equinovarus
Full description | Talipes equinovarus (also called clubfoot) typically has four main components: inversion and adduction of the forefoot; inversion of the heel and hindfoot; equinus (limitation of extension) of the ankle and subtalar joint; and internal rotation of the leg. [HPO:probinson]

Standard name | HP_PES_PLANUS
Systematic name | M35435
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pes planus
Full description | A foot where the longitudinal arch of the foot is in contact with the ground or floor when the individual is standing; or, in a patient lying supine, a foot where the arch is in contact with the surface of a flat board pressed against the sole of the foot by the examiner with a pressure similar to that expected from weight bearing; or, the height of the arch is reduced. [HPO:probinson, PMID:19125433]

Standard name | HP_HAMMERTOE
Systematic name | M35436
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hammertoe
Full description | Hyperextension of the metatarsal-phalangeal joint with hyperflexion of the proximal interphalangeal (PIP) joint. [PMID:19125433]

Standard name | HP_BROAD_FOOT
Systematic name | M35437
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad foot
Full description | A foot for which the measured width is above the 95th centile for age; or, a foot that appears disproportionately wide for its length. [PMID:19125433]

STANDARD_NAME="HP_TOE_SYNDACTYLY" SYSTEMATIC_NAME="M35438" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="" AUTHORS="" GEOID="" EXACT_SOURCE="HP:0001770" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="https://hpo.jax.org/app/browse/term/HP:0001770" CHIP="Human_NCBI_Gene_ID" CATEGORY_CODE="C5" SUB_CATEGORY_CODE="HPO" CONTRIBUTOR="Human Phenotype Ontology Group" CONTRIBUTOR_ORG="The Jackson Laboratory (JAX)" DESCRIPTION_BRIEF="Toe syndactyly" DESCRIPTION_FULL="Webbing or fusion of the toes, involving soft parts only or including bone structure. Bony fusions are referred to as \bony\ Syndactyly if the fusion occurs in a radio-ulnar axis. Fusions of bones of the toes in a proximo-distal axis are referred to as \Symphalangism\. [HPO:curators]"

Standard name | HP_ACHILLES_TENDON_CONTRACTURE
Systematic name | M35439
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Achilles tendon contracture
Full description | A contracture of the Achilles tendon. [HPO:probinson]

Standard name | HP_TALIPES_EQUINOVALGUS
Systematic name | M35440
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Talipes equinovalgus
Full description | A deformity of foot and ankle in which the foot is bent down and outwards. [HPO:probinson]

Standard name | HP_SHORT_FOOT
Systematic name | M35441
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short foot
Full description | A measured foot length that is more than 2 SD below the mean for a newborn of 27 - 41 weeks gestation, or foot that is less than the 3rd centile for individuals from birth to 16 years of age (objective). Alternatively, a foot that appears disproportionately short (subjective). [HPO:probinson, PMID:19125433]

Standard name | HP_BILATERAL_TALIPES_EQUINOVARUS
Systematic name | M35442
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bilateral talipes equinovarus
Full description | Bilateral clubfoot deformity (see HP:0001762). [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_TOE
Systematic name | M35443
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of toe
Full description | An anomaly of a toe. [HPO:probinson]

Standard name | HP_BROAD_METATARSAL
Systematic name | M35444
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad metatarsal
Full description | Increased side-to-side width of a metatarsal bone. [HPO:probinson]

Standard name | HP_ABNORMAL_DELIVERY
Systematic name | M35445
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal delivery
Full description | An abnormality of the birth process. [HPO:probinson]

Standard name | HP_PREMATURE_RUPTURE_OF_MEMBRANES
Systematic name | M35446
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Premature rupture of membranes
Full description | Premature rupture of membranes (PROM) is a condition which occurs in pregnancy when the amniotic sac ruptures more than an hour before the onset of labor. [HPO:probinson]

Standard name | HP_HYDROPS_FETALIS
Systematic name | M35447
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hydrops fetalis
Full description | The abnormal accumulation of fluid in two or more fetal compartments, including ascites, pleural effusion, pericardial effusion, and skin edema. [HPO:probinson]

Standard name | HP_NONIMMUNE_HYDROPS_FETALIS
Systematic name | M35448
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nonimmune hydrops fetalis
Full description | A type of hydrops fetalis in which there is no identifiable circulating antibody to red blood cell antigens . [HPO:probinson]

Standard name | HP_SMALL_NAIL
Systematic name | M35449
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Small nail
Full description | A nail that is diminished in length and width, i.e., underdeveloped nail. [HPO:probinson, PMID:19125433]

Standard name | HP_HYPERCONVEX_NAIL
Systematic name | M35450
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperconvex nail
Full description | When viewed on end (with the digit tip pointing toward the examiner's eye) the curve of the nail forms a tighter curve of convexity. [HPO:probinson, PMID:19125433]

Standard name | HP_ANONYCHIA
Systematic name | M35451
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anonychia
Full description | Aplasia of the nail. [HPO:probinson]

Standard name | HP_SHORT_NAIL
Systematic name | M35452
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short nail
Full description | Decreased length of nail. [PMID:19125433]

Standard name | HP_HYPOPLASTIC_TOENAILS
Systematic name | M35453
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoplastic toenails
Full description | Underdevelopment of the toenail. [HPO:probinson]

Standard name | HP_ABSENT_TOENAIL
Systematic name | M35454
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Absent toenail
Full description | Congenital absence of the toenail. [HPO:probinson]

Standard name | HP_NAIL_PITS
Systematic name | M35455
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nail pits
Full description | Small (typically about 1 mm or less in size) depressions on the dorsal nail surface. [PMID:19125433]

Standard name | HP_HYPOPLASTIC_FINGERNAIL
Systematic name | M35456
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoplastic fingernail
Full description | Underdevelopment of a fingernail. [HPO:curators]

Standard name | HP_ONYCHOGRYPOSIS
Systematic name | M35457
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Onychogryposis
Full description | Nail that appears thick when viewed on end. [PMID:19125433]

Standard name | HP_ONYCHOLYSIS
Systematic name | M35458
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Onycholysis
Full description | Detachment of the nail from the nail bed. [HPO:probinson]

Standard name | HP_RIDGED_NAIL
Systematic name | M35459
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ridged nail
Full description | Longitudinal, linear prominences in the nail plate. [PMID:19125433]

Standard name | HP_FRAGILE_NAILS
Systematic name | M35460
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Fragile nails
Full description | Nails that easily break. [HPO:probinson]

Standard name | HP_SPLIT_NAIL
Systematic name | M35461
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Split nail
Full description | A nail plate that has a longitudinal separation and the two sections of the nail share the same lateral radius of curvature. [PMID:19125433]

Standard name | HP_DYSTROPHIC_TOENAIL
Systematic name | M35462
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dystrophic toenail
Full description | Toenail changes apart from changes of the color of the toenail (nail dyschromia) that involve partial or complete disruption of the various keratinous layers of the nail plate. [HPO:probinson]

Standard name | HP_HYPERCONVEX_FINGERNAILS
Systematic name | M35463
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperconvex fingernails
Full description | When viewed on end (with the finger tip pointing toward the examiner's eye) the curve of the fingernail forms a tighter curve of convexity. [HPO:probinson, PMID:19125433]

Standard name | HP_DEEP_SET_NAILS
Systematic name | M35464
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Deep-set nails
Full description | Deeply placed nails. [HPO:probinson]

Standard name | HP_THIN_NAIL
Systematic name | M35465
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thin nail
Full description | Nail that appears thin when viewed on end. [HPO:probinson, PMID:19125433]

Standard name | HP_ABSENT_FINGERNAIL
Systematic name | M35466
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Absent fingernail
Full description | Absence of a fingernail. [HPO:probinson]

Standard name | HP_PARONYCHIA
Systematic name | M35467
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Paronychia
Full description | The nail disease paronychia is an often-tender bacterial or fungal hand infection or foot infection where the nail and skin meet at the side or the base of a finger or toenail. The infection can start suddenly (acute paronychia) or gradually (chronic paronychia). [HPO:probinson]

Standard name | HP_LEUKONYCHIA
Systematic name | M35468
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Leukonychia
Full description | White discoloration of the nails. [HPO:probinson]

Standard name | HP_BROAD_NAIL
Systematic name | M35469
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad nail
Full description | Increased width of nail. [HPO:probinson]

Standard name | HP_WEIGHT_LOSS
Systematic name | M35470
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Weight loss
Full description | Reduction inexisting body weight. [HPO:probinson]

Standard name | HP_POSTAXIAL_FOOT_POLYDACTYLY
Systematic name | M35471
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Postaxial foot polydactyly
Full description | Polydactyly of the foot most commonly refers to the presence of six toes on one foot. Postaxial polydactyly affects the lateral ray and the duplication may range from a well-formed articulated digit to a rudimentary digit. [HPO:curators]

Standard name | HP_SHORT_TOE
Systematic name | M35472
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short toe
Full description | A toe that appears disproportionately short compared to the foot. [HPO:probinson]

Standard name | HP_ABNORMAL_METATARSAL_MORPHOLOGY
Systematic name | M35473
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal metatarsal morphology
Full description | Abnormalities of the metatarsal bones (i.e. of five tubular bones located between the tarsal bones of the hind- and mid-foot and the phalanges of the toes). [HPO:probinson]

Standard name | HP_LONG_FOOT
Systematic name | M35474
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Long foot
Full description | Increased back to front length of the foot. [UHPO:probinson]

Standard name | HP_CAMPTODACTYLY_OF_TOE
Systematic name | M35475
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Camptodactyly of toe
Full description | Camptodactyly is a painless flexion contracture of the proximal interphalangeal (PIP) joint that is usually gradually progressive. This term refers to camptodactyly of one or more toes. [HPO:probinson]

Standard name | HP_BROAD_TOE
Systematic name | M35476
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad toe
Full description | Visible increase in width of the non-hallux digit without an increase in the dorso-ventral dimension. [PMID:19125433]

Standard name | HP_SPLIT_FOOT
Systematic name | M35477
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Split foot
Full description | A condition in which middle parts of the foot (toes and metatarsals) are missing giving a cleft appearance. The severity is very variable ranging from slightly hypoplastic 3rd toe over absent 2nd or 3rd toes as far as oligo- or monodactyl feet. [HPO:sdoelken]

Standard name | HP_METATARSUS_ADDUCTUS
Systematic name | M35478
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Metatarsus adductus
Full description | The metatarsals are deviated medially (tibially), that is, the bones in the front half of the foot bend or turn in toward the body. [HPO:probinson, PMID:19125433]

Standard name | HP_PREAXIAL_FOOT_POLYDACTYLY
Systematic name | M35479
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Preaxial foot polydactyly
Full description | Duplication of all or part of the first ray. [HPO:probinson, PMID:19125433]

Standard name | HP_FOOT_ACROOSTEOLYSIS
Systematic name | M35480
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Foot acroosteolysis
Full description |

Standard name | HP_ABNORMALITY_OF_THE_HALLUX
Systematic name | M35481
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the hallux
Full description | This term applies for all abnormalities of the big toe, also called hallux. [HPO:probinson]

Standard name | HP_OVERLAPPING_TOE
Systematic name | M35482
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Overlapping toe
Full description | Describes a foot digit resting on the dorsal surface of an adjacent digit when the foot is at rest. [HPO:probinson, PMID:19125433]

Standard name | HP_LONG_HALLUX
Systematic name | M35483
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Long hallux
Full description | Increased length of the big toe. [HPO:probinson]

Standard name | HP_FOOT_OLIGODACTYLY
Systematic name | M35484
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Foot oligodactyly
Full description | A developmental defect resulting in the presence of fewer than the normal number of toes. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_TARSAL_BONES
Systematic name | M35485
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the tarsal bones
Full description | An abnormality of the tarsus are the cluster of seven bones in the foot between the tibia and fibula and the metatarsus, including the calcaneus (heel) bone and the talus (ankle) bone. [HPO:curators]

Standard name | HP_SANDAL_GAP
Systematic name | M35486
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sandal gap
Full description | A widely spaced gap between the first toe (the great toe) and the second toe. [HPO:probinson, PMID:19125433]

Standard name | HP_BIFID_DISTAL_PHALANX_OF_TOE
Systematic name | M35487
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bifid distal phalanx of toe
Full description |

Standard name | HP_SHORT_DISTAL_PHALANX_OF_TOE
Systematic name | M35488
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short distal phalanx of toe
Full description | Short distance from the end of the toe to the most distal interphalangeal crease or distal interphalangeal joint flexion point, i.e., abnormally short distal phalanx of toe. [PMID:19125433]

Standard name | HP_TOE_CLINODACTYLY
Systematic name | M35489
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Toe clinodactyly
Full description | Bending or curvature of a toe in the tibial direction (i.e., towards the big toe). [HPO:probinson]

Standard name | HP_CLINODACTYLY_OF_THE_5TH_TOE
Systematic name | M35490
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Clinodactyly of the 5th toe
Full description | Bending or curvature of a fifth toe in the tibial direction (i.e., towards the big toe). [HPO:probinson]

Standard name | HP_DEEP_PLANTAR_CREASES
Systematic name | M35491
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Deep plantar creases
Full description | The presence of unusually deep creases (ridges/wrinkles) on the skin of sole of foot. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_BLOOD_AND_BLOOD_FORMING_TISSUES
Systematic name | M35492
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of blood and blood-forming tissues
Full description | An abnormality of the hematopoietic system. [HPO:probinson]

Standard name | HP_ABNORMAL_THROMBOCYTE_MORPHOLOGY
Systematic name | M35493
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal thrombocyte morphology
Full description | An abnormality of platelets. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_NEUTROPHILS
Systematic name | M35494
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of neutrophils
Full description | A neutrophil abnormality. [HPO:probinson, PMID:21094463, PMID:26819959]

Standard name | HP_PANCYTOPENIA
Systematic name | M35495
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pancytopenia
Full description | An abnormal reduction in numbers of all blood cell types (red blood cells, white blood cells, and platelets). [HPO:probinson]

Standard name | HP_ABNORMAL_ERYTHROCYTE_MORPHOLOGY
Systematic name | M35496
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal erythrocyte morphology
Full description | Any structural abnormality of erythrocytes (red-blood cells). [HPO:probinson]

Standard name | HP_HEMOLYTIC_ANEMIA
Systematic name | M35497
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hemolytic anemia
Full description | A type of anemia caused by premature destruction of red blood cells (hemolysis). [HPO:probinson]

Standard name | HP_ABNORMAL_EOSINOPHIL_MORPHOLOGY
Systematic name | M35498
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal eosinophil morphology
Full description | An abnormal count or structure of eosinophils. [HPO:probinson, PMID:23154224]

Standard name | HP_LEUKOPENIA
Systematic name | M35499
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Leukopenia
Full description | An abnormal decreased number of leukocytes in the blood. [HPO:probinson]

STANDARD_NAME="HP_TALIPES_CALCANEOVALGUS" SYSTEMATIC_NAME="M35500" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="" AUTHORS="" GEOID="" EXACT_SOURCE="HP:0001884" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="https://hpo.jax.org/app/browse/term/HP:0001884" CHIP="Human_NCBI_Gene_ID" CATEGORY_CODE="C5" SUB_CATEGORY_CODE="HPO" CONTRIBUTOR="Human Phenotype Ontology Group" CONTRIBUTOR_ORG="The Jackson Laboratory (JAX)" DESCRIPTION_BRIEF="Talipes calcaneovalgus" DESCRIPTION_FULL="Talipes calcaneovalgus is a flexible foot deformity (as opposed to a rigid congenital vertical talus foot deformity) that can either present as a positional or structural foot deformity depending on severity and/or causality. The axis of calcaneovalgus deformity is in the tibiotalar joint, where the foot is positioned in extreme hyperextension. On inspection, the foot has an \up and out\ appearance, with the dorsal forefoot practically touching the anterior aspect of the ankle and lower leg. [HPO:curators]"

Standard name | HP_MEGALOBLASTIC_ANEMIA
Systematic name | M35501
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Megaloblastic anemia
Full description | Anemia characterized by the presence of erythroblasts that are larger than normal (megaloblasts). [HPO:probinson]

Standard name | HP_AUTOIMMUNE_HEMOLYTIC_ANEMIA
Systematic name | M35502
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Autoimmune hemolytic anemia
Full description | An autoimmune form of hemolytic anemia. [HPO:probinson]

Standard name | HP_IRON_DEFICIENCY_ANEMIA
Systematic name | M35503
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Iron deficiency anemia
Full description |

Standard name | HP_ABNORMAL_BLEEDING
Systematic name | M35504
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal bleeding
Full description | An abnormal susceptibility to bleeding, often referred to as a bleeding diathesis. A bleeding diathesis may be related to vascular, platelet and coagulation defects. [HPO:probinson]

Standard name | HP_THROMBOCYTOSIS
Systematic name | M35505
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thrombocytosis
Full description | Increased numbers of platelets in the peripheral blood. [HPO:probinson]

Standard name | HP_NORMOCHROMIC_ANEMIA
Systematic name | M35506
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Normochromic anemia
Full description |

Standard name | HP_RETICULOCYTOPENIA
Systematic name | M35507
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Reticulocytopenia
Full description | A reduced number of reticulocytes in the peripheral blood. [HPO:probinson]

Standard name | HP_NORMOCYTIC_ANEMIA
Systematic name | M35508
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Normocytic anemia
Full description | A kind of anemia in which the volume of the red blood cells is normal. [HPO:probinson]

Standard name | HP_INCREASED_HEMOGLOBIN
Systematic name | M35509
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Increased hemoglobin
Full description |

Standard name | HP_POLYCYTHEMIA
Systematic name | M35510
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Polycythemia
Full description | Polycythemia is diagnosed if the red blood cell count, the hemoglobin level, and the red blood cell volume all exceed the upper limits of normal. [HPO:probinson]

Standard name | HP_GIANT_PLATELETS
Systematic name | M35511
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Giant platelets
Full description | Giant platelets are larger than 7 micrometers and usually 10 to 20 micrometers. The term giant platelet is used when the platelet is larger than the size of the average red cell in the field. (Description adapted from College of American Pathologists, Hematology Manual, 1998). [HPO:probinson]

Standard name | HP_NEUTROPENIA_IN_PRESENCE_OF_ANTI_NEUTROPIL_ANTIBODIES
Systematic name | M35512
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neutropenia in presence of anti-neutropil antibodies
Full description | A type of neutropenia that is observed in the presence of granulocyte-specific antibodies. [HPO:probinson, PMID:25642312]

Standard name | HP_CONGENITAL_THROMBOCYTOPENIA
Systematic name | M35513
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Congenital thrombocytopenia
Full description | Thrombocytopenia with congenital onset. [HPO:probinson]

Standard name | HP_THROMBOEMBOLISM
Systematic name | M35514
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Thromboembolism
Full description | The formation of a blood clot inside a blood vessel that subsequently travels through the blood stream from the site where it formed to another location in the body, generally leading to vascular occlusion at the distant site. [HPO:probinson]

Standard name | HP_HYPOPLASTIC_ANEMIA
Systematic name | M35515
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoplastic anemia
Full description | Anemia with varying degrees of erythrocytic hypoplasia without leukopenia or thrombocytopenia. [HPO:probinson]

Standard name | HP_LEUKEMIA
Systematic name | M35516
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Leukemia
Full description | A cancer of the blood and bone marrow characterized by an abnormal proliferation of leukocytes. [HPO:probinson, NCIT:C3161]

Standard name | HP_GRANULOCYTOPENIA
Systematic name | M35517
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Granulocytopenia
Full description | An abnormally reduced number of granulocytes in the blood. [HPO:probinson]

Standard name | HP_APLASTIC_ANEMIA
Systematic name | M35518
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aplastic anemia
Full description | Aplastic anemia is defined as pancytopenia with a hypocellular marrow. [HPO:probinson, PMID:21239768]

Standard name | HP_ACUTE_KIDNEY_INJURY
Systematic name | M35519
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Acute kidney injury
Full description | Sudden loss of renal function, as manifested by decreased urine production, and a rise in serum creatinine or blood urea nitrogen concentration (azotemia). [HPO:probinson]

Standard name | HP_RENAL_ARTERY_STENOSIS
Systematic name | M35520
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal artery stenosis
Full description | The presence of stenosis of the renal artery. [HPO:probinson]

Standard name | HP_VACUOLATED_LYMPHOCYTES
Systematic name | M35521
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Vacuolated lymphocytes
Full description | The presence of clear, sharply defined vacuoles in the lymphocyte cytoplasm. [HPO:probinson, PMID:20633042]

Standard name | HP_RETICULOCYTOSIS
Systematic name | M35522
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Reticulocytosis
Full description | An elevation in the number of reticulocytes (immature erythrocytes) in the peripheral blood circulation. [HPO:probinson]

Standard name | HP_SIDEROBLASTIC_ANEMIA
Systematic name | M35523
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sideroblastic anemia
Full description | Sideroblastic anemia results from a defect in the incorporation of iron into the heme molecule. A sideroblast is an erythroblast that has stainable deposits of iron in cytoplasm (this can be demonstrated by Prussian blue staining). [HPO:probinson]

Standard name | HP_ACANTHOCYTOSIS
Systematic name | M35524
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Acanthocytosis
Full description | Acanthocytosis is a type of poikilocytosis characterized by the presence of spikes on the cell surface. The cells have an irregular shape resembling many-pointed stars. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_COAGULATION
Systematic name | M35525
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of coagulation
Full description | An abnormality of the process of blood coagulation. That is, altered ability or inability of the blood to clot. [HPO:probinson]

Standard name | HP_REDUCED_FACTOR_XI_ACTIVITY
Systematic name | M35526
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Reduced factor XI activity
Full description | Decreased activity of coagulation factor XI. Factor XI, also known as plasma thromboplastin antecedent, is a serine proteinase that activates factor IX. [HPO:probinson]

Standard name | HP_NONSPHEROCYTIC_HEMOLYTIC_ANEMIA
Systematic name | M35527
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nonspherocytic hemolytic anemia
Full description |

Standard name | HP_HYPOCHROMIC_ANEMIA
Systematic name | M35528
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypochromic anemia
Full description | A type of anemia characterized by an abnormally low concentration of hemoglobin in the erythrocytes. [HPO:probinson]

Standard name | HP_SUBCUTANEOUS_HEMORRHAGE
Systematic name | M35529
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Subcutaneous hemorrhage
Full description | This term refers to an abnormally increased susceptibility to bruising (purpura, petechiae, or ecchymoses). [HPO:probinson]

Standard name | HP_PERSISTENT_BLEEDING_AFTER_TRAUMA
Systematic name | M35530
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Persistent bleeding after trauma
Full description |

Standard name | HP_MICROCYTIC_ANEMIA
Systematic name | M35531
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Microcytic anemia
Full description | A kind of anemia in which the volume of the red blood cells is reduced. [HPO:probinson]

Standard name | HP_MICROANGIOPATHIC_HEMOLYTIC_ANEMIA
Systematic name | M35532
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Microangiopathic hemolytic anemia
Full description |

Standard name | HP_METABOLIC_ACIDOSIS
Systematic name | M35533
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Metabolic acidosis
Full description | Metabolic acidosis (MA) is characterized by a fall in blood pH due to a reduction of serum bicarbonate concentration. This can occur as a result of either the accumulation of acids (high anion gap MA) or the loss of bicarbonate from the gastrointestinal tract or the kidney (hyperchloremic MA). By definition, MA is not due to a respirary cause. [HPO:probinson, PMID:17936961, PMID:31418093]

Standard name | HP_DEHYDRATION
Systematic name | M35534
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dehydration
Full description |

Standard name | HP_FEVER
Systematic name | M35535
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Fever
Full description | Elevated body temperature due to failed thermoregulation. [HPO:sdoelken]

Standard name | HP_KETOSIS
Systematic name | M35536
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ketosis
Full description | Presence of elevated levels of ketone bodies in the body. [HPO:probinson, PMID:28278308]

Standard name | HP_RENAL_TUBULAR_ACIDOSIS
Systematic name | M35537
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Renal tubular acidosis
Full description | Acidosis owing to malfunction of the kidney tubules with accumulation of metabolic acids and hyperchloremia, potentially leading to complications including hypokalemia, hypercalcinuria, nephrolithiasis and nephrocalcinosis. [HPO:probinson]

Standard name | HP_ALKALOSIS
Systematic name | M35538
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Alkalosis
Full description | Depletion of acid or accumulation base in the body fluids. [HPO:probinson, PMID:24381489]

Standard name | HP_HYPOKALEMIC_ALKALOSIS
Systematic name | M35539
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypokalemic alkalosis
Full description |

Standard name | HP_RESPIRATORY_ALKALOSIS
Systematic name | M35540
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Respiratory alkalosis
Full description | Alkalosis due to excess loss of carbon dioxide from the body. [HPO:probinson]

Standard name | HP_GLUCOSE_INTOLERANCE
Systematic name | M35541
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Glucose intolerance
Full description | Glucose intolerance (GI) can be defined as dysglycemia that comprises both prediabetes and diabetes. It includes the conditions of impaired fasting glucose (IFG) and impaired glucose tolerance (IGT) and diabetes mellitus (DM). [PMID:29763085]

Standard name | HP_RECURRENT_FEVER
Systematic name | M35542
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Recurrent fever
Full description | Periodic (episodic or recurrent) bouts of fever. [HPO:probinson]

Standard name | HP_UNEXPLAINED_FEVERS
Systematic name | M35543
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Unexplained fevers
Full description | Episodes of fever for which no infectious cause can be identified. [HPO:curators]

Standard name | HP_TRUNCAL_OBESITY
Systematic name | M35544
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Truncal obesity
Full description | Obesity located preferentially in the trunk of the body as opposed to the extremities. [HPO:probinson]

Standard name | HP_NONKETOTIC_HYPOGLYCEMIA
Systematic name | M35545
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nonketotic hypoglycemia
Full description |

Standard name | HP_HYPOKALEMIC_METABOLIC_ALKALOSIS
Systematic name | M35546
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypokalemic metabolic alkalosis
Full description |

Standard name | HP_HYPOPLASTIC_HEART
Systematic name | M35547
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoplastic heart
Full description |

Standard name | HP_PALPITATIONS
Systematic name | M35548
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Palpitations
Full description | A sensation that the heart is pounding or racing, which is a non-specific sign but may be a manifestation of arrhythmia. [HPO:probinson]

Standard name | HP_APLASIA_HYPOPLASIA_OF_METATARSAL_BONES
Systematic name | M35549
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aplasia/Hypoplasia of metatarsal bones
Full description | Absence or underdevelopment of the metatarsal bones. [HPO:curators]

Standard name | HP_ABNORMAL_SCALP_MORPHOLOGY
Systematic name | M35550
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal scalp morphology
Full description | Any anomaly of the scalp, the skin an subcutaneous tissue of the head on which head hair grows. [HPO:probinson]

Standard name | HP_MESANGIAL_ABNORMALITY
Systematic name | M35551
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mesangial abnormality
Full description | An abnormality of the mesangium, i.e., of the central part of the renal glomerulus between capillaries. [HPO:probinson]

Standard name | HP_DIFFUSE_MESANGIAL_SCLEROSIS
Systematic name | M35552
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Diffuse mesangial sclerosis
Full description | Diffuse sclerosis of the mesangium, as manifestated by diffuse mesangial matrix expansion. [HPO:probinson]

Standard name | HP_ABNORMAL_TUBULOINTERSTITIAL_MORPHOLOGY
Systematic name | M35553
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal tubulointerstitial morphology
Full description | An abnormality that involves the tubules and interstitial tissue of the kidney. [HPO:probinson]

Standard name | HP_TUBULOINTERSTITIAL_NEPHRITIS
Systematic name | M35554
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tubulointerstitial nephritis
Full description | A form of inflammation of the kidney affecting the interstitium of the kidneys surrounding the tubules. [HP:probinson]

Standard name | HP_HYPERSPLENISM
Systematic name | M35555
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypersplenism
Full description | A malfunctioning of the spleen in which it prematurely destroys red blood cells. [HPO:probinson]

Standard name | HP_MACROCYTIC_ANEMIA
Systematic name | M35556
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Macrocytic anemia
Full description | A type of anemia characterized by increased size of erythrocytes with increased mean corpuscular volume (MCV) and increased mean corpuscular hemoglobin (MCH). [HPO:probinson, PMID:19202968]

Standard name | HP_AUTOIMMUNE_THROMBOCYTOPENIA
Systematic name | M35557
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Autoimmune thrombocytopenia
Full description | The presence of thrombocytopenia in combination with detection of antiplatelet antibodies. [DDD:wouwehand]

Standard name | HP_LEUKOCYTOSIS
Systematic name | M35558
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Leukocytosis
Full description | An abnormal increase in the number of leukocytes in the blood. [HPO:probinson]

Standard name | HP_REDUCED_ANTITHROMBIN_III_ACTIVITY
Systematic name | M35559
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Reduced antithrombin III activity
Full description | An abnormality of coagulation related to a decreased concentration of antithrombin-III. [HPO:probinson]

Standard name | HP_ABNORMAL_THROMBOSIS
Systematic name | M35560
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal thrombosis
Full description | Venous or arterial thrombosis (formation of blood clots) of spontaneous nature and which cannot be fully explained by acquired risk (e.g. atherosclerosis). [HPO:probinson]

Standard name | HP_EXTRAMEDULLARY_HEMATOPOIESIS
Systematic name | M35561
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Extramedullary hematopoiesis
Full description | The process of hematopoiesis occurring outside of the bone marrow (in the liver, thymus, and spleen) in the postnatal organisms. [HPO:probinson]

Standard name | HP_MEGALOBLASTIC_BONE_MARROW
Systematic name | M35562
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Megaloblastic bone marrow
Full description | Abnormal increased number of megaloblasts in the bone marrow. [HPO:probinson]

Standard name | HP_SCHISTOCYTOSIS
Systematic name | M35563
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Schistocytosis
Full description | The presence of an abnormal number of fragmented red blood cells (schistocytes) in the blood. [HPO:probinson]

Standard name | HP_SEA_BLUE_HISTIOCYTOSIS
Systematic name | M35564
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sea-blue histiocytosis
Full description | An abnormality of histiocytes, in which the cells take on a sea blue appearance due to abnormally increased lipid content. Histiocytes are a type of macrophage. Sea-blue histiocytes are typically large macrophages from 20 to 60 micrometers in diameter with a single eccentric nucleus whose cytoplasm if packed with sea-blue or blue-green granules when stained with Wright-Giemsa. [HPO:probinson, PMID:8797061]

Standard name | HP_HYPOKETOTIC_HYPOGLYCEMIA
Systematic name | M35565
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoketotic hypoglycemia
Full description | A decreased concentration of glucose in the blood associated with a reduced concentration of ketone bodies. [HPO:probinson]

Standard name | HP_HYPERAMMONEMIA
Systematic name | M35566
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperammonemia
Full description | An increased concentration of ammonia in the blood. [HPO:gcarletti]

Standard name | HP_RECURRENT_HYPOGLYCEMIA
Systematic name | M35567
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Recurrent hypoglycemia
Full description | Recurrent episodes of decreased concentration of glucose in the blood. [HPO:gcarletti]

Standard name | HP_FETAL_AKINESIA_SEQUENCE
Systematic name | M35568
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Fetal akinesia sequence
Full description | Decreased fetal activity associated with multiple joint contractures, facial anomalies and pulmonary hypoplasia. Ultrasound examination may reveal polyhydramnios, ankylosis, scalp edema, and decreased chest movements (reflecting pulmonary hypoplasia). [HPO:probinson]

Standard name | HP_APLASIA_HYPOPLASIA_OF_TOE
Systematic name | M35569
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aplasia/Hypoplasia of toe
Full description | Absence or hypoplasia of toes. [HPO:probinson]

Standard name | HP_ORGANIC_ACIDURIA
Systematic name | M35570
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Organic aciduria
Full description | Excretion of non-amino organic acids in urine. [HPO:probinson]

Standard name | HP_KETOACIDOSIS
Systematic name | M35571
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ketoacidosis
Full description | Acidosis resulting from accumulation of ketone bodies. [HPO:probinson]

Standard name | HP_HYPERCHLOREMIC_ACIDOSIS
Systematic name | M35572
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperchloremic acidosis
Full description | Acidosis (pH less than 7.35) that develops with an increase in ionic chloride. [PMID:29493965]

Standard name | HP_GOUT
Systematic name | M35573
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gout
Full description | Recurrent attacks of acute inflammatory arthritis of a joint or set of joints caused by elevated levels of uric acid in the blood which crystallize and are deposited in joints, tendons, and surrounding tissues. [HPO:sdoelken]

Standard name | HP_NEONATAL_HYPOGLYCEMIA
Systematic name | M35574
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neonatal hypoglycemia
Full description |

Standard name | HP_ABNORMAL_FACIAL_SHAPE
Systematic name | M35575
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal facial shape
Full description | An abnormal morphology (form) of the face or its components. [DDD:jclayton-smith]

Standard name | HP_SHORT_COLUMELLA
Systematic name | M35576
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Short columella
Full description | Reduced distance from the anterior border of the naris to the subnasale. [PMID:19152422]

Standard name | HP_DEEP_PHILTRUM
Systematic name | M35577
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Deep philtrum
Full description | Accentuated, prominent philtral ridges giving rise to an exaggerated groove in the midline between the nasal base and upper vermillion border. [PMID:19152422]

Standard name | HP_LARGE_FOREHEAD
Systematic name | M35578
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Large forehead
Full description |

Standard name | HP_FACIAL_CLEFT
Systematic name | M35579
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial cleft
Full description | A congenital malformation with a cleft (gap or opening) in the face. [HPO:probinson]

Standard name | HP_POTTER_FACIES
Systematic name | M35580
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Potter facies
Full description | A facial appearance characteristic of a fetus or neonate due to oligohydramnios experienced in the womb, comprising ocular hypertelorism, low-set ears, receding chin, and flattening of the nose. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_ABDOMINAL_ORGANS
Systematic name | M35581
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the abdominal organs
Full description | An abnormality of the viscera of the abdomen. [HPO:probinson]

Standard name | HP_VOMITING
Systematic name | M35582
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Vomiting
Full description | Forceful ejection of the contents of the stomach through the mouth by means of a series of involuntary spasmic contractions. [HPO:probinson]

Standard name | HP_DIARRHEA
Systematic name | M35583
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Diarrhea
Full description | Abnormally increased frequency of loose or watery bowel movements. [HPO:probinson]

Standard name | HP_DYSPHAGIA
Systematic name | M35584
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dysphagia
Full description | Difficulty in swallowing. [HPO:probinson]

Standard name | HP_NAUSEA_AND_VOMITING
Systematic name | M35585
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nausea and vomiting
Full description | Nausea is a commonly encountered symptom that has been defined as an unpleasant painless subjective feeling that one will imminently vomit. Vomiting has been defined as the forceful expulsion of the contents of the stomach, duodenum, or jejunum through the oral cavity. While nausea and vomiting are often thought to exist on a temporal continuum, this is not always the case. There are situations when severe nausea may be present without emesis and less frequently, when emesis may be present without preceding nausea. [PMID:26770271]

Standard name | HP_NAUSEA
Systematic name | M35586
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nausea
Full description | A sensation of unease in the stomach together with an urge to vomit. [HPO:probinson, PMID:26770271]

Standard name | HP_CONSTIPATION
Systematic name | M35587
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Constipation
Full description | Infrequent or difficult evacuation of feces. [HPO:probinson]

Standard name | HP_GASTROESOPHAGEAL_REFLUX
Systematic name | M35588
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gastroesophageal reflux
Full description | A condition in which the stomach contents leak backwards from the stomach into the esophagus through the lower esophageal sphincter. [HPO:probinson]

Standard name | HP_ANAL_ATRESIA
Systematic name | M35589
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anal atresia
Full description | Congenital absence of the anus, i.e., the opening at the bottom end of the intestinal tract. [HPO:probinson]

Standard name | HP_MALABSORPTION
Systematic name | M35590
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Malabsorption
Full description | Impaired ability to absorb one or more nutrients from the intestine. [HPO:probinson]

Standard name | HP_ANAL_STENOSIS
Systematic name | M35591
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anal stenosis
Full description | Abnormal narrowing of the anal opening. [HPO:probinson]

Standard name | HP_ABDOMINAL_PAIN
Systematic name | M35592
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abdominal pain
Full description | An unpleasant sensation characterized by physical discomfort (such as pricking, throbbing, or aching) and perceived to originate in the abdomen. [HPO:probinson]

Standard name | HP_CHRONIC_DIARRHEA
Systematic name | M35593
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Chronic diarrhea
Full description | The presence of chronic diarrhea, which is usually taken to mean diarrhea that has persisted for over 4 weeks. [HPO:probinson]

Standard name | HP_ABNORMAL_ESOPHAGUS_MORPHOLOGY
Systematic name | M35594
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal esophagus morphology
Full description | A structural abnormality of the esophagus. [HPO:probinson]

Standard name | HP_ESOPHAGEAL_ATRESIA
Systematic name | M35595
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Esophageal atresia
Full description | A developmental defect resulting in complete obliteration of the lumen of the esophagus such that the esophagus ends in a blind pouch rather than connecting to the stomach. [HPO:curators]

Standard name | HP_POOR_SUCK
Systematic name | M35596
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Poor suck
Full description | An inadequate sucking reflex, resulting in the difficult of newborns to be breast-fed. [HPO:curators]

Standard name | HP_ABNORMALITY_OF_THE_RECTUM
Systematic name | M35597
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the rectum
Full description | An abnormaltiy of the rectum, the final segment of the large intestine that stores solid waste until it passes through the anus. [HPO:probinson]

Standard name | HP_RECTAL_PROLAPSE
Systematic name | M35598
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Rectal prolapse
Full description | Protrusion of the rectal mucous membrane through the anus. [HPO:probinson]

Standard name | HP_HIATUS_HERNIA
Systematic name | M35599
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hiatus hernia
Full description | The presence of a hernia in which the upper part of the stomach, i.e., mainly the gastric cardia protrudes through the diaphragmatic esophageal hiatus. [HPO:probinson]

Standard name | HP_INFLAMMATION_OF_THE_LARGE_INTESTINE
Systematic name | M35600
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Inflammation of the large intestine
Full description | Inflammation, or an inflammatory state in the large intestine. []

Standard name | HP_PROTEIN_AVOIDANCE
Systematic name | M35601
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Protein avoidance
Full description |

Standard name | HP_ANOREXIA
Systematic name | M35602
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anorexia
Full description | A lack or loss of appetite for food (as a medical condition). [HPO:probinson]

Standard name | HP_ESOPHAGEAL_VARIX
Systematic name | M35603
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Esophageal varix
Full description | Extreme dilation of the submucusoal veins in the lower portion of the esophagus. [HPO:probinson]

Standard name | HP_INTRACTABLE_DIARRHEA
Systematic name | M35604
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Intractable diarrhea
Full description |

Standard name | HP_ESOPHAGEAL_STRICTURE
Systematic name | M35605
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Esophageal stricture
Full description | A pathological narrowing of the esophagus that is caused by the development of a ring of scar tissue that constricts the esophageal lumen. [HPO:probinson]

Standard name | HP_ZOLLINGER_ELLISON_SYNDROME
Systematic name | M35606
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Zollinger-Ellison syndrome
Full description | A condition in which there is increased production of gastrin by a gastrin-secreting tumor (usually located in the pancreas, duodenum, or abdominal lymph nodes) that stimulates the gastric mucosa to maximal activity, with consequent gastrointestinal mucosal ulceration. [HPO:probinson]

Standard name | HP_HYPOTHERMIA
Systematic name | M35607
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypothermia
Full description | Reduced body temperature due to failed thermoregulation. [HPO:sdoelken]

Standard name | HP_HEAT_INTOLERANCE
Systematic name | M35608
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Heat intolerance
Full description | The inability to maintain a comfortably body temperature in warm or hot weather. [HPO:probinson]

Standard name | HP_MALIGNANT_HYPERTHERMIA
Systematic name | M35609
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Malignant hyperthermia
Full description | Malignant hyperthermia is characterized by a rapid increase in temperature to 39-42 degrees C in response to inhalational anesthetics such as halothane or to muscle relaxants such as succinylcholine. [HPO:curators]

Standard name | HP_PROXIMAL_RENAL_TUBULAR_ACIDOSIS
Systematic name | M35610
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Proximal renal tubular acidosis
Full description | A type of renal tubular acidosis characterized by a failure of the proximal tubular cells to reabsorb bicarbonate, leading to urinary bicarbonate wasting and subsequent acidemia. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_GLABELLA
Systematic name | M35611
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the glabella
Full description | An abnormality of the glabella. [HPO:probinson]

Standard name | HP_MYOPATHIC_FACIES
Systematic name | M35612
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Myopathic facies
Full description | A facial appearance characteristic of myopathic conditions. The face appears expressionless with sunken cheeks, bilateral ptosis, and inability to elevate the corners of the mouth, due to muscle weakness. [HPO:curators]

Standard name | HP_LOWER_LIMB_SPASTICITY
Systematic name | M35613
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lower limb spasticity
Full description | Spasticity (velocity-dependent increase in tonic stretch reflexes with increased muscle tone and hyperexcitable tendon reflexes) in the muscles of the lower limbs, hips, and pelvis [HPO:probinson, UKT:rschuele]

Standard name | HP_MORPHOLOGICAL_ABNORMALITY_OF_THE_PYRAMIDAL_TRACT
Systematic name | M35614
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Morphological abnormality of the pyramidal tract
Full description | Any structural abnormality of the pyramidal tract, whose chief element, the corticospinal tract, is the only direct connection between the brain and the spinal cord. In addition to the corticospinal tract, the pyramidal system includes the corticobulbar, corticomesencephalic, and corticopontine tracts. [HPO:curators]

Standard name | HP_RIGIDITY
Systematic name | M35615
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Rigidity
Full description | Continuous involuntary sustained muscle contraction. When an affected muscle is passively stretched, the degree of resistance remains constant regardless of the rate at which the muscle is stretched. This feature helps to distinguish rigidity from muscle spasticity. [HPO:probinson]

Standard name | HP_SPASTIC_GAIT
Systematic name | M35616
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Spastic gait
Full description | Spasticity is manifested by increased stretch reflex which is intensified with movement velocity. This results in excessive and inappropriate muscle activation which can contribute to muscle hypertonia. Spastic gait is characterized by manifestations such as muscle hypertonia, stiff knee, and circumduction of the leg. [PMID:25649546]

Standard name | HP_GAIT_ATAXIA
Systematic name | M35617
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gait ataxia
Full description | A type of ataxia characterized by the impairment of the ability to coordinate the movements required for normal walking. Gait ataxia is characteirzed by a wide-based staggering gait with a tendency to fall. [HPO:probinson, UKT:rschuele]

Standard name | HP_BRADYKINESIA
Systematic name | M35618
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bradykinesia
Full description | Bradykinesia literally means slow movement, and is used clinically to denote a slowness in the execution of movement (in contrast to hypokinesia, which is used to refer to slowness in the initiation of movement). [HPO:probinson]

Standard name | HP_NEUROMUSCULAR_DYSPHAGIA
Systematic name | M35619
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neuromuscular dysphagia
Full description |

Standard name | HP_BILATERAL_TONIC_CLONIC_SEIZURE
Systematic name | M35620
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bilateral tonic-clonic seizure
Full description | A bilateral tonic-clonic seizure is a seizure defined by a tonic (bilateral increased tone, lasting seconds to minutes) and then a clonic (bilateral sustained rhythmic jerking) phase. [HPO:pnrobinson, PMID:28276060]

Standard name | HP_LIMB_ATAXIA
Systematic name | M35621
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Limb ataxia
Full description | A kind of ataxia that affects movements of the extremities. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_EXTRAPYRAMIDAL_MOTOR_FUNCTION
Systematic name | M35622
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of extrapyramidal motor function
Full description | A neurological condition related to lesions of the basal ganglia leading to typical abnormalities including akinesia (inability to initiate changes in activity and perform volitional movements rapidly and easily), muscular rigidity (continuous contraction of muscles with constant resistance to passive movement), chorea (widespread arrhythmic movements of a forcible, rapid, jerky, and restless nature), athetosis (inability to sustain the muscles of the fingers, toes, or other group of muscles in a fixed position), and akathisia (inability to remain motionless). [HPO:probinson]

Standard name | HP_CHOREA
Systematic name | M35623
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Chorea
Full description | Chorea (Greek for 'dance') refers to widespread arrhythmic involuntary movements of a forcible, jerky and restless fashion. It is a random-appearing sequence of one or more discrete involuntary movements or movement fragments. Movements appear random because of variability in timing, duration or location. Each movement may have a distinct start and end. However, movements may be strung together and thus may appear to flow randomly from one muscle group to another. Chorea can involve the trunk, neck, face, tongue, and extremities. [HPO:probinson, PMID:20589866]

Standard name | HP_PROGRESSIVE_CEREBELLAR_ATAXIA
Systematic name | M35624
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Progressive cerebellar ataxia
Full description |

Standard name | HP_DYSDIADOCHOKINESIS
Systematic name | M35625
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dysdiadochokinesis
Full description | A type of ataxia characterized by the impairment of the ability to perform rapidly alternating movements, such as pronating and supinating his or her hand on the dorsum of the other hand as rapidly as possible. [HPO:probinson, HPO:zaferyueksel, UKB:tklockgether]

Standard name | HP_MIGRAINE
Systematic name | M35626
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Migraine
Full description | Migraine is a chronic neurological disorder characterized by episodic attacks of headache and associated symptoms. [HPO:probinson, PMID:15304572]

Standard name | HP_MIGRAINE_WITH_AURA
Systematic name | M35627
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Migraine with aura
Full description | A type of migraine in which there is an aura characterized by focal neurological phenomena that usually proceed, but may accompany or occur in the absence of, the headache. The symptoms of an aura may include fully reversible visual, sensory, and speech symptoms but not motor weakness. Visual symptoms may include flickering lights, spots and lines and/or loss of vision and/or unilateral sensory symptoms such as paresthesias or numbness. At least one of the symptoms of an aura develops gradually over 5 or more minutes and/or different symptoms occur in succession. [HPO:probinson, PMID:15304572]

Standard name | HP_TRUNCAL_ATAXIA
Systematic name | M35628
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Truncal ataxia
Full description | Truncal ataxia is a sign of ataxia characterized by instability of the trunk. It usually occurs during sitting. [HPO:probinson, UKT:rschuele]

Standard name | HP_HYPOPLASIA_OF_THE_CORPUS_CALLOSUM
Systematic name | M35629
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoplasia of the corpus callosum
Full description | Underdevelopment of the corpus callosum. [HPO:probinson, PMID:21263138]

Standard name | HP_ENCEPHALOCELE
Systematic name | M35630
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Encephalocele
Full description | A neural tube defect characterized by sac-like protrusions of the brain and the membranes that cover it through openings in the skull. [HPO:probinson]

Standard name | HP_OCCIPITAL_ENCEPHALOCELE
Systematic name | M35631
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Occipital encephalocele
Full description | A type of encephalocele (that is, a a protrusion of part of the cranial contents including brain tissue through a congenital opening in the cranium, typically covered with skin or mucous membrane) in the occipital region of the skull. Occipital encephalocele presents as a midline swelling over the occipital bone. It is usually covered with normal full-thickness scalp. [DDD:awilkie, HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_UPPER_RESPIRATORY_TRACT
Systematic name | M35632
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the upper respiratory tract
Full description | An abnormality of the upper respiratory tract. [HPO:probinson]

Standard name | HP_PNEUMONIA
Systematic name | M35633
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pneumonia
Full description | Inflammation of any part of the lung parenchyma. [HPO:probinson]

Standard name | HP_RESTRICTIVE_VENTILATORY_DEFECT
Systematic name | M35634
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Restrictive ventilatory defect
Full description | A functional defect characterized by reduced total lung capacity (TLC) not associated with abnormalities of expiratory airflow or airway resistance. Spirometrically, a restrictive defect is defined as FEV1 (forced expiratory volume in 1 second) and FVC (forced vital capacity) less than 80 per cent. Restrictive lung disease may be caused by alterations in lung parenchyma or because of a disease of the pleura, chest wall, or neuromuscular apparatus. [NIHR:ldaugherty]

Standard name | HP_PULMONARY_ARTERIAL_HYPERTENSION
Systematic name | M35635
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pulmonary arterial hypertension
Full description | Pulmonary hypertension is defined mean pulmonary artery pressure of 25mmHg or more and pulmonary capillary wedge pressure of 15mmHg or less when measured by right heart catheterisation at rest and in a supine position. [HPO:probinson]

Standard name | HP_RESPIRATORY_INSUFFICIENCY
Systematic name | M35636
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Respiratory insufficiency
Full description |

Standard name | HP_DYSPNEA
Systematic name | M35637
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dyspnea
Full description | Difficult or labored breathing. [HPO:probinson]

Standard name | HP_EMPHYSEMA
Systematic name | M35638
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Emphysema
Full description |

Standard name | HP_RESPIRATORY_DISTRESS
Systematic name | M35639
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Respiratory distress
Full description | Difficulty in breathing. The physical presentation of respiratory distress is generally referred to as labored breathing, while the sensation of respiratory distress is called shortness of breath or dyspnea. []

Standard name | HP_ASTHMA
Systematic name | M35640
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Asthma
Full description | Asthma is characterized by increased responsiveness of the tracheobronchial tree to multiple stimuli, leading to narrowing of the air passages with resultant dyspnea, cough, and wheezing. [HPO:probinson]

Standard name | HP_RECURRENT_ASPIRATION_PNEUMONIA
Systematic name | M35641
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Recurrent aspiration pneumonia
Full description | Increased susceptibility to aspiration pneumonia, defined as pneumonia due to breathing in foreign material, as manifested by a medical history of repeated episodes of aspiration pneumonia. [HPO:probinson]

Standard name | HP_ABNORMAL_LUNG_LOBATION
Systematic name | M35642
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal lung lobation
Full description | Defects in the formation of pulmonary lobes. [HPO:probinson]

Standard name | HP_PLEURITIS
Systematic name | M35643
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pleuritis
Full description | Inflammation of the pleura. [HPO:sdoelken]

Standard name | HP_ABNORMAL_PLEURA_MORPHOLOGY
Systematic name | M35644
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal pleura morphology
Full description | An abnormality of the pulmonary pleura, the thin, transparent membrane which covers the lungs and lines the inside of the chest walls. [HPO:probinson]

Standard name | HP_APNEA
Systematic name | M35645
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Apnea
Full description | Lack of breathing with no movement of the respiratory muscles and no exchange of air in the lungs. This term refers to a disposition to have recurrent episodes of apnea rather than to a single event. [HPO:curators]

Standard name | HP_HEMOPTYSIS
Systematic name | M35646
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hemoptysis
Full description | Coughing up (expectoration) of blood or blood-streaked sputum from the larynx, trachea, bronchi, or lungs. [HPO:probinson]

Standard name | HP_PNEUMOTHORAX
Systematic name | M35647
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pneumothorax
Full description | Accumulation of air in the pleural cavity leading to a partially or completely collapsed lung. [HPO:probinson]

Standard name | HP_SPONTANEOUS_PNEUMOTHORAX
Systematic name | M35648
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Spontaneous pneumothorax
Full description | Pneumothorax occurring without traumatic injury to the chest or lung. [HPO:probinson]

Standard name | HP_BRONCHIECTASIS
Systematic name | M35649
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Bronchiectasis
Full description | Persistent abnormal dilatation of the bronchi owing to localized and irreversible destruction and widening of the large airways. [HPO:probinson]

Standard name | HP_PULMONARY_INFILTRATES
Systematic name | M35650
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pulmonary infiltrates
Full description |

Standard name | HP_ABNORMALITY_OF_THE_CEREBRAL_VENTRICLES
Systematic name | M35651
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the cerebral ventricles
Full description | Abnormality of the cerebral ventricles. [HPO:probinson]

Standard name | HP_VENTRICULOMEGALY
Systematic name | M35652
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ventriculomegaly
Full description | An increase in size of the ventricular system of the brain. [HPO:probinson]

Standard name | HP_CEREBRAL_CORTICAL_ATROPHY
Systematic name | M35653
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cerebral cortical atrophy
Full description | Atrophy of the cortex of the cerebrum. [HPO:probinson]

Standard name | HP_GENERALIZED_NON_MOTOR_ABSENCE_SEIZURE
Systematic name | M35654
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Generalized non-motor (absence) seizure
Full description | A generalized non-motor (absence) seizure is a type of a type of dialeptic seizure that is of electrographically generalized onset. It is a generalized seizure characterised by an interruption of activities, a blank stare, and usually the person will be unresponsive when spoken to. Any ictal motor phenomena are minor in comparison to these non-motor features. [HPO:probinson, PMID:28276060, PMID:28276062, PMID:28276064]

Standard name | HP_POLYMICROGYRIA
Systematic name | M35655
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Polymicrogyria
Full description | Polymicrogyria is a congenital malformation of the cerebral cortex characterized by abnormal cortical layering (lamination) and an excessive number of small gyri (folds). [COST:neuromig, HPO:probinson, PMID:24888723]

Standard name | HP_ABNORMAL_UPPER_MOTOR_NEURON_MORPHOLOGY
Systematic name | M35656
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal upper motor neuron morphology
Full description | Any structural anomaly that affects the upper motor neuron. []

STANDARD_NAME="HP_EPISODIC_ATAXIA" SYSTEMATIC_NAME="M35657" HISTORICAL_NAME="" ORGANISM="Homo sapiens" PMID="" AUTHORS="" GEOID="" EXACT_SOURCE="HP:0002131" GENESET_LISTING_URL="" EXTERNAL_DETAILS_URL="https://hpo.jax.org/app/browse/term/HP:0002131" CHIP="Human_NCBI_Gene_ID" CATEGORY_CODE="C5" SUB_CATEGORY_CODE="HPO" CONTRIBUTOR="Human Phenotype Ontology Group" CONTRIBUTOR_ORG="The Jackson Laboratory (JAX)" DESCRIPTION_BRIEF="Episodic ataxia" DESCRIPTION_FULL="Periodic spells of incoordination and imbalance, that is, episodes of ataxia typically lasting from 10 minutes to several hours or days.\n [HPO:probinson]"

Standard name | HP_PORENCEPHALIC_CYST
Systematic name | M35658
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Porencephalic cyst
Full description | A cavity within the cerebral hemisphere, filled with cerebrospinal fluid, that communicates directly with the ventricular system. [HPO:probinson, PMID:9279052]

Standard name | HP_STATUS_EPILEPTICUS
Systematic name | M35659
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Status epilepticus
Full description | Status epilepticus is a type of prolonged seizure resulting either from the failure of the mechanisms responsible for seizure termination or from the initiation of mechanisms which lead to abnormally prolonged seizures (after time point t1). It is a condition that can have long-term consequences (after time point t2), including neuronal death, neuronal injury, and alteration of neuronal networks, depending on the type and duration of seizures. [HPO:jalbers, ORCID:0000-0002-1735-8178, PMID:26336950, PMID:28276060]

Standard name | HP_ABNORMALITY_OF_THE_BASAL_GANGLIA
Systematic name | M35660
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the basal ganglia
Full description | Abnormality of the basal ganglia. [HPO:probinson]

Standard name | HP_BASAL_GANGLIA_CALCIFICATION
Systematic name | M35661
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Basal ganglia calcification
Full description | The presence of calcium deposition affecting one or more structures of the basal ganglia. [HPO:probinson]

Standard name | HP_BROAD_BASED_GAIT
Systematic name | M35662
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Broad-based gait
Full description | An abnormal gait pattern in which persons stand and walk with their feet spaced widely apart. This is often a component of cerebellar ataxia. [HPO:curators]

Standard name | HP_SUBARACHNOID_HEMORRHAGE
Systematic name | M35663
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Subarachnoid hemorrhage
Full description | Hemorrhage occurring between the arachnoid mater and the pia mater. [HPO:sdoelken]

Standard name | HP_ARRHINENCEPHALY
Systematic name | M35664
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Arrhinencephaly
Full description |

Standard name | HP_ISCHEMIC_STROKE
Systematic name | M35665
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Ischemic stroke
Full description |

Standard name | HP_GAIT_IMBALANCE
Systematic name | M35666
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gait imbalance
Full description |

Standard name | HP_ABNORMALITY_OF_THE_SPINAL_CORD
Systematic name | M35667
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the spinal cord
Full description | An abnormality of the spinal cord (myelon). [HPO:probinson]

Standard name | HP_FRONTOTEMPORAL_DEMENTIA
Systematic name | M35668
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Frontotemporal dementia
Full description | A dementia associated with degeneration of the frontotemporal lobe and clinically associated with personality and behavioral changes such as disinhibition, apathy, and lack of insight. The hallmark feature of frontotemporal dementia is the presentation with focal syndromes such as progressive language dysfunction, or aphasia, or behavioral changes characteristic of frontal lobe disorders. [HPO:probinson, PMID:24966676]

Standard name | HP_HYPOPHOSPHATEMIA
Systematic name | M35669
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypophosphatemia
Full description | An abnormally decreased phosphate concentration in the blood. [HPO:gcarletti]

Standard name | HP_HYPERCALCIURIA
Systematic name | M35670
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypercalciuria
Full description |

Standard name | HP_INCREASED_SERUM_LACTATE
Systematic name | M35671
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Increased serum lactate
Full description | Abnormally increased level of blood lactate (2-hydroxypropanoic acid). Lactate is produced from pyruvate by lactate dehydrogenase during normal metabolism. The terms lactate and lactic acid are often used interchangeably but lactate (the component measured in blood) is strictly a weak base whereas lactic acid is the corresponding acid. Lactic acidosis is often used clinically to describe elevated lactate but should be reserved for cases where there is a corresponding acidosis (pH below 7.35). [HPO:probinson, PMID:24079682]

Standard name | HP_HYPERKALEMIA
Systematic name | M35672
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperkalemia
Full description | An abnormally increased potassium concentration in the blood. [HPO:probinson]

Standard name | HP_HYPERTRIGLYCERIDEMIA
Systematic name | M35673
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypertriglyceridemia
Full description | An abnormal increase in the level of triglycerides in the blood. [HPO:probinson]

Standard name | HP_HOMOCYSTINURIA
Systematic name | M35674
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Homocystinuria
Full description | An increased concentration of homocystine in the urine. [HPO:gcarletti]

Standard name | HP_HEPARAN_SULFATE_EXCRETION_IN_URINE
Systematic name | M35675
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Heparan sulfate excretion in urine
Full description | An increased concentration of heparan sulfates in the urine. [HPO:probinson]

Standard name | HP_HYPERHOMOCYSTINEMIA
Systematic name | M35676
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hyperhomocystinemia
Full description | An increased concentration of homocystine in the blood. [HPO:gcarletti]

Standard name | HP_LOW_POSTERIOR_HAIRLINE
Systematic name | M35677
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Low posterior hairline
Full description | Hair on the neck extends more inferiorly than usual. [PMID:19125436]

Standard name | HP_NAIL_DYSPLASIA
Systematic name | M35678
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Nail dysplasia
Full description | The presence of developmental dysplasia of the nail. [HPO:probinson]

Standard name | HP_IMPAIRED_VIBRATION_SENSATION_IN_THE_LOWER_LIMBS
Systematic name | M35679
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Impaired vibration sensation in the lower limbs
Full description | A decrease in the ability to perceive vibration in the legs. [HPO:curators]

Standard name | HP_NEUROLOGICAL_SPEECH_IMPAIRMENT
Systematic name | M35680
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neurological speech impairment
Full description |

Standard name | HP_SCANNING_SPEECH
Systematic name | M35681
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Scanning speech
Full description |

Standard name | HP_CLONUS
Systematic name | M35682
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Clonus
Full description | A series of rhythmic and involuntary muscle contractions (at a frequency of about 5 to 7 Hz) that occur in response to an abruptly applied and sustained stretch. [HPO:probinson]

Standard name | HP_INTRACRANIAL_HEMORRHAGE
Systematic name | M35683
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Intracranial hemorrhage
Full description | Hemorrhage occurring within the skull. [HPO:gcarletti]

Standard name | HP_GLIOSIS
Systematic name | M35684
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gliosis
Full description | Gliosis is the focal proliferation of glial cells in the central nervous system. [HPO:sdoelken]

Standard name | HP_POSTURAL_INSTABILITY
Systematic name | M35685
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Postural instability
Full description | A tendency to fall or the inability to keep oneself from falling; imbalance. The retropulsion test is widely regarded as the gold standard to evaluate postural instability, Use of the retropulsion test includes a rapid balance perturbation in the backward direction, and the number of balance correcting steps (or total absence thereof) is used to rate the degree of postural instability. Healthy subjects correct such perturbations with either one or two large steps, or without taking any steps, hinging rapidly at the hips while swinging the arms forward as a counterweight. In patients with balance impairment, balance correcting steps are often too small, forcing patients to take more than two steps. Taking three or more steps is generally considered to be abnormal, and taking more than five steps is regarded as being clearly abnormal. Markedly affected patients continue to step backward without ever regaining their balance and must be caught by the examiner (this would be called true retropulsion). Even more severely affected patients fail to correct entirely, and fall backward like a pushed toy soldier, without taking any corrective steps. [PMID:25613349]

Standard name | HP_HYPOGLYCEMIC_SEIZURES
Systematic name | M35686
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoglycemic seizures
Full description |

Standard name | HP_POSTURAL_TREMOR
Systematic name | M35687
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Postural tremor
Full description | A type of tremors that is triggered by holding a limb in a fixed position. [HPO:probinson]

Standard name | HP_SPINAL_CORD_COMPRESSION
Systematic name | M35688
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Spinal cord compression
Full description | External mechanical compression of the spinal cord. [HPO:probinson]

Standard name | HP_OPISTHOTONUS
Systematic name | M35689
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Opisthotonus
Full description |

Standard name | HP_NEURODEGENERATION
Systematic name | M35690
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neurodegeneration
Full description | Progressive loss of neural cells and tissue. [HPO:probinson]

Standard name | HP_CEREBRAL_EDEMA
Systematic name | M35691
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cerebral edema
Full description | Abnormal accumulation of fluid in the brain. [HPO:probinson]

Standard name | HP_PHONOPHOBIA
Systematic name | M35692
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Phonophobia
Full description | An abnormally heightened sensitivity to loud sounds. [HPO:probinson]

Standard name | HP_NEUROFIBRILLARY_TANGLES
Systematic name | M35693
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Neurofibrillary tangles
Full description | Pathological protein aggregates formed by hyperphosphorylation of a microtubule-associated protein known as tau, causing it to aggregate in an insoluble form. [HPO:sdoelken]

Standard name | HP_APRAXIA
Systematic name | M35694
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Apraxia
Full description | A defect in the understanding of complex motor commands and in the execution of certain learned movements, i.e., deficits in the cognitive components of learned movements. [HPO:probinson]

Standard name | HP_INTELLECTUAL_DISABILITY_PROFOUND
Systematic name | M35695
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Intellectual disability, profound
Full description | Profound mental retardation is defined as an intelligence quotient (IQ) below 20. [HPO:probinson]

Standard name | HP_DELAYED_CNS_MYELINATION
Systematic name | M35696
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delayed CNS myelination
Full description | Delayed myelination in the central nervous system. [HPO:probinson]

Standard name | HP_CHOROID_PLEXUS_CYST
Systematic name | M35697
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Choroid plexus cyst
Full description | A cyst occurring within the choroid plexus within a cerebral ventricle. [HPO:probinson]

Standard name | HP_PROGRESSIVE_SPASTICITY
Systematic name | M35698
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Progressive spasticity
Full description | Spasticity that increases in degree with time. [HPO:probinson]

Standard name | HP_PSEUDOBULBAR_BEHAVIORAL_SYMPTOMS
Systematic name | M35699
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pseudobulbar behavioral symptoms
Full description | Individuals with Pseudobulbar signs often also demonstrate abnormal behavioral symptoms such as inappropriate emotional outbursts of uncontrolled laughter or weeping etc. [HPO:sdoelken]

Standard name | HP_DELAYED_GROSS_MOTOR_DEVELOPMENT
Systematic name | M35700
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Delayed gross motor development
Full description | A type of motor delay characterized by a delay in acquiring the ability to control the large muscles of the body for walking, running, sitting, and crawling. [HPO:probinson]

Standard name | HP_DYSGENESIS_OF_THE_CEREBELLAR_VERMIS
Systematic name | M35701
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dysgenesis of the cerebellar vermis
Full description | Defective development of the vermis of cerebellum. [HPO:probinson]

Standard name | HP_MYELOPATHY
Systematic name | M35702
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Myelopathy
Full description |

Standard name | HP_GENERALIZED_ONSET_SEIZURE
Systematic name | M35703
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Generalized-onset seizure
Full description | A generalized-onset seizure is a type of seizure originating at some point within, and rapidly engaging, bilaterally distributed networks. The networks may include cortical and subcortical structures but not necessarily the entire cortex. [HPO:probinson, PMID:20196795, PMID:23739099, PMID:28276060, PMID:28276064, PMID:6790275]

Standard name | HP_HYPOCALCEMIC_SEIZURES
Systematic name | M35704
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypocalcemic seizures
Full description |

Standard name | HP_PSEUDOBULBAR_SIGNS
Systematic name | M35705
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pseudobulbar signs
Full description | Pseudobulbar signs result from injury to an upper motor neuron lesion to the corticobulbar pathways in the pyramidal tract. Patients have difficulty chewing, swallowing and demonstrate slurred speech (often initial presentation) as well as abnormal behavioral symptoms such as inappropriate emotional outbursts of uncontrolled laughter or weeping etc. [HPO:sdoelken]

Standard name | HP_PLEURAL_EFFUSION
Systematic name | M35706
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pleural effusion
Full description | The presence of an excessive amount of fluid in the pleural cavity. [HPO:probinson]

Standard name | HP_RESPIRATORY_PARALYSIS
Systematic name | M35707
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Respiratory paralysis
Full description | Inability to move the muscles of respiration. [HPO:probinson]

Standard name | HP_PULMONARY_EMBOLISM
Systematic name | M35708
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pulmonary embolism
Full description | An embolus (that is, an abnormal particle circulating in the blood) located in the pulmonary artery and thereby blocking blood circulation to the lung. Usually the embolus is a blood clot that has developed in an extremity (for instance, a deep venous thrombosis), detached, and traveled through the circulation before becoming trapped in the pulmonary artery. []

Standard name | HP_PULMONARY_FIBROSIS
Systematic name | M35709
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pulmonary fibrosis
Full description | Replacement of normal lung tissues by fibroblasts and collagen. [DDD:tkuijpers, HPO:probinson]

Standard name | HP_COARSE_HAIR
Systematic name | M35710
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Coarse hair
Full description | Hair shafts are rough in texture. [HPO:probinson]

Standard name | HP_SPARSE_SCALP_HAIR
Systematic name | M35711
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sparse scalp hair
Full description | Decreased number of hairs per unit area of skin of the scalp. [PMID:19125436, PMID:28061825]

Standard name | HP_WHITE_FORELOCK
Systematic name | M35712
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | White forelock
Full description | A triangular depigmented region of white hairs located in the anterior midline of the scalp. [DDD:probinson]

Standard name | HP_CURLY_HAIR
Systematic name | M35713
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Curly hair
Full description |

Standard name | HP_FINE_HAIR
Systematic name | M35714
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Fine hair
Full description | Hair that is fine or thin to the touch. [HPO:probinson]

Standard name | HP_PREMATURE_GRAYING_OF_HAIR
Systematic name | M35715
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Premature graying of hair
Full description | Development of gray hair at a younger than normal age. [HPO:probinson]

Standard name | HP_FACIAL_HYPERTRICHOSIS
Systematic name | M35716
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Facial hypertrichosis
Full description | Excessive, increased hair growth located in the facial region. []

Standard name | HP_ABSENT_AXILLARY_HAIR
Systematic name | M35717
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Absent axillary hair
Full description | Absence of axillary hair. [HPO:probinson]

Standard name | HP_ABSENT_EYEBROW
Systematic name | M35718
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Absent eyebrow
Full description | Absence of the eyebrow. [HPO:probinson]

Standard name | HP_WOOLLY_HAIR
Systematic name | M35719
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Woolly hair
Full description | The term woolly hair refers to an abnormal variant of hair that is fine, with tightly coiled curls, and often hypopigmented. Optical microscopy may reveal the presence of tight spirals and a clear diameter reduction as compared with normal hair. Electron microscopy may show flat, oval hair shafts with reduced transversal diameter. [PMID:20464096]

Standard name | HP_WHITE_EYEBROW
Systematic name | M35720
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | White eyebrow
Full description | White color (lack of pigmentation) of the eyebrow. [HPO:probinson]

Standard name | HP_GENERALIZED_HIRSUTISM
Systematic name | M35721
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Generalized hirsutism
Full description | Abnormally increased hair growth over much of the entire body. [HPO:curators]

Standard name | HP_SPARSE_BODY_HAIR
Systematic name | M35722
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sparse body hair
Full description | Sparseness of the body hair. [HPO:probinson]

Standard name | HP_PATCHY_ALOPECIA
Systematic name | M35723
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Patchy alopecia
Full description | Transient, non-scarring hair loss and preservation of the hair follicle located in in well-defined patches. []

Standard name | HP_PILI_CANALICULI
Systematic name | M35724
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Pili canaliculi
Full description | Uncombable hair. [HPO:probinson]

Standard name | HP_FRONTAL_UPSWEEP_OF_HAIR
Systematic name | M35725
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Frontal upsweep of hair
Full description | Upward and/or sideward growth of anterior hair. [PMID:19125436]

Standard name | HP_GASTROINTESTINAL_HEMORRHAGE
Systematic name | M35726
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gastrointestinal hemorrhage
Full description | Hemorrhage affecting the gastrointestinal tract. [HPO:probinson]

Standard name | HP_HEPATOMEGALY
Systematic name | M35727
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hepatomegaly
Full description | Abnormally increased size of the liver. [HPO:probinson]

Standard name | HP_ABNORMAL_INTESTINE_MORPHOLOGY
Systematic name | M35728
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal intestine morphology
Full description | An abnormality of the intestine. The closely related term enteropathy is used to refer to any disease of the intestine. [HPO:probinson]

Standard name | HP_PROTEIN_LOSING_ENTEROPATHY
Systematic name | M35729
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Protein-losing enteropathy
Full description | Abnormal loss of protein from the digestive tract related to excessive leakage of plasma proteins into the lumen of the gastrointestinal tract. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_SMALL_INTESTINE
Systematic name | M35730
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the small intestine
Full description | An abnormality of the small intestine. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_DUODENUM
Systematic name | M35731
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the duodenum
Full description | An abnormality of the duodenum, i.e., the first section of the small intestine. [HPO:probinson]

Standard name | HP_DUODENAL_ATRESIA
Systematic name | M35732
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Duodenal atresia
Full description | A developmental defect resulting in complete obliteration of the duodenal lumen, that is, an abnormal closure of the duodenum. [HPO:probinson]

Standard name | HP_HEMATEMESIS
Systematic name | M35733
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hematemesis
Full description | The vomiting of blood. [HPO:probinson]

Standard name | HP_MELENA
Systematic name | M35734
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Melena
Full description | The passage of blackish, tarry feces associated with gastrointestinal hemorrhage. Melena occurs if the blood remains in the colon long enough for it to be broken down by colonic bacteria. One degradation product, hematin, imbues the stool with a blackish color. Thus, melena generally occurs with bleeding from the upper gastrointestinal tract (e.g., stomach ulcers or duodenal ulcers), since the blood usually remains in the gut for a longer period of time than with lower gastrointestinal bleeding. [HPO:probinson]

Standard name | HP_ABNORMAL_LARGE_INTESTINE_MORPHOLOGY
Systematic name | M35735
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal large intestine morphology
Full description | Any abnormality of the large intestine. [HPO:probinson]

Standard name | HP_AGANGLIONIC_MEGACOLON
Systematic name | M35736
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aganglionic megacolon
Full description | An abnormality resulting from a lack of intestinal ganglion cells (i.e., an aganglionic section of bowel) that results in bowel obstruction with enlargement of the colon. [HPO:probinson, PMID:17965226]

Standard name | HP_COLONIC_DIVERTICULA
Systematic name | M35737
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Colonic diverticula
Full description | The presence of multiple diverticula of the colon. [HPO:probinson]

Standard name | HP_INTERMITTENT_DIARRHEA
Systematic name | M35738
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Intermittent diarrhea
Full description |

Standard name | HP_CHRONIC_RHINITIS
Systematic name | M35739
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Chronic rhinitis
Full description | Chronic inflammation of the nasal mucosa. [HPO:probinson]

Standard name | HP_EXAGGERATED_CUPID_S_BOW
Systematic name | M35740
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Exaggerated cupid's bow
Full description | More pronounced paramedian peaks and median notch of the Cupid's bow. [PMID:19125428]

Standard name | HP_LARGE_FLESHY_EARS
Systematic name | M35741
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Large fleshy ears
Full description |

Standard name | HP_FOCAL_CLONIC_SEIZURE
Systematic name | M35742
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Focal clonic seizure
Full description | A focal clonic seizure is a type of focal motor seizure characterized by sustained rhythmic jerking, that is regularly repetitive. [ORCID:0000-0002-1735-8178, PMID:11580774, PMID:28276060, PMID:28276064]

Standard name | HP_EXAGGERATED_STARTLE_RESPONSE
Systematic name | M35743
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Exaggerated startle response
Full description | An exaggerated startle reaction in response to a sudden unexpected visual or acoustic stimulus, or a quick movement near the face. [HPO:curators]

Standard name | HP_PAROXYSMAL_DYSTONIA
Systematic name | M35744
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Paroxysmal dystonia
Full description | A form of dystonia characterized by episodes of dystonia (often hemidystonia or generalized) lasting from minutes to hours. There are no dystonic symptoms between episodes. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_NEURONAL_MIGRATION
Systematic name | M35745
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of neuronal migration
Full description | An abnormality resulting from an anomaly of neuronal migration, i.e., of the process by which neurons travel from their origin to their final position in the brain. [HPO:probinson]

Standard name | HP_TETRAPARESIS
Systematic name | M35746
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Tetraparesis
Full description | Weakness of all four limbs. [HPO:probinson]

Standard name | HP_POOR_MOTOR_COORDINATION
Systematic name | M35747
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Poor motor coordination
Full description |

Standard name | HP_ENLARGED_CISTERNA_MAGNA
Systematic name | M35748
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Enlarged cisterna magna
Full description | Increase in size of the cisterna magna, one of three principal openings in the subarachnoid space between the arachnoid and pia mater, located between the cerebellum and the dorsal surface of the medulla oblongata. [HPO:probinson]

Standard name | HP_GRAY_MATTER_HETEROTOPIA
Systematic name | M35749
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Gray matter heterotopia
Full description | Heterotopia or neuronal heterotopia are macroscopic clusters of misplaced neurons (gray matter), most often situated along the ventricular walls or within the subcortical white matter. [COST:neuromig, ORCID:0000-0001-5208-3432, PMID:22427329, PMID:25180909, PMID:7524438]

Standard name | HP_GLOBAL_BRAIN_ATROPHY
Systematic name | M35750
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Global brain atrophy
Full description | Unlocalized atrophy of the brain with decreased total brain matter volume and increased ventricular size. [HPO:sdoelken]

Standard name | HP_FAIR_HAIR
Systematic name | M35751
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Fair hair
Full description | A lesser degree of hair pigmentation than would otherwise be expected. [DDD:cmoss]

Standard name | HP_ALOPECIA_UNIVERSALIS
Systematic name | M35752
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Alopecia universalis
Full description | Loss of all hair on the entire body. [HPO:probinson]

Standard name | HP_ALOPECIA_OF_SCALP
Systematic name | M35753
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Alopecia of scalp
Full description |

Standard name | HP_RED_HAIR
Systematic name | M35754
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Red hair
Full description |

Standard name | HP_ABSENT_HAIR
Systematic name | M35755
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Absent hair
Full description |

Standard name | HP_BRITTLE_HAIR
Systematic name | M35756
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Brittle hair
Full description | Fragile, easily breakable hair, i.e., with reduced tensile strength. [DDD:cmoss]

Standard name | HP_MUTISM
Systematic name | M35757
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Mutism
Full description |

Standard name | HP_HEMIPLEGIA
Systematic name | M35758
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hemiplegia
Full description | Paralysis (complete loss of muscle function) in the arm, leg, and in some cases the face on one side of the body. [HPO:curators]

Standard name | HP_AKINESIA
Systematic name | M35759
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Akinesia
Full description | Inability to initiate changes in activity or movement and to perform ordinary volitional movements rapidly and easily. [HPO:probinson]

Standard name | HP_ATHETOSIS
Systematic name | M35760
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Athetosis
Full description | A slow, continuous, involuntary writhing movement that prevents maintenance of a stable posture. Athetosis involves continuous smooth movements that appear random and are not composed of recognizable sub-movements or movement fragments. In contrast to chorea, in athetosis, the same regions of the body are repeatedly involved. Athetosis may worsen with attempts at movement of posture, but athetosis can also occur at rest. [HPO:probinson, PMID:20589866]

Standard name | HP_ARNOLD_CHIARI_MALFORMATION
Systematic name | M35761
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Arnold-Chiari malformation
Full description | Arnold-Chiari malformation consists of a downward displacement of the cerebellar tonsils and the medulla through the foramen magnum, sometimes causing hydrocephalus as a result of obstruction of CSF outflow. [HPO:curators]

Standard name | HP_OROFACIAL_DYSKINESIA
Systematic name | M35762
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Orofacial dyskinesia
Full description |

Standard name | HP_INCOORDINATION
Systematic name | M35763
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Incoordination
Full description |

Standard name | HP_CLUMSINESS
Systematic name | M35764
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Clumsiness
Full description | Lack of physical coordination resulting in an abnormal tendency to drop items or bump into objects. [HPO:probinson]

Standard name | HP_SPASTIC_PARAPARESIS
Systematic name | M35765
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Spastic paraparesis
Full description |

Standard name | HP_DEGENERATION_OF_THE_LATERAL_CORTICOSPINAL_TRACTS
Systematic name | M35766
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Degeneration of the lateral corticospinal tracts
Full description | Deterioration of the tissues of the lateral corticospinal tracts. [HPO:probinson]

Standard name | HP_HEADACHE
Systematic name | M35767
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Headache
Full description | Cephalgia, or pain sensed in various parts of the head, not confined to the area of distribution of any nerve. [HPO:probinson, PMID:15304572]

Standard name | HP_UNSTEADY_GAIT
Systematic name | M35768
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Unsteady gait
Full description |

Standard name | HP_CERVICAL_MYELOPATHY
Systematic name | M35769
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cervical myelopathy
Full description |

Standard name | HP_VERTIGO
Systematic name | M35770
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Vertigo
Full description | An abnormal sensation of spinning while the body is actually stationary. [HPO:probinson]

Standard name | HP_RESTING_TREMOR
Systematic name | M35771
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Resting tremor
Full description | A resting tremor occurs when muscles are at rest and becomes less noticeable or disappears when the affected muscles are moved. Resting tremors are often slow and coarse. [HPO:probinson, PMID:22675666]

Standard name | HP_ANENCEPHALY
Systematic name | M35772
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Anencephaly
Full description |

Standard name | HP_HYDRANENCEPHALY
Systematic name | M35773
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hydranencephaly
Full description | A defect of development of the brain characterized by replacement of greater portions of the cerebral hemispheres and the corpus striatum by cerebrospinal fluid (CSF) and glial tissue. [HPO:probinson]

Standard name | HP_TRANSIENT_ISCHEMIC_ATTACK
Systematic name | M35774
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Transient ischemic attack
Full description |

Standard name | HP_DROWSINESS
Systematic name | M35775
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Drowsiness
Full description | Excessive daytime sleepiness. [HPO:probinson]

Standard name | HP_RECURRENT_PAROXYSMAL_HEADACHE
Systematic name | M35776
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Recurrent paroxysmal headache
Full description | Repeated episodes of headache with rapid onset, reaching a peak within minutes and of short duration (less than one hour) with pain that is throbbing, pulsating, or bursting in quality. [HPO:probinson]

Standard name | HP_MOTOR_DETERIORATION
Systematic name | M35777
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Motor deterioration
Full description | Loss of previously present motor (i.e., movement) abilities. [HPO:probinson]

Standard name | HP_ABNORMALITY_OF_THE_CEREBELLAR_VERMIS
Systematic name | M35778
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of the cerebellar vermis
Full description | An anomaly of the vermis of cerebellum. [HPO:probinson]

Standard name | HP_AGENESIS_OF_CEREBELLAR_VERMIS
Systematic name | M35779
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Agenesis of cerebellar vermis
Full description | Congenital absence of the vermis of cerebellum. [HPO:probinson]

Standard name | HP_ABNORMAL_CAUDATE_NUCLEUS_MORPHOLOGY
Systematic name | M35780
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal caudate nucleus morphology
Full description | Any structural abnormality of the caudate nucleus. [HPO:probinson]

Standard name | HP_CAUDATE_ATROPHY
Systematic name | M35781
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Caudate atrophy
Full description |

Standard name | HP_CERVICAL_CORD_COMPRESSION
Systematic name | M35782
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cervical cord compression
Full description | Compression of the spinal cord in the cervical region, generally manifested by paresthesias and numbness, weakness, difficulty walking, abnormalities of coordination, and neck pain or stiffness. [HPO:probinson]

Standard name | HP_INTELLECTUAL_DISABILITY_MODERATE
Systematic name | M35783
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Intellectual disability, moderate
Full description | Moderate mental retardation is defined as an intelligence quotient (IQ) in the range of 35-49. [HPO:curators]

Standard name | HP_PROGRESSIVE_NEUROLOGIC_DETERIORATION
Systematic name | M35784
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Progressive neurologic deterioration
Full description |

Standard name | HP_ACTION_TREMOR
Systematic name | M35785
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Action tremor
Full description | A tremor present when the limbs are active, either when outstretched in a certain position or throughout a voluntary movement. [HPO:curators]

Standard name | HP_HEAD_TREMOR
Systematic name | M35786
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Head tremor
Full description | An unintentional, oscillating to-and-fro muscle movement affecting head movement. [HPO:probinson]

Standard name | HP_FOCAL_AWARE_SEIZURE
Systematic name | M35787
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Focal aware seizure
Full description | A type of focal-onset seizure in which awareness is preserved. Awareness during a seizure is defined as the patient being fully aware of themself and their environment throughout the seizure, even if immobile. [HPO:probinson, ORCID:0000-0002-1735-8178, PMID:28276060, PMID:28276062, PMID:28276064]

Standard name | HP_CEREBELLAR_CYST
Systematic name | M35788
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cerebellar cyst
Full description |

Standard name | HP_LEUKOENCEPHALOPATHY
Systematic name | M35789
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Leukoencephalopathy
Full description | This term describes abnormality of the white matter of the cerebrum resulting from damage to the myelin sheaths of nerve cells. [HPO:probinson]

Standard name | HP_MEMORY_IMPAIRMENT
Systematic name | M35790
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Memory impairment
Full description | An impairment of memory as manifested by a reduced ability to remember things such as dates and names, and increased forgetfulness. [HPO:probinson]

Standard name | HP_DIFFICULTY_WALKING
Systematic name | M35791
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Difficulty walking
Full description | Reduced ability to walk (ambulate). [HPO:probinson]

Standard name | HP_WRITER_S_CRAMP
Systematic name | M35792
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Writer's cramp
Full description | A focal dystonia of the fingers, hand, and/or forearm that appears when the affected person attempts to do a task that requires fine motor movements such as writing or playing a musical instrument. [HPO:probinson]

Standard name | HP_DYSPHASIA
Systematic name | M35793
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Dysphasia
Full description |

Standard name | HP_FREQUENT_FALLS
Systematic name | M35794
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Frequent falls
Full description |

Standard name | HP_SLEEP_DISTURBANCE
Systematic name | M35795
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Sleep disturbance
Full description | An abnormality of sleep including such phenomena as 1) insomnia/hypersomnia, 2) non-restorative sleep, 3) sleep schedule disorder, 4) excessive daytime somnolence, 5) sleep apnea, and 6) restlessness. [HPO:curators]

Standard name | HP_PSYCHOMOTOR_DETERIORATION
Systematic name | M35796
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Psychomotor deterioration
Full description | Loss of previously present mental and motor abilities. [HPO:probinson]

Standard name | HP_SHUFFLING_GAIT
Systematic name | M35797
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Shuffling gait
Full description | A type of gait (walking) characterized by by dragging one's feet along or without lifting the feet fully from the ground. []

Standard name | HP_ABNORMALITY_OF_BRAINSTEM_MORPHOLOGY
Systematic name | M35798
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormality of brainstem morphology
Full description | An anomaly of the brainstem. [HPO:probinson]

Standard name | HP_HYPOPLASIA_OF_THE_BRAINSTEM
Systematic name | M35799
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypoplasia of the brainstem
Full description | Underdevelopment of the brainstem. [HPO:probinson]

Standard name | HP_ABNORMAL_LOWER_MOTOR_NEURON_MORPHOLOGY
Systematic name | M35800
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Abnormal lower motor neuron morphology
Full description | Any structural anomaly of the lower motor neuron. [HPO:probinson]

Standard name | HP_VISUAL_HALLUCINATIONS
Systematic name | M35801
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Visual hallucinations
Full description |

Standard name | HP_POOR_COORDINATION
Systematic name | M35802
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Poor coordination
Full description |

Standard name | HP_LOSS_OF_SPEECH
Systematic name | M35803
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Loss of speech
Full description |

Standard name | HP_DIMINISHED_MOVEMENT
Systematic name | M35804
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Diminished movement
Full description |

Standard name | HP_HYPOKINESIA
Systematic name | M35805
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hypokinesia
Full description | Abnormally diminished motor activity. In contrast to paralysis, hypokinesia is not characterized by a lack of motor strength, but rather by a poverty of movement. The typical habitual movements (e.g., folding the arms, crossing the legs) are reduced in frequency. [HPO:probinson]

Standard name | HP_DEVELOPMENTAL_REGRESSION
Systematic name | M35806
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Developmental regression
Full description | Loss of developmental skills, as manifested by loss of developmental milestones. [DDD:hvfirth]

Standard name | HP_HAND_TREMOR
Systematic name | M35807
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Hand tremor
Full description | An unintentional, oscillating to-and-fro muscle movement affecting the hand. []

Standard name | HP_FASCICULATIONS
Systematic name | M35808
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Fasciculations
Full description | Fasciculations are observed as small, local, involuntary muscle contractions (twitching) visible under the skin. Fasciculations result from increased irritability of an axon (which in turn is often a manifestation of disease of a motor neuron). This leads to sporadic discharges of all the muscle fibers controlled by the axon in isolation from other motor units. [HPO:curators]

Standard name | HP_APHASIA
Systematic name | M35809
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aphasia
Full description | An acquired language impairment of some or all of the abilities to produce or comprehend speech and to read or write. []

Standard name | HP_ENCEPHALITIS
Systematic name | M35810
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Encephalitis
Full description |

Standard name | HP_FOCAL_IMPAIRED_AWARENESS_SEIZURE
Systematic name | M35811
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Focal impaired awareness seizure
Full description | Focal impaired awareness seizure (or focal seizure with impaired or lost awareness) is a type of focal-onset seizure characterized by some degree (which may be partial) of impairment of the person's awareness of themselves or their surroundings at any point during the seizure. [HPO:pnrobinson, PMID:28276062, PMID:28276064, PMID:9738682]

Standard name | HP_PARAPARESIS
Systematic name | M35812
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Paraparesis
Full description | Weakness or partial paralysis in the lower limbs. [HPO:probinson]

Standard name | HP_CAVUM_SEPTUM_PELLUCIDUM
Systematic name | M35813
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cavum septum pellucidum
Full description | If the two laminae of the septum pellucidum are not fused then a fluid-filled space or cavum is present. The cavum septum pellucidum is present at birth but usually obliterates by the age of 3 to 6 months. It is up to 1cm in width and the walls are parallel. It is an enclosed space and is not part of the ventricular system or connected with the subarachnoid space. [HPO:curators]

Standard name | HP_EEG_WITH_POLYSPIKE_WAVE_COMPLEXES
Systematic name | M35814
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | EEG with polyspike wave complexes
Full description | The presence of complexes of repetitive spikes and waves in EEG. [HPO:jalbers]

Standard name | HP_LOWER_LIMB_HYPERREFLEXIA
Systematic name | M35815
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Lower limb hyperreflexia
Full description |

Standard name | HP_COGWHEEL_RIGIDITY
Systematic name | M35816
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cogwheel rigidity
Full description | A type of rigidity in which a muscle responds with cogwheellike jerks to the use of constant force in bending the limb (i.e., it gives way in little, repeated jerks when the muscle is passively stretched). [HPO:probinson]

Standard name | HP_STROKE_LIKE_EPISODE
Systematic name | M35817
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Stroke-like episode
Full description | No consensus exists on what a stroke-like episode is, but these episodes can be functionally defined as a new neurological deficit, occurring with or without the context of seizures, which last longer than 24 hours. [PMID:22715346, PMID:23907585]

Standard name | HP_POSITIVE_ROMBERG_SIGN
Systematic name | M35818
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Positive Romberg sign
Full description | The patient stands with the feet placed together and balance and is asked to close his or her eyes. A loss of balance upon eye closure is a positive Romberg sign and is interpreted as indicating a deficit in proprioception. [HPO:probinson]

Standard name | HP_LIMB_DYSMETRIA
Systematic name | M35819
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Limb dysmetria
Full description | A type of dysmetria involving the limbs. [HPO:probinson]

Standard name | HP_CEREBRAL_ARTERIOVENOUS_MALFORMATION
Systematic name | M35820
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Cerebral arteriovenous malformation
Full description | An anomalous configuration of blood vessels that shunts arterial blood directly into veins without passing through the capillaries and that is located in the brain. []

Standard name | HP_AQUEDUCTAL_STENOSIS
Systematic name | M35821
Organism | Homo sapiens
PMID |
Authors |
Category | C5
Sub-category | HPO
Brief description | Aqueductal stenosis
Full description | Stenosis of the cerebral aqueduct (also known as the mesencephalic duct, aqueductus mesencephali, or aqueduct of Sylvius), which connects the third cerebral ventricle in the diencephalon to the fourth ventricle, which is between the pons and cerebellum. [HPO:curators]

Standard name | HP_MYOKYMIA
Systematic name | M35822
[member cut: first 33554432 bytes kept]
